package main

import (
	"testing"

	"github.com/knqyf263/go-cpe/naming"
	"github.com/knqyf263/go-cpe/matching"
)

func TestCompare(t *testing.T) {
    vectors := []struct {
		uri       string
		fs        string
	}{
     
    {
        uri: `cpe:/a:%240.99_kindle_books_project:%240.99_kindle_books:6::~~~android~~`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.16.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1024cms:1024_cms:0.7`,
        fs:  `cpe:2.3:a:f5:big-ip:9.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1024cms:1024_cms:1.2.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30173:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1024cms:1024_cms:1.3.1`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:003p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1024cms:1024_cms:1.4.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sru:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1024cms:1024_cms:1.4.2`,
        fs:  `cpe:2.3:h:huawei:ar_18-3x:r0118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1024cms:1024_cms:1.4.2:beta`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_hydravision_full:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1024cms:1024_cms:2.1.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:11in1:11in1:1.2.1:stable_12-31-2011`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:129zou:zombie_diary:1.2.2::~~~android~~`,
        fs:  `cpe:2.3:a:emc:watch4net:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.14.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:openshift:2.0.5:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:giflib_project:giflib:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:quicktime_broadcaster:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:perl:perl:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:networker:7.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:12net:login_rebuilder:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite_sql-server:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:133:flight_manager:4::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15.1\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:163:netease_movie:4.7.2::~~~android~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1800contacts:1800contacts_app:2.7.0::~~~android~~`,
        fs:  `cpe:2.3:a:atmail:atmail:6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1kxun:qianxun_yingshi:1.2.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1673.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:1kxun:qianxun_yingshi:1.3.4`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2g_live_tv_project:2g_live_tv:0.9::~~~android~~`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:0.9.1:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:teamviewer:teamviewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:0.9.2:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:gnu:fileutils:4.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:0.9.4:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-26c-pwr-ei_ls-5100-26c-pwr-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:0.9.5:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:0.9.6:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:h:cisco:nexus_5596up_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:0.9.7:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:o:vmware:photon_os:1.0:2016-08-14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.1:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.2:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.3:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.4:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.5:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.6:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.7:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.6.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.8:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2glux:com_sexypolling:1.0.9:-:~-~-~joomla%21~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:2rv:dr._sheikh_adnan_ibrahim:1::~~~android~~`,
        fs:  `cpe:2.3:a:roxio:creator_content:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:30a:30a:5.26.2::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:141701:-`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c13612:-`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c13613:-`,
        fs:  `cpe:2.3:a:buffalotech:wer-amg54_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c13616:-`,
        fs:  `cpe:2.3:a:qemu:qemu:1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c13700:-`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c13750:-`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c13754:-`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c13758:-`,
        fs:  `cpe:2.3:a:apple:quicktime:6.4.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3c15100d:-`,
        fs:  `cpe:2.3:a:skyarts:neofiler:2.4.2:-:-:*:lite:android:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3c16115-us:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3c16115-us:2.01`,
        fs:  `cpe:2.3:a:gnu:chess:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3c16116-us:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3c16116-us:2.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16450-us:-`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_320_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16450-us:2.15`,
        fs:  `cpe:2.3:a:hp:loadrunner:12.50:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16450-us:2.16`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16479:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16485:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16486:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.08.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16486:1.0.2`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16811-us:-`,
        fs:  `cpe:2.3:a:python:python:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16950-us:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_supervisor_mse_8050_software:2.1\(1.18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16950-us:2.67`,
        fs:  `cpe:2.3:a:quest:intrust:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16950-us:2.68`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16986a-us:-`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16987a-us:-`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c16988a-us:-`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.1.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17100-us:-`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17203-us:-`,
        fs:  `cpe:2.3:a:apache:axis:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17204-us:-`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17205-us:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17210-us:-`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17300:-`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17302:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17304:-`,
        fs:  `cpe:2.3:a:horde:imp:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17400:-`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17401:-`,
        fs:  `cpe:2.3:a:apple:webkit:312.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17701-us:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17702-us:-`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17706-us:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17707-us:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17708-us:-`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c17709-us:-`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c250100a:-`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:7.3.2.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c39024-us:-`,
        fs:  `cpe:2.3:h:ge:multilink_ml1200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c6012-901:-`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:7.6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c6012-902:-`,
        fs:  `cpe:2.3:a:microsoft:outlook:2010:sp1:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c840-us:-`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c8432:-`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c8462:-`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite_java_system_web_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3c8532:-`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cb9e16:-`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3cdaemon:-`,
        fs:  `cpe:2.3:a:digia:qt:4.6.5:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cnj220:-`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cnj220:2.0.22`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cp4144:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cp4144:1.1.7`,
        fs:  `cpe:2.3:a:ca:directory:r12:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cp4144:1.1.9`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cp4144:1.1.9.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.3.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cr29223:-`,
        fs:  `cpe:2.3:a:sonicwall:aventail_webifiers:10.3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cr860-95:-`,
        fs:  `cpe:2.3:a:opnet:license_server:16.0.0.10106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3cradsl72:-`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crtpx505-73:-`,
        fs:  `cpe:2.3:h:rockwellautomation:micrologix_1100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.1:ea7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:1.0.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.50:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:1.0.2.11`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8s\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:1.0.3.5`,
        fs:  `cpe:2.3:a:clamav:clamav:0.95.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:1.02.00`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:1.02.11`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.361:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:1.03.05`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:1.03.07`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:2.1.1.710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe454g72:1.03.07a`,
        fs:  `cpe:2.3:a:opnet:license_server:15.0.0.8631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe554g72t:-`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe747a:-`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe754g72-a:-`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe754g72-a:1.13`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe754g72-a:1.23`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe754g72-a:1.24`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:2.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crwe754g72-a:1.27`,
        fs:  `cpe:2.3:a:hummingbird:docs_fusion_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:3crx506-96:-`,
        fs:  `cpe:2.3:o:juniper:junos:16.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3cserver:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3cserver:1.1`,
        fs:  `cpe:2.3:h:dell:3110cn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3ctftpsvc:-`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:3ctftpsvc:2.0.1`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:hiperarc:4.2.29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:nbx_1000:-`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:netbuilder_2_bridge_router:-`,
        fs:  `cpe:2.3:h:sophos:unified_threat_management:320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:superstack_3_switch_4924:-`,
        fs:  `cpe:2.3:a:facebook_like_box_project:facebook_like_box:2.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:superstack_ii_2000:-`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b1:pk3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:switch_4005:-`,
        fs:  `cpe:2.3:a:docker:docker:0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:switch_4007r:-`,
        fs:  `cpe:2.3:a:compuware:servervantage_agent:10.2.734:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tftp_server:1.05`,
        fs:  `cpe:2.3:a:docker:docker:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_200:-`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.4:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_200e:-`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_2400e:-`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.7.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_50:-`,
        fs:  `cpe:2.3:a:alsunna_project:alsunna:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_5000e:-`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_600e:-`,
        fs:  `cpe:2.3:h:hp:j9641a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips:-`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_ips:-`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_ips_1200e:-`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.1.3.6323`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta34:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.1.3.6323`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.1.4.6324`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.1.4.6324`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.2`,
        fs:  `cpe:2.3:a:gnu:automake:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.2`,
        fs:  `cpe:2.3:a:apache:hadoop:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.2.0.6504`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.2.0.6504`,
        fs:  `cpe:2.3:a:sir:gnuboard:4.34.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.2.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.223.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.2.1`,
        fs:  `cpe:2.3:a:novaces:concerto_web:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.2.1.6506`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.2.1.6506`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.2.2`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.2.2`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.2.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.2.3`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.2.3.6514`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.2.3.6514`,
        fs:  `cpe:2.3:a:bitrix:mpbuilder:1.0.11:*:*:*:*:bitrix:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.2.4`,
        fs:  `cpe:2.3:a:apache:synapse:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.2.4`,
        fs:  `cpe:2.3:h:swann:srnvw-470lcd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.5`,
        fs:  `cpe:2.3:a:adobe:photoshop:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_ips_tos:2.5.1`,
        fs:  `cpe:2.3:a:ibm:informix_extended_parallel_server:8.40_uc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:3com:tippingpoint_ips_tos:2.5.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3com:tippingpoint_sms_client:3.1.1.7943`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_sms_server:-`,
        fs:  `cpe:2.3:a:samba:samba:2.2.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:tippingpoint_sms_server:2.2.1.4477`,
        fs:  `cpe:2.3:a:wave:preboot_manager:3.0.0.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:total_control_netserver_card:-`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_141:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:total_control_netserver_card:3.7.24`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:webbngss3nbxnts:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.13:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:webbngss3nbxnts:4.0.17`,
        fs:  `cpe:2.3:a:ipswitch:imail:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:webbngss3nbxnts:4.1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:webbngss3nbxnts:4.1.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:3com:webbngss3nbxnts:4.2.7`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3dprotect:3d_eqsecure:4.2:-:professional`,
        fs:  `cpe:2.3:a:juniper:networks_mobility_system_software:7.5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3ds:3dvia_composer:6.8.1.1652`,
        fs:  `cpe:2.3:h:3com:3c17302:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3ivx:mpeg-4:4.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3ivx:mpeg-4:4.5.1`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3ivx:mpeg-4:5.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3ivx:mpeg-4:5.0.1`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.47:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3ivx:mpeg-4:5.0.2`,
        fs:  `cpe:2.3:a:microsoft:ie:4.0.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3par:inform_command_line_interface:2.3.1.330`,
        fs:  `cpe:2.3:a:netscape:navigator:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3par:inform_management_console:4.1.1.5`,
        fs:  `cpe:2.3:a:otrs:otrs:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.5.1`,
        fs:  `cpe:2.3:a:infor:eclient:7.3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.5.2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.5.3`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(14\)w5\(20\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.7.0`,
        fs:  `cpe:2.3:h:hp:laserjet_9000_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.8.0`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:17.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.8.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.8.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.1`,
        fs:  `cpe:2.3:a:cisco:business_edition_3000_software:8.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.2`,
        fs:  `cpe:2.3:o:f5:tmos:9.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.3`,
        fs:  `cpe:2.3:a:solarwinds:integrated_virtual_infrastructure_monitor:1.1.674.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.18`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.19`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.27`,
        fs:  `cpe:2.3:a:apple:pages:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_gateway-server:2.3.9.38`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_runtime_system:-`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-51-\/b:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_runtime_system:2.3.9.8`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.00:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_runtime_system:2.3.9.35`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_runtime_system:2.3.9.36`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_runtime_system:2.3.9.37`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:945shg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3s-software:codesys_runtime_system:2.3.9.47`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:3sgroup:t2css:2.0`,
        fs:  `cpe:2.3:a:privatemsg_project:privatemsg:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:4t-niagara:tray_minimizer_free:4.40`,
        fs:  `cpe:2.3:a:google:chrome:4.0.250.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:4t-niagara:tray_minimizer_pro:4.40`,
        fs:  `cpe:2.3:a:keepass:keepass:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:4you-studio:com_jphone:1.0:alpha3`,
        fs:  `cpe:2.3:o:cisco:vpn_3060_concentrator:4.7.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:4you-studio:com_jphone:1.0:alpha4`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:63reasons:supercron:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:6677g:girls_games_-_shoes_maker:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:webmin:usermin:1.040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:3.13`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.20`,
        fs:  `cpe:2.3:a:brian_akers:mod_layout:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.23`,
        fs:  `cpe:2.3:a:lunascape:ilunascape_android:1.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.24:beta`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.25:beta`,
        fs:  `cpe:2.3:a:nuance:openspeech_recognizer:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.26:beta`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.27:beta`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.28:beta`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.29:beta`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.30:beta`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.31`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.32`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.33:beta`,
        fs:  `cpe:2.3:o:schneider-electric:telvent_sage_3030_firmware:c3413-500-001d3_p4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.34:beta`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.30.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.35:beta`,
        fs:  `cpe:2.3:a:atmail:atmail:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.36:beta`,
        fs:  `cpe:2.3:a:mcafee:antivirus_engine:4.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.37:beta`,
        fs:  `cpe:2.3:a:ibm:client_access:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.38:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.39:beta`,
        fs:  `cpe:2.3:a:samba:samba:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.40:beta`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.41:beta`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.42`,
        fs:  `cpe:2.3:a:symantec:netbackup_opscenter:7.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.43:beta`,
        fs:  `cpe:2.3:a:ca:etrust_directory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.44:beta`,
        fs:  `cpe:2.3:o:cisco:ios:15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.45:beta`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.46:beta`,
        fs:  `cpe:2.3:a:hp:application_lifecycle_management:11.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.47:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.48:beta`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.49:beta`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.9\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.50:beta`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.51:beta`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.52:beta`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p144:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.53:beta`,
        fs:  `cpe:2.3:h:d-link:dap-2230:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.54:beta`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.55:beta`,
        fs:  `cpe:2.3:o:wdc:my_net_firmware:1.06.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.56:beta`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.57`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.58:beta`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.59:beta`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.60:beta`,
        fs:  `cpe:2.3:h:juniper:idp8200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.61:beta`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.15-63.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.62`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_customer_relationship_management:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.63`,
        fs:  `cpe:2.3:a:adobe:widget_browser:2.0_build_230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.64`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.65`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:4.65::~~~~x64~`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.8dv:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.04:beta`,
        fs:  `cpe:2.3:a:oracle:agile_product_lifecycle_management:9.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.06:beta`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.07:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.10:beta`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.210.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.11:beta`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.12:beta`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.13:beta`,
        fs:  `cpe:2.3:a:ceph:ceph-deploy:1.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.20`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.20::~~~~x64~`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:9.22:beta`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7-zip:15.14`,
        fs:  `cpe:2.3:h:asus:rt-n14u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7zip:9.20`,
        fs:  `cpe:2.3:a:cisco:content_distribution_manager_4630:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:7zip:15.05:beta`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:0.80`,
        fs:  `cpe:2.3:h:intel:active_management_technology:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:0.81`,
        fs:  `cpe:2.3:a:gnome:glib:2.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:0.90`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:0.91`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.10`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.12`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.13`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.14.01`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview_os_390:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.16`,
        fs:  `cpe:2.3:a:yahoo:yui:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.18`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.20`,
        fs:  `cpe:2.3:a:eviware:soapui:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.27`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.29`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security:r73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.30`,
        fs:  `cpe:2.3:a:ibm:security_guardium:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.33`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.37`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.39`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bpet64g:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.42`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.43`,
        fs:  `cpe:2.3:a:google:chrome:10.0.645.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.44`,
        fs:  `cpe:2.3:a:ains:foiaxpress_ocr_service:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.45`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.47`,
        fs:  `cpe:2.3:a:landesk:landesk_management_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.48`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.49`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.51`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.53`,
        fs:  `cpe:2.3:a:keepass:keepass:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.55`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.37:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.57`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.58`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.138:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.61`,
        fs:  `cpe:2.3:a:python:python:2.7.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:4.65`,
        fs:  `cpe:2.3:h:cisco:ons_15454_sdh_multiservice_provisioning_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:9.04`,
        fs:  `cpe:2.3:a:web2py:web2py:1.89.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:9.20.1`,
        fs:  `cpe:2.3:a:gnu:tar:1.13.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7-zip:p7zip:16.02`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:7_habits_personal_development_project:7_habits_personal_development:1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.1.7.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7725:7725.com_three_kingdoms:2.4::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7andi-fs.co:denny%27s:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:citrix:access_gateway:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7andi-fs.co:denny%27s:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7andi-fs.co:denny%27s:2.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:ninjaforge:com_ninjaxplorer:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7andi-fs.co:denny%27s:2.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.351:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce_suite:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.2`,
        fs:  `cpe:2.3:a:docker:docker:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.3`,
        fs:  `cpe:2.3:a:microsoft:visual_j\#:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.4`,
        fs:  `cpe:2.3:a:ibm:rational_directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.5`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.1241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.6`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.7`,
        fs:  `cpe:2.3:a:john_koleszar:libvpx:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.8`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.0.9`,
        fs:  `cpe:2.3:a:pineapp:mail-secure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7mediaws:edutrac:1.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7sage:7sage_lsat_prep_-_proctor:2.1.1::~~~android~~`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7t:aquis:1.5`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update5:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7t:termis:2.0`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:7t:termis:2.10`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:9.dotpp.net:megalith:12`,
        fs:  `cpe:2.3:h:cisco:catalyst_4224:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:9.dotpp.net:megalith:27`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:9.dotpp.net:megalith:50`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:9.dotpp.net:megalith:51`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:9.dotpp.net:megalith:52`,
        fs:  `cpe:2.3:a:gnu:glibc:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:90meter:cac_smartcard_manager-90:1.1.1.6`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:90meter:cac_smartcard_manager-90:1.1.8`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:90meter:cac_smartcard_manager-90:1.2.04`,
        fs:  `cpe:2.3:a:hp:webproxy:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:90meter:cac_smartcard_manager-90:1.2.14`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:90meter:card_issuance_workstation:1.00.130`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.616:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:99only:buy_99_cents_only_products:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:9bis:kitty:0.66.6.3`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:9gag:9gag_-_funny_pics_and_videos:2.4.10::~~~android~~`,
        fs:  `cpe:2.3:a:ows:scald:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:9jacompass:epl_hat_trick:1::~~~android~~`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:a-pdf:restrictions_remover:1.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:a10networks:advanced_core_operating_system:2.7.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_chargeback_manager:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:a10networks:advanced_core_operating_system:2.7.1`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.0.72.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:a9tech:a9cad:2.2.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aas9:zerocms:1.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aas9:zerocms:1.3.2`,
        fs:  `cpe:2.3:a:avonesoft:rm_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aas9:zerocms:1.3.3`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ab_google_map_travel_project:ab_google_map_travel:3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abb:datamanager:1.0.0`,
        fs:  `cpe:2.3:a:redhat:rhel_virtualization:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abb:datamanager:6.3.6`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abb:panel_builder_800:5.1`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abb:robotstudio:5.60`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.3:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abb:robotstudio:5.61`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(5.35\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abb:robotstudio:5.61.01`,
        fs:  `cpe:2.3:a:xnview:xnview:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abb:test_signal_viewer:1.5`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:4.1`,
        fs:  `cpe:2.3:a:phpjabbers:event_booking_calendar:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:5.0:-:office`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:5.0:-:pro`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:6.0`,
        fs:  `cpe:2.3:a:oracle:application_object_library:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:6.0:-:corporate`,
        fs:  `cpe:2.3:a:connections_project:connections:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:6.0:-:pro`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:15.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:7.0:-:corporate`,
        fs:  `cpe:2.3:a:avast:free_antivirus:11.1.2261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:7.0:-:pro`,
        fs:  `cpe:2.3:h:netgear:wgr614:v1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:8.0:-:corporate`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:8.0:-:pro`,
        fs:  `cpe:2.3:a:apache:poi:3.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:9.0:-:corporate`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:9.0:-:pro`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.238:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:10.0:-:corporate`,
        fs:  `cpe:2.3:a:penguinchefshop_project:penguinchefshop:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:10.0:-:pro`,
        fs:  `cpe:2.3:a:rim:blackberry_desktop_software:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader:10.0:-:site_license`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader_sprint:5.0.0.22227`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader_sprint:6.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader_sprint:6.0.1395.4512`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader_sprint:6.0.1735.41615`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:9.6.0-051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader_sprint:6.0.1990.41618`,
        fs:  `cpe:2.3:a:altiris:recovery_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader_sprint:9.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abbyy:finereader_sprint_plus:6.0`,
        fs:  `cpe:2.3:a:mixpanel_project:mixpanel:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.1`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.1.1`,
        fs:  `cpe:2.3:a:autodesk:dwf_viewer:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.1.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc101a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.2.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert14:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.2.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.84.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.2.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.2.3`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.2.4`,
        fs:  `cpe:2.3:a:microsoft:word:97:sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.2.5`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.2.6`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.2.7`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.3.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.14.2:beta:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.3.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.3.2`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:0.3.3`,
        fs:  `cpe:2.3:a:radio_de_la_cato_project:radio_de_la_cato:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:1.0.0`,
        fs:  `cpe:2.3:a:c-3.co.jp:webcalenderc3:0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:1.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.0.0`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.1.0`,
        fs:  `cpe:2.3:a:opscode:chef:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.0`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.1`,
        fs:  `cpe:2.3:a:lsoft:listserv:14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.2`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.3`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.4`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.5`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.2:-:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.6`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.7`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.8`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abeel:simple_php_agenda:2.2.9`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_direct_user_interface:1.4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abine:donottrackme_-_mobile_privacy:1.1.8::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:frontpage:98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abrahamtours:abraham_tours:1.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.563.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:absolute:computrace:8.0.885`,
        fs:  `cpe:2.3:a:agilebits:knox:2.0.1:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:absolutefuturity:af_imagegrabber:1.0.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:absolutengine:absolut_engine:1.73`,
        fs:  `cpe:2.3:h:hp:9500_vpn_firewall_module:jd245a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abtei-neuburg:stift_neuburg:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:solaris_cluster:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abu_ali_anasheeds_project:abu_ali_anasheeds:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.4:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:abushhab:alwasel:1.5`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accadvocacy:acc_advocacy_action:2::~~~android~~`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:5.0.0.16964:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accelatech:bizsearch:3.2:-:~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:socketmail:socketmail:2.2.9:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accelatech:bizsearch:3.2:-:~~~sunos~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accellion:kiteworks_appliance:kw2016.03.00`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0`,
        fs:  `cpe:2.3:h:airvana:hubbub_c1-600-rt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.1`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.3`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.4`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.5`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.6`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.7`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.8`,
        fs:  `cpe:2.3:a:apple:safari:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.0.9`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.0`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.647.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.2`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.3`,
        fs:  `cpe:2.3:a:s9y:serendipity:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.4`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:27.32.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.5`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper_live_streaming_integration:4.29.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(14\)s7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.7`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.8`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.1.9`,
        fs:  `cpe:2.3:a:microsoft:lync_basic:2013:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.2.0`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.2.0:b`,
        fs:  `cpe:2.3:h:hp:j9850a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.2.1`,
        fs:  `cpe:2.3:a:stillbreathing:bannerman:0.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.3.0`,
        fs:  `cpe:2.3:a:adobe:spelling_dictionaries_support_for_adobe_reader:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.3.0:b`,
        fs:  `cpe:2.3:a:google:chrome:4.0.302.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.3.1`,
        fs:  `cpe:2.3:a:debian:cifs-utils:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.3.2`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:2.1.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.3.3`,
        fs:  `cpe:2.3:o:cisco:unified_wireless_ip_phone_7920_firmware:1.0\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.3.4`,
        fs:  `cpe:2.3:a:gnu:glibc:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.3.5`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.4.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:1.4.1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit-32:10.20d\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:10.1.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:10.4.4`,
        fs:  `cpe:2.3:a:vmware:vma:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:10.4.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:10.4.6`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accomplishtechnology:phpmydirectory:11.04.00`,
        fs:  `cpe:2.3:a:skype:skype:1.0.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accunetix:web_vulnerability_scanner:10`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:accusoft:imagxpress:7.0.74.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.17.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acdsee:photo_editor_2008:5.0:build291`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acdsystems:acdsee:5.0.0::~~standard~~~`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:acer:ac700_chromebook:-`,
        fs:  `cpe:2.3:a:dart:powertcp_zip_compression:1.8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aceviral:angry_gran_toss:1.1.1::~~~android~~`,
        fs:  `cpe:2.3:o:redhat:linux:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acidcat:acidcat_cms:3.5.1`,
        fs:  `cpe:2.3:a:logitech:lws_gallery:13.20.1166.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acidcat:acidcat_cms:3.5.2`,
        fs:  `cpe:2.3:a:pkware:pkzip:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acidcat:acidcat_cms:3.5.6`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.7.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:acl:acl:9.1.0.213`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.6.0.1358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acm.org:er_assistant:2.0`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acmailer:acmailer:3.8`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acmailer:acmailer:3.8.17`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acmailer:acmailer:3.9`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acmailer:acmailer:3.9.10:beta`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:micro_httpd:-`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:mini_httpd:1.21`,
        fs:  `cpe:2.3:a:samba:samba:4.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:1.95`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.00`,
        fs:  `cpe:2.3:a:polycom:rmx_system_software:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.01`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.02`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.55:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.03`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.04`,
        fs:  `cpe:2.3:a:adobe:xmp_panels_cs3:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.05`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.1.122.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.06`,
        fs:  `cpe:2.3:h:cisco:sf302-08pp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.07`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.08`,
        fs:  `cpe:2.3:o:huawei:honor_4c_firmware:chm-tl00c01_b535:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.09`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:hu:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.11`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.12`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.13`,
        fs:  `cpe:2.3:a:google:chrome:14.0.811.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.14`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.2mb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.16`,
        fs:  `cpe:2.3:a:emc:networker:8.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.17`,
        fs:  `cpe:2.3:a:hp:vertica:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.18`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p242:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.19`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.20`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.66:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.20:b`,
        fs:  `cpe:2.3:o:oracle:opus_10g_ethernet_switch_family:1.3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.20:c`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.21`,
        fs:  `cpe:2.3:a:mozilla:mozilla_suite:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.21:b`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.5.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.22`,
        fs:  `cpe:2.3:a:hp:wbem:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.23`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.24`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.25`,
        fs:  `cpe:2.3:a:horde:groupware:5.0.4:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acme:thttpd:2.25:b`,
        fs:  `cpe:2.3:a:ibm:db2:11.1:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acobot_live_chat_%26_contact_form_project:acobot_live_chat_%26_contact_form:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:6.x-2.4`,
        fs:  `cpe:2.3:o:siemens:simatic_s7-1500_cpu_firmware:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:6.x-2.5`,
        fs:  `cpe:2.3:a:ding:ding_ezetop._top-up_any_phone:1.3.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:6.x-2.6`,
        fs:  `cpe:2.3:a:oracle:virtualization_secure_global_desktop:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:6.x-2.7`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:6.x-2.8`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:6.x-2.9`,
        fs:  `cpe:2.3:a:x:libxrandr:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:6.x-2.10`,
        fs:  `cpe:2.3:a:apple:itunes:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:oracle:marketing:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:7.x-3.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p321:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:7.x-3.1`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:7.x-3.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110813:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:commons:7.x-3.x:dev`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:mollom:6.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:mollom:6.x-2.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.15-25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:mollom:6.x-2.9::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:mollom:6.x-2.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.2.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:mollom:6.x-2.11::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:mollom:6.x-2.12::~~~drupal~~`,
        fs:  `cpe:2.3:h:hp:jg405a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:mollom:6.x-2.13::~~~drupal~~`,
        fs:  `cpe:2.3:o:redhat:certificate_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acquia:mollom:6.x-2.14::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acra:acra_library:-:-:~~~android~~`,
        fs:  `cpe:2.3:a:hp:serviceguard:a.11.16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_agent:10.0.11639`,
        fs:  `cpe:2.3:a:emc:networker:7.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_agent:10.0.12703`,
        fs:  `cpe:2.3:h:juniper:secure_access_4500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_agent:10.0.13545`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:101f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_agent:10.0.13762`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.1.4.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_agent:11.0.17217`,
        fs:  `cpe:2.3:h:hp:jc748a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_agent:11.0.17318`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_agent_core:11.0.17217`,
        fs:  `cpe:2.3:a:oracle:endeca_server:7.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_agent_core:11.0.17318`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_bootable_media_builder:10.0.11639`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.334:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_bootable_media_builder:10.0.13762`,
        fs:  `cpe:2.3:a:d.r.commander:libjpeg-turbo:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_bootable_media_builder:11.0.17217`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_management_console:10.0.11639`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0_pl1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_management_console:10.0.13545`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_management_console:10.0.13762`,
        fs:  `cpe:2.3:a:oracle:database_server:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_management_console:11.0.17318`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p313:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_management_server:11.0.17318`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.1:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_tray_monitor:10.0.11639`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_tray_monitor:11.0.17318`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_universal_restore:10.0.13545`,
        fs:  `cpe:2.3:a:gnome:glib:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_universal_restore:10.0.13762`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_universal_restore:11.0.17217`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_universal_restore:11.0.17318`,
        fs:  `cpe:2.3:a:tincan:phplist:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:backup_%26_recovery_upgrade_tool:10.0.11639`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.7.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:components_for_remote_installation:11.0.17318`,
        fs:  `cpe:2.3:o:cray:unicos:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:disk_director_server:10.0.2064`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:license_server:3.0.3470`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:license_server:10.0.13762`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:license_server:11.0.17318`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:snapapi:3.1.329`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:snapdeploy_management_agent:3.0.3470`,
        fs:  `cpe:2.3:a:bib2html_project:bib2html:0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_agent:9.1.3854`,
        fs:  `cpe:2.3:h:cisco:nexus_9508:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_agent:9.7.8206`,
        fs:  `cpe:2.3:a:redhat:kdebase:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_echo_enterprise_server:9.5.8018`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_100_color_mfp_m175:ce866a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_echo_enterprise_server:9.7.8206`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_echo_enterprise_server:9.7.8398`,
        fs:  `cpe:2.3:o:juniper:junos:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_echo_server:9.7.8398`,
        fs:  `cpe:2.3:a:horde:gollem:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_echo_workstation:9.7.8206`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_management_console:9.7.8206`,
        fs:  `cpe:2.3:a:microsoft:greetings:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:true_image_server:9.1.3534`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acronis:universal_restore_for_true_image_echo_server:9.7.8206`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acrosoftware:cutepdf:3.4.1.3::~~professional~~~`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner_documentation:15.0.0.8168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acrosoftware:cutepdf:3.6.2.0::~~professional~~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acrosoftware:cutepdf:3.6.4.0::~~professional~~~`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acrosoftware:cutepdf_writer:2.7`,
        fs:  `cpe:2.3:a:x.org:libx11:1.4.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acrosoftware:cutepdf_writer:2.8`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:acs:putty_connection_manager:0.7.1.136beta`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:act:compass:-`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:act:compass:3.2.1`,
        fs:  `cpe:2.3:a:boost:boost:1.42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activcard:activcard_gold_for_cac:-`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activcard:activcard_gold_for_cac:2.24`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activcard:activcard_gold_for_cac:3.0`,
        fs:  `cpe:2.3:a:microsoft:access:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:active_24_project:active_24:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:wget:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activedev:active_cms:1.2`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.816.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:network_discovery_gateway:2.5.1.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:samba:samba:2.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.6.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.7.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.7.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:sysreport:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.7.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.9.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d34:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:secure_backup:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:2.9.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:3.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:3.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:3.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:3.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:3.4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:lsi:power_console_plus_package:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:3.4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activehelper:activehelper_livehelp_live_chat:3.5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:horde:groupware:5.1.0:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:-`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.4.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.1`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.1.629`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.1.630`,
        fs:  `cpe:2.3:a:samba:samba:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.1.635`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.2`,
        fs:  `cpe:2.3:a:maximus:schoolmax:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.3`,
        fs:  `cpe:2.3:a:google:authenticator:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.633`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.635`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6a:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.6.638`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.7.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.7.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.7.3`,
        fs:  `cpe:2.3:h:dell:latitude_e6410_atg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.7`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.8.815`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.8.817`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.8.820`,
        fs:  `cpe:2.3:a:xymon:xymon:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.807`,
        fs:  `cpe:2.3:a:splunk:splunk:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.809`,
        fs:  `cpe:2.3:a:ca:etrust_security_command_center:8:sp1:cr2:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.810`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.819`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.820`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.22.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.824`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.827`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.8.828`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2007:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.10.1002`,
        fs:  `cpe:2.3:a:novell:web_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.10.1004`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.10.1005`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.10.1006`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.10.1007`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.10.1008::~~~~x64~`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:2.6.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.12.1201::~~~~x64~`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.12.1202`,
        fs:  `cpe:2.3:a:x:libxext:1.0.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.12.1203`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.12.1203::~~~~x64~`,
        fs:  `cpe:2.3:h:iss:proventia:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.12.1204`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.14.1402`,
        fs:  `cpe:2.3:a:microsoft:visio:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl:5.14.1402::~~~~x64~`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activeperl_pdk:9.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activepython:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activepython:2.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activepython:2.5.2.2`,
        fs:  `cpe:2.3:a:x:libxext:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activepython:2.5.4.4`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:activepython:2.6.5.12`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:komodo_edit:5.2.4`,
        fs:  `cpe:2.3:a:x.org:libx11:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:komodo_edit:6.0.3`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.48.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:komodo_edit:6.1.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activestate:komodo_edit:6.1.1`,
        fs:  `cpe:2.3:a:citrix:offline_plug-in:6.0.0.1304:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:activetemplates:template:1.5`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activcard_gold_for_cac:2.200.66.0`,
        fs:  `cpe:2.3:a:ibm:netezza_performance_portal:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activcard_gold_for_cac_feature_pack:3.01.1076.1`,
        fs:  `cpe:2.3:o:vmware:esxi:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activcard_gold_for_cac_feature_pack:3.01.2087.2`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activcard_usb_reader:2.0.3`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.1:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:-`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.0`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.99`,
        fs:  `cpe:2.3:o:cisco:catos:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.100`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.100::~~~~x64~`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.108`,
        fs:  `cpe:2.3:h:hp:3com_router:3013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.113`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.114`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.123`,
        fs:  `cpe:2.3:a:roderick_braun:ya_googlesearch:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.130`,
        fs:  `cpe:2.3:o:honeywell:excel_web_xl_1000c1000_600_i\/o_uukl:2.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.130::~~~~x64~`,
        fs:  `cpe:2.3:a:ibm:access_ibm_message_center:2.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.3.132`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.01.00034`,
        fs:  `cpe:2.3:o:sun:sunos:5.10:-:*:*:*:*:amd64:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.01.00046`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.2\(0\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.01.00051`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.100`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.120`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.124`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.125`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.133`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.137`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.139`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:1.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.148`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.155`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.1.157`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.cors:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2`,
        fs:  `cpe:2.3:a:iqnect:dubstep_hero:1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2::~~~~x64~`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.54`,
        fs:  `cpe:2.3:o:sun:solaris:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.54::~~~~x64~`,
        fs:  `cpe:2.3:a:mozilla:firefox:20.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.69`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0_rev_b:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.69::~~~~x64~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.71`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.71::~~~~x64~`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.72`,
        fs:  `cpe:2.3:a:codiad:codiad:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.72::~~~~x64~`,
        fs:  `cpe:2.3:a:avast:premier:11.1.2241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.73`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r007c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.75`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1032:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.75::~~~~x64~`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.78`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.80`,
        fs:  `cpe:2.3:h:hp:3com_switch:4210_pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.80::~~~~x64~`,
        fs:  `cpe:2.3:h:axis:700_network_document_server:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.81`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.3:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.81::~~~~x64~`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.0.0.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.85`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p419:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.85::~~~~x64~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.6:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.86`,
        fs:  `cpe:2.3:a:alienwp:hatch:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.86::~~~~x64~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.95`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.95::~~~~x64~`,
        fs:  `cpe:2.3:a:polycom:cma_system_software:5.2.1j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.101::~~~~x64~`,
        fs:  `cpe:2.3:a:python:python:2.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.107`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.107::~~~~x64~`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.111`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.113`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.113::~~~~x64~`,
        fs:  `cpe:2.3:a:microsoft:project_server:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.115::~~~~x64~`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.116`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.116::~~~~x64~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.118::~~~~x64~`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper_live_streaming_integration:4.27:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.119`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(7\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.119::~~~~x64~`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.954:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.120::~~~~x64~`,
        fs:  `cpe:2.3:a:mandrakesoft:mandrake_multi_network_firewall:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.122`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.122::~~~~x64~`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.124::~~~~x64~`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.126::~~~~x64~`,
        fs:  `cpe:2.3:a:solarwinds:ip_address_manager_web_interface:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.128`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.128::~~~~x64~`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:15.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.133`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:3.70.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.2.0.133::~~~~x64~`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.1.91.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.11.00039::~~~~x64~`,
        fs:  `cpe:2.3:a:php:php:5.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.11.00050::~~~~x64~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:6.11.155::~~~~x64~`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac:7.0::~~~~x64~`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac_afr:6.1.100`,
        fs:  `cpe:2.3:a:avaya:enterprise_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac_afr:6.1.125`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:activclient_cac_afr:6.1.155`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:actividentity_device_installer:2.00.00012`,
        fs:  `cpe:2.3:a:paperton:allt_om_brollop:1.53:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:actividentity_device_installer:2.2`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.4:*:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:actividentity_device_installer:2.2::~~~~x64~`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:actividentity_device_installer:2.3::~~~~x64~`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:actividentity_device_installer:2.10.00006`,
        fs:  `cpe:2.3:a:conky:conky:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:corestreet_desktop_validation_client:2.1.3.3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp3:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:corestreet_desktop_validation_client:2.1.6.20`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:corestreet_desktop_validation_client:3.1.4.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:corestreet_desktop_validation_client:3.1.4.1::~~~~x64~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(7b\)1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:corestreet_server_validation_extension_dod_settings:1.5.0.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:corestreet_server_validation_extension_for_microsoft_domain_controller:3.1.4.1::~~~~x64~`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:tenc4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:corestreet_server_validation_extension_for_microsoft_internet_information_server:3.1.4.1`,
        fs:  `cpe:2.3:a:cisco:unified_service_monitor:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:corestreet_validation_authority:5.1.5`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actividentity:desktop_validation_client:3.1.4.1`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:activision:call_of_duty_elite:2.0.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.03.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actorskey:actors_key:1.6.24.477::~~~android~~`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.05:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:actualtests:cisco_640-802_demo_in_exam_engine_format:1.0.0`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actualtests:comptia_220-701_in_exam_engine_format:1.0.0`,
        fs:  `cpe:2.3:a:redhat:certificate_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actualtests:comptia_220-702_in_exam_engine_format:1.0.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actualtests:comptia_n10-004_in_exam_engine_format:1.0.0`,
        fs:  `cpe:2.3:a:expressjs:express:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actualtests:comptia_sy0-201_in_exam_engine_format:1.0.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actualtests:exin_ex0-1_in_exam_engine_format:1.0.0`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actualtests:questions_and_answers_for_eccouncil_312-50v7:4.2.13135`,
        fs:  `cpe:2.3:a:cisco:jabber:9.1\(.1\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:actuate:iserver:7.2.6`,
        fs:  `cpe:2.3:a:thalesgroup:datacryptor_element_manager:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actuate:iserver:7.2.19`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actuate:iserver:8.0.5`,
        fs:  `cpe:2.3:a:feedweb:feedweb:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:actuate:iserver:9.2.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ad-manager_project:ad-manager:1.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ad-minister_project:ad-minister:0.4.1`,
        fs:  `cpe:2.3:a:apache:storm:0.10.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ad-minister_project:ad-minister:0.4.2`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0:ru6a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ad-minister_project:ad-minister:0.4.3`,
        fs:  `cpe:2.3:a:yahoo:yui:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ad-minister_project:ad-minister:0.4.4`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ad-minister_project:ad-minister:0.5`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ad-minister_project:ad-minister:0.5.2`,
        fs:  `cpe:2.3:a:oracle:application_server_portal:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ad-minister_project:ad-minister:0.6`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adam_zaninovich:sounder:0.0.1`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adam_zaninovich:sounder:0.0.2`,
        fs:  `cpe:2.3:o:buffalotech:whr-300hp2_firmware:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adam_zaninovich:sounder:1.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adam_zaninovich:sounder:1.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.0.0`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:6.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.1.2`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.1.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.1.6`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.1.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.1.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.34.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.1.9`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.1.10`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.1.11`,
        fs:  `cpe:2.3:a:qualys:qualyssuite:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.2.0`,
        fs:  `cpe:2.3:a:emc:networker:8.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.2.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.0`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.1`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.3`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.5`,
        fs:  `cpe:2.3:a:tm_software:tempo6.3.0:jira42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.7`,
        fs:  `cpe:2.3:a:apache:subversion:0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.8`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-4.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.9`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.10`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.11`,
        fs:  `cpe:2.3:h:d-link:dcs-5029l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.12`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.3.13`,
        fs:  `cpe:2.3:a:crumbs_project:crumbs:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.3`,
        fs:  `cpe:2.3:a:logitech:vid:1.1.1015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.5`,
        fs:  `cpe:2.3:a:mahara:mahara:16.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.6`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.7`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.8`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.9`,
        fs:  `cpe:2.3:a:emc:documentum_xcp:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.10`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.11`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.12`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.13`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.5.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.14`,
        fs:  `cpe:2.3:a:gnu:fingerd:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.15`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.16`,
        fs:  `cpe:2.3:a:bea:aqualogic_enterprise_security:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.4.17`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.1`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.2`,
        fs:  `cpe:2.3:a:ibus_project:ibus:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.4`,
        fs:  `cpe:2.3:a:magzter:penumbra_emag:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.5`,
        fs:  `cpe:2.3:h:ibm:netezza:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.6`,
        fs:  `cpe:2.3:a:vmware:workstation:5.0.0_build_13124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p55:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.8`,
        fs:  `cpe:2.3:a:dell:quest_one_password_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.9`,
        fs:  `cpe:2.3:a:apple:safari:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.10`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.11`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.12`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53_90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:2.5.13`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:3.0.0`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:3.0.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:3.0.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:3.0.3`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:3.0.4`,
        fs:  `cpe:2.3:a:google:v8:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:3.0.5`,
        fs:  `cpe:2.3:a:exim:exim:4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:3.0.6`,
        fs:  `cpe:2.3:a:google:chrome:7.0.536.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.0.0`,
        fs:  `cpe:2.3:a:3s-software:codesys_runtime_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.0.2`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.1.0`,
        fs:  `cpe:2.3:a:hp:alm-platform_loader:11.0.5154.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.1.1`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.1.2`,
        fs:  `cpe:2.3:a:kent-web:joyful_note:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.1.3`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.1.5.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.1.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.424.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.1.7`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.2`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.3`,
        fs:  `cpe:2.3:a:infotecs:vipnet_personal_firewall:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.3.1`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.4`,
        fs:  `cpe:2.3:a:rackspace:rackspace:2.1.5:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.4.1`,
        fs:  `cpe:2.3:a:autodesk:vred:2014:sr1_sp8:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.5`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0:beta4.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p324:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.6.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:9.2:mp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.7`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.8`,
        fs:  `cpe:2.3:a:sun:jre:6.0.220:update22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:4.2.9`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivecomputing:torque_resource_manager:5.0.0-1_43d8f09a`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivelearningsystems:crammaster:1.0`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adaptivelearningsystems:sun_cx-310-200_solaris_10_administrator_%28scsa%29_part_1:1.0`,
        fs:  `cpe:2.3:a:cherokee-project:cherokee:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adastra:trace_mode_data_center:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adastra:trace_mode_data_center:6.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.753.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adastra:trace_mode_data_center:6.04`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adastra:trace_mode_data_center:6.05`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adastra:trace_mode_data_center:6.06`,
        fs:  `cpe:2.3:a:google:chrome:17.0.923.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adastra:trace_mode_data_center:6.07`,
        fs:  `cpe:2.3:a:buffalotech:whr-g54s_firmware:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adastra:trace_mode_data_center:6.07.7`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2706:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adastra:trace_mode_data_center:6.08`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:adb:p.dga4001n:-`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:adb:p.dga4001n_firmware:pdg_tef_sp_4.06l.6`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_hmi\/scada_ifix:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.0.0:::de`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.0.0:::en`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.0.1:::de`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.0.1:::en`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.0.2:::de`,
        fs:  `cpe:2.3:a:netiq:endpoint:5.1.8149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.0.2:::en`,
        fs:  `cpe:2.3:h:huawei:e200x3:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.1.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.1.1`,
        fs:  `cpe:2.3:a:debian:apt:0.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.1.2`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.2.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.686.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.2.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0063:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.2.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.2.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.2.4`,
        fs:  `cpe:2.3:a:gnome:gnome-keyring:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.3.0`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.5:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.3.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.3.2`,
        fs:  `cpe:2.3:o:opensuse_project:suse_linux_enterprise_server:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.3.3`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.0`,
        fs:  `cpe:2.3:a:samba:samba:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.2`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.4`,
        fs:  `cpe:2.3:a:ultimus:ultimus_business_process_management_suite:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.7`,
        fs:  `cpe:2.3:a:powerarchiver:powerarchiver:14.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.9`,
        fs:  `cpe:2.3:a:teradata:.net_data_provider:13.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.10`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.4.11`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.5.0`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.5.1`,
        fs:  `cpe:2.3:a:cisco:pix_firewall_manager:4.3\(2\)g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.5.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.5.3`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.5.4`,
        fs:  `cpe:2.3:a:webgateinc:webeyeaudio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.5.5`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:1.5.6`,
        fs:  `cpe:2.3:a:apache:couchdb:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.0.0`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.22.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.0.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.0.2`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.21.4846:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.0.3`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.0.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.0.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.1.0`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.1.1`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.1.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_replication_server:9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.1.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.404.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.2.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.2.1`,
        fs:  `cpe:2.3:a:autodesk:autocad_electrical:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.2.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.17s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.2.3`,
        fs:  `cpe:2.3:a:apache:struts:2.3.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.2.4`,
        fs:  `cpe:2.3:a:ocsinventory-ng:ocsinventory_ng:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.2.5`,
        fs:  `cpe:2.3:a:iij:seil\/turbo_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.2.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.20:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.2.7`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:rc1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.3.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(4g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.3.1`,
        fs:  `cpe:2.3:a:3sgroup:t2css:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.3.2`,
        fs:  `cpe:2.3:a:digia:qt:4.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.3.3`,
        fs:  `cpe:2.3:a:ca:siteminder:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.3.4`,
        fs:  `cpe:2.3:h:apple:ipod_touch:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.3.5`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.5.1:test1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.4.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.4.1`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.4.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:2.4.3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:3.0.0`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:3.0.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:3.0.2`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:3.0.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:23.0.0.207:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:adbnewssender_project:adbnewssender:3.0.4`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adcillc:simplemeta:6.x-1.0`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adcillc:simplemeta:6.x-1.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adcillc:simplemeta:6.x-1.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adcillc:simplemeta:6.x-1.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adcillc:simplemeta:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adcisolutions:node_view_permissions:7.x-1.0`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adcisolutions:node_view_permissions:7.x-1.1`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adcisolutions:node_view_permissions:7.x-1.2`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:add-in-express:duplicate_remover_for_microsoft_excel:2.5.0`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:addisgag:addis_gag_funny_amharic_pic:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:ultraseek:ultraseek:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:addsoft:storebot:-`,
        fs:  `cpe:2.3:a:vmware:workstation:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:addsoft:storebot:2002`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.4.4:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:addsoft:storebot:2005`,
        fs:  `cpe:2.3:a:horde:imp:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adersoft:vbsedit:3.4`,
        fs:  `cpe:2.3:a:horde:imp:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adgjm:angel_browser:1.47b`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adgjm:angel_browser:1.62b`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:3.00.0612:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adgjm:angel_browser:1.68b`,
        fs:  `cpe:2.3:a:gnu:emacs:23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adgjm:angel_browser:1.76b`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adgjm:galapagos_browser:-:-:~~~android~~`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adidas:adidas_eyewear:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.2.0`,
        fs:  `cpe:2.3:a:att:communication_manager:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.2.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.06:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.2.2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.2.3`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0a3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.3.0`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.4.0`,
        fs:  `cpe:2.3:a:ibm:cognos_command_center:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.4.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.008.20082:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.4.2`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.82.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.4.3`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.4.4`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.5.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.5.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.5.2`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.5.3`,
        fs:  `cpe:2.3:a:bib2html_project:bib2html:0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.5.4`,
        fs:  `cpe:2.3:a:microsoft:exchange_instant_messenger:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adiscon:loganalyzer:3.5.5`,
        fs:  `cpe:2.3:a:vmware:hyperic_hq:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.0.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.0.2`,
        fs:  `cpe:2.3:a:zend:zendservice_nirvanix:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.0.3`,
        fs:  `cpe:2.3:a:idera:pointcheck:1.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.0.4`,
        fs:  `cpe:2.3:a:winzip:winzip:11.1.7466:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.1:alpha`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.1.0`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:p08-0031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.1.95`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.1.98`,
        fs:  `cpe:2.3:a:web2py:web2py:1.86.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.2.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.2.90`,
        fs:  `cpe:2.3:a:hp:product_detection:10.7.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.3.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:46.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.3.90`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.4.0`,
        fs:  `cpe:2.3:a:web2py:web2py:1.94.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.4.90`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_runtime_engine_for_.net_framework_4:13.0.1.220:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.4.95`,
        fs:  `cpe:2.3:a:componentone:flexgrid:7.1_light:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.5.0`,
        fs:  `cpe:2.3:a:sun:openoffice.org:3.1.9420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.5.80`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.6.0`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.6.1`,
        fs:  `cpe:2.3:a:socketmail:socketmail:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.6.80`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.6.85`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.6.95`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.22:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.7.0`,
        fs:  `cpe:2.3:a:androidcommunity:hector_leal:13.08.14:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.7.1`,
        fs:  `cpe:2.3:a:hp:eprint_and_share:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.7.80`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.7.90`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.7.92`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adjam:rekonq:0.8.0`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.20:-:*:*:*:hp-ux:*:*`,
    },
     
    {
        uri: `cpe:/a:admin-font-editor_project:admin-font-editor:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1q\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:administration_views_project:administration_views:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.27.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:administration_views_project:administration_views:7.x-1.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5:beta_pr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:administration_views_project:administration_views:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.50.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:administration_views_project:administration_views:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:promotionalshop:promotional_items:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:administration_views_project:administration_views:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.2.0:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:adminsystems_cms_project:adminsystems_cms:4.0.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:-`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:_reader9.5.3`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.0:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:1.0::~~suite~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:2.0:-:pro`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):juno-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:3.0`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:b.02.01.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:3.0:-:pro`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:3.1`,
        fs:  `cpe:2.3:a:tibco:spotfire_statistics_services:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:4.0`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.2.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:4.0:-:pro`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:4.0.5`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:4.0.5a`,
        fs:  `cpe:2.3:a:meta_tags_quick_project:meta_tags_quick:7.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:4.0.5c`,
        fs:  `cpe:2.3:a:hp:alm_synchronizer:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:5.0`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:5.0:-:pro`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:5.0.5`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:5.0.6`,
        fs:  `cpe:2.3:a:dotcms:dotcms:1.9.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:5.0.10`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d50:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:5.1`,
        fs:  `cpe:2.3:a:novell:groupwise:7.03:hp3\&#43;ftf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:5.1:-:pro`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0:-:~~standard~~~`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0:-:pro`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je071a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0.1`,
        fs:  `cpe:2.3:a:nefarious2_project:nefarious2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0.2`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0.3`,
        fs:  `cpe:2.3:h:d-link:dsl-2730b:c1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0.4`,
        fs:  `cpe:2.3:a:ibm:packaging_utility:1.7.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:6.0.6`,
        fs:  `cpe:2.3:h:ibm:system_x3750_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7`,
        fs:  `cpe:2.3:o:rockwellautomation:compactlogix:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0`,
        fs:  `cpe:2.3:h:cisco:telepresence_profile_55:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0:-:pro`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.2`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.5491:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.3`,
        fs:  `cpe:2.3:h:dell:latitude_e5410:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.4`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.5`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2\(0.899\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.6`,
        fs:  `cpe:2.3:o:huawei:s3300_firmware:v100r006c05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.7`,
        fs:  `cpe:2.3:a:teamst:testlink:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.8`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.0.9`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.1.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.0:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.1.1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.1.3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.1.4`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:7.1.4:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8`,
        fs:  `cpe:2.3:a:opscode:chef:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.0`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.0:-:pro`,
        fs:  `cpe:2.3:a:debian:debmake:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.0.0`,
        fs:  `cpe:2.3:a:ttnetmuzik:ttnet_muzik:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1`,
        fs:  `cpe:2.3:a:pgp:desktop_for_windows:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.1`,
        fs:  `cpe:2.3:a:funnymonkey:feature_set:7.x-1.0-beta1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.2`,
        fs:  `cpe:2.3:a:altiris:console:6.5.1144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.2:-:pro`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.3`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.3:-:pro`,
        fs:  `cpe:2.3:a:apple:itunes:12.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.4`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.5:-`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.6`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.1.7`,
        fs:  `cpe:2.3:o:d-link:dcs-2132l_firmware:1.08.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2`,
        fs:  `cpe:2.3:a:john_albin:zen:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2.1`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.6104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2.1:-`,
        fs:  `cpe:2.3:a:md-systems:simplenews:7.x-1.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2.2`,
        fs:  `cpe:2.3:a:samba:samba:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2.3`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2.4`,
        fs:  `cpe:2.3:a:actividentity:actividentity_device_installer:2.10.00006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2.4:-`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.06:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.2.6`,
        fs:  `cpe:2.3:o:apple:mac_os:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.3::~~professional~~~`,
        fs:  `cpe:2.3:a:avg:anti-virus_plus_firewall:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.3:-`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.3.1::~~professional~~~`,
        fs:  `cpe:2.3:a:ibm:forms_viewer:4.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:8.3.1:-`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.00:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3060_concentrator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.0:-:pro`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.1`,
        fs:  `cpe:2.3:a:gnu:tar:1.13.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.1:-:pro`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.1.1`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.1.1:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.447.7.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.1.2`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.1.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.1.3:-`,
        fs:  `cpe:2.3:a:apache:struts:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.2:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je102a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3:-:pro`,
        fs:  `cpe:2.3:a:microsoft:windows_mobile:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3.1`,
        fs:  `cpe:2.3:o:juniper:junos:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3.1:-`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3.2`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3.2:-`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3.3`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3.4`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.3.4:-`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p123:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.1:-`,
        fs:  `cpe:2.3:o:huawei:s6700_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.2`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.2:-`,
        fs:  `cpe:2.3:a:oracle:virtualization:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.3`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.3:-`,
        fs:  `cpe:2.3:o:apple:airport_base_station_firmware:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.4`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-s24:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.4:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.5`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.5:-`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.30:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.6`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.6:-`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x52:d10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.4.7`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.5`,
        fs:  `cpe:2.3:a:drupal:drupal:5.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.5.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.5.2`,
        fs:  `cpe:2.3:o:redhat:linux:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.5.3`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.4:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.5.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:9.5.5`,
        fs:  `cpe:2.3:a:hp:openview_mib_api_loader_and_mibs:1.30.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.0`,
        fs:  `cpe:2.3:a:novell:iprint:5.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.0:-:pro`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.0.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.0.1:-:pro`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp6:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.0.3`,
        fs:  `cpe:2.3:a:radware:linkproof:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1`,
        fs:  `cpe:2.3:h:foundrynet:fastiron_400_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.0`,
        fs:  `cpe:2.3:a:oracle:service_bus:12.2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1009.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.2`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.4`,
        fs:  `cpe:2.3:a:rpm:rpm:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.5`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.6`,
        fs:  `cpe:2.3:a:piwik:piwik:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.7`,
        fs:  `cpe:2.3:h:oracle:netra_sparc_t3-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.8`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.9`,
        fs:  `cpe:2.3:a:partytrack_library_project:partytrack_library:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.10`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.11`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.12`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.13`,
        fs:  `cpe:2.3:a:anthony_mills:s3_video:0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.14`,
        fs:  `cpe:2.3:a:gnu:lsh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.15`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:10.1.16`,
        fs:  `cpe:2.3:a:google:chrome:11.0.697.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.10:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.0`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.1`,
        fs:  `cpe:2.3:a:peter_kovacs:timesheet_next_gen:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.2`,
        fs:  `cpe:2.3:a:bamboosolutions:enterprise_license:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.3`,
        fs:  `cpe:2.3:a:bamboosolutions:bamboo.worldclockandweather.spv3:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.4`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.5`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.05:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.5:-:~~~windows~~`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.6`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.4jda:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:108.2146.2565.38893:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.10`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.11`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.12`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.13`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.14`,
        fs:  `cpe:2.3:a:infotecs:vipnet_coordinator:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.15`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.15::~~desktop~~~`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.16`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.17`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.18`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.19`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.20`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.21`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.22`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:11.0.23`,
        fs:  `cpe:2.3:a:f5:big-ip:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:17.011.30059`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:17.011.30065`,
        fs:  `cpe:2.3:a:symantec:vrtssfmh:2.1.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:17.011.30066`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:17.011.30068`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat:17.011.30070`,
        fs:  `cpe:2.3:a:altiris:task_server_language_pack:6.0.1404:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_3d:-`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_client:6.1.10000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_business_tools:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_business_tools:4.0`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_business_tools:4.05`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:8.0\(110.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30060::~~classic~~~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.813:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30094::~~classic~~~`,
        fs:  `cpe:2.3:h:apple:imac:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30096::~~classic~~~`,
        fs:  `cpe:2.3:a:dell:client_configuration_toolkit:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30097::~~classic~~~`,
        fs:  `cpe:2.3:a:popuapp:popu_2\:_get_likes_on_instagram:1.7.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30119::~~classic~~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.19:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30121::~~classic~~~`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30172::~~classic~~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd008a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30173::~~classic~~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30174::~~classic~~~`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30198::~~classic~~~`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30201::~~classic~~~`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30243::~~classic~~~`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30244::~~classic~~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30279::~~classic~~~`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30280::~~classic~~~`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30306::~~classic~~~`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30352::~~classic~~~`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30354::~~classic~~~`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30355::~~classic~~~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30392::~~classic~~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.006.30394::~~classic~~~`,
        fs:  `cpe:2.3:a:ibm:maximo_integration_composer:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.008.20082::~~continuous~~~`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.009.20069::~~continuous~~~`,
        fs:  `cpe:2.3:a:symantec:vrtsaa:5.0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.009.20071::~~continuous~~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.1.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.009.20077::~~continuous~~~`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.009.20079::~~continuous~~~`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.010.20056::~~continuous~~~`,
        fs:  `cpe:2.3:h:nec:superscript_4400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.010.20059::~~continuous~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.010.20060::~~continuous~~~`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.016.20039::~~continuous~~~`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:sp2:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.016.20041::~~continuous~~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.016.20045::~~continuous~~~`,
        fs:  `cpe:2.3:h:3com:3c8532:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.017.20050::~~continuous~~~`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.017.20053::~~continuous~~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.020.20039::~~continuous~~~`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.020.20042::~~continuous~~~`,
        fs:  `cpe:2.3:a:php:php:5.5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.023.20053::~~continuous~~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.480.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.023.20056::~~continuous~~~`,
        fs:  `cpe:2.3:a:gnu:glibc:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:15.023.20070::~~continuous~~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:17.009.20044::~~continuous~~~`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:17.009.20058::~~continuous~~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:17.012.20093::~~continuous~~~`,
        fs:  `cpe:2.3:a:tumbleweed:validation_authority:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:17.012.20095::~~continuous~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:17.012.20098::~~continuous~~~`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:18.009.20044::~~continuous~~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.14:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:18.009.20050::~~continuous~~~`,
        fs:  `cpe:2.3:a:veritas:enterprise_administrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:2015.006.30060::~~classic~~~`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_dc:2015.008.20082::~~continuous~~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sy6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_elements:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1684.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_pdfwriter:3.3`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:3.0`,
        fs:  `cpe:2.3:a:commvault:base_client:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:3.01`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:3.02`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:4.0`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:4.0.5`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:4.0.5a`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:4.0.5c`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:4.5`,
        fs:  `cpe:2.3:a:isc:inn:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:5.0`,
        fs:  `cpe:2.3:a:mobiloapps:anderson_musaamil:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:5.0.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:5.0.6`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:5.0.7`,
        fs:  `cpe:2.3:a:altiris:pxe_manager:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:5.0.9`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:5.0.10`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:5.0.11`,
        fs:  `cpe:2.3:o:centos:centos:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.447.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:6.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.2:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:6.0.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:6.0.2`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:6.0.3`,
        fs:  `cpe:2.3:a:gnu:sharutils:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:6.0.4`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:6.0.5`,
        fs:  `cpe:2.3:a:ca:unicenter_data_transport_option:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.3`,
        fs:  `cpe:2.3:o:blackberry:qnx_neutrino_rtos:6.5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.4`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.5`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_client:4.2.0.254483:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1\)db2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.7`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.8`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.0.9`,
        fs:  `cpe:2.3:h:lexmark:c544:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:7.1.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.0`,
        fs:  `cpe:2.3:o:juniper:junos:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20110105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.1.1`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0_b2pl9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.1.2`,
        fs:  `cpe:2.3:h:hp:laserjet_m5025_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.1.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.1.4`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.1.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.1.6`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.1.7`,
        fs:  `cpe:2.3:a:commerce:america\&#39;s_economy_for_phone:1.5.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.2.1`,
        fs:  `cpe:2.3:h:cisco:3945_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.2.2`,
        fs:  `cpe:2.3:o:virtualaccess:gw6110a_firmware:10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.2.3`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.2.4`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.2.6`,
        fs:  `cpe:2.3:a:kunena:kunena:5.0.2:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:8.3`,
        fs:  `cpe:2.3:a:php:php:5.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.0`,
        fs:  `cpe:2.3:o:sun:sunos:5.11:*:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.1.1`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.1.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.1.3`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.0:ea2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.2`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.3`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.3.1`,
        fs:  `cpe:2.3:a:gnu:mailutils:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.3.2`,
        fs:  `cpe:2.3:h:sun:storedge_3510_fc_array:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.3.3`,
        fs:  `cpe:2.3:a:microsoft:ie:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.3.4`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.4.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.47.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.4.2`,
        fs:  `cpe:2.3:a:htc:vivid_software:3.26.502.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.4.3`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:9.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.4.4`,
        fs:  `cpe:2.3:a:gnu:gdb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.4.5`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.4.6`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.4.7`,
        fs:  `cpe:2.3:a:mywebsiteadvisor:simple_security:1.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.5`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.5.1`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.5.2`,
        fs:  `cpe:2.3:a:ivanjaros:feed_block:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.5.3`,
        fs:  `cpe:2.3:a:harfbuzz_project:harfbuzz:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.5.4`,
        fs:  `cpe:2.3:a:splunk:splunk:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:9.5.5`,
        fs:  `cpe:2.3:a:vmware:player:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.0.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.0.2`,
        fs:  `cpe:2.3:a:cisco:videoscape_delivery_system_origin_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.0`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.2`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.3`,
        fs:  `cpe:2.3:a:oracle:hyperion:11.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.4`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.6`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.7`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.4.1_a:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.8`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.9`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.10`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.11`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:2006.02:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.12`,
        fs:  `cpe:2.3:a:ibm:lotus_quickr_for_domino:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.13`,
        fs:  `cpe:2.3:a:emc:vplex_geosynchrony:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.14`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.7:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.15`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:10.1.16`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_5d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.0`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.01`,
        fs:  `cpe:2.3:h:juniper:netscreen-5gt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.02`,
        fs:  `cpe:2.3:a:roxio:recordnow_data:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.03`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.3`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.0.3:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.04`,
        fs:  `cpe:2.3:h:cisco:aironet_ap350:11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.4`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.05`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.5`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.5:-:~~~windows~~`,
        fs:  `cpe:2.3:a:ipswitch:whatsup:2005:sp1:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.06`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.6`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.07`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.7`,
        fs:  `cpe:2.3:h:siemens:scalance_w788-1rr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.8`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.08`,
        fs:  `cpe:2.3:a:adobe:air_sdk:19.0.0.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.09`,
        fs:  `cpe:2.3:a:atutor:atutor:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.10`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.11`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.12`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.13`,
        fs:  `cpe:2.3:h:supermicro:x9sre-3f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.14`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.15`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.16`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.17`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.18`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.19`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.21`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.22`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:11.0.23`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:15.006.30244`,
        fs:  `cpe:2.3:a:isc:bind:9.11.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:15.020.20042`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:17.011.30059`,
        fs:  `cpe:2.3:a:intel:prosafe_for_wired_connections:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:17.011.30065`,
        fs:  `cpe:2.3:a:cisco:mediasense:10.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:17.011.30066`,
        fs:  `cpe:2.3:a:splunk:splunk:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:17.011.30068`,
        fs:  `cpe:2.3:a:gnu:queue:1.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader:17.011.30070`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30060::~~classic~~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30094::~~classic~~~`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30096::~~classic~~~`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30097::~~classic~~~`,
        fs:  `cpe:2.3:h:rad:asm-40:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30119::~~classic~~~`,
        fs:  `cpe:2.3:a:debian:adequate:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30121::~~classic~~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.23:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30172::~~classic~~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.1:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30173::~~classic~~~`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30174::~~classic~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30198::~~classic~~~`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.27:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30201::~~classic~~~`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30243::~~classic~~~`,
        fs:  `cpe:2.3:a:livetecs:timeline:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30244::~~classic~~~`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30279::~~classic~~~`,
        fs:  `cpe:2.3:a:wingrep:windows_grep:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30280::~~classic~~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30306::~~classic~~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.82.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30352::~~classic~~~`,
        fs:  `cpe:2.3:a:nero:mediahome_ce:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30354::~~classic~~~`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30355::~~classic~~~`,
        fs:  `cpe:2.3:h:cisco:ie-4000-8t4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30392::~~classic~~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.006.30394::~~classic~~~`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.008.20082::~~continuous~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p463:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.009.20069::~~continuous~~~`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.009.20071::~~continuous~~~`,
        fs:  `cpe:2.3:a:kde:kmail:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.009.20077::~~continuous~~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.009.20079::~~continuous~~~`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.010.20056::~~continuous~~~`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.010.20059::~~continuous~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p134:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.010.20060::~~continuous~~~`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.016.20039::~~continuous~~~`,
        fs:  `cpe:2.3:a:netscape:navigator:4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.016.20041::~~continuous~~~`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.016.20045::~~continuous~~~`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.017.20050::~~continuous~~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.017.20053::~~continuous~~~`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.020.20039::~~continuous~~~`,
        fs:  `cpe:2.3:a:winace:unace:1.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.020.20042::~~continuous~~~`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.023.20053::~~continuous~~~`,
        fs:  `cpe:2.3:a:itechscripts:itechclassifieds:3.03.057:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.023.20056::~~continuous~~~`,
        fs:  `cpe:2.3:a:gnu:grep:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:15.023.20070::~~continuous~~~`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.7.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:17.009.20044::~~continuous~~~`,
        fs:  `cpe:2.3:a:school_administration_project:school_administration:7.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:17.009.20058::~~continuous~~~`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:17.012.20093::~~continuous~~~`,
        fs:  `cpe:2.3:a:ibm:maximo_industry_solutions:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:17.012.20095::~~continuous~~~`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:17.012.20098::~~continuous~~~`,
        fs:  `cpe:2.3:a:symantec:client_security:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:18.009.20044::~~continuous~~~`,
        fs:  `cpe:2.3:h:juniper:mx240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:18.009.20050::~~continuous~~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:2015.006.30060::~~classic~~~`,
        fs:  `cpe:2.3:a:perl:perl:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:acrobat_reader_dc:2015.008.20082::~~continuous~~~`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:add_or_remove_creative_suite_3_design_premium:1.0`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:3.5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:add_or_remove_creative_suite_3_web_premium:1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:add_or_remove_creative_suite_3_web_standard:1.0`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.0b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.0`,
        fs:  `cpe:2.3:a:microsoft:expression_web:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(27\)sv2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.0.8.4990`,
        fs:  `cpe:2.3:a:citrix:licensing:6.8.9020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.0.4990`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:5.1:r1d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.1.0.5790`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.5`,
        fs:  `cpe:2.3:a:vmware:server:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.5.0.7220`,
        fs:  `cpe:2.3:h:brocade:vyatta_vrouter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.5.1`,
        fs:  `cpe:2.3:h:dlink:dcs-900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.5.1.8210`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.5.2`,
        fs:  `cpe:2.3:a:nortel:sip_softphone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.5.3`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.5.3.9120`,
        fs:  `cpe:2.3:a:emc:digital_assets_manager:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:1.5.3.9130`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.0.2`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.0.2.12610`,
        fs:  `cpe:2.3:a:inria:ocaml:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.0.3`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.835:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.0.3.13070`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20100208:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.0.4`,
        fs:  `cpe:2.3:a:welcart:welcart_plugin:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.5.0.16600`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.5.1.17730`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.6`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.6.0.19120`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.6.0.19140`,
        fs:  `cpe:2.3:a:x:libxext:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.7`,
        fs:  `cpe:2.3:a:isc:bind:9.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.7.0.1948`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:12.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.7.0.1953`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.7.0.19480`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.242:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.7.0.19530`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.4.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.7.1`,
        fs:  `cpe:2.3:o:novell:netware:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:2.7.1.19610`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.0.0.408`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.2.0:beta_r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.0.0.4080`,
        fs:  `cpe:2.3:a:libav:libav:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.1.0.485`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.1.0.488`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.1.0.4880`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.2.0.207`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(2h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.2.0.2070`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.3.0.3670`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.4.0.2540`,
        fs:  `cpe:2.3:a:apache:poi:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.4.0.2710`,
        fs:  `cpe:2.3:a:otrs:otrs:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.5.0.600`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.5.0.880`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_36:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.5.0.890`,
        fs:  `cpe:2.3:a:hp:storageworks_secure_path_windows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.5.0.1060`,
        fs:  `cpe:2.3:a:attachmate:verastream_process_designer:6.0:sp1_hf1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.6.0.597`,
        fs:  `cpe:2.3:h:axis:2420_video_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.6.0.6090`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.7.0.1530`,
        fs:  `cpe:2.3:a:winzip:winzip_command_line_support_add-on:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.7.0.1860`,
        fs:  `cpe:2.3:h:hp:officejet_pro_8500:cn539a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.7.0.2090`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.8.0.870`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_device_manager:5.2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.8.0.910`,
        fs:  `cpe:2.3:h:tropos:1410_mesh_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.9.0.1030`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.9.0.1060`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.9.0.1210`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.41.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:3.9.0.1380`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:4.0.0.1390`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:4.0.0.1628`,
        fs:  `cpe:2.3:a:hitachi:tiered_storage_manager:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:13.0.0.83`,
        fs:  `cpe:2.3:a:adobe:indesign:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:13.0.0.111`,
        fs:  `cpe:2.3:a:cisco:cisco_policy_suite:7.0.4-att:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:14.0.0.110`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ebm:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air:14.0.0.137`,
        fs:  `cpe:2.3:h:hp:0235a0g7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.0.0.4080`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.1.0.488`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.2.0.2070`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.3.0.3650`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(4a\)1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.3.0.3690`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.4.0.2540`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5800-32c-pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.4.0.2710`,
        fs:  `cpe:2.3:a:symantec:sms-smtp-tomcat:5.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.5.0.600`,
        fs:  `cpe:2.3:a:hp:openview_performance_access:10.50.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.5.0.880`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_anywhere:6.0.3.2747:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.5.0.890`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.5.0.1060`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.6.0.599`,
        fs:  `cpe:2.3:a:oracle:jai:1.1.2:01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.6.0.6090`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.7.0.1530`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.7.0.1860`,
        fs:  `cpe:2.3:a:gnu:automake:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.7.0.2090`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.8.0.870`,
        fs:  `cpe:2.3:a:haxx:curl:7.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.8.0.910`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.4.3:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.8.0.1430`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.9.0.1030`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.9.0.1210`,
        fs:  `cpe:2.3:o:asus:dsl-n56u_firmware:3.0.0.4.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:3.9.0.1380`,
        fs:  `cpe:2.3:a:hp:hp-ux_whitelisting:a.01.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:4.0.0.1390`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:4.0.0.1628`,
        fs:  `cpe:2.3:a:xchat:xchat:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:13.0.0.83`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:13.0.0.111`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:14.0.0.110`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_air_sdk:14.0.0.137`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_application_manager:2.0.240.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_content_server:-`,
        fs:  `cpe:2.3:a:digium:asterisk:c.1.0:beta7:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_content_server:3.0`,
        fs:  `cpe:2.3:a:apache:ignite:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_php_ria_sdk:-`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_presenter:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_presenter:7.0`,
        fs:  `cpe:2.3:h:cisco:6400_nrp:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_reader:11.1.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_reader:11.1.3::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_reader:11.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_update_manager_core:1.0.0.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:adobe_update_manager_language_resource:1.0.0.0`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:4.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:4.1`,
        fs:  `cpe:2.3:a:nec:socks_5:1.0r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:4.1.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:5.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:5.5`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:5.5.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:6.0`,
        fs:  `cpe:2.3:a:keepass:keepass:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:6.5.1`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:7.0`,
        fs:  `cpe:2.3:o:apple:mac_os:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects:7.0.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs3:8.0`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs3:8.0.2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs3_presets:8.0`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:03-00-08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs3_template_projects_%26_footage:8.0`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs3_third_party_content:3.0`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs4:9.0`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs4:9.0.2`,
        fs:  `cpe:2.3:a:7_habits_personal_development_project:7_habits_personal_development:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs4_presets:9.0`,
        fs:  `cpe:2.3:a:foolabs:xpdf:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs4_template_projects_%26_footage:9.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:after_effects_cs4_third_party_content:9.0`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:15.0.0.293`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:17.0.0.144`,
        fs:  `cpe:2.3:a:sympa:sympa:2.7b.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:17.0.0.172`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:18.0.0.180`,
        fs:  `cpe:2.3:a:tmobile:webconnect_manager:2.5.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:19.0.0.241`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:19.0.0.241::~~~android~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:0.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:20.0.0.204`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.942:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:20.0.0.233`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air:20.0.0.260`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk:15.0.0.302`,
        fs:  `cpe:2.3:a:symantec:netbackup_enterprise_server:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk:17.0.0.144`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk:17.0.0.172`,
        fs:  `cpe:2.3:a:apache:subversion:0.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk:18.0.0.180`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk:19.0.0.241`,
        fs:  `cpe:2.3:a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk:20.0.0.204`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk:20.0.0.260`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:15.0.0.302`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:17.0.0.144`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:17.0.0.172`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:18.0.0.180`,
        fs:  `cpe:2.3:o:novell:unixware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:19.0.0.241`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:20.0.0.204`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:20.0.0.233`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:20.0.0.260`,
        fs:  `cpe:2.3:h:3com:nbx_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:air_sdk_%26_compiler:22.0.0.153`,
        fs:  `cpe:2.3:h:valcom:vip-821:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:analytics_appmeasurement_for_flash_library:4.0`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:anchor_service:2.1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:anchor_service_cs3:1.0`,
        fs:  `cpe:2.3:a:category_tokens_project:category_tokens:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:anchor_service_cs4:2.0`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:anchor_service_cs4:2.0::~~~~x64~`,
        fs:  `cpe:2.3:a:gnu:libtasn1:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:animate:15.2.1.95`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds5020_disk_controller:1814-20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:asset_services:3.0`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.18:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:asset_services:4.0`,
        fs:  `cpe:2.3:a:zen-cart.jp:zen_cart:1.3.0.1:*:*:ja-jp:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:asset_services_cs3:3.0`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:asset_services_cs3:3.1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.6\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:asset_services_cs4:4.0`,
        fs:  `cpe:2.3:o:netgear:raidiator:4.2.23:-:-:*:-:-:readynas:*`,
    },
     
    {
        uri: `cpe:/a:adobe:brackets:1.6`,
        fs:  `cpe:2.3:a:gnu:binutils:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:breeze_licensed_server:-`,
        fs:  `cpe:2.3:a:gnu:coreutils:5.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:breeze_licensed_server:5`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:breeze_licensed_server:5.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.11s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge:-`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge:1.0.0`,
        fs:  `cpe:2.3:a:citrix:provisioning_services:5.6:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge:1.0.3`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional_oem:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge:1.0.4`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge:2.0`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge:2.1`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge:3.0`,
        fs:  `cpe:2.3:o:d-link:dcs-5000l_firmware:1.02.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cc:6.1`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cs3:2.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.53:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cs3:2.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cs3:2.1.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cs4:3.0`,
        fs:  `cpe:2.3:a:trendmicro:interscan_web_security_suite:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cs5:4.0.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cs5:4.0.3`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cs5:4.0.4`,
        fs:  `cpe:2.3:a:chamanet:chamacargo:7.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_cs5:4.0.5`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_start_meeting:1.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridge_start_meeting:1.0.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.346:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:bridgetalk_plugin_cs3:1.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:2.1`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:2.2`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.05.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:2.3`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:2.4`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:3.1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:52.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:3.2`,
        fs:  `cpe:2.3:a:opensymphony:xwork:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:3.3`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.14.1402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:3.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:3.5`,
        fs:  `cpe:2.3:a:google:android_api:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:3.6`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:3.7`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:4.0`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:4.1`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:4.2`,
        fs:  `cpe:2.3:a:php:phorum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:4.3.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:1.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:4.4.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:4.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:4.6`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:5.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:5.0::~~~~x64~`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:5.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:5.2`,
        fs:  `cpe:2.3:a:netscape:navigator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:5.3`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:5.4`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:camera_raw:5.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:captivate:-`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:captivate:2.0`,
        fs:  `cpe:2.3:a:in-mediakg:filterftp:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:captivate:3.0`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:captivate:4.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:captivate:5.0.0.596`,
        fs:  `cpe:2.3:h:hp:elitebook_820_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:captivate_quiz_results_analyzer:1.0`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.1.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:captivate_reviewer:2.0`,
        fs:  `cpe:2.3:a:dotnetblogengine:blogengine.net:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:cmaps:1.0`,
        fs:  `cpe:2.3:o:cisco:ciscoworks_1105_wireless_lan_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:cmaps_cs4:2.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:cmaps_cs4:2.0::~~~~x64~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:-`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:6.0`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:7.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:7.0.1`,
        fs:  `cpe:2.3:a:hp:icewall_file_manager:3.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:7.0.2`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg210-25:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:7.2:unknown:mx`,
        fs:  `cpe:2.3:h:huawei:s3300hi:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:8.0`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:8.0.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:9.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1034.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:9.0.1`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:9.0.2`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.09.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_1`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_11`,
        fs:  `cpe:2.3:a:apache:archiva:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_14`,
        fs:  `cpe:2.3:a:isc:bind:9.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_15`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.24:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(2a\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_21`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:3.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_3`,
        fs:  `cpe:2.3:a:granita:cloud_browser:2.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_4`,
        fs:  `cpe:2.3:a:shibboleth:identity_provider:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:10.0:update_8`,
        fs:  `cpe:2.3:o:cisco:catos:5.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:11.0:update_10`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:11.0:update_2`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion:11.0:update_4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)xi4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion_.net_integration_services:1.0.0.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion_.net_integration_services:9.0.0.0`,
        fs:  `cpe:2.3:h:huawei:usg5500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion_8:8.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion_8:8.0.1`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion_8_.net_integration_services:1.0`,
        fs:  `cpe:2.3:a:nerdico_project:nerdico:1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion_builder:2.0.0.0`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:coldfusion_solr_service:9.0.0.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_common_setcmyk:2.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_common_setrgb:2.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_common_settings:1.0`,
        fs:  `cpe:2.3:a:vmturbo:operations_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_common_settings:1.0.1`,
        fs:  `cpe:2.3:h:symantec:clientless_vpn_gateway_4400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_extra_settings:1.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:2.1.1063:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_extra_settings_cs4:2.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_photoshop_specific:1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_photoshop_specific_cs4:2.0`,
        fs:  `cpe:2.3:a:hp:web_registration:140.0.213.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_recommended_settings:1.0`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_recommended_settings_cs4:2.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:color_video_profiles_cs_cs4:2.0`,
        fs:  `cpe:2.3:o:raritan:px:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:common_file_installer:1.0.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:common_file_installer:1.0.2`,
        fs:  `cpe:2.3:o:cisco:unified_ip_conference_station_7936:3.3\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:community_help:3.0.0`,
        fs:  `cpe:2.3:a:b-e-soft:artweaver:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:community_help:3.0.0.400`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:community_help:3.4.973`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:community_help:3.4.980`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:community_help:3.5.23`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:1.0.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0sl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:6.0`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:6.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:6.2`,
        fs:  `cpe:2.3:a:microsoft:iis:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:6.3`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:7.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:7.2`,
        fs:  `cpe:2.3:o:sun:solaris:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:7.3`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:7.5`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:8.0`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:8.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.51a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:8.2`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:8.2.1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.8:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:8.2.2`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.0`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.0.2`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.1.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.0.3`,
        fs:  `cpe:2.3:h:cisco:wrvs4400n_wireless-n_gigabit_security_router_-_vpn_v2.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.1`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.1.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.3`,
        fs:  `cpe:2.3:a:perl:perl:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.4.1`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.4.2`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.localization:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.5`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.0:alpha-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.5.2`,
        fs:  `cpe:2.3:a:libpng:libpng:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.5.3`,
        fs:  `cpe:2.3:a:cybozu:office:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.5.4`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.5.5`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.5.6`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.5.7`,
        fs:  `cpe:2.3:a:itechscripts:proman_xpress:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.6`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.6.1`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.6.2`,
        fs:  `cpe:2.3:a:gentoo:linux_webapp-config:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect:9.7`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs752tps:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect_addin_checker:9.3.139.0`,
        fs:  `cpe:2.3:a:microsoft:backoffice_resource_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect_enterprise_server:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2009.113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect_enterprise_server:6`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.155.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect_outlook_add-in:3.0`,
        fs:  `cpe:2.3:a:augeas:augeas:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:connect_pro_add-in_for_microsoft_outlook:1.0.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:contribute:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:contribute:2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:contribute:3`,
        fs:  `cpe:2.3:a:openproject:openproject:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:contribute:4.1`,
        fs:  `cpe:2.3:a:microsoft:msn_chat_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:contribute_cs3:4.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:contribute_cs4:5.0`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_cloud:3.6.0.248`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_cloud:3.7.0.272`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite:1.0`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite:1.3`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite:2.0`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite:3.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3015_concentrator:4.7.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_design_premium:-`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.53b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_design_premium:1.0`,
        fs:  `cpe:2.3:a:apache:activemq:5.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_design_premium:1.0.0`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_design_standard:-`,
        fs:  `cpe:2.3:a:openstack:horizon:folsom-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_master_collection:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_production_premium:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_web_premium:-`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_web_premium:1.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_web_standard:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p113:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_3_web_standard:1.0`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(2\)spc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_4:1.0.0`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.4:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_4_design_premium:-`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_4_design_premium:4.0`,
        fs:  `cpe:2.3:o:cisco:sn_5428_storage_router:3.2.2-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_4_master_collection:-`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_4_production_premium:-`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_4_web_premium:-`,
        fs:  `cpe:2.3:a:hp:unload:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_4_web_premium:4.0`,
        fs:  `cpe:2.3:h:huawei:s6300ei:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_4_web_standard:4.0`,
        fs:  `cpe:2.3:a:pocketmags:classic_racer:\@7f0801aa:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_5_design_standard:5.0`,
        fs:  `cpe:2.3:a:horde:gollem:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_5_master_collection:5.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.424.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:creative_suite_5_web_premium:5.0`,
        fs:  `cpe:2.3:a:debian:duplicity:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:csi:1.0`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:7.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:adobe:csi:1.0::~~~~x64~`,
        fs:  `cpe:2.3:a:preprojects:business_cards_designer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:csi_cs4:1.0`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:csi_cs4:1.0.1`,
        fs:  `cpe:2.3:a:f5:firepass:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:customization_wizard:8.0.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2010.825.2146.37182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:customization_wizard:9.0.0`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:customization_wizard_x:10.0.0`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.22.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:device_central_cs3:-`,
        fs:  `cpe:2.3:a:apple:safari:3.0.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:device_central_cs3:1.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:device_central_cs4:-`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:device_central_cs4:2.0`,
        fs:  `cpe:2.3:a:adobe:soundbooth_cs3:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:-`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:2.0.0`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:2.0.1`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-16p-ei_ls-5100-16p-ei-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.0.0`,
        fs:  `cpe:2.3:a:microsoft:outlook:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.0.1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.0.2`,
        fs:  `cpe:2.3:a:x.org:libxrender:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.5.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.5.1`,
        fs:  `cpe:2.3:a:usebb:usebb:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.5.2`,
        fs:  `cpe:2.3:h:siemens:speedstream_wireless_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.5.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.5.4`,
        fs:  `cpe:2.3:h:siemens:ruggedcom_win5200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.5.5`,
        fs:  `cpe:2.3:a:devsaran:company:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.5.6`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:digital_editions:4.5.7`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:director:-`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dispatcher:4.1.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dng_converter:9.7`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:document_server:-`,
        fs:  `cpe:2.3:a:naver:nhn_japan_naver_line:2.5:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:document_server:5.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:document_server:6.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_assistant:1.0.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sg.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_assistant:1.0.5`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:-`,
        fs:  `cpe:2.3:h:avaya:cajun_p550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.2`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.41`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.44`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.48`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.49`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.60`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.63`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.87`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8b\)e9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.90`,
        fs:  `cpe:2.3:a:cybozu:garoon:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.91`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.97`,
        fs:  `cpe:2.3:a:apache:camel:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.99`,
        fs:  `cpe:2.3:a:hp:pki_activex_control:1.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.100`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.102`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.1047:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:1.6.2.103`,
        fs:  `cpe:2.3:a:avactis:avactis_shopping_cart:1.8.2:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:2.0`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:download_manager:2.1`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver:-`,
        fs:  `cpe:2.3:a:digium:asterisk:13.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver:1.0.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.0.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver:6.1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver:7.0`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_403_382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver:8.0`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver:9.0`,
        fs:  `cpe:2.3:a:hi-tech_software:c_compiler_for_the_pic10\/12\/16_mcus:9.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver:10.0`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver:11.0`,
        fs:  `cpe:2.3:a:intervideo:windvd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver_cs3:-`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver_cs4:-`,
        fs:  `cpe:2.3:a:chat_room_project:chat_room:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver_cs5.5:11.5`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver_mx:6.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver_mx:6.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/f:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver_mx:7.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dreamweaver_mx:7.0.1`,
        fs:  `cpe:2.3:a:oracle:database_server:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:drive_cs4:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:drive_cs4:1.0`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110807:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:drive_cs4:1.0::~~~~x64~`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:dynamiclink_support:1.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:elicensing:-`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:encore_cs3:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:encore_cs4:-`,
        fs:  `cpe:2.3:a:ixiacom:ixreporter:4.0.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:experience_manager:5.6.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:experience_manager:6.0.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:experience_manager:6.1.0`,
        fs:  `cpe:2.3:a:hp:hpssupply:2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extendscript_toolkit:1.0.3`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extendscript_toolkit:2.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.55:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extendscript_toolkit:2.0.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extendscript_toolkit_cs4:3.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extension_manager:1.5`,
        fs:  `cpe:2.3:a:lucent:security_management_server:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extension_manager:1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extension_manager:1.7`,
        fs:  `cpe:2.3:a:mozilla:firefox:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extension_manager:1.8`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extension_manager_cs3:1.8`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extension_manager_cs4:2.0`,
        fs:  `cpe:2.3:a:ucdok:tomato:0.0.6:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:extension_manager_cs4:2.1`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-2.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fireworks:9.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fireworks_cs3:9.0`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.0:rollup_patch_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fireworks_cs4:10.0`,
        fs:  `cpe:2.3:a:apport_project:apport:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fireworks_cs4:10.0.3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fireworks_cs5:11.0`,
        fs:  `cpe:2.3:a:avaya:ip_soft_phone:6.01.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fireworks_mx:6.0`,
        fs:  `cpe:2.3:a:eagletron:trackercam:5.3.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fireworks_mx:7.0`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fireworks_mx:7.0.2`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash:1.0.0`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash:8.0.22`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_cs3:9.0`,
        fs:  `cpe:2.3:a:xymon:xymon:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_cs4:10.0`,
        fs:  `cpe:2.3:a:barebones:textwrangler:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_cs4_extension_flash_lite_sti:3.0`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_cs4_extension_flash_lite_sti:10.0`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_cs4_sti:10.0`,
        fs:  `cpe:2.3:a:augeas:augeas:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.0.1`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.0.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.0.3`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2011:15.0.954.64:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.0.4`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.0.5`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.0.6`,
        fs:  `cpe:2.3:a:jenkins:git:0.2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.0.7`,
        fs:  `cpe:2.3:h:philips:xper_flex_cardio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.5`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.5.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:6.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.5.2`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.095:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.5.3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.5.4`,
        fs:  `cpe:2.3:a:runtastic:runtastic_mountain_bike:2.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:3.5.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:4.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_media_server:4.0.1`,
        fs:  `cpe:2.3:a:apache:log4j:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_mx:6.0`,
        fs:  `cpe:2.3:a:worldwinner:worldwinner_games:1.9.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_mx:7.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_mx:7.2`,
        fs:  `cpe:2.3:a:haxx:curl:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_playe_for_linux:9.0.115.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.15:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:-`,
        fs:  `cpe:2.3:a:apache:groovy:1.9.0:beta_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:2`,
        fs:  `cpe:2.3:h:buffalotech:wer-am54g54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:3`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:5`,
        fs:  `cpe:2.3:a:apptive:horsepower:2.10.11:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:6`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:6.0.21.0`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l30er-nse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:6.0.79`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.1`,
        fs:  `cpe:2.3:a:symantec:netbackup_client:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.14.0`,
        fs:  `cpe:2.3:a:hp:icewall_file_manager:3.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.19.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.662.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.24.0`,
        fs:  `cpe:2.3:a:adobe:captivate:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.25`,
        fs:  `cpe:2.3:a:abbyy:finereader:6.0:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.53.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.60.0`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.61.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.63`,
        fs:  `cpe:2.3:a:ibm:java:7.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.66.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.67.0`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:sp3:unknown:english:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.68.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.69.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.70.0`,
        fs:  `cpe:2.3:a:serve-static_project:serve-static:1.7.1:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.0.73.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1656.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.1.1`,
        fs:  `cpe:2.3:a:ebay-kleinanzeigen:ebay_kleinanzeigen_for_germany:5.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:7.2`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8.0.22.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:14.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8.0.24.0`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8.0.33.0`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.3.0:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8.0.34.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8.0.35.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8.0.39.0`,
        fs:  `cpe:2.3:a:ibm:dashdb_local:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:8.0.42.0`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9`,
        fs:  `cpe:2.3:a:haxx:curl:7.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.7.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.8.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.9.0`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.20:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.16`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.18d60`,
        fs:  `cpe:2.3:a:tuttophp:happy_chat:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.20`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:0.5.142.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.20.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.28`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.4:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.28.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.31`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.31.0`,
        fs:  `cpe:2.3:a:telos:amhs_data:11.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.45.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.484:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.47.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5416:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.48.0`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf285a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.112.0`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.114.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.115.0`,
        fs:  `cpe:2.3:a:adobe:indesign_cs4_application_feature_set_files:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.124.0`,
        fs:  `cpe:2.3:a:oracle:http_server:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.125.0`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d48.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.151.0`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.152.0`,
        fs:  `cpe:2.3:a:openttd:openttd:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.155.0`,
        fs:  `cpe:2.3:a:debian:reportbug:6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.159.0`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.246.0`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.02:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.260.0`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.2900.2180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.262.0`,
        fs:  `cpe:2.3:h:cisco:identity_services_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.277.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.280`,
        fs:  `cpe:2.3:a:adobe:sing_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.0.283.0`,
        fs:  `cpe:2.3:a:apple:iphoto:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:9.125.0`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10`,
        fs:  `cpe:2.3:a:ibm:rational_directory_server:5.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.0.584`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.2.54`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.12.10`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.12.36`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.15.3`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.22.87`,
        fs:  `cpe:2.3:a:blackberry:blackberry_enterprise_service:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.32.18`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.42.34`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.0.45.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.52.14`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:01-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.52.14.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.52.15`,
        fs:  `cpe:2.3:a:apple:quicktime_streaming_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.53.64`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.82.76`,
        fs:  `cpe:2.3:a:microsoft:windows_media_rights_manager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.85.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.92.8`,
        fs:  `cpe:2.3:a:hp:storeonce_4220_backup_system:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.92.10`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-12_t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.95.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.95.2`,
        fs:  `cpe:2.3:a:php.s3.to:php-i-board:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.102.64`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.105.6`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(3\)n2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.106.16`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:-:pre3:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.1.106.17`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.152`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.152.26`,
        fs:  `cpe:2.3:a:microsoft:windows_digital_rights_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.152.32`,
        fs:  `cpe:2.3:a:emc:rsa_access_manager:6.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.152.33`,
        fs:  `cpe:2.3:a:symantec:veritas_dmp_dsm_solution:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.153.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2:update19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.154.13`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.154.25`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.156.12`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-28tp-si_ls-3600-28tp-si-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.157.51`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1671.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.2.159.1`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.181.14`,
        fs:  `cpe:2.3:o:compaq:tru64:5.0a_pk3_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.181.16`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.181.22`,
        fs:  `cpe:2.3:a:samba:samba:4.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.181.23`,
        fs:  `cpe:2.3:a:zhang_zhijun_taiwan_visit_2014-06-25_project:zhang_zhijun_taiwan_visit_2014-06-25:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.181.26`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.181.34`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.5`,
        fs:  `cpe:2.3:a:barebones:yojimbo:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.7`,
        fs:  `cpe:2.3:a:expressjs:express:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.10`,
        fs:  `cpe:2.3:a:busybox:busybox:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.11`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.15`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.16`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.18`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.19`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.20`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.23`,
        fs:  `cpe:2.3:a:vmware:ace:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.25`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.29`,
        fs:  `cpe:2.3:o:huawei:s9303_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.43`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.48`,
        fs:  `cpe:2.3:a:google:chrome:14.0.805.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.50`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.01:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.51`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.61`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.14.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.63`,
        fs:  `cpe:2.3:a:gimp:gimp:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.67`,
        fs:  `cpe:2.3:a:drupal:drupal:7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.68`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.75`,
        fs:  `cpe:2.3:a:tibco:spotfire_automation_services:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.183.86`,
        fs:  `cpe:2.3:h:d-link:dcs-5009l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.185.22`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.185.24`,
        fs:  `cpe:2.3:a:apache:subversion:0.35.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.186.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.186.6`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.03b12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:10.3.186.7`,
        fs:  `cpe:2.3:o:cisco:unified_wireless_ip_phone_7920_firmware:1.0\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.0.1.152`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.0.1.152::~~~~x64~`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.0.1.153`,
        fs:  `cpe:2.3:a:geodesicsolutions:geocore_max:7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.102.55`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.102.55::~~~~x64~`,
        fs:  `cpe:2.3:a:helios:textpad:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.102.59`,
        fs:  `cpe:2.3:a:pcre:pcre:8.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.102.62`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.102.63`,
        fs:  `cpe:2.3:a:novell:libzypp:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.111.8`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.111.44`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_servers_software:x7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.111.50`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.111.54`,
        fs:  `cpe:2.3:a:redhat:rhel_global_file_system:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.111.64`,
        fs:  `cpe:2.3:h:intel:pro_wireless_3945abg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.111.73`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.7`,
        fs:  `cpe:2.3:a:gigabyte:dldrv2_activex_control:1.4.206.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.34`,
        fs:  `cpe:2.3:a:mcafee:portalshield_for_microsoft_sharepoint_server:2.0.216.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.48`,
        fs:  `cpe:2.3:a:openpkg:openpkg:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.54`,
        fs:  `cpe:2.3:a:perl:perl:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.58`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.59`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.63`,
        fs:  `cpe:2.3:h:cisco:content_services_switch_11050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.69`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.1.115.81`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.223`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxe1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.228`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.2\(21\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.233`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm:5.0.63.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.235`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.236`,
        fs:  `cpe:2.3:a:hapijs:crumb:2.2.0:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.238`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.07.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.243`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.2\(2\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.251`,
        fs:  `cpe:2.3:a:haxx:curl:7.47.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.258`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.261`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:x7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.262`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.270`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.273`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.275`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.280`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(26\)w5\(28a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.285`,
        fs:  `cpe:2.3:o:technicolor:tc7200_firmware:std6.01.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.291`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.297`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.310`,
        fs:  `cpe:2.3:h:huawei:cx600:v600r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.327`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.332`,
        fs:  `cpe:2.3:h:linksys:befsru31:1.42.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.335`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.336`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.341`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.346`,
        fs:  `cpe:2.3:a:apport_project:apport:2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.350`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.356`,
        fs:  `cpe:2.3:a:redmine:redmine:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.359`,
        fs:  `cpe:2.3:h:lucent:ascend_pipeline_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.378`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.394`,
        fs:  `cpe:2.3:a:abine:donottrackme_-_mobile_privacy:1.1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.411`,
        fs:  `cpe:2.3:a:x.org:xfree86:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.418`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.0.1570:online_windows_server_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.424`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.425`,
        fs:  `cpe:2.3:a:keepass:password_safe:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.429`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.438`,
        fs:  `cpe:2.3:o:huawei:s12700_firmware:v200r008c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.440`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.442`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.1:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.451`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.460`,
        fs:  `cpe:2.3:a:term_queue_project:term_queue:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.466`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2010:-:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.468`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:fi:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.475`,
        fs:  `cpe:2.3:a:hp:status:100.0.175.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.491`,
        fs:  `cpe:2.3:h:cisco:pix_firewall_501:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.535`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.548`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.554`,
        fs:  `cpe:2.3:a:dell:sonicwall_analyzer:7.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.559`,
        fs:  `cpe:2.3:a:cisco:unified_application_environment_application_server:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.569`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:11.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.577`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r006c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.626`,
        fs:  `cpe:2.3:a:dimastr:outlook_redemption:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.632`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.2.202.637::~~~linux~~`,
        fs:  `cpe:2.3:a:magzter:bbc_knowledge_magazine:3.01:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.3.300.257`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a3\(2.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.3.300.262`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.3.300.265`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.3.300.268`,
        fs:  `cpe:2.3:h:hp:0235a19l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.3.300.270`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.3.300.271`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.3.300.273`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.4.402.265`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.4.402.278`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.4.402.287`,
        fs:  `cpe:2.3:a:opnet:license_server:16.0.0.8934:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.5.502.110`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.5.502.135`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.5.502.136`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.5.502.146`,
        fs:  `cpe:2.3:a:apache:solr:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.5.502.149`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-4520c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.6.602.167`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.6.602.168`,
        fs:  `cpe:2.3:a:hp:update:4.0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.6.602.171`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.7:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.6.602.180`,
        fs:  `cpe:2.3:a:microsoft:content_management_server:2002:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.169`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.202`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2404lf-al:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.203`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.224`,
        fs:  `cpe:2.3:a:microsoft:windows_services_for_unix:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.225`,
        fs:  `cpe:2.3:a:hp:bidi_channel_components_installer:1.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.232`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.242`,
        fs:  `cpe:2.3:a:php:php:5.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.252`,
        fs:  `cpe:2.3:o:d-link:dcs-932l_camera_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.257`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.260`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.261`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.269`,
        fs:  `cpe:2.3:a:ibm:flex_system_manager:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.272`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.275`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.7.700.279`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.8.800.94`,
        fs:  `cpe:2.3:a:tenable:nessus:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.8.800.97`,
        fs:  `cpe:2.3:a:redhat:richfaces:5.0.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.8.800.168`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.9.900.117`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.9.900.152`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.3.0:cp05:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:11.9.900.170`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.3314.2101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:12.0.0.38`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option_server:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:12.0.0.41`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:12.0.0.43`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:12.0.0.44`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:12.0.0.70`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.1.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:12.0.0.77`,
        fs:  `cpe:2.3:a:invensys:intouch\/wonderware_application_server:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.182`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:01-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.201`,
        fs:  `cpe:2.3:a:pinnaclesys:discapi:2.10.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.206`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.214`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.559:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.223`,
        fs:  `cpe:2.3:o:huawei:quidway_s9300_firmware:v200r002c00spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.231`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.250`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.252`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.9f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.258`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.260`,
        fs:  `cpe:2.3:a:emulex:common_san_management:5.0.66.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.262`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.264`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.289`,
        fs:  `cpe:2.3:a:intuit:quickbooks:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:13.0.0.292`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:14.0.0.125`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)yq3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:14.0.0.145`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:15.0.0.189`,
        fs:  `cpe:2.3:a:hp:randmap:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:15.0.0.239`,
        fs:  `cpe:2.3:a:qemu:qemu:0.11.0-rc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:16.0.0.234`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:16.0.0.257`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:16.0.0.287`,
        fs:  `cpe:2.3:a:adobe:search_for_help:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:16.0.0.296`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:16.0.0.305`,
        fs:  `cpe:2.3:a:novell:zenworks:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:17.0.0.134`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:17.0.0.169`,
        fs:  `cpe:2.3:a:gnu:glibc:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:17.0.0.188`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.6:rev36235:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.161`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.194`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0f_pk7_bl18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.209`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.261`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.261::~~esr~~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.268`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.324`,
        fs:  `cpe:2.3:a:iss:blackice_defender:2.9cap:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.326`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p164:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.333::~~esr~~~`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.343::~~esr~~~`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.9:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.352::~~esr~~~`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.360::~~esr~~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:18.0.0.366::~~esr~~~`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:19.0.0.185`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:19.0.0.207`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:19.0.0.226`,
        fs:  `cpe:2.3:o:cisco:ios:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:19.0.0.245`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:19.0.0.245::~~~chrome~~`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:19.0.0.245::~~~edge~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.5.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:19.0.0.245::~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:kryo:iodine:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:20.0.0.228`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:20.0.0.235`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:20.0.0.286`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.92.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:20.0.0.306`,
        fs:  `cpe:2.3:o:juniper:junose_t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:20.0.0.306::~~~chrome~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:20.0.0.306::~~~edge~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:20.0.0.306::~~~internet_explorer~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:21.0.0.97`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:21.0.0.97::~~~chrome~~`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:21.0.0.97::~~~edge~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:21.0.0.97::~~~internet_explorer~~`,
        fs:  `cpe:2.3:h:brickom:wcb-100ap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:21.0.0.213`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:21.0.0.226`,
        fs:  `cpe:2.3:a:oracle:sysfw:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:21.0.0.242::~~~chrome~~`,
        fs:  `cpe:2.3:a:enalean:tuleap:7.5.99.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:21.0.0.242::~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:conky:conky:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:22.0.0.192`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.2.01035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:22.0.0.192::~~~chrome~~`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:22.0.0.192::~~~edge~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:22.0.0.192::~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:techsmith:snagit:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:22.0.0.211`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:22.0.0.211::~~~chrome~~`,
        fs:  `cpe:2.3:a:sparkpay:capital_one_spark:0.9.81:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:22.0.0.211::~~~edge~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:22.0.0.211::~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:23.0.0.185`,
        fs:  `cpe:2.3:a:digia:qt:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:23.0.0.185::~~~chrome~~`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:23.0.0.185::~~~edge~~`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:23.0.0.185::~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.0.1570:online_windows_2000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:23.0.0.207`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:23.0.0.207::~~~chrome~~`,
        fs:  `cpe:2.3:a:fujitsu:serverview_operations_manager:5.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:23.0.0.207::~~~edge~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:23.0.0.207::~~~internet_explorer~~`,
        fs:  `cpe:2.3:h:cisco:voice_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.186`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.186::~~~chrome~~`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.186::~~~edge~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)mra3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.186::~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:beta1:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.194`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.core:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.194::~~~chrome~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.194::~~~edge~~`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.194::~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.221`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.221::~~~chrome~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.221::~~~edge~~`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:24.0.0.221::~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:26.0.0.137`,
        fs:  `cpe:2.3:a:ibm:rational_system_architect:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:26.0.0.137::~~~chrome~~`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:26.0.0.137::~~~edge~~`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player:26.0.0.137::~~~internet_explorer_11~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.02.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_esr:18.0.0.329`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:10.1.106.17`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:10.2.157.51`,
        fs:  `cpe:2.3:a:ibm:workload_deployer:3.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:10.3.186.7`,
        fs:  `cpe:2.3:a:blackbox:inkra_suite:2.1.5-b011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.0.1.153`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.102.59`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.5`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.6`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.2.2021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.7`,
        fs:  `cpe:2.3:h:cisco:meraki_ms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.8`,
        fs:  `cpe:2.3:a:cisco:resource_manager:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.9`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.10`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.16`,
        fs:  `cpe:2.3:a:flurry:flurry-analytics-android:3.3.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.19`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.24`,
        fs:  `cpe:2.3:a:google:chrome:12.0.716.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.29`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.31`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.2:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.32`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.111.43`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.112.60`,
        fs:  `cpe:2.3:a:oracle:identity_management_10g:10.1.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.112.61`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.6`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.7`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.8`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.11`,
        fs:  `cpe:2.3:a:atlassian:jira:3.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.12`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.17`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.20`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.48\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.27`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.34`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.36`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.37`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_android:11.1.115.47`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:9.0.31`,
        fs:  `cpe:2.3:a:isc:bind:9.7.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:9.0.48.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.2.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:9.0.115.0`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:7.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:9.0.124.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:9.0.151.0`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:10.0.12.36`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:11.2.202.559`,
        fs:  `cpe:2.3:a:microsoft:office:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:11.2.202.621`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_player_for_linux:11.2.202.644`,
        fs:  `cpe:2.3:a:soraxsoft:sorax_reader:2.0.3129.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flash_video_encoder:2.0`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:5.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flex_builder:3.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flex_builder_plug-in:3.0.2.214193`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.2_rev_a:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flex_sdk:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:flex_sdk:1.5`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fonts_all:1.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fonts_all:2.0`,
        fs:  `cpe:2.3:a:redhat:cloudforms:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:fonts_all:2.0::~~~~x64~`,
        fs:  `cpe:2.3:a:apache:juddi:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:form_client_end-user_components:5.0.0`,
        fs:  `cpe:2.3:a:xerox:freeflow_print_server:8.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:formflow_filler:-`,
        fs:  `cpe:2.3:a:context_project:context:7.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:formflow_filler:2.3.5`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:formflow_filler:2.22`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:formflow_filler:2.23`,
        fs:  `cpe:2.3:a:vips:vips:7.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:formflow_filler:2.24`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:7.0`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:7.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:7.2`,
        fs:  `cpe:2.3:a:apple:safari:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:8.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_5c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:8.0.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:8.0.2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:8.0.3`,
        fs:  `cpe:2.3:a:sonicwall:aventail_access_manager:10.4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:9.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:9.0.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:9.0.2`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:framemaker:9.0.3`,
        fs:  `cpe:2.3:h:cisco:asa_5585-x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:freehand:11.0`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:freehand:11.0.0.439`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:freehand:11.0.0.458`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:freehand:11.0.1`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:freehand:11.0.2`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:freehand_mx:11.0`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:freehand_mx:11.0.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.03.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:freehand_mx:11.0.2`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive:-`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.14:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive:4.0`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:1.6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive:4.0.1`,
        fs:  `cpe:2.3:a:php:php:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive:5.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive:6.0.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive:9`,
        fs:  `cpe:2.3:a:isc:bind:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive_cs2:7.0.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive_cs2:7.0.2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive_cs2:8.0`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:golive_cs2:8.0.1`,
        fs:  `cpe:2.3:a:atutor:atutor:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:graphics_server:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:graphics_server:2.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:graphics_server:2.1`,
        fs:  `cpe:2.3:a:python:pillow:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:help_center:1.0.0`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:help_center:2.1`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.0.1_build_6403:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:help_viewer:1.0`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:help_viewer:1.1`,
        fs:  `cpe:2.3:a:dotcms:dotcms:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:help_viewer:1.1.198`,
        fs:  `cpe:2.3:a:altiris:cmdb_and_asset_management_report_language_pack:6.5.1021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:help_viewer:2.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:homesite:5.2`,
        fs:  `cpe:2.3:a:shots:shots:1.0.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:homesite:5.5`,
        fs:  `cpe:2.3:a:redhat:sysreport:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:7.0`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:8.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf021:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:9.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:10.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:11.0`,
        fs:  `cpe:2.3:a:vmware:horizon_view:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:11.0.1`,
        fs:  `cpe:2.3:a:libpng:libpng:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:12.0.0`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:13.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:13.0.1`,
        fs:  `cpe:2.3:a:cmscout:cmscout:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:13.0.2`,
        fs:  `cpe:2.3:a:adobe:brackets:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:13.0.3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:14.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:15.0`,
        fs:  `cpe:2.3:h:hp:jd675a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:16.0.1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:16.0.2`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:16.0.3`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:16.0.4`,
        fs:  `cpe:2.3:h:t-mobile:g2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:16.0.5`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cbz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:16.2.0`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:16.2.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:illustrator:16.2.2`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:01-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign:3.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd373a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign:3.0.1`,
        fs:  `cpe:2.3:a:sun:seam:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign:4.0.0`,
        fs:  `cpe:2.3:a:hp:release_control:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign:5.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.7.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign:5.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign:5.0.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign:6.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign_cs3_icon_handler:5.0`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign_cs4_application_feature_set_files:6.0`,
        fs:  `cpe:2.3:a:ibm:hacmp:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign_cs4_common_base_files:6.0`,
        fs:  `cpe:2.3:a:apache:derby:10.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign_cs4_icon_handler:6.0`,
        fs:  `cpe:2.3:o:seil:x86_fuji_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:indesign_cs4_icon_handler:6.0::~~~~x64~`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:jabber:5.2.1.30`,
        fs:  `cpe:2.3:h:linksys:wrt54g_v5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:japanese_fonts_support_for_adobe_reader:9.0.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.827.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:jrun:-`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:jrun:4.0`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:jrun:4.0:sp1`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:jrun:4.0:sp1a`,
        fs:  `cpe:2.3:a:ibm:lotus_mobile_connect:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:jrun:4.0_build_61650`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:kuler:2.0`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:linguistics_cs3:3.0.0`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:sp3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:linguistics_cs4:4.0.0`,
        fs:  `cpe:2.3:a:ibm:java:7.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:linguistics_cs4:4.0.0::~~~~x64~`,
        fs:  `cpe:2.3:h:cisco:2951_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_data_services:3.0`,
        fs:  `cpe:2.3:a:chillcreations:mod_ccnewsletter:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_data_services:4.5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.2.1_a:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_data_services:4.6`,
        fs:  `cpe:2.3:a:libdwarf_project:libdwarf:20160613:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_data_services:4.7`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_designer_es2:9.0.0.20091029.1.612548`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_es:8.2.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_es2:9.0.0.0`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_form_manager:-`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_form_manager:7.01`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:livecycle_workflow:-`,
        fs:  `cpe:2.3:o:suse:suse_linux:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_encoder_cs4:-`,
        fs:  `cpe:2.3:a:ibm:http_server:2.0.47.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_encoder_cs4:1.0`,
        fs:  `cpe:2.3:a:atlassian:jira:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_encoder_cs4_importer:1.0`,
        fs:  `cpe:2.3:o:ibm:aix:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_player:-`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_player:0.0.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_player:1.0`,
        fs:  `cpe:2.3:a:microsoft:data_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_player:1.1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_player:1.5`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:media_player:1.8`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:motionpicture_color_files:1.0`,
        fs:  `cpe:2.3:h:siemens:scalance_w786-2rr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:onlocation_cs3:3.0`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.6.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:onlocation_cs4:4.0.1`,
        fs:  `cpe:2.3:h:lexmark:x544:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:onlocation_cs4:4.0.2`,
        fs:  `cpe:2.3:a:isc:bind:9.10.4:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:onlocation_cs4:4.0.3`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:output_module:2.0`,
        fs:  `cpe:2.3:o:yamaha:rta55i:4.06.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:output_module:2.1`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pagemaker:-`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pagemaker:6.5`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pagemaker:7.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pagemaker:7.0.1`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pagemaker:7.0.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_creation_add-on:9.0.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_ifilter:5.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_ifilter:6.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_ifilter:9.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.9:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_library_sdk:8.0`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f2-s4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_library_sdk:9.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_library_sdk:9.0::~~~~x64~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_settings:1.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_settings_cs4:9.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:5.0\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdf_settings_cs5:10.0`,
        fs:  `cpe:2.3:a:netscape:messaging_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pdistiller:8.1`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photodeluxe:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photodeluxe:3.0`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.720.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photodeluxe:3.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_client:06-50-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photodeluxe:4.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:-`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:2.5::pro`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:3.0::pro`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.3050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:4.0::pro`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:5.0::pro`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:6.0`,
        fs:  `cpe:2.3:a:menalto:gallery:1.6:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:6.0::pro`,
        fs:  `cpe:2.3:a:hp:openview_configuration_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:6.0.1`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:7.0`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:7.0.1`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:8.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:9.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.8:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:9.0.1`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:9.0.2`,
        fs:  `cpe:2.3:a:dropbox:dropbox:0.7.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:10.0`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:10.0.1`,
        fs:  `cpe:2.3:h:huawei:ne40e\/80e:v600r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:11.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-50:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:11.0::~~~~x64~`,
        fs:  `cpe:2.3:a:acronis:license_server:10.0.13762:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:11.0.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:11.0.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:11.0.4`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:12.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12c\)ev01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:12.0.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:12.0.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.243.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:12.0.3`,
        fs:  `cpe:2.3:a:microsoft:office_multilingual_user_interface_pack:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:12.0.4`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.14:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:15.0`,
        fs:  `cpe:2.3:a:gnu:grub2:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:15.2.2`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:16.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:16.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:17.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:17.0.1`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.3.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:18.0`,
        fs:  `cpe:2.3:a:ibm:aix_parallel_systems_support_programs:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:18.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jpb2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:18.1.0`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:18.1.1`,
        fs:  `cpe:2.3:a:redmine:redmine:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:19.0.0`,
        fs:  `cpe:2.3:a:blackbox:inkra_center_point:2.1.6-b032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop:cs`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_album:2.0:-:starter`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.5:beta2:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_album:3.0:-:starter`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_album:3.2:-:starter`,
        fs:  `cpe:2.3:a:boldonjames:masterkeyplus:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cc:16.1.1`,
        fs:  `cpe:2.3:a:batavi:batavi:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs3:10.0`,
        fs:  `cpe:2.3:a:sony:vaio_manual_cybersupport:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs4:11.0`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs4_support:11.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.09.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs5:12.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs5:12.0.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs5:12.0.2`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.0:cr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs5:12.0.3`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1026:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs5:12.0.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs5:12.0.5`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma897xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs5.1:12.1`,
        fs:  `cpe:2.3:a:rsa:authentication_api:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs5.1:12.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs6:13.0`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_cs6:13.0.1`,
        fs:  `cpe:2.3:o:corega:cg-wlbargnl_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:-`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:1.0`,
        fs:  `cpe:2.3:a:josh_fradley:burden:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:2.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:3.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:4.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:5.0`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.999:20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:6.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_74:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:7.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:8.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.2:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:9.0`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:photoshop_elements:10.0`,
        fs:  `cpe:2.3:a:tidio-form_project:tidio-form:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:pixel_bender_toolkit:1.0`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_elements:3.0.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.29:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_elements_templates:1.0.0`,
        fs:  `cpe:2.3:a:alquimia:managesite:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_pro_cs3:3.0.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_pro_cs3:3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_pro_cs3:3.1.1`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_pro_cs3:3.2`,
        fs:  `cpe:2.3:a:php:php:5.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_pro_cs4:4.0.1`,
        fs:  `cpe:2.3:a:apache:libcloud:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_pro_cs4:4.1.0`,
        fs:  `cpe:2.3:a:collectd:collectd:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_pro_cs4:4.2.0`,
        fs:  `cpe:2.3:a:oracle:database_server:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:premiere_pro_cs4:4.2.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:presenter:6.2.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.03.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:presenter:7.0`,
        fs:  `cpe:2.3:a:riken:xoonips:3.44:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:presenter:7.0.6`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:reader:7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:reader:8`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:reader:9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(58\)se2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:reader:11.0.15::~~desktop~~~`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:reader:11.0.16`,
        fs:  `cpe:2.3:a:redhat:jboss_weld:3.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:reader_extended_language_support_font_pack:9.0.0`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:-`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:6`,
        fs:  `cpe:2.3:a:ca:host-based_intrusion_prevention_system:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:7`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:7.0.1`,
        fs:  `cpe:2.3:h:supermicro:x9dre-ln4f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:7.0.2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:7.0.3`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:8`,
        fs:  `cpe:2.3:a:dymo:dymo_label:8.3.0.1242:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:8.0.1`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:13.0.5204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:8.0.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.40.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:9`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf844a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:9.0.0.228`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:9.0.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:9.0.1.232`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:9.0.2`,
        fs:  `cpe:2.3:o:xen:xen:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:10.0`,
        fs:  `cpe:2.3:a:google:chrome:0.4.154.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:11.0`,
        fs:  `cpe:2.3:a:horde:imp:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:2015.0.3`,
        fs:  `cpe:2.3:a:seeddms:seeddms:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp:x5`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.18:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp_server:-`,
        fs:  `cpe:2.3:a:project-redcap:redcap:4.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp_server:6`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp_server:7`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:robohelp_server:8`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:search_for_help:1.0`,
        fs:  `cpe:2.3:a:apple:remote_desktop:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:service_manager_extension:1.0`,
        fs:  `cpe:2.3:a:tiger-fish:fancy_slide:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:setup:1.0`,
        fs:  `cpe:2.3:a:gnu:tramp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:setup:2.0`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:sgm_cs4:3.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave:8.5.1.102`,
        fs:  `cpe:2.3:a:avocent:dsview:3.1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:-`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.02.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:1.0`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:2.0`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:3.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:4.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:5.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:6.0`,
        fs:  `cpe:2.3:a:google:v8:3.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.0.196`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.0:update2_patch5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.0.196a`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-30:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.0.204`,
        fs:  `cpe:2.3:a:gnome:glib:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.0.205`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.1.100`,
        fs:  `cpe:2.3:a:symantec:backupexec_system_recovery:8.0.1.24976:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.1.103`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.1.105`,
        fs:  `cpe:2.3:a:djangoproject:django:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.1.106`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.321`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.323`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.324`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:8.5.325`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:9`,
        fs:  `cpe:2.3:a:huawei:espace_7910:v200r002c00spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:9.0.383`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.651.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:9.0.432`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.0.0.210`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.0.1.004`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.1.0.011`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.1.0.11`,
        fs:  `cpe:2.3:a:symantec:reporting_agents:1.0.258.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.1.1.016`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.1.4.020`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.2.0.021`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.120:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.2.0.022`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.16.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:10.2.0.023`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11`,
        fs:  `cpe:2.3:a:hp:web_registration:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.0.0.456`,
        fs:  `cpe:2.3:o:motorola:android:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.0.3.471`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.0.595`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.2:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.0.596`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.1.601`,
        fs:  `cpe:2.3:a:tejimaya:openpne:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.2.602`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.6.606`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.7.609`,
        fs:  `cpe:2.3:h:huawei:ar3200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.8.612`,
        fs:  `cpe:2.3:a:gnome:glib:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.9.615`,
        fs:  `cpe:2.3:a:hp:software_xalana_xslt_processor:1.10.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.9.620`,
        fs:  `cpe:2.3:a:ibm:lotus_foundations_start:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.5.10.620`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.6.0.626`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.5:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.6.1.629`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.408:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.6.3.633`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.2sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.6.4.634`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:2007.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.6.5.635`,
        fs:  `cpe:2.3:a:wallpaperscript:wallpaperscript:3.5.0082:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.6.6.636`,
        fs:  `cpe:2.3:a:oracle:micros_c2:9.89.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.6.7.637`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:11.6.8.638`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:7.1.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.0.0.112`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.0.2.122`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.0.3.133`,
        fs:  `cpe:2.3:h:nortel:optical_metro_5200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.0.4.144`,
        fs:  `cpe:2.3:a:isc:inn:1.4unoff4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.0.6.147`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2xo.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.0.7.148`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6:\(1\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.0.9.149`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.1.0.150`,
        fs:  `cpe:2.3:a:scott_reynen:node_embed:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player:12.2.7.197`,
        fs:  `cpe:2.3:a:mollify:mollify:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:shockwave_player_merge_module:12.0.0.1`,
        fs:  `cpe:2.3:a:bss:continuity_cms:4.2.22640.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:sing_cs3:0.1`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:3.2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:sing_cs4:2.0`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:soundbooth_cs3:1.0`,
        fs:  `cpe:2.3:a:ibm:spss_samplepower:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:soundbooth_cs4:2.0`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:soundbooth_cs4:2.0.1`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:soundbooth_cs4_codecs:2.0`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.12:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:spelling_dictionaries_support_for_adobe_reader:8.0.0`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:spelling_dictionaries_support_for_adobe_reader:9.0.0`,
        fs:  `cpe:2.3:a:winzip:winzip:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:stock_photos:1.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:stock_photos_cs2:-`,
        fs:  `cpe:2.3:a:google:chrome:8.0.560.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:stock_photos_cs2:1.0.9`,
        fs:  `cpe:2.3:a:webmin:webmin:1.680:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:stock_photos_cs3:1.5`,
        fs:  `cpe:2.3:h:cisco:catalyst_2901:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:stock_photos_cs3:1.5.1`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:studio_mx:7.0`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:suite_shared_configuration_cs4:1.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:suite_specific:2.0.0`,
        fs:  `cpe:2.3:a:redhat:wu_ftpd:2.6.1-18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:svg_viewer:-`,
        fs:  `cpe:2.3:a:apple:preview:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:svg_viewer:1.0`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:svg_viewer:2.0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:svg_viewer:3.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:svg_viewer:3.01`,
        fs:  `cpe:2.3:a:magzter:gent_magazine:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:svg_viewer:3.02`,
        fs:  `cpe:2.3:a:synology:cloud_station:3.0-3005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:type_support:1.0`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:type_support_cs4:9.0`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.13:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:type_support_cs4:9.0::~~~~x64~`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:update_manager:4.0.3`,
        fs:  `cpe:2.3:o:opensuse:evergreen:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:update_manager:4.0.5`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:update_manager:5`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:update_manager:5.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_advanced_media_gateway:1.0\(.1.13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:update_manager:6.0`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue:1.0`,
        fs:  `cpe:2.3:h:buffalotech:wsr-1166dhp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue:1.0.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs2:2.0`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2008:12.0.781.64:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs2:2.0.1`,
        fs:  `cpe:2.3:a:ibm:data_server_client:9.7.0.441:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs3_client:3.0.0`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs3_client:3.1.0`,
        fs:  `cpe:2.3:a:oracle:http_server:1.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs3_server:3.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs3_server:3.1.0`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs3_server:adobe_version_cue_cs3_server_`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs4_server:4.0`,
        fs:  `cpe:2.3:a:trendmicro:interscan_web_security_suite:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:version_cue_cs4_server:4.0.1`,
        fs:  `cpe:2.3:a:mozilla:camino:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:was_cs3:1.0`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:widget_browser:2.0.230`,
        fs:  `cpe:2.3:a:primetek:primefaces:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:widget_browser:2.0_build_230`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0.1984:online_windows_2003_x64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:winsoft_linguistics_plugin:1.0`,
        fs:  `cpe:2.3:a:f5:big-ip:4.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:winsoft_linguistics_plugin:1.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:winsoft_linguistics_plugin:1.1::~~~~x64~`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:xmp_panels_cs3:1.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adobe:xmp_panels_cs4:2.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.00:beta`,
        fs:  `cpe:2.3:h:antlabs:inngate_ig_3101:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.01:beta`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-03-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.02`,
        fs:  `cpe:2.3:a:lxml:lxml:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.02:a`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:38.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.03`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.04`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.04:a`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.05`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.06`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.06:a`,
        fs:  `cpe:2.3:a:sendmail:sendmail:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.07`,
        fs:  `cpe:2.3:a:oracle:payroll:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.08`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.978:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.08:a`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.09`,
        fs:  `cpe:2.3:o:lacie:lac9000436u_firmware:2.3.0.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.09:a`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.10`,
        fs:  `cpe:2.3:a:liftweb:lift:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p220:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.12`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.13`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.14`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2009.211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.15`,
        fs:  `cpe:2.3:h:emerson:network_power_avocent_mergepoint_unity_2016:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.16`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.16:a`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.17`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.18`,
        fs:  `cpe:2.3:h:cisco:rv130_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.18:a`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.19`,
        fs:  `cpe:2.3:a:plone:plone:5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.20.0`,
        fs:  `cpe:2.3:a:goforandroid:go_email_widget:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.20.1`,
        fs:  `cpe:2.3:o:franklinfueling:ts-550_evo_firmware:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.20.2`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.20.3`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.20.4`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.20.5`,
        fs:  `cpe:2.3:a:collabnet:subversion:1.3.0-r17949:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adodb_project:adodb:5.20.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adopt_o_pet_project:adopt_o_pet:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adp4u:adp_agency_immobiliare:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:alfresco:alfresco:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:adrian_chadd:rtg:0.7.4`,
        fs:  `cpe:2.3:a:campustv:campus_link_-_campus_tv_hkusu:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:adrian_chadd:rtg2:0.9`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrian_chadd:rtg2:0.9.1`,
        fs:  `cpe:2.3:h:juniper:nsmexpress:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrian_chadd:rtg2:0.9.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.::~free~wordpress~~~`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.::~pro~wordpress~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.1::~free~wordpress~~~`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.1::~pro~wordpress~~~`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.2::~free~wordpress~~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.2::~pro~wordpress~~~`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.3::~free~wordpress~~~`,
        fs:  `cpe:2.3:o:cisco:catos:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.3::~pro~wordpress~~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.4::~free~wordpress~~~`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.4::~pro~wordpress~~~`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_51:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.5::~free~wordpress~~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.5::~pro~wordpress~~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2400m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.6::~free~wordpress~~~`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_set:07-50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.6::~pro~wordpress~~~`,
        fs:  `cpe:2.3:a:gnu:wget:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adrotateplugin:adrotate:3.9.7::~pro~wordpress~~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.5:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:adt-taxis:adt_taxis:6.0::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:adtran:aos:10.8.0`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.6.0.444:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:adtran:aos:10.8.1`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:adtran:netvanta_7060:-`,
        fs:  `cpe:2.3:a:owncloud:owncloud:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:adtran:netvanta_7100:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advanced_forum_signatures_project:advanced_forum_signatures:2.0.4::~~~mybb~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advancedsearchbar:advanced_search_bar:3.23`,
        fs:  `cpe:2.3:a:pgp:universal_server:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advancedsearchbar:advanced_search_bar:3.25`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advanceprotech:advanceware:-`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advantech:adamview:4.3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.355.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advantech:advantech_webaccess:5.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advantech:advantech_webaccess:6.0`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.922:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advantech:advantech_webaccess:7.0`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:eki-122x_series_firmware:1.49`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:advantech:eki-1321:-`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:eki-1321_series_firmware:1.96`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:eki-1321_series_firmware:2015-10-06`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:advantech:eki-1322:-`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:eki-1322_series_firmware:1.96`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:eki-1322_series_firmware:2015-10-06`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:advantech:eki-1361:-`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:eki-1361_series_firmware:1.17`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xk4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:advantech:eki-1362:-`,
        fs:  `cpe:2.3:a:emc:control_center:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:eki-1362_series_firmware:1.17`,
        fs:  `cpe:2.3:a:google:chrome:14.0.816.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:advantech:vesp211-232:-`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:vesp211-232_firmware:1.5.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:vesp211-232_firmware:1.7.2`,
        fs:  `cpe:2.3:h:linksys:befsr41_v3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:advantech:vesp211-eu:-`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.3:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/o:advantech:vesp211-eu_firmware:1.7.2`,
        fs:  `cpe:2.3:h:rockwellautomation:rslogix_emulate_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advantech:webaccess:7.2`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:advantech:webaccess:8.0`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.7:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:advantech:webaccess:8.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:adways:party_track_sdk:1.6.5::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aegirproject:hostmaster:6.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg510-10:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aegirproject:hostmaster:6.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:winzip:winzip_command_line_support_add-on:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aegirproject:hostmaster:6.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aegirproject:hostmaster:6.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aegirproject:hostmaster:6.x-3.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.12:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aeroexpress:aeroexpress:2.6.2::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:10.1.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.80`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.90`,
        fs:  `cpe:2.3:o:oracle:linux:7:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.91`,
        fs:  `cpe:2.3:h:cisco:catalyst_2900:lre_xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.92`,
        fs:  `cpe:2.3:a:symantec:brightmail_antispam:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.93`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.0.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.94`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.95`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.96`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.97`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.98`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:0.99`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:1.00`,
        fs:  `cpe:2.3:a:ca:identity_manager:12.0.7.441:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aertherwide:exiftags:1.01`,
        fs:  `cpe:2.3:h:hp:color_laserjet_2500n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:affinitycu:affinity_mobile_atm_locator:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:afnetworking_project:afnetworking:2.5.2`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:afro-beat_project:afro-beat:0.2::~~~android~~`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:afsinc:metalcasting_newsstand:3.12.0::~~~android~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aftab:tickfa:1.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:afterlifewitharchie:afterlife_with_archie:2.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:13.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:afterlogic:mailsuite_pro:6.3`,
        fs:  `cpe:2.3:h:hp:jd429b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ag-klettern-odenwald:ag_klettern_odenwald:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:rv042g_dual_gigabit_wan_vpn_firmware:4.2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:age_verification_project:age_verification:0.4`,
        fs:  `cpe:2.3:a:skype:skype:1.0.0.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agi:license_manager:3.0.3`,
        fs:  `cpe:2.3:o:bluecoat:cacheos:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agi:planetary_data_supplement:9.0.0`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agi:stk:9.1.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agi:stk%2fkml_utility_for_stk:9.1.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.1:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agi:stk_engine_deployment_resources:9.1.0`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:1password:-:-:~~~android~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:1password:-:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:1password:-:-:~~~windows~~`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:1password:3.0:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:1password:3.9.9`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:-:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.10.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.5.0:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:microsoft:index_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.5.1:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.5.2:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:opscode:chef:0.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.5.3:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:samba:samba:2.2.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.6.0:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.6.1:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:adobe:studio_mx:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.6.2:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.6.3:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:1.6.4:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.0.0:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:h:sun:fire_x4150_server:sw_2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.0.1:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.2\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.0.2:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.0.3:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.0.4:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:siemens:compas:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.0.5:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.0.6:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.0.8:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:sun:jsse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.0:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.1:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:hp:status:60.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.2:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.3:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:5.1:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.4:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server_solution_engine:5.5.0.46.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.5:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.6:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.7:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8:rc4_pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.8:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:o:juniper:junos:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.9:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.10:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.11:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.12:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.13:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cbr:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.14:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:h:hp:jf807a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.1.15:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.5.841:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilebits:knox:2.2.0:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.15.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilefleet:fleetcommander:4.0`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilefleet:fleetcommander:4.08`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.812:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agilefleet:fleetcommander_kiosk:4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agnitum:outpost_security_suite:6.7.3.3063.452.0726:-:professional`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agnitum:outpost_security_suite:7.0.3330.505.1221:beta:professional`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:agrinsoft:argin_all_dvd_ripper:4.0`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.1:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ahtty:ahtty:1.97.16::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aiadp:guess_the_pixel_character_quiz:1.3::~~~android~~`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:-`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:2013.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:4.0.1.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:4.0.2.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:4.0.3.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:4.0.4.0`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:4.0.5.0`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:5.0.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(24\)sv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:5.0.1.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:5.0.2.0`,
        fs:  `cpe:2.3:a:sharethis:sharethis:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:5.1.0.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.666:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:5.1.1`,
        fs:  `cpe:2.3:a:hp:software_certificate_management_client:6.20.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:5.1.2`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo:6.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)sl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo-asp:4.0.4.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo-asp:5.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo-plus:5.1`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo-plus:5.1.0.1`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aimluck:aipo-plus:5.1.1`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ains:foiaxpress:6.4.0.0`,
        fs:  `cpe:2.3:a:apache:subversion:0.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ains:foiaxpress_document_delivery_service:6.4.0.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.8:bundle11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ains:foiaxpress_ocr_service:6.4.0.0`,
        fs:  `cpe:2.3:a:hp:director:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ains:foiaxpress_sync_service:6.4.0.0`,
        fs:  `cpe:2.3:a:cloudera:cloudera_cdh:cdh3:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aipluspro:asset_inventory_plus:4.6.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:air-watch:air-watch_mobile_device_management_software:6.5`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:air_war_hero_project:air_war_hero:3::~~~android~~`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.5:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.2`,
        fs:  `cpe:2.3:a:4you-studio:com_jphone:1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.2.1`,
        fs:  `cpe:2.3:a:vmware:player:1.0.5_build_56455:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.3`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.4`,
        fs:  `cpe:2.3:a:mobileeventguide:ids_2013:1.21:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.4.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.4.2`,
        fs:  `cpe:2.3:a:realnetworks:realarcade_installer:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.4.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.4.4`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.5`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.6`,
        fs:  `cpe:2.3:a:atlassian:jira:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.6.1`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.6.2`,
        fs:  `cpe:2.3:h:cisco:cs-mars:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.7`,
        fs:  `cpe:2.3:a:bananadance:banana_dance:0.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.8`,
        fs:  `cpe:2.3:a:vmware:vsphere_host_update_utility:4.0.0.12305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.9`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.9.1`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.9.2`,
        fs:  `cpe:2.3:a:isc:bind:9.2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:0.9.3`,
        fs:  `cpe:2.3:a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.0`,
        fs:  `cpe:2.3:a:gameresort:stupid_zombies:1.12:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.0:beta1`,
        fs:  `cpe:2.3:a:netscape:navigator:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.0:beta2`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.7:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.0:rc1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.0:rc2`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.0:rc3`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.0:rc4`,
        fs:  `cpe:2.3:h:cisco:asa_5500_csc-ssm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aircrack-ng:aircrack-ng:1.2:beta1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:airdroid:airdroid:1.0.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:airdroid:airdroid:1.0.2`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:airdroid:airdroid:1.0.3`,
        fs:  `cpe:2.3:a:logitech:lws_motion_detection:13.20.1176.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:airdroid:airdroid:1.0.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:airdroid:airdroid:1.0.4:beta`,
        fs:  `cpe:2.3:a:ibm:rational_performance_tester:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:airdroid:airdroid:1.0.5`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:airdroid:airdroid:1.0.6:beta`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:airshowbuzz:asb.tv:1.2`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:airties:air_6372:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:airties:rt-210:-`,
        fs:  `cpe:2.3:o:sweex:lb000021_router_firmware:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:airties:rt-210_firmware:-`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:airvana:hubbub_c1-600-rt:-`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aisquared:zoomtext:9.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.4`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:1.2:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.5`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-20-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.6`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.7`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:8.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.8`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.9`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.45.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46`,
        fs:  `cpe:2.3:a:homerelectric:hea_mobile:1.153.0034:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sympa:sympa:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.10:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.2`,
        fs:  `cpe:2.3:a:redhat:mod_cluster:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.3`,
        fs:  `cpe:2.3:h:huawei:nip2200:v100r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rack_project:rack:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.5`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:9.9\(9\)st1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.6`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:apple_application_support:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.7`,
        fs:  `cpe:2.3:a:microsoft:visual_c\&#43;\&#43;:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:werdswords:download_shortcode:0.1:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p208:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:serv-u:serv-u:3.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.46.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.1`,
        fs:  `cpe:2.3:a:git-scm:git:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.3`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3k\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:tomcat:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.4`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:4.2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.5`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:lync:2010:*:attendant_x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.6`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.07.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.7`,
        fs:  `cpe:2.3:a:novell:zenworks_desktops:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.8`,
        fs:  `cpe:2.3:h:hp:laserjet_flow_m525c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.9`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.47.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sg.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.52:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.2`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:inmatrix:zoom_player:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.3`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:rc6:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.4`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:camino:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.5`,
        fs:  `cpe:2.3:o:cisco:spa8000_8-port_ip_telephony_gateway_firmware:6.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:audiosharescript:audioshare:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.6`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.0b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.7`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.8`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bea:jrockit_mission_control:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.9`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.48.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49`,
        fs:  `cpe:2.3:a:e-isg:crystal_installer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.1`,
        fs:  `cpe:2.3:a:endonesia:endonesia:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.2`,
        fs:  `cpe:2.3:a:cisco:webns:8.10.6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.3`,
        fs:  `cpe:2.3:a:djogjahotel:liburan_hemat:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.4`,
        fs:  `cpe:2.3:a:samba:samba:4.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.5`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.6`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2a\)sg7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:lttng:ust:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.7`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.8`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x50:d40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:7.0.529.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.9`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2.3:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.49.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8s_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.50`,
        fs:  `cpe:2.3:h:linksys:rv082:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof-security:.50::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.44::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netscape:navigator:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.44.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:magzter:karaf_magazin:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.45::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.45.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.45.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pixologic:zbrush:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.45.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:wicket:6.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:spamassassin:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:stuart_watret:sms_adminconsole_additions:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pantech:pc_usb_modem_software:3.0.4.823:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.50.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.1\(4\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ait-pro:bulletproof_security:.51::~~~wordpress~~`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajax-random-post_project:ajax-random-post:2.00::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nginx:nginx:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajax_timeline_project:ajax_timeline:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.3.3`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.3.4`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.5\(2.10000.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.5`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.27:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.5.4`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.9:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.5.5`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.6.0`,
        fs:  `cpe:2.3:a:nice:recording_express:6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.7.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.25:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.7.2`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:2.7.3`,
        fs:  `cpe:2.3:a:jrsoftware:mousetool:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.0`,
        fs:  `cpe:2.3:a:ibm:rational_performance_tester:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.0.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.577.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.0.2`,
        fs:  `cpe:2.3:a:adobe:photoshop:18.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)jk1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.1`,
        fs:  `cpe:2.3:o:siemens:scalance_w700_series_firmware:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.1.1`,
        fs:  `cpe:2.3:a:x.org:x11:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.403:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.2.1`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r3.4_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.2.2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.2.4`,
        fs:  `cpe:2.3:a:x.org:x11:6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.2.5`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.3.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.3.3`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_.net_runtime:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.3.4`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:3.3.5`,
        fs:  `cpe:2.3:a:adobe:download_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:4.0`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:4.0.1`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:4.0.2`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:4.0.3`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:4.0.4`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:4.2.0`,
        fs:  `cpe:2.3:a:oracle:database_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:4.2.2`,
        fs:  `cpe:2.3:a:xfree86:x11perf:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:4.2.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.409.2:*:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:5.0.0`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:5.0.1`,
        fs:  `cpe:2.3:h:tp-link:tl-wrd841n_\(10.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:5.0.2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:5.0.3`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaxplorer:ajaxplorer:5.0.4`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-400_cpu_416-3_pn\/dp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.363:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:getswish:swish_payments:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:spa_301_1_line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:perl:perl:5.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x:libxcb:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:typo3:typo3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:smart-flv_plugin_project:smart-flv:-:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:guitartuna:guitar_tuner_free_-_guitartuna:2.4.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:php:php:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.6.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:cups:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)s10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wimleers:cdn:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:data_protector:7.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:vrtssfmh:3.0.357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:synology:cloud_station:2.0-2291:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:skype:skype:0.95.0.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.10.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.8.10.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kajona:kajona:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.9.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:42.0.2311.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajaydsouza:contextual_related_posts:1.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openx:openx:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.0`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.2`,
        fs:  `cpe:2.3:a:usebb:usebb:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.3`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.5`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.6`,
        fs:  `cpe:2.3:a:google:chrome:16.0.897.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.7`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.8`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.9`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.10`,
        fs:  `cpe:2.3:a:google:chrome:12.0.719.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.11.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.12`,
        fs:  `cpe:2.3:a:red-gate:sql_data_generator:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.13`,
        fs:  `cpe:2.3:a:zooeffect:zooeffect:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.14`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.15`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.16`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.17`,
        fs:  `cpe:2.3:a:mbtcreations:100_beauty_tips:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.18`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.19.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.19`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.20`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.05c-2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.21`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.14:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ajenti:ajenti:1.2.21.7`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajsquare:aj_auction_pro-oopd:2.0`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajsquare:aj_auction_pro-oopd:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ajsquare:aj_auction_pro-oopd:3.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p36:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:akamai:kona_site_defender_service:-`,
        fs:  `cpe:2.3:a:apple:safari:4.0.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:akamai:netsession:1.9.3.1`,
        fs:  `cpe:2.3:a:cisco:finesse:9.0\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aker:secure_mail_gateway:2.5.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:akiva:webboard:2.90:beta`,
        fs:  `cpe:2.3:a:emc:avamar_plugin:5.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:akiva:webboard:8.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:akiva:webboard:8.0:sr1`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:akiva:webboard:9.0`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:akronchildrens:care4kids:1.03::~~~android~~`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:aktiv:phantom:2.5.1`,
        fs:  `cpe:2.3:a:ibotta:ibotta_-_better_than_coupons.:2.5.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:akunamachata:paypal_express_module:-`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:al-ahsa_news_project:al-ahsa_news:2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:al_3azmi:ce4arab_market:0.12.13093.40460::~~~android~~`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:al_jazeera_project:al_jazeera:6.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(9a\)bc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alaaliwat:www.alaaliwat.com:4.9::~~~android~~`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aladdin:ghostview:2.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aladdin:hasp_srm_run-time:3.10.1.6921`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alan_kennington:mod_bwshare:0.1.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.338:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alan_kennington:mod_bwshare:0.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alawar:motor_town%3a_machine_soul_free:1.1::~~~android~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:albasit_artes_y_danza_project:albasit_artes_y_danza:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.0.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alberto_pittoni:alguest:1.0`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.23-72.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alberto_pittoni:alguest:1.1:c-patched`,
        fs:  `cpe:2.3:o:sun:solaris:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alberto_trujillo_gonzalez:protest:6.x-1.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alberto_trujillo_gonzalez:protest:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alberto_trujillo_gonzalez:protest:7.x-1.0`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alberto_trujillo_gonzalez:protest:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:adsl_modem_1000:-`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.9:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alcatel:aos:-`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alcatel:aos:5.1.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alcatel:aos:5.1.6.463`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alcatel:aos:5.4.1.429`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alcatel:aos:6.1.3.965`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alcatel:aos:6.3.1.966`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:omnistack:-`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.0.471780:*:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:omniswitch:-`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:omniswitch_7800:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:speed_touch_adsl_modem:-`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:speed_touch_home:-`,
        fs:  `cpe:2.3:a:qemu:qemu:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:speed_touch_home:khdsaa.108`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:speed_touch_home:khdsaa.132`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:speed_touch_home:khdsaa.133`,
        fs:  `cpe:2.3:a:schneider-electric:unity_pro:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:speed_touch_home:khdsaa.134`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:speedtouch_7g_router:-`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel:switched_firewall:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alcatel-lucent:omniaccess_wireless:-`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnipcx:-`,
        fs:  `cpe:2.3:a:sybase:sql_anywhere_studio:9.0.2.3702:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnipcx:7.1`,
        fs:  `cpe:2.3:a:activestate:activepython:2.6.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnitouch_8400_instant_communications_suite:6.7.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_idm_launcher:1.5.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnitouch_8400_instant_communications_suite:6.7.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnitouch_8460_advanced_communication_server:9.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnitouch_8460_advanced_communication_server:9.1`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnitouch_8660_my_teamwork:6.6`,
        fs:  `cpe:2.3:h:apple:iphone:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnitouch_8660_my_teamwork:6.7`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnitouch_8670_automated_delivery_message_delivery_system:6.6`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnitouch_8670_automated_delivery_message_delivery_system:6.7`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1055:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:omnivista:-`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:12.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alcatel-lucent:voice_mail_system:-`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:6.x-1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:6.x-1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:6.x-1.2`,
        fs:  `cpe:2.3:a:kde:kde_sc:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:6.x-1.3`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:6.x-1.x-dev`,
        fs:  `cpe:2.3:a:google:chrome:17.0.954.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:7.x-1.0`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:7.x-1.1`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:7.x-1.2`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.012:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:alejandro_garza:apachesolr_autocomplete:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alentum:weblog_expert:6.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alephsystem:cms_ariadna:1.1`,
        fs:  `cpe:2.3:h:3com:switch_4005:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha10`,
        fs:  `cpe:2.3:a:apache:batik:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha11`,
        fs:  `cpe:2.3:h:cisco:nexus_7000_9-slot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha12`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120709:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha13`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha14`,
        fs:  `cpe:2.3:a:fogproject:fog:0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:gnu:glibc:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha4`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha5`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server_client:9.150.39151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha6`,
        fs:  `cpe:2.3:a:opnet:sp_guru_network_planner:16.0.0.10106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha7`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:2.8:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha8`,
        fs:  `cpe:2.3:a:keil-software:photokorn_gallery:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.0:alpha9`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_barth:data:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:typo3:flow:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_feinman:iso_recorder:3.1.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.3`,
        fs:  `cpe:2.3:o:iodata:hdl-a_firmware:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.4`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.5`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.6`,
        fs:  `cpe:2.3:h:cisco:sf300-08:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.7`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.2.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.8:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.9`,
        fs:  `cpe:2.3:a:sun:openoffice.org:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.10`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.34.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.11`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.0.12`,
        fs:  `cpe:2.3:a:acquia:mollom:6.x-2.14:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.0`,
        fs:  `cpe:2.3:a:php-fusion:team_impact_ti_blog_system_module:_nil_:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.1`,
        fs:  `cpe:2.3:a:cisco:videoscape_delivery_system_for_internet_streamer:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.3`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0090:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.4`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.6`,
        fs:  `cpe:2.3:a:oracle:database_server:7.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.7`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.8`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.1.10`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.03.019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.2.0`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:6.0.302.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.2.1`,
        fs:  `cpe:2.3:o:suse:suse_linux:6.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.2.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.2.3`,
        fs:  `cpe:2.3:h:moxa:iologic_e2240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.2.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.1`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.2`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.3`,
        fs:  `cpe:2.3:o:ibm:aix:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.4`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1678.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.5`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.6`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.7`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.7.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.8`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.9`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.414:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.11`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.12`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.11.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.13`,
        fs:  `cpe:2.3:a:magzter:bespoke:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.14`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.62:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.15`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.4:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.3.16`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.1`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.2`,
        fs:  `cpe:2.3:o:cisco:web_security_appliance:8.5.0-497:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.3`,
        fs:  `cpe:2.3:a:websense:websense_content_content_gateway:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.4`,
        fs:  `cpe:2.3:h:iodata:hdl-ah:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.5`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.0.2.542:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.6`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.8`,
        fs:  `cpe:2.3:a:ibm:security_appscan:7.9:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.9`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.10`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.11`,
        fs:  `cpe:2.3:a:globalscape:eft_server:6.2.31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.12`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.0.155.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.13`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.14`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.15`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.15.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.16`,
        fs:  `cpe:2.3:a:augeas:augeas:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.17`,
        fs:  `cpe:2.3:o:sierrawireless:raven_x_ev-do_firmware:4228_4.0.11.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.4.18`,
        fs:  `cpe:2.3:h:lexmark:e260:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.5.0`,
        fs:  `cpe:2.3:a:webmin:usermin:1.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.5.1`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.5.3`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_kellner:powermail:1.6.4`,
        fs:  `cpe:2.3:a:icinga:icinga:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alex_launi:tangerine:0.3.2.2`,
        fs:  `cpe:2.3:a:alkacon:opencms:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alexis_wilke:protected_node:6.x-1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p294:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alexis_wilke:protected_node:6.x-1.2`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alexis_wilke:protected_node:6.x-1.3`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-2.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alexis_wilke:protected_node:6.x-1.4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alexis_wilke:protected_node:6.x-1.5`,
        fs:  `cpe:2.3:a:gnu:gnash:0.8.9:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alexis_wilke:protected_node:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:samba:samba:4.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alfabank:alfa-bank:5.5.1.1::~~~android~~`,
        fs:  `cpe:2.3:a:splunk:splunk:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alfresco:alfresco:4.1.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sliksvn:slik_subversion:1.6.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alfresco:alfresco:4.1.6.13::~~enterprise~~~`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.78.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alfresco:alfresco:4.2.f::~~community~~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alfresco:alfresco:5.0.a::~~community~~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alfresco:alfresco:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:altiris:pxe_server:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.0`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.1`,
        fs:  `cpe:2.3:o:harman:amx_firmware:1.2.322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.2`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.95:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.3`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.4`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:16.30.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.5`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.4:mr4_build_1000:corporate_edition:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.5.b`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.5.c`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.6`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.6.b`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.6.c`,
        fs:  `cpe:2.3:a:david_king:vino:2.11.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.7`,
        fs:  `cpe:2.3:a:nishishi:fumy_teachers_schedule_board:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.8`,
        fs:  `cpe:2.3:a:connectiva:linux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.9`,
        fs:  `cpe:2.3:o:trustix:secure_linux:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.10`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.10.b`,
        fs:  `cpe:2.3:a:softwebsnepal:ananda_real_estate:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.11`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.12`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.13`,
        fs:  `cpe:2.3:a:apple:xcode:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.19`,
        fs:  `cpe:2.3:a:microsoft:project:2000:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algisinfo:aicontactsafe:2.0.21`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algosec:fireflow:6.3:b230`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:algosec:firewall_analyzer:6.1`,
        fs:  `cpe:2.3:a:iss:blackice:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algosec:firewall_analyzer:6.1:b86`,
        fs:  `cpe:2.3:h:cisco:ip_phone_7905:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:algosec:firewall_analyzer:6.4`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alhazai:leadership_newspapers:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ali_visual_project:ali_visual:1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aliakay:aptallik_testi:4::~~~android~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alibaba:alibaba:4.1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:1.0.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.010.20060:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:1.0.6`,
        fs:  `cpe:2.3:a:hp:psprinters08:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:2.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:2.1.2`,
        fs:  `cpe:2.3:a:perl:perl:5.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:2.1.5`,
        fs:  `cpe:2.3:a:debian:axiom:20100701-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:2.1.5-1`,
        fs:  `cpe:2.3:a:apache:jakarta_isapi_redirector:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:2.1.5-2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:2.1.5-3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:-:-:*:*:*:z\/os:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)sl4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:3.1.9`,
        fs:  `cpe:2.3:a:autonomy:sharepoint_connector_cfs:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:3.1.10`,
        fs:  `cpe:2.3:a:microsoft:system.net.security:4.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:3.1.12`,
        fs:  `cpe:2.3:a:apple:safari:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.0.3`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.1.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p124:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.1.3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.2`,
        fs:  `cpe:2.3:h:ibm:s18:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.2.2`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.2.3`,
        fs:  `cpe:2.3:a:microsoft:visio:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.3`,
        fs:  `cpe:2.3:a:nasa_universe_wallpapers_xeus_project:nasa_universe_wallpapers_xeus:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.3.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.1.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.3.2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.3.3`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.5`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2010:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.6`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_300_color_mfp_printer_m375:ce903a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.6.1`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.7.0`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.3.118.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:open_source_security_information_management:4.8.0`,
        fs:  `cpe:2.3:a:vips:vips:7.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienvault:unified_security_management:4.14`,
        fs:  `cpe:2.3:a:cisco:meraki_mr_firmware:2014-09-24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienwp:hatch:7.x-1.0`,
        fs:  `cpe:2.3:a:tincan:phplist:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienwp:hatch:7.x-1.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienwp:hatch:7.x-1.2`,
        fs:  `cpe:2.3:a:citrix:receiver_usb:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienwp:hatch:7.x-1.3`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienwp:hatch:7.x-1.4`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alienwp:hatch:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:435:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alionscience:standard_frequency_action_format_conversion_tool:1.00.0000`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l30er:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alipay_project:alipay:3.6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110716:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:6.0.0`,
        fs:  `cpe:2.3:a:apple:itunes:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:6.0.2`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:6.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.6\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:6.0.4`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:6.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:6.2.1`,
        fs:  `cpe:2.3:a:simple_email_form_project:simple_email_form:1.8.5:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:6.2.2`,
        fs:  `cpe:2.3:a:webmin:usermin:1.280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:6.2.3`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:7.0.3`,
        fs:  `cpe:2.3:a:onesolutionapps:aloha_bail_bonds:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:7.0.4`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:8.5`,
        fs:  `cpe:2.3:a:ibm:sametime:8.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:8.5.1`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:8.5.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alkacon:opencms:9.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:all_around_cyprus_project:all_around_cyprus:2.11::~~~android~~`,
        fs:  `cpe:2.3:a:nih:libzip:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:all_navalny_project:all_navalny:1.1::~~~android~~`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:all_video_gallery_plugin_project:all-video-gallery:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sendmail:sendmail\&#43;pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:all_video_gallery_plugin_project:all_video_gallery_plugin:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.7:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:all_video_gallery_plugin_project:all_video_gallery_plugin:1.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.460:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:all_video_gallery_plugin_project:all_video_gallery_plugin:1.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allaire:homesite:1.0`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allaire:homesite:2.0`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.2:-:core:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allaire:homesite:3.0`,
        fs:  `cpe:2.3:a:asp-dev:xm_forums:-:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allaire:homesite:4.0`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allaire:homesite:4.5`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allamericansportsware:common_controls_pack:1.01.0002`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:2.5.2.c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allegrosoft:rompager:4.07`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allegrosoft:rompager:4.34`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allegrosoft:rompager:4.51`,
        fs:  `cpe:2.3:a:libpng:libpng:0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesis:at-rg634a:-`,
        fs:  `cpe:2.3:a:germanwings:germanwings:2.1.13:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:alliedtelesis:at-rg634a_firmware:3.3%2b`,
        fs:  `cpe:2.3:a:location_module_project:location:6.x-3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesis:img616lh:-`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp1:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alliedtelesis:img616lh_firmware:%2b2.4`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesis:img624a:-`,
        fs:  `cpe:2.3:h:hp:h3c_router:sr8808:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alliedtelesis:img624a_firmware:3.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesis:img646bd:-`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:alliedtelesis:img646bd_firmware:3.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-8024:-`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-8024:1.3.1`,
        fs:  `cpe:2.3:a:google:chrome:47.0.2526.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-9000_24_ethernetswitch:-`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-9724ts:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.0_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-s24:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-s24:2.4.4`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-s30:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-s39:-`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-s39:3.1.1.1`,
        fs:  `cpe:2.3:a:esri:arcsde:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-s39:3.2.0`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:at-s39:3.3.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alliedtelesyn:at-tftp:-`,
        fs:  `cpe:2.3:h:huawei:s9306:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alliedtelesyn:at-tftp:1.9`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.6.0.1355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alliedtelesyn:cable_dsl_router_at-ar220e:-`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allnurses:allnurses:3.4.10::~~~android~~`,
        fs:  `cpe:2.3:a:novell:netmail:3.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allplayer:allplayer:5.6.2`,
        fs:  `cpe:2.3:a:orangelampsoftware:killprocess:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allplayer:allplayer:5.7.0`,
        fs:  `cpe:2.3:a:oracle:universal_work_queue:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allplayer:allplayer:5.8.1`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allqoranvideos:koran_-_alqoranvideos:1::~~~android~~`,
        fs:  `cpe:2.3:h:d-link:dap-2310:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allroundautomation:pl%2fsql_developer:9.0.2.1621`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allroundautomations:pl%2fsql_developer:11.0`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allroundautomations:pl%2fsql_developer:11.0.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allroundautomations:pl%2fsql_developer:11.0.2`,
        fs:  `cpe:2.3:a:location_module_project:location:7.x-5.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allroundautomations:pl%2fsql_developer:11.0.3`,
        fs:  `cpe:2.3:a:hp:san\/iq:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allroundautomations:pl%2fsql_developer:11.0.4`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:allroundautomations:pl%2fsql_developer:11.0.5`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:almanah_project:almanah:0.9.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:almanah_project:almanah:0.10.0`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.0:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:almas:compiere:j253b_a02`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:almas:compiere:j300_a01`,
        fs:  `cpe:2.3:a:citrix:secure_gateway:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:almas:compiere:j300_a02`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:almasiapps:healing_bookstore:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aloaha:aloaha_pdf_suite_free:-`,
        fs:  `cpe:2.3:a:apache:opentaps:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aloaha:aloahapdfviewer:5.0.0.7`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alphabetic_sitemap_project:alphabetic_sitemap:0.0.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alphabetic_sitemap_project:alphabetic_sitemap:0.0.2::~~~typo3~~`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alphabetic_sitemap_project:alphabetic_sitemap:0.0.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alphanetworks:vdsl_asl-55052:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.3\(2.32\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:alphanetworks:vdsl_asl-56552:-`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alphazip:alphazip:1.3.0`,
        fs:  `cpe:2.3:a:umn:mapserver:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:5.4.102.8`,
        fs:  `cpe:2.3:a:ippusbxd_project:ippusbxd:1.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:5.4.104.4`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:5.5.1302.12`,
        fs:  `cpe:2.3:o:aterm:wf800hp_firmware:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:6.0.302.3`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:6.0.302.7`,
        fs:  `cpe:2.3:o:scientificlinux:scientificlinux:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:6.0.303.4`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:6.0.303.5`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.6.2:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:6.0.304.5`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:6.0.304.6`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:6.0.305.5`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:6.0.305.6`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:7.1.102.7`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1047:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:7.2.101.219`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:7.4.102.102`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp1:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:7.102.101.223`,
        fs:  `cpe:2.3:o:juniper:junos:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:7.102.101.228`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alps:touch_pad_driver:7.102.302.203`,
        fs:  `cpe:2.3:a:ibm:security_privileged_identity_manager:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alquimia:managesite:6.x-1.0`,
        fs:  `cpe:2.3:a:asial:monaca_debugger:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alquimia:managesite:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:citrix:receiver_inside:3.0.0.56418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alrazylabs:lostword:5.9::~~~android~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.392:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alstom:e-terracontrol:3.5`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alstom:e-terracontrol:3.6`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alstom:e-terracontrol:3.7`,
        fs:  `cpe:2.3:a:microsoft:office:2003:*:*:*:student_and_teacher:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alstom:micom_s1_agile:1.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alstom:micom_s1_agile:1.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tt4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alstom:micom_s1_studio:-`,
        fs:  `cpe:2.3:h:avocent:dsr1020:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alsunna_project:alsunna:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.142.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:3.1.9`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:3.1.10`,
        fs:  `cpe:2.3:a:indigorose:setup_factory:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:3.1.11`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:3.1.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2010.302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc100a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.2`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.4`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.5`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.01:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.6`,
        fs:  `cpe:2.3:a:yokogawa:fast\/tools:r9.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.7`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.96:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.0.8`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.0`,
        fs:  `cpe:2.3:a:icinga:icinga:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.1`,
        fs:  `cpe:2.3:h:lexmark:cs820dte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.2`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:6:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.21:pre7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.4`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.5`,
        fs:  `cpe:2.3:a:php:php:5.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.6`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.8`,
        fs:  `cpe:2.3:a:openstack:swift:1.13.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.8-h3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.751.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.9`,
        fs:  `cpe:2.3:h:linksys:wet11:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.10`,
        fs:  `cpe:2.3:a:digium:asterisk:14.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.11`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.12`,
        fs:  `cpe:2.3:a:vips:vips:7.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:4.1.13`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:5.0.0`,
        fs:  `cpe:2.3:a:umn:mapserver:5.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:5.0.0-h1`,
        fs:  `cpe:2.3:a:smartsound:quicktracks_plugin:3.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:5.0.1-h1`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:5.0.2`,
        fs:  `cpe:2.3:a:debian:reprepro:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:5.0.3`,
        fs:  `cpe:2.3:a:apple:cups:1.1.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:5.0.4`,
        fs:  `cpe:2.3:a:apple:itunes:4.8.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:altaware:palo_alto_networks_panos:5.0.5`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alternative_connection_project:alternative_connection:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.8:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alterpoint:logwatch:1.0.0.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p247_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alterpoint:networkauthority:6.0.0.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alterpoint:networkauthority_engineering_environment:6.0.1.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(5h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altimatech:netzoom:6.2.2`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:agent_for_mac:6.2.1302`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:agent_for_mac_documentation:6.2.1124`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:agent_for_pocket_pc:6.1.1141`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:agent_for_unix_and_linux:6.2.1378`,
        fs:  `cpe:2.3:a:webmin:webmin:1.670:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:agent_for_unix_and_linux_documentation:6.2.1048`,
        fs:  `cpe:2.3:a:microsoft:office:2010:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:alert_manager:6.0.308`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:application_control_solution_documentation:6.1.1015`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:application_management_language_pack:6.1.4082`,
        fs:  `cpe:2.3:a:searchblox:searchblox:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:application_management_solution:6.1.4088`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:application_management_solution_documentation:6.1.4085`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:application_metering:6.1.55`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)t7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:application_metering_agent:6.1.31`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:application_metering_documentation:6.1.32`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.559:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:application_metering_language_pack:6.1.32`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:appweaver:6.0.308`,
        fs:  `cpe:2.3:a:zope:zope:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:asset_management_report_pack:6.5.1049`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:asset_management_solution:6.5.1126`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:asset_management_solution_documentation:6.5.1049`,
        fs:  `cpe:2.3:a:postfix:postfix:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:audit_integration_component:6.2.124`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:audit_integration_component_documentation:6.2.1016`,
        fs:  `cpe:2.3:a:dish:dish_anywhere:3.5.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:auditexpress_setup_solution:6.2.124`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:barcode_solution:6.7.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.1:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:altiris:barcode_solution_documentation:6.6.1031`,
        fs:  `cpe:2.3:a:vmware:vcenter_operations:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:carbon_copy:-`,
        fs:  `cpe:2.3:a:kiwix:kiwix:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:carbon_copy:5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:carbon_copy:6.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr1604hf-l-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:carbon_copy_solution:6.2.1144`,
        fs:  `cpe:2.3:a:osticket:osticket:1.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:carbon_copy_solution_agent:6.2.1144`,
        fs:  `cpe:2.3:a:microsoft:works_6-9_file_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:carbon_copy_solution_documentation:6.2.1121`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:client_management_suite_quick_start:6.0.1274`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:client_service:-`,
        fs:  `cpe:2.3:h:hp:color_laserjet_4600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:client_service:5.6.181`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:client_service:6.0.88`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:client_task_agent:6.0.1524`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:client_task_management:6.0.1524`,
        fs:  `cpe:2.3:a:apache:httpclient:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:client_task_server:6.0.1524`,
        fs:  `cpe:2.3:a:clamav:clamav:0.60p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:cmdb:6.5.1126`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:cmdb_and_asset_management_language_pack:6.5.1021`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.571:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:cmdb_and_asset_management_report_language_pack:6.5.1021`,
        fs:  `cpe:2.3:a:apache:traffic_server:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:cmdb_report_pack:6.5.1049`,
        fs:  `cpe:2.3:a:iconics:bizviz:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:cmdb_solution_documentation:6.5.1016`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:component_for_active_directory_documentation:6.1.1019`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:computer_management:6.2.3529`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:computer_management_language_pack:6.2.3533`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p385:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:connector_for_veritas_configuration_manager:6.0.1039`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:connector_for_wise:6.1.138`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:connector_solution_data_integration_component:6.5.1149`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.10.474:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:connector_solution_data_integration_component_extensions:6.0.1318`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:connector_solution_documentation:6.5.1026`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1104.958.17837:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:connector_solution_event_integration_component:6.0.1823`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.1.4:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:connector_solution_quick_start:6.0.1102`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:console:6.5.1144`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf800a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:console_data:6.5.31.0:update_kb34732`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:console_data:6.5.1156`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:console_data_language_pack:6.5.1146`,
        fs:  `cpe:2.3:o:d-link:dap-2330_firmware:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:console_documentation:6.5.1024`,
        fs:  `cpe:2.3:a:citadel:hercules_remediation_client_for_windows:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:console_language_pack:6.5.1144`,
        fs:  `cpe:2.3:a:podsfoundation:pods:2.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:context_factory:6.0.1127`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.7:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:dell_client_configuration_utility:3.0.1210.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:dell_client_configuration_utility:3.0.1213.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:dell_client_configuration_utility:3.1.1230.0`,
        fs:  `cpe:2.3:a:perl:perl:5.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:dell_client_manager_documentation:2.2.1017`,
        fs:  `cpe:2.3:a:lxml:lxml:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:dell_client_manager_language_pack:2.2.1010`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0037:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:dell_client_manager_solution:2.2.1019`,
        fs:  `cpe:2.3:a:djangoproject:django:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_agent:1.0.0`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_server_extension_for_ibm_director:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)seb2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_server_extension_for_ibm_director:5.0.1`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.0:*:*:*:*:aix:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_server_extension_for_ibm_director:5.5`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_6900_series_firmware:9.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_server_extension_for_ibm_director:6.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.b01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_server_extension_for_ibm_director:6.1`,
        fs:  `cpe:2.3:o:arubanetworks:instant_access_point_firmware:4.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:-`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.6.0.569:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:5.6`,
        fs:  `cpe:2.3:o:cisco:catos:5.4\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:5.6:sp1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd327a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:5.6.181`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:6.0`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:6.8`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:6.8:sp1`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:6.8:sp2`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:6.9.174`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.08d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution:6.9.355`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution_for_network_devices:6.0.1046`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_solution_for_network_devices_documentation:6.0.1013`,
        fs:  `cpe:2.3:a:blackberry:blackberry_link:1.0.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_web_console:6.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:deployment_web_console:6.9`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.1.7.l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:diagnostics:6.1.7325.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:diagnostics:6.1.7631.0`,
        fs:  `cpe:2.3:h:cisco:telepresence_video_communication_server:-:*:starter_pack_express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:discovery_for_rim:6.1.1091`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:3.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:endpoint_security_solution:6.0.479`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_lights_out_2:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:endpoint_security_solution_documentation:6.0.1007`,
        fs:  `cpe:2.3:a:jease:jease:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:energy_saver_toolkit:6.0.1214`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:energy_saver_toolkit_documentation:6.0.1006`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.15.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:express_deployment_console:6.8`,
        fs:  `cpe:2.3:a:tryton:trytond:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:express_deployment_console:6.9`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.2.1:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:express_deployment_datastore:6.8`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:express_deployment_datastore:6.9`,
        fs:  `cpe:2.3:a:spip:spip:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:express_deployment_server:6.8`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:express_deployment_server:6.9`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.7.15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:helpdesk_proxy:6.0.308`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:helpdesk_solution:6.0.308`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:helpdesk_solution_documentation:6.0.1044`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_design_premium:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:integrated_component_for_microsoft_active_directory:6.1.842.0`,
        fs:  `cpe:2.3:o:advantech:eki-1321_series_firmware:1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_merge_module_msi:6.1.1075.0`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_pack_for_servers:6.1.1058.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_pack_for_servers_documentation:6.1.1019`,
        fs:  `cpe:2.3:a:microfocus:rumba:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_rule_management:6.2.3593`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_rule_management_language_pack:6.2.3595`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:10.0\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_documentation:6.1.1059`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_mac:6.2.1054`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_mac_documentation:6.2.1036`,
        fs:  `cpe:2.3:h:apple:imac:mb953xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_network_devices_documentation:6.0.1015`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_pocket_pc:6.1.1141`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_pocket_pc_documentation:6.1.1007`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_rim:6.1.1091`,
        fs:  `cpe:2.3:a:altiris:patch_management_agent:6.1.1422:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_rim_documentation:6.1.1010`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_unix_and_linux:6.2.1034`,
        fs:  `cpe:2.3:a:samba:samba:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_unix_and_linux_documentation:6.2.1032`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.5:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:inventory_solution_for_windows:6.1.2004.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:it_analytics:6.1.1050`,
        fs:  `cpe:2.3:a:devsaran:professional_theme:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:it_analytics_asset_management_pack:6.1.1085`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:it_analytics_client_management_pack:6.1.1085`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:it_analytics_service_management_pack:6.1.1085`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:it_analytics_solution_documentation:6.1.1010`,
        fs:  `cpe:2.3:a:drupal:drupal:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:it_analytics_symantec_endpoint_protection_pack:6.1.1048`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:knowledge_base_proxy:6.0.308`,
        fs:  `cpe:2.3:a:debian:apt:0.7.17:exp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:language_pack_for_patch_management_core_linux:6.2.1022`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:language_pack_for_patch_management_dell_for_linux:6.2.1015`,
        fs:  `cpe:2.3:h:cisco:web_security_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:linux_pack_for_patch_management_solution_for_dell_servers:6.2.1128`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:migration_portal:1.0.4.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_agent_for_unix_and_linux:6.0.3143`,
        fs:  `cpe:2.3:a:hp:instant_share_devices_mfc:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_agent_for_windows:6.0.1317`,
        fs:  `cpe:2.3:a:busybox:busybox:1.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_agent_for_windows:6.0.1341`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_for_notification_server_metric:6.0.1057`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_pack_for_altiris_infrastructure:6.0.1057`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_packs_for_servers:6.0.2066`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_solution:6.0.1337`,
        fs:  `cpe:2.3:o:siemens:ccmw3025_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_solution:6.0.1341`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_solution_documentation:6.0.1074`,
        fs:  `cpe:2.3:o:tp-link:tl-wrd841n_\(10.0\)_firmware:150104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_solution_for_dell_servers:6.1.2046`,
        fs:  `cpe:2.3:a:tincan:phplist:1.1.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:monitor_solution_for_dell_servers_documentation:6.1.1016`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:network_discovery:6.0.2120`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:network_discovery_documentation:6.0.1025`,
        fs:  `cpe:2.3:o:tp-link:tl-wr841nd_\(9.0\)_firmware:150104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:network_discovery_language_pack:6.0.4`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:network_inventory:6.0.1198`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2_ms1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:notification_server:6.0.6074`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:notification_server_configurator:6.0.5010`,
        fs:  `cpe:2.3:a:expressjs:express:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:notification_server_configurator:6.1.7325.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:notification_server_configurator:6.1.7631.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.704:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:notification_server_documentation:6.0.1056`,
        fs:  `cpe:2.3:a:php:php:5.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:notification_server_email_event_receiver:6.1.1091`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:out_of_band_management_language_pack:6.2.1016`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.97:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:out_of_band_management_solution:6.2.1035`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.22:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:out_of_band_management_solution_documentation:6.2.1012`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:out_of_band_setup_and_configuration_language_pack:6.2.1012`,
        fs:  `cpe:2.3:a:pgp:certificate_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:out_of_band_setup_and_configuration_solution:6.2.1040`,
        fs:  `cpe:2.3:a:openstack:keystone:juno-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:package_rule_management:6.1.4085`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.04.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:package_rule_management_language_pack:6.1.4085`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:package_server_wmi_provider:6.0.1057`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1077.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management:6.2.3643`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100804:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_agent:6.1.1422`,
        fs:  `cpe:2.3:a:uangel:realtalk:a.0.9.250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_agent:6.2.2514`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_core_solution_for_linux:6.2.1161`,
        fs:  `cpe:2.3:a:tm_software:tempo6.3.2:jira42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_dell_agent:6.2.2623`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120605:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_for_windows:6.2.3644`,
        fs:  `cpe:2.3:a:google:v8:3.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_for_windows_dell_servers:6.2.3647`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_for_windows_dell_servers_language_pack:6.2.3647`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_for_windows_language_pack:6.2.3644`,
        fs:  `cpe:2.3:a:mcafee:virusscan:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_language_pack:6.2.3643`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd1.m0xx0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_solution_documentation:6.2.1060`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:patch_management_solution_for_dell_servers_documentation:6.2.2002`,
        fs:  `cpe:2.3:h:dell:latitude_z600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:power_control_task:6.0.1524`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:power_management_agent:6.0.1524`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.5.1:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:power_scheme_task:6.0.1015`,
        fs:  `cpe:2.3:a:web2py:web2py:1.78.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:power_scheme_task_language_pack:6.0.1002`,
        fs:  `cpe:2.3:a:springsource:spring_framework:4.0.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:pxe_manager:6.8`,
        fs:  `cpe:2.3:a:accadvocacy:acc_advocacy_action:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:pxe_manager:6.9`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_for_plsql:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:pxe_server:6.9`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:real-time_console_infrastructure_language_pack:6.3.1022`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:8.5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:real-time_system_manager_language_pack:6.3.1016`,
        fs:  `cpe:2.3:a:mcafee:virusscan:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:realtime_console_infrastructure:6.3.1066`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:realtime_console_infrastructure_documentation:6.3.1006`,
        fs:  `cpe:2.3:a:google:chrome:11.0.663.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:realtime_system_manager:6.3.1066`,
        fs:  `cpe:2.3:a:drei:3kundenzone:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:realtime_system_manager_solution_documentation:6.3.1009`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)t9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:recovery_solution:-`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_application_metering:6.1.1080`,
        fs:  `cpe:2.3:a:saflink:argus:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_audit_integration_component:6.2.1004`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_carbon_copy_solution:6.2.1024`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_dell_client_manager:2.1.1004`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_helpdesk_solution:6.0.1043`,
        fs:  `cpe:2.3:a:lxml:lxml:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_inventory_pack_for_servers:6.1.1039`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_inventory_solution_for_mac:6.2.1007`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_inventory_solution_for_unix_and_linux:6.2.1004`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_inventory_solution_for_windows:6.2.1047`,
        fs:  `cpe:2.3:a:codiad:codiad:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_monitor_solution:6.0.1064`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.04:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_monitor_solution_for_dell_servers:6.1.1063`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_monitor_solution_for_servers:6.0.1112`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_unified_software:1.3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_network_discovery_solution:6.0.1026`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_out_of_band_management_solution:6.2.1004`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_patch_management_solution:6.2.3647`,
        fs:  `cpe:2.3:h:nvidia:geforce_gt_730:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_patch_management_solution_for_windows:6.2.3644`,
        fs:  `cpe:2.3:h:hp:laserjet_4050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_patch_management_solutions_for_dell_servers:6.2.3665`,
        fs:  `cpe:2.3:a:vmware:player:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_real_time_console_infrastructure:6.3.1004`,
        fs:  `cpe:2.3:a:aptana:aflax:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_real_time_system_manager:6.3.1006`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.1.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_software_delivery_solution:6.1.1101`,
        fs:  `cpe:2.3:a:ibm:soliddb:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_software_delivery_solution_for_windows:6.1.1080`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_software_virtualization_solution_for_windows:2.1.1026`,
        fs:  `cpe:2.3:a:sap:3d_visual_enterprise_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_symantec_ep_integration_component:6.0.1237`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:report_pack_for_task_server:6.0.1007`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_358_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:resource_management:6.0.2927`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:script_task:6.0.1524`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:script_task_agent:6.0.1524`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.11:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:security_audit_agent_solution:6.2.124`,
        fs:  `cpe:2.3:a:oracle:traffic_director:11.1.1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:securityexpressions:3.4.0`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:server_management_suite:-`,
        fs:  `cpe:2.3:a:checkpoint:web_intelligence:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:service_control_task:6.0.1524`,
        fs:  `cpe:2.3:a:inria:ocaml:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:service_control_task_agent:6.0.1524`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_for_mac_documentation:6.1.1020`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)bc3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_solution:6.1.1058.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_solution_agent:6.1.1016.0`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_solution_documentation:6.1.1041`,
        fs:  `cpe:2.3:a:apple:quicktime:7.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_solution_for_mac:6.1.2032`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_solution_for_unix_and_linux:6.1.3006`,
        fs:  `cpe:2.3:h:hp:3com_switch:ss4_5500-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_solution_for_unix_and_linux_documentation:6.1.1028`,
        fs:  `cpe:2.3:a:watch4net:apg:4.3u3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_task_server_plug-in:6.1.1030`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_delivery_task_server_plug-in_language_pack:6.1.1030`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_management:6.2.4270`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_management_language_pack:6.2.4274`,
        fs:  `cpe:2.3:a:google:chrome:7.0.530.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_virtualization_agent:2.1.2095`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_virtualization_solution:2.1.2095`,
        fs:  `cpe:2.3:a:autodesk:revit_structure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_virtualization_solution:2.1.3062`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:software_virtualization_solution_documentation:2.1.1009`,
        fs:  `cpe:2.3:o:juniper:junos:11.4r13:s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:svs_task:6.3.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_sametime:7.5.70413:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:svs_task:6.4.0`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:svs_task_server_plugin_language_pack:6.3.0`,
        fs:  `cpe:2.3:a:netiq:appmanager_console:7.0.10160.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:svs_task_server_plugin_language_pack:6.4.0`,
        fs:  `cpe:2.3:a:oracle:database_server:7.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:symantec_endpoint_protection_integration_component:6.0.1171`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:symantec_endpoint_protection_integration_component_documentation:6.0.1008`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_management:6.0.1524`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_management_pack:6.0.1504`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.10.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_management_pack_language_pack:6.0.1033`,
        fs:  `cpe:2.3:a:siteminder_agent_for_sharepoint:2010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_management_pack_language_pack:6.0.1504`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_server_documentation:6.0.1013`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_server_language_pack:6.0.1404`,
        fs:  `cpe:2.3:a:ruby-i18n:i18n:0.6.8:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_server_language_pack:6.0.1509`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_synchronization_agent:6.1.1030.0`,
        fs:  `cpe:2.3:a:autodesk:survey:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:task_synchronization_agent:6.1.1034.0`,
        fs:  `cpe:2.3:a:apache:struts:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:topology_viewer:6.0.1.0`,
        fs:  `cpe:2.3:a:wp_plugin_manager_project:wp_plugin_manager:1.6.4.b:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:veritas_configuration_manager_integration_component:6.0.1005`,
        fs:  `cpe:2.3:o:cisco:ios:12.4sw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altiris:wise_toolkit:6.1.3`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altitude:altitude_unified_customer_interaction:7.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altn:mdaemon:9.6.4`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_universal_restore:10.0.13545:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altn:mdaemon:9.6.5`,
        fs:  `cpe:2.3:a:qnap:qsync:4.2.2.0724:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:altn:mdaemon:12.5.4:-:free`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altnet:altnet_download_manager:4.0.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc4:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:altnet:altnet_download_manager:4.0.0.4`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altnet:altnet_download_manager:4.0.0.6`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:altova_installer_for_apache_fop_for_jdk_1.4:0.93`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:databasespy_2008:2.1`,
        fs:  `cpe:2.3:a:citrix:xendesktop:5.6:fp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:databasespy_2011:2.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:databasespy_2011:2.1::~~professional~~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:databasespy_2011:3.0::~~professional~~~`,
        fs:  `cpe:2.3:a:kaseya:virtual_system_administrator:8.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:databasespy_2012:-::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp5:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:diffdog_2008:2.1`,
        fs:  `cpe:2.3:a:icofx:icofx:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:diffdog_2011:-:sp1:~~enterprise~~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:diffdog_2011:2.0::~~professional~~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:missionkit_2009:0.1`,
        fs:  `cpe:2.3:o:cisco:clean_access:4.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:missionkit_2011:2.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.97.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:missionkit_2012:-`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:missionkit_2012:0.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:missionkit_for_enterprise_software_architects:2010.00.00`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:umodel_2012:-::~~enterprise~~~`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2006:30.1::~~professional~~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2007:30.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:intel:network_connections:14.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2008:2.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2009:0.1::~~professional~~~`,
        fs:  `cpe:2.3:h:enterasys:6h258-17:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2011:2.0::~~professional~~~`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2011:3.0::~~professional~~~`,
        fs:  `cpe:2.3:a:digi:www_server:compieuw:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2011:3.1::~~professional~~~`,
        fs:  `cpe:2.3:a:disney:maleficent_free_fall:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2012:-::~~professional~~~`,
        fs:  `cpe:2.3:a:cisco:unity_connection:6.1\(3b\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altova:xmlspy_2012:0.1::~~professional~~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:altsoft:xml2pdf_workstation_2007:1.2.34`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alvaro_herrera:pl%2fphp:1.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alvaro_herrera:pl%2fphp:1.1`,
        fs:  `cpe:2.3:a:tibco:formvine:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alvaro_herrera:pl%2fphp:1.2`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alvaro_herrera:pl%2fphp:1.3.1`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alvaro_herrera:pl%2fphp:1.3.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alvaro_herrera:pl%2fphp:1.3.3`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alvaro_herrera:pl%2fphp:1.3.5:beta1`,
        fs:  `cpe:2.3:o:cray:unicos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:alvaro_herrera:pl%2fphp:1.4`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sru:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amanda:amanda:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amanda:amanda:2.3.0.4`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:ec2_api_tools_java_library:-`,
        fs:  `cpe:2.3:a:keepass:keepass:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:-`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.009.20071:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0:1`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0.3.4`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0.9.3`,
        fs:  `cpe:2.3:a:tenable:nessus:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0.10.0`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0.11.1`,
        fs:  `cpe:2.3:a:nttdocomo:overseas_usage:2.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0.12.0`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bpet64b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0.14.3`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0.15.1`,
        fs:  `cpe:2.3:h:nortel:alteon_2424_application_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:elastic_load_balancing_api_tools:1.0.17.0`,
        fs:  `cpe:2.3:a:icofx:icofx:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:flexible_payments_service:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:kindle:4.4.0::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_identity_manager_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:kindle:4.4.4::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:kindle:4.5.0::~~~android~~`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:kindle:4.6.0::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:kindle_for_pc:1.3.0.30884`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon:merchant_sdk:-`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amazon_aws_project:amazon_aws:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:h:apple:ipod_touch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amberdms:amberdms_billing_system:1.0.0`,
        fs:  `cpe:2.3:a:ibm:db2_recovery_expert:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amberdms:amberdms_billing_system:1.1.0`,
        fs:  `cpe:2.3:a:x:x_display_manager:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amberdms:amberdms_billing_system:1.2.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.3:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amberdms:amberdms_billing_system:1.3.0`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amberdms:amberdms_billing_system:1.4.0`,
        fs:  `cpe:2.3:h:cisco:spa_504g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amberdms:amberdms_billing_system:1.4.1`,
        fs:  `cpe:2.3:a:searchblox:searchblox:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amberfog:vk_amberfog:3.5.6::~~~android~~`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.4.5.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amcharts:flash:1.0`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:amd:16h_model_00h_processor:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:amd:16h_model_0fh_processor:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:amd:16h_model_processor_firmware:-`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:amd:amd64:-`,
        fs:  `cpe:2.3:a:avast:email_server_security:8.0.1609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amd:app_sdk_runtime:2.4.595.10`,
        fs:  `cpe:2.3:a:mysql:eventum:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amd:app_sdk_runtime:2.4.650.9`,
        fs:  `cpe:2.3:o:asus:rt-g32_firmware:2.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amd:app_sdk_runtime:2.5.684.213`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(2\)xc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amd:app_sdk_runtime:2.5.793.1`,
        fs:  `cpe:2.3:h:xerox:document_centre_440:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amd:catalyst_driver:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p37:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amd:power_monitor:1.0.1.47`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amebra_ameba_project:amebra_ameba:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amecuae:amgc:6::~~~android~~`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:americostech:selfshot_front_flash_camera:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amiscu:michael_baker_federal_credit_union:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amiscu:westmoreland_water_fcu:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.7::~~~ruby~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.8::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.9::~~~ruby~~`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.10::~~~ruby~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.11::~~~ruby~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.12::~~~ruby~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.13::~~~ruby~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.14::~~~ruby~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxd7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.15::~~~ruby~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.13:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.16::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.17::~~~ruby~~`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.18::~~~ruby~~`,
        fs:  `cpe:2.3:o:huawei:s9300e_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.19::~~~ruby~~`,
        fs:  `cpe:2.3:a:altiris:deployment_solution_for_network_devices:6.0.1046:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.20::~~~ruby~~`,
        fs:  `cpe:2.3:a:ronan_dowling:node_hierarchy:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.21::~~~ruby~~`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.22::~~~ruby~~`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.23::~~~ruby~~`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.24::~~~ruby~~`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.25::~~~ruby~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amos_benari:rbovirt:0.0.26::~~~ruby~~`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ampedwireless:r10000:-`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ampedwireless:r10000_firmware:2.5.2.11`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amtelco:misecuremessages:-`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:amtelco:misecuremessages:6.2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:amx:resource_management_suite:3.3.85`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analects_of_confucius_project:analects_of_confucius:8::~~~android~~`,
        fs:  `cpe:2.3:a:dart:powertcp_ftp_for_activex:2.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:3.0`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.6.2:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.4542`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.5450`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d48.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.5491`,
        fs:  `cpe:2.3:a:standardchartered:breeze_jersey:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.5851`,
        fs:  `cpe:2.3:a:umn:mapserver:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.6380`,
        fs:  `cpe:2.3:o:cisco:cisco_ons_15454_system_software:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.7255`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.7260`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.7265`,
        fs:  `cpe:2.3:h:hp:0235a31n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.10.01.7270`,
        fs:  `cpe:2.3:a:sap:netweaver_exchange_infrastructure_\(bc-xi\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.12.01.3890`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.12.01.5246`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.4:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.12.01.7000`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0\(5.31\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:5.12.02.5280`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:6.10.1.5450`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analog:soundmax:6.10.2.7260`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:6.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:atomic_timesync:-`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:-`,
        fs:  `cpe:2.3:a:jquery:jquery:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.0`,
        fs:  `cpe:2.3:a:webedition:webedition_cms:6.2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.0.1`,
        fs:  `cpe:2.3:a:mysql:mysql:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.0.2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.2\(2\):sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.0.3`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.0.4`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5108c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.0.5`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.0.6`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cpn:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.0.7`,
        fs:  `cpe:2.3:a:avaya:vsu_7500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.4`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnitouch_8670_automated_delivery_message_delivery_system:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:proxy:4.13`,
        fs:  `cpe:2.3:a:apache:qpid:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_shout:-`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_shout:1.0`,
        fs:  `cpe:2.3:a:interworx:web_control_panel:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:-`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.0.1`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.0.6`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.0.8`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:4.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.01`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.03`,
        fs:  `cpe:2.3:a:nq:easy_finder_\&amp;_anti-theft:2.0.10.08:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.04`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.05`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.06`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analogx:simpleserver_www:1.16`,
        fs:  `cpe:2.3:a:david_king:vino:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:analytictech:netdraw:2.00.0097`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.2.0.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:ananursespace:american_nurses_association:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anark:client:1.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anchorcms:anchor_cms:0.9.1`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andre_wiethoff:exact_audio_copy:1.0beta1`,
        fs:  `cpe:2.3:a:david_stosik:comment_moderation:6.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andreas_krennmair:tpp:1.3.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_levine:multiblock:6.x-1.1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.13:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_levine:multiblock:6.x-1.2`,
        fs:  `cpe:2.3:a:ekahau:real-time_location_system_controller:6.0.5-final:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_levine:multiblock:6.x-1.3`,
        fs:  `cpe:2.3:h:hp:officejet_5610:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_levine:multiblock:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_levine:multiblock:7.x-1.0`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_levine:multiblock:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_levine:multiblock:7.x-1.0:beta2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_levine:multiblock:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_magdy_kamal%27s_network_project:andrew_magdy_kamal%27s_network:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.3:beta`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.30`,
        fs:  `cpe:2.3:a:tenable:plugin-set:201402092115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.31`,
        fs:  `cpe:2.3:a:sambar:sambar_server:4.3:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.32`,
        fs:  `cpe:2.3:a:ibm:filenet_idm_desktop:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.40`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.41`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.42`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.50`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.51`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.60`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.60a`,
        fs:  `cpe:2.3:a:cisco:jabber:9.0\(.5\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.61`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.62`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.62a`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.70`,
        fs:  `cpe:2.3:a:thinkshout:mandrill:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.71`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.71a`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf234a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.80`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:1.81`,
        fs:  `cpe:2.3:a:bluecoat:unified_agent:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.00`,
        fs:  `cpe:2.3:a:hp:openview_configuration_management:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.01`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.10`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.11`,
        fs:  `cpe:2.3:h:cisco:nexus_5010p_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.20`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.30`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.31`,
        fs:  `cpe:2.3:a:citrix:xenserver:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.40`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.50`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.60`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.61`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:2.0.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.70`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:2.71`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.27:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:3.00`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:3.10`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:3.20`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:3.21`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:3.30`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.5:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andrew_simpson:webcollab:3.31`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:android_excellence_project:android_excellence:1.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:androidcommunity:hector_leal:13.08.14::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:active_directory_federation_services:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:androidebookapp:healthy_lunch_diet_recipes:3.6.1::~~~android~~`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:androidsu:chainsdd_superuser:3.1.3::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:androkera:las_vegas_lottery_scratch_off:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.3.8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andsocialrew:amkamal_science_portfolio:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:0.078`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:0.079`,
        fs:  `cpe:2.3:a:drupal:drupal:7.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:0.080`,
        fs:  `cpe:2.3:a:forgerock:openam:10.1.0:*:*:*:xpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:0.081`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:0.082`,
        fs:  `cpe:2.3:a:f5:big-ip_domain_name_system:12.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:0.83`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.0`,
        fs:  `cpe:2.3:a:oracle:human_capital_management_configuration_workbench:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.1`,
        fs:  `cpe:2.3:a:freedesktop:libdbus:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.1.1`,
        fs:  `cpe:2.3:a:apple:itunes:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.1.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_unified_software:1.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.103`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.4.0373:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.104`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.105`,
        fs:  `cpe:2.3:a:pocketmags:gambling_insider_magazine:\@7f0801aa:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.106`,
        fs:  `cpe:2.3:a:videowhisper:video_presentation:3.25:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.107`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.108`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.109`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.110`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.111`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi-simple:1.112`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.4`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.42`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.43`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:10.1.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.44`,
        fs:  `cpe:2.3:a:hp:openview_performance_core:10.50.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.45`,
        fs:  `cpe:2.3:o:huawei:secospace_antiddos8000_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.50`,
        fs:  `cpe:2.3:a:kurzweiledu:kurzweil_3000:9.0.0:*:*:*:trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.51`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.52`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.53`,
        fs:  `cpe:2.3:a:cisco:jabber:9.6\(2\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.54`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.55`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.56`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:1.57`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.0`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.01`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.13`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.14`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.15`,
        fs:  `cpe:2.3:a:webmin:usermin:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.16`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.17`,
        fs:  `cpe:2.3:o:huawei:5310hi_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.18`,
        fs:  `cpe:2.3:a:git-scm:git:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.19`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.20`,
        fs:  `cpe:2.3:a:hp:storage_operations_manager_eva_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.21`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.22`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.23`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.24`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d45.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.25`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.26`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.27`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.28`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.29`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.30`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.31`,
        fs:  `cpe:2.3:a:redhat:subscription_asset_manager:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.32`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.33`,
        fs:  `cpe:2.3:a:apache:batik:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.34`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.35`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.36`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.37`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.0:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.38`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:2.2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.39`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1058.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.40`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.41`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_unified_software:1.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.42`,
        fs:  `cpe:2.3:a:cisco:security_agent_management_center:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.43`,
        fs:  `cpe:2.3:h:supermicro:h8dgt-hlibqf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.44`,
        fs:  `cpe:2.3:a:prestashop:ebay_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.45`,
        fs:  `cpe:2.3:a:redhat:kdelibs_devel:3.1-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.46`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.47`,
        fs:  `cpe:2.3:a:gnu:bash:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.48`,
        fs:  `cpe:2.3:a:docker:docker:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.49`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.50.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.50`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.6:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.51`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.52`,
        fs:  `cpe:2.3:h:cisco:asr_1004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.53`,
        fs:  `cpe:2.3:h:f5:big-ip_5110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.54`,
        fs:  `cpe:2.3:o:apple:watchos:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.55`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.56`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.57`,
        fs:  `cpe:2.3:a:docker:docker-py:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.58`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.x-dev:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.59`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.60`,
        fs:  `cpe:2.3:h:ovislink:airlive_poe200hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.61`,
        fs:  `cpe:2.3:a:activcard:activcard_gold_for_cac:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.62`,
        fs:  `cpe:2.3:h:d-link:di-624s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.63`,
        fs:  `cpe:2.3:a:myapp:treves_dance_center:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.64`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0571:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.65`,
        fs:  `cpe:2.3:a:apache:struts:2.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.66`,
        fs:  `cpe:2.3:a:jenkins:git:0.4.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.67`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.68`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.23:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.69`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance:a5\(1.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.70`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.71`,
        fs:  `cpe:2.3:o:netgear:prosafe_firmware:5.4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.72`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.73`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall_1:4.1.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.74`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.75`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.76`,
        fs:  `cpe:2.3:a:pictobrowser_project:pictobrowser:0.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.77`,
        fs:  `cpe:2.3:a:hp:select_identity:4.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.78`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.79`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.80`,
        fs:  `cpe:2.3:a:apache:cxf:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.81`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.82`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.83`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:*:x86-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.84`,
        fs:  `cpe:2.3:a:goforandroid:go_email_widget:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.85`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.86`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.87`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:1000.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.88`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.89`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.90`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.91`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.92`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2011.1025.2152.37348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.93`,
        fs:  `cpe:2.3:a:ca:etrust_siteminder_documentation:12.0.105.635:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.94`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.95`,
        fs:  `cpe:2.3:a:microsoft:sna_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.96`,
        fs:  `cpe:2.3:a:debian:dpkg:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.97`,
        fs:  `cpe:2.3:o:dlink:dsl-2640b_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.98`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.99`,
        fs:  `cpe:2.3:a:icinga:icinga:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.751`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:2.752`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix_5570_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.00`,
        fs:  `cpe:2.3:a:perl:perl:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.01`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.02`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.37.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.03`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.04`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.05`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.06`,
        fs:  `cpe:2.3:a:webcreate:web_mart:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.07`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.08`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.09`,
        fs:  `cpe:2.3:a:google:chrome:9.0.573.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.10`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.11`,
        fs:  `cpe:2.3:a:apache:httpclient:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.12`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.13`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.14`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.15`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.16`,
        fs:  `cpe:2.3:a:hp:application_lifecycle_management:11.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.17`,
        fs:  `cpe:2.3:a:gnome:evolution:2.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.18`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.19`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.20`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.21`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.22`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.23`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.24`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.25`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.26`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.27`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.513:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.28`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p128:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.30`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.31`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.32`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.33`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.34`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:17.0.0.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.35`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.80:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.36`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.0_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.37`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.38`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.12:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.39`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5b\)su4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.40`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.41`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.42`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.43`,
        fs:  `cpe:2.3:a:microsoft:orca:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.44`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.45`,
        fs:  `cpe:2.3:h:hp:5500_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.46`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.47`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.48`,
        fs:  `cpe:2.3:a:microsoft:isa_server:2000:fp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:andy_armstrong:cgi.pm:3.49`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anecms:anecms:-`,
        fs:  `cpe:2.3:a:x:libxres:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anecms:anecms:2e2c583`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/b:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l24er-qbfc1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:atmail:atmail:6.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:novell:zenworks_servers:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:hp:insight_control_performance_management:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0:beta3`,
        fs:  `cpe:2.3:a:toocharger:myboard:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0:beta4`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.2`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.3`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.4`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.5`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.6`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.7`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.8`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.9`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)dc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:7.22.020.3453:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0:alpha4`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.1\(1.82\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:emc:powerpath:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0:dev`,
        fs:  `cpe:2.3:a:microsoft:visio:2002:sp2:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.0:rc2`,
        fs:  `cpe:2.3:a:apple:quicktime:7.3.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.1`,
        fs:  `cpe:2.3:a:apple:safari:3.0.1b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.2`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angrydonuts:ctools:7.x-1.3`,
        fs:  `cpe:2.3:h:intel:active_management_technology:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:0.5.0.1`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:1.0.0.5`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.0.1.2`,
        fs:  `cpe:2.3:a:pocoproject:poco_c\&#43;\&#43;_libraries:1.4.6:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.1.1.4`,
        fs:  `cpe:2.3:a:cacti:cacti:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.2.0.1`,
        fs:  `cpe:2.3:a:apache:axis:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.3.0.1`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.3.0.2`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.3.0.3`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.3.0.5`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.8:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.3.0.6`,
        fs:  `cpe:2.3:a:microsys:promotic:8.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.4.0.2`,
        fs:  `cpe:2.3:a:nginx:nginx:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.4.0.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.4.0.4`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.5.0`,
        fs:  `cpe:2.3:a:posh_project:posh:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:2.6.0`,
        fs:  `cpe:2.3:o:supermicro:intelligent_platform_management_firmware:2.26:-:-:*:-:-:x9_generation_motherboards:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.0.0`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.1.0`,
        fs:  `cpe:2.3:h:softbank:samsung_3g_handset:941sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.2`,
        fs:  `cpe:2.3:a:ibm:qradar_risk_manager:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.3`,
        fs:  `cpe:2.3:a:redhat:libreport:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.5`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.6`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.7`,
        fs:  `cpe:2.3:a:huawei:webui:11.010.06.01.858:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p253:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.9`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.2.10`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.3.1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.3.2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxj8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.3.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.4.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.5.0`,
        fs:  `cpe:2.3:a:sunil_nanda:blue_wrench_video_widget:1.0.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:angusj:resource_hacker:3.6.0.92`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:animalcenter:light_for_pets:1::~~~android~~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:animoca:bunny_run:1.1.2::~~~android~~`,
        fs:  `cpe:2.3:h:securecomputing:snapgear:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:animoca:fashion_style:3.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:ca:desktop_management_suite:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:animoca:star_girl:3.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:archangelmgt:weblog:0.90.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:animoca:star_girl%3a_colors_of_spring:3.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:knox:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anixis:password_policy_client:3.5`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anixis:password_policy_client:3.6.0.1`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anixis:password_policy_client:4.5`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anixis:password_policy_client:5.1`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anixis:password_policy_enforcer:3.6`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anixis:password_policy_enforcer:4.5`,
        fs:  `cpe:2.3:a:sgminer_project:sgminer:4.1.242:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anixis:password_policy_enforcer:5.11`,
        fs:  `cpe:2.3:h:cabletron:6h302-48:4.08.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anjuke:anjuke:7.1.7::~~~android~~`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anl:bcfg2:0.9.6`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anl:bcfg2:1.0.1`,
        fs:  `cpe:2.3:a:hp:proliant_ilo_management_controller_package:3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anl:bcfg2:1.1.3`,
        fs:  `cpe:2.3:a:apache:apache-ssl:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anl:bcfg2:1.2.0`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anl:bcfg2:1.2.0:rc2`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anl:bcfg2:1.2.3`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anonymous_posting_project:anonymous_posting:7.x-1.2`,
        fs:  `cpe:2.3:a:symantec:data_center_security_server:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anonymous_posting_project:anonymous_posting:7.x-1.3`,
        fs:  `cpe:2.3:a:bea:weblogic_workshop:8.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anritsu:traceview:3.1`,
        fs:  `cpe:2.3:a:phponlinechat:phponlinechat:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:0.1.0`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:0.1.1`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:0.2.0`,
        fs:  `cpe:2.3:a:openstack:keystone:juno-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:2.0.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.363.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:2.2`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:2.2.1`,
        fs:  `cpe:2.3:a:gimp:gimp:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:2.2.3`,
        fs:  `cpe:2.3:a:microsoft:office:2008:*:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:2.2.4`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:2.3`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_access_control_list_manager:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:2.3.1`,
        fs:  `cpe:2.3:a:microstrategy:microstrategy:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anshul_sharma:category-grid-view-gallery:2.3.3`,
        fs:  `cpe:2.3:h:linksys:befw11s4_v3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansible:tower:2.0.4`,
        fs:  `cpe:2.3:a:horde:groupware:1.0.6:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.1`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.5.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.016.20041:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.2.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.2.2`,
        fs:  `cpe:2.3:a:intel:iparty:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.2.3`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.3.0`,
        fs:  `cpe:2.3:a:emc:vplex_geosynchrony:5.4:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.3.1`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.9.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:1.9.6`,
        fs:  `cpe:2.3:a:oracle:corporate_time_outlook_connector:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:2.0`,
        fs:  `cpe:2.3:a:ca:spectrum:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansibleworks:ansible:2.0.1`,
        fs:  `cpe:2.3:a:yahoo:yahoo\!_browser:1.2.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ansys:ls-dyna:-`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansys:ls-dyna:7.1`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansys:ls-dyna:8.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansys:ls-dyna:9.0`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansys:mechanical:-`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansys:mechanical:7.1`,
        fs:  `cpe:2.3:a:ibm:net.commerce_hosting_server:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansys:mechanical:8.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9.1as:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ansys:mechanical:9.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00-06:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anthony_mills:s3_video:0.98`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.4p6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anthony_mills:s3_video:0.981`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anthony_mills:s3_video:0.982`,
        fs:  `cpe:2.3:h:d-link:dcs-2330l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anthony_tuininga:cx_oracle-10g:5.0.4`,
        fs:  `cpe:2.3:a:hp:storeonce_4210_fc_backup_system:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anti-plagiarism_project:anti-plagiarism:3.60::~~~wordpress~~`,
        fs:  `cpe:2.3:a:freebsd:aide:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anti-virus:virusblockada32:3.12.12.4:-:personal`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.6b.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.4.1`,
        fs:  `cpe:2.3:a:sun:java_system_content_delivery_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.4.2`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.4.3`,
        fs:  `cpe:2.3:h:zyxel:p-660hw_t3:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.4.4`,
        fs:  `cpe:2.3:a:vmware:player:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.4.5`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.5`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.5.1`,
        fs:  `cpe:2.3:a:yourkit:java_profiler:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.5.2`,
        fs:  `cpe:2.3:h:linksys:hpro200:1.42.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.5.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.5.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.5.6`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antisamy_project:antisamy:1.5.7`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antiword_project:antiword:0.37`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:antlabs:inngate_ig_3.00_e:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.10.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:antlabs:inngate_ig_3.01_e:-`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:antlabs:inngate_ig_3.02_e:-`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup:6.5.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:antlabs:inngate_ig_3.10_e:-`,
        fs:  `cpe:2.3:a:magzter:where_dallas:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:antlabs:inngate_ig_3.10_g:-`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:antlabs:inngate_ig_3100:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:antlabs:inngate_ig_3101:-`,
        fs:  `cpe:2.3:h:hp:advanced_server_9000:b.04.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antoine_beaupre:hostmaster:6.x-1.2`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antoine_beaupre:hostmaster:6.x-1.3`,
        fs:  `cpe:2.3:a:3ivx:mpeg-4:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antoine_beaupre:hostmaster:6.x-1.4`,
        fs:  `cpe:2.3:a:fusebox:fusebox:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antoine_beaupre:hostmaster:6.x-1.5`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_desktop:11:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antoine_beaupre:hostmaster:6.x-1.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.23:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antoine_beaupre:hostmaster:6.x-1.7`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antoine_beaupre:hostmaster:6.x-1.8`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antoine_beaupre:hostmaster:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antti_alamki:prh_search:7.x-1.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antti_alamki:prh_search:7.x-1.1`,
        fs:  `cpe:2.3:a:datadynamics:activebar:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:antti_alamki:prh_search:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anusthanokarehasya:baglamukhi:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anydesk:anydesk:3.6.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.20:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anyfont_plugin_project:anyfont:2.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:rave:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.2.255`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.3.296`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(4\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.4.302`,
        fs:  `cpe:2.3:a:drupal:drupal:5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.5.388`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.6.398`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.6.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.7.407`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.8.432`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.9.434`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.20.0:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.10.446`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.12.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.11.459`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6cno:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:1.5.12.464`,
        fs:  `cpe:2.3:o:d-link:dir505l_shareport_mobile_companion_firmware:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.0.0:rc522`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.0.1.531`,
        fs:  `cpe:2.3:a:lester_chan:wp-downloadmanager:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.0.2.542`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p448:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.0.3.545`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.0.641`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:4.1:update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.1.644`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(29a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.2.649`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.3.680`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.13:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.4.734`,
        fs:  `cpe:2.3:a:myrephp:myre_vacation_rental:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.5.746`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5137-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.6.749`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.7.1.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.7.761`,
        fs:  `cpe:2.3:a:hp:lights-out_passthrough_service:1.2.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anything-digital:sh404sef:2.1.8.777`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anywhere_anytime_yoga_workout_project:anywhere_anytime_yoga_workout:1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:anywherepad:anywhere_pad-meet_collaborate:4.0.1031::~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p104:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass:4.5.7:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:symantec:mail_security:5.0.0.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass_pro:6.2.1:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.23a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass_pro:6.2.2:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:wegoi:re-volt_2_\:_multiplayer:1.1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass_pro:6.3.0:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:sun:java_system_access_manager:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass_pro:6.3.4:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass_pro:6.3.5:-:~-~-~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass_pro:6.3.7:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:juniper:netscreen_remote_security_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass_pro:6.3.8:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aokitaka:zip_with_pass_pro:6.3.9:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:1.0`,
        fs:  `cpe:2.3:o:oracle:linux:6:5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:1.0.1.2`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.5.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:1.06`,
        fs:  `cpe:2.3:a:microcart_project:microcart:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:1.7`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:2.0`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:2.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:3.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:3.5`,
        fs:  `cpe:2.3:a:tenable:nessus:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:4.1`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:4.2`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:4.3`,
        fs:  `cpe:2.3:h:schneider-electric:bmxp3420302h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:4.4`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:4.7`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2009.1118.1260.23275:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:4.8`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:5.0`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:5.1`,
        fs:  `cpe:2.3:a:oracle:database_server_lite:5.0.2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:5.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:5.5`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:5.9`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:6.0`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:6.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim:6.8`,
        fs:  `cpe:2.3:a:macromedia:jrun:4.0_build_61650:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim_toolbar:-`,
        fs:  `cpe:2.3:a:f5:firepass:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aim_toolbar:5.96.6.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aol_toolbar:-`,
        fs:  `cpe:2.3:a:htc:evo_view_4g_software:1.22.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:3.3.1`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:3.4`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:3.4.2`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:3.5.5`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:3.5.10`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:4.0`,
        fs:  `cpe:2.3:a:wysigot:wysigot:5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:4.0.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:4.0.7`,
        fs:  `cpe:2.3:a:kan-studio:kandidat_cms:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:4.0.9`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:4.0.10`,
        fs:  `cpe:2.3:a:macromedia:coldfusion_fusebox:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:aolserver:4.5.1`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:browser:1.1`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.05\/32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:browser:1.6:-:embedded`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:browser:1.6:-:standalone`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:browser:1.7:-:embedded`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:browser:1.7:-:standalone`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf230a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:dailyfinance_-_stocks_%26_news:2.0.2.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:email_toolbar:-`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.71:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:aol:email_toolbar:5.22.27.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:explorer:-`,
        fs:  `cpe:2.3:a:copadata:zenon_dnp3_process_gateway:7.11:sp0_build_10238:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:explorer:1.5`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:internet_software:4.0`,
        fs:  `cpe:2.3:h:hp:cd645a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:internet_software:5.0`,
        fs:  `cpe:2.3:a:richard_cook:rgpg:0.2.1:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:internet_software:6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:internet_software:7.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:internet_software:8.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.0:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:internet_software:9.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p457:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aol:toolbar:5.74.1.1`,
        fs:  `cpe:2.3:h:3com:webbngss3nbxnts:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:-`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_anti-spyware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:4.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:4.0:m4`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:4.0:rc2`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:4.0.1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:4.0.2`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:4.1.0`,
        fs:  `cpe:2.3:a:ibm:algo_one:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:4.1.1`,
        fs:  `cpe:2.3:a:otrs:faq:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:4.1.2`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.0.0`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.2.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.3.0`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.3.1`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle:8.0.0.1551:*:*:*:trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.3.2`,
        fs:  `cpe:2.3:a:apache:poi:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.4.0`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_center:12.1.3:-:small_business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.4.1`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.4.2`,
        fs:  `cpe:2.3:a:mythicsoft_ltd:filelocator_pro:6.0.1225.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.4.3`,
        fs:  `cpe:2.3:a:oscommerce:online_merchant:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.5.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.5.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.6.0`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.7.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.8.0`,
        fs:  `cpe:2.3:a:apache:struts:2.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.9.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.9.1`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.10.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(3\)m2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.10.1`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.10.2`,
        fs:  `cpe:2.3:a:bylight:20\/20:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.11.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.11.1`,
        fs:  `cpe:2.3:a:social_slider_project:social_slider:7.4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.11.2`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.11.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.12.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_secureway_policy_director:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.12.1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.973:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.13.1`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq:5.13.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq_artemis:1.0.0`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq_artemis:1.1.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq_artemis:1.2.0`,
        fs:  `cpe:2.3:o:novell:suse_manager_proxy:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:activemq_artemis:1.3.0`,
        fs:  `cpe:2.3:a:devsaran:corporate:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.1.2`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.2.0`,
        fs:  `cpe:2.3:a:xnview:xnview:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.2.1`,
        fs:  `cpe:2.3:a:midgard-project:midgard2:10.05.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.2.2`,
        fs:  `cpe:2.3:a:oracle:retail_order_management_system_cloud_service:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.2.2:rc0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.2.2:rc1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.4.0`,
        fs:  `cpe:2.3:a:oracle:javafx:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.4.0:rc0`,
        fs:  `cpe:2.3:a:gnu:zlib:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.4.1`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_sp_isp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.4.1:rc0`,
        fs:  `cpe:2.3:h:google:glass:xe5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.4.1:rc1`,
        fs:  `cpe:2.3:a:altiris:application_metering_language_pack:6.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.4.2:rc0`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.4.2:rc1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.5.0:rc0`,
        fs:  `cpe:2.3:a:perl:perl:5.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.5.0:rc1`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.7:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ambari:2.5.0:rc2`,
        fs:  `cpe:2.3:a:yahoo:messenger:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apache-ssl:1.37`,
        fs:  `cpe:2.3:a:digium:asterisk:11.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apache-ssl:1.47`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apache-ssl:1.48`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.396:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apache-ssl:1.53`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apache-ssl:1.55`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)se1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apache-ssl:1.57`,
        fs:  `cpe:2.3:a:jason_flatt:basic_webmail:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apache_test:-`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apache_test:1.29`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.05:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.3`,
        fs:  `cpe:2.3:a:google:android_api:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.4`,
        fs:  `cpe:2.3:a:scott_reynen:node_embed:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.6`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.7`,
        fs:  `cpe:2.3:a:puppetlabs:hiera:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.8`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.11`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_manager:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.12`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.13`,
        fs:  `cpe:2.3:h:3com:3crtpx505-73:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.14`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(14\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.16`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.08.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.17`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:0.9.18`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.0`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.0.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a6\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.0.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.1.0`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.1.1`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.04:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.1.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.1`,
        fs:  `cpe:2.3:h:axis:m1034-w_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.6`,
        fs:  `cpe:2.3:a:hp:solution_center:60.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.7`,
        fs:  `cpe:2.3:a:openstack:neutron:2012.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.8`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.10`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.2.13`,
        fs:  `cpe:2.3:o:openvz:vzkernel:2.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.2`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.1.4.1518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.3`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.16:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.6`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.7`,
        fs:  `cpe:2.3:a:saflink:netsign_cac:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.8`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:5.5.0.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.9`,
        fs:  `cpe:2.3:a:google:v8:3.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.3.10`,
        fs:  `cpe:2.3:a:hkbn:hkbn_my_account:\@7f070015:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.4.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:apr-util:1.4.4`,
        fs:  `cpe:2.3:a:sap:netweaver_abap:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.2`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.2.1`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.2.2`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3`,
        fs:  `cpe:2.3:a:dell:openmanage_active_directory_snap-in_utility:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p186:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3.3`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3.5`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3.6`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_device_driver_installation:5.1.110:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3.8`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:archiva:1.3.9`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:-`,
        fs:  `cpe:2.3:a:owncloud:owncloud:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:-:alpha1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.7.0.19530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:-:alpha2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:-:alpha3`,
        fs:  `cpe:2.3:a:apple:cups:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:-:beta1`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:-:beta2`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.5.746:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:-:beta3`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.0`,
        fs:  `cpe:2.3:a:sap:sql_anywhere:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.0:beta`,
        fs:  `cpe:2.3:a:id:id-software:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.0:rc1`,
        fs:  `cpe:2.3:a:hp:web_registration:60.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.0:rc2`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.1`,
        fs:  `cpe:2.3:a:adcillc:simplemeta:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.1:beta`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.1:rc1`,
        fs:  `cpe:2.3:a:haxx:curl:7.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.1:rc2`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2:alpha`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2:beta1`,
        fs:  `cpe:2.3:a:microsoft:outlook:2013:-:-:*:-:-:x64:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2:beta2`,
        fs:  `cpe:2.3:a:mozilla:firefox:29.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2:beta3`,
        fs:  `cpe:2.3:a:busybox:busybox:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2:rc1`,
        fs:  `cpe:2.3:a:zfcuser_project:zfcuser:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2:rc2`,
        fs:  `cpe:2.3:a:emc:connectrix_manager:12.0.1:-:-:*:converged_network_edition:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2:rc3`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.1.2:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.2.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp9:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.3`,
        fs:  `cpe:2.3:a:apache:batik:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis:1.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:-`,
        fs:  `cpe:2.3:a:recruit:dokodemo_rikunabi_2013:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.3`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.4`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.4.1`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.1:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.5`,
        fs:  `cpe:2.3:a:nrgglobal:clevereye:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.5.1`,
        fs:  `cpe:2.3:a:hp:photosmart_essential:1.9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.5.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.5.3`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.5.4`,
        fs:  `cpe:2.3:a:symantec:sms-smtp-mysql-init:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.5.5`,
        fs:  `cpe:2.3:a:oracle:connector\/j:5.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.5.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.6`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.0.0.508:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.6.1`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:axis2:1.6.2`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:batik:-`,
        fs:  `cpe:2.3:a:apereo:central_authentication_service:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:batik:1.0`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:batik:1.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:batik:1.1.1`,
        fs:  `cpe:2.3:a:sun:one_web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:batik:1.5`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers:2.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:batik:1.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.424:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.0.0`,
        fs:  `cpe:2.3:h:ibm:m15:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.1.0`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.2.0`,
        fs:  `cpe:2.3:a:emc:unisphere:1.0:-:*:*:*:vmax:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.3.0`,
        fs:  `cpe:2.3:h:linksys:befsr41:0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.4.0`,
        fs:  `cpe:2.3:a:freedomscientific:synthesizer_eloquence:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.5.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:5.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.6.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.6.1`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.6.2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.6.3`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:1.6.4`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.0.0`,
        fs:  `cpe:2.3:a:mysql:eventum:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.0.0:m1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.0.0:m2`,
        fs:  `cpe:2.3:h:axis:2400_video_server:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.0.0:m3`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.1.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.8:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.2.0`,
        fs:  `cpe:2.3:a:php:pear:1.3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.3.0`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.4.0`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.5.0`,
        fs:  `cpe:2.3:a:docker:docker:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.6.0`,
        fs:  `cpe:2.3:a:ubnt:unifi_controller:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.7.0`,
        fs:  `cpe:2.3:a:sophos:enterprise_console:5.2.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.7.1`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.7.2`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.7.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.520:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.7.4`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.7.5`,
        fs:  `cpe:2.3:a:perl:perl:5.12.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.8.0`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.8.1`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.8.2`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:4.54.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.8.3`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.8.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.8.5`,
        fs:  `cpe:2.3:a:openstack:compute:2014.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.8.6`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.0`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.1`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.93:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.4`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.7.1:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.5`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.6`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1495.34686:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.7`,
        fs:  `cpe:2.3:a:ite:smart_guardian:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.9.8`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.10.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2a\)se9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.10.1`,
        fs:  `cpe:2.3:a:quest:intrust_monitoring_console:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.10.2`,
        fs:  `cpe:2.3:a:ibm:spectrum_protect_snapshot:4.1:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.10.3`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.10.4`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.10.5`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.8.2:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.10.6`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.10.7`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.11.0`,
        fs:  `cpe:2.3:a:oracle:retail_order_management_system_cloud_service:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.11.1`,
        fs:  `cpe:2.3:a:x:libxt:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.11.2`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.11.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.275.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.11.4`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.12.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.12.1`,
        fs:  `cpe:2.3:o:wdc:arkeia_virtual_appliance_firmware:10.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.12.2`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.12.3`,
        fs:  `cpe:2.3:h:linksys:befcmu10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.12.4`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.9:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.12.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.13.0`,
        fs:  `cpe:2.3:a:kuronecostudio:noble_sticker_\&#34;free\&#34;:1.0.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.13.1`,
        fs:  `cpe:2.3:h:hp:laserjet_2200dtn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.13.2`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.13.3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.13.4`,
        fs:  `cpe:2.3:a:apache:solr:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.14.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.14.1`,
        fs:  `cpe:2.3:a:netgenius:multilink:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.14.2`,
        fs:  `cpe:2.3:a:tilman_hausherr:xenu_link_sleuth:1.0u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.14.3`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.14.4`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc3008\/epc3008:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.15.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.15.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.15.2`,
        fs:  `cpe:2.3:a:omnigroup:omniweb:5.1:563.34:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.15.3`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.15.4`,
        fs:  `cpe:2.3:a:snapapp_project:snapapp:1.5:-:*:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.16.0`,
        fs:  `cpe:2.3:a:redmine:redmine:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.16.1`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.16.2`,
        fs:  `cpe:2.3:a:phimviethoa:chien_binh_bakugan_2_longtieng:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.16.3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.16.4`,
        fs:  `cpe:2.3:a:samba:samba:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.17.0`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.17.1`,
        fs:  `cpe:2.3:h:schneider-electric:tburjr900:05002eh0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.17.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.17.3`,
        fs:  `cpe:2.3:a:openstack:heat:2015.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.17.4`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.18.0`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.18.1`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.19.4`,
        fs:  `cpe:2.3:a:eeye:retina:5.14.1.2510:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:camel:2.20.0`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.0`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.2`,
        fs:  `cpe:2.3:a:hp:arcsight_logger:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.3`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.4`,
        fs:  `cpe:2.3:a:buffalotech:whr-g54s_firmware:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.5`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.6`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.09:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.7`,
        fs:  `cpe:2.3:h:moxa:iologic_e2242:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.8`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.9`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.10`,
        fs:  `cpe:2.3:a:telligent:evolution:7.6.7.36651:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.11`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.12`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.13`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.14`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.15`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd310a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.16`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.4:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.17`,
        fs:  `cpe:2.3:a:buffalotech:whr-ampg_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.18`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:1.2.19`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.0`,
        fs:  `cpe:2.3:a:businessobjects:business_intelligence:12.1.0.882:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.2`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.3`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.5`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.6`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.8`,
        fs:  `cpe:2.3:a:kde:kscreenlocker:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.9`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.10`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.11`,
        fs:  `cpe:2.3:o:pheonixcontact-software:proconos_eclr:-:*:*:*:visual_studio:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.12`,
        fs:  `cpe:2.3:a:altiris:svs_task:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.0.13`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.1.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.12:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.1.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.1.2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cassandra:2.1.3`,
        fs:  `cpe:2.3:a:isc:bind:9.3.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.0:-:community`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.0.1`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.0`,
        fs:  `cpe:2.3:a:novell:netmail:3.5.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.1`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.2`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:08.00.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je168a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.4`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:012:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.5`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.40.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.6`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.7`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.8`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.9`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00-05:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.1.10`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.0`,
        fs:  `cpe:2.3:a:hp:directories_support_for_proliant_management_processors:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.1`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.3`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.5`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.6`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.8`,
        fs:  `cpe:2.3:a:apache:hadoop:0.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.9`,
        fs:  `cpe:2.3:a:ibm:rational_automation_framework:3.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.11`,
        fs:  `cpe:2.3:a:google:chrome:11.0.689.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.12`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.13`,
        fs:  `cpe:2.3:h:polycom:mgc-100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:2.2.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.8:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:3.0.0`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_sp_isp_decoder_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:3.0.1`,
        fs:  `cpe:2.3:a:magic_hills:wonderplugin_audio_player:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:3.0.2`,
        fs:  `cpe:2.3:a:ca:single_sign-on:r12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.0.0:incubating`,
        fs:  `cpe:2.3:o:lexmark:printer_firmware:pp.02.048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.0.1`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.0.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.46.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.1.0`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.1.1`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.2.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.2:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.4.4`,
        fs:  `cpe:2.3:a:wordpress_social_login_project:wordpress_social_login:2.0.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.5.1`,
        fs:  `cpe:2.3:a:hp:solution_center:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.5.2`,
        fs:  `cpe:2.3:a:digium:asterisk:11.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.6.0`,
        fs:  `cpe:2.3:o:cisco:catos:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.6.1`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.6.2`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.7.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cloudstack:4.8`,
        fs:  `cpe:2.3:a:yahoo:yui:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cocoon:-`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cocoon:2.1`,
        fs:  `cpe:2.3:a:getpixie:pixie:1.01:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cocoon:2.1.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cocoon:2.2`,
        fs:  `cpe:2.3:a:irislink:readiris:11.0.4965:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-compress:1.0`,
        fs:  `cpe:2.3:a:emc:networker_module_for_microsoft_applications:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-compress:1.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-compress:1.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-compress:1.3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-compress:1.4`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.4.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-compress:1.4.1`,
        fs:  `cpe:2.3:a:mercadolibre:mercadolibre:3.8.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:3.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.7.0:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.0`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.0.1`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.0.2`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2011-05-25c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.0.3`,
        fs:  `cpe:2.3:a:apache:httpclient:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.1.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.1.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.1.3`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v100r006c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p190:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.2.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.2.2`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.2.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.2.4`,
        fs:  `cpe:2.3:a:samba:samba:3.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.2.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons-httpclient:4.2.6`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_beanutils:1.9.1`,
        fs:  `cpe:2.3:o:cisco:sn_5428_storage_router:3.2.1-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_collections:3.2.1`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_collections:4.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_email:1.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_email:1.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_email:1.2`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.76:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_email:1.3`,
        fs:  `cpe:2.3:a:perl:perl:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_email:1.3.1`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_email:1.3.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_email:1.3.3`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_email:1.4`,
        fs:  `cpe:2.3:a:typo3:typo3:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_fileupload:1.0`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp1:x86-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_fileupload:1.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_fileupload:1.1.1`,
        fs:  `cpe:2.3:a:gizra:og_vocab:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_fileupload:1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(27\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_fileupload:1.2.1`,
        fs:  `cpe:2.3:a:zooeffect:zooeffect:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_fileupload:1.2.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_fileupload:1.3`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.2k1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:commons_fileupload:1.3.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cordova:3.5.0::~~~android~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:7:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cordova:3.9.1::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cordova:5.2.2::~~~android~~`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cordova_file_transfer:1.2.1::~~~android~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.0.0`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.10-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.0.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.0.3`,
        fs:  `cpe:2.3:a:hp:toolbox:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.0.4`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.1.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.1.1`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.1.2`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.2.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.5.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.2.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:couchdb:1.5.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:coyote_http_connector:-`,
        fs:  `cpe:2.3:a:invensys:wonderware_archestra_integrated_development_environment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:coyote_http_connector:1.0`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:coyote_http_connector:1.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.4.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.4.1`,
        fs:  `cpe:2.3:h:rockwellautomation:rslinx_enterprise:cpr9:sr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.4.2`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.6.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.4.3`,
        fs:  `cpe:2.3:a:yeast_infection_project:yeast_infection:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.4.4`,
        fs:  `cpe:2.3:o:huawei:s5700_firmware:v200r005c03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.4.5`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.4.6`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.4.7`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.0`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.1415926:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.3`,
        fs:  `cpe:2.3:a:adobe:form_client_end-user_components:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.4`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:9.0.0-193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.5`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.21:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.6`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.7`,
        fs:  `cpe:2.3:o:hospira:lifecare_pcainfusion_pump_firmware:412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.8`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.5.9`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.1`,
        fs:  `cpe:2.3:a:splunk:splunk:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.2`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ebs:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.3`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.409.2:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.5`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.6`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.7`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.8`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.9`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.10`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.11`,
        fs:  `cpe:2.3:a:boost:boost:1.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ea:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.13`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.6.14`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp4:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.0`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent_option:10.0:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.1`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.2`,
        fs:  `cpe:2.3:a:organizer_project:organizer:1.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.3`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.4`,
        fs:  `cpe:2.3:a:christopher_mitchell:smart_breadcrumb:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.6`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.7`,
        fs:  `cpe:2.3:h:h3c:s7500e_secblade_vpn_firewall_module:0231a832:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.8`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.3\(2\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.9`,
        fs:  `cpe:2.3:a:krisonav:krisonav:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.10`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(2\)xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.12`,
        fs:  `cpe:2.3:a:hp:bufferchm:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.13`,
        fs:  `cpe:2.3:a:apache:knox:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:2.7.17`,
        fs:  `cpe:2.3:h:lg:l-04d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.0.0`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.0.1`,
        fs:  `cpe:2.3:a:ibm:algo_one:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.0.6`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.1.2`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.10-1.8:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.1.3`,
        fs:  `cpe:2.3:o:cisco:rv130w_wireless-n_multifunction_vpn_router_firmware:1.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.1.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.1.5`,
        fs:  `cpe:2.3:a:nttdata:web_analytics_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.1.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.1.7`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u6\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.1.8`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.290:update29:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:apache:cxf:3.1.9`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:3.2.0:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.923.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.1.1.0`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.1.2.1`,
        fs:  `cpe:2.3:a:plainblack:webgui:7.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.1.3.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.2.1.6`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.2.2.0`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.3.3.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.4.1.3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.4.2.0`,
        fs:  `cpe:2.3:a:saltstack:salt:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.5.1.1`,
        fs:  `cpe:2.3:a:quassel-irc:quassel:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.5.3.0`,
        fs:  `cpe:2.3:a:interworx:web_control_panel:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.6.1.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch_4000m:c.08.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.6.2.1`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.7.1.1`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.8.1.2`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.8.2.2`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.8.3.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.9.1.0`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.10.1.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.955.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.10.2.0`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.11.1.1`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.12.1`,
        fs:  `cpe:2.3:h:radware:certaint_100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.12.1.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:derby:10.13.1.1`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.8.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:flex:4.14.0`,
        fs:  `cpe:2.3:a:bigware:bigware_shop:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geode:1.1.0`,
        fs:  `cpe:2.3:a:redhat:sysstat:4.0.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:1.0`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:2.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:2.0.1`,
        fs:  `cpe:2.3:a:apache:hadoop:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:2.0.2`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:2.1`,
        fs:  `cpe:2.3:a:logitech:khalinstallwrapper:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:3.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:3.0:beta1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:geronimo:3.0:m1`,
        fs:  `cpe:2.3:a:kde:kde_applications:14.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.0:beta_1`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.0:beta_2`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.12.3:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.0:rc1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.0:rc2`,
        fs:  `cpe:2.3:a:david_king:vino:2.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.4`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.58.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.5`,
        fs:  `cpe:2.3:a:grape_project:grape:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.6`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd7.d4xxwtpf_firmware:1.24.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.7`,
        fs:  `cpe:2.3:a:novell:groupwise:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.8`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.9`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.21.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.10`,
        fs:  `cpe:2.3:a:google:v8:3.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.7.11`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0:beta_1`,
        fs:  `cpe:2.3:h:hp:color_laserjet_4700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0:beta_2`,
        fs:  `cpe:2.3:a:perl:perl:2.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0:beta_3`,
        fs:  `cpe:2.3:a:qemu:qemu:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0:beta_4`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0:rc1`,
        fs:  `cpe:2.3:a:google:android_api:19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0:rc2`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0:rc3`,
        fs:  `cpe:2.3:a:bitbucket:xnbd:0.1.0:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.0:rc4`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.1`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.2`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.5`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.7`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.8`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.8.9`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.9.0`,
        fs:  `cpe:2.3:a:eagletron:dvdriver:1.0.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.9.0:beta_1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.1:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.9.0:beta_3`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:1.9.0:beta_4`,
        fs:  `cpe:2.3:o:hp:tru64:5.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.0`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.0:beta_1`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.0:beta_2`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.0:beta_3`,
        fs:  `cpe:2.3:a:sun:openoffice.org:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.0:rc1`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.7:e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.0:rc2`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.0:rc3`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.0:rc4`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.3`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.599:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.4`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.10:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.5`,
        fs:  `cpe:2.3:a:web2py:web2py:1.83.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.6`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.7`,
        fs:  `cpe:2.3:o:pheonixcontact-software:proconos_eclr:-:*:*:*:single_chip:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.0.8`,
        fs:  `cpe:2.3:a:readydesk:readydesk:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.0`,
        fs:  `cpe:2.3:a:oracle:webcenter_sites:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.0:beta_1`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.1389:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.0:rc1`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.0:rc2`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall_1:4.1.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.0:rc3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:08-00-02:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.2`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.3`,
        fs:  `cpe:2.3:a:hp:jetadmin:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.4`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.4.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.5`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.6`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.7`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.8`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.1.9`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.2.0`,
        fs:  `cpe:2.3:a:microsoft:publisher:2002:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.2.0:beta_1`,
        fs:  `cpe:2.3:a:google:web_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.2.0:beta_2`,
        fs:  `cpe:2.3:o:hp:tru64:4.0g_pk4_bl22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.2.0:rc1`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.2.0:rc2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.2.0:rc3`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.2.1`,
        fs:  `cpe:2.3:a:curecos:cure_viewer:1.03:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.2.2`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.0`,
        fs:  `cpe:2.3:o:fortinet:fortiadc_firmware:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.0:beta_1`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.0:beta_2`,
        fs:  `cpe:2.3:a:microsoft:office:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jb4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.0:rc2`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2008:-:government:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.0:rc3`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.1`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.1.0:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.2`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.6.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.3`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.4`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.5`,
        fs:  `cpe:2.3:a:invensys:wonderware_archestra_configuration_access_component_activex_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.6`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.7`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.8`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.9`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers:2.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.10`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.3.11`,
        fs:  `cpe:2.3:a:alex_launi:tangerine:0.3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.0:beta_1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.0:beta_2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.0:beta_3`,
        fs:  `cpe:2.3:a:soprano:fonecta_verify:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.0:beta_4`,
        fs:  `cpe:2.3:a:ibm:filenet_content_manager:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.0:rc1`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ey3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.1`,
        fs:  `cpe:2.3:h:moxa:oncell_gateway_g3251:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:groovy:2.4.3`,
        fs:  `cpe:2.3:h:cisco:wap4410n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.14.1`,
        fs:  `cpe:2.3:a:php:php:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.14.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.14.4`,
        fs:  `cpe:2.3:h:iij:seil\/neu_2fe_plus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.15.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.15.1`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.15.2`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2012:r2:-:-:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.15.3`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.4.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.16.0`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.16.1`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.38:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.16.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)xc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.16.3`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.16.4`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.17.0`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.17.1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.17.2`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.18.0`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.4.9:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.18.1`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.18.2`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.18.3`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.19.0`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.19.1`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.5.2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.19.2`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.20.0`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.20.1`,
        fs:  `cpe:2.3:a:horde:imp:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.20.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(2a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.20.203.0`,
        fs:  `cpe:2.3:a:typo3:typo3:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.20.204.0`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.20.205.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:5.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.21.0`,
        fs:  `cpe:2.3:a:alterpoint:networkauthority_engineering_environment:6.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.22.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.3`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp3:srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.6`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.7`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.8`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.9`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.10`,
        fs:  `cpe:2.3:a:novell:groupwise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:0.23.11`,
        fs:  `cpe:2.3:a:amberdms:amberdms_billing_system:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.0.0`,
        fs:  `cpe:2.3:o:extremenetworks:extremeware_xos:11.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.0.1`,
        fs:  `cpe:2.3:a:microsoft:home_publishing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.0.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.0.3`,
        fs:  `cpe:2.3:a:vips:vips:7.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.0.4`,
        fs:  `cpe:2.3:a:ghozylab:gallery_-_photo_albums_-_portfolio:1.3.47:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.1.1`,
        fs:  `cpe:2.3:o:huawei:s7703_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.1.2`,
        fs:  `cpe:2.3:a:git-scm:git:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:1.2.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.0.0:alpha`,
        fs:  `cpe:2.3:a:oracle:identity_analytics:11.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.0.1:alpha`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.05.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.0.2:alpha`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.11.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.0.3:alpha`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.0.4:alpha`,
        fs:  `cpe:2.3:a:xnview:xnview:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.0.5:alpha`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.0.6:alpha`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.1.0:beta`,
        fs:  `cpe:2.3:a:powerdns:authoritative:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.1.1:beta`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.2.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.3.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.4.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:beta_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.4.1`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.5.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_39:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.5.1`,
        fs:  `cpe:2.3:a:hp:centralview_dealer_performance_audit:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.6.0`,
        fs:  `cpe:2.3:a:oracle:database_server:11.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.6.1`,
        fs:  `cpe:2.3:a:soprano:fonecta_verify:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.6.2`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.6.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.6.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.7.0`,
        fs:  `cpe:2.3:a:samba:samba:3.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.7.1`,
        fs:  `cpe:2.3:a:immigrer:forum_ic:3.3.12:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hadoop:2.7.2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:harmony:6.0:m3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.92.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.379:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.92.1`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.92.2`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.92.3`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.0`,
        fs:  `cpe:2.3:a:vanilla_perl_project:strawberry_perl:5.12.512:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.2`,
        fs:  `cpe:2.3:a:werdswords:download_shortcode:1.1:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.3`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.4`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.5`,
        fs:  `cpe:2.3:o:suse:suse_linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.6`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.6.1`,
        fs:  `cpe:2.3:a:mautic:mautic:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.7`,
        fs:  `cpe:2.3:a:zend:zendservice_slideshare:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.8`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.94.9`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.0`,
        fs:  `cpe:2.3:a:samba:samba:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.1`,
        fs:  `cpe:2.3:a:pinnaclesys:studio:11.0.13:*:*:*:ultimate:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.2`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.191:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.3`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.4`,
        fs:  `cpe:2.3:a:nancy_wichmann:sitedoc:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.5`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.6`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.270:update27:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.6.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.584:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.7`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.8`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.9`,
        fs:  `cpe:2.3:a:apache:wss4j:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.10`,
        fs:  `cpe:2.3:h:hp:cm8060_color_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.10.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.11`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hbase:0.98.12`,
        fs:  `cpe:2.3:h:lexmark:xc8155de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:0.13.0`,
        fs:  `cpe:2.3:a:collectiveaccess:providence:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:0.13.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:0.14.0`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:1.0.0`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.40.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:1.0.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2626:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:1.1.0`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:1.1.1`,
        fs:  `cpe:2.3:a:silexlabs:silex:2.0.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:1.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:hive:1.2.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.792.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:-`,
        fs:  `cpe:2.3:a:curvycorners:curvycorners:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:0.8.11`,
        fs:  `cpe:2.3:a:tribiq:tribiq_cms:5.0.9a:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:0.8.14`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.0`,
        fs:  `cpe:2.3:a:wolfssl:wolfssl:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.0.2`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.1\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.0.5`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.1.1`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.2`,
        fs:  `cpe:2.3:a:apple:itunes:12.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.2.4`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.2.5`,
        fs:  `cpe:2.3:a:sun:solaris_libfont:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.2.6`,
        fs:  `cpe:2.3:a:netiq:sentinel_agent_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.2.9`,
        fs:  `cpe:2.3:a:vmware:workstation_player:12.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.1.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.2`,
        fs:  `cpe:2.3:a:hp:status:82.0.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.4`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.5`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.6`,
        fs:  `cpe:2.3:a:apache:solr:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.7`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.8`,
        fs:  `cpe:2.3:h:huawei:mate_7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.9`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.10`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.11`,
        fs:  `cpe:2.3:h:hp:eliteone_705_g2_23in_aio_t\/nt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.12`,
        fs:  `cpe:2.3:a:radius_extension_project:radius:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.13`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.14`,
        fs:  `cpe:2.3:a:rockwellautomation:1763-l16dwd_series_a:15.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.15`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.16`,
        fs:  `cpe:2.3:a:php:php:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.17`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.18`,
        fs:  `cpe:2.3:o:sun:solaris:2.6:hw3:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.19`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.20`,
        fs:  `cpe:2.3:a:piriform:ccleaner:5.02.5101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.22`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.23`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.24`,
        fs:  `cpe:2.3:o:microsoft:windows:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.25`,
        fs:  `cpe:2.3:a:mcafee:e-business_server:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.26`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.27`,
        fs:  `cpe:2.3:a:openidm_project:openidm:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.28`,
        fs:  `cpe:2.3:a:microsoft:baseline_security_analyzer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.29`,
        fs:  `cpe:2.3:a:perl:perl:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.30`,
        fs:  `cpe:2.3:a:ibm:tivoli_opc_tracker_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.31`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.32`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:12:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.33`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.34`,
        fs:  `cpe:2.3:a:plone:plone:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.35`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.36`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.37`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.38`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.39`,
        fs:  `cpe:2.3:a:php:pear:1.3b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.41`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.42`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.65`,
        fs:  `cpe:2.3:a:mcafee:change_control:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.3.68`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.4.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-50-\/f:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:1.99`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0`,
        fs:  `cpe:2.3:o:google:android:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.9`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.28`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.28:beta`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2003_server:6.3.1700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.32`,
        fs:  `cpe:2.3:a:huawei:s5700_firmware:v200r003c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.32:beta`,
        fs:  `cpe:2.3:a:google:earth:4.3.7204.836:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.34:beta`,
        fs:  `cpe:2.3:a:haxx:curl:7.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.35`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.36`,
        fs:  `cpe:2.3:a:djangoproject:django:1.10.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.37`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.38`,
        fs:  `cpe:2.3:a:mumble:mumble:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.39`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tcu4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.40`,
        fs:  `cpe:2.3:o:cisco:ios:12.2x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.41`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.42`,
        fs:  `cpe:2.3:h:cisco:pix_firewall:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.43`,
        fs:  `cpe:2.3:a:linux-sottises:board-tnk:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.44`,
        fs:  `cpe:2.3:a:google:chrome:6.0.471.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.45`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.46`,
        fs:  `cpe:2.3:a:emulex:hbanyware:4.01a36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.47`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.48`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.49`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.50`,
        fs:  `cpe:2.3:h:hp:0235a31p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.51`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.52`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.53`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.54`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.55`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.56`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.57`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.58`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.59`,
        fs:  `cpe:2.3:a:apache:ofbiz:11.04.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.60`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(20\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.61`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:19.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.63`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.0.64`,
        fs:  `cpe:2.3:a:mislav_marohnic:will_paginate:3.0:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1`,
        fs:  `cpe:2.3:a:invensys:foxboro_control_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.326:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.393:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.3`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.4`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.5`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.1.3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.6`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.7`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.8`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.1.9`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.5.0:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.0`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.2`,
        fs:  `cpe:2.3:a:autodesk:building_systems:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.3`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.4`,
        fs:  `cpe:2.3:h:siemens:scalance_w786-1pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.5`,
        fs:  `cpe:2.3:a:cherry-design:wikipad:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.6`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.8`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.5:-:network:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.9`,
        fs:  `cpe:2.3:a:mathew_winstone:mobile_tools:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.10`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.11`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110622:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.12`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.13`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.14`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.15`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.16`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_configuration_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.17`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.18`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.19`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.20`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.21`,
        fs:  `cpe:2.3:a:pdflib:pdflib:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.22`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.23`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.24`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:01-02-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.25`,
        fs:  `cpe:2.3:a:altiris:endpoint_security_solution:6.0.479:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.26`,
        fs:  `cpe:2.3:a:shopware:shopware:4.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.27`,
        fs:  `cpe:2.3:a:nero:photosnap_help:1.53.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.2.34`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.0`,
        fs:  `cpe:2.3:a:skype:skype:4.0:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.221.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.01.163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.4`,
        fs:  `cpe:2.3:h:netgear:rt314:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.5`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.24:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.6`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.7`,
        fs:  `cpe:2.3:a:spumko_project:hapi_server_framework:2.2.0:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.8`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.9`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.10`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.11`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.12`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.13`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.14`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.15`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.3.16`,
        fs:  `cpe:2.3:a:splunk:splunk:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.1`,
        fs:  `cpe:2.3:a:apache:nutch:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.2`,
        fs:  `cpe:2.3:a:fitnesse:fitnesse_wiki:20140201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.3`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.6`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.7`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.8`,
        fs:  `cpe:2.3:h:hp:laserjet_2430:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.14:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.10`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.12`,
        fs:  `cpe:2.3:a:tag1consulting:support_timer:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.14`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.16`,
        fs:  `cpe:2.3:a:vmware:fusion_pro:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.19`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.20`,
        fs:  `cpe:2.3:a:websense:websense_web_security:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.21`,
        fs:  `cpe:2.3:a:pivotal_software:redis:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.22`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.23`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.301:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:2.4.27`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:http_server:3.1`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg210-25:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0:alpha1`,
        fs:  `cpe:2.3:a:wafer:webmatic:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0:alpha2`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0:alpha3`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0:beta1`,
        fs:  `cpe:2.3:h:d-link:dcs-2230l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0:beta2`,
        fs:  `cpe:2.3:a:gcspublishing:georgia_packing:3.9.16:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0:beta3`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0:beta4`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.7.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0.1`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpasyncclient:4.0.2`,
        fs:  `cpe:2.3:a:mcafee:security_center:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.0`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.0:alpha1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.0:alpha2`,
        fs:  `cpe:2.3:a:sybase:pylon_anywhere:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.0:alpha3`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.898:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.0:alpha4`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.0:beta1`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.0:beta2`,
        fs:  `cpe:2.3:o:mercurycom:mr804_firmware:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.0.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.1`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.1:alpha1`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.1:alpha2`,
        fs:  `cpe:2.3:a:ricky_morse:excluded_users:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.1:beta1`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.1.1`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.1.2`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.2`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_39:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.2:alpha1`,
        fs:  `cpe:2.3:a:happyworm:jplayer:0.2.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.2:beta1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.2.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.2.2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.2.3`,
        fs:  `cpe:2.3:a:projectsend:projectsend:180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3`,
        fs:  `cpe:2.3:h:huawei:s7700:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3:alpha1`,
        fs:  `cpe:2.3:a:plone:plone:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3:beta1`,
        fs:  `cpe:2.3:a:polycom:datastore:5.22.109.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3:beta2`,
        fs:  `cpe:2.3:h:lucent:ascend_pipeline_router:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3.1`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3.2`,
        fs:  `cpe:2.3:h:nortel:ip_phone_1140e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3.3`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.0.2.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:httpclient:4.3.5`,
        fs:  `cpe:2.3:a:adobe:photoshop:12.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.0.0`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0086:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.0.0:rc3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.370:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.1.0`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.3.0`,
        fs:  `cpe:2.3:a:lunarline:scapsync:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.4.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.5.0:b1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.5.0:final`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.0.1.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.6.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.7.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.9:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.8.0`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:1.9.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ignite:2.0.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:1.4`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:1.5.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:0.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.0.5`,
        fs:  `cpe:2.3:a:microsoft:excel:97:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.0`,
        fs:  `cpe:2.3:o:belkin:n150_f9k1009_firmware:1.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.1`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.2`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.4`,
        fs:  `cpe:2.3:a:kadu:kadu:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.5`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.7`,
        fs:  `cpe:2.3:a:cmu:isilk:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.8`,
        fs:  `cpe:2.3:a:yoshinori_tahara:mycaljp:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.9`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.10`,
        fs:  `cpe:2.3:a:intelliants:esyndicat:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.11`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.12`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.2.13`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.4.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-51-\/e:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.4.1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.4.2`,
        fs:  `cpe:2.3:a:novell:iprint:4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.4.3`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.03:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.4.4`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.4.5`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.6.0`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.6.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.6.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.6.3`,
        fs:  `cpe:2.3:a:apache:hadoop:2.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.6.4`,
        fs:  `cpe:2.3:a:microsoft:dhcp_client_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.6.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.8.0`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.8.1`,
        fs:  `cpe:2.3:a:adobe:connect:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.8.2`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.10.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.315:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.10.1`,
        fs:  `cpe:2.3:a:ubnt:unifi_video:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.10.2`,
        fs:  `cpe:2.3:a:openx:openx:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.10.3`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.12.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.12.1`,
        fs:  `cpe:2.3:a:cisco:desktop_base:6.1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.12.2`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.12.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.13.0`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.13.1`,
        fs:  `cpe:2.3:a:oracle:corporate_time_outlook_connector:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jackrabbit:2.13.2`,
        fs:  `cpe:2.3:a:webassist:powerstore:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jakarta_isapi_redirector:1.2.12`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.5.1681:unknown:online_windows_2000:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jakarta_isapi_redirector:1.2.14`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jakarta_isapi_redirector:1.2.15`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jakarta_slide:-`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:jakarta_slide:2.1`,
        fs:  `cpe:2.3:h:xerox:workcentre_m55:4.84.16.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:james:-`,
        fs:  `cpe:2.3:a:oracle:mysql_workbench:6.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:james:2.2.0`,
        fs:  `cpe:2.3:a:nvidia:nview:136.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:james_server:2.3.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:james_server:3.0.0`,
        fs:  `cpe:2.3:a:atvise:webmi2ads:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:0.9:rc1`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:0.9:rc2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:0.9:rc3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:0.9:rc4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:2.0:rc5`,
        fs:  `cpe:2.3:a:adobe:flash_player:22.0.0.211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:3.1.2`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:3.1.3`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:3.1.4`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.08b51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:juddi:3.1.5`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:1.47.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.2.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.3.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.4.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.5.0`,
        fs:  `cpe:2.3:h:juniper:junos_space_ja1500_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.6.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.7.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.8.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.9.0`,
        fs:  `cpe:2.3:a:ibm:traveler:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.10.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:knox:0.11.0`,
        fs:  `cpe:2.3:a:pyyaml:libyaml:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.2.0`,
        fs:  `cpe:2.3:a:micropact:icomplaints:8.0.2.1.8.8014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.3.0`,
        fs:  `cpe:2.3:a:petition_project:petition:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.0sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.4.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.4.2`,
        fs:  `cpe:2.3:a:adobe:robohelp:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.5.2`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.6.0:beta1`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.6.1`,
        fs:  `cpe:2.3:a:altiris:language_pack_for_patch_management_core_linux:6.2.1022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.6.2`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.7.0`,
        fs:  `cpe:2.3:h:supermicro:x9drw-itpf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.7.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.8.0`,
        fs:  `cpe:2.3:a:gnu:grub2:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.9.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-02-18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.10.1`,
        fs:  `cpe:2.3:a:apache:solr:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.11.0`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.11.1`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:45.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.11.2`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.11.3`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.12.3`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.12.4`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.13.0`,
        fs:  `cpe:2.3:a:apache:cordova_file_transfer:1.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.13.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:libcloud:0.13.2`,
        fs:  `cpe:2.3:a:freedomscientific:talking_installer:8.0.2173.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:alpha1`,
        fs:  `cpe:2.3:a:altiris:patch_management_for_windows_dell_servers:6.2.3647:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:alpha2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta1`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta2`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta3`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta4`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta6`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta7`,
        fs:  `cpe:2.3:a:dell:system_manager:1.7.10000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta8`,
        fs:  `cpe:2.3:a:iss:blackice_defender:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:beta9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:rc1`,
        fs:  `cpe:2.3:a:avaya:call_management_system_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.0.2`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_plant_applications:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.2`,
        fs:  `cpe:2.3:a:biscom:faxcom_cover_page_editor:9.6.700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.3`,
        fs:  `cpe:2.3:a:ruby-i18n:i18n:0.6.6:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.4`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.4.1`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:10.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.5`,
        fs:  `cpe:2.3:h:sophos:unified_threat_management:110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.6`,
        fs:  `cpe:2.3:a:apache:roller:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.6.1`,
        fs:  `cpe:2.3:a:redhat:stronghold:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.6.2`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.7`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.4c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.8`,
        fs:  `cpe:2.3:a:pocketmags:model_laboratory:\@7f080193:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4j:2.8.1`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4net:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:log4net:1.2.9_beta`,
        fs:  `cpe:2.3:a:hp:destinations:60.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:maven:3.0`,
        fs:  `cpe:2.3:o:centos:centos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:maven:3.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:maven:3.0.2`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:maven:3.0.3`,
        fs:  `cpe:2.3:a:hp:serviceguard:a.11.15.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:maven:3.0.4`,
        fs:  `cpe:2.3:a:python:python:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:maven:3.0.5`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.9661:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:maven_wagon:2.1`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_auth_radius:-`,
        fs:  `cpe:2.3:a:hp:xp_p9000_tiered_storage_manager:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_auth_radius:1.5.4`,
        fs:  `cpe:2.3:a:isc:bind:9.3.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_dav_svn:-`,
        fs:  `cpe:2.3:h:hp:cm8050_color_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_dontdothat:-`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.1`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg221a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.4`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.5`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.2:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.6`,
        fs:  `cpe:2.3:a:vips:vips:7.11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.7`,
        fs:  `cpe:2.3:a:jce-tech:video_niche_script:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.8`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_fcgid:2.3.9`,
        fs:  `cpe:2.3:a:hp:release_control:9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_imap:-`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:-`,
        fs:  `cpe:2.3:a:nginx:nginx:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:0.93`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.21`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.22`,
        fs:  `cpe:2.3:a:htc:hero_software:2.31.651.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.23`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.24_01`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1296.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.25`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.26`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.27`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.28`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.29`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.9:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.30`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:08`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.3.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:09`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.51.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:10`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30244:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:11`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_idm_launcher:1.5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:12`,
        fs:  `cpe:2.3:a:phplist:phplist:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:13`,
        fs:  `cpe:2.3:h:hp:deskjet_3420_color_inkjet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:14`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:16`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:17`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.99:18`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.999`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15:exp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.999:20`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.999:21`,
        fs:  `cpe:2.3:a:openstack:swift:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:1.999:22`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:2.0.0`,
        fs:  `cpe:2.3:a:ibm:java:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:2.0.1`,
        fs:  `cpe:2.3:h:hp:8\/20q_fibre_channel_switch_16_port:ak242b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:2.0.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.409.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_perl:2.0.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.19:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:-`,
        fs:  `cpe:2.3:h:nvidia:quadro_m3000m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:1.9a`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.333:*:*:*:esr:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.2`,
        fs:  `cpe:2.3:a:citrix:presentation_server_for_windows:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.3`,
        fs:  `cpe:2.3:o:moxa:edr_g903_firmware:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.4.1`,
        fs:  `cpe:2.3:a:playscape:pets_fun_house:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.5`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:cf12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.6`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-07-07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.6.1`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.6.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5\(1\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.6.3`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:5.x-1.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.6.4`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7`,
        fs:  `cpe:2.3:h:hp:t620:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.1`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:01-03-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.2`,
        fs:  `cpe:2.3:o:ibm:xiv_storage_system_gen3_firmware:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.10:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.4`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.5`,
        fs:  `cpe:2.3:o:nec:up-ux_v:4.2mp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.6`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.7`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.8`,
        fs:  `cpe:2.3:a:heaventools:pe_explorer:1.99.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:2.7.9`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.0.1`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.0.2`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.0.3`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.1.3`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.4\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.1.4`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.2.7`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r5_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.2.8`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.2.10`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:mod_python:3.3.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.1`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.2`,
        fs:  `cpe:2.3:a:mislav_marohnic:will_paginate:3.0.1:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.450.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.4`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.5`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.5:i4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.6`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc373xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.7`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_administrator:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.8`,
        fs:  `cpe:2.3:a:mw6tech:aztec_activex_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.9`,
        fs:  `cpe:2.3:a:netjapan:tsushima_travel_guide:1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.11`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.12`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.0.13`,
        fs:  `cpe:2.3:h:huawei:5710ei:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.0`,
        fs:  `cpe:2.3:a:netiq:security_manager_reporting:6.0.0.194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.2`,
        fs:  `cpe:2.3:a:tcpdump:tcpdump:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.3`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.4`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.5`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.6`,
        fs:  `cpe:2.3:a:symantec:mail_security:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.7`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.1.8`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.1.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.2`,
        fs:  `cpe:2.3:a:isc:bind:9.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.3`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.4`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.4:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.5`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.6`,
        fs:  `cpe:2.3:a:nuance:paperport:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.7`,
        fs:  `cpe:2.3:a:exim:exim:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.9`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.10`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.64.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.11`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.12`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.2.5-50.sles10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.13`,
        fs:  `cpe:2.3:o:vmware:esx:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:1.2.14`,
        fs:  `cpe:2.3:a:trillian:trillian:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.0`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.1`,
        fs:  `cpe:2.3:a:altiris:securityexpressions:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.16b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.3`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.4`,
        fs:  `cpe:2.3:a:e107:e107:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.6`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.7`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.9`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.10`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.11`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.12`,
        fs:  `cpe:2.3:h:motorola:razr_m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.13`,
        fs:  `cpe:2.3:a:sun:one_application_server:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.14`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.15`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.16`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.17`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.18`,
        fs:  `cpe:2.3:a:unisys:enterprise_output_manager_secure_e-mail:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.19`,
        fs:  `cpe:2.3:h:hp:3com_router:jg005a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.20`,
        fs:  `cpe:2.3:a:march-hare:cvs_suite:2.5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.0.21`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.0`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.14:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.1`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1_pk5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.9_pre1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.3`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.451:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.5`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.6`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.8`,
        fs:  `cpe:2.3:a:tibco:activematrix_management_agent:1.1.0:*:*:*:*:windows_communication_foundation:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.9`,
        fs:  `cpe:2.3:a:vips:vips:7.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.10`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.11`,
        fs:  `cpe:2.3:a:nvidia:install_application:2.275.82.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.12`,
        fs:  `cpe:2.3:h:lexmark:x546:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.13`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.14`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces:2.1.15`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces_tomahawk:-`,
        fs:  `cpe:2.3:a:roderick_baier:weberknecht:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:myfaces_tomahawk:1.1.5`,
        fs:  `cpe:2.3:a:sage-mozdev:sage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:nutch:0.8.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:nutch:0.9`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:11.04`,
        fs:  `cpe:2.3:a:adobe:svg_viewer:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:11.04.01`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:11.04.02`,
        fs:  `cpe:2.3:a:nancy_wichmann:taxonomy_list:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:11.04.03`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:11.04.04`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.2.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:11.04.05`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:11.04.06`,
        fs:  `cpe:2.3:a:mcafee:dlp_agent:9.1.100.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:12.04`,
        fs:  `cpe:2.3:a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:12.04.01`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:12.04.02`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:12.04.03`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:12.04.04`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:12.04.06`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:13.07`,
        fs:  `cpe:2.3:a:scilab:scilab:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:13.07.01`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg237a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ofbiz:13.07.03`,
        fs:  `cpe:2.3:a:wali:walisms_cn:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:-`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:09.04`,
        fs:  `cpe:2.3:a:symantec:product_authentication_service_client:4.3.28.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:09.04.01`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:10.04`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:10.04.01`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7970g:8.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:10.04.02`,
        fs:  `cpe:2.3:o:cisco:staros:12.2\(300\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:10.04.03`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:10.04.04`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:10.04.05`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:11.04.01`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.0\(2.48\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:11.04.02`,
        fs:  `cpe:2.3:h:hp:jc808a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:open_for_business_project:12.04.01`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.0.0`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.0.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)xz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.0.3`,
        fs:  `cpe:2.3:a:roriis.codeplex.com:rails_for_iis_fast-cgi:1.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.0.4`,
        fs:  `cpe:2.3:a:sixnet:sixview_manager:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.1.0`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.2.0`,
        fs:  `cpe:2.3:a:rpm:rpm:4.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.2.1`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:1.2.2`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:2.0.0`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:2.0.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.9.4:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:2.1.0`,
        fs:  `cpe:2.3:a:mozilla:bonsai:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:2.1.1`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:11.03.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:2.2.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openjpa:2.2.1`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openmeetings:3.1.1`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.5.0`,
        fs:  `cpe:2.3:a:oracle:siebel_suite:7.8.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.5.1`,
        fs:  `cpe:2.3:a:humhub:humhub:0.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.5.2`,
        fs:  `cpe:2.3:a:ibm:security_guardium:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.5.3`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.6.0`,
        fs:  `cpe:2.3:a:intel:inbusiness_email_station:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.7.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.7.1`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:3.6\(10\):es01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.7.2`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.8.0`,
        fs:  `cpe:2.3:a:microsoft:word:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opennlp:1.8.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice:4.0.0`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice:4.0.1`,
        fs:  `cpe:2.3:a:koha:koha:3.20.00:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice:4.1.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.02.248:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice:4.1.1`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice:4.1.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice.org:3.2.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice.org:3.2.1`,
        fs:  `cpe:2.3:a:microsoft:system_center_configuration_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice.org:3.3.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice.org:3.4:beta`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice.org:3.4:beta_1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice.org:3.4.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice.org:3.4.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.00:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:openoffice.org:4.0`,
        fs:  `cpe:2.3:h:schneider_electric:struxureware_building_operations_automation_server_as:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opentaps:-`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:opentaps:0.9.3`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:org.apache.sling.servlets.post:2.1.0`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:org.apache.sling.servlets.post:2.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xm7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:org.apache.sling.servlets.post:2.2.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:org.apache.sling.servlets.post:2.3.0`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-3:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.1`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.2`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.5`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:11.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.6`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.7`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.8`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.9`,
        fs:  `cpe:2.3:a:nancy_wichmann:announcements:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.10`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:1.8.11`,
        fs:  `cpe:2.3:h:cisco:secure_pix_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:2.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.339:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:2.0:rc1`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:2.0:rc2`,
        fs:  `cpe:2.3:a:skype:skype:0.90.0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:pdfbox:2.0:rc3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.2`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.3`,
        fs:  `cpe:2.3:a:systemtools:hyena:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.4`,
        fs:  `cpe:2.3:a:ucweb:uc_browser:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.5`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je072a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.6`,
        fs:  `cpe:2.3:a:netwitness:netwitness_investigator:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.7`,
        fs:  `cpe:2.3:o:y-cam:ycw004_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.10.0`,
        fs:  `cpe:2.3:o:siemens:synco_ozw_web_server_firmware:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.11.0`,
        fs:  `cpe:2.3:o:google:android:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.12.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.13.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:0.14.0`,
        fs:  `cpe:2.3:a:utorrent:utorrent:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.0.0`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.0.1`,
        fs:  `cpe:2.3:a:apache:xerces2_java:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.0.2`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.1.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.2.0`,
        fs:  `cpe:2.3:a:libraw:libraw:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.5`,
        fs:  `cpe:2.3:a:autodesk:survey:2006:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.5.1`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.7:dev`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.8:dev`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.4.1.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:1.10:dev`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_101:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:2.0`,
        fs:  `cpe:2.3:a:ibm:java:6.0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:2.0:pre1`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:2.0:pre2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.409.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:2.0:pre3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:2.0:rc1`,
        fs:  `cpe:2.3:a:autodesk:autocad:2007:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:2.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(3.4\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:2.5`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:2.5.1`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.0`,
        fs:  `cpe:2.3:a:apple:iphoto:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.0:alpha1`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.0:alpha2`,
        fs:  `cpe:2.3:o:apple:a_ux:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.0:alpha3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.0.1`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.0.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.0.2:beta1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.0.2:beta2`,
        fs:  `cpe:2.3:o:microsoft:windows_rt:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.1:beta1`,
        fs:  `cpe:2.3:a:adobe:connect:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.1:beta2`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.2`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.5.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.5`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.5:beta1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.5:beta2`,
        fs:  `cpe:2.3:a:gajim:gajim:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.5:beta3`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.0\(0\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.5:beta4`,
        fs:  `cpe:2.3:a:microsoft:jscript:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.5:beta5`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:4.0.1.4502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.5:beta6`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.6`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.0.7:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.7`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.7:beta1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.7:beta2`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.7:beta3`,
        fs:  `cpe:2.3:a:adobe:camera_raw:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.8:beta1`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.8:beta2`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.8:beta3`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.621:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.8:beta4`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.8:beta5`,
        fs:  `cpe:2.3:h:iij:seil_x2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.9`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.10`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.10:beta1`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.10:beta2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.11:beta1`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller:1.0\(1k\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:poi:3.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.5`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.6`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.328:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.7`,
        fs:  `cpe:2.3:a:vips:vips:7.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.8`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.9`,
        fs:  `cpe:2.3:a:ca:desktop_protection_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.10`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.11`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.12`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.13`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.14`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.15`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.16`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:rc.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.17`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.19`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.1.1:*:*:*:*:wotlab_burning_board:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.20`,
        fs:  `cpe:2.3:a:adobe:creative_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.22`,
        fs:  `cpe:2.3:a:rpm:rpm:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid:0.30`,
        fs:  `cpe:2.3:a:sap:netweaver_development_infrastructure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:qpid_java:6.0.2`,
        fs:  `cpe:2.3:h:juniper:router_m20:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ranger:0.4.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ranger:0.5.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ranger:0.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2mx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ranger:0.5.2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ranger:0.5.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:ranger:0.6.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.11`,
        fs:  `cpe:2.3:a:ups:worldship_msichecker:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.12`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:11.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.13`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.14`,
        fs:  `cpe:2.3:o:openbsd:openbsd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.15`,
        fs:  `cpe:2.3:a:gecad:axigen_free_mail_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.16`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.17`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.18`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.19`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:rave:0.20`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(4\)m12a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.5`,
        fs:  `cpe:2.3:a:ca:etrust_siteminder_policy_server:12.0.102.414:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.6`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.6.3`,
        fs:  `cpe:2.3:a:rockwellautomation:rslogix_5000_design_and_configuration_software:20.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.6.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.7.1`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:564:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.7.2`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.8`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.8.1`,
        fs:  `cpe:2.3:o:google:chrome_os:0.10.140.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.8.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:0.9.9`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.0`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.0:rc1`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.0:rc2`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.0.1`,
        fs:  `cpe:2.3:a:apache:traffic_server:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.1`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.1.1`,
        fs:  `cpe:2.3:a:google:toolbar:5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.1.2`,
        fs:  `cpe:2.3:a:qemu:qemu:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.2`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:1.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:2.0`,
        fs:  `cpe:2.3:a:digium:asterisk:c:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:2.0.1`,
        fs:  `cpe:2.3:a:ibm:java:6.0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:2.0.2`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:2.1`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:2.1.1`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:2.3`,
        fs:  `cpe:2.3:a:uiu4you:universal_imaging_utility:3.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:3.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4501_series_software:4.1\(1.51\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:3.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:4.0`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.5.3:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:4.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:5.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:5.0.1`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:roller:5.0.2`,
        fs:  `cpe:2.3:a:oracle:reports:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:santuario_xml_security_for_java:2.0.0`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:santuario_xml_security_for_java:2.0.1`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:santuario_xml_security_for_java:2.0.2`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:sentry:1.5.1`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:sentry:1.6.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:shindig:2.5.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:shiro:1.2.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:shiro:1.3.1`,
        fs:  `cpe:2.3:o:dlink:des-3800_firmware:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:sling:-`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:sling_auth_core_component:1.0.2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:264:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:sling_auth_core_component:1.0.4`,
        fs:  `cpe:2.3:o:cisco:catos:6.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:sling_auth_core_component:1.0.6`,
        fs:  `cpe:2.3:a:jason_a_donenfeld:cgit:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:sling_auth_core_component:1.1.0`,
        fs:  `cpe:2.3:a:cybozu:garoon:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:sling_auth_core_component:1.1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:3.6.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:3.6.1`,
        fs:  `cpe:2.3:a:qemu:qemu:0.11.0-rc0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:3.6.2`,
        fs:  `cpe:2.3:a:spi\/si263b:message_classification:2.2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.0.0`,
        fs:  `cpe:2.3:a:microsoft:office_word_viewer:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.0.0:alpha`,
        fs:  `cpe:2.3:a:macromedia:director:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.0.0:beta`,
        fs:  `cpe:2.3:a:openx:openx:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.2.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.2.1`,
        fs:  `cpe:2.3:a:adobe:fireworks_mx:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.3.0`,
        fs:  `cpe:2.3:h:hp:service_manager:9.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.3.1`,
        fs:  `cpe:2.3:a:gizra:og_vocab:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.4.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.5.0`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.54:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.5.1`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.6.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.6.1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.7.0`,
        fs:  `cpe:2.3:a:apache:tomcat:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.7.1`,
        fs:  `cpe:2.3:a:qemu:qemu:0.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.7.2`,
        fs:  `cpe:2.3:h:huawei:5310ei:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.8.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.8.1`,
        fs:  `cpe:2.3:h:apple:imac:m9250xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.9.0`,
        fs:  `cpe:2.3:a:ssh:secure_shell_for_servers:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.9.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.565.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.10.0`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.10.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:4.10.2`,
        fs:  `cpe:2.3:o:netbsd:netbsd:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.0`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.1`,
        fs:  `cpe:2.3:a:bradfordnetworks:network_sentry_appliance_software:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.2.1`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.3`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.3.0`,
        fs:  `cpe:2.3:a:isc:bind:9.6.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.3.1`,
        fs:  `cpe:2.3:a:cisco:peap_module:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.3.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.4.1`,
        fs:  `cpe:2.3:a:redhat:application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.5.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.5.1`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.5.2`,
        fs:  `cpe:2.3:a:microsoft:ie:5.50.4134.0600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.5.3`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.6.100.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:5.5.4`,
        fs:  `cpe:2.3:a:hp:toolbox:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.0.0`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.0.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.3.6219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.1.0`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.2.0`,
        fs:  `cpe:2.3:a:tibco:spotfire_automation_services:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.2.1`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:2.0.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.3.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.4.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.4.1`,
        fs:  `cpe:2.3:a:ibm:b2b_advanced_communications:1.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.4.2`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.5.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:solr:6.5.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:3.0.1`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:3.0.2`,
        fs:  `cpe:2.3:a:apache:struts:1.1:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:3.0.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:3.0.4`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:3.1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:3.1.1`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.2.1:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:3.1.2`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:spamassassin:3.1.7`,
        fs:  `cpe:2.3:a:intel:proset_wireless:12.4.3000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:standard_taglibs:1.2.1`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.23:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:storm:0.9.0.1`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:storm:0.10.0:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7\)ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:storm:1.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:storm:1.0.1`,
        fs:  `cpe:2.3:a:oscommerce:online_merchant:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:storm:1.0.2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:storm:1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:storm:1.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:-`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.0`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.0.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1670.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.1`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.1:b1`,
        fs:  `cpe:2.3:a:hp:universal_configuration_management_database:10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.1:b2`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.1:b3`,
        fs:  `cpe:2.3:h:linksys:wrt54g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.1:rc1`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.1:rc2`,
        fs:  `cpe:2.3:a:otrs:otrs:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.2.2`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.2.4`,
        fs:  `cpe:2.3:o:juniper:junos:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.2.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.2.7`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.2.8`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.2.9`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.3.5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.3.8`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-2500c_firmware:t380sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:1.3.10`,
        fs:  `cpe:2.3:a:apache:solr:4.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.1`,
        fs:  `cpe:2.3:a:altiris:console_language_pack:6.5.1144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.3`,
        fs:  `cpe:2.3:a:gnu:emacs:21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.5`,
        fs:  `cpe:2.3:o:sun:sunos:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.6`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.7`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.8`,
        fs:  `cpe:2.3:a:op5:monitor:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.9`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.10:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.10`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.11`,
        fs:  `cpe:2.3:a:hp:web_registration:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.11.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.11.2`,
        fs:  `cpe:2.3:o:cisco:ios:11.2sa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.12`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.13`,
        fs:  `cpe:2.3:a:bowenehs:cih_quiz_game:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.0.14`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.00.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.1`,
        fs:  `cpe:2.3:a:apple:safari:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.2`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.3`,
        fs:  `cpe:2.3:a:altiris:deployment_web_console:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.4`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.5`,
        fs:  `cpe:2.3:a:plumtree:logging_utilities:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.6`,
        fs:  `cpe:2.3:a:apache:axis2:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.8`,
        fs:  `cpe:2.3:a:emc:eroom:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.1.8.1`,
        fs:  `cpe:2.3:a:cyrus:imap:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.2.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.22.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.2.1.1`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.2.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.614:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.2.3.1`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:5.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.1.1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.1.2`,
        fs:  `cpe:2.3:a:libav:libav:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.4.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.5`,
        fs:  `cpe:2.3:a:citrix:license_server_administration:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.6`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.7`,
        fs:  `cpe:2.3:h:sony:snc_dh240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.9`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.10`,
        fs:  `cpe:2.3:a:apache:struts:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.11`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.12`,
        fs:  `cpe:2.3:a:linuxcontainers:cgmanager:0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.13`,
        fs:  `cpe:2.3:h:juniper:srx240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.14`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.14.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.14.2`,
        fs:  `cpe:2.3:a:ati:control_panel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.14.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.15`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.15.1`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_update_service:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.15.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.15.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.16`,
        fs:  `cpe:2.3:o:juniper:junos:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.16.1`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.16.2`,
        fs:  `cpe:2.3:a:apache:axis2:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.16.3`,
        fs:  `cpe:2.3:a:altiris:application_management_language_pack:6.1.4082:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.17`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.19`,
        fs:  `cpe:2.3:a:sun:java_web_start:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.20`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.20.1`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_secureclient:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.20.2`,
        fs:  `cpe:2.3:a:ipswitch:imserver:2.0.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.21`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.22`,
        fs:  `cpe:2.3:a:samba:samba:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.23`,
        fs:  `cpe:2.3:a:location_module_project:location:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.24.2`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:52.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.24.3`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.25`,
        fs:  `cpe:2.3:h:tp-link:tl-sc3171g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.26`,
        fs:  `cpe:2.3:a:schedmd:slurm:17.02.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.27`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.28`,
        fs:  `cpe:2.3:a:paymentsplus:payments_plus:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.28.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.30`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.31`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.32`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.3.33`,
        fs:  `cpe:2.3:a:schneider-electric:interactive_graphical_scada_system:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5`,
        fs:  `cpe:2.3:a:isc:bind:9.5.3:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5:beta1`,
        fs:  `cpe:2.3:o:apple:watchos:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5:beta2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5:beta3`,
        fs:  `cpe:2.3:a:umn:mapserver:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.1`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.3`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpx\/epx2203c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.4`,
        fs:  `cpe:2.3:a:nng:naviextras_toolbox_prerequesities:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.5`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.6`,
        fs:  `cpe:2.3:a:dell:system_e-support_tool:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.7`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.8`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.9`,
        fs:  `cpe:2.3:a:sybase:easerver:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.10`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.11`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.13`,
        fs:  `cpe:2.3:a:autonomy:keyview_export_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.14`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.409:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.15`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.3\(1\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.16`,
        fs:  `cpe:2.3:a:gnu:glibc:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.17`,
        fs:  `cpe:2.3:a:citrix:cloudportal_services_manager:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.18`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.19`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.20`,
        fs:  `cpe:2.3:h:cisco:unified_contact_center_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.21`,
        fs:  `cpe:2.3:o:supermicro:intelligent_platform_management_firmware:3.15:-:-:*:-:-:x9_generation_motherboards:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.22`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.23`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)st6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.24`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.25`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:8.0.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.26`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.27`,
        fs:  `cpe:2.3:a:lightscribe:lightscribe:1.6.43.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.28`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.29`,
        fs:  `cpe:2.3:a:tribiq:tribiq_cms:5.0.9:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.30`,
        fs:  `cpe:2.3:a:xiph:icecast:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.31`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.32`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts:2.5.33`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts2-showcase:2.0.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:struts2-showcase:2.3.13`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.6`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.7`,
        fs:  `cpe:2.3:a:apache:subversion:0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.9`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:4.1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.10.0`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux_corporate_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.10.1`,
        fs:  `cpe:2.3:h:linksys:befsru31:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.10.2`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.11.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.12.0`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_sprint_wifi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.13.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p135:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.13.1`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:9.1:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.13.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.14.0`,
        fs:  `cpe:2.3:a:unisys:enterprise_output_manager_service:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.14.1`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.14.2`,
        fs:  `cpe:2.3:a:quest:installer_logging:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.14.3`,
        fs:  `cpe:2.3:a:divx:web_player:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.14.4`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.14.5`,
        fs:  `cpe:2.3:a:nokia:affix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.15`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.16`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_endp:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.16.1`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.6.0.1347:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.17.0`,
        fs:  `cpe:2.3:a:boeing:imis_message_system_rabbit:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.17.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.18.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.18.1`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.19.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.19.1`,
        fs:  `cpe:2.3:a:redmine:redmine:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.20.0`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.20.1`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.21.0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.1:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.22.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.22.1`,
        fs:  `cpe:2.3:a:adobe:photoshop:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.22.2`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.23.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp2:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.24.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.24.1`,
        fs:  `cpe:2.3:a:kajona:kajona:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.24.2`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.25.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.26.0`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.27.0`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.28.0`,
        fs:  `cpe:2.3:a:apple:apple_tv:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.28.1`,
        fs:  `cpe:2.3:a:videowhisper:live_streaming_integration_plugin:4.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.28.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je045a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.29.0`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.30.0`,
        fs:  `cpe:2.3:a:opnet:ace_analyst:15.0.0.8631:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.31.0`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.32.1`,
        fs:  `cpe:2.3:a:kajona:kajona:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.33.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p186:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.33.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2.8.225.2152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.34.0`,
        fs:  `cpe:2.3:h:hp:0235a31q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.35.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.35.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:10.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.36.0`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:0.37.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.0`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.1`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.2`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.3`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.3:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.4`,
        fs:  `cpe:2.3:a:redhat:gdk_pixbuf:0.18.0-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1687.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.6`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.7`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.8`,
        fs:  `cpe:2.3:a:oracle:sysfw:8.0.3:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.0.9`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.1.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/e:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.1.1`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.1.2`,
        fs:  `cpe:2.3:a:diziturky:diziturky_hd_2015:2014:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.1.3`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.1.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.2.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.2.1`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.18.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.2.2`,
        fs:  `cpe:2.3:a:novell:bordermanager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.2.3`,
        fs:  `cpe:2.3:a:e107:e107:0.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.3.0`,
        fs:  `cpe:2.3:a:drupal:drupal:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.3.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.3.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_unified_software:1.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.4.0`,
        fs:  `cpe:2.3:a:keepass:keepass:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.4.1`,
        fs:  `cpe:2.3:o:raritan:px:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.4.2`,
        fs:  `cpe:2.3:a:vmware:tools:3.1.2.12548:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.4.3`,
        fs:  `cpe:2.3:a:apple:weblog_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.4.4`,
        fs:  `cpe:2.3:a:oleggo_livestream_project:oleggo_livestream:0.2.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.4.6`,
        fs:  `cpe:2.3:a:webyog:sqlyog:2.5:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.2`,
        fs:  `cpe:2.3:a:novell:imanager:2.7.3:ftf4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.3`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.4`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.5`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.6`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.0p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.7`,
        fs:  `cpe:2.3:a:busybox:busybox:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.5.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.0`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.2`,
        fs:  `cpe:2.3:a:marksdailyapple:mark\&#39;s_daily_apple_forum:2.9.4.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.3`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.4`,
        fs:  `cpe:2.3:a:hp:hpssupply:100.0.172.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.5`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.6`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.7`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.8`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.9`,
        fs:  `cpe:2.3:a:compaq:web-enabled_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.10`,
        fs:  `cpe:2.3:o:cisco:asa_with_firepower_services:5.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.11`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2010.211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.12`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.08.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.13`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.14`,
        fs:  `cpe:2.3:a:hp:status:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.15`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.16`,
        fs:  `cpe:2.3:a:cisco:trust_agent:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.17`,
        fs:  `cpe:2.3:a:osticket:osticket:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.18`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.19`,
        fs:  `cpe:2.3:a:oracle:applications_framework:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.20`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.05.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.21`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.6.23`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.1`,
        fs:  `cpe:2.3:a:arellia:arellia_file_inventory_language_pack:6.1.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.2`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.4.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.b02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.6`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.7`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.8`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:1.0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.9`,
        fs:  `cpe:2.3:a:civicrm:civicrm_private_report:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.10`,
        fs:  `cpe:2.3:a:dell:openmanage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.11`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.12`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.13`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.02:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.14`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.15`,
        fs:  `cpe:2.3:a:clausmuus:spitfire:1.0436:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.16`,
        fs:  `cpe:2.3:o:cisco:catos:6.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.17`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns8200rx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.18`,
        fs:  `cpe:2.3:o:cisco:ios:12.4jdc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.19`,
        fs:  `cpe:2.3:a:apache:subversion:0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.7.20`,
        fs:  `cpe:2.3:a:huawei:vcn500:v100r002c00spc200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.0`,
        fs:  `cpe:2.3:o:novell:opensuse:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.1`,
        fs:  `cpe:2.3:a:citadel:ux:6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.2`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.3`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.4`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.7.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p194:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.6`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.7`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.8`,
        fs:  `cpe:2.3:a:gentoo:poppassd_pam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.9`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.10`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.11`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:5.0.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.12`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1sg.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.13`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.14`,
        fs:  `cpe:2.3:a:apache:struts:2.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.15`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.8.18`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.9.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.5.0.7220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.9.1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.507.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.9.2`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.9.3`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:9.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.9.4`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.9.5`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.9.6`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.10.0`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.5.1:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.10.0:alpha1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.30.186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.10.0:alpha2`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer_with_flow_analytics_module:8.6.2:-:pay:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:1.10.0:alpha3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.611:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:m1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:m2`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:m3`,
        fs:  `cpe:2.3:a:freedomscientific:jaws:11.0.756.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:subversion:m4%2fm5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:synapse:1.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5_1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:synapse:1.1`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:synapse:1.1.1`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:synapse:1.1.2`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:synapse:1.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:7.0.0:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:synapse:2.0.0`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.03.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:synapse:2.1.0`,
        fs:  `cpe:2.3:a:oracle:odac_documentation_for_visual_studio_2010:11.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:synapse:3.0.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.0`,
        fs:  `cpe:2.3:a:theforeman:foreman:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.0:rc2`,
        fs:  `cpe:2.3:a:apache:tomcat:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.0:rc3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.3`,
        fs:  `cpe:2.3:a:oracle:javafx:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.4`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.5`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.2\(1\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.6`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.7`,
        fs:  `cpe:2.3:a:google:chrome:4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.0.9`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:9.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.2`,
        fs:  `cpe:2.3:o:f5:tmos:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.3`,
        fs:  `cpe:2.3:a:adobe:fireworks_mx:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.4`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.5`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.7`,
        fs:  `cpe:2.3:a:apple:apple_tv:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:syncope:1.1.8`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tika:1.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(15\)md:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tika:1.13`,
        fs:  `cpe:2.3:a:bbs_technologies:sharepoint_security_manager:3.50.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:-`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:1.1.3`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.347.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.1.1`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.2`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.2.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.2.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.2.2:beta2`,
        fs:  `cpe:2.3:a:microsoft:ie:4.72.2106.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.2.3`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:7.30.020.3852:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.2.4`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.3`,
        fs:  `cpe:2.3:a:sap:enterprise_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.3.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.4:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.3.1a`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:3.3.2`,
        fs:  `cpe:2.3:a:hp:photosmart_essential:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4`,
        fs:  `cpe:2.3:a:apple:iphoto:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.0.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1055.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.0.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.33:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.0.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.0.4`,
        fs:  `cpe:2.3:a:zend:zendservice_audioscrobbler:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.0.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.0.6`,
        fs:  `cpe:2.3:a:debian:apt:0.7.15:exp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.327.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.335.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.2`,
        fs:  `cpe:2.3:a:libav:libav:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.3:beta`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.2.103.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.9:beta`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.246.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.10`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.110.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.12`,
        fs:  `cpe:2.3:a:clearone:converge_console:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.24`,
        fs:  `cpe:2.3:h:huawei:ar120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.28`,
        fs:  `cpe:2.3:a:gnome:glib:2.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.29`,
        fs:  `cpe:2.3:a:juniper:netscreen-security_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.31`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:4.1.36`,
        fs:  `cpe:2.3:a:avast:endpoint_protection_plus:8.0.1609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.2`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.3`,
        fs:  `cpe:2.3:a:google:chrome:17.0.925.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.4`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc3212:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.5`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.7`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.9`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_task_server:6.0.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.10`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.11`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.12`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r005c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.13`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(1x\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.14`,
        fs:  `cpe:2.3:a:symantec:message_gateway_for_service_providers:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.15`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.16`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.17`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_standalone:4.3.0.292238:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.18`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.19`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.21`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.20:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.22`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.23`,
        fs:  `cpe:2.3:a:izarc:izarc:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.24`,
        fs:  `cpe:2.3:a:ibm:websphere_extended_deployment_compute_grid:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.25`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.26`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.27`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\)eb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.28`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.29`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6ecb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.0.30`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.580:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.0`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.66:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.1`,
        fs:  `cpe:2.3:a:invensys:wonderware_information_server:5.0:-:portal:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.2`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.4`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.5`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.831:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.6`,
        fs:  `cpe:2.3:a:zemanta:related_posts:2.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.7`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.8`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.3:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.9`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.10`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.11`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.12`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.13`,
        fs:  `cpe:2.3:a:apache:cocoon:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.14`,
        fs:  `cpe:2.3:a:securecomputing:sidewinder_g2_admin_console:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.15`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.16`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.17`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.19`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je095a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.20`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:9.1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.21`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.22`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.23`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.24`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.25`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.26`,
        fs:  `cpe:2.3:a:altiris:script_task:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.27`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.28`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.29`,
        fs:  `cpe:2.3:a:ember-entertainment:towers_n\&#39;_trolls:1.6.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.30`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.31`,
        fs:  `cpe:2.3:a:securityinnovation:ntru_hybrid_tss:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.32`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.33`,
        fs:  `cpe:2.3:o:cisco:staros:18.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.34`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:8.1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:5.5.35`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.5en:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6`,
        fs:  `cpe:2.3:o:moxa:miineport_e1_4641_firmware:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.0`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.5.0:*:ja:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.0:alpha`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.1:alpha`,
        fs:  `cpe:2.3:a:isc:bind:8.2.3_t1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.2`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.2:alpha`,
        fs:  `cpe:2.3:o:google:chrome_os:8.0.552.343:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.2:beta`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.3`,
        fs:  `cpe:2.3:o:oracle:linux:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.4`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:6.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.4:alpha`,
        fs:  `cpe:2.3:a:cisco:customer_response_solutions:6.0.1068.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.5`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.6`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.6:alpha`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.7`,
        fs:  `cpe:2.3:o:cisco:catos:6.4\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.7:alpha`,
        fs:  `cpe:2.3:a:nortel:meridian_option_61c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.7:beta`,
        fs:  `cpe:2.3:a:apache:hive:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.8`,
        fs:  `cpe:2.3:a:tribiq:tribiq_cms:5.0.10b:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.8:alpha`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.9`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.9:beta`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.10`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.18:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.11`,
        fs:  `cpe:2.3:a:dell:client_configuration_toolkit:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.12`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.13`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.14`,
        fs:  `cpe:2.3:a:photocati_media:photocrati:4.07:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.15`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.16`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.17`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.18`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.2.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.19`,
        fs:  `cpe:2.3:a:perl:perl:5.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.20`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.21`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.22`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.23`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:1.0.2345.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.24`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.25`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.26`,
        fs:  `cpe:2.3:a:plone:plone:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.27`,
        fs:  `cpe:2.3:a:digium:asterisk:11.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.28`,
        fs:  `cpe:2.3:a:bradfordnetworks:network_sentry_appliance_software:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.29`,
        fs:  `cpe:2.3:o:blackberry:qnx_neutrino_rtos:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.30`,
        fs:  `cpe:2.3:a:apache:poi:3.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.31`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.32`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.33`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.34`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.35`,
        fs:  `cpe:2.3:a:powerarchiver:powerarchiver:14.02.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.36`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.37`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.2.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.38`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.40`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.5.905.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.41`,
        fs:  `cpe:2.3:a:bluecoat:content_analysis_system_software:1.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.42`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.43`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.44`,
        fs:  `cpe:2.3:a:adobe:color_extra_settings:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.45`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.46`,
        fs:  `cpe:2.3:a:pgp:desktop_security:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.47`,
        fs:  `cpe:2.3:a:oracle:hyperion_production_reporting_server:11.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.48`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.49`,
        fs:  `cpe:2.3:a:degraaff:checkbot:1.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.50`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.51`,
        fs:  `cpe:2.3:a:narr8:secret_city_-_motion_comic:2.1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:6.0.52`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.0:beta`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.2`,
        fs:  `cpe:2.3:a:wave:private_information_manager:7.0.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.2:beta`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.4`,
        fs:  `cpe:2.3:h:cisco:guard_ddos_mitigation_appliance:5.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.4:beta`,
        fs:  `cpe:2.3:a:digium:asterisk:11.23.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.5`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.5:beta`,
        fs:  `cpe:2.3:a:hp:mercury_loadrunner_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.7`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.8`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.9`,
        fs:  `cpe:2.3:a:apple:apple_tv:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.10`,
        fs:  `cpe:2.3:a:ibm:net.commerce:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.11`,
        fs:  `cpe:2.3:a:fileopen:fileopen_client:3.0.67.914:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.12`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.13`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.14`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.15`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.16`,
        fs:  `cpe:2.3:a:bestpractical:rtfm:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.17`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.18`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.602:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.19`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.20`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.21`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.22`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20050410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.23`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.24`,
        fs:  `cpe:2.3:a:devsaran:fresh:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.25`,
        fs:  `cpe:2.3:a:adobe:air:20.0.0.233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.26`,
        fs:  `cpe:2.3:a:seeddms:seeddms:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.27`,
        fs:  `cpe:2.3:o:microsoft:windows_10:-:gold:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.28`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.29`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.30`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.31`,
        fs:  `cpe:2.3:o:yahama:rt56v:4.07.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.32`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.33`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.34`,
        fs:  `cpe:2.3:h:cisco:ubr10012:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.35`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.36`,
        fs:  `cpe:2.3:h:intel:express_510t:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.37`,
        fs:  `cpe:2.3:h:xerox:document_centre_555:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.38`,
        fs:  `cpe:2.3:a:sun:one_directory_server:4.16:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.39`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.40`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.41`,
        fs:  `cpe:2.3:a:hp:vertica:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.42`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.43`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.44`,
        fs:  `cpe:2.3:a:hp:openview_cross_platform_component:3.10.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.45`,
        fs:  `cpe:2.3:a:hp:rapid_deployment_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.46`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:1.9.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.47`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.48`,
        fs:  `cpe:2.3:a:divx:player:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.49`,
        fs:  `cpe:2.3:a:kerio:control:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.50`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.0.43:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.51`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.54`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.1.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.55`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.187:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.56`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.57`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.58`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.59`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.60`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.61`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.62`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.63`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(4g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.64`,
        fs:  `cpe:2.3:a:intel:network_connections:16.6.126.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.65`,
        fs:  `cpe:2.3:a:solarwinds:collector:2.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.66`,
        fs:  `cpe:2.3:a:norman:security_suite:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.67`,
        fs:  `cpe:2.3:a:google:chrome:11.0.672.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.68`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.69`,
        fs:  `cpe:2.3:a:ibm:u2_universe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.70`,
        fs:  `cpe:2.3:o:freebsd:freebsd:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.71`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.72`,
        fs:  `cpe:2.3:a:ibm:sametime:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.73`,
        fs:  `cpe:2.3:a:unisys:sentinel_alert_service:9.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.74`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.75`,
        fs:  `cpe:2.3:a:symantec:norton_security_scan:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.76`,
        fs:  `cpe:2.3:a:apache:roller:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.77`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.79`,
        fs:  `cpe:2.3:h:lexmark:cs820de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.80`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:7.0.81`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.0:rc1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.0:rc10`,
        fs:  `cpe:2.3:o:novell:opensuse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.0:rc2`,
        fs:  `cpe:2.3:a:reviewboard:djblets:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.0:rc5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.1`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.7:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.2`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.6.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.4`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.6`,
        fs:  `cpe:2.3:h:dell:poweredge_sc1435:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.7`,
        fs:  `cpe:2.3:a:herpin_time_radio_project:herpin_time_radio:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.9`,
        fs:  `cpe:2.3:a:perl:perl:5.12.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.10`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.11`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.12`,
        fs:  `cpe:2.3:o:huawei:s9312_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.13`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.4:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.14`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.15`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.16`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r75.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.17`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zj3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.18`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.20`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.21`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.22`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.23`,
        fs:  `cpe:2.3:a:cisco:evolved_programmable_network_manager:1.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.24`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.25`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.26`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:b.03.00.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.27`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.26:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.28`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.30`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.22:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.31`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.32`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050526:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.33`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.34`,
        fs:  `cpe:2.3:a:bestsoftinc:advance_hotel_booking_system:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.35`,
        fs:  `cpe:2.3:h:iss:proventia_server:1.0.914.1880:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.36`,
        fs:  `cpe:2.3:a:mit:kerberos:5_1.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.37`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.38`,
        fs:  `cpe:2.3:a:tenable:nessus:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.39`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.40`,
        fs:  `cpe:2.3:h:rockwellautomation:1769_compactlogix_5370_l2_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.41`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.42`,
        fs:  `cpe:2.3:a:macromedia:extension_manager:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.0.43`,
        fs:  `cpe:2.3:a:git-scm:git:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.0`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.2`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.3`,
        fs:  `cpe:2.3:a:vmware:vcenter_server_appliance:5.0:update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.4`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(15a\)p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.5`,
        fs:  `cpe:2.3:a:hummingbird:cyberdocs:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.6`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.7`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.9`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.20:sp01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.10`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.11`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.12`,
        fs:  `cpe:2.3:a:quest:benchmark_factory_for_databases:5.8.1.571:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.13`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:8.5.14`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.33.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m1`,
        fs:  `cpe:2.3:h:d-link:dir-619l:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m10`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m11`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1077.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m12`,
        fs:  `cpe:2.3:a:wdc:smartware:1.3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m13`,
        fs:  `cpe:2.3:a:avsmedia:dvdmenu_editor:1.2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m14`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7940g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m15`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m16`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m17`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m18`,
        fs:  `cpe:2.3:a:yard_radius_project:yard_radius:1.1.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m19`,
        fs:  `cpe:2.3:a:phorum:phorum:5.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m2`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m20`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m4`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m5`,
        fs:  `cpe:2.3:a:janrain:ruby-openid:2.2.3:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m6`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m7`,
        fs:  `cpe:2.3:a:cisco:desktop_administrator:80.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m8`,
        fs:  `cpe:2.3:a:vmware:infrastructure:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat:9.0.0:m9`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat_connectors:1.2.40`,
        fs:  `cpe:2.3:a:drupal:drupal:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat_jk_web_server_connector:-`,
        fs:  `cpe:2.3:o:oracle:linux:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat_jk_web_server_connector:1.2.19`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat_jk_web_server_connector:1.2.20`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomcat_jk_web_server_connector:1.2.22`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:tomee:-`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.0.0`,
        fs:  `cpe:2.3:o:moxa:edr_g903_firmware:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.0.0:alpha`,
        fs:  `cpe:2.3:a:cmsdevelopment:business_card_web_builder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.0.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.0`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.1`,
        fs:  `cpe:2.3:a:gnu:glibc:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.7.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.3`,
        fs:  `cpe:2.3:a:no-margin-for-errors:prettyphoto:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.4`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x51:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.5`,
        fs:  `cpe:2.3:o:cisco:catos:7.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.6`,
        fs:  `cpe:2.3:a:ooorl_project:ooorl:-:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.7`,
        fs:  `cpe:2.3:a:nullsoft:winamp:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.8`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(5\)sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:2.1.9`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.0.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.0.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.0.2`,
        fs:  `cpe:2.3:h:arris:touchstone_tg862g\/ct:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.0.3`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.0.4`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.1.0`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.1.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.1.2`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.1.3`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.1.4`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.2.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.3.0`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.3.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.3.2`,
        fs:  `cpe:2.3:a:smartsound:quicktracks:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.3.3`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.3.4`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:3.3.5`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:4.0.1`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:4.1.0`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:4.2.0`,
        fs:  `cpe:2.3:a:totalseminars:a\&#43;_2006_demo:4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:4.2.1`,
        fs:  `cpe:2.3:a:rockwellautomation:1763-l16bwa_series_a:15.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:4.2.1.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:5.0.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:5.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:5.1.1`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.4:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:5.3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:5.3.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:6.0.0`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:6.1.0`,
        fs:  `cpe:2.3:a:drupal:drupal:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:6.1.1`,
        fs:  `cpe:2.3:a:apache:wink:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:traffic_server:6.2.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.0`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.1`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.39:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.2`,
        fs:  `cpe:2.3:a:oracle:developer_suite:9.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.3`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.4`,
        fs:  `cpe:2.3:a:apache:axis:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.5`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.6`,
        fs:  `cpe:2.3:a:gajim:gajim:0.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.7`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.9`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1672.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.10`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)xn1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.12`,
        fs:  `cpe:2.3:a:profile2_privacy_project:profile2_privacy:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.13`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.14`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.15`,
        fs:  `cpe:2.3:a:macromedia:shockwave_flash_plugin:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.16`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.17`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.18`,
        fs:  `cpe:2.3:a:digium:asterisk:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.19`,
        fs:  `cpe:2.3:a:teradata:shared_icu_libraries:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.20`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.4.21`,
        fs:  `cpe:2.3:a:oracle:industry_applications:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.0`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.2`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.3`,
        fs:  `cpe:2.3:h:huawei:h3c_ar\(oem_in\):r2209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.4`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.6`,
        fs:  `cpe:2.3:a:rack_project:rack:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.7`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.8`,
        fs:  `cpe:2.3:a:morequick:greenbrowser:6.1.0216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:1.5.14`,
        fs:  `cpe:2.3:a:ibm:installation_manager:1.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.0.0`,
        fs:  `cpe:2.3:a:bloodjournal:blood:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.9.0`,
        fs:  `cpe:2.3:a:microsoft:works:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.10.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p478:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.11.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.12.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.13.0`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.14.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.15.0`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.16.0`,
        fs:  `cpe:2.3:a:red-gate:sql_doc:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.17.0`,
        fs:  `cpe:2.3:a:mavenhut:solitaire_arena:1.0.15:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.18.0`,
        fs:  `cpe:2.3:a:libraw:libraw:0.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.19.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2fz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.20.0`,
        fs:  `cpe:2.3:a:drupal:drupal:7.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.21.0`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.22.0`,
        fs:  `cpe:2.3:a:python:python:3.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.23.0`,
        fs:  `cpe:2.3:a:acquia:commons:6.x-2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:6.24.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.8:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wicket:7.1.0`,
        fs:  `cpe:2.3:a:horde:imp:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wink:0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wink:1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wink:1.1.0`,
        fs:  `cpe:2.3:a:sun:java_studio_enterprise:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wink:1.1.1`,
        fs:  `cpe:2.3:a:hp:product_assistant:100.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wink:1.1.2`,
        fs:  `cpe:2.3:a:opera:opera_mini:7.5:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wink:1.2.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p163:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wink:1.2.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wink:1.3.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:1.6.10`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:1.6.11`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:1.6.12`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:1.6.13`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.6:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:1.6.14`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:8.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:1.6.15`,
        fs:  `cpe:2.3:a:bundler:bundler:1.11.0:pre.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:1.6.16`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2040-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:2.0.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:2.0.0:rc1`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.0.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:wss4j:2.0.1`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:1.0.0`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.0.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.1.0`,
        fs:  `cpe:2.3:a:dell:dataengine:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.2.0`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.01:-:*:*:*:windows_server_2008:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.4.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.4.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.5.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.5.1`,
        fs:  `cpe:2.3:o:yahama:rt56v:4.07.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.5.2`,
        fs:  `cpe:2.3:o:huawei:s2350ei_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.6.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.7.0`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.7.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2009.211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xalan-java:2.7.2`,
        fs:  `cpe:2.3:a:mysql:mysql:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)n1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.0.0`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_discovery_for_distributed:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.2.0`,
        fs:  `cpe:2.3:h:cisco:router_3600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.3.0`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.4.0`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.7:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.5.0`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.6.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.9.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:1.7.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.0.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.1.0`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.2.0`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.3.0`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle:7.5.0.1113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.4.0`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.21_b6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.5.0`,
        fs:  `cpe:2.3:a:subsplash:renny_mclean_ministries:2.8.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.6.0`,
        fs:  `cpe:2.3:a:gnu:readline:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.7.0`,
        fs:  `cpe:2.3:h:supermicro:x9dbi-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:2.8.0`,
        fs:  `cpe:2.3:h:hp:laserjet_4200dnt_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces-c%2b%2b:3.1.3`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces2_java:-`,
        fs:  `cpe:2.3:a:fiverrscript:fiverrscript:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces2_java:2.9.1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces2_java:2.10.0`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xerces2_java:2.11.0`,
        fs:  `cpe:2.3:a:bmc:atrium_integration_engine:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:0.1.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:0.2.0`,
        fs:  `cpe:2.3:a:citrix:xenapp_administration:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.1.0`,
        fs:  `cpe:2.3:o:microsoft:windows_8.1:-:-:-:*:-:-:x64:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.2.0`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2_ms2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.2.1`,
        fs:  `cpe:2.3:a:appstros:appstros_-_free_gift_cards\!:1.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.3.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.426:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.3.1`,
        fs:  `cpe:2.3:a:macromedia:shockwave_flash_plugin:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.4.0`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.5.0`,
        fs:  `cpe:2.3:a:sun:jre:6.0.220:update22:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.5.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.6.0`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.0:rc4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.6.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.7.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_c%2b%2b:1.7.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(6c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.2.0`,
        fs:  `cpe:2.3:a:skype:skype:1.3.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.2.1`,
        fs:  `cpe:2.3:a:debian:kernel-patch-vserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.3.0`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.0`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.1`,
        fs:  `cpe:2.3:a:graphisoft:archicad:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.2`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.2.8:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.4`,
        fs:  `cpe:2.3:a:joakim_nygard:webgrind:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.6`,
        fs:  `cpe:2.3:a:gpg4win:gpg4win:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.7`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.4.8`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.5.0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.5.1`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.5.2`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.1.9.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.5.3`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.5.4`,
        fs:  `cpe:2.3:a:vmware:vcloud_automation_center:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.5.5`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:xml_security_for_java:1.5.6`,
        fs:  `cpe:2.3:o:broadcom:widcomm_bluetooth:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:-`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.4:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.2`,
        fs:  `cpe:2.3:a:docker:docker:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.3`,
        fs:  `cpe:2.3:a:batavi:batavi:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.4`,
        fs:  `cpe:2.3:a:designsandcode:forget-about-shorcode-buttons:1.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.6`,
        fs:  `cpe:2.3:a:ibm:content_collector:3.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.7`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.8`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.4.9`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.5.0`,
        fs:  `cpe:2.3:h:alliedtelesis:img646bd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.5.1`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_76:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache:zookeeper:3.5.2`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_friends:xampp:-`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:313.00:-:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_friends:xampp:1.5.2`,
        fs:  `cpe:2.3:a:logitech:lws_launcher:13.30.1379.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.5`,
        fs:  `cpe:2.3:h:zyxel:p-660hw_d1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.6`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:*:client_workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.7`,
        fs:  `cpe:2.3:h:polycom:viewstation_128:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.8`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.11`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2008.225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.13`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.14`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.16`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.17`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.18`,
        fs:  `cpe:2.3:a:wppa.opajaap:wp-photo-album-plus:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.19`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.20`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.21`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.22`,
        fs:  `cpe:2.3:a:nextcloud:nextcloud_server:9.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.23`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a4\(2.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.25`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.26`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.27`,
        fs:  `cpe:2.3:h:huawei:s12708:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.30`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apache_software_foundation:tomcat:4.1.33`,
        fs:  `cpe:2.3:a:busybox:busybox:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apc:1500:-`,
        fs:  `cpe:2.3:o:bluecoat:sgos:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apc:2200:-`,
        fs:  `cpe:2.3:a:netscape:fasttrack_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apc:3000:-`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:apc:700:-`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apc:ap9606:-`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apc:ap9606:3.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apc:ap9606:3.0.1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:apcupsd:-`,
        fs:  `cpe:2.3:a:promotic:promotic:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute:-`,
        fs:  `cpe:2.3:a:boost:boost:1.54.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute:1.3.4:-:personal`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(5d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute:1.5.0:-:personal`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute:2.0:-:personal`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute:2.1.1:-:personal`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute:2.2:-:personal`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute:5.0.2`,
        fs:  `cpe:2.3:a:acme:thttpd:2.25:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute:9.0.1.606::~~business~~~`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute_network_shutdown:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:powerchute_network_shutdown:3.0.0`,
        fs:  `cpe:2.3:a:ibm:spectrum_lsf:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apc:smart-ups_2200:-`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:switched_rack_pdu_firmware:-`,
        fs:  `cpe:2.3:a:drupal:drupal:6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apc:switched_rack_pdu_firmware:3.5.5`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apereo:central_authentication_service:3.5.2`,
        fs:  `cpe:2.3:o:conectiva:linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aperturemobilemedia:aperture_mobile_media:1.404::~~~android~~`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apexoo:spider:1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)xl4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apexsql:apexsql_log:2008`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apheliontechnologies:hydfm:1.1.9::~~~android~~`,
        fs:  `cpe:2.3:a:hp:universal_cmbd_foundation:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aphpkb:aphpkb:0.95.5`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:13.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aphpkb:aphpkb:0.95.6`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aphpkb:aphpkb:0.95.7`,
        fs:  `cpe:2.3:o:sun:sunos:5.11:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:apollogrp:riverpoint_writer:1.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:app_maker_ks:buy_books:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appa-apps:top_roller_coasters_europe_1:%407f050001::~~~android~~`,
        fs:  `cpe:2.3:a:sun:java_db:10.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appa-apps:top_roller_coasters_europe_2:%407f050001::~~~android~~`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apparound:apparound_blend:4.9.0::~~~android~~`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appbasedtechnologies:belaire_family_orthodontics:1.304::~~~android~~`,
        fs:  `cpe:2.3:a:ca:unicenter_nsm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appbelle:stop_headaches_and_migraines:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appbelle:top_hangover_cures:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:abbyy:finereader:6.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appdeploy:free_appdeploy_repackager:1.2.53`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appeak:poker:2.4.5::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appearingbusiness:magic_balloonman_marty_boone:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.0.9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.1.3`,
        fs:  `cpe:2.3:a:mediawiki:rssreader:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.2.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.3.0`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.4.4`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.5.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.6.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.7.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.8.4`,
        fs:  `cpe:2.3:h:amd:16h_model_00h_processor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apphp:hotel_site:3.9.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:802.11n:7.3.1`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:a_ux:-`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:a_ux:2.0.1`,
        fs:  `cpe:2.3:h:hp:cz257a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:a_ux:3.1.1`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:afp_server:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:airport_base_station:-`,
        fs:  `cpe:2.3:h:cisco:7920_wireless_ip_phone:1.0\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:airport_base_station_firmware:7.3.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:airport_base_station_firmware:7.4.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:airport_base_station_firmware:7.4.2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:airport_base_station_firmware:7.5.2`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:airport_base_station_firmware:7.6`,
        fs:  `cpe:2.3:a:avaya:vsu_100:3.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:airport_base_station_firmware:7.6.1`,
        fs:  `cpe:2.3:a:tylertech:taxweb:3.13.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:airport_base_station_firmware:7.6.2`,
        fs:  `cpe:2.3:h:oracle:sparc_t3-4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:airport_base_station_firmware:7.6.3`,
        fs:  `cpe:2.3:a:hp:scan:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:airport_card:-`,
        fs:  `cpe:2.3:a:cisco:jabber:9.7\(3\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:airport_express:-`,
        fs:  `cpe:2.3:a:apache:solr:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:airport_express:6.1`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:airport_express_base_station_firmware:6.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:airport_extreme:-`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:airport_extreme:5.5`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:airport_extreme_base_station_firmware:5.5`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apache_mod_digest_apple:-`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-04-09:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:apple_airport_base_station_firmware:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:1.0`,
        fs:  `cpe:2.3:a:samba:samba:3.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:1.2.1`,
        fs:  `cpe:2.3:o:cisco:catos:6.2\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:1.3.1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:1.3.2`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:1.4.1`,
        fs:  `cpe:2.3:a:adobe:add_or_remove_creative_suite_3_design_premium:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:1.5.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:1.5.2`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:2.0.1`,
        fs:  `cpe:2.3:h:hp:jf233a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_application_support:2.1.5`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:apple_laserwriter:-`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_mobile_device_support:2.1.0.25`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_mobile_device_support:3.2.0.47`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_2600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_mobile_device_support:3.3.0.69`,
        fs:  `cpe:2.3:o:juniper:junos:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_mobile_device_support:3.4.0.25`,
        fs:  `cpe:2.3:a:ibm:http_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_mobile_device_support:3.4.1.2`,
        fs:  `cpe:2.3:a:emc:rsa_security_analytics:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_mobile_device_support:4.0.0.97`,
        fs:  `cpe:2.3:a:csc:serviceclient:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:1.2.4`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.6d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:2.0.0`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:2.1.0`,
        fs:  `cpe:2.3:h:dell:3010cn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:2.2`,
        fs:  `cpe:2.3:a:divx:web_player:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.0.0`,
        fs:  `cpe:2.3:a:pcre:pcre:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.1.5.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.2`,
        fs:  `cpe:2.3:a:radvision:l2w-323:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.2.1`,
        fs:  `cpe:2.3:a:sysax:multi_server:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.2.2`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.3.1`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.3.2`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.0:alpha4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.4`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.5`,
        fs:  `cpe:2.3:a:apache:activemq:5.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.5.1`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.5.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.5.3`,
        fs:  `cpe:2.3:h:tp-link:tl-wrd841nd_\(9.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.5.4`,
        fs:  `cpe:2.3:a:speed_software:explorer:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.6`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.6.1`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:45.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.6.2`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_remote_desktop:3.7`,
        fs:  `cpe:2.3:a:roxio:recordnow_audio:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:1.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:1.1.0`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.3.3:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:2.0.0`,
        fs:  `cpe:2.3:h:cisco:nexus_3064t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:2.0.1`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:2.0.2`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r5-b1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:2.1.0`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:2.2.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:2.3.0`,
        fs:  `cpe:2.3:o:vmware:esx:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:2.3.1`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:2.4.0`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:3.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:3.0.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:3.0.2`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_6921:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.1.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.2.0`,
        fs:  `cpe:2.3:a:ibm:spss_statistics:22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.2.1`,
        fs:  `cpe:2.3:h:nokia:n70:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.2.2`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.3.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.27:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.4.0`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.4.2`,
        fs:  `cpe:2.3:a:webprancer:garfield\&#39;s_defense:1.5.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.4.3`,
        fs:  `cpe:2.3:h:axis:2411_video_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:4.4.4`,
        fs:  `cpe:2.3:a:commerceguys:commerce_reorder:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:5.0.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:5.0.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:5.0.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:5.1.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:5.1.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:5.2.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:6.0`,
        fs:  `cpe:2.3:a:openstack:icehouse:2014.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:6.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:6.0.2`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:6.1`,
        fs:  `cpe:2.3:a:openstack:keystone:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:6.1.1`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:6.1.2`,
        fs:  `cpe:2.3:o:freebsd:freebsd:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:6.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.555:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:6.2.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:7.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:7.0.1`,
        fs:  `cpe:2.3:o:apple:apple_tv:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:7.0.3`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.92:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:7.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:apple_tv:9.0`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:9.0.1`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction_content_service_for_windows_files:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:apple_tv:9.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:9.1.1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:apple_tv:9.2`,
        fs:  `cpe:2.3:a:citrix:command_center:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:apple_tv:9.2.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:apple_tv:9.2.2`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp9:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:10.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:10.0.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:10.1`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:10.1.1`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:apple_tv:10.2`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:applescript:-`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bomarchivehelper:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xe4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:1.0.0:-:windows`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:1.0.1:-:windows`,
        fs:  `cpe:2.3:a:ibm:web_content_manager:7.0.0.1:cf002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:1.0.2:-:windows`,
        fs:  `cpe:2.3:a:citrix:metaframe_secure_access_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:1.0.3:-:windows`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:1.0.4:-:windows`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:1.0.105`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:1.0.106`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:2.0.3.0`,
        fs:  `cpe:2.3:a:redhat:kernel:2.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:2.0.4.0`,
        fs:  `cpe:2.3:a:gnome:evolution:2.3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:2.0.5.0`,
        fs:  `cpe:2.3:a:microsoft:publisher:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:3.0.0.2`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:bonjour:3.0.0.10`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.18:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:boot_camp:5.0`,
        fs:  `cpe:2.3:a:hp:unified_functional_testing:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:boot_camp:5.1`,
        fs:  `cpe:2.3:a:compaq:version_control_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cfnetwork:-`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:claris_emailer:-`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:claris_emailer:2.0v2`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:core_audio_technologies:-`,
        fs:  `cpe:2.3:h:samsung:galaxy_s2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.1`,
        fs:  `cpe:2.3:a:tincan:phplist:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.2`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.3`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.4`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.5`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.5-1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.05:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.5-2`,
        fs:  `cpe:2.3:o:yahama:rta55i:4.06.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.6`,
        fs:  `cpe:2.3:a:novell:groupwise:7.02:hp2r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.6-1`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.6-2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.6-3`,
        fs:  `cpe:2.3:a:analogx:simpleserver_shout:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.7`,
        fs:  `cpe:2.3:a:apple:cups:1.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.8`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.9`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.9-1`,
        fs:  `cpe:2.3:a:tinc-vpn:tinc:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.10`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.10-1`,
        fs:  `cpe:2.3:a:google:android_api:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.11`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.12`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.13`,
        fs:  `cpe:2.3:a:juniper:networks_mobility_system_software:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.14`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.15`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.16`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.17`,
        fs:  `cpe:2.3:a:avast:endpoint_protection_suite_plus:8.0.1609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.18`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.19`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.19:rc1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.19:rc2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.19:rc3`,
        fs:  `cpe:2.3:a:cisco:transport_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.19:rc4`,
        fs:  `cpe:2.3:a:djangoproject:django:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.19:rc5`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.20`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.20:rc1`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.20:rc2`,
        fs:  `cpe:2.3:a:atlassian:jira:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.20:rc3`,
        fs:  `cpe:2.3:a:php:php:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.20:rc4`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.20:rc5`,
        fs:  `cpe:2.3:h:siemens:scalance_x204irt_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.20:rc6`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.21`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.21:rc1`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.21:rc2`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.22`,
        fs:  `cpe:2.3:a:apache:knox:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.22:rc1`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.22:rc2`,
        fs:  `cpe:2.3:a:acquia:mollom:6.x-2.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.23`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.1.23:rc1`,
        fs:  `cpe:2.3:a:secunia:csi_agent:7.0.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2:b1`,
        fs:  `cpe:2.3:a:microsoft:netmeeting:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2:b2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2:rc1`,
        fs:  `cpe:2.3:a:digium:asterisk:c.1.8.0:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2:rc2`,
        fs:  `cpe:2.3:a:actividentity:actividentity_device_installer:2.2:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2:rc3`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.0`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.2.0.6504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-03-03:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.2`,
        fs:  `cpe:2.3:a:netiq:appmanager_web_management_server:7.0.41039.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.4`,
        fs:  `cpe:2.3:a:cisco:content_security_management_appliance:9.6.6-068:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.5`,
        fs:  `cpe:2.3:a:idrt:marvin_teaches_fingerspelling_ii:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.6`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.7`,
        fs:  `cpe:2.3:a:lsoft:listserv:1.8d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.8`,
        fs:  `cpe:2.3:a:web2py:web2py:1.79.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.9`,
        fs:  `cpe:2.3:a:forgerock:openam:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.10`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.11`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.2.12`,
        fs:  `cpe:2.3:a:atlassian:jira:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3:b1`,
        fs:  `cpe:2.3:a:usr:faxtools:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3:rc1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3:rc2`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.0`,
        fs:  `cpe:2.3:a:microsoft:office_infopath:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.2`,
        fs:  `cpe:2.3:a:cmcm:cm_backup_-restorecloudphoto:1.1.0.135:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.3`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.4`,
        fs:  `cpe:2.3:a:goahead:goahead_webserver:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.5`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.6`,
        fs:  `cpe:2.3:a:boson:netsim:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.7`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.8`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.9`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:5.2.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.10`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:beta6:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.3.11`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4:b1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4:b2`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4:b3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4:rc1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.1`,
        fs:  `cpe:2.3:a:katello:katello:1.5.0-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.2`,
        fs:  `cpe:2.3:h:tp-link:tl-sc3171:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.5`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.6`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.7`,
        fs:  `cpe:2.3:a:libraw:libraw:0.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.4.8`,
        fs:  `cpe:2.3:a:debian:adequate:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.5:b1`,
        fs:  `cpe:2.3:a:wu-rating_project:wu-rating:1.0_12319:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.5:b2`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.5:rc1`,
        fs:  `cpe:2.3:a:google:chrome:0.1.40.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.5.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.5.1`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.5.2`,
        fs:  `cpe:2.3:a:apache:hive:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.5.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.5.4`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.1.00495:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.6:b1`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.6:rc1`,
        fs:  `cpe:2.3:a:ca:client_automation:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.6.1`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.6.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.9.1p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.6.3`,
        fs:  `cpe:2.3:h:cisco:meraki_mx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.6.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.18.0as:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.7:rc1`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.7.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.7.1`,
        fs:  `cpe:2.3:a:apache:poi:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.7.1:b1`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp5225:ce712a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.7.2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.7.3`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:1.7.4`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:2.0::~~development~~~`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:2.0.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:cups:2.1::~~development~~~`,
        fs:  `cpe:2.3:a:gnu:libtool-ltdl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:-`,
        fs:  `cpe:2.3:a:citadel:ux:6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:4.1`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:4.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:4.1.3`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:4.1.3g`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-51-\/k:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:5.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:5.0.1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:5.5`,
        fs:  `cpe:2.3:a:sun:javamail:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:5.5:-:windows`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:darwin_streaming_server:5.5.4`,
        fs:  `cpe:2.3:a:condor_project:condor:7.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:finder:-`,
        fs:  `cpe:2.3:a:matrix42:service_store:5.3:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:help_viewer:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.1:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:apple:ibooks_author:2.4.0`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.00.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:ibooks_author:2.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:ical:-`,
        fs:  `cpe:2.3:a:imember360:imember360:3.7.007:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:ichat:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.26.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:ichat_av:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ird:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:ichat_av:2.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.30:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:ichat_server:-`,
        fs:  `cpe:2.3:a:hp:dynrootdisk:a.2.0.0.592:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:icloud:7.0`,
        fs:  `cpe:2.3:a:social_stats_project:social_stats:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:icloud:7.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:-`,
        fs:  `cpe:2.3:a:microsoft:office:2007:sp2:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:m9248xx%2fa`,
        fs:  `cpe:2.3:a:logitech:lws_wlm_plugin:1.30.1201.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:m9249xx%2fa`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.16a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:m9250xx%2fa`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:m9363xx%2fa`,
        fs:  `cpe:2.3:a:citrix:xenapp_power_and_capacity_management_agent:2.0.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:m9823xx%2fa`,
        fs:  `cpe:2.3:a:augeas:augeas:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:m9843xx%2fa`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:m9844xx%2fa`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:m9845xx%2fa`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:9.0:bundle3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma063xx%2fa`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma064xx%2fa`,
        fs:  `cpe:2.3:o:google:android:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma199xx%2fa`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma200xx%2fa`,
        fs:  `cpe:2.3:a:hp:photosmart_premier_software:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma406xx%2fa`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1027:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma456xx%2fa`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma589xx%2fa`,
        fs:  `cpe:2.3:o:oracle:solaris:-:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma590xx%2fa`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma710xx%2fa`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma876xx%2fa`,
        fs:  `cpe:2.3:o:iij:seil\%2fx1_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma877xx%2fa`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:ma878xx%2fa`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb199xx%2fa`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb200xx%2fa`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.3:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb322xx%2fa`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb323xx%2fa`,
        fs:  `cpe:2.3:a:openstack:telemetry_\(ceilometer\):2014.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb324xx%2fa`,
        fs:  `cpe:2.3:a:apache:roller:0.9.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb325xx%2fa`,
        fs:  `cpe:2.3:a:hexagon:erdas_apollo_ecwp:13.00.0001:-:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb388xx%2fa`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:9.0.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb391xx%2fa`,
        fs:  `cpe:2.3:a:apple:xcode:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb393xx%2fa`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.3.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb398xx%2fa`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb417xx%2fa`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb418xx%2fa`,
        fs:  `cpe:2.3:a:bmobile:imagine_next_bmobile:1.7.10.243:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb419xx%2fa`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.13:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb420xx%2fa`,
        fs:  `cpe:2.3:a:hp:photosmart_disclabel_printondisc:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb950xx%2fa`,
        fs:  `cpe:2.3:a:erlang:crypto:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb952xx%2fa`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mb953xx%2fa`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc019xx%2fa`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:fp0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc020xx%2fa`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc021xx%2fa`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc022xx%2fa`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(3a\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc413xx%2fa`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc508xx%2fa`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc509xx%2fa`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc510xx%2fa`,
        fs:  `cpe:2.3:h:chiyu:bf-660c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:imac:mc511xx%2fa`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-00:-:standard:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:imageio:-`,
        fs:  `cpe:2.3:a:techradar_news_project:techradar_news:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:imovie:-`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.5.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:imovie:6.0.3`,
        fs:  `cpe:2.3:a:collabnet:scrumworks:5.0:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:installer:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:instant_message_framework:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:ipad:-`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0058:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:ipad_mini:-`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:ipad_mini-:-`,
        fs:  `cpe:2.3:a:cisco:unity_connection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:ipad2:-`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone:-`,
        fs:  `cpe:2.3:a:google:chrome:7.0.542.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone:1.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone:1.0.1`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone:1.0.2`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone:1.1.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.466.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone:1.1.2`,
        fs:  `cpe:2.3:a:yokogawa:centum_vp_software:4.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone:1.02`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.093:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone_4s:-`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:iphone_5:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.7.0.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.0.0`,
        fs:  `cpe:2.3:a:degraaff:checkbot:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.0.0:-:iphone`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.0.1`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.0.1:-:iphone`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.0.2`,
        fs:  `cpe:2.3:a:apache:sling_auth_core_component:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.0.2:-:iphone`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro:275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.0`,
        fs:  `cpe:2.3:h:huawei:s5100:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.0:-:iphone`,
        fs:  `cpe:2.3:h:polycom:viewstation_h.323:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.0:-:ipodtouch`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.1`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.1:-:iphone`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.1:-:ipodtouch`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.2`,
        fs:  `cpe:2.3:a:openstack:swift:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.2:-:iphone`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.2:-:ipodtouch`,
        fs:  `cpe:2.3:a:redhat:cloudforms_cloud_engine:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:11.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.3:-:iphone`,
        fs:  `cpe:2.3:a:piwik:piwik:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.3:-:ipodtouch`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.2-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.4`,
        fs:  `cpe:2.3:a:keepass:keepass:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.4:-:iphone`,
        fs:  `cpe:2.3:a:hp:web_registration:140.0.212.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.4:-:ipodtouch`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.5`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.5:-:iphone`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:1.1.5:-:ipodtouch`,
        fs:  `cpe:2.3:a:busybox:busybox:1.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.20.342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.0`,
        fs:  `cpe:2.3:a:microsoft:word:2010:sp2:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.0:-:iphone`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.0:-:ipodtouch`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.2_cf2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.1`,
        fs:  `cpe:2.3:a:openproject:openproject:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.1:-:iphone`,
        fs:  `cpe:2.3:a:tablefield_project:tablefield:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.1:-:ipodtouch`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.7.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.2:-:iphone`,
        fs:  `cpe:2.3:a:emc:navisphere_command_line_interface:26.0.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.0.2:-:ipodtouch`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.1`,
        fs:  `cpe:2.3:a:vmware:fusion:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.1:-:iphone`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.1:-:ipodtouch`,
        fs:  `cpe:2.3:a:puzzles_and_matchup_games_project:educational_puzzles_-_letters:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.1.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.2`,
        fs:  `cpe:2.3:o:juniper:junos:11.4x27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.2:-:iphone`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.2:-:ipodtouch`,
        fs:  `cpe:2.3:a:apple:core_audio_technologies:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.2.1`,
        fs:  `cpe:2.3:a:openstack:folsom:2012.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.2.1:-:iphone`,
        fs:  `cpe:2.3:a:isc:bind:9.1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:2.2.1:-:ipodtouch`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.20:-:*:*:*:suse_linux:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.0:-:iphone`,
        fs:  `cpe:2.3:a:debian:internet_message:133-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.0:-:ipodtouch`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.0.1:-:iphone`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.13:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.0.1:-:ipodtouch`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1:-:iphone`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1:-:ipodtouch`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1.2`,
        fs:  `cpe:2.3:h:siemens:sinamics_g120c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1.2:-:iphone`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1.2:-:ipodtouch`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1.3`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1.3:-:iphone`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ea1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.1.3:-:ipodtouch`,
        fs:  `cpe:2.3:a:openid:openid4java:0.9.5.593:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.2:-:iphone`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1061.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.2:-:ipodtouch`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.2.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.2.1:-:ipad`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:3.2.2`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.0:-:iphone`,
        fs:  `cpe:2.3:a:apple:cups:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.0:-:ipodtouch`,
        fs:  `cpe:2.3:o:ibm:aix:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.0.1:-:iphone`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.0.1:-:ipodtouch`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.2.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53_90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.2.5`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.2.8`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.3.0`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.0.4.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.3.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.509:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.3.2`,
        fs:  `cpe:2.3:a:apple:safari:3.2.2b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.3.3`,
        fs:  `cpe:2.3:a:horde:groupware:1.1:rc2:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.3.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.3.5:-:ipad`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:4.3.5:-:ipodtouch`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.0`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.0:-:ipad`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.0:-:iphone`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.0:-:ipodtouch`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.0.1`,
        fs:  `cpe:2.3:a:pkware:pkzip_server_for_windows:12.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.0.1:-:ipad`,
        fs:  `cpe:2.3:a:tivoli_storage_productivity_center:5.1.1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.0.1:-:iphone`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.0.1:-:ipodtouch`,
        fs:  `cpe:2.3:h:symantec:firewall_vpn_appliance_100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.1`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r7_p1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:5.1.1`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.0`,
        fs:  `cpe:2.3:a:checkpoint:provider-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.0.1`,
        fs:  `cpe:2.3:a:altiris:it_analytics_asset_management_pack:6.1.1085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.0.2`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.05.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.1.2`,
        fs:  `cpe:2.3:a:ibm:informix_client_sdk:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.1.3`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.1.4`,
        fs:  `cpe:2.3:a:php:pear:1.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.1.5`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:6.1.6`,
        fs:  `cpe:2.3:a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.0`,
        fs:  `cpe:2.3:a:dell:sonicwall_email_security:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.0.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.0.2`,
        fs:  `cpe:2.3:a:hp:jfs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.0.3`,
        fs:  `cpe:2.3:a:microsoft:windows_media_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.0.4`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.0.5`,
        fs:  `cpe:2.3:a:heliconsoft:isapi_rewrite_lite:3.1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.0.6`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.1`,
        fs:  `cpe:2.3:a:expressdigital:darkroom_professional_edition:8.91.1678:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.1.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:7.1.2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:8.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:8.0.1`,
        fs:  `cpe:2.3:a:palm:blazer:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:8.0.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:8.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:8.1.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:8.1.3`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:8.2`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:8.4.1`,
        fs:  `cpe:2.3:a:hitachi:jp1\/it_desktop_management-manager:10-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.0`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.0.1`,
        fs:  `cpe:2.3:a:gnu:flash_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.0.2`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:2.1:*:ia64-es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.2`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.2.1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.3`,
        fs:  `cpe:2.3:a:magicam_photo_magic_editor_project:magicam_photo_magic_editor:5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.3.1`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.3.2`,
        fs:  `cpe:2.3:a:emc:vmware_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.3.3`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.49:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.3.4`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:9.3.5`,
        fs:  `cpe:2.3:a:spip:spip:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.0`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:01-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.0.2`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.0.3`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.4:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.1.1`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.2`,
        fs:  `cpe:2.3:a:php:pear:1.3b6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.2.1`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a4:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.3`,
        fs:  `cpe:2.3:a:macromedia:sitespring:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.3.1`,
        fs:  `cpe:2.3:a:ibm:systems_director:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.3.2`,
        fs:  `cpe:2.3:a:shopware:shopware:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:10.3.3`,
        fs:  `cpe:2.3:a:sigmatel:c-major_audio:5.10.4820.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:11.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:11.0.1`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:5.4.102.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:11.0.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:11.0.3`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:11.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:11.1.1`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:iphone_os:11.1.2`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:-`,
        fs:  `cpe:2.3:a:adobe:creative_suite_4_web_premium:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:6.0.0`,
        fs:  `cpe:2.3:a:redhat:subscription_asset_manager:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:6.0.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:6.0.2`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.8.4:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:6.0.3`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:6.0.4`,
        fs:  `cpe:2.3:a:oracle:warehouse_builder:10.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:6.0.5`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:05-05-\/p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:7.0.0`,
        fs:  `cpe:2.3:a:emc:legato_networker:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:7.1.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iphoto:7.1.1`,
        fs:  `cpe:2.3:a:david_king:vino:2.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:ipod_touch:-`,
        fs:  `cpe:2.3:h:sun:crypto_accelerator_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:ipod_touch:1.1`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.4.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:ipod_touch:1.1.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:ipod_touch:1.1.2`,
        fs:  `cpe:2.3:a:yahoo:yui:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.0.0:-:mac`,
        fs:  `cpe:2.3:a:roderick_braun:ya_googlesearch:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.0.0:-:windows`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.0.1`,
        fs:  `cpe:2.3:a:cisco:vpn_3002_hardware_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.0.1:-:mac`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_enterprise_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.0.1:-:windows`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.1.0`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.1.0:-:mac`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.1.0:-:windows`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.2.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_99:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.2.0:-:mac`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.2.0:-:windows`,
        fs:  `cpe:2.3:o:ibm:os_400:v5r3m0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.5`,
        fs:  `cpe:2.3:h:cisco:nexus_92160yc-x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.5::windows`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.5.0`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.976:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.5.0:-:mac`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.5.0:-:windows`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.6`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.11.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.6::windows`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.6.0`,
        fs:  `cpe:2.3:a:square:okhttp:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.6.0:-:mac`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.6.0:-:windows`,
        fs:  `cpe:2.3:a:jease:jease:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.5.7:*:*:*:*:mybb:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7::windows`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7.0:-:mac`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7.0:-:windows`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7.1::windows`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7.1:-:mac`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7.1:-:windows`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-3520c_firmware:t450sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.7.2`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.8.0`,
        fs:  `cpe:2.3:a:python:python:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.8.0:-:mac`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.8.0:-:windows`,
        fs:  `cpe:2.3:a:hp:photosmart_essentials:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.9.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.9.0:-:mac`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2013:-:gen:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:4.9.0:-:windows`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.2:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:5.0`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:5.0::windows`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.8:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:5.0.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:alpha0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:5.0.0:-:mac`,
        fs:  `cpe:2.3:a:hp:software_core_korean_localization:6.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:5.0.0:-:windows`,
        fs:  `cpe:2.3:a:google:v8:3.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:5.0.1`,
        fs:  `cpe:2.3:a:google:v8:3.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:5.0.1:-:mac`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.492:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:5.0.1:-:windows`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.1.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.0`,
        fs:  `cpe:2.3:o:redhat:linux:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.0:-:mac`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.0:-:windows`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.1`,
        fs:  `cpe:2.3:a:google:authenticator:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.1::windows`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.1:-:mac`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.1:-:windows`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.2::windows`,
        fs:  `cpe:2.3:a:redhat:qspice:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.2:-:mac`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.2:-:windows`,
        fs:  `cpe:2.3:a:apple:itunes:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.3:-:mac`,
        fs:  `cpe:2.3:a:mobfox:madserve:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.3:-:windows`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.4`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.4::windows`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.8.0.870:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.4:-:mac`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp10:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.4:-:windows`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.5`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.5:-:mac`,
        fs:  `cpe:2.3:a:ibm:maximo_service_desk:7.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:6.0.5:-:windows`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.0`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.0:-:mac`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.0:-:windows`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.101_2097:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.1:-:mac`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.1:-:windows`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.2`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.2::windows`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.2:-:mac`,
        fs:  `cpe:2.3:a:apple:safari:3.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.0.2:-:windows`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.3:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.1.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.00.303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.1.0:-:mac`,
        fs:  `cpe:2.3:o:suse:suse_linux:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.1.0:-:windows`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.1.1`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.1.1:-:mac`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.3.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.1.1:-:windows`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.3.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.2.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.2.0:-:mac`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.2.0:-:windows`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:189:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.0:-:mac`,
        fs:  `cpe:2.3:a:sympa:sympa:2.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.0:-:windows`,
        fs:  `cpe:2.3:a:realvnc:realvnc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.1`,
        fs:  `cpe:2.3:a:actorskey:actors_key:1.6.24.477:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.1:-:mac`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.1:-:windows`,
        fs:  `cpe:2.3:a:oracle:forms:6.0.8.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.2::windows`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.2:-:mac`,
        fs:  `cpe:2.3:a:symantec:endpoint_encryption:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.3.2:-:windows`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4::windows`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:7.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.0:-:mac`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.40.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.0:-:windows`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.1::windows`,
        fs:  `cpe:2.3:a:perl:perl:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.1:-:mac`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.1:-:windows`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.2`,
        fs:  `cpe:2.3:a:starkvilleelectric:sed_account:1.153.0034:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.2::windows`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.2:-:mac`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.2:-:windows`,
        fs:  `cpe:2.3:a:skype:skype:0.98.0.04:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.3`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.4.3::windows`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.5`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.5::windows`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp5:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.5.0`,
        fs:  `cpe:2.3:a:vastal:phpvid:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.5.0:-:mac`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.5.0:-:windows`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.0`,
        fs:  `cpe:2.3:a:samba:samba:4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.0:-:mac`,
        fs:  `cpe:2.3:a:ggbu:twitter_no_background:0.85.13509.97828:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.0:-:windows`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.1::windows`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.1:-:mac`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.1:-:windows`,
        fs:  `cpe:2.3:a:junefabrics:pdanet_for_android:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.2`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.2:-:mac`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.6.2:-:windows`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.7`,
        fs:  `cpe:2.3:a:clamav:clamav:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.7.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.7.0:-:mac`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_sametime:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.7.0:-:windows`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.7.1`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.7.1::windows`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.7.1:-:mac`,
        fs:  `cpe:2.3:a:ibm:tivoli_omegamon_xe_for_messaging_on_z\/os:601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:7.7.1:-:windows`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:8.0.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.0\(6.7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:8.0.0:-:mac`,
        fs:  `cpe:2.3:a:playscape:ninja_chicken:1.7.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:8.0.0:-:windows`,
        fs:  `cpe:2.3:h:dell:latitude_e6400_atg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:8.0.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:8.0.1:-:mac`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp3:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:8.0.1:-:windows`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:9.0.0`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:9.0.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:9.0.2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:9.0.3`,
        fs:  `cpe:2.3:a:symantec:norton_pc_checkup:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:9.1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:0.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:9.1.1`,
        fs:  `cpe:2.3:h:cisco:content_security_management_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:9.2`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:9.2.1`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_9.0_firmware:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.0`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.0.1`,
        fs:  `cpe:2.3:a:jollygiant:qws3270_secure:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.1`,
        fs:  `cpe:2.3:a:exim:exim:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.1.1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.1.1.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.1.2`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.1:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.2`,
        fs:  `cpe:2.3:a:redaxo:redaxo:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.2.2.12`,
        fs:  `cpe:2.3:o:ibm:aix:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.3`,
        fs:  `cpe:2.3:h:dlink:dcs-2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.3.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.4`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.4.0.80`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.4.1`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.4.1.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.5`,
        fs:  `cpe:2.3:a:altiris:client_management_suite_quick_start:6.0.1274:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.5.1`,
        fs:  `cpe:2.3:a:moxa:softcms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.5.1.42`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.5.2`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.5.3`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.6`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-3.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.6.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:10.6.3`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.0.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.0.2`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.26:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.0.3`,
        fs:  `cpe:2.3:a:jordan_de_laune:mp3_player:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.0.4`,
        fs:  `cpe:2.3:a:x:libxcb:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.0.5`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.1.1`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.1.2`,
        fs:  `cpe:2.3:a:socketmail:socketmail:2.2.6:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.1.3`,
        fs:  `cpe:2.3:a:samba:samba:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.1.4`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.0.235.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.1.5`,
        fs:  `cpe:2.3:h:dell:latitude_e6510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:11.2.1`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf803a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.0`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.0.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.1`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.22:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.1.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.1.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.224.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.1.3`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3b.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.2`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.2.1`,
        fs:  `cpe:2.3:a:mcafee:e-business_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.2.2`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.3`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.3.0`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:r15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.3.1`,
        fs:  `cpe:2.3:a:realflex:realwin:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.4`,
        fs:  `cpe:2.3:a:urbanairship:python-oauth2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.4.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.11.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.4.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.4.3`,
        fs:  `cpe:2.3:a:exim:exim:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.5`,
        fs:  `cpe:2.3:a:progress:database:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.5.1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.5.2`,
        fs:  `cpe:2.3:a:sgi:fam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.5.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p50:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.5.4`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.5.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.0.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.6`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.6.1`,
        fs:  `cpe:2.3:a:cisco:catalyst_6000_intrusion_detection_system_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.6.2`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.6.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.7`,
        fs:  `cpe:2.3:a:intel:mhlpdell:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:itunes:12.7.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:iwork:2.5.4`,
        fs:  `cpe:2.3:h:huawei:ips_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.3:1:15`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.4:0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.4:1`,
        fs:  `cpe:2.3:a:open_atrium_project:open_atrium:7.x-2.21:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.4:1:08`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.4:1:r1`,
        fs:  `cpe:2.3:a:sun:java_enterprise_system:5.0:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.4:2`,
        fs:  `cpe:2.3:a:hp:service_manager:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.4:2:16`,
        fs:  `cpe:2.3:a:sun:rte:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.4:2:18`,
        fs:  `cpe:2.3:a:crear.ne.jp:al-mail32:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.5:-`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.5:0`,
        fs:  `cpe:2.3:a:php:mysql_extension:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.5:0:13`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.5:0:16`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.4:rev34757:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.6:-`,
        fs:  `cpe:2.3:h:ibm:e12:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.6:0`,
        fs:  `cpe:2.3:a:huawei:espace_desktop:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.6:0:05`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:java_1.6:0:07`,
        fs:  `cpe:2.3:a:qemu:qemu:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:2.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:2.0.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:2.0.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.020.20042:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.0`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.0.1`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.0.2`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.0.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.0.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.0.5`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.1.1`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.2`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:5.3`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:keynote:6.5`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:7.5.3`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:7.6`,
        fs:  `cpe:2.3:a:compuware:applicationvantage_agent:10.2.277:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:7.6.1`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:8.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:8.1`,
        fs:  `cpe:2.3:a:gnu:gcc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:8.5`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:8.6`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:9`,
        fs:  `cpe:2.3:a:apache:subversion:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os:9.0`,
        fs:  `cpe:2.3:a:hp:openview_performance_extended_capability_technology:4.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_appleshare_ip:9`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mac_os_nsl_manager:-`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mac_os_nsl_manager:2`,
        fs:  `cpe:2.3:a:avg:identity_protection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mac_os_runtime_for_java:-`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mac_os_runtime_for_java:2.1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.038:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mac_os_runtime_for_java:2.2.3`,
        fs:  `cpe:2.3:a:curtis_galloway:libexif:0.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mac_os_runtime_for_java:2.2.4`,
        fs:  `cpe:2.3:a:google:chrome:7.0.526.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_server:9`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mac_os_x:-`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:-`,
        fs:  `cpe:2.3:a:postfix:postfix:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.0`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.0.0`,
        fs:  `cpe:2.3:a:pulsesecure:client:-:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.0.1`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.0.2`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.0.3`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.0.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-71-\/h:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.1`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.01.00034:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.1.0`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.1.1`,
        fs:  `cpe:2.3:a:debian:apt:0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.1.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.1.3`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.1.4`,
        fs:  `cpe:2.3:a:corel:coreldraw:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.1.5`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg311a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.3`,
        fs:  `cpe:2.3:h:supermicro:x9scm-iif:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.4`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.5`,
        fs:  `cpe:2.3:o:cisco:ios:3.5.0e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.6`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.17:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.7`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.2.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(6e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3`,
        fs:  `cpe:2.3:a:symantec:netbackup_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.1`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.2`,
        fs:  `cpe:2.3:a:raphael_zschorsch:rzautocomplete:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.3`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.4`,
        fs:  `cpe:2.3:a:apache:libcloud:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.5`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.6`,
        fs:  `cpe:2.3:a:microsoft:office:2001:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.8`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:201hw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.3.9`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.0`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:6.1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_3y:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.3`,
        fs:  `cpe:2.3:a:symantec:veritas_authentication_service:4.1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.4`,
        fs:  `cpe:2.3:a:logitech:lws_video_mask_maker:13.30.1379.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.5`,
        fs:  `cpe:2.3:a:active_24_project:active_24:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.6`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:532:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.7`,
        fs:  `cpe:2.3:a:hp:oracle_for_openview:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.8`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.9`,
        fs:  `cpe:2.3:a:vmware:player:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.10`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.4.11`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5`,
        fs:  `cpe:2.3:a:iss:proventia_desktop:8.0.812.1790:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.0`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.1`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.2`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.3`,
        fs:  `cpe:2.3:a:horde:gollem:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.4`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.5`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2012:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.6`,
        fs:  `cpe:2.3:a:apache:axis:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.7`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.5.8`,
        fs:  `cpe:2.3:a:oracle:html_db:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.4`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.5`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.6`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.7`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.6.8`,
        fs:  `cpe:2.3:a:efstechnology:autoform_pdm_archive:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.7.0`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.7.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.7.2`,
        fs:  `cpe:2.3:a:novell:sentinel_log_manager:1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.7.3`,
        fs:  `cpe:2.3:a:oracle:goldengate:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.7.4`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.21f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.7.5`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.8.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.8.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.8.2`,
        fs:  `cpe:2.3:a:vips:vips:7.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.8.3`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.8.4`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.8.5`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:10.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.8.5:supplemental_update`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.9`,
        fs:  `cpe:2.3:a:cisco:emergency_responder:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.9.1`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.9.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.9.3`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.9.4`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.9.5`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.95.p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.10.0`,
        fs:  `cpe:2.3:a:microsoft:iis:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.10.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.10.2`,
        fs:  `cpe:2.3:a:gcspublishing:bersa_forum:3.9.16:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.10.3`,
        fs:  `cpe:2.3:h:zyxel:p-660hw_d3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.10.4`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.10.5`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.11.0`,
        fs:  `cpe:2.3:a:electric_cloud:electriccommander:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.11.1`,
        fs:  `cpe:2.3:a:rsa:authentication_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.11.2`,
        fs:  `cpe:2.3:a:novell:access_manager:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.11.3`,
        fs:  `cpe:2.3:a:cisco:cisco_policy_suite:7.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.11.4`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.11.5`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.11.6`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.12.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2009.113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.12.1`,
        fs:  `cpe:2.3:a:kryo:iodine:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.12.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.16:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.12.3`,
        fs:  `cpe:2.3:a:citrix:presentation_server_administration_snap-in:4.6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.12.4`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.12.5`,
        fs:  `cpe:2.3:a:suse:suse_open_enterprise_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.12.6`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.12.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x:10.13.0`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:-`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:5.0.2`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.11:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:5.0.3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:5.0.14`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:5.0.15`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.0.1`,
        fs:  `cpe:2.3:a:netfilter:ipset:6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.0.2`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.0.3`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.0.4`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(3\)m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.1.0`,
        fs:  `cpe:2.3:a:keepass:keepass:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.1.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.1.2`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.2.3800.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.25.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.1.4`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.2.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.1.5`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.106.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.2`,
        fs:  `cpe:2.3:h:axis:250s_mpeg2_video_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.3`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.4`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.5`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.6`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.7`,
        fs:  `cpe:2.3:a:rob_loach:sharethis:7.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.2.8`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.0`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.35.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.1`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.2`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.4`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.5`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.6`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.7`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3204a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.8`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.3.9`,
        fs:  `cpe:2.3:a:adobe:photoshop:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper_live_streaming_integration:4.27.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.2`,
        fs:  `cpe:2.3:a:apache:log4j:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.3`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.22:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.5`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.6`,
        fs:  `cpe:2.3:a:atlassian:hipchat:3.16.1:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2fy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.8`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.9`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.10`,
        fs:  `cpe:2.3:a:adp4u:adp_agency_immobiliare:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.4.11`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:nb:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.0`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.1.1219:online_windows_2000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.2`,
        fs:  `cpe:2.3:a:saltstack:salt_2015:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.3`,
        fs:  `cpe:2.3:o:cisco:rv130w_wireless-n_multifunction_vpn_router_firmware:1.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.4`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.5`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.7`,
        fs:  `cpe:2.3:a:alkacon:opencms:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.5.8`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.1`,
        fs:  `cpe:2.3:a:microsoft:directx_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.2`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.3`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.4`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.5`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.6`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:rc2:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.7`,
        fs:  `cpe:2.3:o:d-link:dcs-932l_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.6.8`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.7.0`,
        fs:  `cpe:2.3:a:jenkins-ci:build_failure_analyzer:1.4.0:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.7.1`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.7.2`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.7.3`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1002.101.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.7.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.25.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:mac_os_x_server:10.7.5`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_air:-`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:-`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma092xx%2fa`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma463xx%2fa`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma464xx%2fa`,
        fs:  `cpe:2.3:a:websitepanel:websitepanel:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma600xx%2fa`,
        fs:  `cpe:2.3:h:supermicro:x9dbl-3f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma601xx%2fa`,
        fs:  `cpe:2.3:a:vastal:phpvid:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma609xx%2fa`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma610xx%2fa`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma611xx%2fa`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma895xx%2fa`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma896xx%2fa`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:ma897xx%2fa`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb133xx%2fa`,
        fs:  `cpe:2.3:a:oracle:internet_expenses:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb134xx%2fa`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)xr6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb166xx%2fa`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb470xx%2fa`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb471xx%2fa`,
        fs:  `cpe:2.3:a:corel:wordperfect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb604xx%2fa`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb766xx%2fa`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb985xx%2fa`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-03-02:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb986xx%2fa`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb990xx%2fa`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mb991xx%2fa`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc024xx%2fa`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc026xx%2fa`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc118xx%2fa`,
        fs:  `cpe:2.3:a:sun:chilisoft:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc226xx%2fa`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc371xx%2fa`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc372xx%2fa`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.441:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc373xx%2fa`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc374xx%2fa`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:macbook_pro:mc375xx%2fa`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd2.m5xx0_firmware:1.24.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mail:-`,
        fs:  `cpe:2.3:h:cisco:telepresence_mcu_4515:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mail:2.0`,
        fs:  `cpe:2.3:h:xerox:phaser_7500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mail:3.5`,
        fs:  `cpe:2.3:a:ddsn:cm3_acora_content_management_system:5.5.0\/1b-p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mdnsresponder:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:motion:5.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:motion:5.0.1`,
        fs:  `cpe:2.3:a:fireflymediaserver:firefly_media_server:1.0.0.1359:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:motion:5.0.2`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:motion:5.0.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.264:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:motion:5.0.4`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.3:7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:motion:5.0.5`,
        fs:  `cpe:2.3:a:koha:koha:3.14.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:motion:5.0.6`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:motion:5.0.7`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:mpeg2_codec:6.0:-:windows`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p482:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:numbers:3.5`,
        fs:  `cpe:2.3:a:ibm:application_support_facility:3.4.0:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:2.0`,
        fs:  `cpe:2.3:a:teradata:sql_assistant:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7.4\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:2.1.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:2.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:2.2.1`,
        fs:  `cpe:2.3:a:ca:ehealth_systemedge:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:2.2.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:3.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:3.0.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:3.0.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.03a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:3.0.3`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.19.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:3.1`,
        fs:  `cpe:2.3:a:drifty:ionic_view:0.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:3.1.1`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:3.1.2`,
        fs:  `cpe:2.3:a:oracle:webcenter_analytics:10.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:os_x_server:4.0`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.5:-:-:*:documentum:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:pages:2.0`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.1:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:pages:2.0.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg225a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:pages:2.0.2`,
        fs:  `cpe:2.3:a:sendmail:managed_mta:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:pages:5.0`,
        fs:  `cpe:2.3:a:oracle:sun_role_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:pages:5.0.1`,
        fs:  `cpe:2.3:a:utorrent:utorrent:1.8.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:pages:5.5.3`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:pdfkit:-`,
        fs:  `cpe:2.3:a:cloudera:hadoop:0.20.2\&#43;923:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:personal_web_sharing:-`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:personal_web_sharing:1.1`,
        fs:  `cpe:2.3:a:freeradius:freeradius:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:personal_web_sharing:1.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:personal_web_sharing:1.5.5`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_client:7.1.249_:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:apple:powerpc:-`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r006c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:preview:-`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:preview:3.0.8`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quartz_composer:-`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:-`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:3`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:3.0`,
        fs:  `cpe:2.3:a:zope:zserver:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:4.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:5.0`,
        fs:  `cpe:2.3:a:open-realty:open-realty:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:5.0.1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.60:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:5.0.2`,
        fs:  `cpe:2.3:a:snort:snort:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:5.0.2:-:windows`,
        fs:  `cpe:2.3:a:superluckycasino:slots_heaven\:free_slot_machine:1.123:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0:-:windows`,
        fs:  `cpe:2.3:a:jenkins-ci:build_failure_analyzer:1.3.0:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.0:-:mac`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.0:-:windows`,
        fs:  `cpe:2.3:a:adobe:premiere_pro_cs4:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.1`,
        fs:  `cpe:2.3:o:sun:sunos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.1:-:mac`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.92.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.1:-:windows`,
        fs:  `cpe:2.3:a:tgrmn:viceversa:2.0.0.9:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.2`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.2:-:mac`,
        fs:  `cpe:2.3:a:process-one:exmpp:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.0.2:-:windows`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.04:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.1.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.1.0:-:mac`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.1.0:-:windows`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.1.1`,
        fs:  `cpe:2.3:a:socketmail:socketmail:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.1.1:-:mac`,
        fs:  `cpe:2.3:a:apple:textedit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.1.1:-:windows`,
        fs:  `cpe:2.3:a:march-hare:cvs_suite:2009:pre-release:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.2.0`,
        fs:  `cpe:2.3:o:cisco:epc3928_docsis_3.0_8x4_wireless_residential_gateway_with_embedded_digital_voice_adapter:5.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.2.0:-:mac`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.5.3.9120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.2.0:-:windows`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.3.0`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.3.0:-:mac`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.3.0:-:windows`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.4.0`,
        fs:  `cpe:2.3:a:jruby:jruby:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.4.0:-:mac`,
        fs:  `cpe:2.3:a:hp:business_availability_center:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.4.0:-:windows`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.0.0.4080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.0`,
        fs:  `cpe:2.3:a:veritas:backup_exec_remote_agent:9.1.4691:sp4a:windows_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.0:-:mac`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp2:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.0:-:windows`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.1:-:mac`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.1:-:windows`,
        fs:  `cpe:2.3:a:tibco:spotfire_automation_services:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.2:-:mac`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:6.5.2:-:windows`,
        fs:  `cpe:2.3:a:runtastic:runtastic_heart_rate:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-51:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.0:-:mac`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.0:-:windows`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)jk4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.1`,
        fs:  `cpe:2.3:a:solarwinds:advanced_subnet_calculator:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.1:-:mac`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.8:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.1:-:windows`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.2`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:2.0.0:rev27524:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.2:-:mac`,
        fs:  `cpe:2.3:o:dell:powervault_ml6000_firmware:i8.2.0.1_\(641g.gs003\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.2:-:windows`,
        fs:  `cpe:2.3:a:digia:qt:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.3`,
        fs:  `cpe:2.3:a:crunchify:foursquare-checkins:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.3:-:mac`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.3:-:windows`,
        fs:  `cpe:2.3:a:google:chrome:10.0.630.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.4`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.4:-:mac`,
        fs:  `cpe:2.3:a:apache:traffic_server:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.4:-:windows`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:1.0.2:rev25487:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.0.8`,
        fs:  `cpe:2.3:a:bea:tuxedo:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1`,
        fs:  `cpe:2.3:a:vmware:workstation:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:52.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.0:-:mac`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100427:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.0:-:windows`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.1:-:mac`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.1:-:windows`,
        fs:  `cpe:2.3:a:ibm:api_management:3.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.2:-:mac`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.2:-:windows`,
        fs:  `cpe:2.3:a:zope:zope:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.3:-:mac`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.3:-:windows`,
        fs:  `cpe:2.3:a:gnu:gdb:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.4`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.4:-:windows`,
        fs:  `cpe:2.3:a:posh_project:posh:2.1:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.5`,
        fs:  `cpe:2.3:o:conectiva:linux:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.5:-:mac`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.5:-:windows`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0.2359:online_windows_server_2003_x64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.6`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.6:-:mac`,
        fs:  `cpe:2.3:a:mumble:mumble:1.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.1.6:-:windows`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.2`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.2.0:-:mac`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.2.0:-:windows`,
        fs:  `cpe:2.3:a:google:chrome:12.0.746.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.2.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.2.1:-:mac`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(9\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.2.1:-:windows`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.3`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.3.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.3.0:-:mac`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.3.0:-:windows`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.3.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.3.1:-:mac`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1006:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.3.1:-:windows`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.3.1.70`,
        fs:  `cpe:2.3:a:sun:solaris_pc_netlink:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4`,
        fs:  `cpe:2.3:a:efendimizin_sunnetleri_project:efendimizin_sunnetleri:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.0:-:mac`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.0:-:windows`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(23a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.1`,
        fs:  `cpe:2.3:a:xnview:xnview:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.1:-:mac`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.1:-:windows`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.5`,
        fs:  `cpe:2.3:h:axis:2401_video_server:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.5:-:mac`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0005_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.4.5:-:windows`,
        fs:  `cpe:2.3:a:iss:internet_scanner:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.5.0`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.5.0:-:mac`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.5.0:-:windows`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.5.5`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.5.5:-:mac`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.5.5:-:windows`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.6.0`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.3:e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.6.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_fasttrack:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.6.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.6.5`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.6.6`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.6.7`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.07.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.6.8`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.6.9`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.1`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.2`,
        fs:  `cpe:2.3:a:google:chrome:42.0.2311.107:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.4t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.4`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.5`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.6`,
        fs:  `cpe:2.3:o:cisco:ios:11.3aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.7`,
        fs:  `cpe:2.3:a:isc:bind:9.2.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.7.8`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.60.92.0`,
        fs:  `cpe:2.3:a:twilightcms:twilight_cms:5.17:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.62.14.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.64.17.73`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p5_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.65.17.80`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.66.71.0`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.67.75.0`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.68.75.0`,
        fs:  `cpe:2.3:a:pax_project:pax:1\:20140703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.69.80.9`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.70.80.34`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime:7.71.80.42`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime_broadcaster:4.1.3`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime_darwin_mp3_broadcaster:-`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime_pictureviewer:-`,
        fs:  `cpe:2.3:a:avast:free_antivirus:11.1.2253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime_streaming_server:-`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.6\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quicktime_streaming_server:4.1.1`,
        fs:  `cpe:2.3:a:samba:samba:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:quictime:7.7.4`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:-`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:2.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:2.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:3.0`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2007:11.0.703.32:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:3.1`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:3.2`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:3.3`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:3.4`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:3.5`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:3.5.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:remote_desktop:3.7`,
        fs:  `cpe:2.3:a:iomega:hotburn:2.3.1:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:-`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:7.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0:beta`,
        fs:  `cpe:2.3:a:visualware:myconnection_server:8.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0:beta2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:3.3\(5\)sr2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0.0`,
        fs:  `cpe:2.3:a:nuance:paperport:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0.0b1`,
        fs:  `cpe:2.3:a:citrix:access_gateway_plug-in:9.3:57-5:*:*:enterprise:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0.0b2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)xb2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0.3:85.8`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0.3:85.8.1`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.0b1:-:mac`,
        fs:  `cpe:2.3:h:hp:0235a0e7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.1`,
        fs:  `cpe:2.3:a:synology:download_station:3.8.3-3458:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.1.0`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.1.1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.2.0`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.2.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.2.2`,
        fs:  `cpe:2.3:a:redhat:tcpdump:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.2.3`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.2.4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.2.5`,
        fs:  `cpe:2.3:a:rising-global:rising_antivirus:22.83.00.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.3`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.3.0`,
        fs:  `cpe:2.3:a:sympa:sympa:2.2.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.3.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.3.2`,
        fs:  `cpe:2.3:a:google:chrome:10.0.603.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.3.2:312.5`,
        fs:  `cpe:2.3:a:jenkins:git:2.4.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:1.3.2:312.6`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.389:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.00:-:*:*:*:redhat_enterprise_linux:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.0`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.1`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.2`,
        fs:  `cpe:2.3:h:cisco:rv130w_wireless-n_multifunction_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.3`,
        fs:  `cpe:2.3:a:ibm:flex_system_manager:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.3:417.8`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.3:417.9`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.3:417.9.2`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.3:417.9.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.4`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp4:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:2.0.4:-:mac`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3`,
        fs:  `cpe:2.3:h:cisco:telepresence_codec_c90:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0`,
        fs:  `cpe:2.3:a:ubercart_views_project:uc_views:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.0:-:mac`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1285.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.0b`,
        fs:  `cpe:2.3:a:pocketknife_bravo_super_project:pocketknife_bravo_super:0.54.13345.33028:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.0b:-:windows`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.1:-:mac`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.1:beta`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.6c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.1b`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.1b:-:windows`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-26t-si_ls-s3100-26t-si-ac-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.2:-:mac`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.46:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.2b`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.07.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.2b:-:windows`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.3`,
        fs:  `cpe:2.3:a:xnview:xnview:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.3:-:mac`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-72:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.3b`,
        fs:  `cpe:2.3:a:playscape:ninja_chicken_adventure_island_:1.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.3b:-:windows`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.8:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1017:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.4:-:mac`,
        fs:  `cpe:2.3:a:shareaholic:sexybookmarks:6.1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.4b`,
        fs:  `cpe:2.3:o:virtualaccess:gw6110a_firmware:10.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.0.4b:-:windows`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.1.0`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_windows:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.1.0:-:mac`,
        fs:  `cpe:2.3:a:gajim:gajim:0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.1.0b`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.1.0b:-:windows`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.1.1`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.44:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.1.1b:-:windows`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.1.2`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.1.2b:-:windows`,
        fs:  `cpe:2.3:a:apache:apr-util:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.2.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.2.0b:-:windows`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.2.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.2.1b:-:windows`,
        fs:  `cpe:2.3:a:gnu:gnats:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.2.2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:3.2.2b:-:windows`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.0:beta`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.0.0b`,
        fs:  `cpe:2.3:a:citrix:desktop_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.0.1`,
        fs:  `cpe:2.3:a:f5:linerate:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.0.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.0.3`,
        fs:  `cpe:2.3:a:otrs:faq:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.0.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.0.5`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.1`,
        fs:  `cpe:2.3:a:x.org:x11:6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.1.1`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:4.1.2`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.0`,
        fs:  `cpe:2.3:o:y-cam:yck004_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.0.1`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.0.2`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.0.4`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.0.5`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.5.0.4306:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.0.6`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.1.1`,
        fs:  `cpe:2.3:h:buffalotech:wmr-433:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.1.2`,
        fs:  `cpe:2.3:a:plataformatec:devise:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.1.3`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle:7.4.1.834:*:*:*:trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.1.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.1.5`,
        fs:  `cpe:2.3:o:novell:suse_linux:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.1.6`,
        fs:  `cpe:2.3:a:monotone:monotone:0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:5.1.7`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd242a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.0.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.0.2`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.0.3`,
        fs:  `cpe:2.3:a:luracast:restler:1.5.5:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.0.4`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.0.5`,
        fs:  `cpe:2.3:a:google:v8:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce_suite_marketplace:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.1.2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.1.3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1077.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.1.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.1.5`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.2.4`,
        fs:  `cpe:2.3:a:biscom:faxcom_server:6.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.2.5`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:6.2.6`,
        fs:  `cpe:2.3:a:phusion:passenger:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.0`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.0.1`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.5:-:-:*:enterprise:-:-:compuset_engine`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.0.2`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.0.3`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.0.4`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.4:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.0.5`,
        fs:  `cpe:2.3:h:supermicro:h8dgu-ln4f\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.1.4`,
        fs:  `cpe:2.3:a:powerprogrammer:web_update_wizard:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.1.5`,
        fs:  `cpe:2.3:a:mathijs_koenraadt:search_api_sorts:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:7.1.6`,
        fs:  `cpe:2.3:a:google:chrome:17.0.926.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:8.0`,
        fs:  `cpe:2.3:a:ssh:secure_shell:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:8.0.4`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:8.0.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:8.0.6`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:8.0.8`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:9.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:9.0.2`,
        fs:  `cpe:2.3:a:hp:network_automation:9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:9.0.3`,
        fs:  `cpe:2.3:a:altova:databasespy_2012:-:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:9.1`,
        fs:  `cpe:2.3:a:aol:aim:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:9.1.1`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:9.1.3`,
        fs:  `cpe:2.3:a:pay_per_media_player_project:pay_per_media_player:1.24:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:10.0.3`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:10.1`,
        fs:  `cpe:2.3:a:emc:vipr_srm:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:10.1.1`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:10.1.2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:11.0`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:safari:11.0.1`,
        fs:  `cpe:2.3:a:ca:unicenter_tng:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:server_manager:-`,
        fs:  `cpe:2.3:h:technicolor:tc7200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:software_update:-`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:software_update:2.1.0.110`,
        fs:  `cpe:2.3:a:ca:cleverpath_aion:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:software_update:2.1.1.116`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:software_update:2.1.2.120`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:software_update:2.1.3.127`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.13-60.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:tcp_ip_configuration_utility:-`,
        fs:  `cpe:2.3:a:condor_project:condor:7.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:terminal:-`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:textedit:-`,
        fs:  `cpe:2.3:a:mcafee:security_for_microsoft_exchange:7.6.7718.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:transporter:1.9.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watch_os:2.2.2`,
        fs:  `cpe:2.3:a:halanew:sunnat_e_rasool:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:1.0`,
        fs:  `cpe:2.3:a:mikejolley:download_monitor:1.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:1.0.1`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.21:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:2.0`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:2.0.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:2.1`,
        fs:  `cpe:2.3:a:google:chrome:59.0.3071.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:2.2`,
        fs:  `cpe:2.3:a:isc:bind:9.11.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:2.2.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.9.0.1380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:2.2.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:2.2.2`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.6.1.629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:3.0`,
        fs:  `cpe:2.3:a:welcart:welcart_plugin:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:3.1`,
        fs:  `cpe:2.3:h:y-cam:ycblhd5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:3.1.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.50:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:3.1.3`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:apple:watchos:3.2`,
        fs:  `cpe:2.3:a:innominate:eagle_mguard:hw-201000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webcore:-`,
        fs:  `cpe:2.3:a:isc:bind:9.2.7:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:-`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:51`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:85`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:85.7`,
        fs:  `cpe:2.3:a:oracle:webcenter_content:11.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:85.8.2`,
        fs:  `cpe:2.3:a:landesk:landesk_security_suite:8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:85.8.5`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:103`,
        fs:  `cpe:2.3:a:techsmith:snagit:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:106.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:124`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:125.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:125.4`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:125.5.5`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:125.5.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:312.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:312.5`,
        fs:  `cpe:2.3:a:veeam:backup_and_replication:8.0.0.2030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:312.5.2`,
        fs:  `cpe:2.3:h:polycom:hdx_7001:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:312.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:312.8.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:412`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:412.6`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:412.7`,
        fs:  `cpe:2.3:a:emc:documentum_records_manager:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:413`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:416.11`,
        fs:  `cpe:2.3:h:softbank:mobile_wi-fi_router:101sb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:416.12`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:417.9`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:417.10`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:418`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1036:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:418.8`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:418.9`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:418.9.1`,
        fs:  `cpe:2.3:a:nortel:11c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:419`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:419.2`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:419.2.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:420`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:512.11`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:512.11.3`,
        fs:  `cpe:2.3:a:ibm:java:6.0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:522`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:522.8.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:522.10.1`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:522.12.1`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.40.020.1248:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webkit:522.13.1`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:weblog_server:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webobjects:-`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webobjects:3.1`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webobjects:3.5`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webobjects:4.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.3\(2h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webobjects:4.5`,
        fs:  `cpe:2.3:h:symantec:gateway_security_5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webobjects:5.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webobjects:5.1`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:webobjects:5.2`,
        fs:  `cpe:2.3:a:gsview:gsview:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:1.5.0`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_redundant_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:2.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:2.1.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:2.2.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.15:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:2.3.0`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:2.4.0`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.64.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:2.4.1`,
        fs:  `cpe:2.3:a:gnu:bash:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.1.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.1.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.10:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.1.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.1.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.2.2`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.2.3`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.4:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.2.4`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:3.2.5`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.0`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:8.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.0.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.0.2`,
        fs:  `cpe:2.3:a:lemon-s_php:simple_oekaki_bbs:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.1.1`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:6.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.2`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.2.1`,
        fs:  `cpe:2.3:a:altiris:client_service:6.0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.3`,
        fs:  `cpe:2.3:a:adobe:connect:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.3.1`,
        fs:  `cpe:2.3:h:cisco:c200_m1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.3.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.3.3`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc2202:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:4.4`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:6.1`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:6.1.1`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-backup:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:6.2`,
        fs:  `cpe:2.3:a:girlsgames123:kiss_kiss_office:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:6.4`,
        fs:  `cpe:2.3:a:ibm:db2:9.0:fp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:7.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:7.1.1`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:7.2.1`,
        fs:  `cpe:2.3:a:sqldts:dtsbackup:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xcode:7.3.1`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xsan:-`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xsan:1.0`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xsan:1.2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xsan:1.3`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.2:*:pro:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apple:xserve_lights-out_management:-`,
        fs:  `cpe:2.3:a:atlassian:jira:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apploi:apploi_job_search-_find_jobs:4.19::~~~android~~`,
        fs:  `cpe:2.3:h:rockwellautomation:micrologix_1400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appnitro:machform:2.0`,
        fs:  `cpe:2.3:a:teradata:administrator:13.10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appnitro:machform:3.5`,
        fs:  `cpe:2.3:a:hp:performance_core:10.50.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.13`,
        fs:  `cpe:2.3:a:ibm:informix:7.25_.uc2_se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.13.1`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.13.2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.13.3`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.14`,
        fs:  `cpe:2.3:a:nero:nero_soundtrax_help:4.0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.14.1`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.14.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.14.3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.0:pre.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.14.4`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.14.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.14.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.14.7`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.15`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.15.1`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.16`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.16.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.16.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.17`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.2.1.830:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apport_project:apport:2.20.3`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apppasta:aerospace_jobs:1.399::~~~android~~`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:0.1.0`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:0.1.1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:0.1.2`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:0.1.3`,
        fs:  `cpe:2.3:a:debian:duplicity:0.4.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:0.1.4`,
        fs:  `cpe:2.3:a:hp:openview_cross_platform_component_java:3.10.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:0.1.5`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:0.2.1.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:3.0.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3080_concentrator:4.7.1.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprain:apprain:3.0.2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1292.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apprenticeuitgevers:schoolxm:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0.0:preview2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apps2you:cedar_kiosk:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apps4u%40android:sd_card_manager:20140223::~~~android~~`,
        fs:  `cpe:2.3:a:brocade:smi_agent:120.7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apps4u%40android:sd_card_manager:20140224::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appsflyer:appsflyer:-::~~~android~~`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appsgeyser:backyard_wrestling:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appsgeyser:btd5_videos:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appsgeyser:competition_information:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:isc:bind:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appstronautme:cleveland_football_stream:2.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appstros:appstros_-_free_gift_cards%21:1.1.3::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appsworld:condor_s.e.:1.399::~~~android~~`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apptalk_project:apptalk:1.4.8::~~~android~~`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apptha:contus_video_gallery:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apptha:wordpress_video_gallery:2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wali:walisms_cn:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appthemes:classipress:3.0.5.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appthemes:classipress:3.0.5.3`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appthemes:classipress:3.1.3`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.0:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:appthemes:classipress:3.1.4`,
        fs:  `cpe:2.3:a:f-secure:ssh_client:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appthemes:classipress:3.1.5`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apptive:horsepower:2.10.11::~~~android~~`,
        fs:  `cpe:2.3:a:joachim_noreiko:flag_module:7.x-3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:apptreestudios:gangsta_auto_thief_iii:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:appytimes:mr_whippet_-_yorkshire_ice:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:monotone:monotone:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aprel:exe_to_msi_converter_free:1.2.0`,
        fs:  `cpe:2.3:a:unify:sqlbase_sqlconsole:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aprelium:abyss_web_server_x1:2.3.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aprelium:abyss_web_server_x1:2.3.2:-:win32`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aprelium:abyss_web_server_x1:2.4.0.3`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aprelium:abyss_web_server_x1:2.4.0.3:-:win32`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:april%27s_super_functions_pack_project:april%27s_super_functions_pack:1.4.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2967:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aptana:aflax:1.0`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.1:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aptana:aptana_studio:2.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.30:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aptexx:resident_anywhere:-`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.2.1.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arabia2000:car_wallpapers_hd:1.3::~~~android~~`,
        fs:  `cpe:2.3:h:siemens:scalance_x201-3pirt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arabic_troll_football_project:arabic_troll_football:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.6f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arabportal:arab_portal:3.0`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:arbiter:1094b_gps_substation_clock:-`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:arbiter:power_sentinel:1133a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p311:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arbiter:power_sentinel_1133a_firmware:11jun2012`,
        fs:  `cpe:2.3:h:cisco:catalyst_2940:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arbiter:power_sentinel_1133a_firmware:11jun2012:rev421`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.40:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arbornetworks:peakflow_sp:5.1.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1008:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arbornetworks:peakflow_sp:5.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arbornetworks:peakflow_sp:5.6.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcanadev:adtempus:2.1.0004`,
        fs:  `cpe:2.3:a:isc:bind:9.9.7:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcanadev:adtempus:3.00.0601`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcanadev:adtempus:3.00.0703`,
        fs:  `cpe:2.3:a:david_king:vino:2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcanadev:adtempus:3.00.0800`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcanadev:arcana_scheduler:2.3.0202`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcanadev:sql_server_for_adtempus:1.00.0000`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcananet:opsxml:2.1.1.96`,
        fs:  `cpe:2.3:h:emc:dmx_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:archangelmgt:weblog:-`,
        fs:  `cpe:2.3:a:debian:debian-goodies:0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:archangelmgt:weblog:0.90.02`,
        fs:  `cpe:2.3:a:helios:textpad:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:archmage_project:archmage:0.2.4`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arclogics:cch_teammate_desktop:9.1.0.0000`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arclogics:cch_teammate_nt_services:9.1.0.0000`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arclogics:cch_teammate_tools:9.1.0.0000`,
        fs:  `cpe:2.3:o:toshibacommerce:4690_point_of_sale_operating_system:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.2.4`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.4.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.4.1`,
        fs:  `cpe:2.3:a:runtastic:runtastic_me:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.5.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.6.4`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.0`,
        fs:  `cpe:2.3:a:richard_cook:rgpg:0.2.4:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.2`,
        fs:  `cpe:2.3:a:cisco:ios:15.2\(2\)ea1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.3`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.4`,
        fs:  `cpe:2.3:a:google:chrome:49.0.2623.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.5`,
        fs:  `cpe:2.3:a:vmware:tools:8.4.6.16648:*:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.7`,
        fs:  `cpe:2.3:a:websvn:websvn:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.9`,
        fs:  `cpe:2.3:a:python:python:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.10`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.11`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.12`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.13`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.14`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arco_van_geest:goof_fotoboek:1.7.15`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.01:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_console:4.0.2.0:sp2`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_console:4.0.3.0:sp3`,
        fs:  `cpe:2.3:a:redhat:certificate_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_console:4.0.3.5:sp3_patch_5`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_console:5.0.0.0`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_console:5.0.1.0:sp1`,
        fs:  `cpe:2.3:a:ibm:daeja_viewone:4.1.5.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_console:5.0.1.2:sp1_patch_2`,
        fs:  `cpe:2.3:a:gnome:tomboy:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_smartconnector:4.0.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_smartconnector:5.0.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsight:arcsight_smartconnector:5.0.5.0`,
        fs:  `cpe:2.3:a:oracle:reports:6.0.8.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:panorama_maker:3.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:3`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:4`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.5:*:pro:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:4.0`,
        fs:  `cpe:2.3:a:skydrive_assistant_project:skydrive_assistant:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:4.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_fasttrack:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:5`,
        fs:  `cpe:2.3:a:sympa:sympa:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:6.5`,
        fs:  `cpe:2.3:h:dell:poweredge_2850:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photoimpression:7`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:photostudio:5.5`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arcsoft:totalmedia_backup:1.1.2.13`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ardour:ardour:2.8.8`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ardour:ardour:2.8.10`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ardour:ardour:2.8.11`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2.5:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arduino_json_project:arduino_json:4.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.5.3\(2115\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:application_control_solution:6.1.1318`,
        fs:  `cpe:2.3:a:gnome:gnome-keyring:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_application_control_language_pack:6.1.1100`,
        fs:  `cpe:2.3:a:h2o_project:h2o:2.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_application_control_report_language_pack:6.1.1102`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_application_control_report_pack:6.1.1202`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_common:6.0.1417`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_common_language_pack:6.0.1101`,
        fs:  `cpe:2.3:a:infoblox:netmri:6.2.1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_common_report_language_pack:6.0.1101`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_common_report_pack:6.0.1103`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_file_inventory_language_pack:6.1.1100`,
        fs:  `cpe:2.3:a:mcafee:application_control:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_file_inventory_report_pack:6.1.1100`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_file_inventory_report_pack_language_pack:6.1.1100`,
        fs:  `cpe:2.3:a:php:pear:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_file_inventory_solution:6.1.1312`,
        fs:  `cpe:2.3:a:citrix:presentation_server_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arellia:arellia_local_security_report_pack:6.2.1401`,
        fs:  `cpe:2.3:h:hp:jc474a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.4.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.4.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.4.1.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.4.2`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.5.0`,
        fs:  `cpe:2.3:a:gajennings:this:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.6.0`,
        fs:  `cpe:2.3:a:novell:ichain:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.7.0`,
        fs:  `cpe:2.3:a:nero:nero:9.0.9.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.7.1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:arg0:encfs:1.7.2`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2008-05-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:0.1.0`,
        fs:  `cpe:2.3:h:dell:latitude_e6220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:0.2.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:0.2.1`,
        fs:  `cpe:2.3:a:novell:netware:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:0.2.2`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:0.3.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:0.6.0`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:0.7.0:beta_8`,
        fs:  `cpe:2.3:a:ibm:disposal_and_governance_management_for_it:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.0.0`,
        fs:  `cpe:2.3:a:telos:xacta_asset_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.0.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.0.3`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.416.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.1.1`,
        fs:  `cpe:2.3:a:nuance:omnipage:4.0:*:*:*:se:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.2.0`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.3.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_metadata_workbench:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.3.1`,
        fs:  `cpe:2.3:a:sun:storedge_enterprise_backup_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.3.2`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.3.3`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_1m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.3.4`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.3.5`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.3.6`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.3.7`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:argyllcms:argyllcms:1.4.0`,
        fs:  `cpe:2.3:a:aware:nistpack_sdk:4.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ariel_barreiro:noderecommendation:6.x-1.0`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ariel_barreiro:noderecommendation:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.3:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arj_software:arj_archiver:3.10.22`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ark-web:a-form:1.3.6`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ark-web:a-form:2.0.3`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ark-web:a-form_bamboo:1.3.6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ark-web:a-form_bamboo:2.0.3`,
        fs:  `cpe:2.3:a:rxspencer_project:rxspencer:3.8.g5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ark-web:a-form_pc:3.1`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ark-web:a-form_pc_mobile:3.1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.2`,
        fs:  `cpe:2.3:o:juniper:junos:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.3`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.4`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.5`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(8a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(9a\)bc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.8`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.9`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p89:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.11`,
        fs:  `cpe:2.3:a:oracle:service_contracts:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.12`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:armin_burgmeier:net6:1.3.13`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arraynetworks:ssl_vpn_client:840264`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:arris:sbg901:-`,
        fs:  `cpe:2.3:a:isc:bind:9.10.1:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:arris:touchstone_tg862g%2fct:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arris:touchstone_tg862g%2fct_firmware:7.6.59s.ct`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arris:vap2500_firmware:08.41`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.2`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.7.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.2.1`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.3`,
        fs:  `cpe:2.3:a:clearone:converge_console:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.4`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.4.1`,
        fs:  `cpe:2.3:a:giantrobot:zipcart:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.5`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20150228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.2`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.4`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.5`,
        fs:  `cpe:2.3:a:mb_tickets_project:mb_tickets:3.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.6`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.7`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.0b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.7.1`,
        fs:  `cpe:2.3:a:ibm:maximo_service_desk:7.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.7.2`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.8`,
        fs:  `cpe:2.3:a:hp:ocr_software_by_i.r.i.s:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.9`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.10`,
        fs:  `cpe:2.3:a:keepass:keepass:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.11`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.6.12`,
        fs:  `cpe:2.3:o:hp:thinpro:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.794.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.2`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.5`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.6`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.7`,
        fs:  `cpe:2.3:a:clamav:clamav:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.8`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.9`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.10`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.11`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.12`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.13`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.14`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p158:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.15`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.16`,
        fs:  `cpe:2.3:a:divx:player:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.17`,
        fs:  `cpe:2.3:a:sun:java_system_communications_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.7.18`,
        fs:  `cpe:2.3:a:digia:qt:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.0`,
        fs:  `cpe:2.3:a:siemens:scalance_x-408_firmware:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.1`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:05-00-\/i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.4`,
        fs:  `cpe:2.3:a:emc:avamar:5.0.0-407:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.5`,
        fs:  `cpe:2.3:h:sensatronics:e4_temperature_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.6`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.7`,
        fs:  `cpe:2.3:a:gnu:icecat:2.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.9`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:10.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.10`,
        fs:  `cpe:2.3:a:hp:imc_branch_intelligent_management_system_software_module:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.11`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arthurdejong:nss-pam-ldapd:0.8.12`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifectx:xclassified:1.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:6.0`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:6.01`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:6.50`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.2:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:7.00`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:7.03`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:7.04`,
        fs:  `cpe:2.3:a:php:pear:1.2b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.00`,
        fs:  `cpe:2.3:a:autodesk:autocad_civil_3d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.11`,
        fs:  `cpe:2.3:a:google:chrome:5.0.366.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.12`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.13`,
        fs:  `cpe:2.3:a:rakus:maildealer:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.14`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.8:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.50`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.51`,
        fs:  `cpe:2.3:a:netscape:navigator:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.52`,
        fs:  `cpe:2.3:a:packagekit_project:packagekit:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.53`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100518.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:afpl_ghostscript:8.54`,
        fs:  `cpe:2.3:h:hp:j9475a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:ghostscript:8_64`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(2\)n2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:ghostscript_fonts:6.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.493.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:ghostscript_fonts:8.11`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.01`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.15`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.50`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.51`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.54`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.56`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.14.15926:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.57`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1290.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.60`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.61`,
        fs:  `cpe:2.3:a:realflex:realwin:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.62`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.63`,
        fs:  `cpe:2.3:a:mozilla:camino:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.64`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.70`,
        fs:  `cpe:2.3:a:mortbay:jetty:7.0.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:8.71`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:9.00`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:9.02`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript:9.04`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:gpl_ghostscript_lite:8.70`,
        fs:  `cpe:2.3:a:hp:openview_perl:5.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mujs:-`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(4c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mupdf:1.0`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mupdf:1.1`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mupdf:1.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mupdf:1.3`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mupdf:1.9`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mupdf:1.10a`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mupdf:2008.09.02`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artifex:mupdf:2009.02.23`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artiphp:artiphp_cms:5.5.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.3`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.4`,
        fs:  `cpe:2.3:a:healthadvocate:health_advocate_smarthelp:3.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5.7`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5.8`,
        fs:  `cpe:2.3:a:tibco:silver_mobile:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5.9`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5.10`,
        fs:  `cpe:2.3:a:softwarefx:chartfx_net_silent_setup:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5.11`,
        fs:  `cpe:2.3:h:ibm:iseries:5.0:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5.12`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5.13`,
        fs:  `cpe:2.3:a:adobe:robohelp:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artis.imag:basilic:1.5.14`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.0.8.8`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.0.1`,
        fs:  `cpe:2.3:o:huawei:s2300_firmware:v100r006c00spc800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.0.2`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.0.3`,
        fs:  `cpe:2.3:a:ntop:ntop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.0.4`,
        fs:  `cpe:2.3:o:suse:linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.0.5`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.0`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1036.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.2`,
        fs:  `cpe:2.3:a:agilebits:1password:3.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.3`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.4`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.5`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.11.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.7`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.99.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.8`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.9`,
        fs:  `cpe:2.3:o:cisco:catos:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.2.10`,
        fs:  `cpe:2.3:a:emc:rsa_netwitness_nextgen:9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.3.0`,
        fs:  `cpe:2.3:a:ibm:spss_statistics:21.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.3.1`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.3.2`,
        fs:  `cpe:2.3:a:corel:coreldraw_filters:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.3.3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.3.4`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.3.5`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.4.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.13:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.4.1`,
        fs:  `cpe:2.3:a:apple:webkit:522.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.4.3`,
        fs:  `cpe:2.3:a:perl:perl:5.13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.4.4`,
        fs:  `cpe:2.3:a:cisco:jabber:9.7\(0\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.4.6`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.4.7`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.4.8`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.5.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.5.1`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.5.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.5.3`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:1.7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.5.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.5.5`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.5.6`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.5.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ewa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.6.0`,
        fs:  `cpe:2.3:a:sun:patchpro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.6.1`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.5.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.7.0`,
        fs:  `cpe:2.3:a:citrix:group_policy_client-side_extension:1.5.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.7.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.7.2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.7.3`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.7.4`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.7.5`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.7.6`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.8.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.8.1`,
        fs:  `cpe:2.3:a:gimp:gimp:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.6.8.3`,
        fs:  `cpe:2.3:a:samba:samba:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.0.0`,
        fs:  `cpe:2.3:a:cybozu:office:9.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.0.5`,
        fs:  `cpe:2.3:a:microsoft:office:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.1.0`,
        fs:  `cpe:2.3:a:websquare:job_web_system:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.1.1`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.6:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.1.2`,
        fs:  `cpe:2.3:o:emerson:network_power_avocent_mergepoint_unity_2016_firmware:1.9.16473:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.2.0`,
        fs:  `cpe:2.3:a:sun:jre:1.3.0:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.4.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.5.0`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)sy3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.7.34`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.7.35`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:artonx.org:activescriptruby:1.8.7.36`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.5_build_736:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:airwave:7.7.13`,
        fs:  `cpe:2.3:o:juniper:ive_os:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:airwave:8.0.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.1.3.7`,
        fs:  `cpe:2.3:a:x:libxcb:1.1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.1.3.8`,
        fs:  `cpe:2.3:h:huawei:mt882:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.1.3.9`,
        fs:  `cpe:2.3:a:commvault:exchange_webproxy_archiver_agent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.1`,
        fs:  `cpe:2.3:a:autodesk:sketchbook_pro:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.97b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.4`,
        fs:  `cpe:2.3:a:intel:system_setup_utility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.5`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.6`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.7`,
        fs:  `cpe:2.3:a:php:php:5.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.8`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.2.3.9`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.0.0`,
        fs:  `cpe:2.3:a:affinitycu:affinity_mobile_atm_locator:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1`,
        fs:  `cpe:2.3:a:locationvalue:restaurant_karaoke_shidax:1.3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.3`,
        fs:  `cpe:2.3:a:php:php:5.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.4`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.6`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.7`,
        fs:  `cpe:2.3:a:apache:struts:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.8`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.10`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:31.07.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.11`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.12`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.13`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.3.1.14`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.9.95478.509:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.4.2.3`,
        fs:  `cpe:2.3:a:e-isg:visual_asset_manager:5.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.4.2.4`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:arubaos:6.4.2.5`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.40.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:5.0.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:5.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:5.2`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:6.0.1`,
        fs:  `cpe:2.3:o:hp:hp-ux:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:6.0.2`,
        fs:  `cpe:2.3:a:gnu:anubis:3.9.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:6.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.19116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:6.1.4.61696`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_microsoft_identity_integration_server:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:6.2`,
        fs:  `cpe:2.3:h:hp:digital_sender_9200c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:6.2.6.62196`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:6.3`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass:6.3.4`,
        fs:  `cpe:2.3:a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass_guest:3.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd344a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass_guest:3.1`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass_guest:3.2`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass_guest:3.3`,
        fs:  `cpe:2.3:o:cisco:spa3102_voice_gateway_with_router_firmware:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass_guest:3.5`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass_guest:3.7`,
        fs:  `cpe:2.3:h:logitec:lan-w300n\/r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass_guest:3.9`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:arubanetworks:clearpass_policy_manager:6.3.0.60730`,
        fs:  `cpe:2.3:a:luratech:lurawave_jp2_activex_control:2.1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:arubanetworks:instant_access_point:-`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:instant_access_point_firmware:4.0.0.6`,
        fs:  `cpe:2.3:a:phusion:passenger:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:instant_access_point_firmware:4.1.0.0`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:instant_access_point_firmware:4.1.0.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:instant_access_point_firmware:4.1.0.2`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:instant_access_point_firmware:4.1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:beta.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:arubanetworks:instant_access_point_firmware:4.1.1.1`,
        fs:  `cpe:2.3:a:sophos:anti-virus:9.5.1:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:asg:asg-report.web:3.2.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:asg:asg_report.web_insight_viewer:3.2.1_%28build_367%29`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ashok88:jja-_juvenile_justice_act_1986:1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:infosphere_metadata_workbench:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:asial:monaca_debugger:1.4.1`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:asial:monaca_debugger:1.4.2`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.2920.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ask:ask.com:2.2.5::~~~android~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ask:ask_toolbar:1.6.5.0`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ask:ask_toolbar:1.8.0.0`,
        fs:  `cpe:2.3:a:saltstack:salt:0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ask:ask_toolbar:1.13.1.0`,
        fs:  `cpe:2.3:a:sap:xi_3.1_integration_for_sap_solutions_applications:12.3.0.601:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askapache:firefox_adsense:3.0`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.40`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.41`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.42`,
        fs:  `cpe:2.3:a:kennziffer:ke_dompdf:0.0.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.43`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1667.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.44`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.45`,
        fs:  `cpe:2.3:a:x:libxt:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.46`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:346.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.47`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.223:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.48`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askbot:askbot:0.7.49`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:askia:askiaweb:-`,
        fs:  `cpe:2.3:a:mobilizedsolutions:aloha_stadium_-_hawaii:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:asp-dev:xm_diary:-`,
        fs:  `cpe:2.3:a:splunk:splunk:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:asp-dev:xm_forums:-:rc3`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:aspen:aspen:0.8`,
        fs:  `cpe:2.3:a:google:chrome:13.0.777.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aspen:aspen:0.22`,
        fs:  `cpe:2.3:h:oberthur:id-one_cosmo:5.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aspen:aspen:0.29`,
        fs:  `cpe:2.3:a:gnu:anubis:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:asperasoft:aspera_client:2.6.3.28253`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:association_min_ajlik_project:association_min_ajlik:1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:assyrianapp:assyrian:2.2::~~~android~~`,
        fs:  `cpe:2.3:h:symantec:gateway_security_5300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:astaro:security_gateway:-`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:astaro:security_gateway_software:8.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3015_concentrator:4.7\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:astaro:security_gateway_software:8.305`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:dsl-n55u:-`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:dsl-n56u_firmware:1.0.0.9`,
        fs:  `cpe:2.3:o:cisco:ios:15.4sn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:dsl-n56u_firmware:3.0.0.4.188`,
        fs:  `cpe:2.3:a:hummingbird:dm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:dsl-n56u_firmware:3.0.0.4.314`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:dsl-n56u_firmware:3.0.0.4.364`,
        fs:  `cpe:2.3:h:hp:storevirtual_4335:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:asus:ipswcom_activex_component:1.0.0.1`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:asus:net4switch:1.0.0020`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-ac56r:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-ac56s:-`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac56s_firmware:3.0.0.4.376.3715`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-ac66r:-`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-ac66u:-`,
        fs:  `cpe:2.3:a:digium:asterisk:14.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac66u_firmware:3.0.0.4.140`,
        fs:  `cpe:2.3:a:google:chrome:14.0.801.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac66u_firmware:3.0.0.4.220`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:9.9.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac66u_firmware:3.0.0.4.246`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac66u_firmware:3.0.0.4.260`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac66u_firmware:3.0.0.4.270`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.2.0-283.rhel5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac66u_firmware:3.0.0.4.354`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert1_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-ac68u:-`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac68u_firmware:3.0.0.4.374.4755`,
        fs:  `cpe:2.3:a:ibm:jazz_reporting_service:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac68u_firmware:3.0.0.4.374.5047`,
        fs:  `cpe:2.3:a:openafs:openafs:1.3.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac68u_firmware:3.0.0.4.374_4561`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution_assurance:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac68u_firmware:3.0.0.4.374_4887`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac68u_firmware:3.0.0.4.374_4983`,
        fs:  `cpe:2.3:a:openx:openx:2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac68u_firmware:3.0.0.4.376.3715`,
        fs:  `cpe:2.3:a:recoverytoolbox:recovery_toolbox_for_outlook_password:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-ac87u:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-ac87u_firmware:3.0.0.4.378.3754`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-g32:-`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110726:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-g32_firmware:2.0.2.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p266:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-g32_firmware:2.0.3.2`,
        fs:  `cpe:2.3:a:ibm:algo_credit_limits:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n10%2bd1:-`,
        fs:  `cpe:2.3:a:isc:dhcpd:2.0.pl5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n10%2bd1_firmware:2.1.1.1.70`,
        fs:  `cpe:2.3:a:amd:app_sdk_runtime:2.4.595.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n10e:-`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n10e_firmware:2.0.0.7`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n10e_firmware:2.0.0.10`,
        fs:  `cpe:2.3:a:mit:pgp_public_key_server:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n10e_firmware:2.0.0.16`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n10e_firmware:2.0.0.19`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n10e_firmware:2.0.0.20`,
        fs:  `cpe:2.3:a:juniper:smartpass:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n10e_firmware:2.0.0.24`,
        fs:  `cpe:2.3:a:combodo:itop:2.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n10e_firmware:2.0.0.25`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n14u:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p56:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n14u_firmware:3.0.0.4.322`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n14u_firmware:3.0.0.4.356`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.23:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n16:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:1.0.1.9`,
        fs:  `cpe:2.3:o:redhat:enterprise_virtualization_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:1.0.2.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:3.0.0.3.108`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr5040-dc-ovs-h3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:3.0.0.3.162`,
        fs:  `cpe:2.3:o:f5:tmos:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:3.0.0.3.178`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:3.0.0.4.220`,
        fs:  `cpe:2.3:a:topdesk:topdesk:5.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:3.0.0.4.246`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:3.0.0.4.260`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:3.0.0.4.354`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n16_firmware:7.0.2.38b`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n56r:-`,
        fs:  `cpe:2.3:a:gentoo:nvclock:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n56u:-`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:1.0.1.4`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:1.0.1.4o`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:1.0.1.7c`,
        fs:  `cpe:2.3:a:cisco:content_security_management_virtual_appliance:9.1.0-033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:1.0.1.7f`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:1.0.1.8j`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:1.0.1.8l`,
        fs:  `cpe:2.3:a:usebb:usebb:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:1.0.1.8n`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:3.0.0.4.318`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:10.0:*:*:*:standard:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:3.0.0.4.334`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.706.2127.36662:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:3.0.0.4.342`,
        fs:  `cpe:2.3:a:shopware:shopware:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:3.0.0.4.360`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:3.0.0.4.376.3715`,
        fs:  `cpe:2.3:a:x2engine:x2crm:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:7.0.1.21`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.71a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:7.0.1.32`,
        fs:  `cpe:2.3:a:dell:openmanage_remote_access_components:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n56u_firmware:8.1.1.4`,
        fs:  `cpe:2.3:a:google:chrome:12.0.717.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n65u:-`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:4.0.1:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n65u_firmware:3.0.0.3.134`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n65u_firmware:3.0.0.3.176`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n65u_firmware:3.0.0.4.260`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n65u_firmware:3.0.0.4.334`,
        fs:  `cpe:2.3:a:intel:network_connections:16.0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n65u_firmware:3.0.0.4.342`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n65u_firmware:3.0.0.4.346`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n66r:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:rt-n66u:-`,
        fs:  `cpe:2.3:a:novell:imanager:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n66u_firmware:3.0.0.4.272`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n66u_firmware:3.0.0.4.370`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt-n66u_firmware:3.0.0.4.376.3715`,
        fs:  `cpe:2.3:a:dell:controlvault_host_components_installer:2.2.30.355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:rt_series_firmware:3.0.0.4.374.x`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:asus:video_security_online:-`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:asus:wl-330nul:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_20:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:wl-330nul_firmware:3.0.0.41`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:wrt_firmware:3.0.0.4.376.2524-g0012f52`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:asus:wrt_firmware:3.0.0.4.376_1071`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:at32:reverse_proxy:1.060.310`,
        fs:  `cpe:2.3:a:apache:log4j:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atanasoft:atanasuite_2010:8.1.3::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atanasoft:atanasuite_2011:9.1.0.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atar2b:atar2b_cms:4.0.1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atastefromheaven:angel_reigns:1.2.6.185::~~~android~~`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atcom:netvolution:1.0`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.03.0560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atcom:netvolution:2.5.6`,
        fs:  `cpe:2.3:a:hulihanapplications:hulihan_bxr:0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atcom:netvolution:3.0`,
        fs:  `cpe:2.3:a:jochen_wiedmann:html\:\:ep:0.2011:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:atecea:atecea:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:perl:perl:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:aten:cn8000:-`,
        fs:  `cpe:2.3:h:huawei:ar150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:aten:cn8000_firmware:1.6.154`,
        fs:  `cpe:2.3:a:atlassian:jira:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:aterm:wf800hp:-`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:aterm:wf800hp_firmware:1.0.17`,
        fs:  `cpe:2.3:a:apache:synapse:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:aterm:wg300hp:-`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:aterm:wg300hp_firmware:1.0.8`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aternity:aternity:9.0`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:5.2.0`,
        fs:  `cpe:2.3:h:nortel:ethernet_routing_switch_1648:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:5.2.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:5.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:5.2.3`,
        fs:  `cpe:2.3:a:symantec:norton_antispam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:5.2.4`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:5.2.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:40.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:5.2.6`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:5.2.7`,
        fs:  `cpe:2.3:a:nas4free:nas4free:9.1.0.1.847:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.0`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.2`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.3`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:1.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.4`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.5`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.6`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.7`,
        fs:  `cpe:2.3:a:icecomm:turboprep_web:1.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.8`,
        fs:  `cpe:2.3:a:erlang:crypto:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:6.0.9`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1655.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:7.0.0`,
        fs:  `cpe:2.3:a:gnome:evolution:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:7.0.0:alpha1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:7.0.0:beta1`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:7.0.0:beta2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atheme:atheme:7.2.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:athoc:athocgov:6.2.4.26`,
        fs:  `cpe:2.3:o:sun:solaris:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:athoc:enterprise_notifications_suite:6.1.8.72`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:avivo_codecs:10.0.0.40103`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:1.2`,
        fs:  `cpe:2.3:a:ibm:java:6.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:1.7.2007.318`,
        fs:  `cpe:2.3:a:google:chrome:6.0.450.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2.7`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2.8.225.2152`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2.8.717.2342`,
        fs:  `cpe:2.3:h:tek:phaser_network_printer_750:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2.8.1201.1503`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2.009.0113.2221`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2.9.211.2224`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2.9.312.2222`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:11.2.202.621:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2.9.925.1706`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2009.0113.2222.40119`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2010.0211.1740.31663`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2010.0211.1740.31663::~~~~x64~`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2011.524.2259.39378`,
        fs:  `cpe:2.3:a:tim_ban_bon_phuong_project:tim_ban_bon_phuong:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2011.707.2315.39839`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2011.728.1723.29300`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center:2011.1025.2152.37348`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_branding:1.0.0`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.70\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:0108.2146.2565.38893`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1515f-2_pn_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2008.0225.2153.39091`,
        fs:  `cpe:2.3:a:prosody:prosody:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2008.0717.2343.40629`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2008.1201.1504.27008`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2009.0113.2222.40119`,
        fs:  `cpe:2.3:a:cakewalk:cakewalk_pyro:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2009.0211.2225.40219`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb470xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2009.0312.2223.38381`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2009.0925.1707.28889`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2009.1104.959.17837`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2010.0211.1740.31663`,
        fs:  `cpe:2.3:h:cisco:spa500_series_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_implementation:2010.0302.2233.40412`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.564:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2008.225.2153.39091`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p111:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2008.717.2343.40629`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2008.1201.1504.27008`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)eo1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2009.113.2222.40119`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2009.211.2225.40219`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:02-50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2009.312.2223.38381`,
        fs:  `cpe:2.3:a:suckless:slock:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2009.925.1707.28889`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2009.1104.959.17837`,
        fs:  `cpe:2.3:h:lexmark:cx860dtfe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:alterpoint:networkauthority:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_preinstall:2010.302.2233.40412`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:108.2146.2565.38893`,
        fs:  `cpe:2.3:h:3com:3c16450-us:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2008.225.2153.39091`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2008.717.2343.40629`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2008.1201.1504.27008`,
        fs:  `cpe:2.3:a:autonomy:verity_k2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2009.113.2222.40119`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2009.211.2225.40219`,
        fs:  `cpe:2.3:a:esri:arcview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2009.312.2223.38381`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2009.925.1707.28889`,
        fs:  `cpe:2.3:h:cisco:catalyst_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2009.1104.959.17837`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:cs:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2010.211.1740.31663`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2010.302.2233.40412`,
        fs:  `cpe:2.3:a:apache:derby:10.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2010.706.2128.36662`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2010.825.2146.37182`,
        fs:  `cpe:2.3:a:saltstack:salt:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2010.910.2122.36517`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_core_static:2010.1125.2142.38865`,
        fs:  `cpe:2.3:a:kaseya:virtual_system_administrator:7.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:108.2146.2565.38893`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2008.225.2153.39091`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_huawei_switch:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2008.717.2343.40629`,
        fs:  `cpe:2.3:o:ibm:integrated_management_module_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2008.1201.1504.27008`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2009.113.2222.40119`,
        fs:  `cpe:2.3:h:3com:3cr860-95:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2009.211.2225.40219`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2009.312.2223.38381`,
        fs:  `cpe:2.3:h:hp:laserjet_5000:r.25.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2009.925.1707.28889`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2009.1104.959.17837`,
        fs:  `cpe:2.3:a:md-systems:simplenews:7.x-1.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2009.1118.1260.23275`,
        fs:  `cpe:2.3:h:juniper:srx100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2010.211.1740.31663`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_existing:2010.302.2233.40412`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:108.2146.2565.38893`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2008.225.2153.39091`,
        fs:  `cpe:2.3:a:hp:status:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2008.717.2343.40629`,
        fs:  `cpe:2.3:h:dell:optiplex_990:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2008.1201.1504.27008`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2009.113.2222.40119`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2009.211.2225.40219`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2009.312.2223.38381`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2009.925.1707.28889`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2009.1104.959.17837`,
        fs:  `cpe:2.3:a:apple:cups:1.1.20:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:apple:apple_tv:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2010.211.1740.31663`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_3_firmware:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_full_new:2010.302.2233.40412`,
        fs:  `cpe:2.3:a:gnome:glib:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:108.2146.2565.38893`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2008.225.2153.39091`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2008.717.2343.40629`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2008.1201.1504.27008`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2009.113.2222.40119`,
        fs:  `cpe:2.3:a:pixman:pixman:0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2009.211.2225.40219`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2009.312.2223.38381`,
        fs:  `cpe:2.3:a:splunk:splunk:6.4.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2009.925.1707.28889`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2009.1104.959.17837`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:copadata:zenon_dnp3_ng_driver:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2010.211.1740.31663`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.991:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_light:2010.302.2233.40412`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2008.225.2153.39091`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2008.1201.1504.27008`,
        fs:  `cpe:2.3:h:apple:iphone:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2009.113.2222.40119`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2009.211.2225.40219`,
        fs:  `cpe:2.3:o:novell:opensuse:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2009.312.2223.38381`,
        fs:  `cpe:2.3:a:sqlite:sqlite:3.8.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2009.925.1707.28889`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2009.1104.959.17837`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2009.1118.1260.23275`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp2:tablet_pc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2009.1124.2131.38610`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2010.302.2233.40412`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.07:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2010.706.2128.36662`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2010.825.2146.37182`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(1w\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2010.910.2122.36517`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2010.1125.2142.38865`,
        fs:  `cpe:2.3:a:apache:subversion:0.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2011.524.2259.39378`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:11.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2011.707.2315.39839`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.100:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2011.728.1723.29300`,
        fs:  `cpe:2.3:a:hillside_project:hillside:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_common:2011.1025.2152.37348`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_vista:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:redhat:richfaces:5.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_graphics_previews_vista:2010.211.1740.31663`,
        fs:  `cpe:2.3:o:ibm:aix:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::de`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::en`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::es`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.01:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::fr`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::it`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::ja`,
        fs:  `cpe:2.3:a:schneider-electric:wonderware_intouch_access_anywhere_server:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::ko`,
        fs:  `cpe:2.3:a:emc:navisphere_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::pl`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::pt`,
        fs:  `cpe:2.3:a:symantec:workspace_virtualization:6.4.1953.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::th`,
        fs:  `cpe:2.3:a:oracle:jre:1.4.2_38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:108.2146.2564.38893:::zh`,
        fs:  `cpe:2.3:o:apple:os_x_server:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.225.2152.39091:::en`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::de`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::en`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::es`,
        fs:  `cpe:2.3:o:cisco:voip_phone_cp-7910:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::fr`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::it`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::ja`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::ko`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::pl`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::pt`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::th`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.717.2342.40629:::zh`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::de`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::en`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::es`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::fr`,
        fs:  `cpe:2.3:a:mcafee:dlp_management_tools:9.1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::hu`,
        fs:  `cpe:2.3:a:infotecs:vipnet_client:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::it`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::ja`,
        fs:  `cpe:2.3:a:devsaran:responsive_blog:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::ko`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::pt`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::tr`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2008.1201.1503.27008:::zh`,
        fs:  `cpe:2.3:a:osisoft:pi_interface:1.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.113.2221.40119:::en`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::cs`,
        fs:  `cpe:2.3:a:adobe:acrobat:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::da`,
        fs:  `cpe:2.3:a:twitget_project:twitget:3.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::de`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::el`,
        fs:  `cpe:2.3:a:jease:jease:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::en`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::es`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::fi`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::fr`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::hu`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::it`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::ja`,
        fs:  `cpe:2.3:h:dell:latitude_e4310:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::ko`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::nb`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.523:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::nl`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:06-12-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::pl`,
        fs:  `cpe:2.3:a:hp:data_protector_express:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::pt`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::ru`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sre:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::sv`,
        fs:  `cpe:2.3:a:squareup:okhttp3:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::th`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-8:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::tr`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.183:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.211.2224.40219:::zh`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::de`,
        fs:  `cpe:2.3:a:webmin:usermin:1.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::en`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::es`,
        fs:  `cpe:2.3:a:hp:document_viewer:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::fr`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::hu`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::it`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::ja`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::ko`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::pt`,
        fs:  `cpe:2.3:a:python:python:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::tr`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.312.2222.38381:::zh`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.4.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.925.1706.28889:::en`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1104.958.17837:::en`,
        fs:  `cpe:2.3:a:pcre:pcre:8.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::cs`,
        fs:  `cpe:2.3:a:f-secure:email_and_server_security:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::da`,
        fs:  `cpe:2.3:a:utage.org:enkai:110916:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::de`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p329:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::el`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::en`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.4.1_a:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::es`,
        fs:  `cpe:2.3:a:emc:isilon_insightiq:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::fi`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.10.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::fr`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.6:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::hu`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::it`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::ja`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::ko`,
        fs:  `cpe:2.3:a:boson:subnet_calculator:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::nb`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::nl`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::pl`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::pt`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::ru`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:7.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::sv`,
        fs:  `cpe:2.3:a:cisco:telepresence_serial_gateway:1.0.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::th`,
        fs:  `cpe:2.3:h:xerox:docuprint_n40:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::tr`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1118.1259.23275:::zh`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2009.1124.2130.38610:::en`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::cs`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::da`,
        fs:  `cpe:2.3:a:cisco:pix_private_link:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::de`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::el`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::en`,
        fs:  `cpe:2.3:a:adobe:camera_raw:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::es`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::fi`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.0.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::fr`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::hu`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::it`,
        fs:  `cpe:2.3:a:debian:php5-common:5.3.3-7\&#43;squeeze4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::ja`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::ko`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(4b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::nb`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::nl`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::pl`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.13.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::pt`,
        fs:  `cpe:2.3:a:hp:insight_management:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::ru`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.4:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::sv`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.1.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::th`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.16:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::tr`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.211.1739.31663:::zh`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.302.2232.40412:::en`,
        fs:  `cpe:2.3:a:isc:bind:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.706.2127.36662:::en`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.825.2145.37182:::en`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.910.2121.36517:::en`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2010.1125.2141.38865:::en`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2011.524.2258.39378:::en`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2011.707.2314.39839:::en`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2011.728.1722.29300:::en`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.1:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_help:2011.1025.2151.37348:::en`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:preview3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_hydravision_full:2009.0113.2222.40119`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)ewa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_hydravision_full:2009.0211.2225.40219`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p290:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_hydravision_full:2009.0925.1707.28889`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:04-01-\/a:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_hydravision_full:2009.1104.959.17837`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_hydravision_full:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:1.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_hydravision_full:2010.0302.2233.40412`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2008.717.2343.40629`,
        fs:  `cpe:2.3:a:apache:struts:2.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2009.1104.959.17837`,
        fs:  `cpe:2.3:a:vmware:vsphere_profile-driven_storage:5.0.0.16964:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2010.211.1740.31663`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2010.302.2233.40412`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2010.706.2128.36662`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2010.825.2146.37182`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2010.910.2122.36517`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2010.1125.2142.38865`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2011.308.2346.42594`,
        fs:  `cpe:2.3:a:businessobjects:webintelligence:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2011.524.2259.39378`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2011.707.2315.39839`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(5j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2011.728.1723.29300`,
        fs:  `cpe:2.3:a:gnu:radius:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_installproxy:2011.1025.2152.37348`,
        fs:  `cpe:2.3:h:alcatel-lucent:omniaccess_wireless:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:108.2146.2565.38893:::ar`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.4.0:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:108.2146.2565.38893:::de`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:108.2146.2565.38893:::es`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.49.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:108.2146.2565.38893:::fr`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:108.2146.2565.38893:::it`,
        fs:  `cpe:2.3:o:cisco:content_services_switch_11500:7.20_\(03.10\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:108.2146.2565.38893:::ja`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:108.2146.2565.38893:::ko`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:108.2146.2565.38893:::zh`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::de`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::es`,
        fs:  `cpe:2.3:a:daiki_ueno:libfep:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::fr`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::it`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::ja`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::ko`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::pl`,
        fs:  `cpe:2.3:a:livezilla:livezilla:4.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::pt`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::th`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.717.2343.40629:::zh`,
        fs:  `cpe:2.3:h:apple:apple_laserwriter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::de`,
        fs:  `cpe:2.3:a:hp:creativeprojects_posterprintconfig:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::es`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.9.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::fr`,
        fs:  `cpe:2.3:a:arabic_troll_football_project:arabic_troll_football:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::hu`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::it`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1038:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::ja`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.0.0.59211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::ko`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.4b.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::pt`,
        fs:  `cpe:2.3:o:huawei:s5720hi_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::tr`,
        fs:  `cpe:2.3:a:blackboard:transact_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2008.1201.1504.27008:::zh`,
        fs:  `cpe:2.3:h:tek:phaser_network_printer_750dp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2009.211.2225.40219`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2009.312.2223.38381`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:jenkins-ci:exclusion:0.8:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_localization:2010.211.1740.31663`,
        fs:  `cpe:2.3:a:avonesoft:pro_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:108.2146.2565.38893`,
        fs:  `cpe:2.3:a:dell:client_system_update:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2008.225.2153.39091`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.13527:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2008.717.2343.40629`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2008.1201.1504.27008`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2009.113.2222.40119`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2009.211.2225.40219`,
        fs:  `cpe:2.3:a:rabidhamster:r2\/extreme:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2009.312.2223.38381`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2009.925.1707.28889`,
        fs:  `cpe:2.3:a:emc:networker:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2009.1104.959.17837`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2009.1118.1260.23275`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2009.1118.1260.23275::~~~~x64~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_broker:1.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2009.1124.2131.38610`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2010.211.1740.31663::~~~~x64~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2010.302.2233.40412`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2010.706.2128.36662`,
        fs:  `cpe:2.3:a:veritas:netbackup:5.1.0:mp1:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2010.825.2146.37182`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2010.910.2122.36517`,
        fs:  `cpe:2.3:h:mcafee:e-appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2010.1125.2142.38865`,
        fs:  `cpe:2.3:a:apple:safari:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2011.524.2259.39378`,
        fs:  `cpe:2.3:a:tumbleweed:desktop_validator:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2011.707.2315.39839`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2011.728.1723.29300`,
        fs:  `cpe:2.3:a:sitecore:cms:7.0:3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_control_center_utility:2011.1025.2152.37348`,
        fs:  `cpe:2.3:a:polylang_plugin_project:polylang:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_driver:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_driver:7.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_driver:8.0`,
        fs:  `cpe:2.3:a:hp:scan:8.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.682.0`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.750.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_3200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.754.0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.765.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.769.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.782.0`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.14:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.786.0`,
        fs:  `cpe:2.3:a:hp:universal_cmbd_foundation:10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.790.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.795.0`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0590:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.804.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.816.0`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.825.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.6:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.829.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.833.0`,
        fs:  `cpe:2.3:o:cisco:unified_sip_phone_3900_firmware:8.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.838.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.842.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.13.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_install_manager:3.0.851.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_registration:2.01.0000`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:catalyst_registration:3.00.0000`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:communication_opt-in:2.02.0000`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:control_panel:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:control_panel:6.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(28\)s5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:control_panel:6.14.10.5125`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:hydravision:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.452:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:hydravision:4.0.2.0`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.13:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:hydravision:4.2.148.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.315.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:hydravision_aps:4.0.0.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:parental_control_%26_encoder:3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:skins:0108.2146.2565.38893`,
        fs:  `cpe:2.3:a:f5:big-iq_centralized_management:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:skins:2008.0225.2153.39091`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:skins:2008.1201.1504.27008`,
        fs:  `cpe:2.3:h:oracle:power_distribution_unit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:skins:2009.0113.2222.40119`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:skins:2009.0211.2225.40219`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:skins:2009.0312.2223.38381`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:skins:2009.1118.1260.23275`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:-`,
        fs:  `cpe:2.3:a:agilebits:knox:1.6.3:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1010`,
        fs:  `cpe:2.3:a:apache:libcloud:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1013`,
        fs:  `cpe:2.3:a:avaya:interactive_response:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1014`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1015`,
        fs:  `cpe:2.3:a:oracle:approvals_management:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1016`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_284_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1017`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1018`,
        fs:  `cpe:2.3:a:vercot:serva32:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1020`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1021`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ati:software_uninstall_utility:6.14.10.1022`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aticts:aticts:6.3.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlasrr:right_track_software:10.0_freeware`,
        fs:  `cpe:2.3:a:siteminder_federation:12.5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.0`,
        fs:  `cpe:2.3:a:libav:libav:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.0:beta`,
        fs:  `cpe:2.3:a:apache:axis2:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.0.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.0.2`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.0.3`,
        fs:  `cpe:2.3:a:jwcrypto_project:jwcrypto:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.0.4`,
        fs:  `cpe:2.3:a:exim:exim:4.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.0.5`,
        fs:  `cpe:2.3:a:ibm:interact:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.1`,
        fs:  `cpe:2.3:a:rocketsoftware:rocket_servergraph:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.1.1`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.1.2`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.2.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.2.2`,
        fs:  `cpe:2.3:h:oracle:sun_blade_x6275_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.2.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:3.0-04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:1.2.4`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0`,
        fs:  `cpe:2.3:a:novell:netmail:3.52b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta`,
        fs:  `cpe:2.3:h:sitecom:wl-111:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta1`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2009:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(4\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta3`,
        fs:  `cpe:2.3:a:yourmembers_project:yourmembers:-:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta4`,
        fs:  `cpe:2.3:h:yokogawa:centum_cs_3000_entry_class:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta6`,
        fs:  `cpe:2.3:a:plone:plone:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta8`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0:beta9`,
        fs:  `cpe:2.3:a:debian:adequate:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0.1`,
        fs:  `cpe:2.3:a:oracle:internet_directory:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0.2`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0.3`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0.4`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0.5`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.0.6`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.0.1p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-00-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.1.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.1.2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.1.3`,
        fs:  `cpe:2.3:a:gnu:gzip:1.2.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.1.4`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.1.5`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.2`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.2.1`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.2.2`,
        fs:  `cpe:2.3:a:wireshark:wireshark:0.99.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.2.3`,
        fs:  `cpe:2.3:a:altiris:task_server_language_pack:6.0.1509:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.2.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p352:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.3.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.4.1`,
        fs:  `cpe:2.3:a:kde:koffice:1.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.4.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.4.3`,
        fs:  `cpe:2.3:a:symantec:ghost_solutions_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.5`,
        fs:  `cpe:2.3:a:tinywebgallery:tinywebgallery:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.5.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.5.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.5.3`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.5.5`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.6`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.6.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.5.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.6.2`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:3.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.6.3`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.7`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.7.1`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.7.2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.7.3`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:2.7.4`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.0.1`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-backup:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.0.2`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.0.3`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.1`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2_.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.1.1`,
        fs:  `cpe:2.3:h:ibm:flashsystem_9846-ae2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.1.3`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_2000_service_management_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.1.4`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.3`,
        fs:  `cpe:2.3:h:huawei:eudemon_8080e:v100r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.3.1`,
        fs:  `cpe:2.3:a:elefantcms:elefantcms:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.3.2`,
        fs:  `cpe:2.3:a:google:v8:3.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.3.3`,
        fs:  `cpe:2.3:a:vmware:fusion_pro:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.3.4`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.4`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.4.1`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.4.2`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.4.3`,
        fs:  `cpe:2.3:o:virtualaccess:gw6110a_firmware:9.50.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.4.4`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:3.4.5`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.0.1`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.1`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.1.1`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.1.2`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.2`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.2.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.3`,
        fs:  `cpe:2.3:a:brian_altenhofel:slidebox:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.3.1`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.3.2`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.3.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.292.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.3.4`,
        fs:  `cpe:2.3:a:skype:skype:1.0.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.4.1`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.4.2`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.4.3`,
        fs:  `cpe:2.3:a:kerio:control:8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.4.4`,
        fs:  `cpe:2.3:a:websense:enterprise:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.4.5`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:4.4.8`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:.1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.0`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.0:beta1`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd433a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.0:beta2`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.0:beta3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.0:rc1`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.0.1`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:02-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.1`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro_35:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.1.1`,
        fs:  `cpe:2.3:a:adobe:reader:11.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.2`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.2.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.2.2`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.3`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.4`,
        fs:  `cpe:2.3:o:cisco:500_series_switch_firmware:1.2.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.4.1`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.4.2`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.5`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(2\):build15:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.6`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.6.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.7`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.7.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.7.2`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.8`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.8.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.8.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.2.2p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.8.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p62:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.9`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.9.1`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.9.2`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.9.3`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.9.4`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.9.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.11.3`,
        fs:  `cpe:2.3:o:huawei:s5300ei_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.12.0`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.12.1`,
        fs:  `cpe:2.3:a:python:python:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.12.2`,
        fs:  `cpe:2.3:a:horde:imp:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.12.4`,
        fs:  `cpe:2.3:a:google:v8:3.24.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.12.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.13.0`,
        fs:  `cpe:2.3:a:mclewin:wishlist:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.13.1`,
        fs:  `cpe:2.3:h:hp:elitebook_850_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.13.2`,
        fs:  `cpe:2.3:a:adobe:sing_cs3:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.14.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.14.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.339:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.14.2`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.14.3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.14.4.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:bamboo:5.14.5`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.0.1`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.0.3`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1499.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.1`,
        fs:  `cpe:2.3:h:hp:j8698a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.1.1`,
        fs:  `cpe:2.3:a:adobe:photoshop:12.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.1.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.2`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.2.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.2.2`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:3.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.2.3`,
        fs:  `cpe:2.3:a:backhand:mod_backhand:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.3.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.3.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.3.4`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.4:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.3.5`,
        fs:  `cpe:2.3:a:ez:ez_publish:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.3.6`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.4`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.4.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.4.2`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.4.3`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.3:1003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:1.4.4`,
        fs:  `cpe:2.3:a:bmc:control-m\/enterprise_manager:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.6`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.6.1`,
        fs:  `cpe:2.3:a:sgi:propack:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.6.2`,
        fs:  `cpe:2.3:a:hp:product_assistant:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.6.3`,
        fs:  `cpe:2.3:a:novell:suse_audit_log_keeper:0.2.1-0.4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.7`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.7.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)t5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.7.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.7.3`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.7.4`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.5.102.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.8`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.8:beta`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.8.1`,
        fs:  `cpe:2.3:a:docker:docker:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.8.2`,
        fs:  `cpe:2.3:a:techsmith:camtasia_relay:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.8.3`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.9.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.9.2`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.9.3`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.73:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.10.1`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.10.2`,
        fs:  `cpe:2.3:a:hummingbird:enterprise_collaboration:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.10.3`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner:16.0.0.10353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:2.10.4`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.12.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.0`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.0.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.1`,
        fs:  `cpe:2.3:a:hp:data_protector_media_operations:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.1.1`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.1.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.2`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.2.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.3`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.3.1`,
        fs:  `cpe:2.3:a:tibco:silver_fabric_enabler:1.6.0:*:*:*:*:spotfire_web_player:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.3.3`,
        fs:  `cpe:2.3:o:huawei:s7712_firmware:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.789.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4.5`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4.6`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4.7`,
        fs:  `cpe:2.3:a:apache:opennlp:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4.8`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.4.9`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0sv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.2`,
        fs:  `cpe:2.3:a:usebb:usebb:0.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.3`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.19.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.4`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp3:media_center:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.6`,
        fs:  `cpe:2.3:a:novell:zenworks_handheld_management:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.7`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.9`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.11`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.6:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:3.5.13`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.0`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.0.3`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.219.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.0.4`,
        fs:  `cpe:2.3:h:hp:color_laserjet_1500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.0.5`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.1`,
        fs:  `cpe:2.3:a:okb.co.jp:smartphone_passbook:1.00:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.1.2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.1.3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.1.4`,
        fs:  `cpe:2.3:a:bed_and_breakfast_project:bed_and_breakfast:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.1.5`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.1.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.1.7`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.2:ea3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:4.1.9`,
        fs:  `cpe:2.3:a:t1lib:t1lib:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.5.0`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.8.16`,
        fs:  `cpe:2.3:a:citrix:xenapp_plugin_for_hosted_apps:11.0.150.5357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.2`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.4`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.3se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.5`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.6`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.7`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.8`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.9`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.10`,
        fs:  `cpe:2.3:o:iij:seil\%2fx1_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.11`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.9.12`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.10.0`,
        fs:  `cpe:2.3:h:xerox:workcentre:275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.10.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.10.2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.10.3`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:5.10.5`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:6.0`,
        fs:  `cpe:2.3:a:playscape:ninja_chicken_ooga_booga:1.4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:6.0.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:6.0.2`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:6.0.3`,
        fs:  `cpe:2.3:a:informatica:powerexchange_client_for_powercenter:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:6.0.4`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:6.0.5`,
        fs:  `cpe:2.3:a:php-proxima:php-proxima:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:confluence:6.0.6`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.2:beta`,
        fs:  `cpe:2.3:a:avast:pro_antivirus:11.1.2245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.3:beta`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.3.2:beta`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.3.3`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.4:beta`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.4.1:beta`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.4.2:beta`,
        fs:  `cpe:2.3:a:sysaid:sysaid:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.4.3:beta`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.4.4:beta`,
        fs:  `cpe:2.3:o:cisco:ios:3.7.3e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:0.4.5:beta`,
        fs:  `cpe:2.3:a:invensys:intouch\/wonderware_application_server:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.0.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.0.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc653a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.0.2`,
        fs:  `cpe:2.3:h:supermicro:h8sml-7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.0.3`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.0.4`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:8.8.0-000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.0.5`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.0.6`,
        fs:  `cpe:2.3:a:google:updater:2.4.2432.1652:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.0.7`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.1.0`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.1.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.1.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.2`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_xi:11.5.8.8265:release_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.2.1`,
        fs:  `cpe:2.3:a:adobe:shockwave_player_merge_module:12.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.22.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.2.4`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.uc5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.3.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.3.2`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.3.3`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.4`,
        fs:  `cpe:2.3:a:freemind:freemind:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.4.1`,
        fs:  `cpe:2.3:a:oracle:secure_backup:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.4.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p142:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.4.3`,
        fs:  `cpe:2.3:a:ibm:rational_directory_server:5.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.4.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.4.7`,
        fs:  `cpe:2.3:a:samba:samba:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.4.8`,
        fs:  `cpe:2.3:a:quest:toad_for_data_analysts:2.6.2:*:*:*:basic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.329:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.5.1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.5.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.5.3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.6`,
        fs:  `cpe:2.3:a:cisco:cius_software:9.2\(1\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.6.1`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:1.6.3`,
        fs:  `cpe:2.3:a:brian_akers:mod_layout:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0`,
        fs:  `cpe:2.3:a:jenkins:git:0.7.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0:beta`,
        fs:  `cpe:2.3:a:good:good_mobile_control_server:_1.3.1.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0.1`,
        fs:  `cpe:2.3:a:altiris:real-time_console_infrastructure_language_pack:6.3.1022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0.2`,
        fs:  `cpe:2.3:a:sun:grid_engine:6.0:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0.3`,
        fs:  `cpe:2.3:a:luracast:restler:1.4.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0.4`,
        fs:  `cpe:2.3:h:huawei:s3300:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0.5`,
        fs:  `cpe:2.3:a:hp:mercury_quality_center:9.0_build_9.1.0.4352:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0.6`,
        fs:  `cpe:2.3:o:siemens:ozw672_firmware:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0.7`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.0.9`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je099a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.1:beta2`,
        fs:  `cpe:2.3:a:christophe_thibault:k-meleon:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.1:beta4`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.84:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.1.2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.0-11:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.2.2`,
        fs:  `cpe:2.3:a:x.org:libxrender:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.2.4`,
        fs:  `cpe:2.3:a:apache:log4net:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.2.7`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.2.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.3.1`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.3.2`,
        fs:  `cpe:2.3:a:adobe:bridge:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.3.3`,
        fs:  `cpe:2.3:h:conceptronic:cipcamptiwl:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.3.4`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.3.6`,
        fs:  `cpe:2.3:h:hp:officejet_pro_8500:cb794a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.3.7`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.3.8`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.4`,
        fs:  `cpe:2.3:a:conky:conky:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.4.1`,
        fs:  `cpe:2.3:a:buffalotech:whr-g54s_firmware:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(25.4\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.4.9`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.13:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.5.0`,
        fs:  `cpe:2.3:o:huawei:ale_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.5.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.5.2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.5.3`,
        fs:  `cpe:2.3:a:oracle:application_testing_suite:12.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.5.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p315:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.6.0`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.6.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.6.3`,
        fs:  `cpe:2.3:h:xerox:document_centre_425:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.8.4`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.9.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.14.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crowd:2.9.1`,
        fs:  `cpe:2.3:a:apache:poi:3.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.1.1`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.1.2`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.1.3`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.1.4`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.2`,
        fs:  `cpe:2.3:a:bentley:microstation_powerdraft:8.5.2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.2.1`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.2.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.07.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.2.3`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.5.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.5.1`,
        fs:  `cpe:2.3:a:omeka:omeka:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.5.3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.5.4`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.6.0`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.1:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.6.1`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.6.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.6.2.1`,
        fs:  `cpe:2.3:a:boopsie:scottcolibmn:4.5.110:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.6.3`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.6.4`,
        fs:  `cpe:2.3:a:nero:showtime:4.99.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.6.5.a`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_20.16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:1.6.6`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jb3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je164a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0:beta2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0:beta3`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:*:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0.1`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf808a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0.3`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0.4`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.0.6`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.1.0`,
        fs:  `cpe:2.3:h:hp:zbook_15_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.1.1`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.1.2`,
        fs:  `cpe:2.3:a:tightvnc:tightvnc:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.1.3`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.1.4`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20161004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.2.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.6:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.2.1`,
        fs:  `cpe:2.3:a:libav:libav:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.2.3`,
        fs:  `cpe:2.3:a:powerarchiver:powerarchiver:14.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.360:*:*:*:esr:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.4.0.2710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.2`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.3`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_html5:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.5`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.6`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.7`,
        fs:  `cpe:2.3:a:gnu:libtool:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.3.8`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.4.0`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.4.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.23:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.4.2`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.4.3`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.4.4`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:59.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.4.5`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.4.6`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf815a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.5.0`,
        fs:  `cpe:2.3:a:moodle:moodle:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.5.1`,
        fs:  `cpe:2.3:a:pythonware:python_imaging_library:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.5.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.5.3`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-00-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.5.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.5.5`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.5.6`,
        fs:  `cpe:2.3:a:ruby-i18n:i18n:0.6.5:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.5.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.6.0`,
        fs:  `cpe:2.3:a:ultraseek:ultraseek:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.6.1`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:2006:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.6.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.6.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_01a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.6.4`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp4:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.6.5`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.5.1.657:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.6.6`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.9:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.6.7`,
        fs:  `cpe:2.3:a:wp_restful_project:wp_restful:0.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.1`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.3`,
        fs:  `cpe:2.3:a:digimobistudio:qq_copy:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.4`,
        fs:  `cpe:2.3:a:synology:diskstation_manager:4.3-3810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.1.887:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.6`,
        fs:  `cpe:2.3:a:smartypantsplugins:sp_project_\&amp;_document_manager:2.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.7`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.8`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.9`,
        fs:  `cpe:2.3:a:brian_akers:mod_layout:2.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.10`,
        fs:  `cpe:2.3:a:ibm:websphere_eclipse_platform:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.11`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:crucible:2.7.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.3`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.4`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle_common:3.0.0.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.4.1`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg810-25:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.4.2`,
        fs:  `cpe:2.3:a:gnu:cpio:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.4.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.5.0`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.5.1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.3\(3\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.5.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.5.3`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.5.4`,
        fs:  `cpe:2.3:a:qemu:qemu:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.6.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.6.1`,
        fs:  `cpe:2.3:h:hp:3com_switch:4200g_pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.6.2`,
        fs:  `cpe:2.3:a:citrix:access_gateway_plug-in:9.3:*:*:*:enterprise:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.6.3`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.6.4`,
        fs:  `cpe:2.3:h:hp:3com_switch:4210-24g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.6.5.a`,
        fs:  `cpe:2.3:a:skype:skype:0.98.0.42:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:1.6.6`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0`,
        fs:  `cpe:2.3:a:ibm:pureedge_viewer:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0:beta`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0:beta2`,
        fs:  `cpe:2.3:a:9.dotpp.net:megalith:52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0:beta3`,
        fs:  `cpe:2.3:o:cray:unicos:6.0e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0.1`,
        fs:  `cpe:2.3:a:ca:embedded_entitlements_manager:8.4.218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0.2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0.3`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0.4`,
        fs:  `cpe:2.3:a:nagios:nagios:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0.5`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.0.6`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.1.0`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.1.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.1.2`,
        fs:  `cpe:2.3:a:semantictitle_project:semantictitle:1.1.0:*:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.1.3`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.1.0.59780:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.1.4`,
        fs:  `cpe:2.3:a:linkit_project:linkit:7.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.2.0`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.2.1`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.2.3`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.1`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.2`,
        fs:  `cpe:2.3:a:vips:vips:7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.3`,
        fs:  `cpe:2.3:a:nexters:throne_rush:2.3.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.4`,
        fs:  `cpe:2.3:a:oxide_project:oxide:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.5`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:06-01\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.6`,
        fs:  `cpe:2.3:a:roxio:media_manager:9.1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.7`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.3.8`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.4.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.4.1`,
        fs:  `cpe:2.3:a:emc:networker:7.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.4.2`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.08c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.4.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.4.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.4.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.4.6`,
        fs:  `cpe:2.3:a:vmware:fusion:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.5.0`,
        fs:  `cpe:2.3:a:gslideshow_project:gslideshow:0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.5.1`,
        fs:  `cpe:2.3:o:huawei:5300hi_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.5.2`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.5.3`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.5.4`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.5.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.5.6`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.5.7`,
        fs:  `cpe:2.3:h:hp:0235a326:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.6.0`,
        fs:  `cpe:2.3:a:buffalotech:whr-ampg_firmware:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.6.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.6.2`,
        fs:  `cpe:2.3:a:withdata:oraloader:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.6.3`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.9:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.6.4`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.6.5`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.6.6`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.6.7`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.0`,
        fs:  `cpe:2.3:a:hotel-room:hotel_room:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.1`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.2`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.4`,
        fs:  `cpe:2.3:a:remote-rac:rac_server:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.5`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.6:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.6`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.7`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.8`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.9`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.10`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.11`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.5.0:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:fisheye:2.7.12`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:hipchat:3.16.1::~~~iphone_os~~`,
        fs:  `cpe:2.3:h:hp:t520:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:hipchat:6.29.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.10.0\(259\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.24:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.1`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.1::enterprise`,
        fs:  `cpe:2.3:a:hp:proactive_services:1.6.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.1::professional`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.1::standard`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.2::enterprise`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.2::professional`,
        fs:  `cpe:2.3:h:intel:core_2_extreme_x6800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.2::standard`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.2.1`,
        fs:  `cpe:2.3:a:symantec:encryption_desktop:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.2.1::enterprise`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.2.1::professional`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.2.1::standard`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.3`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:2.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.3::enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.3::professional`,
        fs:  `cpe:2.3:o:juniper:junos:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.3::standard`,
        fs:  `cpe:2.3:a:oracle:oracle_berkeley_db:11.2.5.2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.4.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.4.1::enterprise`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.4.1::professional`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.4.1::standard`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.1`,
        fs:  `cpe:2.3:a:ipa:ilogscanner:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.1::enterprise`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.175:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.1::professional`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_reference_data_management_hub:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.1::standard`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.2`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.2::enterprise`,
        fs:  `cpe:2.3:o:cisco:ios:12.4jl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.2::professional`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.2::standard`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.3`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.3::enterprise`,
        fs:  `cpe:2.3:o:cisco:ios_xr:2.0\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.3::professional`,
        fs:  `cpe:2.3:a:adobe:pagemaker:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.5.3::standard`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.6`,
        fs:  `cpe:2.3:a:google:chrome:5.0.354.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.6::enterprise`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.6::professional`,
        fs:  `cpe:2.3:a:altiris:application_metering:6.1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.6::standard`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.7.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.6.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(0\)n1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.6.1::enterprise`,
        fs:  `cpe:2.3:a:gnu:coreutils:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.6.1::professional`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.5:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:2.6.1::standard`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.11.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0::enterprise`,
        fs:  `cpe:2.3:a:gajim:gajim:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0::professional`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0::standard`,
        fs:  `cpe:2.3:a:avonesoft:iphone_video_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.1::enterprise`,
        fs:  `cpe:2.3:a:cfdbplugin:contact_form_db:2.8.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.1::professional`,
        fs:  `cpe:2.3:a:mautic:mautic:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.1::standard`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.2::enterprise`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.2::professional`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update3:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.2::standard`,
        fs:  `cpe:2.3:a:libmspack_project:libmspack:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.3::enterprise`,
        fs:  `cpe:2.3:a:apple:xcode:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.3::professional`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.0.3::standard`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.1::enterprise`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.1::professional`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.1::standard`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.1.1`,
        fs:  `cpe:2.3:a:withbuddies:slots_vacation_-_free_slots_:1.47.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.1.1::enterprise`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.1.1::professional`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.1.1::standard`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_services:3.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2::enterprise`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.4b.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2::professional`,
        fs:  `cpe:2.3:a:boost:boost:1.47.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2::standard`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.34:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.1::enterprise`,
        fs:  `cpe:2.3:h:cisco:nexus_2248tp_fex_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.1::professional`,
        fs:  `cpe:2.3:a:vmware:vma:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.1::standard`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.2`,
        fs:  `cpe:2.3:a:imagecms:imagecms:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.2::enterprise`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.2::professional`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.2::standard`,
        fs:  `cpe:2.3:a:jig:movatwitouch:1.792:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.3`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.3::enterprise`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.3::professional`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.2.3::standard`,
        fs:  `cpe:2.3:a:webmin:usermin:1.030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3`,
        fs:  `cpe:2.3:a:vmware:tools:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3::enterprise`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3::professional`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3::standard`,
        fs:  `cpe:2.3:a:unisys:enterprise_output_manager:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.1`,
        fs:  `cpe:2.3:a:hp:netdevicemanager:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.1::enterprise`,
        fs:  `cpe:2.3:a:nero:neronet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.1::professional`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.1::standard`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p241:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.2::enterprise`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.2::professional`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.2::standard`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.3`,
        fs:  `cpe:2.3:a:microsoft:word:2010:sp2:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.3::enterprise`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.3::professional`,
        fs:  `cpe:2.3:h:rim:blackberry_playbook_tablet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.3.3::standard`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.1`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g54_firmware:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.1::enterprise`,
        fs:  `cpe:2.3:a:powie:pfile:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.1::professional`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.1::standard`,
        fs:  `cpe:2.3:a:dialogic:brooktrout_system_software:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.2`,
        fs:  `cpe:2.3:h:hp:procurve_router:jc149a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.2::enterprise`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.2::professional`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.2::standard`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.3`,
        fs:  `cpe:2.3:a:news_project:news:3.5.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.3::enterprise`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.3::professional`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.4.3::standard`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.3.3:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5::enterprise`,
        fs:  `cpe:2.3:a:php:php:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5::professional`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5::standard`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.1`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.1::enterprise`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.1::professional`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.1::standard`,
        fs:  `cpe:2.3:a:hp:hph_productcontext:70.0.260.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.40:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.2::enterprise`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.2::professional`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.2::standard`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.3::enterprise`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.3::professional`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.5.3::standard`,
        fs:  `cpe:2.3:a:nortel:business_communications_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6`,
        fs:  `cpe:2.3:a:microfocus:enterpriselink:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6::enterprise`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6::professional`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6::standard`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.1::enterprise`,
        fs:  `cpe:2.3:a:wikidforum:wikidforum:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.1::professional`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.1::standard`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.2::enterprise`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.2::professional`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.2::standard`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.2_156`,
        fs:  `cpe:2.3:a:opscode:chef:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.3::enterprise`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.3::professional`,
        fs:  `cpe:2.3:a:powerdns:authoritative_server:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.3::standard`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.4`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.4::enterprise`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.4::professional`,
        fs:  `cpe:2.3:a:inclind:custom_pub:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.4::standard`,
        fs:  `cpe:2.3:h:ibm:power_5:9116-561:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.5`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.5::enterprise`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.5::professional`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.6.5::standard`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7`,
        fs:  `cpe:2.3:a:cisco:unified_cdm_application_software:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7::enterprise`,
        fs:  `cpe:2.3:a:busybox:busybox:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7::professional`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7::standard`,
        fs:  `cpe:2.3:a:barton:ngircd:20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.1`,
        fs:  `cpe:2.3:h:y-cam:ycb001:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.1::enterprise`,
        fs:  `cpe:2.3:a:oracle:html_db:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.1::professional`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.1::standard`,
        fs:  `cpe:2.3:a:rationalplan:moos_project_viewer:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.2`,
        fs:  `cpe:2.3:h:polycom:converged_management_application_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.2::enterprise`,
        fs:  `cpe:2.3:a:spice_project:spice:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.2::professional`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.2::standard`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)mra:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.3::enterprise`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.3::professional`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.6p7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.3::standard`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.4`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.4::enterprise`,
        fs:  `cpe:2.3:a:icinga:icinga:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.4::professional`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.7.4::standard`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.02b25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.8`,
        fs:  `cpe:2.3:a:geo_redirector_plugin_project:geo_redirector:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.8::enterprise`,
        fs:  `cpe:2.3:a:emc:networker:7.6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.8::professional`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.8::standard`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.8.1`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.8.1::enterprise`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.8.1::professional`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.8.1::standard`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6cpk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9::enterprise`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9::professional`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9::standard`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.14:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.1`,
        fs:  `cpe:2.3:a:polycom:global_management_system:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.1::enterprise`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.1::professional`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.1::standard`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.2::enterprise`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.2::professional`,
        fs:  `cpe:2.3:h:axis:700_network_document_server:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.2::standard`,
        fs:  `cpe:2.3:a:roxio:backontrack:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.3`,
        fs:  `cpe:2.3:a:symantec:veritas_gridnode_agent:5.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.3::enterprise`,
        fs:  `cpe:2.3:a:oracle:common_applications:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.3::professional`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.9.3::standard`,
        fs:  `cpe:2.3:a:citrix:presentation_server_client:10.150.58643:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10::enterprise`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10::professional`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10::standard`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10.1::enterprise`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10.1::professional`,
        fs:  `cpe:2.3:a:gnu:bash:2.05:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10.1::standard`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10.2`,
        fs:  `cpe:2.3:a:ardour:ardour:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10.2::enterprise`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10.2::professional`,
        fs:  `cpe:2.3:a:bundler:bundler:1.4.0:rc.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.10.2::standard`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1030:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.11::enterprise`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.3sq:3.3.0sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.11::professional`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.11::standard`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:2.1.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12::enterprise`,
        fs:  `cpe:2.3:a:sun:openwindows:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12::professional`,
        fs:  `cpe:2.3:h:hp:jd668a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12::standard`,
        fs:  `cpe:2.3:a:busybox:busybox:1.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.1`,
        fs:  `cpe:2.3:h:hp:proliant_dl170h_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.1::enterprise`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass_pro:6.2.2:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.1::professional`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ewa3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.1::standard`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.2`,
        fs:  `cpe:2.3:a:php:php:5.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.2::enterprise`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.2.182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.2::professional`,
        fs:  `cpe:2.3:a:magzter:champak_-_hindi:3.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.2::standard`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.3`,
        fs:  `cpe:2.3:a:tibco:activematrix_policy_agent:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.3::enterprise`,
        fs:  `cpe:2.3:a:cisco:personal_assistant:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.3::professional`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.12.3::standard`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13::enterprise`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13::professional`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71-\/f:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13::standard`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13.1`,
        fs:  `cpe:2.3:a:werdswords:download_shortcode:0.2:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13.1::enterprise`,
        fs:  `cpe:2.3:o:huawei:s5300li_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13.1::professional`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13.1::standard`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.12:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13.2`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13.3`,
        fs:  `cpe:2.3:h:ibm:power_5:9111-520:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13.4`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:3.13.5`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.0.2`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.3.2\(466\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.2`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.60:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.2.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.3`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:4.1.1.733:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.3.1`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.3.2`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.3.3`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.3.4`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:7.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.4`,
        fs:  `cpe:2.3:a:emc:networker:8.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.4.1`,
        fs:  `cpe:2.3:a:atutor:atutor:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.4.2`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.4.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.4.4`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:4.4.5`,
        fs:  `cpe:2.3:a:arg0:encfs:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.0`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.0.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.0.3`,
        fs:  `cpe:2.3:a:rockwellautomation:rslogix_5000_design_and_configuration_software:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.0.4`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.0.5`,
        fs:  `cpe:2.3:a:hitachi:it_operations_analyzer:02-51-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.0.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.346:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1.1`,
        fs:  `cpe:2.3:a:john_koleszar:libvpx:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1.2`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.16.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1.3`,
        fs:  `cpe:2.3:a:atmail:atmail:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1.4`,
        fs:  `cpe:2.3:a:facebook:barcode_scanner:2.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1.5`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1.6`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1.7`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.1.8`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2`,
        fs:  `cpe:2.3:a:hp:software_update:3.0.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.1`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.8:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.3`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.4`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.5`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.6`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.7`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.8`,
        fs:  `cpe:2.3:o:hp:700_series_firmware:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.9`,
        fs:  `cpe:2.3:a:sybase:sql_anywhere_studio:9.0.2.2451:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.10`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:5.2.11`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.0`,
        fs:  `cpe:2.3:a:skype:skype:1.2.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.0.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.0.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.0.3`,
        fs:  `cpe:2.3:a:hp:procurve_manager:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.0.4`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.0.5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.0.7`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.0.8`,
        fs:  `cpe:2.3:a:isc:bind:9.0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.1`,
        fs:  `cpe:2.3:a:curtis_galloway:exif:0.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.3`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:1.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.5`,
        fs:  `cpe:2.3:a:cipherdyne:fwknop:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.6`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.7`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.8`,
        fs:  `cpe:2.3:a:samba:samba:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.1.9`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.16:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.2.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.2.2`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.2.3`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.7.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.2.4`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.2.5`,
        fs:  `cpe:2.3:a:sap:hybris:5.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.2.6`,
        fs:  `cpe:2.3:a:isc:bind:9.3.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:6.2.7`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:7.0.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:7.1.4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.65:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:7.1.8`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira:7.2.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_core:7.0.3`,
        fs:  `cpe:2.3:a:baseurl:yum:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:6.26.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:6.26.10`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:6.29.1`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.26.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:6.29.2`,
        fs:  `cpe:2.3:o:opensuse_project:suse_linux_enterprise_server:11.0:sp3:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:6.31.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:7.1.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp5:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:7.2.1`,
        fs:  `cpe:2.3:a:mcafee:cloud_identity_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:7.3.2`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:7.3.3`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:7.4.1`,
        fs:  `cpe:2.3:o:ibm:aix:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:7.8.1`,
        fs:  `cpe:2.3:a:apport_project:apport:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:7.8.3`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:2.2.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_integration_for_hipchat:7.8.12`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:jira_service_desk:3.0.3`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.1`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4008:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p159:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.4`,
        fs:  `cpe:2.3:a:apache:struts:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.5`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.6`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.7`,
        fs:  `cpe:2.3:h:polycom:mgc-50:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.8`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.9`,
        fs:  `cpe:2.3:a:winzip:winzip:15.0.9411:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.3.10`,
        fs:  `cpe:2.3:a:debian:apt:0.7.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.4.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.9:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.4.0:m1`,
        fs:  `cpe:2.3:a:hp:scan:5.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.4.0:m2`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs3_server:adobe_version_cue_cs3_server_:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.4.1`,
        fs:  `cpe:2.3:a:oracle:siebel_suite:7.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.5.0`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.5.0:m1`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.5.0:m3`,
        fs:  `cpe:2.3:a:avaya:vpnremote:4.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.6.0`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.6.0:m1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.6.0:m4`,
        fs:  `cpe:2.3:a:connections_project:connections:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.6.1`,
        fs:  `cpe:2.3:a:cisco:ids_device_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.7.0`,
        fs:  `cpe:2.3:a:bmc:guardian_angel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.8.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.8.0:m1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.8.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.8.2`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.8.3`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.8.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.8.5`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.0`,
        fs:  `cpe:2.3:o:cisco:sn_5428_storage_router:3.3.2-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.0:m1`,
        fs:  `cpe:2.3:a:logitech:mvision:11.10.2030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.0:m2`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.2`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.4`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.5`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.6`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.12.335:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.8`,
        fs:  `cpe:2.3:h:asus:rt-ac56r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.9`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:1.9.11`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:2.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:oauth:2.0.3`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassian:sourcetree:2.5c`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:4.0.2.17`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:6.0.0.52`,
        fs:  `cpe:2.3:h:siemens:gigaset_se361_wlan_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:7.0.9`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:7.0.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.23:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:8.0.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:8.0.5`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:8.0.6`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.18_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:8.0.7`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atlassolutions:accipiter_direct_server:10.0`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6cch:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.3.0`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.3.1`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.3.2`,
        fs:  `cpe:2.3:a:f5:linerate:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.3.3`,
        fs:  `cpe:2.3:o:zte:zxhn_h108n_r1a_firmware:zte.bhs.zxhnh108nr1a.h_pe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.3.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.3.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p244:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.3.6`,
        fs:  `cpe:2.3:h:f5:big-ip_1600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.4.0`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.4.1`,
        fs:  `cpe:2.3:h:dell:latitude_e4300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.4.2`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.5.0`,
        fs:  `cpe:2.3:a:cisco:unified_ip_ivr:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.6.0`,
        fs:  `cpe:2.3:a:samba:samba:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.6.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.573:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.6.2`,
        fs:  `cpe:2.3:a:apple:quicktime:7.64.17.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.6.3`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.6.4`,
        fs:  `cpe:2.3:a:php:php:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.4`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.5`,
        fs:  `cpe:2.3:a:cisco:content_distribution_manager_4630:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.6`,
        fs:  `cpe:2.3:a:commons_wikis_project:commons_wikis:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.554.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.8`,
        fs:  `cpe:2.3:a:hp:trayapp:60.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.10`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0.1:test1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.11`,
        fs:  `cpe:2.3:a:canon:captureperfect:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.12`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:6.20.13`,
        fs:  `cpe:2.3:a:redhat:libpng:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.0.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.0.1`,
        fs:  `cpe:2.3:a:macromedia:flash_media_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.0.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.0.3`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.1.0`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.1.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.1.2`,
        fs:  `cpe:2.3:a:peel:peel_shopping:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.1.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.1.4`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.1.5`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.1.6`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmail:atmail:7.2.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.1.0.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.1.1.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.1.2.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.2.0.0`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.3.0.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.3.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.3.1.1`,
        fs:  `cpe:2.3:a:barracuda:web_filter:8.0.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.5.0.0`,
        fs:  `cpe:2.3:a:bluecoat:winproxy:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.5.1.0`,
        fs:  `cpe:2.3:a:sympa:sympa:2.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atmarkweb:%40web_shoppingcart:1.5.2.0`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atme:atme:1.0.10::~~~android~~`,
        fs:  `cpe:2.3:a:vmware:tools:8.4.6.16648:*:*:*:winpre2k:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atom:electron:0.33.4`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:5.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:5.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:5.3`,
        fs:  `cpe:2.3:a:smartertools:smartermail:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.2`,
        fs:  `cpe:2.3:a:drupal:drupal:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.3`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.3:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.5`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.6`,
        fs:  `cpe:2.3:h:hp:jg520a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.7`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.8`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.9`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.10`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.12`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:6.12.0046.0`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:7.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.3:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:communication_manager:7.02.0610.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:8.5.71`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:8.9.35`,
        fs:  `cpe:2.3:a:firebird:firebird:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:9.0.0`,
        fs:  `cpe:2.3:a:pulsesecure:client:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:9.0.82`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:9.2.0`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:9.9.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:9.3.0`,
        fs:  `cpe:2.3:h:citrix:netscaler_application_delivery_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:9.3.14`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:9.5.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:connect_participant_application:9.5.51`,
        fs:  `cpe:2.3:a:gnu:glibc:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:labs%27_natural_voices_desktop_redist:1.4.0916`,
        fs:  `cpe:2.3:a:estsoft:alsee:6.20.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:natural_voices_crystal_16k:1.4.0011`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.5.1\(420\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:att:natural_voices_mike_16k:1.4.0011`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:att:status:-`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:extra%21_for_windows_95%2fnt:6.4`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:infoconnect_enterprise_edition:7.50.0000`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:infoconnect_enterprise_edition:8.00.0000`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager_im_and_presence_service:9.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:infoconnect_for_unisys:9.0.1393`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5b\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:infoconnect_options_pack:8.00.0000`,
        fs:  `cpe:2.3:a:yokogawa:centum_vp:r5.01.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:installer_service:8.00.0001`,
        fs:  `cpe:2.3:a:bea:aqualogic_service_bus:2.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:oracle_provider:1.0.0`,
        fs:  `cpe:2.3:a:game_tabs_project:game_tabs:0.4.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_administrator%27s_toolkit:14.0.3670`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_hp:14.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_hp:14.1:sp1`,
        fs:  `cpe:2.3:a:haxx:curl:7.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_ibm:14.0`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_ibm:14.0.3558`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_ibm:14.1:sp1`,
        fs:  `cpe:2.3:a:openstack:heat:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_regis_graphics_server:14.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_regis_graphics_server:14.1:sp1`,
        fs:  `cpe:2.3:a:vips:vips:7.7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it:6.0`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it:6.1`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it:6.1.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it:6.1.3`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_client:7.0.96`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_client:7.1.249_`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_client:7.2.106_`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_client:7.2.1163`,
        fs:  `cpe:2.3:a:exim:exim:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_client:7.2.1163_service_pack_1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_server:6.0_build_15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_server:6.1.3_build_8`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_server:6.1.4_build_6`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_server:6.1_build_21`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_server:7.1.211`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.0.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_server:7.1.835`,
        fs:  `cpe:2.3:a:ibm:http_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_secure_it_server:7.2.151`,
        fs:  `cpe:2.3:a:web2py:web2py:1.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_the_web_2008:10.1.549:r2`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_server:11.0:sp3:*:*:ltss:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_the_web_2008:10.2.527:r3`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_the_web_2008:10.2.534:r3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_unix_and_openvms:14.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_unix_and_openvms:14.0.3670`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.11:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_for_unix_and_openvms:14.1:sp1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_pki_services_manager:1.1.70`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_standard_suite:15.3.436_`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_x:13.0.0307`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_x:14.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:reflection_x:14.1:sp1`,
        fs:  `cpe:2.3:h:d-link:dir-120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:4.5`,
        fs:  `cpe:2.3:h:intel:enterprise_southbridge_bmc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:5.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:5.5`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:6.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.11:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:6.5`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:6.6`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:7.0`,
        fs:  `cpe:2.3:a:redhat:kdelibs:2.1.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:7.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:7.5`,
        fs:  `cpe:2.3:a:livetecs:timeline:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:7.5:sp1`,
        fs:  `cpe:2.3:a:transifex:transifex:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_host_integrator:7.5:sp2`,
        fs:  `cpe:2.3:a:google:v8:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_process_designer:6.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_process_designer:6.0:sp1`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:attachmate:verastream_process_designer:6.0:sp1_hf1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:achecker:1.0`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.1.191.xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:acollab:1.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:acontent:1.2`,
        fs:  `cpe:2.3:a:freso:languageicons:6.x-2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:acontent:1.2:1`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:acontent:1.2:2`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:acontent:1.2-1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:0.9.6`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.16.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:0.9.7`,
        fs:  `cpe:2.3:a:gnu:wget:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.0`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.2.1`,
        fs:  `cpe:2.3:a:apple:apple_tv:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.2.2`,
        fs:  `cpe:2.3:a:apple:itunes:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.3`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.3.1`,
        fs:  `cpe:2.3:a:commdevices:distributed_database_manager-odbc:4.21.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.3.2`,
        fs:  `cpe:2.3:a:janrain:ruby-openid:2.2.0:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.3.3`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.4.1`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.4.2`,
        fs:  `cpe:2.3:a:tacticalforcellc:tactical_force_llc:1.9.23.276:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.4.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.1:pl1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.1:pl2`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.2`,
        fs:  `cpe:2.3:a:mod_nss_project:mod_nss:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.3:rc2`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.3.1`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.3.2`,
        fs:  `cpe:2.3:a:isc:bind:9.6:*:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.4`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.5.5`,
        fs:  `cpe:2.3:o:cisco:voip_phone_cp-7960:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.6`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:7.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.6.1`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.5:*:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.6.1:pl1`,
        fs:  `cpe:2.3:a:samba:samba:3.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:1.6.4`,
        fs:  `cpe:2.3:a:symantec:vrtsjre:1.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:2.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.220:update22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:2.0.1`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:2.0.2`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:2.0.3`,
        fs:  `cpe:2.3:a:sybase:pylon_anywhere:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:2.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:2.1.1`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility_for_windows_server_2003:2.0.4.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:atutor:atutor:2.2`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atvise:webmi2ads:1.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atvise:webmi2ads:2.0`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atvise:webmi2ads:2.0.1`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_7941g:8.0\(4\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atvise:webmi2ads:2.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(4\)xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:atvise:webmi2ads:2.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:auctiontrac:auctiontrac_dealer:2.0.3::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:audacity:audacity:1.2.6`,
        fs:  `cpe:2.3:a:vmware:gsx_server:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:audiograbber:audiograbber:1.83_se_`,
        fs:  `cpe:2.3:a:citrix:command_center:5.2:43.19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:audiograbber:audiograbber_mp3_plugin:1.0`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.05.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:audiosharescript:audioshare:2.0.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.0.1`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3bc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.0.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.0.4`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.0.5`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.0.6`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.0.7`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.0.8`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.1.1`,
        fs:  `cpe:2.3:a:gnu:gv:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.2.0`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.2.1`,
        fs:  `cpe:2.3:a:oracle:human_capital_management_configuration_workbench:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.2.2`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.3.0`,
        fs:  `cpe:2.3:a:varnish_http_accelerator_integration_project:varnish:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.3.1`,
        fs:  `cpe:2.3:a:phppgadmin_project:phppgadmin:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.3.2`,
        fs:  `cpe:2.3:a:netiq:appmanager_agent:7.0.10160.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.3.3`,
        fs:  `cpe:2.3:a:isc:bind:9.8.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.3.4`,
        fs:  `cpe:2.3:a:fusedpress:buddypress-extended-frienship-request:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.3.5`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.3.6`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.4.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.4.2`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.5.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.5.2`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.5.3`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.6.0`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.7.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.465.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.7.1`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro_65:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.7.2`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.7.3`,
        fs:  `cpe:2.3:a:nomachine:nomachine:5.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.7.4`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.8.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.8.1`,
        fs:  `cpe:2.3:h:axis:2400_video_server:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.9.0`,
        fs:  `cpe:2.3:a:microsoft:office:95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:0.10.0`,
        fs:  `cpe:2.3:a:pygments:pygments:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:1.0.0`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:augeas:augeas:1.1.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_2820:9.0_0.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:auracms:auracms:3.0`,
        fs:  `cpe:2.3:a:pgp:universal_server:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:authentec:atmininstall:7.10.0.1129`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5608:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:authentec:authentec_fingerprint_sensor:7.10.0.0129`,
        fs:  `cpe:2.3:h:supermicro:x9drfr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:authentium:command_antivirus:5.2.11.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:authoring_html:6.x-1.0:-`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:authorsontourlive:authors_on_tour_-_live%21:4::~~~android~~`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.3.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:3ds_max:-`,
        fs:  `cpe:2.3:a:redhat:policycoreutils:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:3ds_max:7`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:architectural_desktop:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:architectural_desktop:2005`,
        fs:  `cpe:2.3:a:anthony_mills:s3_video:0.982:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:architectural_desktop:2006`,
        fs:  `cpe:2.3:a:trivantis:coursemill_enterprise_learning_management_system:4.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad:-`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad:6.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(1\)n2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad:2005`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad:2005:::en`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1\(.1f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad:2006`,
        fs:  `cpe:2.3:o:redhat:certificate_server:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad:2007:::en`,
        fs:  `cpe:2.3:h:moxa:iologic_e2240-t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad:2010`,
        fs:  `cpe:2.3:a:gnu:gv:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_architecture_2009:5.7.68.0`,
        fs:  `cpe:2.3:a:redhat:network_proxy:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_architecture_2010:6.0.56.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_architecture_2010:6.0.70.0`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro_studio:1.0.0:*:*:*:dell:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_architecture_2010_language_pack:18.0.55.0:::en`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_architecture_2011:6.5.49.0:::en`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_architecture_2011_language_pack:18.1.49.0:::en`,
        fs:  `cpe:2.3:a:microsoft:active_directory_federation_services:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_architecture_2012:6.7.49.0:::en`,
        fs:  `cpe:2.3:a:jason_flatt:basic_webmail:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_architecture_2012_language_pack:18.2.51.0:::en`,
        fs:  `cpe:2.3:a:htc:shift_4g_software:2.77.651.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_civil_3d:-`,
        fs:  `cpe:2.3:o:cisco:virtualization_experience_client_6000_series_firmware:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_civil_3d:2005`,
        fs:  `cpe:2.3:a:tibco:spotfire_analyst:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_civil_3d:2006`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_electrical:-`,
        fs:  `cpe:2.3:a:jason_savino:fp:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_electrical:2005`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.39:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_electrical:2006`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:-`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:95`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:6.x-3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:97`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:98`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2000`,
        fs:  `cpe:2.3:a:x:libxinerama:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2000i`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2000i:sp1:unlocked:de`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2000i:sp1:unlocked:fr`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2000i:sp1:unlocked:it`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2000i:sp2:locked:en`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2000i:sp2:unlocked:en`,
        fs:  `cpe:2.3:o:d-link:dsr-250n_firmware:1.01b56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1::cs`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.70.0.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1::de`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1::es`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1::fr`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.3:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1::it`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1::pl`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1::ru`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1:locked:en`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2002:sp1:unlocked:en`,
        fs:  `cpe:2.3:a:perl:perl:5.12.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2004`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2004:sp1a`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2005`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2005:::en`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.1.4.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2005:sp1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2006`,
        fs:  `cpe:2.3:a:cisco:unified_presence_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2006:::en`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6\(3\)_b50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2006:sp1`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2007`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2007:::en`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.6:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2007:sp1`,
        fs:  `cpe:2.3:a:apache:groovy:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2007:sp2`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.3:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2008`,
        fs:  `cpe:2.3:a:qemu:qemu:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2008:::en`,
        fs:  `cpe:2.3:a:oracle:sysfw:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2008:sp1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2009`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2009:::en`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2009:1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:08-00-02:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2009:2.01`,
        fs:  `cpe:2.3:a:gnome:glib:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2009:3`,
        fs:  `cpe:2.3:o:freebsd:freebsd:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2010`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.3:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2010:::en`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2010:1`,
        fs:  `cpe:2.3:h:hp:0231a0kl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2010:2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2011`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2011:::en`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2011:1.1`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2011:2`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2012`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2012:::en`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt:2012:sp1`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.54:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt_2010_language_pack:18.0.59.0:::en`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt_2011_language_pack:18.1.49.0:::en`,
        fs:  `cpe:2.3:a:gnome:glib:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_lt_2012_language_pack:18.2.51.0:::en`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-5520c_firmware:t430sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_map_3d_2009:12.0.048.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_mechanical:-`,
        fs:  `cpe:2.3:a:altiris:deployment_server_extension_for_ibm_director:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_mechanical:2005`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autocad_mechanical:2006`,
        fs:  `cpe:2.3:o:cisco:catos:5.4\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autodesk:-`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:autodesk_backburner:2016.0.0.2150`,
        fs:  `cpe:2.3:a:smarty:smarty:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:backburner:3.0.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:building_systems:-`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:building_systems:2005`,
        fs:  `cpe:2.3:a:emc:rsa_security_analytics:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:building_systems:2006`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)seb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:cad_manager_tools:16.0.0.65`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:civil_design:-`,
        fs:  `cpe:2.3:h:juniper:dx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:civil_design:2005`,
        fs:  `cpe:2.3:h:yokogawa:prosafe-rs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:content_service:2.0.90`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review:2013`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2008:4.1.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.235:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2008:4.2.0`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2009:9.0.96`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2009:9.1.127`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2009_dgn_importer:2.00.071`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2010:10.0.0.108`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2011:11.0.0.86`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.7:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2012:12.0.0.93`,
        fs:  `cpe:2.3:a:isc:bind:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:design_review_2013:-`,
        fs:  `cpe:2.3:h:polycom:viewstation_128:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:dwf_viewer:5.1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:dwf_viewer:6.5`,
        fs:  `cpe:2.3:a:westerndeal:advanced_dewplayer:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:dwf_viewer:7.0.0`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.8:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:dwf_viewer:7.2.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:dwg_trueview:17.1.65.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:dwg_trueview:17.2.56.0`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:2nd_gen_i5_i7_sinit_1.9.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:dwg_trueview:18.1.49.0`,
        fs:  `cpe:2.3:a:naver:loctouch:3.4.6:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:dwg_trueview:18.2.51.0`,
        fs:  `cpe:2.3:a:rubinius:rubinius:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:inventor:-`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(15b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:inventor:9`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:inventor_fusion:1.0.0.79`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:land_desktop:-`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:land_desktop:2005:sp1`,
        fs:  `cpe:2.3:a:microsoft:word:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:land_desktop:2006`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:*:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:map_3d:-`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:map_3d:2005`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:map_3d:2006`,
        fs:  `cpe:2.3:a:adobe:camera_raw:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:material_library_2011:2.0.0.49`,
        fs:  `cpe:2.3:a:basic-cms:sweetrice:0.6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:material_library_2012:2.5.0.8`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:material_library_base_image_library_2011:2.0.0.49`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:material_library_base_resolution_image_library_2012:2.5.0.8`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:material_library_medium_image_library_2011:2.0.0.49`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:raster_design:-`,
        fs:  `cpe:2.3:h:ubnt:aircam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:raster_design:2005`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:raster_design:2006`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:revit:-`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:6.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:revit:7`,
        fs:  `cpe:2.3:a:redhat:openshift:2.0.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:revit:8`,
        fs:  `cpe:2.3:a:sgi:infosearch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:revit_structure:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook:6.2.4::~~copic~~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100403:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook:6.2.5::~~copic~~~`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:4.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook_express:6.2.4`,
        fs:  `cpe:2.3:a:python:pillow:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook_express:6.2.5`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook_for_enterprise_2014:6.2.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook_for_enterprise_2014:6.2.5`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook_pro:6.2.4`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook_pro:6.2.5`,
        fs:  `cpe:2.3:a:roxio:creator_tools:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:sketchbook_pro:6.2.6`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:survey:-`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.3560.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:survey:2005`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(55\)se8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:survey:2006:sp1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:utility_design:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:utility_design:2005`,
        fs:  `cpe:2.3:a:google:v8:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:viz:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:viz:2006`,
        fs:  `cpe:2.3:a:yahoo:yui:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:volo_view_express:2002.20.0.811`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.192:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:vred:2014::~~professional~~~`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autodesk:vred:2014:sr1_sp8:~~professional~~~`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autoit:autoit:3.3.0.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.11:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automatedqa:testcomplete:7.52.678.3`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automatedqa:testcomplete:8.20.538.7`,
        fs:  `cpe:2.3:h:apple:airport_extreme_base_station_firmware:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automatedqa:testcomplete_demo:7.52.678.3`,
        fs:  `cpe:2.3:o:dell:idrac7_firmware:1.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automatedqa:testexecute:7.52.678.9`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:18.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automatedqa:testexecute_demo:7.52.678.9`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automatedqa:testrecorder:7.52.678.13`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:genericons:3.3`,
        fs:  `cpe:2.3:a:rockwellautomation:factorytalk_services_platform:cpr9:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:enterprise_common_services:8.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:grep:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kurzweiledu:kurzweil_1000:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:15.0.868.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100815:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:relsoftware:web_link_validator:4.0_build_406:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.34b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:apple_tv:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.40.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:03-00-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:1.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.1.3.2967:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:samba:samba:3.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:ibm:sng:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pcre:pcre:8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:asset_manager:9.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:h:xerox:workcentre_m165:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:altiris:console_data_language_pack:6.5.1146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:tandberg_2000_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:r8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:unicenter_management_web_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:service_manager_web_tier:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)ew3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.0.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:findingscience:mod_auth_openid:0.7:*:*:*:*:apache:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.14:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:jetdirect_300x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:drupal:drupal:7.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dell:wyse_device_manager:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:perl:perl:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automattic:jetpack:2.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automon:alisha_marie:1.4.0.6::~~~android~~`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automon:ledline.gr_official:1.4.0.9::~~~android~~`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automon:marcus_butler_unofficial:1.4.0.6::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automon:mikeius:1.4.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:automon:zoella_unofficial:1.4.0.5::~~~android~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:connector_framework:1.0.0.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:keyview_export_sdk:-`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.2.3:p14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:keyview_filter_sdk:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:keyview_idol:-`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.3.1-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:keyview_viewer_sdk:-`,
        fs:  `cpe:2.3:a:finalbeta:mywebsearch:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:sharepoint_connector_cfs:1.0.0.0`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:survey_editor:430`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:verity_k2:-`,
        fs:  `cpe:2.3:o:opensuse:opensuse:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autonomy:verity_k2:5.5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p412:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autotrace_project:autotrace:0.31.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.9:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:autotrader.co.za:auto_trader:2.0::~~~android~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.13:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avactis:avactis_shopping_cart:1.8.0:-:free`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avactis:avactis_shopping_cart:1.8.1:-:free`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avactis:avactis_shopping_cart:1.8.2:-:free`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avactis:avactis_shopping_cart:1.9.0:-:free`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avactis:avactis_shopping_cart:1.9.1:-:free`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.009.20069:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.0`,
        fs:  `cpe:2.3:h:planex:brl-04ur:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.1.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.3`,
        fs:  `cpe:2.3:h:hp:laserjet_2200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.4`,
        fs:  `cpe:2.3:a:apple:personal_web_sharing:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.4.1`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:7.5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.4.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.2.2_14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.5`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.6`,
        fs:  `cpe:2.3:a:qemu:qemu:1.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.7`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.8`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:2.8.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.0.5.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.0.1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.1`,
        fs:  `cpe:2.3:a:php:php:5.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.1.1`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:9.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.2.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.3`,
        fs:  `cpe:2.3:h:hp:0235a323:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.4`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.4.1`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.251:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avanset:visual_certexam_manager:3.4.2`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avantar:white_%26_yellow_pages:5.1.1::~~~android~~`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avantstar:quick_view_plus:6.0`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avas%21t:avast%21_mobile_security:2.0.4304:-:~~~android~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:avast%21_mobile_security:2.0.4304:-:~~~android~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:avast_antivirus_free:5.0.594`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.25:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:business_security:11.1.2241`,
        fs:  `cpe:2.3:a:php:php:5.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:business_security:11.1.2245`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.a8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:business_security:11.1.2253`,
        fs:  `cpe:2.3:a:digium:asterisk:10.6.0:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:business_security:11.1.2260`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:business_security:11.1.2261`,
        fs:  `cpe:2.3:a:rsa:envision:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:business_security:11.1.2262`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:email_server_security:8.0.1606`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:email_server_security:8.0.1609`,
        fs:  `cpe:2.3:a:intel:mpfmgr:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:endpoint_protection:8.0.1606`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.5.4.\(gd\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:endpoint_protection:8.0.1609`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:endpoint_protection_plus:8.0.1606`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p250:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:endpoint_protection_plus:8.0.1609`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:endpoint_protection_suite:8.0.1606`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.1.1-171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:endpoint_protection_suite:8.0.1609`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:endpoint_protection_suite_plus:8.0.1606`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:endpoint_protection_suite_plus:8.0.1609`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:file_server_security:8.0.1606`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:file_server_security:8.0.1609`,
        fs:  `cpe:2.3:a:tenable:nessus:6.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:free_antivirus:11.1.2241`,
        fs:  `cpe:2.3:a:python:python:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:free_antivirus:11.1.2245`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_eventlog_analyzer:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:free_antivirus:11.1.2253`,
        fs:  `cpe:2.3:a:microsoft:access:2000:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:free_antivirus:11.1.2260`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.09.4471:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:free_antivirus:11.1.2261`,
        fs:  `cpe:2.3:a:connman:connman:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:free_antivirus:11.1.2262`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:internet_security:11.1.2241`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:internet_security:11.1.2245`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:internet_security:11.1.2253`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:internet_security:11.1.2260`,
        fs:  `cpe:2.3:a:sun:j2ee_sdk:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:internet_security:11.1.2261`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.360:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:internet_security:11.1.2262`,
        fs:  `cpe:2.3:a:path_breadcrumbs_project:path_breadcrumbs:7.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:premier:11.1.2241`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd7.d4xxd_firmware:1.24.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:premier:11.1.2245`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:premier:11.1.2253`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:premier:11.1.2260`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:premier:11.1.2261`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:premier:11.1.2262`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:pro_antivirus:11.1.2241`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:pro_antivirus:11.1.2245`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:pro_antivirus:11.1.2253`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:pro_antivirus:11.1.2260`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:pro_antivirus:11.1.2261`,
        fs:  `cpe:2.3:a:ibm:db2:9.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast:pro_antivirus:11.1.2262`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_human_capital_management_global_payroll:9.2:*:*:*:switzerland:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avast%21:avast%21_internet_security:5.0::~~korean_trial~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avatar_uploader_project:avatar_uploader:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:h:axis:2400_video_server:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:4602sw_ip_phone:-`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:4602sw_ip_phone:r2.2`,
        fs:  `cpe:2.3:a:ubi:uplay_pc:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:ag250:2.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.39:pl3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:argent_office:-`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:argent_office:2.1`,
        fs:  `cpe:2.3:a:x.org:libx11:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:aura_application_server_5300:1.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:aura_application_server_5300:1.0.2`,
        fs:  `cpe:2.3:a:ad-minister_project:ad-minister:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:aura_application_server_5300:2.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:basic_call_management_system_reporting_desktop:-`,
        fs:  `cpe:2.3:a:hdwplayer:hdw-player-video-player-video-gallery:2.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_m770-atm:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p130:-`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p330:-`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p550:-`,
        fs:  `cpe:2.3:a:techsmith:camtasia_relay:6.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p550:4.3.5`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.0:rc2.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p550r:-`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.1.1.k9sec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p550r:5.2.14`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p580:-`,
        fs:  `cpe:2.3:a:hp:network:140.0.215.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p580:5.2.14`,
        fs:  `cpe:2.3:o:huawei:s12700_firmware:v200r007c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p880:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.8:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p880:5.2.14`,
        fs:  `cpe:2.3:a:agilebits:1password:-:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p882:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:2.10:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:cajun_p882:5.2.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:call_management_system_server:-`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:call_management_system_supervisor:-`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.52.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:-`,
        fs:  `cpe:2.3:a:google:android_api:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:1.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:1.3.1`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:9.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:2.0`,
        fs:  `cpe:2.3:h:rockwellautomation:flexlogix_l34_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:2.0.1`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1.1`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1.2`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1.3`,
        fs:  `cpe:2.3:a:xinetd:xinetd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1.4`,
        fs:  `cpe:2.3:a:samba:samba:3.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1.4:sp1`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r3.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1.4:sp2`,
        fs:  `cpe:2.3:a:isc:bind:9.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1.5`,
        fs:  `cpe:2.3:a:nishishi:fumy_teachers_schedule_board:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:communication_manager:3.1.5:sp0`,
        fs:  `cpe:2.3:a:hp:dynrootdisk:a.1.0.16.417:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:computer_telephony:-`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0._5:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:converged_communications_server:-`,
        fs:  `cpe:2.3:a:keepass:keepass:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:converged_communications_server:2.0`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:csu_5000:-`,
        fs:  `cpe:2.3:a:contenido:contendio:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:csu_5000:3.2.40`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:definity_one_media_server:-`,
        fs:  `cpe:2.3:a:gnu:enscript:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:definity_one_media_server:r9`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:definity_one_media_server:r10`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1207.101.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:enterprise_manager:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:integrated_management:-`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:interaction_center:-`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:interaction_center_voice_quick_start:-`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.7.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:interactive_response:-`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:interactive_response:1.2.1`,
        fs:  `cpe:2.3:a:apache:roller:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:interactive_response:1.3`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:intuity_audix:-`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:intuity_audix:5.1.46`,
        fs:  `cpe:2.3:a:microsoft:site_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:intuity_audix_lx:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20101019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_agent:-`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_office_customer_call_reporter:7.0`,
        fs:  `cpe:2.3:a:websense:triton_unified_security_center:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_office_customer_call_reporter:8.0`,
        fs:  `cpe:2.3:a:sandisk:u3launcher:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_office_phone_manager:-`,
        fs:  `cpe:2.3:a:google:v8:3.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_soft_phone:-`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_soft_phone:5.2`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_soft_phone:5.2:sp2`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_soft_phone:6.0`,
        fs:  `cpe:2.3:a:mautic:mautic:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_soft_phone:6.0:sp4`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.2:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip_soft_phone:6.01.85`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip600_media_servers:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:ip600_media_servers:r10`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:1.3.4`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:1.3.8`,
        fs:  `cpe:2.3:o:rockwellautomation:compactlogix_5830_firmware:v29.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.1`,
        fs:  `cpe:2.3:a:gimp:gimp:2.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.3`,
        fs:  `cpe:2.3:h:cisco:catalyst_4232-13:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.5`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.6`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.7`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.8`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.9`,
        fs:  `cpe:2.3:a:emc:networker:7.6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.10`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.11`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg223a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.12`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.14`,
        fs:  `cpe:2.3:a:hp:image_zone:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.15`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.16a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:libsafe:2.0.16`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:media_server:-`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:message_networking:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:message_networking:3.1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:mn100:-`,
        fs:  `cpe:2.3:h:hp:h3c_processing_module:msr_50_g2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:network_reporting:-`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:network_routing:-`,
        fs:  `cpe:2.3:h:d-link:dsl2740u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:octelaccess_server:-`,
        fs:  `cpe:2.3:a:irider:irider:2.21.1108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:octeldesigner_tm:-`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_hmi\/scada_ifix:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:one-x:-`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:operational_analyst:-`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:predictive_dialer_system:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:predictive_dialer_system:9.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:predictive_dialer_system:11`,
        fs:  `cpe:2.3:a:3s-software:codesys_runtime_system:2.3.9.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:predictive_dialer_system:12`,
        fs:  `cpe:2.3:a:git-scm:git:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:s3400:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:s8100:-`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:s8300:-`,
        fs:  `cpe:2.3:a:add-in-express:duplicate_remover_for_microsoft_excel:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:s8500:-`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_agent_framework:3.3.782:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:s8700:-`,
        fs:  `cpe:2.3:a:apache:camel:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:s8710:-`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:secure_access_link_gateway:1.5`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc8:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:secure_access_link_gateway:1.8`,
        fs:  `cpe:2.3:a:wp_app_maker_project:wp_app_maker:1.0.16.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:secure_access_link_gateway:2.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg200:-`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg200:4.4`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.2.0.2070:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg203:-`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:1.4.0.45-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg203:4.4`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg208:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg208:4.4`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg5:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg5:4.2`,
        fs:  `cpe:2.3:a:ibm:ilog_elixir:2.5.0:*:*:*:trial:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg5:4.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:sg5:4.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:sip_enablement_services:-`,
        fs:  `cpe:2.3:a:administration_views_project:administration_views:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:speech_access:-`,
        fs:  `cpe:2.3:a:phorum:phorum:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avaya:tn2602ap_ip_media_resource_320_circuit_pack:-`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.1.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:unified_communication_center:-`,
        fs:  `cpe:2.3:a:apache:mod_python:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:visual_messenger_tm:-`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.12:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:visual_vector_client:-`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.551:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vpnmanager:-`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.51204.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vpnremote:-`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:8.0.5_hp1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vpnremote:4.2.23`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vpnremote:4.2.24`,
        fs:  `cpe:2.3:a:samba:samba:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vpnremote:4.2.26`,
        fs:  `cpe:2.3:a:symantec:brightmail_antispam:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vpnremote:4.2.29`,
        fs:  `cpe:2.3:a:oracle:global_order_promising:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vpnremote:4.2.30`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vpnremote:4.2.32`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vsu_100:-`,
        fs:  `cpe:2.3:a:poll_chart_block_project:poll_chart_block:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vsu_100:3.2.40`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vsu_10000:-`,
        fs:  `cpe:2.3:a:sun:dtmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vsu_10000:3.2.40`,
        fs:  `cpe:2.3:a:microsoft:directx:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vsu_2000:-`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vsu_2000:3.2.40`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vsu_7500:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:vsu_7500:3.2.40`,
        fs:  `cpe:2.3:a:thycotic:secret_server:2.3:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:web_messenger:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-3:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-3:2.5`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-3:2.5.4`,
        fs:  `cpe:2.3:a:hp:ibrix:6.1.247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-4:-`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-4:2.5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-4:2.5.4`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-5:-`,
        fs:  `cpe:2.3:a:samba:samba:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-5:2.5`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-5:2.5.4`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8ze:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-6:-`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-6:2.5`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-6:2.5.4`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-7:-`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-7:2.5`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-8:-`,
        fs:  `cpe:2.3:a:microsoft:project_server:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avaya:wireless_ap-8:2.5`,
        fs:  `cpe:2.3:a:cdotech:device_registration:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avd-app:avd_download_video:3.3.13::~~~android~~`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:10.04.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aventinobrand:aventino_brand:2.2::~~~android~~`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avery:avery_wizard:3.1.5`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avery:avery_wizard:4.0.4`,
        fs:  `cpe:2.3:a:ca:igateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avery:avery_wizard:4.0.103`,
        fs:  `cpe:2.3:o:cisco:ios:11.1cc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avery:avery_wizard_for_microsoft_office_word_2003:2.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.96.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avery:design_pro:5.2.1201::~~limited~~~`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avery:design_pro:5.5.708`,
        fs:  `cpe:2.3:a:apache:roller:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avexim:noticias_bebes_beybies:1::~~~android~~`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:7.0:-:free`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:7.1:-:free`,
        fs:  `cpe:2.3:a:vmware:movie_decoder:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:7.5:-:free`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.1p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.0:-:free`,
        fs:  `cpe:2.3:h:kodak:dc210:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.1:-:free`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.2:-:free`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.3:-:free`,
        fs:  `cpe:2.3:a:mcafee:virex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.4:-:free`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.1:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.5`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.5:-:email_server`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.5:-:file_server`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.5:-:free`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.5:-:network`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.5:-:sbs`,
        fs:  `cpe:2.3:a:winscp:winscp:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.5:-:server_for_linux%2ffreebsd`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.0.471780:*:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.6:-:free`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.7:-:free`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.18.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:8.8:-:free`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:9.0`,
        fs:  `cpe:2.3:a:xnview:xnview:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:9.0:-:business`,
        fs:  `cpe:2.3:a:x.org:xfree86:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:9.0:-:email_server`,
        fs:  `cpe:2.3:a:php:php:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:9.0:-:file_server`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus:9.0:-:free`,
        fs:  `cpe:2.3:h:beetel:450tc2_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus_plus_firewall:8.5`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:anti-virus_plus_firewall:9.0`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:identity_protection:-`,
        fs:  `cpe:2.3:a:libexpat:expat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:internet_security:8.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:internet_security:8.5:-:3-pack`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.8.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:internet_security:8.5:-:network`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:internet_security:8.5:-:sbs`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:internet_security:9.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:internet_security:9.0:-:business`,
        fs:  `cpe:2.3:a:hotlingo:hotlingo:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:internet_security:9.0.791`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:internet_security:2015`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:safeguard:18.1.7`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:safeguard:18.1.7.644`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(8.0.2\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:secure_search_toolbar:18.1.7`,
        fs:  `cpe:2.3:a:yuichiro_okuyama:tetra_filer:2.3.1:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:avg:secure_search_toolbar:18.1.7.598`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avigilon:avigilon_control_center:4.12.0.53`,
        fs:  `cpe:2.3:a:winmagic:securedoc_disk_encryption:4.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avigilon:avigilon_control_center:5.4.2.21`,
        fs:  `cpe:2.3:a:websense:websense_web_security:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aviosoft:dtv_player:1.0.1.2`,
        fs:  `cpe:2.3:o:hp:openvms:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avira:avira_secure_backup:1.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avira:premium_security_suite:10.0.0.536`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:avm:fritz%21_os:6.23`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avocent:dsr1020:-`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avocent:dsr2035:-`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avocent:dsview:-`,
        fs:  `cpe:2.3:a:intel:high-bandwidth_digital_content_protection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avocent:dsview:3.1.1.17`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avocent:kvm:-`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.12:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:avocent:msi_server:1.0.0`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.16.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:3gp_video_converter:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:iphone%2fitouch%2fipod_to_computer_transfer:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:iphone_video_converter:-`,
        fs:  `cpe:2.3:a:serv-u:serv-u:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:ipod_video_converter:-`,
        fs:  `cpe:2.3:a:bottomline:transform_foundation_server:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:movavi_videosuite:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:mp3_converter:-`,
        fs:  `cpe:2.3:a:hp:hp-ux_whitelisting:a.01.02.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:photo_to_dvd_maker:-`,
        fs:  `cpe:2.3:a:sendcard:sendcard:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:pro_converter:-`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:psp_video_converter:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.5\(1.17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:rm_converter:-`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:spynomore:-`,
        fs:  `cpe:2.3:h:google:mini_search_appliance:4.4.102.m.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:stick_photo_star:-`,
        fs:  `cpe:2.3:a:apache:activemq:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:video_converter:-`,
        fs:  `cpe:2.3:a:ca:brigthstor_arcserve_client_for_windows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avonesoft:zune_video_converter:-`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade:2.1b`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade:3`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.5.5.588:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade:4.2`,
        fs:  `cpe:2.3:a:docker:docker:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.0.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.1.1`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:16.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.1.2`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.1.3`,
        fs:  `cpe:2.3:a:microsoft:visual_c\&#43;\&#43;:2008:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.1.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.1.5`,
        fs:  `cpe:2.3:a:peel:peel_shopping:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avscripts:av_arcade_pro:5.2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.284:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avsmedia:audio_tools:4.4`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:98:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avsmedia:cover_editor:1.3.1.81`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avsmedia:dvd_copy:1.4`,
        fs:  `cpe:2.3:a:novell:client:4.91:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avsmedia:dvd_player:2.4`,
        fs:  `cpe:2.3:h:hp:nonstop_himalaya_s78:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avsmedia:dvdmenu_editor:1.2.1.19`,
        fs:  `cpe:2.3:a:preplogic:exam_70-290:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avsmedia:tv_box:1.5.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p440:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avsmedia:video_editor:3.5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avsmedia:video_tools:5.6`,
        fs:  `cpe:2.3:a:codiad:codiad:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avst:callxpress:7.50`,
        fs:  `cpe:2.3:o:cisco:ios:12.2scc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avst:callxpress:7.70`,
        fs:  `cpe:2.3:a:progress:webspeed:3.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avst:callxpress:7.71`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1023:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avst:callxpress:7.90`,
        fs:  `cpe:2.3:a:vmware:player:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avst:callxpress:7.91`,
        fs:  `cpe:2.3:a:gimp:gimp:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avst:callxpress:8.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:avtech:avn801_dvr:-`,
        fs:  `cpe:2.3:a:connections_project:connections:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:avtech:avn801_dvr_firmware:1017-1003-1009-1003`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:avto-russia:russian_federation_traffic_rules:1.21::~~~android~~`,
        fs:  `cpe:2.3:a:samba:samba:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aware:nistpack_sdk:4.1.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:awebsupport:aweb_cart_watching_system_for_virtuemart:2.6.0::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:tony_freixas:ubercart_product_keys:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:awesome_antivirus_2014_project:awesome_antivirus_2014:1::~~~android~~`,
        fs:  `cpe:2.3:a:barebones:yojimbo:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:awesomeseating:buy_tickets:2.3::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:awesomewidgets:rasta_weed_widgets_hd:4.0::~~~android~~`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:awful_ninja_game_project:awful_ninja_game:1.0.23::~~~android~~`,
        fs:  `cpe:2.3:a:novell:edirectory:8.8:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:awpcp:another_wordpress_classifieds_plugin:3.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:0.0.1`,
        fs:  `cpe:2.3:a:tm_software:tempo:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:0.1.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing:10.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:0.2.0`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:0.2.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:0.2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xnf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:0.2.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.0.0`,
        fs:  `cpe:2.3:o:vmware:esx:2.0.1:build6403:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.0.1`,
        fs:  `cpe:2.3:a:apache:struts:2.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.0.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.7b:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.0.4`,
        fs:  `cpe:2.3:a:minitab:minitab:16.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.1.14`,
        fs:  `cpe:2.3:a:microsoft:windows_media_encoder:9_series:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.1.15`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.2.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.2.1`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.14.130099.587:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.2.2`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.007:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.2.3`,
        fs:  `cpe:2.3:h:siemens:scalance_x201-3p_irt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axel_jung:js_css_optimizer:1.2.4`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.0.1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.0.2`,
        fs:  `cpe:2.3:a:siemens:processsuite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.0.3`,
        fs:  `cpe:2.3:a:drupal:drupal:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.1.0`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.1.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.93:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.1.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.755.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.1.3`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axigen:axigen_mail_server:8.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:aximediasoft:slide_show_creator:4.4.3::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axiosys:bento4:1.5.1.0`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:207_network_camera:-`,
        fs:  `cpe:2.3:a:networkautomation:automate:6.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:207w_camera:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:207w_network_camera:-`,
        fs:  `cpe:2.3:a:ibm:application_support_facility:3.4.0:-:*:*:*:z\/os:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:-`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:0.3.1:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.01`,
        fs:  `cpe:2.3:h:siemens:simatic_s7_cpu-1211c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.02`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.03`,
        fs:  `cpe:2.3:a:google:chrome:6.0.413.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.12`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.30`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.31`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.32`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.0.6.147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.33`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.34`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.39`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.40`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2100_network_camera:2.41`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:-`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:2.12`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:2.30`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:2.31`,
        fs:  `cpe:2.3:a:toddm:gravity_bounce:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:2.32`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:2.34`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.590:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:2.39`,
        fs:  `cpe:2.3:a:kajona:kajona:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:2.40`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.04m-2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2110_network_camera:2.41`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:2.12`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:2.30`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:2.31`,
        fs:  `cpe:2.3:a:ibm:db2:9.5:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:2.32`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:2.34`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:2.39`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.20.263:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:2.40`,
        fs:  `cpe:2.3:a:allaire:homesite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2120_network_camera:2.41`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_30-40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2130_ptz_network_camera:-`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(2b\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2130_ptz_network_camera:2.30`,
        fs:  `cpe:2.3:h:dell:powerconnect_6224f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2130_ptz_network_camera:2.31`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2130_ptz_network_camera:2.32`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2130_ptz_network_camera:2.34`,
        fs:  `cpe:2.3:h:supermicro:x8dtl-6f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2130_ptz_network_camera:2.39`,
        fs:  `cpe:2.3:a:pip-installer:pip:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2130_ptz_network_camera:2.40`,
        fs:  `cpe:2.3:o:juniper:junos_t:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:230_mpeg2_video_server:-`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:-`,
        fs:  `cpe:2.3:a:mozilla:mozilla_suite:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:1.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:1.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:1.10`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:1.11`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:1.12`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:1.15`,
        fs:  `cpe:2.3:a:apache:hadoop:0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:2.20`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:2.30`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:2.31`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:2.32`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:5.06.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:2.33`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:2.34`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2400_video_server:2.39`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:-`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:1.0_1`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:1.15`,
        fs:  `cpe:2.3:a:qemu:qemu:0.15.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:2.20`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:2.30`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:2.31`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:2.32`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:2.33`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:2.34`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2401_video_server:2.39`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.24:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2411_video_server:-`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420-ir_network_camera:-`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420-ir_network_camera:2.39`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:-`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.12`,
        fs:  `cpe:2.3:a:google:chrome:4.0.278.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.30`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.31`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.32`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.33`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp5:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.34`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.39`,
        fs:  `cpe:2.3:a:adobe:indesign_cs3_icon_handler:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.40`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_network_camera:2.41`,
        fs:  `cpe:2.3:a:gnome:glib:2.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_video_server:-`,
        fs:  `cpe:2.3:a:openstack:heat:2013.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_video_server:2.32`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2420_video_server:2.34`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2460_network_dvr:-`,
        fs:  `cpe:2.3:a:hp:sonic_primo_sdk:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2460_network_dvr:3.00`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf845a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2460_network_dvr:3.10`,
        fs:  `cpe:2.3:a:sgi:propack:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2460_network_dvr:3.11`,
        fs:  `cpe:2.3:a:haowanlab:qincard:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2460_network_dvr:3.12`,
        fs:  `cpe:2.3:h:intel:d845bg_motherboard:p05-0024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2490_serial_server:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.5.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:2490_serial_server:2.11.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:250s_mpeg2_video_server:-`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a1\(8a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:250s_video_server:-`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:250s_video_server:3.02`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:250s_video_server:3.03`,
        fs:  `cpe:2.3:a:apple:webkit:85.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:250s_video_server:3.10`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:700_network_document_server:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:700_network_document_server:1.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:183:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:700_network_document_server:1.10`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:700_network_document_server:1.11`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53_96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:700_network_document_server:1.12`,
        fs:  `cpe:2.3:a:isc:dhcp:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:700_network_document_server:1.13`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.376:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:700_network_document_server:1.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axis:camera_management:-`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axis:camera_station:-`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/i:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axis:camera_station_one:-`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axis:ip_utility:-`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_inventory_solution_for_mac:6.2.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:axis:m10_series_network_cameras_firmware:5.21`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.0.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:m1011-w_network_camera:-`,
        fs:  `cpe:2.3:a:yuichiro_okuyama:tetra_filer:1.5.1:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:m1013_network_camera:-`,
        fs:  `cpe:2.3:a:microsoft:media_player:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:m1014_network_camera:-`,
        fs:  `cpe:2.3:a:symantec:product_authentication_service_client:4.3.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:m1033-w_network_camera:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:m1034-w_network_camera:-`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:m1054_network_camera:-`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb134xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axis:media_control:-`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axis:media_control_activex_control:6.2.10.11`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axis:media_control_embedded_installer:5.4`,
        fs:  `cpe:2.3:a:apple:quicktime:5.0.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:mpeg-2_video_server:-`,
        fs:  `cpe:2.3:a:craig_barratt:backuppc:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:neteye_200:-`,
        fs:  `cpe:2.3:a:oracle:retail_order_broker_cloud_service:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:neteye_200%2b:-`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:panorama_ptz_camera:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:panorama_ptz_camera:2.39`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:serial_server:-`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:storpoint_cd:-`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:storpoint_cd%2b:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:axis:storpoint_cd%2b:6.04`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axosoft:ontime:2010_web`,
        fs:  `cpe:2.3:a:novell:iprint:5.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:axway:email_firewall:-`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.6:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:axway:secure_messenger:6.3.2`,
        fs:  `cpe:2.3:a:wppa.opajaap:wp-photo-album-plus:6.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:axway:secure_messenger:6.5.0`,
        fs:  `cpe:2.3:a:primera:ptpublisher:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayatana_project:unity:7.0.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayatana_project:unity:7.0.1`,
        fs:  `cpe:2.3:a:redaxscript:redaxscript:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayatana_project:unity:7.1.0`,
        fs:  `cpe:2.3:a:gnu:gdb:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayatana_project:unity:7.1.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayatana_project:unity:7.1.2`,
        fs:  `cpe:2.3:a:citrix:xenserver:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayatana_project:unity:7.1.3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayatana_project:unity:7.2.0`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayatana_project:unity:7.2.1`,
        fs:  `cpe:2.3:a:perl:perl:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ayuntamientodecoana:ayuntamiento_de_coana:0.2::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:content_navigator:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b-e-soft:artweaver:1.5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.9:*:*:*:liberty:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b-e-soft:artweaver:2.0`,
        fs:  `cpe:2.3:h:lexmark:e460:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b-e-soft:artweaver:2.06`,
        fs:  `cpe:2.3:a:freemind:freemind:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b-e-soft:artweaver:3.0`,
        fs:  `cpe:2.3:h:netgear:r7000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b-e-soft:artweaver_free:3.1.4`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b-e-soft:artweaver_free:3.1.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b-e-soft:artweaver_plus:3.1.4`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.832:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b-e-soft:artweaver_plus:3.1.5`,
        fs:  `cpe:2.3:a:apple:itunes:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:4.1.0`,
        fs:  `cpe:2.3:a:emc:networker:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:4.1.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.0:tp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:4.1.2`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:4.1.3`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:4.1.4`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:4.1.5`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:4.1.6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:4.1.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:5.1.2:stable`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:10.1.106.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:5.2.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg239a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:5.2.0:stable`,
        fs:  `cpe:2.3:a:opscode:chef:0.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:5.2.1`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:5.2.1:stable`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:5.2.2`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.6b.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:5.2.2:rc2`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6-9-4`,
        fs:  `cpe:2.3:a:python-requests:requests:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6-9-5`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.0.0:alpha`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.0.0:alpha1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.1.2:alpha`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.4.2:beta`,
        fs:  `cpe:2.3:a:oracle:developer_suite:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.4.3:beta`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.4.4:beta`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.5.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.47.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.2`,
        fs:  `cpe:2.3:a:apple:apple_application_support:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.3`,
        fs:  `cpe:2.3:a:microsoft:ie:5.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.4`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.5`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.6`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.7`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.8`,
        fs:  `cpe:2.3:h:cisco:sg300-20:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.6.10`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.0:alpha`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.1:beta`,
        fs:  `cpe:2.3:a:altiris:resource_management:6.0.2927:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.2`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.4`,
        fs:  `cpe:2.3:a:webroot:msxml_4.0_sp2_and_soap_toolkit_3.0:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.5`,
        fs:  `cpe:2.3:a:rpm:rpm:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.6`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.04:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.7`,
        fs:  `cpe:2.3:a:cogentdatahub:cascade_datahub:6.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.8`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.9`,
        fs:  `cpe:2.3:a:docker:docker:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.10`,
        fs:  `cpe:2.3:a:hunting_trophy_whitetails_project:hunting_trophy_whitetails:0.75.13441.88885:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.7.11`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.0:beta`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.1`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.2`,
        fs:  `cpe:2.3:a:apache:camel:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.3`,
        fs:  `cpe:2.3:h:foundrynet:bigiron_800_backbone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.4`,
        fs:  `cpe:2.3:a:hp:bpdsoftware:140.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.5`,
        fs:  `cpe:2.3:a:archmage_project:archmage:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.6`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:3.6.7.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.7`,
        fs:  `cpe:2.3:a:roxio:backontrack:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.8`,
        fs:  `cpe:2.3:a:sybase:adaptive_server:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.9`,
        fs:  `cpe:2.3:h:xerox:workcentre:5665:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.10`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.8.11`,
        fs:  `cpe:2.3:a:google:chrome:12.0.707.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.9.0:beta`,
        fs:  `cpe:2.3:o:cisco:catos:8.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.9.1:beta`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.9.2:beta`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.9.3`,
        fs:  `cpe:2.3:a:freedesktop:libdbus:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.9.4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.9.5`,
        fs:  `cpe:2.3:a:web2py:web2py:1.91.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:b2evolution:b2evolution:6.9.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babybus:babybus:3.91::~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p4_beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babydays:baby_days:1.5.8::~~~android~~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update2:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:0.90`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:0.91`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:0.98:alpha`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:0.99:beta`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2bz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.1.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.1.1`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.1.2`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.1.3`,
        fs:  `cpe:2.3:h:netgear:fsm726s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.1.4`,
        fs:  `cpe:2.3:a:busybox:busybox:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.1.5`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.2.0`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.508:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.2.2`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babygekko:baby_gekko:1.2.2:a`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_products:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:babylon:babylon:8.1.0:r16`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:backhand:mod_backhand:1.1.0`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bad_behavior_project:bad_behavior:6.x-2.2215::~~~drupal~~`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bad_behavior_project:bad_behavior:7.x-2.2215::~~~drupal~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.00:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baidu:baidu_navigation:3.5.0::~~~android~~`,
        fs:  `cpe:2.3:a:ipswitch:imail_secure_server:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baidu:spark_browser:26.5.9999.3511`,
        fs:  `cpe:2.3:a:pantech:pc_usb_modem_software:1.2.3619.926:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bakbone:netvault:8.2.2.17`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:balanced:commerce_balanced_payments:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:alert%2b_services:1.0.1`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator_agent:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:alert%2b_subscriber_web_service:1.0.0`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:bamboo.hello.webpart.spv3:2.0.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:bamboo.worldclockandweather.spv3:1.0.0.0`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.4_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:bamboo_license_manager:2.7`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_hmi\/scada_cimplicity:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:bulk_export:1.0.0`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.0:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:bulk_import_application:1.0.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:custom_column_license_pack:1.0.0`,
        fs:  `cpe:2.3:o:cisco:catos:6.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:enterprise_license:1.0.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bamboosolutions:sharepoint_project_portfolio_dashboard_pack_license_install:1.0.0`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bananadance:banana_dance:0.9:beta`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bananadance:banana_dance:1.5:beta`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:band:band_-group_sharing_%26_planning:3.2.8::~~~android~~`,
        fs:  `cpe:2.3:o:cray:unicos_max:1.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandainamcogames:madomagi-ip_android:1.05`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandainamcogames:madomagi-ip_android:1.06`,
        fs:  `cpe:2.3:a:symantec:wxrt_ccf_client_apppack:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandh:b%26h_photo_video_pro_audio:2.5.1::~~~android~~`,
        fs:  `cpe:2.3:a:bluecoat:blue_coat_authentication_and_authorization_agent:5.2.3.2.32711:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.00`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.01`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.02`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.03`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.04`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.05`,
        fs:  `cpe:2.3:a:cybozu:cybozu_office:9.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.06`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.07`,
        fs:  `cpe:2.3:a:cisco:virtual_central_office_4000:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.08`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.09`,
        fs:  `cpe:2.3:a:gnome:glib:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandisoft:bandizip:3.10`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandoo:savevid_plug-in:2.0.0.107556`,
        fs:  `cpe:2.3:a:skin_conditions_and_diseases_project:skin_conditions_and_diseases:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bandoo:windows_savevid_toolbar:2.5.0.103268`,
        fs:  `cpe:2.3:a:libssh:libssh:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bandoo:windows_searchqu_toolbar:3.0.0.112202`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:banner_effect_header_project:banner_effect_header:1.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:banner_effect_header_project:banner_effect_header:1.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bannersky:bsk_pdf_manager:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bannersky:bsk_pdf_manager:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bannersky:bsk_pdf_manager:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bannersky:bsk_pdf_manager:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bannersky:bsk_pdf_manager:1.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:networker:8.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bannersky:bsk_pdf_manager:1.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:toolbar_for_internet_explorer:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:7.5`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:7.6`,
        fs:  `cpe:2.3:a:apple:xcode:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.0`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.221:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.2:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.3`,
        fs:  `cpe:2.3:a:bea:jrockit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.5`,
        fs:  `cpe:2.3:a:castor_project:castor:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.6`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.7`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.8`,
        fs:  `cpe:2.3:a:casinogame:video_poker_casino:1.0.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:baramundi:management_suite:8.9`,
        fs:  `cpe:2.3:a:isc:bind:8.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barandisolutions:shareyourcart:1.7.1`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barcode_scanner_project:barcode_scanner:2.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:cubecart:cubecart:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barcodewiz:barcode_activex_control:2.0`,
        fs:  `cpe:2.3:a:citrix:access_gateway:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barcodewiz:barcode_activex_control:2.52`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barcodewiz:barcode_activex_control:3.29`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1083.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.0.1`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.1.1`,
        fs:  `cpe:2.3:a:wernerd:zrtpcpp:3.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.1.2`,
        fs:  `cpe:2.3:a:innovaphone:innovaphone_pbx:10.00:sr11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.5`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.5:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.5.1`,
        fs:  `cpe:2.3:a:websvn:websvn:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.5.2`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.5.3`,
        fs:  `cpe:2.3:a:hp:bpd_scan:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.5.4`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.5.5`,
        fs:  `cpe:2.3:a:buffalotech:wer-amg54_firmware:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.5.6`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:bbedit:10.5.7`,
        fs:  `cpe:2.3:a:mkssoftware:mks_toolkit:8.7.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:2.3`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:3.0`,
        fs:  `cpe:2.3:a:spice_project:spice:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:3.1`,
        fs:  `cpe:2.3:a:citrix:provisioning_services:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:3.5`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:3.5.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:3.5.3`,
        fs:  `cpe:2.3:a:intel:mdriver:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:4.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:4.0.1`,
        fs:  `cpe:2.3:a:ubi:uplay_pc:4.6.3208:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:4.5`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3.0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:4.5.1`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:4.5.2`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5600-26c-pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:4.5.3`,
        fs:  `cpe:2.3:a:rsa:pluggable_authentication_module_agent:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:4.5.4`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:textwrangler:4.5.5`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:1.4`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.92.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:1.4.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:3.5.801:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:1.4.2`,
        fs:  `cpe:2.3:a:ibm:director_agent:5.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:1.5`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.0:beta4.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:1.5.1`,
        fs:  `cpe:2.3:a:gnu:emacs:21.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:1.5.2`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:2.0`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.01:-:*:*:*:windows_server_2003:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:2.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:2.2`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:3.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:3.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:3.0.2`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:3.0.3`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:3.0.4`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:4.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_import_export_manager:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:4.0.1`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barebones:yojimbo:4.0.2`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp1:x64-home_premium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bareftp:bareftp:0.3.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.5.102.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bareftp:bareftp:0.3.1`,
        fs:  `cpe:2.3:a:forgerock:openam:9.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bareftp:bareftp:0.3.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bareftp:bareftp:0.3.3`,
        fs:  `cpe:2.3:h:siemens:scalance_w784-1rr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bareftp:bareftp:0.3.4`,
        fs:  `cpe:2.3:o:redhat:linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bareftp:bareftp:0.3.5`,
        fs:  `cpe:2.3:a:apple:safari:1.3.2:312.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bareftp:bareftp:0.3.6`,
        fs:  `cpe:2.3:a:hp:storeonce_4220_backup_system:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.0.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.0.1`,
        fs:  `cpe:2.3:a:autodesk:autodesk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.0.2`,
        fs:  `cpe:2.3:a:iscripts:autohoster:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.0.2.1`,
        fs:  `cpe:2.3:a:citrix:single_sign-on_console:5.0.0.6684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.0.4`,
        fs:  `cpe:2.3:a:claris:claris_emailer:2.0v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.0.4.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.0.5`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.11:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.1`,
        fs:  `cpe:2.3:a:adobe:illustrator:16.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.1.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.6:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.2`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_38:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.2.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.3`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.4:rc1`,
        fs:  `cpe:2.3:a:quest:intrust:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.5:rc1`,
        fs:  `cpe:2.3:a:perlmonks:module\:\:signature:0.71:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.5:rc2`,
        fs:  `cpe:2.3:a:microsoft:ie:4.70.1155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.5.1`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.6`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.6.1`,
        fs:  `cpe:2.3:h:cisco:sg300-52mp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barnowl:barnowl:1.6.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracuda:web_filter:7.0`,
        fs:  `cpe:2.3:a:poul-henning_kamp:md5crypt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracuda:web_filter:7.0.1`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracuda:web_filter:7.1.0`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.15:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:barracuda:web_filter:8.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracuda:web_filter:8.0.002`,
        fs:  `cpe:2.3:a:hp:bufferchm:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracuda:web_filter:8.0.003`,
        fs:  `cpe:2.3:a:hiox:hiox_guest_book:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracuda:yosemite_server_backup:8.8.3`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracuda:yosemite_server_backup:8.9.1`,
        fs:  `cpe:2.3:a:oracle:internet_directory:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:3.4`,
        fs:  `cpe:2.3:a:ibm:content_template_catalog:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:3.5`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:3.6`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:3.7`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:7.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:3.7.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:3.8`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:3.9`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.0.1`,
        fs:  `cpe:2.3:a:emc:networker:7.6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.0.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.2`,
        fs:  `cpe:2.3:a:ibm:sterling_b2b_integrator:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.3`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4`,
        fs:  `cpe:2.3:a:fusebox:fusebox:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.2.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4.2`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4.3`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.2.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4.4`,
        fs:  `cpe:2.3:o:mandriva:corporate_server:4.0:*:x86_64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4.5`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:572:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4.6`,
        fs:  `cpe:2.3:a:opensis:opensis:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4.7`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.4.8`,
        fs:  `cpe:2.3:a:mark_theunissen:views_lang_switch:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.22:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.5.1`,
        fs:  `cpe:2.3:a:apache:solr:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.5.2`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.5.3`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:16.30.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.5.4`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.5.5`,
        fs:  `cpe:2.3:a:buffalotech:wer-ag54_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.6`,
        fs:  `cpe:2.3:a:xchat:xchat:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.6.1`,
        fs:  `cpe:2.3:a:wp_content_source_control_project:wp_content_source_control:3.0.0:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.7`,
        fs:  `cpe:2.3:h:schneider_electric:sage_1450:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.8`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.22.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.8.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.9`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.9.1`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.520:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:4.9.2`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:5.0`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:5.1`,
        fs:  `cpe:2.3:a:topgames:top_games_script:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:5.3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.0`,
        fs:  `cpe:2.3:a:pcre:pcre:8.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.1`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.2`,
        fs:  `cpe:2.3:a:dedecms:dedecms:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.3`,
        fs:  `cpe:2.3:a:janetter:janetter:1.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.4`,
        fs:  `cpe:2.3:a:sap:netweaver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.5`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.6`,
        fs:  `cpe:2.3:a:adobe:dng_converter:9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.7`,
        fs:  `cpe:2.3:a:apache:archiva:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.7.1`,
        fs:  `cpe:2.3:a:perl:perl:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudadrive:barracudadrive:6.7.2`,
        fs:  `cpe:2.3:a:comodo:backup:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:barracudanetworks:spam_%26_virus_firewall_600:-`,
        fs:  `cpe:2.3:a:red-gate:sql_comparison_sdk:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:barracudanetworks:spam_%26_virus_firewall_600_firmware:4.0.1.009`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudanetworks:yosemite_server_backup:8.8.3`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit-32:10.20d\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barracudanetworks:yosemite_server_backup:8.9.1`,
        fs:  `cpe:2.3:a:fancyfon:famoc:3.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:barraguard:barracuda_link_balancer:230`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:barraguard:barracuda_link_balancer:330`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:8.10:-:*:*:*:windows_8:*:*`,
    },
     
    {
        uri: `cpe:/h:barraguard:barracuda_link_balancer:430`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:barraguard:barracuda_link_balancer_series_firmware:1.3.2.005`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r6:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:alpha4`,
        fs:  `cpe:2.3:a:google:chrome:10.0.613.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:alpha5`,
        fs:  `cpe:2.3:a:mcafee:change_control:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:alpha6`,
        fs:  `cpe:2.3:a:k2top:k2editor:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:beta2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6a:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:projectsend:projectsend:335:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.1`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.2`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_feenstra:payment:-:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xe2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bart_lagerweij:pe_builder:3.1.10a`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.6.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barton:ngircd:18.0`,
        fs:  `cpe:2.3:h:fortinet:fortigate-300c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barton:ngircd:19.0`,
        fs:  `cpe:2.3:a:hp:c7100_help:70.0.231.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barton:ngircd:19.1`,
        fs:  `cpe:2.3:o:huawei:ar_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barton:ngircd:20.0`,
        fs:  `cpe:2.3:a:altova:missionkit_2011:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barton:ngircd:20.1`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barton:ngircd:20.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:barton:ngircd:20.3`,
        fs:  `cpe:2.3:a:vmware:converter:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.2`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.3`,
        fs:  `cpe:2.3:a:perl:perl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.4`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.5`,
        fs:  `cpe:2.3:a:ca:etrust_security_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.6`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.7`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7911g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.8`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.9`,
        fs:  `cpe:2.3:a:ati:hydravision:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.10`,
        fs:  `cpe:2.3:a:koha:koha:3.14.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.11`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.12`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.13`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.15`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.16`,
        fs:  `cpe:2.3:a:file_project:file:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.17`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.50.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.18`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.19`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:0.0.20`,
        fs:  `cpe:2.3:a:drupal:drupal:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.0`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.16:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.650.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.2`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.48.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.3`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.4`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.5`,
        fs:  `cpe:2.3:a:serf_project:serf:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.6`,
        fs:  `cpe:2.3:a:icinga:icinga:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.7`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.8`,
        fs:  `cpe:2.3:a:hp:customer_participation_program:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.9`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.10`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.11`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.2:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.12`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.14`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.15`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.16`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.17`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.18`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.19`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.20`,
        fs:  `cpe:2.3:a:isc:bind:9.6.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.21`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.22`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.23`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.2.110.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.24`,
        fs:  `cpe:2.3:a:openx:openx:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.25`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_workstation:31:ebh:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.26`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.27`,
        fs:  `cpe:2.3:a:color:icclib:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.28`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.30`,
        fs:  `cpe:2.3:a:iconics:bizviz:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.31`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.32`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.33`,
        fs:  `cpe:2.3:a:google:chrome:4.0.296.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.34`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.35`,
        fs:  `cpe:2.3:a:gnu:enscript:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.36`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.37`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.38`,
        fs:  `cpe:2.3:o:microsoft:windowst:vista:sp1:x64-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:1.0.39`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.1`,
        fs:  `cpe:2.3:h:iij:seil\/b1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.3`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.4`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.5`,
        fs:  `cpe:2.3:a:ibm:db2:10.1:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.6`,
        fs:  `cpe:2.3:a:samba:samba:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.7`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.9`,
        fs:  `cpe:2.3:a:citrix:common_commands:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.10`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.11`,
        fs:  `cpe:2.3:a:ni:measurementstudio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.12`,
        fs:  `cpe:2.3:o:cisco:vpn_5000_concentrator_series_software:6.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.13`,
        fs:  `cpe:2.3:a:samba:samba:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.14`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.15`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.16`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.17`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.18`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:2.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.19`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.20`,
        fs:  `cpe:2.3:a:emc:appsync:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.21`,
        fs:  `cpe:2.3:h:buffalotech:whr-300hp2_firmware:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.22`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.23`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.24`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.25`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.11s.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.26`,
        fs:  `cpe:2.3:a:wearegumball:comment-attachment:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.28`,
        fs:  `cpe:2.3:a:typo3:neos:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.29`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.31`,
        fs:  `cpe:2.3:a:apple:safari:2.0.3:417.9.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.32`,
        fs:  `cpe:2.3:a:att:connect_participant_application:8.5.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.33`,
        fs:  `cpe:2.3:a:gnome:libsocialweb:0.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.34`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.35`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.36`,
        fs:  `cpe:2.3:a:emil_stjerneman:linkit:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.37`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.4.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.38`,
        fs:  `cpe:2.3:a:opensis:opensis:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bas_van_beek:multishop:2.0.39`,
        fs:  `cpe:2.3:a:emc:rsa_identity_management_and_governance:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basercms:basercms:3.0.2`,
        fs:  `cpe:2.3:a:emc:eroom:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basercms:basercms:3.0.5.1`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basercms:basercms:3.0.6`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basercms:basercms:3.0.6.1`,
        fs:  `cpe:2.3:a:microsoft:home_publishing:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basercms:basercms:3.0.7`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basercms:basercms:3.0.8`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:6:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basercms:basercms:3.0.10`,
        fs:  `cpe:2.3:a:gnu:automake:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.8:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.20:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:citrix:online_plug-in:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.7::~~~ruby~~`,
        fs:  `cpe:2.3:a:mcafee:securify_studio:v6.0_\(build_v60_270\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.20`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.21`,
        fs:  `cpe:2.3:a:2rv:dr._sheikh_adnan_ibrahim:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.22`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1686.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.23`,
        fs:  `cpe:2.3:o:dell:idrac7_firmware:1.20.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.24`,
        fs:  `cpe:2.3:a:clip-bucket:clipbucket:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.25`,
        fs:  `cpe:2.3:h:snapgear:560:3.1.4u2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.26`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(8a\)cv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.27`,
        fs:  `cpe:2.3:h:linksys:wrt54g:2.04.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.28`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf430a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.2.29`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.4.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.4.1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.4.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.66.29:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:baseurl:yum:3.4.3`,
        fs:  `cpe:2.3:a:ftpgetter:ftpgetter:3.51.0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bashgaming:bingo_bash_free_bingo_casino:1.31.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basic-cms:sweetrice:0.6.7.1`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5580_firmware:v28.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:basketball_news_%26_videos_project:basketball_news_%26_videos:1::~~~android~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bastian_kleineidam:linkchecker:4.4`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bastian_kleineidam:linkchecker:4.5`,
        fs:  `cpe:2.3:a:knowledgetree:knowledgetree:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bastien_nocera:libsocialweb:0.25.7`,
        fs:  `cpe:2.3:a:acme:thttpd:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.0`,
        fs:  `cpe:2.3:a:facebook:hunting_trophy_whitetails:0.75.13441.88885:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.0.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:2.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.0.2`,
        fs:  `cpe:2.3:h:hp:jg182a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.0.3`,
        fs:  `cpe:2.3:a:rsa:authentication_api:8.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.0.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.0.5`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.8:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.0.6`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62p:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.1.1`,
        fs:  `cpe:2.3:a:ibm:connections:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.1.2`,
        fs:  `cpe:2.3:a:perl:perl:5.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.1.4`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.2.2`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.6:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batavi:batavi:1.3`,
        fs:  `cpe:2.3:a:exim:exim:4.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batch:batch_library:-::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1010.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:batch_jobs_project:batch_jobs:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:wernerd:zrtpcpp:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0001`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0002`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0003`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0004`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:201k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0005`,
        fs:  `cpe:2.3:a:isaac_sukin:browserid:7.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0006`,
        fs:  `cpe:2.3:h:wdc:my_net_n900c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0007`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.4.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0008`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0009`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvcomet%2a:0009:b`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0001`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0002`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0003`,
        fs:  `cpe:2.3:a:apache:tomcat:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0004`,
        fs:  `cpe:2.3:a:emil_stjerneman:linkit:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0005`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.6.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0006`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0007`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0008`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0008:b`,
        fs:  `cpe:2.3:a:adobe:acrobat:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0008:b2`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0008:b3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0009`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)scj2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0010`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0011`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0012`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0013`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0014`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0015`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0016`,
        fs:  `cpe:2.3:a:f5:big-ip:4.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0017`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0018`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0019`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2\(3.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0020`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0021`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.45.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0022`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0023`,
        fs:  `cpe:2.3:a:redhat:docbook_stylesheets:1.54.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0024`,
        fs:  `cpe:2.3:a:clientresponse_project:clientresponse:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0025`,
        fs:  `cpe:2.3:o:cisco:vpn_3080_concentrator:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0026`,
        fs:  `cpe:2.3:a:adobe:air_sdk:18.0.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0027`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0028`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0029`,
        fs:  `cpe:2.3:a:debian:backupninja:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0030`,
        fs:  `cpe:2.3:a:david_king:vino:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0031`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0032`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sy7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0033`,
        fs:  `cpe:2.3:a:sun:java_plug-in:1.4.2_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0034`,
        fs:  `cpe:2.3:a:microsoft:access:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0035`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0036`,
        fs:  `cpe:2.3:a:cisco:integrated_management_controller_supervisor:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0037`,
        fs:  `cpe:2.3:a:ca:directory:r12:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0038`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.40:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0039`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0040`,
        fs:  `cpe:2.3:a:apache:roller:0.9.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0041`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0042`,
        fs:  `cpe:2.3:o:f5:tmos:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0043`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0044`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0045`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0046`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0047`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0048`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.30.0044:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0049`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0050`,
        fs:  `cpe:2.3:o:apple:watchos:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0051`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0052`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0053`,
        fs:  `cpe:2.3:a:mibizapps:accurate_lending:1.0021.b0021:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0054`,
        fs:  `cpe:2.3:a:polycom:mgc_manager:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0055`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0056`,
        fs:  `cpe:2.3:h:cisco:asa_5500:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0057`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0058`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0059`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ec1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0060`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0062`,
        fs:  `cpe:2.3:a:cognos:contributor_client:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0063`,
        fs:  `cpe:2.3:a:innominate:mguard_delta:bd-201000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0064`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0065`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0066`,
        fs:  `cpe:2.3:a:dadabik:dadabik:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0067`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0068`,
        fs:  `cpe:2.3:a:citrix:access_management_console:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0069`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0070`,
        fs:  `cpe:2.3:a:mcafee:rogue_system_detection_sensor:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0071`,
        fs:  `cpe:2.3:a:google:chrome:6.0.401.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0072`,
        fs:  `cpe:2.3:a:emil_stjerneman:linkit:7.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0073`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0074`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.13.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0075`,
        fs:  `cpe:2.3:a:ibm:security_qradar_incident_forensics:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0076`,
        fs:  `cpe:2.3:a:commvault:srm_windows_file_system_agent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0077`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:16.04:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0078`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0079`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0080`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0081`,
        fs:  `cpe:2.3:o:iij:seil\%2fneu_2fe_plus_firmware:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0082`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0083`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0084`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0085`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0086`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.9.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0087`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0088`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0089`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.8.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0090`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bayashi:dopvstar%2a:0091`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k_secure:14.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bblog_project:bblog:-`,
        fs:  `cpe:2.3:a:oracle:internet_expenses:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bbs_technologies:sharepoint_security_manager:3.50.0.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bci:etasker_scheduling_service_setup:2.0.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bdale_garbee:as31:2.3.1-4`,
        fs:  `cpe:2.3:a:sgk:sgk_hizmet_dokumu_4a:1.103:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:be-graph:bezip:3.00`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:be-graph:bezip:3.02`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:be-graph:bezip:3.03`,
        fs:  `cpe:2.3:h:mcdata:sphereon_4300_fabric_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:be-graph:bezip:3.04`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:be_user_log_project:be_user_log:1.1.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_.net_portlet_toolkit:1.1.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_analytics:2.5.1.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_enterprise_security:-`,
        fs:  `cpe:2.3:a:apache:roller:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_enterprise_security:2.0`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_enterprise_security:2.1`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution_assurance:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_enterprise_security:2.1:sp1`,
        fs:  `cpe:2.3:a:oracle:siebel_core-common_components:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_enterprise_security:2.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.549.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction:-`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction:5.0.2`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction:5.0.3`,
        fs:  `cpe:2.3:h:sony:snc_ch280:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction:5.0.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.379:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction:6.0.1.218452`,
        fs:  `cpe:2.3:a:qemu:qemu:0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction:6.5.1.328335`,
        fs:  `cpe:2.3:a:aimluck:aipo:4.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction_collaboration:4.5.1.328258`,
        fs:  `cpe:2.3:a:buffercode:random_banner:1.1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction_content_service_for_windows_files:1.0.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction_content_service_for_windows_files:6.1.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_interaction_identity_service_for_ldap:2.2.2.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4501_series_software:4.2\(1.50\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_service_bus:-`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_service_bus:2.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_service_bus:2.1`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.0.4:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_service_bus:2.1:sp1`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(7\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_service_bus:2.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:aqualogic_service_bus:2.5`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:jolt:1.2`,
        fs:  `cpe:2.3:a:herac:tuxguitar:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:jrockit:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg245a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:jrockit:1.4.2:r24.5`,
        fs:  `cpe:2.3:a:apple:xcode:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:jrockit_jdk:r28.1.3`,
        fs:  `cpe:2.3:a:lucent:vitalevent:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:jrockit_jre:r27.6.3`,
        fs:  `cpe:2.3:a:fujitsu:serverview_operations_manager:6.30.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:jrockit_mission_control:3.1.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:liquid_data:-`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:liquid_data:1.1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:logging_utilities:6.1.0.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:tuxedo:-`,
        fs:  `cpe:2.3:a:python:pillow:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:tuxedo:6.3`,
        fs:  `cpe:2.3:a:django-markupfield_project:django-markupfield:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:tuxedo:6.4`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/r_firmware:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:tuxedo:6.5`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:tuxedo:7.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:tuxedo:8.0`,
        fs:  `cpe:2.3:a:adobe:freehand:11.0.0.458:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:tuxedo:8.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.7:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:tuxedo:10.3.0.0:r3`,
        fs:  `cpe:2.3:a:netscape:communicator:4.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:-`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:2.0`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.4494-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:7.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:8.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:8.1:sp1`,
        fs:  `cpe:2.3:a:idevspot:idevcart:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:8.1:sp2`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:8.1:sp3`,
        fs:  `cpe:2.3:a:opera:mini:3.1.7196:1690:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:8.1:sp4`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:8.1:sp5`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:8.1:sp6`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_integration:9.2`,
        fs:  `cpe:2.3:a:netapp:windows_host_utilities:5.3.3508.1105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_mobility_server:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_mobility_server:3.3`,
        fs:  `cpe:2.3:h:buffalotech:wmr-300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_mobility_server:3.5`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_mobility_server:3.6`,
        fs:  `cpe:2.3:a:techsmith:snagit:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_mobility_server:3.6:sp1`,
        fs:  `cpe:2.3:o:cisco:nx-os_1000v_switch:4.0\(4\)sv1\(3d\):*:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_platform:8.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:-`,
        fs:  `cpe:2.3:o:asus:dsl-n56u_firmware:3.0.0.4.314:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:8.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:8.1`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:8.1:sp1`,
        fs:  `cpe:2.3:a:emc:networker:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:8.1:sp2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5\)su1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:8.1:sp3`,
        fs:  `cpe:2.3:a:fortinet:fortiauthenticator:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:8.1:sp4`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:8.1:sp5`,
        fs:  `cpe:2.3:a:google:chrome:6.0.426.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:9.2`,
        fs:  `cpe:2.3:a:phillip_lougher:squashfs:2.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_portal:9.2:ga`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:-`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:3.1.8`,
        fs:  `cpe:2.3:a:devexpress:devexpress_components:2011.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:4.0`,
        fs:  `cpe:2.3:a:bluecoat:reporter:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:4.0.4`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:4.5`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp5:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:4.5.1`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:4.5.1:sp15`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:4.5.2`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_firmware:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:4.5.2:sp1`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:-:*:oracle:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:4.5.2:sp2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.46:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.11:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp1`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp1:express`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp1:win32`,
        fs:  `cpe:2.3:h:nortel:optical_metro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp10`,
        fs:  `cpe:2.3:a:zope:zserver:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp10:express`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp10:win32`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp11`,
        fs:  `cpe:2.3:a:omeka:omeka:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp11:express`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp11:win32`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp12`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp12:express`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp12:win32`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp13`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp13:express`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u2\(2d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp13:win32`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp2`,
        fs:  `cpe:2.3:a:digia:qt:4.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp2:express`,
        fs:  `cpe:2.3:a:krisonav:krisonav:2.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp2:win32`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp3`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp3:express`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp3:win32`,
        fs:  `cpe:2.3:o:maygion:ip_camera_firmware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp4`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp4:express`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp4:win32`,
        fs:  `cpe:2.3:a:jease:jease:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp5`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp5:express`,
        fs:  `cpe:2.3:a:jruby:jruby:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp5:win32`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp6`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp6:express`,
        fs:  `cpe:2.3:a:alvaro_herrera:pl\/php:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp6:win32`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp7`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp7:express`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp7:win32`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp8`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp8:express`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.3.3:interim_fix_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp8:win32`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.0\(6\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp9:express`,
        fs:  `cpe:2.3:a:gnu:libtasn1:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:5.1:sp9:win32`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1`,
        fs:  `cpe:2.3:a:autodesk:utility_design:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp1:express`,
        fs:  `cpe:2.3:a:perl:perl:0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp1:win32`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.47.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp2:express`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp2:win32`,
        fs:  `cpe:2.3:a:roxio:easy_cd_\&amp;_dvd_creator:6.0.0.171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp3:express`,
        fs:  `cpe:2.3:a:symantec:norton_security_with_backup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp3:win32`,
        fs:  `cpe:2.3:a:sympa:sympa:2.2.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp4`,
        fs:  `cpe:2.3:a:emulex:hbanyware:3.4a9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp4:express`,
        fs:  `cpe:2.3:h:tropos:6310_mesh_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp4:win32`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp5`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp5:express`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp5:win32`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.11s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp6:express`,
        fs:  `cpe:2.3:a:teradata:sql_assistant:12.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp6:win32`,
        fs:  `cpe:2.3:h:hp:zbook_studio_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp7`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp7:express`,
        fs:  `cpe:2.3:h:cisco:application_velocity_system_3180a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp7:win32`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:1.1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp8`,
        fs:  `cpe:2.3:a:ibm:qradar_vulnerability_manager:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp8:express`,
        fs:  `cpe:2.3:a:independent:i_newspaper:\@7f080184:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:6.1:sp8:win32`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1`,
        fs:  `cpe:2.3:a:bamboosolutions:alert\&#43;_services:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp1`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp1:express`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp1:win32`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp2`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.03b36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp2:express`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.2.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp2:win32`,
        fs:  `cpe:2.3:a:debian:kernel-patch-vserver:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp3`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.2.5:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp3:express`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.434:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:7.0.0.1:sp4:express`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp1`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp1:express`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp1:win32`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(1s\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp2`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp2:express`,
        fs:  `cpe:2.3:a:roderick_braun:ya_googlesearch:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp2:win32`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.0.0:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp3:express`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp3:win32`,
        fs:  `cpe:2.3:a:yahoo:yahoo\!_browser:1.4.6:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp4`,
        fs:  `cpe:2.3:a:iojs:io.js:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp4:express`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp4:win32`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp5`,
        fs:  `cpe:2.3:a:ibm:java:5.0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp5:express`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp5:win32`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp6`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:8.1:sp6:express`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:9.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:9.1`,
        fs:  `cpe:2.3:a:divx:codec:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:9.1:ga`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:9.1:ga:express`,
        fs:  `cpe:2.3:a:marked_project:marked:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:9.2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:9.2:ga`,
        fs:  `cpe:2.3:a:schneider-electric:vampset:2.2.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:9.2:mp1`,
        fs:  `cpe:2.3:a:wpsymposium:wp_symposium:14.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:9.2:mp2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_server:10.0`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_workshop:-`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_workshop:8.1:sp2`,
        fs:  `cpe:2.3:a:iss:internet_scanner:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_workshop:8.1:sp3`,
        fs:  `cpe:2.3:a:tumbleweed:server_validator_suite:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_workshop:8.1:sp4`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_workshop:8.1:sp5`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bea:weblogic_workshop:8.1:sp6`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bean_project:bean:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bean_project:bean:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bean_project:bean:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bean_project:bean:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beanshell_project:beanshell:2.0b5`,
        fs:  `cpe:2.3:a:isc:bind:9.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bearidlock:bear_id_lock:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:plone:plone:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:become:becomebot:3.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.5.0.890:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bed_and_breakfast_project:bed_and_breakfast:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bedita:bedita:3.4.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.277.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beehive_forum:beehive_forum:1.4.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus\/opentp1_web_web_front-endset:02-70-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:beetel:450tc2_router:-`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:beetel:450tc2_router_firmware:tx6-0q-005_retail`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beijerelectronics:beijer_adp:6.5.0-180_r1967`,
        fs:  `cpe:2.3:a:trillian:trillian:0.724:aim_b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beijerelectronics:beijer_adp:6.5.1-186_r2942`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beijerelectronics:h-designer:6.5.0_b180_r1967`,
        fs:  `cpe:2.3:a:monotone:monotone:0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:belarc:advisor:7.1`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:belarc:advisor:7.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:belarc:advisor:8.1`,
        fs:  `cpe:2.3:a:votecount_for_balatarin_project:votecount_for_balatarin:0.1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:belarc:belmanage%2fbelsecure_2010:8.1.7.2`,
        fs:  `cpe:2.3:a:extplorer:extplorer:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:belarc:belmonitor_client_components:8.1.9.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:belasfrasesdeamor:belas_frases_de_amor:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:ca:desktop_management_suite:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:belden:hirschmann_firmware:05.3.06`,
        fs:  `cpe:2.3:a:microsoft:windows_live_messenger:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:belden:hirschmann_firmware:09.0.05`,
        fs:  `cpe:2.3:a:commpower:security_label_server:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:belden:hirschmann_l2b:-`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:belden:hirschmann_l2e:-`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:belden:hirschmann_l2p:-`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1036.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:belden:hirschmann_l3e:-`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-3500c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:belden:hirschmann_l3p:-`,
        fs:  `cpe:2.3:a:elabftw:elabftw:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:belkin:f5d8236-4:v2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0.2112:unknown:online_windows_server_2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:belkin:n150_f9k1009:v1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:belkin:n150_f9k1009_firmware:1.00.01`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:belkin:n150_f9k1009_firmware:1.00.07`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:belkin:n150_f9k1009_firmware:1.00.08`,
        fs:  `cpe:2.3:a:hp:ignite-ux:a.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:belkin:n600_db_wi-fi_dual-band_n%2b_router_f9k1102:2.0`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:belkin:n600_db_wi-fi_dual-band_n%2b_router_f9k1102_firmware:2.10.17`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:belkin:switch2:1.0.2.14`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4016:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:belkin:wireless_usb_utility:6.3.2.16`,
        fs:  `cpe:2.3:a:ibm:informix_i-connect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bellyhoodcom_project:bellyhoodcom:3.4.23::~~~android~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ben10_omniverse_walkthrough_project:ben10_omniverse_walkthrough:0.7::~~~android~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beneplus:bene%2b_odmeny_a_slevy:1.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:benjamin_mack:seo_basics:0.8.1`,
        fs:  `cpe:2.3:a:curvycorners:curvycorners:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bentley:bentley_view:8.5.2.27`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bentley:bentley_view:8.11.7.440`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bentley:microstation:7.1`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3011-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bentley:microstation_powerdraft:8.5.2.55`,
        fs:  `cpe:2.3:o:asus:rt-n65u_firmware:3.0.0.4.334:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bepopapp:like4like%3aget_instagram_likes:2.1.5::~~~android~~`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bernhard_wymann:torcs:1.2.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bernhard_wymann:torcs:1.2.4`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bernhard_wymann:torcs:1.3.0`,
        fs:  `cpe:2.3:a:atlassian:jira:2.4.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bernhard_wymann:torcs:1.3.1`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bernhard_wymann:torcs:1.3.2`,
        fs:  `cpe:2.3:a:ibm:sterling_secure_proxy:3.4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beroux:rename-it:3.32`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:best_free_giveaways_project:best_free_giveaways:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:allroundautomations:pl\/sql_developer:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestapp:best_greatness_quotes:1::~~~android~~`,
        fs:  `cpe:2.3:a:facebook:hiphop_virtual_machine:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.6.8`,
        fs:  `cpe:2.3:a:hp:application_information_optimizer:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.6.10`,
        fs:  `cpe:2.3:a:lksctp:stream_control_transmission_protocol:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.6.11`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.4`,
        fs:  `cpe:2.3:a:ains:foiaxpress_sync_service:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.7`,
        fs:  `cpe:2.3:a:apple:safari:1.0.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.8`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:2.06\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.9`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.10`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.11`,
        fs:  `cpe:2.3:a:ibm:toolscenter_suite:9.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.12`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.13`,
        fs:  `cpe:2.3:a:lxml:lxml:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.15`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.16`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:3.8.17`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.0`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.1`,
        fs:  `cpe:2.3:a:dell:client_configuration_toolkit:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.0_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.5`,
        fs:  `cpe:2.3:a:hp:arcsight_enterprise_security_manager:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.6`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.7`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.5:e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.8`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.9`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.10`,
        fs:  `cpe:2.3:a:perl:perl:5.10.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.11`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.12`,
        fs:  `cpe:2.3:o:ibm:aix:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.14`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ecf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.15`,
        fs:  `cpe:2.3:a:blaine_lang:maestro:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.16`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.13:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.17`,
        fs:  `cpe:2.3:a:sophos:unified_threat_management_software:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.18`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.19`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.2:a:commercial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.20`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.21`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.0.22`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.3:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(3\)n2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.2`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.033_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.3`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.0:ea5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.5`,
        fs:  `cpe:2.3:a:oracle:olap:11.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.6`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.7`,
        fs:  `cpe:2.3:a:allroundautomations:pl\/sql_developer:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.8`,
        fs:  `cpe:2.3:a:ingumadev:bokken:1.5-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:request_tracker:4.2.9`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.261:*:*:*:esr:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:1.0.0`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:1.0.1`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:1.0.2`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:1.0.3`,
        fs:  `cpe:2.3:h:xerox:workcentre_5150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:1.0.4`,
        fs:  `cpe:2.3:a:apache:geronimo:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:1.0.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s_3.4.3s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:1.0.6`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:1.0.7`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.0`,
        fs:  `cpe:2.3:a:apache:tomcat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.1`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.3`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.2:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.5`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.5.1`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.5.3`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.6`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.7`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.8`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.8.2`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.9`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.11`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.12`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.13`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.14`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:2.0.15`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.0`,
        fs:  `cpe:2.3:a:vips:vips:7.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.3`,
        fs:  `cpe:2.3:a:courseforum:projectforum:7.0.1.3038:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.4`,
        fs:  `cpe:2.3:a:symantec:mail_security_for_microsoft_exchange:7.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.5`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.0.1:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.5:rc1`,
        fs:  `cpe:2.3:a:ca:license_software:1.9.1.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.6:rc1`,
        fs:  `cpe:2.3:h:tp-link:tl-wr841nd_\(9.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.7`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.7:01`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.8:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.7:pre1`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_server_apppack:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.7:pre2`,
        fs:  `cpe:2.3:h:quantum:scalar_i500:14u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.7:pre3`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.7:rc1`,
        fs:  `cpe:2.3:a:sun:jre:6.0.140:update14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.7.1`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.8`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.8:pre1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:16.20.0.1009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.8:pre2`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.8:rc1`,
        fs:  `cpe:2.3:a:emc:secure_remote_services:3.02:*:*:*:virtual:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.9`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.9:pre1`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.4.2048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.9:pre2`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.1.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.9:pre3`,
        fs:  `cpe:2.3:a:apache:poi:3.5:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.9:pre4`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.9:pre6`,
        fs:  `cpe:2.3:a:call-cc:http-client:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.10`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc102a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.10:pre1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.10:pre2`,
        fs:  `cpe:2.3:h:corega:cg-wlbargnl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.10:rc1`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.11`,
        fs:  `cpe:2.3:a:hp:loadrunner:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.11:rc1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.11:rc2`,
        fs:  `cpe:2.3:a:freesshd:freesshd:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.11:rc3`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.11:rc4`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.0.12`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.3`,
        fs:  `cpe:2.3:a:drupal:drupal:6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.4`,
        fs:  `cpe:2.3:a:mautic:mautic:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.5`,
        fs:  `cpe:2.3:a:k7computing:ultimate_security:14.2.0.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.6`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.7`,
        fs:  `cpe:2.3:a:apache:pdfbox:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.8`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.8:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.10`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.10:rc1`,
        fs:  `cpe:2.3:h:cisco:tandberg_770_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.11`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gw_3241:2.1\(1.49\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.12`,
        fs:  `cpe:2.3:a:apple:ibooks_author:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.13`,
        fs:  `cpe:2.3:a:globiz_solutions:snowfox_content_management_system:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(2\)xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.15`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.16`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.1.17`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.0`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.0:rc1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.0:rc2`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.a4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.0:rc3`,
        fs:  `cpe:2.3:a:scilab:scilab:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.0:rc4`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.1`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.1:rc1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.6.0_2003-04-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.1:rc2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.1:rc3`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.1:rc4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.2`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:6.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.2:rc1`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.3`,
        fs:  `cpe:2.3:a:esri:arcinfo_workstation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.3:rc1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.2.3:rc2`,
        fs:  `cpe:2.3:a:vips:vips:7.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.4`,
        fs:  `cpe:2.3:a:busybox:busybox:1.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.5`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.6`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.7`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.9`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p316:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.11`,
        fs:  `cpe:2.3:o:y-cam:ycw002_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.12`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.13`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.14`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.15`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.3.16`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2013.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4:ch6`,
        fs:  `cpe:2.3:h:supermicro:x9dbi-tpf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4:ch7`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.0:rc1`,
        fs:  `cpe:2.3:a:avaya:one-x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.0:rc2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.0:rc3`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.0:rc4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.11.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.0:rc5`,
        fs:  `cpe:2.3:a:xiph:vorbis-tools:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.0:rc6`,
        fs:  `cpe:2.3:h:ibm:e26:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.1`,
        fs:  `cpe:2.3:a:pdfforge:pdfcreator_toolbar:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.2:rc1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.d1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.2:rc2`,
        fs:  `cpe:2.3:a:haxx:curl:7.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.3`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.3:pre1`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.3:rc1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.3:rc2`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.4`,
        fs:  `cpe:2.3:o:huawei:s5300li_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.4:pre1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.4:pre2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.4:pre3`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.5`,
        fs:  `cpe:2.3:a:trend_micro:mobile_security:3.1:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.5:pre1`,
        fs:  `cpe:2.3:o:sgi:irix:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.5:rc1`,
        fs:  `cpe:2.3:a:mysql:mysql_tools:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.5:rc2`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.6`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.6:rc1`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.6:rc2`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.4.7:rc1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.5.1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.5.2`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-alpha2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.5.3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.5.4`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.5.5`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.5.6`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.5.7`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.0`,
        fs:  `cpe:2.3:a:mcafee:application_control:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.0:pre0`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.0:pre1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.0:rc1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p465:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.0:rc2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.5:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.0:rc3`,
        fs:  `cpe:2.3:a:gnu:gdb:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.8.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.1:pre2`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe-c_toolkits:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.1:rc1`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_eventlog_analyzer:9.0:9000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.1:rc2`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.2:rc1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.2:rc3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.2:rc4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.2:rc5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p410:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.3`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.880:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.3:rc1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.7.006:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.3:rc2`,
        fs:  `cpe:2.3:a:3com:3ctftpsvc:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.3:rc3`,
        fs:  `cpe:2.3:a:digium:asterisk:b.1.3.3:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.3:rc4`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.4`,
        fs:  `cpe:2.3:a:perl:perl:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.4:rc1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.4:rc2`,
        fs:  `cpe:2.3:a:oracle:application_server_portal:9.0.2.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.5`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.5:rc1`,
        fs:  `cpe:2.3:h:huawei:s6700:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.5:rc2`,
        fs:  `cpe:2.3:a:ibm:rational_appscan_source:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.6`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.6:rc1`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.0.2-68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.6:rc2`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.6:rc3`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:6.14.12.5922:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.7`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.8`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.2:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.9`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.6.10`,
        fs:  `cpe:2.3:a:apache:opennlp:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.7.1`,
        fs:  `cpe:2.3:a:php:php:5.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.7.5`,
        fs:  `cpe:2.3:h:linksys:befsru31:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.7.15`,
        fs:  `cpe:2.3:o:f5:tmos:9.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.7.80`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.7.85`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.7.86`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.0`,
        fs:  `cpe:2.3:a:openstack:oslo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.0:preflight1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.0:rc1`,
        fs:  `cpe:2.3:a:hp:jfs:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.0:rc2`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.0.44:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.0:rc3`,
        fs:  `cpe:2.3:a:apache:struts:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.1:preflight0`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.1:rc1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.1:rc2`,
        fs:  `cpe:2.3:h:hp:jf232a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.1:rc3`,
        fs:  `cpe:2.3:a:emc:powerpath:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.1:rc4`,
        fs:  `cpe:2.3:a:buffalotech:whr-g54s_firmware:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.1:rc5`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.8:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.2`,
        fs:  `cpe:2.3:a:chainfire:supersu:1.69:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.2:rc1`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.2:rc2`,
        fs:  `cpe:2.3:a:cpuminer_project:cpuminer:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.3`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.3:rc1`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.3:rc2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.4`,
        fs:  `cpe:2.3:a:rezgo:online_booking:1.8:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.4:rc1`,
        fs:  `cpe:2.3:a:roxio:recordnow_copy:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.5`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.6`,
        fs:  `cpe:2.3:a:cisco:remote_access_plugins_for_adaptive_security_appliance:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.6:rc1`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.7`,
        fs:  `cpe:2.3:a:citrix:licensing:7.1.10007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.7:rc1`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.8`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.0\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.8:rc2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.8:rc3`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.0:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.8:rc4`,
        fs:  `cpe:2.3:h:f5:big-ip_access_policy_manager:11.2.1:*:*:*:*:*:*:standalone`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.9`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.608:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.9:rc1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.9:rc2`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.9:rc3`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.10`,
        fs:  `cpe:2.3:a:apple:webkit:125.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.10:rc1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.2:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.11`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.11:rc1`,
        fs:  `cpe:2.3:a:twiki:twiki:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.11:rc2`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.12`,
        fs:  `cpe:2.3:a:microsoft:windows_defender:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.13`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.13:rc1`,
        fs:  `cpe:2.3:a:collabnet:subversion_server:1.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.13:rc2`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.14`,
        fs:  `cpe:2.3:a:emc:networker:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.14:rc1`,
        fs:  `cpe:2.3:a:mozilla:firefox:24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.15`,
        fs:  `cpe:2.3:a:keepass:keepass:0.88:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.16`,
        fs:  `cpe:2.3:a:ciphertrust:ironmail:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.8.17`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.9.4`,
        fs:  `cpe:2.3:a:debian:shadow:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.9.6`,
        fs:  `cpe:2.3:a:ca:unicenter_service_level_management:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:3.9.7`,
        fs:  `cpe:2.3:a:microsoft:powerpoint_for_mac:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(30\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0:rc1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0:rc2`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0:rc3`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0:rc4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0:rc5`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0:rc6`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0:rc7`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.0:rc8`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.1:rc1`,
        fs:  `cpe:2.3:a:novell:extend_director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.1:rc2`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.2`,
        fs:  `cpe:2.3:a:olaschool:ola_school:1.2.7.132:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.2:rc1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.2p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.2:rc2`,
        fs:  `cpe:2.3:a:bea:weblogic_server:9.2:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.3:rc1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.3:rc2`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(1\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.4`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.5`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.5:rc1`,
        fs:  `cpe:2.3:a:emc:documentum_eroom:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.6`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_85:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.7`,
        fs:  `cpe:2.3:a:hp:arcsight_logger:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.7:rc1`,
        fs:  `cpe:2.3:a:ramui:ramui_forum:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.8`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.8:rc1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.8:rc2`,
        fs:  `cpe:2.3:a:anl:bcfg2:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.9`,
        fs:  `cpe:2.3:a:opensolution:quick.cms.lite:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.10`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.7:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.11`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.12`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.82:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.13`,
        fs:  `cpe:2.3:a:splunk:splunk:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.14`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.15`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.16`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.17`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.18`,
        fs:  `cpe:2.3:h:cisco:distributed_director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.19`,
        fs:  `cpe:2.3:a:kde:ark:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.0.20`,
        fs:  `cpe:2.3:a:isamu_kaneko:winny:2.0b5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.2.0`,
        fs:  `cpe:2.3:h:enterasys:xp-2400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.2.1`,
        fs:  `cpe:2.3:o:dasanzhone:znid_2426a_firmware:s3.0.501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.2.2`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.2.3`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.2.4`,
        fs:  `cpe:2.3:h:intel:d845pt_motherboard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt:4.2.5`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt-extension-mobileui:1.02`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rt-extension-mobileui:1.04`,
        fs:  `cpe:2.3:a:lttng:ust:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rtfm:2.2.0`,
        fs:  `cpe:2.3:a:altiris:patch_management_language_pack:6.2.3643:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rtfm:2.2.1`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rtfm:2.2.2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rtfm:2.4.0`,
        fs:  `cpe:2.3:o:ibm:zos:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rtfm:2.4.1`,
        fs:  `cpe:2.3:a:gnu:automake:1.4:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rtfm:2.4.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestpractical:rtfm:2.4.3`,
        fs:  `cpe:2.3:a:apple:cups:1.1.22:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestsoftinc:advance_hotel_booking_system:1.0`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.2.56.5158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestsoftinc:advance_hotel_booking_system:2.0`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.4.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bestwebsoft:captcha:4.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openstack:grizzly:2013.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bestwebsoft:google_captcha:1.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:betster_project:betster:1.0.4`,
        fs:  `cpe:2.3:a:cachefly:besthop:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.00`,
        fs:  `cpe:2.3:a:f5:arx:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.02`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.09.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.04`,
        fs:  `cpe:2.3:a:tvdr:vdr:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.05_01`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.06`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.08`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.10`,
        fs:  `cpe:2.3:a:isc:bind:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.11`,
        fs:  `cpe:2.3:h:hp:designjet_755:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.11_01`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.11_02`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1305.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:beyondgrep:ack:2.12`,
        fs:  `cpe:2.3:a:microsoft:access:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfac:grandparenting_is_great:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:windows_data_access_components:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.0`,
        fs:  `cpe:2.3:a:ntp:ntp:p99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.2`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.3`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.4`,
        fs:  `cpe:2.3:a:itiw-webdev:dino_village:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.5`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.6`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.7`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.0.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.8`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.2.9`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:3.3.0`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:4.0.0`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bfgminer:bfgminer:4.1.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.480.3.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.2`,
        fs:  `cpe:2.3:a:tec-it:tbarcode3_dll:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.0:a4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.5`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0009_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.12:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.7`,
        fs:  `cpe:2.3:h:hp:nonstop_himalaya_s74:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p118:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.9`,
        fs:  `cpe:2.3:a:thegr:dl:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.27:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.11`,
        fs:  `cpe:2.3:a:apache:struts:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.12`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.13`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.14`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.15`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.16`,
        fs:  `cpe:2.3:a:linecorp:line:4.3.0.724:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.17`,
        fs:  `cpe:2.3:o:conceptronic:cipcamptiwl_1.0_firmware:21.37.2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.18`,
        fs:  `cpe:2.3:a:plone:plone:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.19`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.20`,
        fs:  `cpe:2.3:a:avaya:vsu_100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.21`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:0.97.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.22`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.2p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.23`,
        fs:  `cpe:2.3:a:samsung:net-i_viewer:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.24`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.5.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.24-1`,
        fs:  `cpe:2.3:a:hp:solution_center:140.0.214.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.0.24-2`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.1.0`,
        fs:  `cpe:2.3:a:redhat:directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.1.1`,
        fs:  `cpe:2.3:a:dell:idrac7:1.56.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.1.2`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.1.3`,
        fs:  `cpe:2.3:a:emc:rsa_web_threat_detection:4.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.2.0`,
        fs:  `cpe:2.3:a:oracle:business_intelligence:11.1.1.7.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.2.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.2.2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.3.1`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.3.2`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.4.0`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.4.1`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.5.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.2:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.6.0`,
        fs:  `cpe:2.3:h:fujitsu:f-12c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.6.1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.6.2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.6.3`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.6.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.6.5`,
        fs:  `cpe:2.3:h:hp:4600_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.6.6`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.7.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.1:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.7.2`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.8.1`,
        fs:  `cpe:2.3:a:apache:struts:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.8.2`,
        fs:  `cpe:2.3:a:apache:camel:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.8.3`,
        fs:  `cpe:2.3:a:gnu:inet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.8.4`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:i:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.9.0`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.9.1`,
        fs:  `cpe:2.3:a:cisco:jabber:9.7\(2\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.9.2`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:1.9.3`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.07.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.0.0`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.0.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.0.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.0.2`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.0.3`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.1.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.1.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.1.2`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.2.0`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.2.1`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.4.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.91.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.5.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.7.0`,
        fs:  `cpe:2.3:a:citrix:access_management_console_report_center:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.8.0`,
        fs:  `cpe:2.3:a:ibm:informix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:2.9.0`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.4.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.0.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.14:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.1.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.2.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.3.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.4.0`,
        fs:  `cpe:2.3:a:cisco:hsrp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.5.0`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.7.0`,
        fs:  `cpe:2.3:a:cisco:cius_software:9.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.8.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:49.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:3.9.0`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.1.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.2.0`,
        fs:  `cpe:2.3:a:bryce_hamrick:janrain_capture:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.3.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.4.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p229:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.5.0`,
        fs:  `cpe:2.3:a:vmware:tools:8.4.6.16648:*:*:*:linux:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.6.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bftpd_project:bftpd:4.8.0`,
        fs:  `cpe:2.3:a:util-linux_project:util-linux:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bgenergy:bgenergy:1.153.0034::~~~android~~`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biais:reddit_aww:1.2.1::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bias-inc:bias_soundsoap_pe:2.1.1`,
        fs:  `cpe:2.3:a:libexpat:expat:1.95.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biat:biatnet:1.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bib2html_project:bib2html:0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.0.0-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bib2html_project:bib2html:0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:google:android:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bib2html_project:bib2html:0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:janetter:janetter:3.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bib2html_project:bib2html:0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bib2html_project:bib2html:0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bib2html_project:bib2html:0.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:omnikey.aaitg:omnikey_cardman:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bib2html_project:bib2html:0.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bib2html_project:bib2html:0.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bic_media_widget_plugin:bic_media_widget:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biebernoticias:bieber_news_now:12.0.5::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigfix:discovery_platform:6.0`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigfix:discovery_platform:6.1`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb471xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigfix:discovery_platform:7.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigfix:discovery_platform:7.1`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:b1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:b2`,
        fs:  `cpe:2.3:a:joachim_ruhs:locator:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:b3`,
        fs:  `cpe:2.3:a:litronic:argus:5.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:b4`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:b5`,
        fs:  `cpe:2.3:a:collectiveaccess:providence:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:b6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:b7`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:rc1`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0:rc2`,
        fs:  `cpe:2.3:a:apache:traffic_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.1`,
        fs:  `cpe:2.3:a:ad-minister_project:ad-minister:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.2`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.4`,
        fs:  `cpe:2.3:a:health:how_to_boil_eggs:251333:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.6`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.7`,
        fs:  `cpe:2.3:a:nvidia:install_application:2.0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.8`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.tc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.9`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.10`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.11`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.12`,
        fs:  `cpe:2.3:a:citrix:xendesktop:4.0:fp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.0.13`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.1`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.2`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r3.4_1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.3`,
        fs:  `cpe:2.3:a:emc:rsa_authentication_agent:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.4`,
        fs:  `cpe:2.3:h:huawei:s3700:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.101_2097:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.9`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.10`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.12`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.13`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.14`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.15`,
        fs:  `cpe:2.3:a:redmine:redmine:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.16`,
        fs:  `cpe:2.3:o:yahama:rtw65i:5.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.17`,
        fs:  `cpe:2.3:a:clip-bucket:clipbucket:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.1.18`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_email_engine:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.3`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.4`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.5`,
        fs:  `cpe:2.3:h:cisco:nexus_5548p_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.6`,
        fs:  `cpe:2.3:a:equifax:equifax_mobile:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.7`,
        fs:  `cpe:2.3:h:sony:snc_ch180:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.8`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.10`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.11`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.12`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.13`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.14`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.15`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.16`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.17`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.18`,
        fs:  `cpe:2.3:o:cisco:ios:11.3na:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigtreecms:bigtree_cms:4.2.19`,
        fs:  `cpe:2.3:a:intel:mzconfig:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigware:bigware_shop:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigware:bigware_shop:2.0`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigware:bigware_shop:2.1.4`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bigware:bigware_shop:2.1.5`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bikersromagna:bikers_romagna:1::~~~android~~`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bikersunderground:bikers_underground:4.5.10::~~~android~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bil_simser:sharepointforums:1.2.0.0`,
        fs:  `cpe:2.3:a:samba:samba:2.2.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bilingual_magic_ball_project:bilingual_magic_ball:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:piwik:piwik:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bilingual_magic_ball_relajo_project:bilingual_magic_ball_relajo:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:magzter:dhanam:3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:billgbennett:bill_g._bennett:1::~~~android~~`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.1.8.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bilyoner:bilyoner:2.1.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bilyoner:bilyoner:2.3.1::~~~android~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bilyoner:bilyoner:4.6::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.06.0.171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bilyoner:bilyoner:4.6.2::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:binarymoon:timthumb:1.09`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:binarymoon:timthumb:1.15`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:binarymoon:timthumb:1.99`,
        fs:  `cpe:2.3:h:hp:laserjet_m725z\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:binarymoon:timthumb:2.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:binarymoon:timthumb:2.8.13`,
        fs:  `cpe:2.3:o:maygion:ip_camera_firmware:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:binarymoon:wordthumb:1.07`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0`,
        fs:  `cpe:2.3:a:umn:mapserver:6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.1`,
        fs:  `cpe:2.3:a:shopware:shopware:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.2`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.770.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.4`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.27:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.6`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.7`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.8`,
        fs:  `cpe:2.3:h:htc:evo_4g:gri40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.0.9`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.7:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.1.1`,
        fs:  `cpe:2.3:a:trendnet:securview_wireless_internet_camera_activex_control:1.1.52.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.1.2`,
        fs:  `cpe:2.3:a:ntwind:winsnap:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.1.3`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.1.3-6`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.1.4`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.1.5`,
        fs:  `cpe:2.3:a:novell:emframe:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:htmlawed:1.1.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:ordersys:1.5.5`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:ordersys:1.5.6`,
        fs:  `cpe:2.3:a:compaq:foundation_agents:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:ordersys:1.6`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_inventory_solution_for_unix_and_linux:6.2.1004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:ordersys:1.6.1`,
        fs:  `cpe:2.3:a:debian:sgml-tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:ordersys:1.6.2`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:ordersys:1.6.3`,
        fs:  `cpe:2.3:a:driveraccess:driveraccess:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:ordersys:1.6.4`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bioinformatics:ordersys:1.7`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biopdf:pdf_writer:7.1.0.1186`,
        fs:  `cpe:2.3:o:engardelinux:secure_linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bir.gov.ph:alphalist_data_entry_and_validation:2.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.7:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bir.gov.ph:alphalist_data_entry_and_validation:2.0:beta`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.239:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bir.gov.ph:alphalist_data_entry_and_validation:3.10`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bir.gov.ph:alphalist_data_entry_and_validation:3.20`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_ibm:14.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bird_feeder_project:bird_feeder:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:birebin:birebin.com_app:-::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_cover_page_editor:9.3.313`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:8.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_cover_page_editor:9.6.700`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p375:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_job_tracking:2.1.16`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_server:5.5.13.20`,
        fs:  `cpe:2.3:a:prosody:prosody:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_server:6.3.3.0`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_suite_for_windows:9.4.100`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_suite_for_windows:9.6.990`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1b.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_suite_for_windows_admin:9.4.100`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(25\)w5\(27\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_suite_for_windows_admin:9.6.990`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_suite_for_windows_client:9.4.100`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcom_suite_for_windows_client:9.6.990`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcomapi_for_faxcom_queue:9.4.0`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:biscom:faxcomapi_for_faxcom_queue:9.6.990`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha1`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha10`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha11`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha2`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha4`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha5`,
        fs:  `cpe:2.3:a:apache:subversion:0.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha6`,
        fs:  `cpe:2.3:a:altiris:software_delivery_solution:6.1.1058.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha7`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha8`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:-:alpha9`,
        fs:  `cpe:2.3:a:nortel:multimedia_communication_server_5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.1:alpha`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.1:beta`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.2:beta`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.3:beta`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.4:beta`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.5:beta`,
        fs:  `cpe:2.3:o:cisco:ons_15454_mspp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.6:beta`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.7:beta`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.10.1008:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.8:beta`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.9:beta`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.10:beta`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.11:beta`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.97.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.13:beta`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.1.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.14:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.15:beta`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:0.16:beta`,
        fs:  `cpe:2.3:a:wpgetready:nextcellent_gallery:1.9.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.04.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.1`,
        fs:  `cpe:2.3:a:sun:net_connect_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.3`,
        fs:  `cpe:2.3:a:google:chrome:14.0.813.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.4`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:ecd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.5`,
        fs:  `cpe:2.3:h:hp:topshot_laserjet_pro_m275_mfp:cf040a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.6`,
        fs:  `cpe:2.3:a:gnu:grep:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.7`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.8.1`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:1.9`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.0`,
        fs:  `cpe:2.3:a:beijerelectronics:beijer_adp:6.5.1-186_r2942:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.1`,
        fs:  `cpe:2.3:a:htc:hero_software:2.27.651.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.2`,
        fs:  `cpe:2.3:a:nbcfc:new_beginnings_cfc:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.3`,
        fs:  `cpe:2.3:o:vmware:esx:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.4`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.5`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.6`,
        fs:  `cpe:2.3:h:xerox:document_centre_535:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.7`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.8`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:2.0.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.9`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.10`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(6\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.12`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.13`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.25:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.14`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.16`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.17`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:2.18`,
        fs:  `cpe:2.3:a:security_questions_project:security_questions:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2-alpha1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.2`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.3`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.4`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.5`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.6`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.7`,
        fs:  `cpe:2.3:a:compaq:insight_management_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.8`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_it_asset_management_for_it:7.1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.10`,
        fs:  `cpe:2.3:a:gparted:gparted:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.11`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.0.12`,
        fs:  `cpe:2.3:h:intel:mobile_intel_gm45_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.1`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_foundation:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.2`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.2.1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.2.2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.2.3`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.2.4`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bit51:better-wp-security:3.2.5`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitbucket:xnbd:0.1.0:pre`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.3.4`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.3.5`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.3.8`,
        fs:  `cpe:2.3:h:hp:elitedesk_800_sff:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.3.10`,
        fs:  `cpe:2.3:a:boldonjames:masterkeyplus:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.3.11`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.3.12`,
        fs:  `cpe:2.3:a:python:python:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.0`,
        fs:  `cpe:2.3:a:apache:groovy:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.1:rc6`,
        fs:  `cpe:2.3:a:redhat:libtirpc:0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.2`,
        fs:  `cpe:2.3:a:macroplant:iexplorer:3.6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.4`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.4:rc2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:7.1.3:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.5`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.6`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.4.7:rc2`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.2.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.5.0:rc`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.5.1`,
        fs:  `cpe:2.3:a:altiris:appweaver:6.0.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.5.2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.5.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.5.3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.5.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.5.5`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.5.6:rc2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0:rc1`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.2.0:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0:rc3`,
        fs:  `cpe:2.3:a:emc:eroom:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0.1`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-rc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0.2`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0.4`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0.5`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0.6`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0.7`,
        fs:  `cpe:2.3:a:codepeople:com_multicalendar:4.9.0:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.0.8`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.6.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.480:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.8.0:rc1`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoin-qt:0.8.1`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.3.4`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.5:u1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.3.5`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.3.8`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g54_firmware:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.3.10`,
        fs:  `cpe:2.3:a:ibm:spss_analytical_decision_management:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.3.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.3.12`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.0`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.1:rc6`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.2`,
        fs:  `cpe:2.3:a:arcsight:arcsight_console:4.0.3.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.3`,
        fs:  `cpe:2.3:a:apache:hadoop:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.4`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:6.x-1.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.4:rc2`,
        fs:  `cpe:2.3:a:ca:etrust_admin:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.5`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.6`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.4.7:rc2`,
        fs:  `cpe:2.3:a:stilesoft:netcaptor:7.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.5.0:rc`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.5.2`,
        fs:  `cpe:2.3:a:apache:struts:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.5.3`,
        fs:  `cpe:2.3:a:serv-u:serv-u:4.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.5.3.1`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_microsoft_isa_server:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.5.4`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.5.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.5.6:rc2`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0`,
        fs:  `cpe:2.3:a:scripteen:free_image_hosting_script:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0:rc1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0:rc3`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0.1`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0.2`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:fnc9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0.4`,
        fs:  `cpe:2.3:a:posh_project:posh:2.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0.5`,
        fs:  `cpe:2.3:a:sybase:software_developer\&#39;s_kit:15.0_ga:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0.6`,
        fs:  `cpe:2.3:a:debian:reprepro:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0.7`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.0.8`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.6.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.14.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.8.0:rc1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:bitcoind:0.8.1`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.3.4`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.3.5`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.3.8`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.3.10`,
        fs:  `cpe:2.3:a:gnu:readline:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.3.11`,
        fs:  `cpe:2.3:a:hp:panostandalone:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.4.0`,
        fs:  `cpe:2.3:a:relsoftware:web_link_validator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.4.1`,
        fs:  `cpe:2.3:a:apache:spamassassin:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.4.1:rc6`,
        fs:  `cpe:2.3:a:ca:common_services:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin:wxbitcoin:0.5.0:rc`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.0`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:0.9.6:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.0:rc1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ixd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.0:rc3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.1`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.1:rc1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.1:rc2`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.11.2:rc1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.12.0`,
        fs:  `cpe:2.3:a:airdroid:airdroid:1.0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc2`,
        fs:  `cpe:2.3:a:caucho:resin:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc3`,
        fs:  `cpe:2.3:h:cisco:2700_wireless_location_appliance:1.1.73.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc4`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc5`,
        fs:  `cpe:2.3:a:skype:skype:3.1.0.134:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.12.0.knots20160226:rc1`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.12.1.knots20160629:rc2`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.3:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcoin_knots_project:bitcoin_knots:0.13.0.knots20160814`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitcricket:ip_calculator:1.1.0`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitdefender:gravityzone:5.1.5.386`,
        fs:  `cpe:2.3:a:hitachi:cosminexus\/opentp1_web_web_front-endset:02-50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitdefender:gravityzone:5.1.11.432`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bite_it%21_project:bite_it%21:1.1.8::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a3\(2.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitrix:mpbuilder:1.0.11::~~~bitrix~~`,
        fs:  `cpe:2.3:h:huawei:svn2000:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitrix:xscan:1.0.3::~~~bitrix~~`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.1f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitrock:bitrock_installbuilder_enterprise:7.0.2`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bitrock:bitrock_installbuilder_enterprise:7.2.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitrock:bitrock_installbuilder_enterprise:7.2.5`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bitrock:bitrock_installbuilder_enterprise:8.0.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bittorrent:bittorrent:6.4.0`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bittorrent:sync:-`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bittorrent:utorrent:2.0.3`,
        fs:  `cpe:2.3:a:mcafee:security_scan_plus:2.0.181.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bizagi:business_process_management_suite:10.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bizagi:business_process_management_suite:10.0.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(1\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bizagi:business_process_management_suite:10.1`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bizagi:business_process_management_suite:10.2`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bizagi:business_process_management_suite:10.3`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bizagi:business_process_management_suite:10.4`,
        fs:  `cpe:2.3:a:avg:anti-virus:7.0:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_enterprise_service:10.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_enterprise_service:10.1.0`,
        fs:  `cpe:2.3:h:3com:3c17304:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_enterprise_service:10.1.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.811:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_enterprise_service:10.2.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_enterprise_service:10.2.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_link:1.0.1.12`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_link:1.1.1.26`,
        fs:  `cpe:2.3:a:ask:ask_toolbar:1.13.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_link:1.1.1.41`,
        fs:  `cpe:2.3:a:activestate:activepython:2.5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_link:1.2.0.12`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_link:1.2.0.28`,
        fs:  `cpe:2.3:a:belarc:advisor:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.0`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.0.9.2743`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.0.10`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.0.10.85`,
        fs:  `cpe:2.3:h:3com:3c8462:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.0.10.261`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.0.10.648`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.1.0.273`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.1.0.2006`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.1.0.2014`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.1.0.2019`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.7.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.1.0.2312`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.2.0`,
        fs:  `cpe:2.3:a:emc:networker:7.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.2.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_os:10.3.0`,
        fs:  `cpe:2.3:a:emc:controlcenter:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:blackberry_playbook_os:2.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_universal_device_service:6.0`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.325:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_world:5.0.0.261`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_world:5.0.0.262`,
        fs:  `cpe:2.3:a:sun:netdynamics:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:blackberry_world:5.1.0.52`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:enterprise_server:5.0.4:mr6:~~~exchange_server~~`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:enterprise_server:5.0.4:mr6:~~~groupwise~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:enterprise_server:5.0.4:mr6:~~~lotus_domino~~`,
        fs:  `cpe:2.3:a:samba:samba:3.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:enterprise_server:12.4`,
        fs:  `cpe:2.3:a:adobe:freehand:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:enterprise_server_express:5.0.4::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:enterprise_server_express:5.0.4::~~~lotus_domino~~`,
        fs:  `cpe:2.3:a:transifex:transifex:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:good_control_server:2.2.511.26`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:qnx_momentics_tool_suite:4.5`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:qnx_momentics_tool_suite:4.6`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:qnx_momentics_tool_suite:4.7`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:qnx_momentics_tool_suite:6.5.0`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:qnx_momentics_tool_suite:6.5.0:sp1`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:10.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:qnx_neutrino_rtos:6.4.1`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:qnx_neutrino_rtos:6.5.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.9:bundle4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:blackberry:qnx_neutrino_rtos:6.5.0:sp1`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackberry:qnx_software_development_platform:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:226:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:blackberry:z10:-`,
        fs:  `cpe:2.3:a:apache:derby:10.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackboard:transact_suite:-`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackboard:transact_suite:3.6.0.1`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.12.142.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackboard:vista%2fce:8.0:sp6`,
        fs:  `cpe:2.3:a:cisco:ucs_director:4.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackbox:inkra_center_point:2.1.5-b011`,
        fs:  `cpe:2.3:a:csc:ddoe_cryptoprovider:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackbox:inkra_center_point:2.1.6-b032`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.2.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blackbox:inkra_suite:2.1.5-b011`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bladeenc:bladeenc:0.94.2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.8.0.2257:online_windows_server_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:filedepot:6.x-1.0`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:filedepot:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:filedepot:6.x-1.0:rc2`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:filedepot:6.x-1.0:rc3`,
        fs:  `cpe:2.3:a:mautic:mautic:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:filedepot:6.x-1.0:rc4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)mb13b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:filedepot:6.x-1.1`,
        fs:  `cpe:2.3:a:mystorexpress:tienda_virtual:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:filedepot:6.x-1.2`,
        fs:  `cpe:2.3:a:netfilter:ipset:6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:filedepot:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:dlink:dir865l_firmware:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:maestro:7.x-1.0`,
        fs:  `cpe:2.3:a:myanmar_movies_hd_project:myanmar_movies_hd:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:maestro:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress_ecommerce_shopping_cart:1.3.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:maestro:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:maestro:7.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:maestro:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:mozilla:firefox:50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:maestro:7.x-1.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blaine_lang:maestro:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blair_williams:pretty_link_lite:1.6.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blair_williams:pretty_link_lite:1.6.1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blair_williams:pretty_link_lite:1.6.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.340:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blingo:blingo_toolbar:1.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.1`,
        fs:  `cpe:2.3:a:tim_taylor:icon_restore:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.1.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.1.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.2.1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.2.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.05.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.2.3`,
        fs:  `cpe:2.3:a:sap:netweaver_logviewer:6.30:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.2.4`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.2.5`,
        fs:  `cpe:2.3:a:php:php:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.2.6`,
        fs:  `cpe:2.3:a:adobe:premiere_pro_cs4:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.2.7`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.3`,
        fs:  `cpe:2.3:a:yahoo:yui:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.3.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:1.4`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p392:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.1`,
        fs:  `cpe:2.3:a:drupal:drupal:7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.2`,
        fs:  `cpe:2.3:h:avaya:cajun_p580:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.2.1`,
        fs:  `cpe:2.3:a:gnu:screen:3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.3`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.3.5`,
        fs:  `cpe:2.3:a:apple:cups:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.4.1`,
        fs:  `cpe:2.3:a:pgp:desktop_for_mac:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.5.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.6`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.15:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.7`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.8`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.8.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.5.0.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.8.2`,
        fs:  `cpe:2.3:a:motorola:motohelper_mergemodules:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9`,
        fs:  `cpe:2.3:a:batavi:batavi:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9.1`,
        fs:  `cpe:2.3:h:alcatel:omniswitch_7800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9.3`,
        fs:  `cpe:2.3:a:openstack:swift:1.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9.4`,
        fs:  `cpe:2.3:a:apple:itunes:7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9.5`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9.6`,
        fs:  `cpe:2.3:a:emc:navisphere_manager:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9.7`,
        fs:  `cpe:2.3:a:v-one:smartpass:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:2.9.8`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:3.0`,
        fs:  `cpe:2.3:a:hp:select_identity:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:3.0.1`,
        fs:  `cpe:2.3:a:apple:cups:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:3.0.2`,
        fs:  `cpe:2.3:a:sophos:unified_threat_management_software:9.319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:3.0.3`,
        fs:  `cpe:2.3:a:lost_temple_project:lost_temple:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:3.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:3.2`,
        fs:  `cpe:2.3:o:dlink:des-3810_firmware:r2.00.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:3.3`,
        fs:  `cpe:2.3:a:trioniclabs:sentinel:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:4.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:4.0.1`,
        fs:  `cpe:2.3:h:lucent:access_point_service_router_1500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blinkwebeffects:social-media-widget:4.0.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.473:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blogengine:e2:2.4`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blogengine:e2:2.4:2845`,
        fs:  `cpe:2.3:a:debian:strongswan:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blogkamek:koleksi_hadis_nabi_saw:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blogstand_banner_plugin_project:blogstand-smart-banner:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bloodjournal:blood:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bloodshed:dev-c%2b%2b:4.9.9.2`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bloomyou:bloomyou_valentine:2.4::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blubrry:powerpress_podcasting:6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sunil_nanda:blue_wrench_video_widget:1.0.4:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecatnetworks:adonis:5.5.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sni1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecatnetworks:adonis_management_console:4.0.0.0`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecatnetworks:adonis_management_console:5.5.2.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_4948:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluechip:bc_post2facebook:0.2.0`,
        fs:  `cpe:2.3:h:intel:active_management_technology:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluechip:bc_post2facebook:0.2.1`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a3:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluechip:bc_post2facebook:0.2.2`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:advanced_secure_gateway:6.6`,
        fs:  `cpe:2.3:a:google:v8:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:avos:3.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:avos:3.2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:avos:3.2.6`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:avos:3.2.6.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:blue_coat_authentication_and_authorization_agent:5.2.3.2.32711`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:cacheos:-`,
        fs:  `cpe:2.3:a:wave:preboot_manager:1.0.3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:cacheos:4.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:cacheos:4.1.6`,
        fs:  `cpe:2.3:a:hp:xp7_command_view:8.4.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:cacheos_ca:4.1.10`,
        fs:  `cpe:2.3:a:horde:imp:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:cacheos_ca:4.1.12`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:8.0.1010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:cacheos_sa:4.1.10`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd7.d4xxd_svga_mb_firmware:1.24.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:cacheos_sa:4.1.12`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.54a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:content_analysis_system:-`,
        fs:  `cpe:2.3:a:f5:linerate:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:content_analysis_system_software:1.1`,
        fs:  `cpe:2.3:a:kftc:www.knote.kr_smart:1.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:content_analysis_system_software:1.1.1.1`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:content_analysis_system_software:1.1.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:content_analysis_system_software:1.1.4.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.08.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:director:5.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:director:5.5`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:director:5.5.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:director:5.5.2.3`,
        fs:  `cpe:2.3:a:ibm:lotus_quickr_for_domino:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:director_mc:1.0.0.0`,
        fs:  `cpe:2.3:a:microsoft:access:2013:*:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:k9_web_protection:-`,
        fs:  `cpe:2.3:a:oracle:internet_expenses:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:k9_web_protection:3.2.36`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxyav:-`,
        fs:  `cpe:2.3:a:avg:anti-virus:9.0:-:file_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:proxyclient:3.3.3.2`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:proxyclient:3.4.4.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.651:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg:-`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysg:4.1.2.1`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg:4.2.6`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.6:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg:5.2.2.4`,
        fs:  `cpe:2.3:a:chromium:chromium:11.0.696.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysg:5.3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysg:6.2.16.4`,
        fs:  `cpe:2.3:a:otrs:otrs:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysg:6.5.7.0`,
        fs:  `cpe:2.3:a:monotone:monotone:0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:proxysg:6.5.8.7`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysg:6.6.2.0`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg210-10:-:-:acceleration`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.6.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg210-10:-:-:full_proxy`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.10.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg210-25:-:-:acceleration`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2011.524.2259.39378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg210-25:-:-:full_proxy`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg210-5:-:-:acceleration`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg210-5:-:-:full_proxy`,
        fs:  `cpe:2.3:a:mobile4social:exposed_filter_data:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg510-10:-:-:acceleration`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(6\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg510-10:-:-:full_proxy`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg510-20:-:-:acceleration`,
        fs:  `cpe:2.3:h:htc:chacha:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg510-20:-:-:full_proxy`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg510-25:-:-:acceleration`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg510-25:-:-:full_proxy`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg510-5:-:-:full_proxy`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sq.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg810-10:-:-:acceleration`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg810-10:-:-:full_proxy`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg810-20:-:-:acceleration`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg810-20:-:-:full_proxy`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sg_3.3.0sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg810-25:-:-:acceleration`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg810-25:-:-:full_proxy`,
        fs:  `cpe:2.3:a:symantec:vrtsccg:5.0.286:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg810-5:-:-:full_proxy`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg9000-10:-:-:acceleration`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg9000-10:-:-:full_proxy`,
        fs:  `cpe:2.3:a:bundler:bundler:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg9000-20:-:-:acceleration`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg9000-20:-:-:full_proxy`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg9000-5:-:-:acceleration`,
        fs:  `cpe:2.3:a:magento:magento:1.9.1.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bluecoat:proxysg_sg9000-5:-:-:full_proxy`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:proxysg_va-10:-`,
        fs:  `cpe:2.3:h:hp:3com_switch:4500_pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:proxysg_va-15:-`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:proxysg_va-20:-`,
        fs:  `cpe:2.3:a:teradata:bteq:13.10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:proxysg_va-5:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.2:ea2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:5.3`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:proxysgos:5.4`,
        fs:  `cpe:2.3:a:pantech:umw190_end_user_upgrade:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:5.5`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:5.5.11`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.1.6.3`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.2`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.2.15.3`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.3`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.4`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.4.6.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.5`,
        fs:  `cpe:2.3:a:room_reservations_project:room_reservations:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:proxysgos:6.5.4`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:reporter:-`,
        fs:  `cpe:2.3:a:apache:ambari:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:reporter:7.1.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:reporter:9.2.4.1`,
        fs:  `cpe:2.3:a:avonesoft:stick_photo_star:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:-`,
        fs:  `cpe:2.3:a:apple:java_1.5:0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:3.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.65.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:3.1`,
        fs:  `cpe:2.3:a:citrix:provisioning_services:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:3.1.2`,
        fs:  `cpe:2.3:a:f5:big-iq_cloud:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:3.1.2.2`,
        fs:  `cpe:2.3:a:cisco:finesse:8.6\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:3.1.3.2`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.09:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:3.1.3.7`,
        fs:  `cpe:2.3:a:rack_project:rack:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:3.1.3.13`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:3.2.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:4.2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:5.2`,
        fs:  `cpe:2.3:a:apple:itunes:4.7:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:security_gateway_os:5.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:3.2.6`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.1.2.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.1.2`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.1.6`,
        fs:  `cpe:2.3:a:b-e-soft:artweaver_free:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.2`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.2.1`,
        fs:  `cpe:2.3:a:tincan:phplist:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.2.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.3`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.0.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.3.4`,
        fs:  `cpe:2.3:a:qemu:qemu:0.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.3.7`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.3.12`,
        fs:  `cpe:2.3:a:gnu:gdb:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.3.21`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.3.26`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.39.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.4.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.5`,
        fs:  `cpe:2.3:a:apple:itunes:4.7.1:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.5.1`,
        fs:  `cpe:2.3:a:powerdns:authoritative:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.6`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.6.1`,
        fs:  `cpe:2.3:a:cisco:webex_social:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.6.4`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.2.7.1`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper_live_streaming_integration:4.29.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.3.4`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:4.3.4.2`,
        fs:  `cpe:2.3:a:acme:thttpd:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:5.2.2.4`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:5.4.5`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:5.4.5.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:5.5.4`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.2.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:5.5.4.1`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-207_with_network_printer_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:6.1.2`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:bluecoat:sgos:6.1.2.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:unified_agent:4.1.3`,
        fs:  `cpe:2.3:a:icofx:icofx:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:unified_agent:4.6.1`,
        fs:  `cpe:2.3:a:exim:exim:4.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:-`,
        fs:  `cpe:2.3:a:microsoft:virtual_machine_manager:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1a`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1b`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1c`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1e`,
        fs:  `cpe:2.3:a:minitab:minitab:16.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1f`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2008.717.2343.40629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1h`,
        fs:  `cpe:2.3:h:cisco:epc3212:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1k`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1m`,
        fs:  `cpe:2.3:a:redhat:kdelibs_sound:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1n`,
        fs:  `cpe:2.3:a:webmin:usermin:1.350:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:4.0:r1p`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.173:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:5.0:r1a`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:5.0:r1b`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:5.0:r1c`,
        fs:  `cpe:2.3:a:sap:crystal_enterprise_xi_client_tools:3.1:fp_3.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:5.1:r1a`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:5.1:r1d`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:5.1:r1e`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:5.2:r1a`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:6.0:r1a`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:webproxy:6.0:r1c`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:winproxy:-`,
        fs:  `cpe:2.3:h:trendnet:tew-812dru:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:winproxy:6.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:17.011.30070:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:winproxy:6.0:r1c`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluecoat:winproxy:6.1:r1a`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blueeleph_project:blueeleph:1::~~~android~~`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blueman_project:blueman:2.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluemarblegeo:global_mapper:14.1.0`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluestacks:bluestacks:2.1.3.5650`,
        fs:  `cpe:2.3:a:invensys:wonderware_information_server:5.5:-:-:-:portal:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blueteck:witze_addon:0.9`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:2.9.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bluetooth:bluetooth_stack:2.1`,
        fs:  `cpe:2.3:a:devsaran:responsive:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluez:bluez:5.41`,
        fs:  `cpe:2.3:a:novell:zenworks_asset_management:7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluez:bluez:5.42`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bluez:bluez:5.46`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blynk:clarks_inn:3.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:api_management:4.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:blynk:deltin_suites:3.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:glib:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bm:bank_of_moscow_eirts_rent:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:compute_cluster:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:atrium_integration_engine:7.1.0`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:batch_impact_manager:6.4.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_console:8.0.0.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5_1.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_console:8.0.6.622`,
        fs:  `cpe:2.3:a:sap:router:721:117:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_console:8.1.2.233`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_console:8.1.3.312`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_operations_manager:7.4.6.790`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:7.4.6.790`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:7.6.0.168`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.0.2:*:*:*:*:wotlab_burning_board:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.359`,
        fs:  `cpe:2.3:a:bamboosolutions:alert\&#43;_subscriber_web_service:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.380`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.396`,
        fs:  `cpe:2.3:a:google:chrome:12.0.714.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.422`,
        fs:  `cpe:2.3:a:oracle:pharmaceutical:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.441`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.1\(1\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.6.622`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.1\(1.97\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.7.711`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.7.720`,
        fs:  `cpe:2.3:a:haxx:curl:7.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.7.722`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.8.814`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.8.817`,
        fs:  `cpe:2.3:h:linksys:wap55ag:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.0.10.1014`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.1.2.232`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.10.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.1.2.233`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.1.2.261`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.1.3.312`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:bladelogic_server_automation_rscd_agent:8.2.0.111`,
        fs:  `cpe:2.3:a:freedomscientific:magic:11.0.603.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:control-m%2fagent:6.3.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:control-m%2fagent:6.4.1`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:control-m%2fenterprise_manager:6.4.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:control-m%2fforecast:6.4.1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.8:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:control-m%2fserver:6.4.1`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-30-\/g:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:guardian_angel:-`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol:9.13.10.01`,
        fs:  `cpe:2.3:a:novell:netmail:3.10f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:-`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.2`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.2.3`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.2.5`,
        fs:  `cpe:2.3:a:freelinking_project:freelinking:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.2.7`,
        fs:  `cpe:2.3:a:attachmate:verastream_process_designer:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.3.00`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.4.00`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.4.11`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.7`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_agent:3.9.00::~~~aix~~`,
        fs:  `cpe:2.3:a:siemens:wincc:7.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:patrol_perform_agent:-`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_set:07-50-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:performance_manager:-`,
        fs:  `cpe:2.3:a:plone:plone:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system:1.0.0`,
        fs:  `cpe:2.3:o:hp:thinpro:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system:7.5.0.0`,
        fs:  `cpe:2.3:a:hp:webinspect:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system:7.10.2`,
        fs:  `cpe:2.3:a:invensys:wonderware_historian:10.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_administrator:6.3`,
        fs:  `cpe:2.3:a:codehaus:redback:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_administrator:7.1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_alert:7.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_email_engine:6.3`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_email_engine:7.1`,
        fs:  `cpe:2.3:a:ca:client_automation:12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_flashboards:5.1`,
        fs:  `cpe:2.3:a:redhat:network_satellite:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_flashboards:7.1`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_mid_tier:6.3`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_mid_tier:7.1`,
        fs:  `cpe:2.3:a:rpm:rpm:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_server:5.x%2f6.x`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.2\(3c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_user:6.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_user:7.0`,
        fs:  `cpe:2.3:h:hp:jg875a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_user:7.1`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass_pro:6.3.9:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:remedy_action_request_system_user:8.0.7820.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:service_desk_express:10.2.1.95`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:software_control-m_agent:-`,
        fs:  `cpe:2.3:a:tribiq:tribiq_cms:5.2.7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmc:software_control-m_agent:6.1.03`,
        fs:  `cpe:2.3:o:technicolor:td5130_router_firmware:2.05.c29gv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bmobile:imagine_next_bmobile:1.7.10.243::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.0\(0\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boa:boa:0.94.13`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boa:boa:0.94.14.17`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boa:boa:0.94.14.19`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.2.0:cp04:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boa:boa:0.94.14.20`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boa:boa:0.94.14.21`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:2.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:realvnc:realvnc:4.1.3:*:*:*:free:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:2.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:f5:big-ip:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:2.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20121027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:2.3:-:~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:2.4.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:2.5.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p461:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:2.6:-:~~~android~~`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:3.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.5.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:3.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:3.2.1:-:~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:3.3:-:~~~android~~`,
        fs:  `cpe:2.3:a:adobe:connect:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.3:-:~~~android~~`,
        fs:  `cpe:2.3:a:ipswitch:imail:2006.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.5.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.6:-:~~~android~~`,
        fs:  `cpe:2.3:a:netbsd:ftpd:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.6.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.10:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.7.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.7.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:crunchify:foursquare-checkins:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser:4.8:-:~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:2.6.1:-:~~~android~~`,
        fs:  `cpe:2.3:h:xerox:docutech_6110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:2.7:-:~~~android~~`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:2.7.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:10.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:2.8:-:~~~android~~`,
        fs:  `cpe:2.3:a:cisco:mediasense:10.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:2.9:-:~~~android~~`,
        fs:  `cpe:2.3:a:apple:cups:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:2.9.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:2.9.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:apache:camel:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.0.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.0.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:ca:spectrum:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.2:-:~~~android~~`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.3:-:~~~android~~`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.4:-:~~~android~~`,
        fs:  `cpe:2.3:h:dell:latitude_e5500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.5:-:~~~android~~`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.6:-:~~~android~~`,
        fs:  `cpe:2.3:a:oracle:e-business_intelligence:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.7:-:~~~android~~`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.8:-:~~~android~~`,
        fs:  `cpe:2.3:a:sony:sonicstage_mastering_studio:2.2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boatmob:boat_browser_mini:3.9:-:~~~android~~`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:1.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:1.4`,
        fs:  `cpe:2.3:a:sap:business_one_2005-a:6.80.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:1.5`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:1.8`,
        fs:  `cpe:2.3:a:alienwp:hatch:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:1.9`,
        fs:  `cpe:2.3:a:veritas:netbackup:4.5.0:mp3:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf011:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:2.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:2.2`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:2.3`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:2.4`,
        fs:  `cpe:2.3:a:gnu:automake:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:3.1`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:3.2`,
        fs:  `cpe:2.3:a:naver:line_play:2.3.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:3.3`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:3.4`,
        fs:  `cpe:2.3:a:imgburn:imgburn:2.5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:3.5`,
        fs:  `cpe:2.3:a:debian:apt-cacher:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:3.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:3.7`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.0`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p247:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.4`,
        fs:  `cpe:2.3:a:wdc:diagnostics:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.6`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.7`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.8`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.9`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.10`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.12`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.7_pre5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.13`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.14`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.14:alpha1`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_security_suite:6.1.744.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:4.14:alpha2`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:*:x86-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.0:alpha1`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.0:alpha2`,
        fs:  `cpe:2.3:a:microsoft:psshutdown:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.0:alpha3`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.0:alpha4`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.0:alpha6`,
        fs:  `cpe:2.3:o:novell:suse_linux:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.0:alpha7`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:pre.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.1`,
        fs:  `cpe:2.3:h:cisco:unity_server:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.2`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:5.4`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.5.5.568:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha1`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha2`,
        fs:  `cpe:2.3:a:idevspot:textads:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha3`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha4`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:17.012.20098:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha5`,
        fs:  `cpe:2.3:a:craig_peterson:turbopower_abbrevia:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha6`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha7`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha8`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.0:alpha9`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.1`,
        fs:  `cpe:2.3:a:hp:jetadmin:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.1:alpha1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1.\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.1:alpha2`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:15.0.5.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.1:alpha3`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.1:alpha4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.1:alpha5`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.2:alpha1`,
        fs:  `cpe:2.3:h:huawei:s3000:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.2:alpha2`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.2:alpha3`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.2:alpha4`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.2:alpha5`,
        fs:  `cpe:2.3:h:siemens:scalance_xf204irt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.2:alpha6`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.3:alpha1`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.3:alpha2`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:17.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.3:alpha3`,
        fs:  `cpe:2.3:a:google:chrome:16.0.894.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.3:alpha4`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.3:alpha5`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_flashboards:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.3:alpha6`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.4`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.5`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.6`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.7`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.8`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:6.9`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.0:alpha1`,
        fs:  `cpe:2.3:a:horde:groupware:5.1.0:rc1:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.0:alpha2`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.0:alpha3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.0:alpha4`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs3_third_party_content:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.0:alpha5`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.22.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.0:alpha7`,
        fs:  `cpe:2.3:a:php:php:5.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.0:alpha9`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.7:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.17:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.1:alpha2`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r21.2:*:*:*:*:linux_kernel:tegra:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.2:alpha2`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:2008.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.2:alpha4`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boehm-demers-weiser:garbage_collector:7.2:alpha6`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.20-25.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:drs_annotation_tool:2.5.0.1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:drs_data_courier_web:2.14.0.1`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:drs_data_courier_web:3.1.0.0`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:drs_data_courier_web:3.2.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:drs_web_configuration_manager:2.0.0.2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.8_rc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:drs_wiring_illuminator_web:1.10.0.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:drs_wiring_illuminator_web:1.14.0.0`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.24-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:imis_application_suite:5.0.2.1`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:imis_application_suite:5.2.2.26`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1664.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boeing:imis_message_system_rabbit:1.1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.0.0`,
        fs:  `cpe:2.3:a:microsoft:word:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.0.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.0.3`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p217:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.1.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.1.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2jx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.1.4`,
        fs:  `cpe:2.3:a:divx:player:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.1.5`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.1.6`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.1.7`,
        fs:  `cpe:2.3:a:shibboleth:opensaml_java:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.2.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:ga:client_workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.5:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.2.2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bogofilter_project:bogofilter:1.2.3`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.832:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boka:siteengine:5.0`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boka:siteengine:7.1.0`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bokublock:bbadminviewscontrol:2.0::~~~ec-cube~~`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bokublock:bbadminviewscontrol213:1.0::~~~ec-cube~~`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:5.x-3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boldonjames:masterkeyplus:4.4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boldonjames:masterkeyplus:5.4.0`,
        fs:  `cpe:2.3:a:netscape:communicator:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.0`,
        fs:  `cpe:2.3:a:microsoft:outlook:2010:sp2:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.01`,
        fs:  `cpe:2.3:a:kajona:kajona:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.02`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.0`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.3`,
        fs:  `cpe:2.3:a:kde:kauth:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.343:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.5`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.7`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p364:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.9`,
        fs:  `cpe:2.3:a:symantec:storage_exec:5.5.2310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.10`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.03v3-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.2.11`,
        fs:  `cpe:2.3:a:mclewin:wishlist:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3`,
        fs:  `cpe:2.3:a:zemanta:search_everything:7.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.03`,
        fs:  `cpe:2.3:h:cisco:c24_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.1`,
        fs:  `cpe:2.3:a:intergraph:user_access_tool:1.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.2`,
        fs:  `cpe:2.3:a:oracle:olap:12.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.4`,
        fs:  `cpe:2.3:a:inria:ocaml:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.5`,
        fs:  `cpe:2.3:a:novarm:diptrace:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.6`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.7`,
        fs:  `cpe:2.3:a:qianqin:qtranslate:2.5.39:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.8`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:7.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.3.9`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.04`,
        fs:  `cpe:2.3:a:mvd:surething_cd_labeler:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.2`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.3`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.5`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.6`,
        fs:  `cpe:2.3:a:fungames-forfree:sniper_shooter_free_-_fun_game:2.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.7`,
        fs:  `cpe:2.3:a:google:chrome:6.0.419.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.8`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.9`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.10`,
        fs:  `cpe:2.3:o:extremenetworks:exos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.11`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.12`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.13`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.20:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.14`,
        fs:  `cpe:2.3:a:ca:etrust_admin:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.15`,
        fs:  `cpe:2.3:a:emc:documentum_eroom:7.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.4.16`,
        fs:  `cpe:2.3:a:apache:derby:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.5`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.05`,
        fs:  `cpe:2.3:a:apache:axis:1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.06`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.07`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.08`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.09`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.10`,
        fs:  `cpe:2.3:a:debian:adequate:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.11`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.12`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:ccc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.13`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.14`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.15`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u1\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.16`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p273:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.17`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boltwire:boltwire:3.18`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bongomovie_project:bongomovie:1::~~~android~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.64:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bonitasoft:bonita_bpm_portal:6.5.2`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bookformobile:simple_car_care_tip_and_advice:1.03::~~~android~~`,
        fs:  `cpe:2.3:a:shopware:shopware:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bookjam:cookbible:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:booksbyraven:raven_-_the_culture_lover:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:codehaus:redback:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:booksellerscanada:free_canadian_author_previews:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bookx_plugin_project:bookx:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.1`,
        fs:  `cpe:2.3:a:microsoft:greetings:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.2`,
        fs:  `cpe:2.3:o:cisco:staros:18.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.4`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(6d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.6`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.7`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.8`,
        fs:  `cpe:2.3:a:apache:hadoop:0.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:7.x-2.0:alpha1`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:7.x-2.0:alpha2`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boombatower:subuser:7.x-2.x:dev`,
        fs:  `cpe:2.3:o:google:android:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.2`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.3`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.3:beta`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_deployment:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.5`,
        fs:  `cpe:2.3:a:businessobjects:infoview:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.7`,
        fs:  `cpe:2.3:a:opentext:livelink_imaging:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.8`,
        fs:  `cpe:2.3:a:lxml:lxml:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.0.9`,
        fs:  `cpe:2.3:a:nero:live:1.0.164.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.1.0`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.92.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.1.0:b1`,
        fs:  `cpe:2.3:a:plone:plone:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.1.0:b2`,
        fs:  `cpe:2.3:a:hp:software_perl:5.8.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.1.1`,
        fs:  `cpe:2.3:a:oracle:oracle_and_sun_systems_product_suite:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.1.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:11.5\(1.12000.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.1.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boonex:dolphin:7.1.4`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:boopsie:aapld:4.5.110::~~~android~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boopsie:anaheim_library_2go%21:4.5.110::~~~android~~`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boopsie:boopsie_mylibrary:4.5.110::~~~android~~`,
        fs:  `cpe:2.3:a:rivetcode:rivettracker:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boopsie:deschutes_public_mobilelibrary:4.5.110::~~~android~~`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:1.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boopsie:scottcolibmn:4.5.110::~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.25.0`,
        fs:  `cpe:2.3:a:seagate:maxtor_manager:4.2.303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.25.1`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:beta_5.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.26.0`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver_r304:309.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.27.0`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2006-03-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.28.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.29.0`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.30.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.30.1`,
        fs:  `cpe:2.3:a:ibm:informix_client-sdk:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.30.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.31.0`,
        fs:  `cpe:2.3:h:huawei:ne40e:v300r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.32.0`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.33.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.33.1`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.34.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.35.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.36.0`,
        fs:  `cpe:2.3:a:qemu:qemu:1.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.37.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p7_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.38.0`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.39.0`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.40.0`,
        fs:  `cpe:2.3:a:juniper:junos_space:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.41.0`,
        fs:  `cpe:2.3:a:mahara:mahara:16.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.42.0`,
        fs:  `cpe:2.3:a:oracle:micros_cwdirect:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.43.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p413:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.44.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.45.0`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.46.0`,
        fs:  `cpe:2.3:a:google:v8:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.46.1`,
        fs:  `cpe:2.3:a:hp:esupportdiagnostics:1.0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.47.0`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.48.0`,
        fs:  `cpe:2.3:a:ioserver:opc_drivers:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.49.0`,
        fs:  `cpe:2.3:h:hp:jd429a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.50.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:r9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.51.0`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.52.0`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.53.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.54.0`,
        fs:  `cpe:2.3:a:busybox:busybox:0.60.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.55.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.56.0`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.57.0`,
        fs:  `cpe:2.3:a:tips_and_tricks_hq:all_in_one_wordpress_security_and_firewall:3.8.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.58.0`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.59.0`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.60.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.61.0`,
        fs:  `cpe:2.3:a:winzip:winzipbar_toolbar:6.7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.62.0`,
        fs:  `cpe:2.3:a:gigaccsecure:gigacc_office:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.63.0`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.60129.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.64.0`,
        fs:  `cpe:2.3:h:hp:jetdirect_600n_eio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.65.0`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boost:boost:1.65.1`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:3.2.2:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:caliberrm:7.2.157.404`,
        fs:  `cpe:2.3:a:redhat:kernel_source:2.4.20-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:caliberrm:9.0.847`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:caliberrm:10.0.229`,
        fs:  `cpe:2.3:h:cisco:spa_525g_5-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:caliberrm_sdk:10.0.212`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(1.22\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:jbuilder_2005:11.0.0.0::~~developer~~~`,
        fs:  `cpe:2.3:a:blackberry:enterprise_server:5.0.4:mr6:*:*:*:groupwise:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:ldap_quickstart_manager:10.0.7.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:license_server:4.0.4.0`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:paradox:7.0`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:search:3.0.34.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:starteam_cross-platform_client:10.0.63.0`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:starteam_sdk_for_.net:10.0.58.0`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:starteam_sdk_runtime:10.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:starteam_sdk_runtime:2006`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:starteam_sdk_runtime_for_.net:10.0.58.0`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:starteam_server:10.0.57.0`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:borland:starteammpx_services:10.0.57.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boson:exam_environment:1.4.2`,
        fs:  `cpe:2.3:a:cdotech:edcl_common_web_service:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boson:exam_environment:1.5.5`,
        fs:  `cpe:2.3:a:subnet:substation_server:2.8.0106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boson:exam_environment:1.5.9`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.10.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boson:ms-exam_for_comptia_sy0-201:9.41`,
        fs:  `cpe:2.3:a:rsa:ace_agent:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boson:netsim:8.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.7.4\(270\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boson:subnet_calculator:2.0.4`,
        fs:  `cpe:2.3:a:ibm:websphere_extended_deployment_compute_grid:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.1`,
        fs:  `cpe:2.3:a:adobe:connect_enterprise_server:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.3`,
        fs:  `cpe:2.3:a:docker:docker:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.4`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.6`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.7`,
        fs:  `cpe:2.3:a:debian:apt-setup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.8`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.9`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.10`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.11`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.12`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.13`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.14`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.8.15`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.0`,
        fs:  `cpe:2.3:a:kofax:virtualrescan:4.50.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.1`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.2`,
        fs:  `cpe:2.3:o:compaq:easy_access_keyboard_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.3`,
        fs:  `cpe:2.3:a:hp:jetadmin:rev._d.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.4`,
        fs:  `cpe:2.3:a:lumension:patchlink_update_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.5`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.6`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.7`,
        fs:  `cpe:2.3:a:perl:perl:5.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.8`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.9`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.10`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:2.1:*:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.11`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.12`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.13`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.14`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update8:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.15`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.6.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.16`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.17`,
        fs:  `cpe:2.3:a:sympa:sympa:0.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.9.18`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.0`,
        fs:  `cpe:2.3:a:wave:embassy_security_setup:4.0.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.2`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.3`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a3:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.4`,
        fs:  `cpe:2.3:a:adaptivelearningsystems:crammaster:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.5`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.6`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.8`,
        fs:  `cpe:2.3:o:d-link:dsr-250n_firmware:1.08b39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.9`,
        fs:  `cpe:2.3:a:pass4sure:questions_and_answers_for_cisco_640-802:7.13.13049:*:*:*:demo:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.10`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.11`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.12`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.13`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.14`,
        fs:  `cpe:2.3:a:kmonos:xacrett:50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.10.15`,
        fs:  `cpe:2.3:a:python:python:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.0`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.1`,
        fs:  `cpe:2.3:a:fedora:pacemaker_configuration_system:0.9.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.2`,
        fs:  `cpe:2.3:a:apache:tomcat:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.3`,
        fs:  `cpe:2.3:a:drupal:drupal:7.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.4`,
        fs:  `cpe:2.3:a:mahara:mahara:17.04.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.5`,
        fs:  `cpe:2.3:a:opera:opera_browser:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.6`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.7`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.8`,
        fs:  `cpe:2.3:a:smackcoders:wp_ultimate_email_marketer_plugin:1.0.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.522:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.10`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.11`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.12`,
        fs:  `cpe:2.3:a:gnu:icecat:2.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.14`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.15`,
        fs:  `cpe:2.3:a:apache:apr-util:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.16`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update1:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.17`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:6.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.18`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62u:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.19`,
        fs:  `cpe:2.3:a:cisco:evolved_programmable_network_manager:1.2.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.20`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.17:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.21`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_endpoints:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.22`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.23`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.24`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.25`,
        fs:  `cpe:2.3:a:futomi:kmail_cgi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.26`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.27`,
        fs:  `cpe:2.3:a:sympa:sympa:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.28`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:1.11.33`,
        fs:  `cpe:2.3:a:infradead:openconnect:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botan_project:botan:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-1.0`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.2.4:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-1.1`,
        fs:  `cpe:2.3:a:getsetgames:mega_jump:\@7f080002:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ez1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-1.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-1.4`,
        fs:  `cpe:2.3:a:admin-font-editor_project:admin-font-editor:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-1.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-1.6`,
        fs:  `cpe:2.3:a:samba:samba:4.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:oracle:oracle_data_provider_for_.net_help:11.1.620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-2.0`,
        fs:  `cpe:2.3:a:qemu:qemu:0.13.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:digium:asterisk:c.1.0:beta8:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-3.0`,
        fs:  `cpe:2.3:a:fonality:fonality:12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-3.1`,
        fs:  `cpe:2.3:a:vmware:vcenter_update_manager:4.1.0.8977:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-3.2`,
        fs:  `cpe:2.3:a:emc:watch4net:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-3.3`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-3.x:dev`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:botcha_spam_prevention_project:botcha:7.x-4.x:dev`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.1`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.2`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.3`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.5`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg240a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.6`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.7`,
        fs:  `cpe:2.3:a:codehaus:redback:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.8`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.9`,
        fs:  `cpe:2.3:a:f5:big-iq_device:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.10`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.2.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.10.11`,
        fs:  `cpe:2.3:a:barebones:yojimbo:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.11.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.11.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.11.2`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.11.3`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.11.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)za2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.11.5`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.11.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.11.7`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.12.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.12.1`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.12.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(3\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.12.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.12.4`,
        fs:  `cpe:2.3:a:lsi:mystorage:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottlepy:bottle:0.12.5`,
        fs:  `cpe:2.3:a:microsoft:visio:2010:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottomline:transform_foundation_server:4.3.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bottomline:transform_foundation_server:5.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.66.33:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:0.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.01`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.02`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.2`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.3`,
        fs:  `cpe:2.3:a:chattanoogastate:elearn:1.0.649.1194:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.03`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.1.92a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.04`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.4`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:101p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.5`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.05`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1281.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.06`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.6`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.6.1`,
        fs:  `cpe:2.3:a:isc:bind:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.7`,
        fs:  `cpe:2.3:a:shirakaba_project:shirakaba:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.07`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.b03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.08`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.09`,
        fs:  `cpe:2.3:a:compaq:survey_utility:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.10`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.11`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.00c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.12`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.13`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.14`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.15`,
        fs:  `cpe:2.3:a:opscode:chef:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.16`,
        fs:  `cpe:2.3:a:id:libdigidoc:3.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.17`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.18`,
        fs:  `cpe:2.3:a:roxio:mydvd_plus:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.19`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.20`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.21`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.22`,
        fs:  `cpe:2.3:a:x.org:libxv:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.23`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.24`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.3s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.25`,
        fs:  `cpe:2.3:a:apache:solr:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.26`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0068:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.27`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.28`,
        fs:  `cpe:2.3:a:jruby:jruby:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.29`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.30`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.32`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.33`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.34`,
        fs:  `cpe:2.3:h:cisco:b200_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.35`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.36`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.37`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.38`,
        fs:  `cpe:2.3:o:ibm:vios:1.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.39`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.40`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.41`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.42`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.43`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.44`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.45`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1670.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.46`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.47`,
        fs:  `cpe:2.3:a:samba:samba:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-cryptography-api:1.48`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:0.0`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.0`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.1`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.3p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.5`,
        fs:  `cpe:2.3:a:sybase:powerbuilder_virtual_machine:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.6.1`,
        fs:  `cpe:2.3:a:webmin:webmin:1.620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.7`,
        fs:  `cpe:2.3:a:pwgrandom_project:pwgrandom:1.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-c%23-crytography-api:1.8`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.01`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2104he:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.02`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.03`,
        fs:  `cpe:2.3:h:xerox:workcentre_m55:4.97.20.032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.04`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.05`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.06`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.07`,
        fs:  `cpe:2.3:a:xnview:xnview:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.08`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.09`,
        fs:  `cpe:2.3:h:cisco:sg300-52:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.10`,
        fs:  `cpe:2.3:a:bea:weblogic_server:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.11`,
        fs:  `cpe:2.3:a:x:x_server:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.12`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.5:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.13`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.14`,
        fs:  `cpe:2.3:a:commonsensesoftwarellc:bates:1.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.15`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x52:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.16`,
        fs:  `cpe:2.3:a:novell:iprint:5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.17`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.2:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.18`,
        fs:  `cpe:2.3:a:saltstack:salt_2015:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.19`,
        fs:  `cpe:2.3:a:squid-cache:squid:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.20`,
        fs:  `cpe:2.3:h:lexmark:e33x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.21`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.3:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.22`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_viewer:12.2.208.1040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.23`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.3.2:pl:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.24`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.25`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.26`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.27`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.28`,
        fs:  `cpe:2.3:a:rsa:authentication_client:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.29`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.30`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.31`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp5:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.32`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.00:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.33`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.34`,
        fs:  `cpe:2.3:h:f5:big-ip_3900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.35`,
        fs:  `cpe:2.3:a:oracle:database:12.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.36`,
        fs:  `cpe:2.3:a:gnome:glib:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.37`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.38`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.39`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.40`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.41`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.42`,
        fs:  `cpe:2.3:h:rockwellautomation:ab_micrologix_controller:1400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.43`,
        fs:  `cpe:2.3:a:symantec:ghost_console_client:115.0.2113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.44`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.45`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:9.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.46`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.47`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.48`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.d2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.54`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bouqs_-_flowers_simplified_project:bouqs_-_flowers_simplified:1.8.4::~~~android~~`,
        fs:  `cpe:2.3:a:h2o_project:h2o:2.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bowenehs:cih_quiz_game:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.1:mp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxautomation:c2box:4.0.0`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp5:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.816:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0:beta2`,
        fs:  `cpe:2.3:a:atlassian:jira:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0:beta4`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0:beta5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0:beta6`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.0.1.2708:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0:beta7`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.0:beta8`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:boxes_project:boxes:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpurcell:keytool_gui:1.7`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.0.157`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.0.161`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.0.163`,
        fs:  `cpe:2.3:a:autonomy:keyview_viewer_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.0.174`,
        fs:  `cpe:2.3:a:busybox:busybox:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.1.188`,
        fs:  `cpe:2.3:a:ibm:sametime:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.1.204`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.2.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.2.226`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xnc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.3.248`,
        fs:  `cpe:2.3:a:php:php:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.4.254`,
        fs:  `cpe:2.3:a:crear.ne.jp:al-mail32:1.13:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:2.4.256`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.4.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:3.0.306`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:3.1.322`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bpvn:pipeboost:3.1.324`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bradesco_gateway_plugin_project:bradesco_gateway:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mixpanel_project:mixpanel:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns500rx`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns500x`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns550rx`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns1200rx`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns1200x`,
        fs:  `cpe:2.3:h:cisco:nexus_5648q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns2200rx`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns8200rx`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.642.4:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns8200x`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:bradfordnetworks:network_sentry_appliance:ns9200rx`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.2:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bradfordnetworks:network_sentry_appliance_software:5.3`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bradfordnetworks:network_sentry_appliance_software:5.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brainabundance:brain_abundance_info:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:projectsend:projectsend:156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.0`,
        fs:  `cpe:2.3:a:redhat:openshift_origin:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.1`,
        fs:  `cpe:2.3:a:realflex:realwin:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.2`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.3.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:6.3.2:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.4`,
        fs:  `cpe:2.3:a:sap:hybris:5.0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.5`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.7.5`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.8.9.1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.8.9.3`,
        fs:  `cpe:2.3:a:pagetriage_project:pagetriage:-:*:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.1`,
        fs:  `cpe:2.3:o:huawei:5710ei_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.5`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.6`,
        fs:  `cpe:2.3:a:gns3:gns3:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.7.6`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:5.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.7.7`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.8`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.8.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.8.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1672.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.8.3`,
        fs:  `cpe:2.3:a:jease:jease:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)sv3\(1.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9.3`,
        fs:  `cpe:2.3:a:buffalotech:fs-g54_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9.4`,
        fs:  `cpe:2.3:a:runtastic:runtastic_pedometer:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9.5`,
        fs:  `cpe:2.3:a:social_stats_project:social_stats:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9.6`,
        fs:  `cpe:2.3:a:apple:webkit:412.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9.7`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.9.8`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.10`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.11`,
        fs:  `cpe:2.3:a:apache:mod_perl:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.12`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.13`,
        fs:  `cpe:2.3:o:huawei:s5300ei_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.14`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.020.20039:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.15`,
        fs:  `cpe:2.3:a:php:php:5.6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.16`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.75:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.17`,
        fs:  `cpe:2.3:a:perl:perl:5.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.18`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:compute_cluster:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.19`,
        fs:  `cpe:2.3:a:ibm:sametime:8.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.19.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_3500xl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.19.2`,
        fs:  `cpe:2.3:h:siemens:scalance_x201-3p_irt_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.19.3`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.1:ur1:platform:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.19.4`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.19.5`,
        fs:  `cpe:2.3:a:h-fj:mt-phpincgi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.20`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.21`,
        fs:  `cpe:2.3:h:hp:0235a327:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.21.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.22`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.22.1`,
        fs:  `cpe:2.3:a:mollify:mollify:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.23`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.24`,
        fs:  `cpe:2.3:o:cisco:spa3102_voice_gateway_with_router_firmware:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.25`,
        fs:  `cpe:2.3:a:moodle:moodle:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bravenewcode:wptouch:1.9.26`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:breakingpointsystems:breakingpoint_storm_appliance:-`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:breakingpointsystems:breakingpoint_storm_appliance_ctm:1.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:breakingpointsystems:breakingpoint_storm_appliance_ctm:1.4`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:breakingpointsystems:breakingpoint_storm_appliance_ctm:1.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.08.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:breakingpointsystems:breakingpoint_storm_appliance_ctm:2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:breakingpointsystems:breakingpoint_storm_appliance_ctm:3.0`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:07-56:-:enterprise:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:-:-:~~~android~~`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:1.2.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_pdfwriter:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:1.2.3:-:~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.18:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:1.2.4:-:~~~android~~`,
        fs:  `cpe:2.3:a:snake_evolution_project:snake_evolution:1.3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:1.2.8:-:~~~android~~`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:1.2.10:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.2:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:1.2.13:-:~~~android~~`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:1.2.14:-:~~~android~~`,
        fs:  `cpe:2.3:a:novaboard:novaboard:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:breezy:breezy:1.2.15:-:~~~android~~`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_layout:2.1`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_layout:2.11.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_layout:2.11.14`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_layout:3.0.3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_layout:3.2`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_layout:3.2.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_layout:3.3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_layout:3.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_akers:mod_mp3:0.40`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_altenhofel:slidebox:5.x-1.x:dev`,
        fs:  `cpe:2.3:a:tibco:spotfire_automation_services:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_altenhofel:slidebox:7.x-1.0`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_altenhofel:slidebox:7.x-1.1`,
        fs:  `cpe:2.3:a:apple:xcode:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_altenhofel:slidebox:7.x-1.2`,
        fs:  `cpe:2.3:h:f5:big-ip_6400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_altenhofel:slidebox:7.x-1.3`,
        fs:  `cpe:2.3:a:oracle:commerce_guided_search_and_experience_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_altenhofel:slidebox:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:oracle:customer_interaction_history:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_burton:paypal_pro_payflow_module:-`,
        fs:  `cpe:2.3:a:redhat:jboss_fuse:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brian_cabunac:browser_to_email_phone_message_system:1.0`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brickom:100ap_device_firmware:3.0.6.16c1`,
        fs:  `cpe:2.3:a:cisco:spark:2015-07-04_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brickom:100ap_device_firmware:3.1.0.8`,
        fs:  `cpe:2.3:a:cisco:content_security_management_appliance:9.1.0-103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brickom:fb-100ap:-`,
        fs:  `cpe:2.3:a:hp:network_node_manager:8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brickom:md-100ap:-`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brickom:ob-100ae:-`,
        fs:  `cpe:2.3:h:hp:jf802a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brickom:osd-040e:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brickom:wcb-100ap:-`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brickom:wfb-100ap:-`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brio:folder_size_for_windows:2.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brio:folder_size_for_windows:2.5`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brion_vibber:centralauth_extension:-:-:~-~-~mediawiki~~`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brivo:acs5000-s:-`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(4f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brlcad:brlcad:7.26.0`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:advanced_control_suite:8.20.1`,
        fs:  `cpe:2.3:a:janetter:janetter:3.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:asf_management_applications:10.6.1`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:asf_management_applications:10.16.2`,
        fs:  `cpe:2.3:o:cisco:ios:10.3\(4.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:4.9.0`,
        fs:  `cpe:2.3:a:milesj:decoda:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:7.70.5`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:8.12.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:10.3.1`,
        fs:  `cpe:2.3:a:devicelock:devicelock:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:10.15.1`,
        fs:  `cpe:2.3:a:emc:navisphere_manager:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:10.20.3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:10.38.6`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:10.59.11`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_for_visual_studio_2010:13.0.2.469:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:11.88.1`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:management_programs:12.30.11`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:broadcom:pipa_c211:-:rev2`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:2.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:pipa_c211_web_interface:1.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:ush_host_components:1.2.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_server:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:broadcom:widcomm_bluetooth:-`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-28p-pwr-ei_ls-3600-28p-pwr-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:widcomm_bluetooth:-`,
        fs:  `cpe:2.3:a:boost:boost:1.38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadcom:widcomm_bluetooth:4.0.1.1500`,
        fs:  `cpe:2.3:h:cisco:ie-4000-4t4p4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broadvision:command_center:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.15:pre16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:data_center_fabric_manager:10.4.0.0`,
        fs:  `cpe:2.3:a:ca:resource_initialization_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:data_center_fabric_manager:10.4.2.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:ezswitchsetup:2.0.0.0`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brocade:fabric_os:-`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brocade:fabric_os:2.1.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brocade:fabric_os:2.2`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7942g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brocade:fabric_os:3.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brocade:fabric_os:5.0.5b`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_os_deployment:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brocade:fabric_os:5.2.0`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brocade:fabric_os:5.2.0a`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:network_advisor:11.0.0.0`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110829:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:network_advisor:11.0.2.0`,
        fs:  `cpe:2.3:a:dataload:dataload:5.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:san_health_diagnostics_capture:3.1.4a`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:san_health_diagnostics_capture:3.1.5a`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:san_health_diagnostics_capture:3.2.1a`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:san_health_diagnostics_capture:3.2.4`,
        fs:  `cpe:2.3:a:apple:xcode:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:san_health_professional:1.0.0.4`,
        fs:  `cpe:2.3:a:scriptlogic:secure_copy:3.82.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:silkworm_12000_director:-`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:silkworm_200e_switch:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p162:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:silkworm_24000_director:-`,
        fs:  `cpe:2.3:a:git-scm:git:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:silkworm_3250_fabric_switch:-`,
        fs:  `cpe:2.3:a:textpattern:textpattern:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:silkworm_3850_fabric_switch:-`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:silkworm_3900_switch:-`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:silkworm_48000_director:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:silkworm_4900_fibre_channel_switch:-`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:smi_agent:120.7.2.0`,
        fs:  `cpe:2.3:o:dlink:des-3810-28_firmware:r2.20.b017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:smi_agent:120.8.0.0`,
        fs:  `cpe:2.3:a:novell:edirectory:8.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brocade:vyatta_vrouter:-`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.807:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brocade:vyatta_vrouter_software:6.6`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broderbund:calendar_creator:10.0`,
        fs:  `cpe:2.3:a:shiromuku:diary:-:*:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:broderbund:calendar_creator:12.0`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brokenscreencrank_project:brokenscreencrank:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brother:mfc-j4410dw:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:brother:mfc-j4410dw_firmware:k`,
        fs:  `cpe:2.3:a:redhat:kdelibs_sound_devel:2.1.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brother:mfl-pro_suite:1.0`,
        fs:  `cpe:2.3:h:yokogawa:centum_vp_entry_class:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brother:mfl-pro_suite:1.0.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.21.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brother:mfl-pro_suite:1.1.8.0`,
        fs:  `cpe:2.3:a:apache:org.apache.sling.servlets.post:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:brother:nc-3100h:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.802:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brother:p-touch_editor:3.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p298:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brother:p-touch_editor:3.2`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:brotherscripts:business_directory:-`,
        fs:  `cpe:2.3:a:ixiacom:ixos_easp1:5.20.400.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:browserweb:whizz:1.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.0\(2\)e0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bryce_hamrick:janrain_capture:6.x-1.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bryce_hamrick:janrain_capture:7.x-1.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsalsa:embeddedwb:14.57`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsalsa:embeddedwb:14.59`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:f:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bscw:bscw:5.0.7`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bscw:bscw:5.0.8`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsd_group:license_server:6.1.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsd_mailx_project:bsd_mailx:8.1.2`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.0.1`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.1`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.2`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.2:rc1`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.2:rc2`,
        fs:  `cpe:2.3:a:apple:apple_mobile_device_support:3.2.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.2:rc3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.97:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.2:rc4`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:60.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.2.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.2.2`,
        fs:  `cpe:2.3:h:fortinet:fortigaterugged-100c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:1.2.3`,
        fs:  `cpe:2.3:a:microsoft:dynamics_ax:2009:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bsdperimeter:pfsense:2.0:beta4`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_enterprise_client:3.23:-:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:bss:continuity_cms:4.2.22640.0`,
        fs:  `cpe:2.3:a:impresspages:impresspages_cms:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bssys:rbs_bs-client:3.17.9`,
        fs:  `cpe:2.3:a:atlassian:jira:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddhist_prayer_project:buddhist_prayer:3::~~~android~~`,
        fs:  `cpe:2.3:a:sun:one_messaging_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.50.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5.2`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5.3`,
        fs:  `cpe:2.3:a:tincan:phplist:1.1.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5.3.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_server:04-01:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5.4`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5.5`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5.6`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.5.7`,
        fs:  `cpe:2.3:a:docker:docker:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.6`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.6.1`,
        fs:  `cpe:2.3:o:alliedtelesis:img624a_firmware:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.6.2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.6.3`,
        fs:  `cpe:2.3:a:digium:asterisk:10.6.1:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.6.4`,
        fs:  `cpe:2.3:a:ca:api_gateway:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.6.5`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.7`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.7.1`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.7.2`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.7.3`,
        fs:  `cpe:2.3:a:exim:exim:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.8`,
        fs:  `cpe:2.3:a:apache:geronimo:3.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.8.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.9`,
        fs:  `cpe:2.3:a:cisco:security_manager_client:3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buddypress:buddypress_plugin:1.9.2`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.6.9`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7.1`,
        fs:  `cpe:2.3:a:kaseya:virtual_system_administrator:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7.2`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7.3`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7.5`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7.6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7.7`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7.8`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.7.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xi1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:0.8.1`,
        fs:  `cpe:2.3:a:netscape:navigator:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.0`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.1`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.2`,
        fs:  `cpe:2.3:a:perl:perl:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.4`,
        fs:  `cpe:2.3:a:git-scm:git:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.4.1`,
        fs:  `cpe:2.3:a:debian:apt:0.7.2-0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.4.2`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.4.3-6`,
        fs:  `cpe:2.3:a:buffalotech:whr-ampg_firmware:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.4.7`,
        fs:  `cpe:2.3:a:busybox:busybox:1.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.5`,
        fs:  `cpe:2.3:a:google:chrome:14.0.822.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.5.1`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.5.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.5.3-8`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.6.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-00-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.6.3`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.6.4`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.15:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.6.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.6.6-7`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.6.8`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.6.9`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.2`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.4`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.5`,
        fs:  `cpe:2.3:h:cisco:nexus_5020p_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.6`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.7`,
        fs:  `cpe:2.3:a:lsoft:listserv:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.8`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.9`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.10`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.12`,
        fs:  `cpe:2.3:a:openttd:openttd:0.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.13`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.14`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.15`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:sp2:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.16`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.607:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.17`,
        fs:  `cpe:2.3:a:equis:metastock:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.18`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.19`,
        fs:  `cpe:2.3:a:gentoo:glibc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.20`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.21`,
        fs:  `cpe:2.3:a:oracle:financial_consolidation_hub:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.22`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.23`,
        fs:  `cpe:2.3:a:apple:apache_mod_digest_apple:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.24`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.25`,
        fs:  `cpe:2.3:a:microsoft:orca:11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.26`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bueltge:adminimize:1.7.27`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:airstation_extreme_n600:-`,
        fs:  `cpe:2.3:a:quick_edit_project:quick_edit:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:airstation_extreme_n600_firmware:2.09`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:airstation_extreme_n600_firmware:2.13`,
        fs:  `cpe:2.3:a:condor_project:condor:7.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:airstation_extreme_n600_firmware:2.16`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:as-100:-`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:as-100_firmware:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.14s.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:bbr-4hg:-`,
        fs:  `cpe:2.3:a:siemens:teamcenter_visualization:8.0.9085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:-`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:beta2:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.02`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p483:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.04`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.04:beta`,
        fs:  `cpe:2.3:a:deltek:risk_\&#43;:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.10`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:12.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.10:beta`,
        fs:  `cpe:2.3:a:citrix:metaframe_secure_access_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.11:beta`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.12`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:2.0.0:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.20`,
        fs:  `cpe:2.3:a:microsoft:ie:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.20:beta`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.30`,
        fs:  `cpe:2.3:a:adobe:photoshop:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.30:beta`,
        fs:  `cpe:2.3:a:cisco:secure_services_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.31`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.32`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.32:beta`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.8.14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.33:beta`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.40:beta`,
        fs:  `cpe:2.3:a:debian:ppthtml:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.42`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.43`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.43:beta`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.1r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4hg_firmware:1.43:beta2`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:bbr-4mg:-`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:-`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.00`,
        fs:  `cpe:2.3:a:hp:product_assistant:140.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.01:beta`,
        fs:  `cpe:2.3:h:3com:tippingpoint_200e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.03`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.04`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.04:beta`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.10`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:4.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.10:beta`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.11:beta`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.12`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.20`,
        fs:  `cpe:2.3:a:serv-u:serv-u:11.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.20:beta`,
        fs:  `cpe:2.3:o:microsoft:windows:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.30`,
        fs:  `cpe:2.3:a:google:v8:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.30:beta`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.3.0:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.31`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:1.6.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.32`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.159.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.32:beta`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.33`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.33:beta`,
        fs:  `cpe:2.3:a:mathijs_koenraadt:search_api_sorts:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.40:beta`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.377:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.42`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.43`,
        fs:  `cpe:2.3:a:happyworm:jplayer:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.43:beta`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bbr-4mg_firmware:1.43:beta2`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:bhr-4grv2:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:bhr-4grv2_firmware:1.03`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:bhr-4grv2_firmware:1.04`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:bhr-4grv2_firmware:1.04`,
        fs:  `cpe:2.3:a:projectsend:projectsend:105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:bhr-4grv2_firmware:1.05`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:3.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:bhr-4rv:-`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:-`,
        fs:  `cpe:2.3:o:siemens:scalance_x200irt_firmware:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.31`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:rc4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.32:prebeta`,
        fs:  `cpe:2.3:a:jenkins:git:3.4.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.33:prebeta`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2-p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.42`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.7:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.46`,
        fs:  `cpe:2.3:a:wimba:pronto:3.1.0-d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.48`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.49`,
        fs:  `cpe:2.3:o:cisco:mgx_8230:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.50`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:bhr-4rv_firmware:2.52`,
        fs:  `cpe:2.3:a:gnu:emacs:21.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:fs-g54:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:fs-g54_firmware:-`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6a:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:fs-g54_firmware:2.07`,
        fs:  `cpe:2.3:a:capasystems:performance_guard:6.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wer-a54g54:-`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:-`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.00`,
        fs:  `cpe:2.3:a:microsoft:sysinternals_pstools:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.01:beta`,
        fs:  `cpe:2.3:a:sap:hybris:5.5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.02`,
        fs:  `cpe:2.3:a:hp:openview_performance_extended_capability_technology:4.70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.03`,
        fs:  `cpe:2.3:a:haxx:curl:7.52.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.10`,
        fs:  `cpe:2.3:a:ca:brightstor_process_automation_manager:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.12`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.526:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.12:beta`,
        fs:  `cpe:2.3:a:adobe:framemaker:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.13`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-a54g54_firmware:1.43`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wer-ag54:-`,
        fs:  `cpe:2.3:a:hp:toolbox:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-ag54_firmware:-`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-ag54_firmware:1.04`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-ag54_firmware:1.12`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.4m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-ag54_firmware:1.12:beta`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-ag54_firmware:1.43`,
        fs:  `cpe:2.3:a:oracle:application_server_portal:9.0.2.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wer-am54g54:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-am54g54_firmware:-`,
        fs:  `cpe:2.3:a:emc:documentum_administrator:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-am54g54_firmware:1.11`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2011.1025.2152.37348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-am54g54_firmware:1.12`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-am54g54_firmware:1.12:beta`,
        fs:  `cpe:2.3:a:apple:safari:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-am54g54_firmware:1.13`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-am54g54_firmware:1.14`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.06.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-am54g54_firmware:1.43`,
        fs:  `cpe:2.3:a:dadabik:dadabik:3.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wer-amg54:-`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-amg54_firmware:-`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-amg54_firmware:1.11`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-amg54_firmware:1.12`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-amg54_firmware:1.14`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wer-amg54_firmware:1.43`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wex-300:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wex-300_firmware:1.50`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wex-300_firmware:1.60`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:wex-300_firmware:1.70`,
        fs:  `cpe:2.3:a:innominate:mguard_pci:hw-102050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:wex-300_firmware:1.90`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-1166dhp:-`,
        fs:  `cpe:2.3:a:oracle:applications:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-1166dhp_firmware:1.41`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-1166dhp_firmware:1.60`,
        fs:  `cpe:2.3:a:crgroup-lb:c.r._group:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:whr-1166dhp_firmware:1.70`,
        fs:  `cpe:2.3:a:python:python:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:whr-1166dhp_firmware:1.90`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-300hp2:-`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-300hp2_firmware:1.10`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-300hp2_firmware:1.20`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:7.02.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-300hp2_firmware:1.40`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-300hp2_firmware:1.60`,
        fs:  `cpe:2.3:a:spip:spip:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:whr-300hp2_firmware:1.70`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:whr-300hp2_firmware:1.71`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:8.0.298.035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:whr-300hp2_firmware:1.90`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-600d:-`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-600d_firmware:1.41`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-600d_firmware:1.60`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:whr-600d_firmware:1.70`,
        fs:  `cpe:2.3:a:demandmedia:pluck_sitelife:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:whr-600d_firmware:1.90`,
        fs:  `cpe:2.3:a:sun:mysql_connector\/j:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-am54g54:-`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-am54g54_firmware:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-am54g54_firmware:1.30`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-am54g54_firmware:1.38`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.4.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-am54g54_firmware:1.40`,
        fs:  `cpe:2.3:a:php:php:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-am54g54_firmware:1.42`,
        fs:  `cpe:2.3:a:kde:koffice:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-am54g54_firmware:1.43`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-amg54:-`,
        fs:  `cpe:2.3:a:cisco:webex_meetmenow:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-amg54_firmware:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-amg54_firmware:1.31`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-amg54_firmware:1.38`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_6941:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-amg54_firmware:1.40`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-amg54_firmware:1.42`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-amg54_firmware:1.43`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-ampg:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-ampg_firmware:-`,
        fs:  `cpe:2.3:a:conky:conky:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-ampg_firmware:1.46`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-ampg_firmware:1.51`,
        fs:  `cpe:2.3:a:isc:bind:9.1.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-ampg_firmware:1.52`,
        fs:  `cpe:2.3:a:php:php:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-g:-`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.1.4:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g_firmware:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g_firmware:1.46`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g_firmware:1.47`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g_firmware:1.49`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:q35_sinit_51.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-g54s:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g54s_firmware:-`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g54s_firmware:1.20`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(13a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g54s_firmware:1.21`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g54s_firmware:1.23`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g54s_firmware:1.38`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g54s_firmware:1.40`,
        fs:  `cpe:2.3:a:skyarc:mailpack:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g54s_firmware:1.42`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-g54s_firmware:1.43`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-hp-ampg:-`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-ampg_firmware:-`,
        fs:  `cpe:2.3:h:siemens:scalance_w747-1rr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-ampg_firmware:1.32`,
        fs:  `cpe:2.3:a:typo3:typo3:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-ampg_firmware:1.43`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-hp-g:-`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g_firmware:-`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g_firmware:1.46`,
        fs:  `cpe:2.3:a:cisco:webns:5.20.0.06a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g_firmware:1.47`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g_firmware:1.49`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:whr-hp-g54:-`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g54_firmware:-`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1\(3\)sr4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g54_firmware:1.20`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g54_firmware:1.21`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.18:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g54_firmware:1.23`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g54_firmware:1.38`,
        fs:  `cpe:2.3:a:corel:coreldraw:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g54_firmware:1.40`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.44.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g54_firmware:1.42`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:whr-hp-g54_firmware:1.43`,
        fs:  `cpe:2.3:a:openafs:openafs:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wmr-300:-`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(3u\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wmr-300_firmware:1.02`,
        fs:  `cpe:2.3:a:rsa:envision:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wmr-300_firmware:1.03`,
        fs:  `cpe:2.3:h:cisco:as5350:12.2\(11t\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wmr-300_firmware:1.30`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wmr-300_firmware:1.60`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:wmr-300_firmware:1.70`,
        fs:  `cpe:2.3:a:location_module_project:location:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:wmr-300_firmware:1.90`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wmr-433:-`,
        fs:  `cpe:2.3:a:janetter:janetter:2.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:wmr-433_firmware:1.01`,
        fs:  `cpe:2.3:a:vmware:tools:3.1.2.10559:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wsr-1166dhp:-`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.0_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:wsr-1166dhp_firmware:1.01`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wsr-600dhp:-`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wsr-600dhp_firmware:1.60`,
        fs:  `cpe:2.3:a:samba:samba:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:buffalotech:wsr-600dhp_firmware:1.70`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wzr-ampg144nh:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-ampg144nh_firmware:-`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.4.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-ampg144nh_firmware:1.47`,
        fs:  `cpe:2.3:o:tesla:gateway_ecu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-ampg144nh_firmware:1.48`,
        fs:  `cpe:2.3:h:intel:d845bg_motherboard:p01-0012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-ampg144nh_firmware:1.48:beta`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-ampg144nh_firmware:1.49`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wzr-ampg300nh:-`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-ampg300nh_firmware:-`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-ampg300nh_firmware:1.48`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.1:patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-ampg300nh_firmware:1.50:beta`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wzr-g144n:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144n_firmware:-`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144n_firmware:1.45`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144n_firmware:1.46:beta`,
        fs:  `cpe:2.3:a:apple:bonjour:1.0.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144n_firmware:1.47`,
        fs:  `cpe:2.3:h:cisco:ips_4345_sensor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144n_firmware:1.47:beta`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144n_firmware:1.48`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wzr-g144nh:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144nh_firmware:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144nh_firmware:1.45`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:ru:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144nh_firmware:1.47`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.3.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144nh_firmware:1.47:beta`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr-g144nh_firmware:1.48`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:buffalotech:wzr2-g300n:-`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr2-g300n_firmware:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr2-g300n_firmware:1.48`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:11:sp3:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr2-g300n_firmware:1.50:beta`,
        fs:  `cpe:2.3:a:hp:scan:4.9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffalotech:wzr2-g300n_firmware:1.51`,
        fs:  `cpe:2.3:a:adobe:soundbooth_cs4_codecs:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:fujitsu:regza_phone_t-01d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:retail_xstore_point_of_service:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.0.0:beta_update1:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.9.2:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:plone:plone:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:siemens:comos:10.0.3.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:meetingplace:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:te2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:inria:ocaml:3.07:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.7-168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.443:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bufferapp:digg_digg:5.3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffercode:random_banner:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffercode:random_banner:1.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buffercode:random_banner:1.1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nuance:dragon_naturallyspeaking:9.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bugfree:bugfree:2.1.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p102:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bulbsecurity:smartphone_pentest_framework:0.1.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bulbsecurity:smartphone_pentest_framework:0.1.3`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger_service_for_exchange:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bulbsecurity:smartphone_pentest_framework:0.1.4`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bullguard:bdagent.sys:1.0.0.6`,
        fs:  `cpe:2.3:a:bad_behavior_project:bad_behavior:7.x-2.2215:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bullguard:internet_security:14.1.287`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bullguard:online_backup:14.1.287`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bullguard:premium_protection:14.1.287`,
        fs:  `cpe:2.3:h:ibm:system_x3300_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bump_project:bump:-::~~~android~~`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.0:05:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0`,
        fs:  `cpe:2.3:a:microsoft:system.net.websockets.client:4.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:beta.1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:beta.10`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:beta.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:beta.7`,
        fs:  `cpe:2.3:a:alexis_wilke:protected_node:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:beta.8`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.98.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:beta.9`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:rc.1`,
        fs:  `cpe:2.3:h:hospira:lifecare_pca5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:rc.2`,
        fs:  `cpe:2.3:a:ninjaforms:ninja_forms:2.8.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:rc.3`,
        fs:  `cpe:2.3:o:huawei:mate_7_firmware:mt7-cl00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:rc.4`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:rc.5`,
        fs:  `cpe:2.3:a:apache:openoffice:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.0:rc.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.1`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.2`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.4`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.5`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.6`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.7`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.8`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.9`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.10`,
        fs:  `cpe:2.3:h:juniper:srx650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.11`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.12`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-26c-si_ls-s3100-26c-si-ac-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.13`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.14`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1054:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.15`,
        fs:  `cpe:2.3:a:apache:batik:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.16`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.17`,
        fs:  `cpe:2.3:a:mumble:mumble:1.2.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.18`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.19:rc`,
        fs:  `cpe:2.3:a:dublabs:yulman_stadium:1.4.25:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.20`,
        fs:  `cpe:2.3:a:intervideo:windvd:7.0.27.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.20:rc`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.21`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.0.21:rc`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a6\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.1`,
        fs:  `cpe:2.3:o:cisco:mgx_8250:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.10`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.2`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.3`,
        fs:  `cpe:2.3:a:digium:asterisk:10.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.4`,
        fs:  `cpe:2.3:a:trioniclabs:sentinel:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.5`,
        fs:  `cpe:2.3:a:drupal:drupal:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.6`,
        fs:  `cpe:2.3:a:google:chrome:6.0.437.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.7`,
        fs:  `cpe:2.3:a:sun:java_system_access_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.8`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.25:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:pre.9`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:rc`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.5:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:rc.2`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:rc.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:rc.4`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:rc.5`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:rc.6`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:rc.7`,
        fs:  `cpe:2.3:a:bea:weblogic_mobility_server:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1:rc.8`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.11:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1.1`,
        fs:  `cpe:2.3:a:suse:suse_linux_enterprise_software_development_kit:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1.3`,
        fs:  `cpe:2.3:h:cisco:ipvc-3520-gw-2v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1.4`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.1.5`,
        fs:  `cpe:2.3:a:adobe:captivate:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.0:pre`,
        fs:  `cpe:2.3:h:cisco:ons_15454_sonet_multiservice_provisioning_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.0:pre.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.0:rc`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.08.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.0:rc.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.1`,
        fs:  `cpe:2.3:o:asus:rt-ac66u_firmware:3.0.0.4.354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.2`,
        fs:  `cpe:2.3:a:sun:java_web_console:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.3`,
        fs:  `cpe:2.3:a:privatemsg_project:privatemsg:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.4`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.2.5`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0`,
        fs:  `cpe:2.3:a:divx:codec:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0:pre`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0:pre.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.350:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0:pre.3`,
        fs:  `cpe:2.3:a:perl:perl:5.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0:pre.4`,
        fs:  `cpe:2.3:a:docker:docker:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0:pre.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0:pre.6`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0:pre.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p170:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.0:pre.8`,
        fs:  `cpe:2.3:a:redhat:rsync:2.5.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.3.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.2`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p374:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.4`,
        fs:  `cpe:2.3:a:google:sketchup:7.1:maintenance_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.5`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.3.6`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.04.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.4.0:pre.1`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.7:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.4.0:rc.1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.5.0`,
        fs:  `cpe:2.3:h:avaya:sg208:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.5.0:rc.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.5.0:rc.2`,
        fs:  `cpe:2.3:h:sun:cobalt_raq_2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.5.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.5.2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.5.3`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.6.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.6.1`,
        fs:  `cpe:2.3:a:horde:imp:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.6.2`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.6.3`,
        fs:  `cpe:2.3:a:adobe:coldfusion:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.6.4`,
        fs:  `cpe:2.3:a:antti_alamki:prh_search:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.6.5`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.6.6`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.6.7`,
        fs:  `cpe:2.3:a:apache:roller:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.0`,
        fs:  `cpe:2.3:a:cisco:webex_meeting_center_for_firefox_or_chrome:8.5.1106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.1`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.351:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.3`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.4`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.5`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.6`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.7`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.8`,
        fs:  `cpe:2.3:a:zemanta:related_posts:2.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.9`,
        fs:  `cpe:2.3:a:fpinternet:texas_poker_unlimited_hold\&#39;em:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.11`,
        fs:  `cpe:2.3:a:hp:server_migration_pack_universal_edition:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.12`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.13`,
        fs:  `cpe:2.3:a:c97:cart_engine:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.14`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.7.15`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.0`,
        fs:  `cpe:2.3:h:cisco:4400_wireless_lan_controller:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.0:pre`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53_94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.0:rc`,
        fs:  `cpe:2.3:a:php-nuke:satel_lite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.1`,
        fs:  `cpe:2.3:a:facebook:arabic_troll_football:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.3`,
        fs:  `cpe:2.3:a:ibm:lotus_symphony:1.3.0.20090908.0900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.4`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.331:pre-alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.5`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.6`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.7`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.366:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.8`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.4.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.8.9`,
        fs:  `cpe:2.3:a:att:communication_manager:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.0`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.0.243.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.0:pre`,
        fs:  `cpe:2.3:a:tincan:phplist:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.0:pre.1`,
        fs:  `cpe:2.3:a:devsaran:professional_theme:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.0:rc`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.2`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.340:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.4`,
        fs:  `cpe:2.3:a:mediaplayercodecpack:media_player_codec_pack:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.5`,
        fs:  `cpe:2.3:a:libexpat:expat:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.6`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.7`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.8`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.9`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.9.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.0`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.5112:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.0:pre`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.0:pre.1`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.0:pre.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.0:rc`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.1`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.11.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.2`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_mobile:8.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.4`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.5`,
        fs:  `cpe:2.3:a:veritas:netbackup:5.0.0:mp5:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.10.6`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.11.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.11.0:pre.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.14a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.11.0:pre.2`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.11.1`,
        fs:  `cpe:2.3:a:tus-radis:tus_1947_radis:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.11.2`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.0:pre.1`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.0:pre.2`,
        fs:  `cpe:2.3:a:web2py:web2py:1.90.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.0:rc`,
        fs:  `cpe:2.3:a:etopuponline:etopuponline:3.4.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.0:rc.2`,
        fs:  `cpe:2.3:a:dotclear:dotclear:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.0:rc.3`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.0:rc.4`,
        fs:  `cpe:2.3:o:d-link:dir-605l_firmware:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.1`,
        fs:  `cpe:2.3:a:logitech:lws_youtube_plugin:13.20.1166.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.2`,
        fs:  `cpe:2.3:a:roxio:central_audio:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.3`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.5`,
        fs:  `cpe:2.3:a:projectforge:projectforge:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.12.6`,
        fs:  `cpe:2.3:a:dadabik:dadabik:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.0`,
        fs:  `cpe:2.3:a:microsoft:isa_server:2004:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.0:pre.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.0:rc.1`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:9.1.1-000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.0:rc.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.1`,
        fs:  `cpe:2.3:h:yokogawa:centum_vp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.2`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.3`,
        fs:  `cpe:2.3:a:corosync:corosync:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.4`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.5`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bundler:bundler:1.13.6`,
        fs:  `cpe:2.3:a:microsoft:services:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:burnsy:jbshop_plugin:-`,
        fs:  `cpe:2.3:a:filenice:filenice:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buronya:dil_bilgisi_kurallari:1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1277.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:business_explorer:7.20`,
        fs:  `cpe:2.3:a:pivotal_software:redis:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:business_intelligence:12.1.0.882`,
        fs:  `cpe:2.3:o:freebsd:freebsd:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:businessobjects_enterprise:65.10.0.1011`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise:-`,
        fs:  `cpe:2.3:a:apache:axis2:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise:8.5`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise:9`,
        fs:  `cpe:2.3:a:csounds:csound:5.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise:10`,
        fs:  `cpe:2.3:a:thycotic:secret_server:8.8.000004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_embedded:10.0.0.533`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_java_sdk:-`,
        fs:  `cpe:2.3:a:icinga:icinga:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_java_sdk:8.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_os_deployment:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_ras_for_unix:-`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_xi:-`,
        fs:  `cpe:2.3:a:intel:mwmi:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_xi:3.1`,
        fs:  `cpe:2.3:a:redhat:rhevm-reports:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_xi:3.1:fp1.8`,
        fs:  `cpe:2.3:a:apple:apple_tv:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_xi:11.5.8.8265:release_2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_enterprise_xi_client_tools:3.1`,
        fs:  `cpe:2.3:a:redhat:resteasy:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports:-`,
        fs:  `cpe:2.3:h:hp:sn6000_stackable_8gb_24-port_single_power_fibre_channel_switch:aw575b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports:7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)t7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports:8.5.0.2176`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2010.302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports:9`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports:10`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp3:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports:10.0.0.53327`,
        fs:  `cpe:2.3:a:oracle:application_server_discussion_forum_portlet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports:12.3.1.684`,
        fs:  `cpe:2.3:h:hp:3com_baseline_plus_switch:2900g-28hpwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_.net_runtime:10.0.0.0`,
        fs:  `cpe:2.3:a:exim:exim:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_.net_server:11.0.0.0`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_basic_runtime_for_visual_studio_2008:10.5.0.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.6:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_basic_runtime_for_visual_studio_2008:10.5.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:zarafa:zarafa:5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_basic_runtime_for_visual_studio_2008:10.5.2.0`,
        fs:  `cpe:2.3:a:redhat:certificate_system:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_client:7.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_for_.net_framework_2.0:10.2.0::~~~~x64~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.06.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_for_visual_studio_2010:13.0.2.469`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_runtime:1.4.0`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_runtime:12.0.0.840`,
        fs:  `cpe:2.3:a:topgames:top_games_script:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_runtime_engine_for_.net_framework_4:13.0.1.220`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_runtime_engine_for_.net_framework_4:13.0.1.220::~~~~x64~`,
        fs:  `cpe:2.3:a:acme:thttpd:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_server:-`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_server_xi:-`,
        fs:  `cpe:2.3:a:hawk_project:hawk:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_update_service:1.0.0.0`,
        fs:  `cpe:2.3:a:adobe:version_cue:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_viewer:12.2.208.1040`,
        fs:  `cpe:2.3:a:monotone:monotone:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_viewer:12.2.209.1094`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_viewer:12.2.211.1241`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-755_firmware:t100sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_xi:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_xi:11.0.0.128227`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_xi:11.5.3.41727`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_xi:11.5.8.82627`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_xi:r2`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.2.11:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:crystal_reports_xi_.net_server:11.5.0.0`,
        fs:  `cpe:2.3:o:advantech:eki-122x_series_firmware:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:data_insight:12.1.0.0`,
        fs:  `cpe:2.3:a:debian:netkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:data_services:12.1.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:infoview:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:infoview:5.1.4`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:infoview:5.1.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:18.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:infoview:5.1.6`,
        fs:  `cpe:2.3:a:inclind:custom_pub:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:infoview:5.1.7`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:infoview:5.1.8`,
        fs:  `cpe:2.3:a:symantec:liveupdate:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:lifecycle_manager:12.1.0.0`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.6.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:report_application_server:-`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:report_application_server:11.0.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool_webtop:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:webintelligence:-`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:webintelligence:2.7`,
        fs:  `cpe:2.3:a:mahara:mahara:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:webintelligence:2.7.1`,
        fs:  `cpe:2.3:a:csounds:csound:5.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:webintelligence:2.7.2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:webintelligence:2.7.3`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:webintelligence:2.7.4`,
        fs:  `cpe:2.3:a:questionmark:questionmark_secure_browser:5.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:webintelligence:6.5`,
        fs:  `cpe:2.3:a:cisco:evolved_programmable_network_manager:1.2.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:xcelsius:12.0.1.0`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.4:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:businessobjects:xcelsius:12.3.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.38`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.39`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.40`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.4b.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.41`,
        fs:  `cpe:2.3:a:madipass:madipass_martinique:1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.42`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.43`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.43:pre`,
        fs:  `cpe:2.3:a:mobile_face_project:mobile_face:0.74.13432.91159:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.45`,
        fs:  `cpe:2.3:a:rpm:rpm:4.9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.46`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.1.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.47`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.48`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.49`,
        fs:  `cpe:2.3:a:apache:geode:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.50`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.4.0-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.51`,
        fs:  `cpe:2.3:a:wave:document_manager_lite:6.9.0.159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.52`,
        fs:  `cpe:2.3:a:google:earth:6.1.0.5001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.60.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.60.1`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.60.2`,
        fs:  `cpe:2.3:o:hp:700_series_firmware:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.60.3`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.60.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:0.60.5`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.00`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1036.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre10`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.33:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-24p-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre3`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0076:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre4`,
        fs:  `cpe:2.3:h:hp:officejet_pro_8500:cb862a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre5`,
        fs:  `cpe:2.3:a:telligent:evolution:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre6`,
        fs:  `cpe:2.3:o:y-cam:ycb004_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre7`,
        fs:  `cpe:2.3:a:oracle:application_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre8`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:pre9`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.101:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:rc1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:rc2`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.0.0:rc3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.01`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.1.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.1.0:pre1`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.1.1`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.1.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.27.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.1.3`,
        fs:  `cpe:2.3:a:zabbix:zabbix:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.2.0`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.2.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase_lt:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.2.2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.2.2.1`,
        fs:  `cpe:2.3:a:intel:mmhouse:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.3.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.3.1`,
        fs:  `cpe:2.3:a:boost:boost:1.59.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.3.2`,
        fs:  `cpe:2.3:h:edimax:br-6104k:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.4.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.4.1`,
        fs:  `cpe:2.3:a:x:libxt:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.4.2`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.5.0`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.5.1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.5.2`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.6.0`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.4.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.6.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.6.2`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.7.0`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.15-25.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.7.1`,
        fs:  `cpe:2.3:a:hp:ibrix:6.1.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.7.2`,
        fs:  `cpe:2.3:a:microsoft:security_compliance_manager:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.7.3`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.7.4`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.7.5`,
        fs:  `cpe:2.3:h:dell:powervault_ml6010:5u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.8.0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.8.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/h:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.8.2`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.8.3`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.9.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.9.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.21.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.9.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.10.0`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.0.471780:*:*:*:solaris:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.10.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.10.2`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.10.3`,
        fs:  `cpe:2.3:a:redhat:openshift:2.0.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.10.4`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.11.0`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_monitoring_center_for_security:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.11.1`,
        fs:  `cpe:2.3:o:cisco:catos:6.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.11.2`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.11.3`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.12.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.12.1`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.12.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.12.3`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.12.4`,
        fs:  `cpe:2.3:a:softbb:softbb:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.13.0`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.13.1`,
        fs:  `cpe:2.3:a:vmware:capacityiq:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.13.2`,
        fs:  `cpe:2.3:a:inria:ocaml:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.13.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.13.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.14.0`,
        fs:  `cpe:2.3:h:cisco:epc2203:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.14.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.14.2`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.14.3`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.14.4`,
        fs:  `cpe:2.3:a:hp:hp-ux_containers:a.03.00.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.15.0`,
        fs:  `cpe:2.3:a:altiris:express_deployment_datastore:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.15.1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.15.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.15.3`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.9:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.16.0`,
        fs:  `cpe:2.3:a:otrs:otrs:1.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.16.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.16.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.17.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.17.1`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-11-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.17.2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.17.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.17.4`,
        fs:  `cpe:2.3:a:cisco:mediasense:9.0\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.18.0`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.18.1`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:cbr:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.18.2`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.1.1:*:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.18.3`,
        fs:  `cpe:2.3:a:apache:roller:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.18.4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.72.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.18.5`,
        fs:  `cpe:2.3:o:rockwellautomation:compactlogix_5830_firmware:v28.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.19.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.19.1`,
        fs:  `cpe:2.3:h:cisco:4400_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.19.2`,
        fs:  `cpe:2.3:a:buffercode:random_banner:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.19.3`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.19.4`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.46:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.20.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:4.0.5c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.20.1`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.20.2`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.21.0`,
        fs:  `cpe:2.3:a:apple:itunes:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.21.1`,
        fs:  `cpe:2.3:a:hp:operations_integration_adapter_policy_activation:9.0.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.22.0`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.5.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.22.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.23.0`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.23.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.23.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.24.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.24.1`,
        fs:  `cpe:2.3:a:ains:foiaxpress_document_delivery_service:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.24.2`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.25.0`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:4.01:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.25.1`,
        fs:  `cpe:2.3:a:vips:vips:7.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.26.0`,
        fs:  `cpe:2.3:a:lxml:lxml:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.26.1`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.1\(1\)e2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.26.2`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.27.0`,
        fs:  `cpe:2.3:a:docker:docker:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.27.1`,
        fs:  `cpe:2.3:a:vips:vips:7.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:busybox:busybox:1.27.2`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buycoins:buy_coins:0.62.13364.24150::~~~android~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buydot:funny_%26_interesting_things:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:intel:proset_wireless:14.0.2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:buzztouch:emt-paramedic_lite:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:f5:tmos:9.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:byfes:ileri_gazetesi_-_yozgat:1::~~~android~~`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bylight:20%2f20:2.2`,
        fs:  `cpe:2.3:a:novell:internet_messaging_system:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:byond:byond:3.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bytemark:symbiosis:1321`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bytemark:symbiosis:1322`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bzip:bzip2:1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:7.0.510.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bzip:bzip2:1.0.4`,
        fs:  `cpe:2.3:a:microsoft:iis:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bzip:bzip2:1.0.5`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bzip:bzip2:1.0.6`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bzrtp_project:bzrtp:1.0.0`,
        fs:  `cpe:2.3:a:mediawiki:checkuser:2.3:-:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:bzrtp_project:bzrtp:1.0.2`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:bzrtp_project:bzrtp:1.0.3`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-3.co.jp:webcalenderc3:0.31`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-3.co.jp:webcalenderc3:0.31:s2`,
        fs:  `cpe:2.3:a:gnu:automake:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-3.co.jp:webcalenderc3:0.32`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.399:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-3.co.jp:webcalenderc3:0.32:s2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.2.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.0.0`,
        fs:  `cpe:2.3:a:microsoft:office:xp:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.1.0`,
        fs:  `cpe:2.3:a:cisco:secure_intrusion_detection_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.2.0`,
        fs:  `cpe:2.3:a:privatemsg_project:privatemsg:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.2.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.3.0`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.3.1`,
        fs:  `cpe:2.3:a:logitech:lws_webcam_software:13.20.1168.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.3.2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.4.0`,
        fs:  `cpe:2.3:o:xen:xen:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.5.0`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.5.1`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.10.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.5.2`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.5.3`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.6.0`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.7.0`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.7.1`,
        fs:  `cpe:2.3:a:keepass:keepass:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.7.2`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.7.3`,
        fs:  `cpe:2.3:h:sony:snc_dh180:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.7.4`,
        fs:  `cpe:2.3:a:rsa:keon_certificate_authority_manager:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.7.5`,
        fs:  `cpe:2.3:a:instachat:instachat_-instagram_messenger:1.6.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.8.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.9.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.98.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.9.1`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.10.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-ares_project:c-ares:1.11.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.424:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.01:b1`,
        fs:  `cpe:2.3:a:adobe:acrobat:17.011.30070:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.01:b2`,
        fs:  `cpe:2.3:a:chemssou_blink_project:chemssou_blink:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.01:b3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.01:b4`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.01:b6`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.02:b1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8\)aa1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.03:b1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.03:b2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-board_moyuku_project:c-board_moyuku:1.03:b3`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-icap_project:c-icap:0.2.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.1.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:c-icap_project:c-icap:0.2.2`,
        fs:  `cpe:2.3:o:vmware:esx:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-icap_project:c-icap:0.2.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-icap_project:c-icap:0.2.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30060:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-icap_project:c-icap:0.2.5`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c-icap_project:c-icap:0.2.6`,
        fs:  `cpe:2.3:a:broadcom:widcomm_bluetooth:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c%2fssolutions:risk%2b_for_microsoft_project:2.0.1.1`,
        fs:  `cpe:2.3:a:apache:struts:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c2ae:water_lateral_sizer:1.2::~~~android~~`,
        fs:  `cpe:2.3:h:buffalotech:bhr-4grv2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c2enterprise:c2_webresource:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c3-ilex:eoscada:11.0.19.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c4plans:k-tool:2.7.5`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c4plans:k-tool:3.31.12`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.02.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c4plans:sg_tool:3.1.21`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:c97:cart_engine:3.0`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:2e_web_option:r8.1.2`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.15.21:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:advantage_data_transport:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.922.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:advantage_data_transport:3.0`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:adviseit:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:adviseit:2.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:alert_notification_server:-`,
        fs:  `cpe:2.3:a:aimluck:aipo:4.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-spyware:2007`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-spyware:2008`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_66:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-spyware_for_the_enterprise:8.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.0.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-spyware_for_the_enterprise:r8`,
        fs:  `cpe:2.3:a:tibco:slingshot:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus:2007:8`,
        fs:  `cpe:2.3:a:digium:asterisk:14.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus:2008`,
        fs:  `cpe:2.3:a:apache:openoffice.org:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus_for_the_enterprise:-`,
        fs:  `cpe:2.3:a:adobe:illustrator:16.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus_for_the_enterprise:7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus_for_the_enterprise:7.1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus_for_the_enterprise:8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus_for_the_enterprise:8.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus_for_the_enterprise:r8`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.0.1:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti-virus_sdk:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:anti_virus_sdk:-`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:antispyware_for_the_enterprise:-`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:antispyware_for_the_enterprise:8`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:antispyware_for_the_enterprise:8.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:antispyware_for_the_enterprise:8.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:antivirus_gateway:7.1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:antivirus_sdk:-`,
        fs:  `cpe:2.3:a:samba:samba:4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:api_gateway:7.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.07:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:api_gateway:8.0`,
        fs:  `cpe:2.3:a:brion_vibber:centralauth_extension:-:-:-:*:-:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:api_gateway:8.1`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:api_gateway:8.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)yq1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:api_gateway:8.3`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.6:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:api_gateway:8.4`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:application_configuration_manager_agent:12.0.1.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:application_configuration_manager_agent:12.0.19.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:application_configuration_manager_agent:12.0.19.110`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(3a\)su1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:6.5`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:6.61`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:6.61:sp2a`,
        fs:  `cpe:2.3:a:ticketone:ticketone.it:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r12.0`,
        fs:  `cpe:2.3:a:gtopala:siw:1.68.626:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r12.0:sp1`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r12.0:sp2`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r12.5`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r12.5:sp1`,
        fs:  `cpe:2.3:a:hp:webinspect:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r12.5:sp2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r15.0`,
        fs:  `cpe:2.3:a:apache:libcloud:0.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r15.0:sp1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.39:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r16.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup:r16.0:sp1`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup_2000:-`,
        fs:  `cpe:2.3:a:openstack:neutron:juno-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup_agent_for_open_files_for_windows:12.0.0.0`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_backup_client_agent_for_windows:12.0.0.0`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_client_agent:-::windows`,
        fs:  `cpe:2.3:a:spigot:pdfforge_toolbar:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:arcserve_client_agent:_nil_:_nil_:windows`,
        fs:  `cpe:2.3:o:suse:suse_linux:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:asset_management_performance_liteagent:11.2.7277`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:-`,
        fs:  `cpe:2.3:o:siemens:simatic_s7_cpu_1200_firmware:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:-::macintosh`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:-::netware`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7985g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:-::oracle`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:-::solaris`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:-::tru64`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:-::windows`,
        fs:  `cpe:2.3:o:trustix:secure_linux:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:9.01`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:10.5`,
        fs:  `cpe:2.3:h:cisco:spa942_4-line_ip_phone_with_2-port_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:11`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:11.1`,
        fs:  `cpe:2.3:a:abb:robotstudio:5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:11.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.541:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:11.5:sp1`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup:11.5:sp2`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:10.00.tc3tl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_agent_exchange:-`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_agent_sap:-`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_agent_sql:-`,
        fs:  `cpe:2.3:a:samba:samba:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_aix:-`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_for_windows:-`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.11:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_hp:-`,
        fs:  `cpe:2.3:a:oracle:identity_federation:11.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_laptops_desktops:-`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_laptops_desktops:4.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_laptops_desktops:11.0`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_laptops_desktops:11.1`,
        fs:  `cpe:2.3:a:sybase:m-business_anywhere:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_laptops_desktops:11.1:sp1`,
        fs:  `cpe:2.3:a:plotsoft:pdfill_pdf_editor:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_laptops_desktops:11.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_server:-`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_backup_server:11.5`,
        fs:  `cpe:2.3:a:apache:solr:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_arcserve_client:-`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise:-`,
        fs:  `cpe:2.3:a:twilio_project:twilio:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:-`,
        fs:  `cpe:2.3:a:exim:exim:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:-::aix`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:-::hpux`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:-::mainframe_linux`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:-::solaris`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:-::tru54`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:-::windows`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:10.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup:10.5`,
        fs:  `cpe:2.3:a:adobe:bridge_cs5:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup_agent:-::oracle`,
        fs:  `cpe:2.3:a:ca:application_configuration_manager_agent:12.0.19.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup_agent:-::sap`,
        fs:  `cpe:2.3:a:altiris:network_discovery:6.0.2120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_enterprise_backup_agent:-::sql`,
        fs:  `cpe:2.3:a:cognos:planning_client_framework:8.4.2058.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_hierarchical_storage_manager:-`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_hierarchical_storage_manager:11.5`,
        fs:  `cpe:2.3:a:redhat:rhel_cluster:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_mobile_backup:-`,
        fs:  `cpe:2.3:a:attachmate:infoconnect_enterprise_edition:8.00.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_mobile_backup:r4.0`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_portal:-`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_portal:11.1`,
        fs:  `cpe:2.3:a:radware:cache_server_directory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_process_automation_manager:-`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_process_automation_manager:11.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p202:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_san_manager:-`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_san_manager:1.1`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_san_manager:1.1:sp1`,
        fs:  `cpe:2.3:a:roxio:creator:10.1.207:*:*:*:business_edition_gold:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_san_manager:1.1:sp2`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.9:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_san_manager:11.1`,
        fs:  `cpe:2.3:a:adobe:air:17.0.0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_san_manager:11.5`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_storage_resource_manager:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_storage_resource_manager:6.3`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_storage_resource_manager:6.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_storage_resource_manager:11.1`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:11.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brightstor_storage_resource_manager:11.5`,
        fs:  `cpe:2.3:a:apache:activemq:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:brigthstor_arcserve_client_for_windows:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:business_intelligence:3.0.0.13`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:business_protection_suite:-`,
        fs:  `cpe:2.3:a:irssi:irssi:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:business_protection_suite:2.0`,
        fs:  `cpe:2.3:a:emc:documentum_xplore:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:business_protection_suite:r2`,
        fs:  `cpe:2.3:a:david_king:vino:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ccc_harvest:-`,
        fs:  `cpe:2.3:o:huawei:s2350ei_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ccc_harvest:5.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_aion:-`,
        fs:  `cpe:2.3:a:adobe:photoshop:18.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_aion:10.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_ecm:-`,
        fs:  `cpe:2.3:a:ca:license_software:1.62.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_ecm:3.5`,
        fs:  `cpe:2.3:a:isc:bind:9.9.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_eureka:7.0.11`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_olap:-`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf008:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_olap:5.1`,
        fs:  `cpe:2.3:a:ca:directory:12.0.4099:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_portal:-`,
        fs:  `cpe:2.3:h:brocade:silkworm_3250_fabric_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_portal:4.7`,
        fs:  `cpe:2.3:a:mikejolley:download_monitor:1.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_portal:4.71`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_predictive_analysis_server:-`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.05.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_predictive_analysis_server:2.0`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cleverpath_predictive_analysis_server:3.0`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a4:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:client_automation:12.8`,
        fs:  `cpe:2.3:a:nuance:pdf_reader:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:client_automation:12.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:client_automation:14.0`,
        fs:  `cpe:2.3:a:apache:openoffice:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cohesion_agent:4.5.0.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cohesion_agent:4.5.1.0`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:cohesion_server:4.5.1.0`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:-`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:1.0`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.52.020.2735:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:1.1`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.15m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:2.0`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:2.1`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:2.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.03:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:3.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:11`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:common_services:11.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:configuration_automation_agent:12.5.0.29`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:8.0:r3:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:configuration_automation_agent:12.5.8.1016`,
        fs:  `cpe:2.3:a:sun:jre:6.0.260:update26:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:ca:configuration_automation_grid_node:12.5.8.1016`,
        fs:  `cpe:2.3:a:sympa:sympa:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:configuration_automation_server:12.5.0.29`,
        fs:  `cpe:2.3:a:in-portal:in-portal:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:configuration_automation_server:12.5.8.1016`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:controlit:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:controlit:4.5`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:desktop_management_suite:-`,
        fs:  `cpe:2.3:a:david_king:vino:2.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:desktop_management_suite:11.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p154:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:desktop_management_suite:11.1`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.14:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:desktop_management_suite:11.2`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:desktop_protection_suite:-`,
        fs:  `cpe:2.3:a:intel:rapid_storage_technology:9.6.0.1014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:desktop_protection_suite:2.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:8.1`,
        fs:  `cpe:2.3:a:apache:subversion:0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:12.0.4099`,
        fs:  `cpe:2.3:h:cisco:c420_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:12.0.4574`,
        fs:  `cpe:2.3:h:rim:blackberry:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:r12:sp1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:compute_cluster:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:r12:sp2`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:r12:sp3`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7941g-ge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:r12:sp4`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:r12:sp5`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:r12:sp6`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:directory:r12:sp7`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_for_voice:4.0.3`,
        fs:  `cpe:2.3:a:umn:mapserver:4.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_livehealth:5.7`,
        fs:  `cpe:2.3:a:cybozu:cybozu_live:1.0.4:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_livehealth:6.0.0.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_livehealth:6.1.0.0`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:4.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_systemedge:4.1`,
        fs:  `cpe:2.3:a:ca:api_gateway:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_systemedge:4.2.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_systemedge:4.2.2`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_systemedge:4.2.3`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:ehealth_systemedge:4.2.5`,
        fs:  `cpe:2.3:a:openstack:horizon:folsom-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:embedded_entitlements_manager:8.4.218`,
        fs:  `cpe:2.3:a:luratech:lurawave_jp2_activex_control:2.1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:embedded_entitlements_manager:8.4.406`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:enterprise_common_services:8.2.9.92`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:enterprise_common_services:8.3.5`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:enterprise_log_manager:11.1.0`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:erwin_data_model_validator:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:erwin_data_modeler:7.1.1075`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.7.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:erwin_process_modeler:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:erwin_process_modeler:7.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:erwin_process_modeler:7.2`,
        fs:  `cpe:2.3:a:wellintech:kingview:6.5.30.2010.18018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_access_control:-`,
        fs:  `cpe:2.3:a:microsoft:zero_administration_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_access_control:4.1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_access_control:5.0`,
        fs:  `cpe:2.3:a:ibm:java:5.0.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:-`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:2.01`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:2.04`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(100\)m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:2.07`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:2.09`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:8.0`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:8.1`,
        fs:  `cpe:2.3:a:trendmicro:interscan_messaging_security_virtual_appliance:8.5.1.1516:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:8.1.1`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.60.501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_admin:8.1.2`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:-`,
        fs:  `cpe:2.3:a:python:python:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:6.0`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:7.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:7.0.1.4`,
        fs:  `cpe:2.3:a:joomla:session:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:7.1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:8`,
        fs:  `cpe:2.3:a:ca:license_software:1.8.0.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:8.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:8.1`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:8.2:beta`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus:31.6.6086`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_ee:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_ee:7.0`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_gateway:-`,
        fs:  `cpe:2.3:a:emc:controlcenter:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_gateway:7.0`,
        fs:  `cpe:2.3:a:sebastien_sauvage:webgobbler:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_gateway:7.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_iris_engine:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_sdk:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_webscan:-`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_client:5.0.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_webscan:1.1.0.1045`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_antivirus_webscan:1.1.0.1047`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_aries:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_aries:8.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_client:-`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_client:1.5:sp2`,
        fs:  `cpe:2.3:a:autodesk:autocad_electrical:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_client:1.5:sp3`,
        fs:  `cpe:2.3:a:phplist:phplist:2.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_client:8.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_datatools:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_datatools:1.5:sp2`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_datatools:1.5:sp3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_datatools:8.0`,
        fs:  `cpe:2.3:a:php:php:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_irecorder:-`,
        fs:  `cpe:2.3:h:hp:storageworks_nas_executor_e7000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_irecorder:1.5:sp2`,
        fs:  `cpe:2.3:a:compaq:survey_utility:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_irecorder:1.5:sp3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_irecorder:8.0`,
        fs:  `cpe:2.3:a:businessobjects:infoview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_policy_manager:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_policy_manager:1.5:sp2`,
        fs:  `cpe:2.3:a:aol:internet_software:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_policy_manager:1.5:sp3`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1\(3f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_audit_policy_manager:8.0`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_directory:-`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:6.0`,
        fs:  `cpe:2.3:o:brocade:fabric_os:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:6.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_server:04-00-\/a:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:6.2`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:6.3`,
        fs:  `cpe:2.3:a:nishishi:fumy_teachers_schedule_board:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.1.1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.3:a-beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.1.2`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:5.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.1.3`,
        fs:  `cpe:2.3:h:nortel:switched_firewall_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.1.4`,
        fs:  `cpe:2.3:a:apple:itunes:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.2`,
        fs:  `cpe:2.3:a:apache:tomee:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.2.1`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.3`,
        fs:  `cpe:2.3:a:symantec:livereg:2.0.6.1314:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.0.4`,
        fs:  `cpe:2.3:a:vmware:virtual_disk_development_kit:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:7.1`,
        fs:  `cpe:2.3:a:capasystems:performance_guard:6.2.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:r6.1`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp2025_printer:cb494a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_antivirus:r7`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:-`,
        fs:  `cpe:2.3:a:sybase:pylon_anywhere:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:1`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:1.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.1.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:2`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.2516.1900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:2.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:2.3`,
        fs:  `cpe:2.3:a:sendmail:sendmail:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:2.4`,
        fs:  `cpe:2.3:a:citrix:license_server_administration:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:2.4.4`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:3.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor:3.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor_le:2.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_ez_armor_le:3.0.0.14`,
        fs:  `cpe:2.3:a:microsoft:service_bus:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_iam_suite:12.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_iam_suite:12.0.1.114`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.335:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_iam_suite:12.0.7.441`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_identity_minder:-`,
        fs:  `cpe:2.3:a:openstack:horizon:2013.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_identity_minder:8.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_integrated_threat_management:-`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_integrated_threat_management:8.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_integrated_threat_management:8.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_internet_security_suite:-`,
        fs:  `cpe:2.3:a:ibm:websphere_caching_proxy_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_internet_security_suite:1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.800.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_internet_security_suite:2`,
        fs:  `cpe:2.3:a:ibm:sametime:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_intrusion_detection:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_intrusion_detection:1.4.1.13`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_intrusion_detection:1.4.5`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.406:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_intrusion_detection:1.5`,
        fs:  `cpe:2.3:a:symantec:backupexec_system_recovery:7.0.0.20351:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_intrusion_detection:2.0`,
        fs:  `cpe:2.3:a:paypal:payments_standard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_intrusion_detection:3.0`,
        fs:  `cpe:2.3:a:viewvc:viewvc:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_intrusion_detection:4.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_pestpatrol:-`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_pestpatrol:8.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_secure_content_manager:-`,
        fs:  `cpe:2.3:a:adobe:robohelp:9.0.0.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_secure_content_manager:1.0`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:16.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_secure_content_manager:1.1`,
        fs:  `cpe:2.3:a:crawlability:vbseo:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_secure_content_manager:8.0`,
        fs:  `cpe:2.3:a:hp:openview_reporter:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_security_command_center:-`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:01-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_security_command_center:1.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_security_command_center:8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_security_command_center:8:sp1:cr1`,
        fs:  `cpe:2.3:a:qnap:qsync:4.2.3.0915:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_security_command_center:8:sp1:cr2`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_security_suite:-`,
        fs:  `cpe:2.3:a:oracle:complex_maintenance_repair_and_overhaul:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_security_suite:1`,
        fs:  `cpe:2.3:a:mcafee:webshield_smtp:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_security_suite:2`,
        fs:  `cpe:2.3:a:nuance:paperport:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_siteminder:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_siteminder:5.5`,
        fs:  `cpe:2.3:a:emc:avamar:6.1:-:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_siteminder_documentation:12.0.105.635:sp1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2011.707.2315.39839:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_siteminder_policy_server:6.0.506.223:sp5`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_siteminder_policy_server:12.0.102.414:sp1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.8:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_siteminder_policy_server:12.0.105.635:sp1`,
        fs:  `cpe:2.3:h:apple:ipad_mini-:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_siteminder_user_context_gateway:1.3.0.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_siteminder_web_access_manager_administrative_ui:12.0.100.209`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:etrust_threat_management_console:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:host-based_intrusion_prevention_system:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:host-based_intrusion_prevention_system:8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:identity_manager:12.0.7.441`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:igateway:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.17:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:igateway:3.0`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:igateway:4.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:inoculan:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1661.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:inoculateit:-`,
        fs:  `cpe:2.3:a:jruby:jruby:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:inoculateit:4.53`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:inoculateit:6.0`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:inoculateit_agent_for_exchange:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:integrated_threat_management:-`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:integrated_threat_management:8.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:internet_security_suite:-`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:internet_security_suite:1.0`,
        fs:  `cpe:2.3:a:altiris:task_synchronization_agent:6.1.1030.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:internet_security_suite:2.0`,
        fs:  `cpe:2.3:a:microsoft:visio:2000:sr1:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:internet_security_suite:3.0`,
        fs:  `cpe:2.3:h:cisco:ie-4000-4tc4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:introscope:7.2.0.0`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:introscope_agent_for_.net_3.0:7.2.0.0`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:introscope_workstation:7.2.0.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:introscope_workstation:8.2.3.0`,
        fs:  `cpe:2.3:h:hp:0235a239:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:investigation_tool:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-2.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.813:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.041221`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050126`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050224`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050306`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.1.3:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050321`,
        fs:  `cpe:2.3:h:hp:jf231a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050322`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050325`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050401`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050413`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050414`,
        fs:  `cpe:2.3:o:dell:bios:a12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050518`,
        fs:  `cpe:2.3:a:mobiledeluxe:solitaire_deluxe:2.8.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050526`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050601`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:1.0.3086.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050613`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050615`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1024:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050623`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050624`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050717`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050718`,
        fs:  `cpe:2.3:a:justsystems:shuriken:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050803`,
        fs:  `cpe:2.3:a:cisco:security_device_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050826`,
        fs:  `cpe:2.3:h:cisco:ons_15310-ma_sdh_multiservice_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050905`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.050915`,
        fs:  `cpe:2.3:h:lucent:cajun_p334_network_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.051017`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.051124`,
        fs:  `cpe:2.3:a:apple:cups:1.1.20:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.0.060109`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.6.1.0`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:itechnology_igateway:4.6.1.8`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:-`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:0.1.0.15`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.5.3`,
        fs:  `cpe:2.3:a:powerpc-utils_project:powerpc-utils:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.8.0.110`,
        fs:  `cpe:2.3:a:projectforge:projectforge:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.8.0.114`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.9.1.105`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.46`,
        fs:  `cpe:2.3:a:serv-u:serv-u:4.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.50`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:1.2:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.52`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.53`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.54.0`,
        fs:  `cpe:2.3:a:cisco:webns:5.0_0.038s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.55.0`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.56.0`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.57.0`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.60.0`,
        fs:  `cpe:2.3:a:ibm:java:5.0.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.60.2`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.60.3`,
        fs:  `cpe:2.3:h:hp:color_laserjet_3000:q7534a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.61.0`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.61.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.61.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.61.8`,
        fs:  `cpe:2.3:a:vmware:springsource_spring_security:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.61.9`,
        fs:  `cpe:2.3:a:x:x.org_x11:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.62.7`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.62.10`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.62.11`,
        fs:  `cpe:2.3:a:bigfix:discovery_platform:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.62.12`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.62.14`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.62.15`,
        fs:  `cpe:2.3:a:phpnuke:myheadlines:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.62.16`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.63.0`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.63.02.03`,
        fs:  `cpe:2.3:a:apache:commons-compress:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.63.03`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.70.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.70.1.101`,
        fs:  `cpe:2.3:a:microsoft:active_directory_federation_services:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.80`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0a5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.80.01`,
        fs:  `cpe:2.3:a:horde:groupware:5.0.0:rc1:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.90.0`,
        fs:  `cpe:2.3:a:bestpractical:rtfm:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.90.01`,
        fs:  `cpe:2.3:a:gnu:libtasn1:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.90.02`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:license_software:1.90.03`,
        fs:  `cpe:2.3:h:cisco:virtualization_experience_client_6215:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:message_queuing:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.05.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:message_queuing:1.05`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.288:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:message_queuing:1.07_build_220_13`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:message_queuing:1.11_build_29_13`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:-`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.05`,
        fs:  `cpe:2.3:o:suse:suse_linux:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.5`,
        fs:  `cpe:2.3:a:wb-i:contents-mall:14.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.7`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1298.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.210.0`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.0`,
        fs:  `cpe:2.3:a:livezilla:livezilla:4.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.3`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.4`,
        fs:  `cpe:2.3:a:redhat:linux_powertools:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.5`,
        fs:  `cpe:2.3:a:gnome:glib:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.6`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.7`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.8`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.9`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update3:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.10`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:4.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.11`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.13`,
        fs:  `cpe:2.3:a:siemens:simatic_logon:1.5:sp3_update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.14`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.07.220.15`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11`,
        fs:  `cpe:2.3:a:closeprotectionworld:cpworld_close_protection_world:3.4.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.18.0`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.19.0`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.21`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.22`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sg.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.23`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.24`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.25`,
        fs:  `cpe:2.3:a:atlassian:jira:3.1.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.26`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.26.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.0-15:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.26.2`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.26.6`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.26.7`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.26.8`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.26.9`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.26.10`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.27.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.27.1`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.27.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.27.3`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.28.0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.2`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.3`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.5`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.6`,
        fs:  `cpe:2.3:a:adobe:anchor_service_cs3:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.7`,
        fs:  `cpe:2.3:o:hp:hp_h-series_fibre_channel_switch_firmware:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.8`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.2.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.9`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.13`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sy2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.14`,
        fs:  `cpe:2.3:a:sap:customer_relationship_management:7.02:ehp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.15`,
        fs:  `cpe:2.3:a:php:php:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.16`,
        fs:  `cpe:2.3:a:dotcms:dotcms:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.17`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1039.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.18`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:messaging:1.11.29.19`,
        fs:  `cpe:2.3:a:x:libxtst:1.0.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:mlink:-`,
        fs:  `cpe:2.3:a:openstack:keystone:2014.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:mlink:6.5`,
        fs:  `cpe:2.3:a:microsoft:directx_sdk:february_2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:netviz_professional:4.0`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:netviz_viewer:6.5`,
        fs:  `cpe:2.3:a:pcre:pcre:8.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:network_and_systems_management:r3.0`,
        fs:  `cpe:2.3:o:sgi:irix:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:network_and_systems_management:r3.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:network_and_systems_management:r11`,
        fs:  `cpe:2.3:a:runkeeper:runkeeper_-_gps_track_run_walk:4.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:network_and_systems_management:r11.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2008.225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:network_discovery_gateway:2.0.41.0`,
        fs:  `cpe:2.3:a:ipswitch:imail:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:network_discovery_gateway:2.5.1.117`,
        fs:  `cpe:2.3:a:sudaninet:sudaninet:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:output_management_web_viewer:11.0`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:output_management_web_viewer:11.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:release_automation:4.7.1`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:resource_initialization_manager:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:resource_initialization_manager:1.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:secure_content_manager:-`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:secure_content_manager:1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:secure_content_manager:8.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:secure_content_manager:8.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:server_protection_suite:-`,
        fs:  `cpe:2.3:a:forgerock:openam:9.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:server_protection_suite:2`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:server_protection_suite:r2`,
        fs:  `cpe:2.3:o:d-link:dsr-150_firmware:1.05b29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:service_desk:11.2`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:service_desk_manager:12.5`,
        fs:  `cpe:2.3:a:magzter:indian_management:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:service_desk_manager:12.6`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:service_desk_manager:12.7`,
        fs:  `cpe:2.3:a:david_king:vino:2.31.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:single_sign-on:r6.0`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a1:8.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:single_sign-on:r12.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11\)ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:single_sign-on:r12.0j`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:-:opsconsole:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:single_sign-on:r12.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:single_sign-on:r12.51`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:single_sign-on:r12.52`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:siteminder:12.0:sp1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.1.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:siteminder:12.0:sp2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:siteminder:12.0:sp3:cr01`,
        fs:  `cpe:2.3:a:apache:activemq:5.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:siteminder:12.5`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1027:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:siteminder:12.51`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:8.5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:siteminder_federation:12.0`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:spectrum:9.2`,
        fs:  `cpe:2.3:a:opentext:enterprise_library_enterprise_server_patches_for_els:10.1.0.269:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:spectrum:9.3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.4.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:systemedge:5.8.2`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.5_build_741:*:exchange:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:systemedge:5.9`,
        fs:  `cpe:2.3:a:novell:groupwise:2014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:systems_performance_for_infrastructure_managers:12.8`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.0.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:systems_performance_for_infrastructure_managers:12.9`,
        fs:  `cpe:2.3:a:innominate:mguard_pci:bd-111020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:systems_performance_liteagent:11.2.9273`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:threat_manager:-`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:threat_manager:8`,
        fs:  `cpe:2.3:a:ekahau:activator:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:total_defense:r12`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:total_defense:r12:se2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_application_performance_monitor:-`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_application_performance_monitor:3.0`,
        fs:  `cpe:2.3:a:emc:rsa_data_loss_prevention:9.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_application_performance_monitor:3.5`,
        fs:  `cpe:2.3:a:isc:bind:8.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_application_server_managment:-`,
        fs:  `cpe:2.3:a:oracle:jd_edwards_enterpriseone_tools:9.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_asset_management:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_asset_management:3.1`,
        fs:  `cpe:2.3:a:plone:plone:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_asset_management:3.2`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_asset_management:3.2:sp1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_asset_management:3.2:sp2`,
        fs:  `cpe:2.3:a:thecleanerapp:the_cleaner_-_speed_up_\&amp;_clean:1.4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_asset_management:4.0`,
        fs:  `cpe:2.3:a:apple:xcode:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_asset_portfolio_management:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_asset_portfolio_management:11.0`,
        fs:  `cpe:2.3:a:atutor:atutor:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_autosys_jm:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_autosys_jm:11.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_browser_interface:-`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_data_transport_option:-`,
        fs:  `cpe:2.3:a:apport_project:apport:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_data_transport_option:2.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_dsm_agent_%2b_asset_management_plugin:11.2.4000.12`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.8f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_dsm_agent_%2b_basic_inventory_plugin:11.2.4000.6`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.21:-:*:*:*:sunos:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_dsm_agent_%2b_remote_control_plugin:11.2.4000.6`,
        fs:  `cpe:2.3:a:androidsu:chainsdd_superuser:3.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_dsm_agent_%2b_software_delivery_plugin:11.2.4000.6`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:a4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_enterprise_job_manager:-`,
        fs:  `cpe:2.3:a:hp:network_node_manager:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_exchange_management_console:-`,
        fs:  `cpe:2.3:a:pgp:certificate_server:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_jasmine:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_jasmine:3.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_management:-`,
        fs:  `cpe:2.3:h:netgear:wndr4700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_management_lotus_note_domino:-`,
        fs:  `cpe:2.3:a:directadmin:directadmin:1.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_management_microsoft_exchange:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_management_portal:-`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_management_portal:2.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_management_portal:3.1`,
        fs:  `cpe:2.3:a:hp:hppsendfax:0.105.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_management_web_servers:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.269:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_management_websphere_mq:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_mq_management:-`,
        fs:  `cpe:2.3:a:owncloud:owncloud:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_network_and_systems_management:-`,
        fs:  `cpe:2.3:o:asus:rt-n66u_firmware:3.0.0.4.370:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_network_and_systems_management:3.0`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_network_and_systems_management:3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_network_and_systems_management:11`,
        fs:  `cpe:2.3:a:basercms:basercms:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_network_and_systems_management:11.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_nsm:-`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.00:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_nsm:3.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_nsm:3.1`,
        fs:  `cpe:2.3:a:google:v8:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_nsm_wireless_network_management_option:-`,
        fs:  `cpe:2.3:a:rack_project:rack:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_nsm_wireless_network_management_option:3.0`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_performance_management:2.4:sp3:openvms`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_performance_management_for_openvms:-`,
        fs:  `cpe:2.3:a:webmin:usermin:1.520:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control:-`,
        fs:  `cpe:2.3:a:crawlability:vbseo:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control:5.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control:6.0`,
        fs:  `cpe:2.3:a:hp:sitescope:11.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control:6.0:sp1`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control_host:-`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control_host:6.0`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control_option:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.5:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control_option:5.0`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_remote_control_option:5.1`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_delivery:-`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_delivery:11.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_desk:-`,
        fs:  `cpe:2.3:a:axis:media_control_activex_control:6.2.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_desk:11.0`,
        fs:  `cpe:2.3:h:cisco:ie-4000-4gs8gp4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_desk_knowledge_tools:-`,
        fs:  `cpe:2.3:a:stdutility:stdu_explorer:1.0.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_desk_knowledge_tools:11.0`,
        fs:  `cpe:2.3:a:kbs:weblygo:3.093:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_fulfillment:-`,
        fs:  `cpe:2.3:a:blackbox:inkra_center_point:2.1.5-b011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_fulfillment:2.2`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_level_management:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_level_management:3.0`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_level_management:3.0.1`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_level_management:3.0.2`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_level_management:3.5`,
        fs:  `cpe:2.3:a:nokia:7610:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_metric_analysis:-`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_service_metric_analysis:11.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_serviceplus_service_desk:-`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_serviceplus_service_desk:6.0`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.16:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_software_delivery:-`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_software_delivery:3.0`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_software_delivery:3.1`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_software_delivery:3.1:sp1`,
        fs:  `cpe:2.3:a:skyarts:neofiler:5.4.3:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_software_delivery:3.1:sp2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_software_delivery:4.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_tng:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1a\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_tng:2.1`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_tng:2.2`,
        fs:  `cpe:2.3:a:isc:bind:9.4.2:p2_w1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_tng:2.4`,
        fs:  `cpe:2.3:o:hp:hp-ux:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_tng:2.4.2`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_tng_jpn:-`,
        fs:  `cpe:2.3:a:xnview:xnview:1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_web_services_distributed_management:-`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:unicenter_web_services_distributed_management:11.0`,
        fs:  `cpe:2.3:a:vips:vips:7.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:universal_job_management_agent:11.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:vet_antivirus:-`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:vet_antivirus:10.66`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:web_agents:6.0`,
        fs:  `cpe:2.3:a:corel:wordperfect:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:workload_automation_ae:11.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:workload_automation_ae:11.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd319b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:workload_automation_ae:11.3.5`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca:workload_automation_ae:11.3.6`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.16.4:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ca_lottery_results_project:ca_lottery_results:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:0.1`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:0.2`,
        fs:  `cpe:2.3:a:php-nuke:advanced_classified_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:0.3`,
        fs:  `cpe:2.3:h:intel:mobile_intel_qm67_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:0.4`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:0.5`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:0.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:1.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.336:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:1.1`,
        fs:  `cpe:2.3:o:cisco:staros:17.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:1.2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.494.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabextract:cabextract:1.3`,
        fs:  `cpe:2.3:a:aimluck:aipo:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:2h252-25r:-`,
        fs:  `cpe:2.3:a:php:xhprof:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:2h252-25r:5.03.08`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:2h252-25r:5.04.09`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:2h252-25r:5.05.10`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:2h252-25r:5.07.12`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-05-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h202-24:-`,
        fs:  `cpe:2.3:a:corel:wordperfect:x3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h202-24:5.07.12`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h252-17:-`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper_live_streaming_integration:4.29.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h252-17:4.08.50`,
        fs:  `cpe:2.3:a:arellia:arellia_local_security_report_pack:6.2.1401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h252-17:5.05.10`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h252-17:5.07.12`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h302-48:-`,
        fs:  `cpe:2.3:a:google:chrome:16.0.877.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h302-48:4.08.50`,
        fs:  `cpe:2.3:h:cisco:pix_firewall_506e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h302-48:5.05.10`,
        fs:  `cpe:2.3:a:linear_case_project:linear_case:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h302-48:5.06.04`,
        fs:  `cpe:2.3:a:analog:soundmax:5.12.01.5246:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:6h302-48:5.07.12`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:micro_mmac:-`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:micro_mmac:1.10.14`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:smartswitch_router_8000_firmware:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cabletron:smartswitch_router_8000_firmware:2.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabletron:spectrum_enterprise_manager:-`,
        fs:  `cpe:2.3:a:koha:koha:3.16.00:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cabletron:spectrum_enterprise_manager:5.0`,
        fs:  `cpe:2.3:h:siemens:sinamics_g120p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cachefly:besthop:3.5.10`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8`,
        fs:  `cpe:2.3:a:hp:hppfonts:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.2`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.2a`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.3`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.3:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.3a`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.4`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.5`,
        fs:  `cpe:2.3:a:hp:insight_control_performance_management:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.5a`,
        fs:  `cpe:2.3:h:ibm:security_network_protection_xgs_5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6a`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6b`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6c`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6d`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6e`,
        fs:  `cpe:2.3:h:f5:big-ip_access_policy_manager:10.1.0:*:*:*:*:*:*:standalone`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6f`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.27:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6g`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)mc2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6h`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6i`,
        fs:  `cpe:2.3:a:apache:poi:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6j`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.6k`,
        fs:  `cpe:2.3:h:cooperindustries:smp_16_gateway_\(data_concentrator\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7a`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7b`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sy8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7c`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7d`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7e`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7f`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7g`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.29:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7h`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.7i`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.8`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.8a`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.8b`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.4:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.8c`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:5.2:2005q4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.8d`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.8f`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:0.8.8g`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)e12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:1.1.12`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:1.1.13`,
        fs:  `cpe:2.3:a:compaq:insight_management_desktop_web_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:cacti:1.1.17`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cacti:superlinks:1.4-2::~~~cacti~~`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cadpage:cadpage:1.7.44::~~~android~~`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cafuego:simple_document_management_system:1.1.4`,
        fs:  `cpe:2.3:o:lexmark:printer_firmware:yk.02.048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cafuego:simple_document_management_system:1.1.5`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cafuego:simple_document_management_system:1.1.6`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.0`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l18er-bb1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.2:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.12:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.4`,
        fs:  `cpe:2.3:a:spip:spip:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.5`,
        fs:  `cpe:2.3:a:werdswords:download_shortcode:0.2.2:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.7`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.25`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:1.71`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:2.01`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:3.0:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:2.03`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gateway_software:2.1\(1.79\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:2.03.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.1.1`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.1.2`,
        fs:  `cpe:2.3:a:henner_zeller:henplus:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.2`,
        fs:  `cpe:2.3:a:skype:skype:0.96.0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.2.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.2.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.2.3`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.3.0`,
        fs:  `cpe:2.3:a:mcafee:application_control:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.3.1`,
        fs:  `cpe:2.3:o:juniper:junos:13.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cagintranetworks:getsimple_cms:3.3.2:beta3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cairographics:cairo:-`,
        fs:  `cpe:2.3:a:synology:cloud_station:2.1-2577:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cairographics:cairo:1.10.2`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:p04-0018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cairographics:cairo:1.12.16`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.0.1.2708`,
        fs:  `cpe:2.3:a:sierrawireless:sprint_pcs_connection_manager:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.1.3.2967`,
        fs:  `cpe:2.3:a:openbsd:openssh:7.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.1.4.3104`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.1.5.3148`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.1.6.3264`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.1.7.3363`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.1.8.3544`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.0`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.87.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.752:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.4`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.5`,
        fs:  `cpe:2.3:a:ibm:integration_bus:10.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.6`,
        fs:  `cpe:2.3:o:redhat:linux:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.7`,
        fs:  `cpe:2.3:a:microsoft:excel:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.8`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.9`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.10`,
        fs:  `cpe:2.3:a:redhat:directory_server:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.2.11`,
        fs:  `cpe:2.3:a:citrix:receiver_hdx_flash_redirection:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3:dev`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.210:update21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.0:alpha`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.0:beta`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.0:rc1`,
        fs:  `cpe:2.3:a:smarty:smarty:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.0:rc2`,
        fs:  `cpe:2.3:a:adobe:after_effects:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.0:rc3`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.0:rc4`,
        fs:  `cpe:2.3:a:commvault:srm_exchange_agent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.5`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.6`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.5.711.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.7`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-850_firmware:t390sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.8`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.9`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.10`,
        fs:  `cpe:2.3:a:apple:safari:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.11`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.12`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.13`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.14`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p93:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:1.3.15`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.0`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.0:alpha`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.0:beta`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.0:dev`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.0:rc1`,
        fs:  `cpe:2.3:h:novatech:orionlx_dnp_slave:1.23.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.0:rc2`,
        fs:  `cpe:2.3:h:linksys:wip_330_wireless-g_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.0:rc3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.1`,
        fs:  `cpe:2.3:a:libav:libav:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.2`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.3`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.5`,
        fs:  `cpe:2.3:a:gajim:gajim:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.0.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.04.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.1.0`,
        fs:  `cpe:2.3:a:piwik:piwik:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.1.0:alpha`,
        fs:  `cpe:2.3:a:webmd:webmd:3.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.1.0:beta`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.1.0:rc`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.1.1`,
        fs:  `cpe:2.3:a:redmine:redmine:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.1.2`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.1.3`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.1.4`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r5_b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.2.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.2.0:rc1`,
        fs:  `cpe:2.3:a:ibs_mappro_project:ibs_mappro:0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.2.0:rc2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.2.0-beta`,
        fs:  `cpe:2.3:a:altiris:network_discovery_language_pack:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.2.1`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.2.2`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakefoundation:cakephp:2.2.3`,
        fs:  `cpe:2.3:h:hp:nonstop_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.0`,
        fs:  `cpe:2.3:a:epson:print_cd:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.0:alpha`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp1:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.0:beta`,
        fs:  `cpe:2.3:a:gigpress:gigpress:2.3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.0:dev`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.04.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.0:rc2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.0:rc3`,
        fs:  `cpe:2.3:a:autodesk:viz:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.1`,
        fs:  `cpe:2.3:a:apple:pages:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.2`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.3`,
        fs:  `cpe:2.3:a:apple:quicktime_streaming_server:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.4`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.5`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.0.6`,
        fs:  `cpe:2.3:a:oracle:industry_applications:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.0`,
        fs:  `cpe:2.3:h:f5:firepass_1200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.0:alpha`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.0:beta`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.0:rc1`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.2`,
        fs:  `cpe:2.3:a:7andi-fs.co:denny\&#39;s:2.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.3`,
        fs:  `cpe:2.3:a:adobe:coldfusion:11.0:update_10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.4`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.1.5`,
        fs:  `cpe:2.3:a:microsoft:small_business_srv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.0:beta`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.0:rc1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.0:rc2`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.1`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.2`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.0d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.3`,
        fs:  `cpe:2.3:a:uacinemas:ua_cinemas_-_mobile_ticketing:2.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.4`,
        fs:  `cpe:2.3:h:cisco:gss_4492r_global_site_selector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.5`,
        fs:  `cpe:2.3:a:mybb:mybb:1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.6`,
        fs:  `cpe:2.3:a:microsoft:project:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.7`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.8`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.2.9`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.6:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.0`,
        fs:  `cpe:2.3:o:redhat:linux:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.0:beta`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:313.00:-:*:*:esx:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.268.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.0:rc2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.1`,
        fs:  `cpe:2.3:a:google:earth:6.0.3.2197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.2`,
        fs:  `cpe:2.3:a:shoutcast:dnas:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.3`,
        fs:  `cpe:2.3:a:oracle:exchange:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.4`,
        fs:  `cpe:2.3:a:mautic:mautic:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.5`,
        fs:  `cpe:2.3:h:unisys:libra_8300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.7`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.8`,
        fs:  `cpe:2.3:a:mysql:mysql_tools:5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.9`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2040-ac-ovs-h3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.3.10`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_inventory_solution_for_windows:6.2.1047:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.0:beta`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.0:rc1`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.0:rc2`,
        fs:  `cpe:2.3:a:samba:samba:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.165:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.4`,
        fs:  `cpe:2.3:a:siemens:automation_license_manager:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.6`,
        fs:  `cpe:2.3:a:attachmate:infoconnect_options_pack:8.00.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.7`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.10:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.8`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.9`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.7.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.4.10`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.0`,
        fs:  `cpe:2.3:a:adobe:suite_shared_configuration_cs4:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.0:beta`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.0:rc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.0:rc2`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.1`,
        fs:  `cpe:2.3:a:adobe:golive_cs2:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.4`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.5`,
        fs:  `cpe:2.3:a:square:okhttp:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.6`,
        fs:  `cpe:2.3:a:lynx:lynx:2.8.8:dev.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.7`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.8`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.5.9`,
        fs:  `cpe:2.3:a:isc:bind:9.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.0:beta`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.0:rc1`,
        fs:  `cpe:2.3:a:symantec:vrtssfmh:3.0.358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.1`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.2`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.3`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r2.12_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.4`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.7`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.8`,
        fs:  `cpe:2.3:a:php:php:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.9`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.10`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.11`,
        fs:  `cpe:2.3:a:freeaudiovideosoft:free_iso_create_wizard:3.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.6.12`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.0`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.0:rc1`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.3`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.4`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.51:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.5`,
        fs:  `cpe:2.3:a:mochiweb_project:mochiweb:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.6`,
        fs:  `cpe:2.3:a:ilearnwith:fun_preschool_creativity_game:1.6.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.7`,
        fs:  `cpe:2.3:a:novatel:installvc90support:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.8`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.7.9`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:2.8.0:rc1`,
        fs:  `cpe:2.3:a:inria:ocaml:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:alpha1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:alpha2`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:beta1`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.30.020.1819:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:beta2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:beta3`,
        fs:  `cpe:2.3:h:smc:smc8024l2_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:dev1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.409.1:*:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:dev2`,
        fs:  `cpe:2.3:a:milesj:decoda:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:dev3`,
        fs:  `cpe:2.3:a:krisonav:krisonav:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:rc1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.0:rc2`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.1`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.2`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.3`,
        fs:  `cpe:2.3:a:oxil:simplified-content:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.4`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_expansion_module_7914:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.4.402.265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.6`,
        fs:  `cpe:2.3:a:gajim:gajim:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.411:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.8`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.55:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.9`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.10`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.11`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.12`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.13`,
        fs:  `cpe:2.3:a:jease:jease:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.14`,
        fs:  `cpe:2.3:a:x3cms:x3_cms:0.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.0.15`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.1.0`,
        fs:  `cpe:2.3:h:huawei:campus_s5700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.1.0:beta1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.1.0:beta2`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.1.0:rc1`,
        fs:  `cpe:2.3:o:huawei:s7712_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.1.1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.1.2`,
        fs:  `cpe:2.3:a:samba:samba:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.1.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakephp:cakephp:3.1.4`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cakewalk:cakewalk_pyro:5.0`,
        fs:  `cpe:2.3:a:mcafee:spamkiller:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caldera:caldera:9.10`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.2\(3.100\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caldera:caldera:9.20`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:3.0.0`,
        fs:  `cpe:2.3:o:f5:tmos:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:3.1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:3.2.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:3.3.0`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6ecc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:3.4.0`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.0.0`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.1.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.2.0`,
        fs:  `cpe:2.3:a:motorola:airdefense_personal_agent:3.4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.3.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.3.3`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.3.4`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.3.5`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.7:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.3.6`,
        fs:  `cpe:2.3:o:cisco:mgx_8230:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.3.7`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.4.0`,
        fs:  `cpe:2.3:a:pentalogix:viewmate:11.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.4.3`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.4.4`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a3:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.4.5`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1\(1f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.4.6`,
        fs:  `cpe:2.3:a:skyboardapps:penguin_run:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.5.0`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.5.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:ga:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.5.5`,
        fs:  `cpe:2.3:a:yurl_retwitt_project:yurl_retwitt:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.5.6`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.5.7`,
        fs:  `cpe:2.3:a:e107:e107:0.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.6.0`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.2.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.6.1`,
        fs:  `cpe:2.3:a:dell:sonicwall_global_management_system:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.6.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.6.3`,
        fs:  `cpe:2.3:a:zope:zope:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.6.5`,
        fs:  `cpe:2.3:a:vmware:horizon_view:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.6.6`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.6.7`,
        fs:  `cpe:2.3:a:apple:cups:1.1.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.7.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.20:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.7.0.6`,
        fs:  `cpe:2.3:a:curtis_galloway:exif:0.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.7.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.7.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.7.4`,
        fs:  `cpe:2.3:o:juniper:junos:14.1r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0:rc1`,
        fs:  `cpe:2.3:a:debian:mime-support:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0:rc2`,
        fs:  `cpe:2.3:a:adobe:photoshop:12.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0:rc3`,
        fs:  `cpe:2.3:a:newsignature:addressfield_tokens:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0:rc4`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0.3`,
        fs:  `cpe:2.3:a:ptc:isoview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0.4`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0.5`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:10.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0.6`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_manager:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.0.7`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:010:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.1`,
        fs:  `cpe:2.3:a:vmware:movie_decoder:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.8.2`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.9.0::~~~~~development_snapshot`,
        fs:  `cpe:2.3:a:anti-virus:virusblockada32:3.12.12.4:-:personal:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.9.0:rc1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.18:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.9.1::~~~~~development_snapshot`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.11.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:chicken:4.12.0`,
        fs:  `cpe:2.3:o:freebsd:freebsd:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:http-client:0.4.2`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:call-cc:http-client:0.9`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.7sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4:beta2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.8:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4:beta3`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4:beta4`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4:beta6`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4:beta7`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4:rc2`,
        fs:  `cpe:2.3:a:roxio:update_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4.1`,
        fs:  `cpe:2.3:a:stage_file_proxy_project:stage_file_proxy:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4.2`,
        fs:  `cpe:2.3:a:schneems:wicked:0.0.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:calligra:calligra:2.4.3`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:0.5`,
        fs:  `cpe:2.3:a:janetter:janetter:1.6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:0.6`,
        fs:  `cpe:2.3:h:lexmark:cx825dtfe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:0.7`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.6.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(21a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:0.9`,
        fs:  `cpe:2.3:h:cisco:888_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.20.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:1.1`,
        fs:  `cpe:2.3:a:oracle:javafx:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:1.2`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:1.3`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:1.4`,
        fs:  `cpe:2.3:o:apple:watchos:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:1.5`,
        fs:  `cpe:2.3:a:adobe:coldfusion:11.0:update_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:1.6`,
        fs:  `cpe:2.3:a:lsi:mystorage_gca:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:2.0`,
        fs:  `cpe:2.3:a:vmware:vcloud_director:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cambridge_enterprise:jbig-kit:2.1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:campaign_monitor_project:campaign_monitor:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:mcafee:agent:4.6.0.1694:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:campustv:campus_link_-_campus_tv_hkusu:2.2::~~~android~~`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:camtron:cmnc-200:-`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canadapps:central_east_lhin_news:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canal44:canal_44:1::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:candlepinproject:candlepin:0.4.5`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:candlepinproject:candlepin:0.4.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p120:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:candlepinproject:candlepin:0.4.27`,
        fs:  `cpe:2.3:a:spice_project:spice:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:candlepinproject:candlepin:0.5.5`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:candlepinproject:candlepin:0.6.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:candlepinproject:candlepin:0.7.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:candy_blast_project:candy_blast:1.1.001::~~~android~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:candycaneapps:fling_gold:1.1.3::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:canon:canoscan_8440f:-`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:canoscan_toolbox:1.0`,
        fs:  `cpe:2.3:a:imember360:imember360:3.9.003:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:canoscan_toolbox:2.0`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:canoscan_toolbox:3.0`,
        fs:  `cpe:2.3:h:y-cam:ycb002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:canoscan_toolbox:4.0`,
        fs:  `cpe:2.3:h:xerox:workcentre_255:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:canoscan_toolbox:4.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:canoscan_toolbox:4.9`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:canoscan_toolbox:4.9.3.2`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:canoscan_toolbox:5.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:captureperfect:3.0`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:captureperfect:3.0.2306.216`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:captureperfect:3.0.8209.309`,
        fs:  `cpe:2.3:h:tp-link:tl-wr841n_\(9.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:captureperfect:3.0.9009.710`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:dr-2020u_captureontouch:1.1.109.1119`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:7.0.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:dv_network_software:2.0.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:canon:eos_d60:-`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imageprograf_firmware_update_tool:3.40`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_2620:-`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_5000i:-`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_5020:-`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_6870:-`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_8500:-`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_9070:-`,
        fs:  `cpe:2.3:a:phm:phm_registry_editor:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_c3200:-`,
        fs:  `cpe:2.3:a:hp:loadrunner_results_translator:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_c3220:-`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:3.2_.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:imagerunner_c6800:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.21:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:mp_navigator:2.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:mp_navigator_ex:1.0`,
        fs:  `cpe:2.3:a:pyyaml:libyaml:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:mp_navigator_ex:2.0`,
        fs:  `cpe:2.3:a:atlassian:jira:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:mp_navigator_ex:2.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_1j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon:mp_navigator_ex:4.0`,
        fs:  `cpe:2.3:h:hp:jh060a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:canon:network_camera_server_vb100:-`,
        fs:  `cpe:2.3:a:apache:derby:10.10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:canon:network_camera_server_vb101:-`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:canon:network_camera_server_vb150:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:canon:powershot_s200:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canon-its:accessguardian:-`,
        fs:  `cpe:2.3:a:umn:mapserver:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:accountsservice:0.6.14`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:acpi-support:0.141`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.6.1p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:acpi-support:0.142`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:libpam-modules:0.9.7`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:libpam-modules:1.1.1`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:libpam-modules:1.1.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.b0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:libpam-modules:1.1.3`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:ltsp_display_manager:2.2.4`,
        fs:  `cpe:2.3:a:plone:plone:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:ltsp_display_manager:2.2.5`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:ltsp_display_manager:2.2.6`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:ltsp_display_manager:2.2.7`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0.8.6067:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:lxcfs:0.11`,
        fs:  `cpe:2.3:h:htc:hero:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:php5:5.3.2-1ubuntu4.16`,
        fs:  `cpe:2.3:a:huawei:campus_series_switch_software:v200r002sph005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:php5:5.3.2-1ubuntu4.17`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:php5:5.3.5-1ubuntu7.9`,
        fs:  `cpe:2.3:a:bea:jrockit:1.4.2:r24.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:php5:5.3.5-1ubuntu7.10`,
        fs:  `cpe:2.3:a:f5:big-ip:4.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:reportbug:6.5.0`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:software-properties:0.81.13.1`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_codec_3000_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:software-properties:0.81.13.3`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1518f-4_pn\/dp_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:telepathy-idle:0.1.10.1`,
        fs:  `cpe:2.3:a:combodo:itop:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:telepathy-idle:0.1.11.1`,
        fs:  `cpe:2.3:a:cisco:cloudcenter_orchestrator:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:telepathy-idle:0.1.11.2`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:telepathy-idle:0.1.12.1`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:10.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:telepathy-idle:0.1.14`,
        fs:  `cpe:2.3:a:freedomscientific:document_server:10.19.760.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:telepathy-idle:0.1.14.1`,
        fs:  `cpe:2.3:a:samba:samba:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:telepathy-idle:0.1.15`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_core:15.04`,
        fs:  `cpe:2.3:a:apache:roller:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:4.10`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:5.04`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:5.10`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:6.06`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:6.06::~~lts~~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:6.06:-:lts`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:02-00-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:6.10`,
        fs:  `cpe:2.3:o:google:android:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:7.04`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:2.5.2.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:7.10`,
        fs:  `cpe:2.3:h:linksys:befsx41:1.45.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:8.04::~~lts~~~`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:8.04:-:lts`,
        fs:  `cpe:2.3:o:opensuse:opensuse:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:8.10`,
        fs:  `cpe:2.3:a:sun:mysql_connector_c:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:9.04`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.468:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:9.10`,
        fs:  `cpe:2.3:a:microsoft:ie:5.01:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:10.04::~~lts~~~`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:10.04:-:lts`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:10.10`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:11.04`,
        fs:  `cpe:2.3:a:snilesh:content_slide:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:11.10`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:12.04::~~lts~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:12.04:-:lts`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:12.10`,
        fs:  `cpe:2.3:a:lester_chan:wp-downloadmanager:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:13.04`,
        fs:  `cpe:2.3:a:cherokee-project:cherokee:1.2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:13.10`,
        fs:  `cpe:2.3:a:emc:isilon_insightiq:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:14.04::~~lts~~~`,
        fs:  `cpe:2.3:a:qualys:qualysguardscap:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:14.04::lts`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:14.10`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:15.04`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:15.10`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:16.04::~~lts~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_linux:16.10`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canonical:ubuntu_touch:15.04`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.87.24`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p385:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.87.31.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.134.7`,
        fs:  `cpe:2.3:a:google:chrome:2.0.156.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.134.11.1`,
        fs:  `cpe:2.3:h:huawei:eudemon_usg9300:v100r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.142.19`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.142.23.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.150`,
        fs:  `cpe:2.3:a:bea:weblogic_server:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.150.5.1`,
        fs:  `cpe:2.3:a:luracast:restler:1.5.7:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.152.25`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:canonical:update-manager:1%3a0.152.25.5`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:canyon-tech:cn-wf512:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canyon-tech:cn-wf512_router_firmware:1.83`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:canyon-tech:cn-wf514:-`,
        fs:  `cpe:2.3:a:ca:application_configuration_manager_agent:12.0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:canyon-tech:cn-wf514_router_firmware:2.08`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:capasystems:performance_guard:6.0`,
        fs:  `cpe:2.3:a:attachmate:extra\!_for_windows_95\/nt:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:capasystems:performance_guard:6.1.16`,
        fs:  `cpe:2.3:a:wamba:wamba-meet_women_and_men:3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:capasystems:performance_guard:6.1.27`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:capasystems:performance_guard:6.1.29`,
        fs:  `cpe:2.3:a:estrongs:es_file_explorer:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:capasystems:performance_guard:6.2.20`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:capasystems:performance_guard:6.2.25`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:capasystems:performance_guard:6.2.102`,
        fs:  `cpe:2.3:a:apache:log4j:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:capnproto:capnproto:0.5.3`,
        fs:  `cpe:2.3:a:gnu:grep:2.5.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carahsoft:extras_for_the_jabber_xcp:5.4.0.14409`,
        fs:  `cpe:2.3:a:rsa:authentication_agent_for_windows:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carahsoft:jabber_outlook_add-in:1.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carahsoft:jabber_xcp:5.4.0.6098`,
        fs:  `cpe:2.3:a:nokia:qt_creator:0.9.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carahsoft:jabber_xcp:5.4.0.14409`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carbonblack:carbon_black:4.0.3`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carbonblack:carbon_black:4.1.0:-`,
        fs:  `cpe:2.3:a:apache:maven:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carbonblack:carbon_black:4.1.0:beta1`,
        fs:  `cpe:2.3:a:apple:quicktime:6.1.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carbonblack:carbon_black:4.1.0:beta2`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.1.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carbonite:online_backup_setup:3.7.3`,
        fs:  `cpe:2.3:a:vitamin_plugin_project:vitamin:1.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cardscan:cardscan:6.0.4`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cardscan:cardscan:8.0.5`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:1.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:carefusion:pyxis_supplystation:8.1`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carel:plantvisor_enhanced:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carel:plantvisorenhanced:-`,
        fs:  `cpe:2.3:a:icinga:icinga:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:carlosgavazzi:eos-box_photovoltaic_monitoring_system:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.577:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:carlosgavazzi:eos-box_photovoltaic_monitoring_system_firmware:1.0.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:carlosgavazzi:eos-box_photovoltaic_monitoring_system_firmware:1.0.0.1080_2.1.10`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.0:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:carrierenterprise:carrier_enterprise_hvac_assist:4::~~~android~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart-app:cart_app:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.0.7:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.6d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.0.8:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.0:alpha_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:webcrafted_project:webcrafted:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.1.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.1.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.1.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:26.0.0.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.1.4:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.1.5:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:huawei:5710hi_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.1.6:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20110124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.3.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.4.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:router_7500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.4.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.4.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.4.4:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.4.7:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:bridge:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.4.8:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.4.9:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:8.0.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:15.00.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.0.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:nexus_9272q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.0.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:codiad:codiad:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.1.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.1.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.1.8:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.1.14:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.612:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cart66:cart66_lite_plugin:1.5.1.15:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:9.40.uc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.00`,
        fs:  `cpe:2.3:h:hp:procurve_router:jc147b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.01`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.31-77.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.02`,
        fs:  `cpe:2.3:a:ca:configuration_automation_agent:12.5.8.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.03`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.04`,
        fs:  `cpe:2.3:a:hp:interconnect_component:3.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.05`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.9:gamma:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.06`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:9.1\(2.10000.28\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.07`,
        fs:  `cpe:2.3:a:ati:catalyst_driver:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.08`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.09`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.10`,
        fs:  `cpe:2.3:a:sharp:zaurus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.11`,
        fs:  `cpe:2.3:a:caucho:resin:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.12`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.23.616:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.13`,
        fs:  `cpe:2.3:h:dell:latitude_e6400_atg_xfr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.14`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.15`,
        fs:  `cpe:2.3:a:i-doit:i-doit:-:*:*:*:open:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.16`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.17`,
        fs:  `cpe:2.3:a:apache:tomcat:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.18`,
        fs:  `cpe:2.3:a:hp:sitescope_integrations:11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.19`,
        fs:  `cpe:2.3:a:apache:poi:3.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.20`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.21`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.3.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.21.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.22`,
        fs:  `cpe:2.3:a:microsoft:pocket_ie:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.23`,
        fs:  `cpe:2.3:a:sap:businessobjects_edge:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.23.1`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.23.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.24`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.25`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.02b11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.26`,
        fs:  `cpe:2.3:a:snort:snort:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.27`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.19-25.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.28`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.2:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.28.1`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.28.2`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.30`,
        fs:  `cpe:2.3:a:nancy_wichmann:taxonomy_list:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.31`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.31.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.01.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.31.2`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.31.3`,
        fs:  `cpe:2.3:a:gowkster:fabulas_infantiles:3.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.31.4`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.32`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.32.1`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.33`,
        fs:  `cpe:2.3:o:cray:unicos:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:mingle-forum:1.0.34`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:shortcode-redirect:1.0.00`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_reference_data_management_hub:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:shortcode-redirect:1.0.01`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cartpauj:shortcode-redirect:1.0.02`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:casinogame:video_poker_casino:1.0.5::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:castech:ezccid_smart_card_reader_setup_for_windows_2000_xp_2003:1.0.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:castech:ezusb_smart_card_reader_setup_for_windows_2000_xp_2003:1.0.0`,
        fs:  `cpe:2.3:h:xerox:docucolor_4lp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:castillobueno:ccmplayer:1.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)t15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:castlerock:snmpc:7.1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:castor_project:castor:1.3`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:castor_project:castor:1.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:castor_project:castor:1.3.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:castor_project:castor:1.3.3`,
        fs:  `cpe:2.3:a:tenon:itools:8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cat:quick_heal:11.00`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.0`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.5.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.3`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.4`,
        fs:  `cpe:2.3:a:biopdf:pdf_writer:7.1.0.1186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.5`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.6`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.7`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.8`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.9`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.7\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.10`,
        fs:  `cpe:2.3:o:oracle:linux:5:11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.11`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.12`,
        fs:  `cpe:2.3:a:google:chrome:9.0.584.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.13`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.489:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.14`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.04:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.15`,
        fs:  `cpe:2.3:o:juniper:vmx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.16`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.17`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.0`,
        fs:  `cpe:2.3:h:google:search_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.1`,
        fs:  `cpe:2.3:a:kde:koffice:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.3`,
        fs:  `cpe:2.3:a:apache:activemq:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.4`,
        fs:  `cpe:2.3:a:umn:mapserver:4.6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.6`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.7`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.8`,
        fs:  `cpe:2.3:a:google:chrome:5.0.378.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.9`,
        fs:  `cpe:2.3:a:cisco:webex_recorder_and_player:3.17.2109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalin_florian_radut:zeropoint:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:netfilter:ipset:6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catalyst:file_transfer:6.0.6030`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catapultsoftware:catapult_dnp3_i%2fo_driver:7.2.0.60`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7960:8.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catapultsoftware:catapult_dnp3_i%2fo_driver:7.20.56`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:catbot_project:catbot:0.4.2`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:r2:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:category_tokens_project:category_tokens:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:jre:6.0.300:update30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:category_tokens_project:category_tokens:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.0.1`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.0.2`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.0.4`,
        fs:  `cpe:2.3:a:microsoft:antigen:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.0.5`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.0`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:3.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.1`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.2`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.3`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec:13.0.2896:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.5`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.6`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.7`,
        fs:  `cpe:2.3:a:vmware:ovf_tool:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.8`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.9`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.10`,
        fs:  `cpe:2.3:a:divx:converter:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.11`,
        fs:  `cpe:2.3:a:clamav:clamav:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.12`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.13`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.14`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.15`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.8.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.16`,
        fs:  `cpe:2.3:a:vmware:fusion:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:2.1.snap`,
        fs:  `cpe:2.3:a:cisco:spark:2015-06_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.0`,
        fs:  `cpe:2.3:o:y-cam:ycb003_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.1:beta`,
        fs:  `cpe:2.3:o:d-link:dcs-942l_firmware:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.2:beta`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.3`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.964:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.4`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.5`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.6`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.7`,
        fs:  `cpe:2.3:h:cisco:nexus_93180yc-ex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.8`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.9`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.10`,
        fs:  `cpe:2.3:a:oracle:jdk:7.0:update_131:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.11`,
        fs:  `cpe:2.3:a:click_project:click:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.12`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1061.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.13`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_helpdesk_solution:6.0.1043:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.14`,
        fs:  `cpe:2.3:a:citrix:netscaler:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.16`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.uc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.17`,
        fs:  `cpe:2.3:a:debian:apt:0.8.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.18`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.19`,
        fs:  `cpe:2.3:h:supermicro:x8sit-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.0.20`,
        fs:  `cpe:2.3:o:cisco:virtualization_experience_client_6000_series_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.0`,
        fs:  `cpe:2.3:a:cisco:unified_application_environment_platform_services:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.1`,
        fs:  `cpe:2.3:a:intergraph:employee_id_generator:1.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.2`,
        fs:  `cpe:2.3:h:huawei:5700hi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.3`,
        fs:  `cpe:2.3:a:gnome:update-manager-core:0.150.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.4`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.5`,
        fs:  `cpe:2.3:o:huawei:p8_firmware:gra-cl100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.6`,
        fs:  `cpe:2.3:a:google:chrome:17.0.928.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.7`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.8`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.5:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.9`,
        fs:  `cpe:2.3:h:hp:laserjet_enterprise_p3015:ce526a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.10`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.11`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1.2.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:3.1.13`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.0`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.1`,
        fs:  `cpe:2.3:a:apple:webkit:125.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.2`,
        fs:  `cpe:2.3:o:cisco:ons_15454_system_software:9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.4`,
        fs:  `cpe:2.3:a:google:picasa:3.9.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.5`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2108c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.6`,
        fs:  `cpe:2.3:a:csc:ddoeserviceclient:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.7`,
        fs:  `cpe:2.3:h:xerox:workcentre:5635:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.8`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.9`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd_se:5.0.2214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.10`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.11`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.12`,
        fs:  `cpe:2.3:a:apple:safari:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.13`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.14`,
        fs:  `cpe:2.3:a:microsoft:project_multilingual_user_interface_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.15`,
        fs:  `cpe:2.3:a:fabien_coelho:mod_macro:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.16`,
        fs:  `cpe:2.3:a:sympa:sympa:3.0b.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.17`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.18`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.19`,
        fs:  `cpe:2.3:a:feeds_project:feeds:7.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.20`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.21`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.22`,
        fs:  `cpe:2.3:a:drupal:drupal:6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.23`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.24`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.25`,
        fs:  `cpe:2.3:a:impresspages:impresspages_cms:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.26`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-alpha3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.27`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.28`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.29`,
        fs:  `cpe:2.3:a:qemu:qemu:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.30`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.8:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.36::~~professional~~~`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.37::~~professional~~~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.38::~~professional~~~`,
        fs:  `cpe:2.3:a:emc:networker:7.5.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.39::~~professional~~~`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:caucho:resin:4.0.40::~~professional~~~`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-02-20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cazoodle:nutch:0.9`,
        fs:  `cpe:2.3:a:condusiv:diskeeper:9.0.532:*:*:*:server_standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cb_-_calciatori_brutti_project:cb_-_calciatori_brutti:1::~~~android~~`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cbi_referral_manager_project:cbi_referral_manager:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:babylon:babylon:8.1.0:r16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdnvote_project:cdnvote:0.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:baseline_validator:1.0.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:cdo_dal_components:1.6.1`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:cdo_dal_components:2.0.6`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:device_registration:1.5.0`,
        fs:  `cpe:2.3:a:tera_charts_plugin_project:tera-charts:0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl-picsadc:1.6.0`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_afsdb:1.6.1`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_aimt:1.6.2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0:feature_pack_5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_asset_update:1.6.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_common_components:1.6.2`,
        fs:  `cpe:2.3:a:forosocuellamos:forosocuellamos:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_common_web_service:1.1.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_common_workflow_components:1.6.1`,
        fs:  `cpe:2.3:a:ibm:spss_statistics:23.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_management_console:1.7`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_server_monitoring:1.7`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:5.2.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:edcl_tmo_incheck:1.7.1`,
        fs:  `cpe:2.3:o:google:android:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:pics:1.6.1`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:pics_dashboard:1.6.0`,
        fs:  `cpe:2.3:a:wetstonetech:gargoyle_investigator:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdotech:pod_distribution:1.6.0`,
        fs:  `cpe:2.3:o:yamaha:rt56v:4.07.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdrl:cdrl:2.0`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cds:cds_client:4.1`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:0.5.0`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.797:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.0.0`,
        fs:  `cpe:2.3:a:redhat:kernel_source:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.1.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.1.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.1.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.2.0`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.3.0`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.4.0`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.5.0`,
        fs:  `cpe:2.3:a:apple:itunes:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.5.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_serial_gateway:1.0.1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.5.2`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.5.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.6.0`,
        fs:  `cpe:2.3:a:krisonav:krisonav:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.7.0`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.0`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.1`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-2.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.4`,
        fs:  `cpe:2.3:a:ibm:powerkvm:2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.5`,
        fs:  `cpe:2.3:a:digia:qt:4.7.6:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.6`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.3.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.7`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.8`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.8.1`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsincdesign:simple_dropbox_upload_form:1.8.8.2`,
        fs:  `cpe:2.3:h:linksys:befw11s4:1.37.9b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cdsoft:cdsoft:0.2::~~~android~~`,
        fs:  `cpe:2.3:h:fujitsu:arrows_me_f-11d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cedrick_collomb:unlocker:1.9.1`,
        fs:  `cpe:2.3:a:otrs:otrs:0.5:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.14.0:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.3`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.4`,
        fs:  `cpe:2.3:a:equis:metastock:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.5`,
        fs:  `cpe:2.3:o:freebsd:freebsd:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.6`,
        fs:  `cpe:2.3:a:apache:wink:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.7`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.6.0:sr2:ja:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.2.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.3.1`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.4:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.3.2`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.3.3`,
        fs:  `cpe:2.3:a:jan_bednarik:cooluri:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.3.4`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.3:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.4.0`,
        fs:  `cpe:2.3:o:siemens:simatic_s7_cpu_1200_firmware:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.4.1`,
        fs:  `cpe:2.3:a:apple:webkit:312.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.4.2`,
        fs:  `cpe:2.3:a:apple:cups:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.4.3`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.4.4`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.6228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.4.5`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celeryproject:celery:2.4.6`,
        fs:  `cpe:2.3:a:digium:asterisk:12.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celframe:office_2008:-:-:standard`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:celluloidapp:celluloid:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:celsian:celsian_bridge_g450:-`,
        fs:  `cpe:2.3:o:cisco:ios:11.0\(20.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:centos:centos:-`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:centos:centos:4`,
        fs:  `cpe:2.3:a:location_module_project:location:6.x-3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:centos:centos:5`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:centos:centos:6`,
        fs:  `cpe:2.3:a:bestwebsoft:google_captcha:1.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:centos:centos:6.1`,
        fs:  `cpe:2.3:o:hp:hp-ux:7.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:centos:centos:6.2`,
        fs:  `cpe:2.3:a:pmail:mercury_mail_transport_system:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:centos:centos:6.3`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:centreon:centreon:2.5.4`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:centrify:centrify_deployment_manager:2.1.0.283`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:centrify:centrify_suite:2012`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:centrify:centrify_suite:2012.5`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ceph:ceph-deploy:1.5.22`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ceragon:fiberair_ip-10c:-`,
        fs:  `cpe:2.3:a:emc:rsa_security_analytics:10.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ceragon:fiberair_ip-10e:-`,
        fs:  `cpe:2.3:a:apache:camel:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ceragon:fiberair_ip-10g:-`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.0:-`,
        fs:  `cpe:2.3:a:autodesk:utility_design:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.01`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1044:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.1`,
        fs:  `cpe:2.3:a:nokia_maps_\&amp;_places_project:nokia_maps_\&amp;_places:1.6.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.02`,
        fs:  `cpe:2.3:a:aol:aolserver:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.13.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.03`,
        fs:  `cpe:2.3:a:sophos:anti-virus:9.6.1:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.05`,
        fs:  `cpe:2.3:a:devsaran:responsive:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.5`,
        fs:  `cpe:2.3:a:alternative_connection_project:alternative_connection:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.6:beta`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.7`,
        fs:  `cpe:2.3:a:nedprod:nedmalloc:1.10:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.22`,
        fs:  `cpe:2.3:h:amd:16h_model_0fh_processor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:1.71`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.0`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.0:beta1`,
        fs:  `cpe:2.3:o:bluecoat:avos:3.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.0:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(4\)xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.0:beta3`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.0:beta4`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l33erm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.01`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.7:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.1`,
        fs:  `cpe:2.3:a:oracle:application_testing_suite:12.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.02`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.2`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.02:beta`,
        fs:  `cpe:2.3:a:avd-app:avd_download_video:3.3.13:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.2:beta1`,
        fs:  `cpe:2.3:o:d-link:dcs-930l_firmware:2.13.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.2:beta2`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.2:beta3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.3`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.4`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.4:beta1`,
        fs:  `cpe:2.3:a:f5:linerate:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.4:beta2`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.4:beta3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.11`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.11:beta`,
        fs:  `cpe:2.3:h:hp:j9540a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.11:beta2`,
        fs:  `cpe:2.3:a:mcafee:agent:4.0.301:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.15:beta`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.16`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.21`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.22`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.23:beta`,
        fs:  `cpe:2.3:o:buffalotech:whr-300hp2_firmware:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.31`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.32`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.41`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.42`,
        fs:  `cpe:2.3:a:microsoft:pssuspend:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.43`,
        fs:  `cpe:2.3:a:sap:netweaver_software_lifecycle_manager:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.44`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.45`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.46`,
        fs:  `cpe:2.3:o:huawei:s5700_firmware:v200r003c02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.47`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.48`,
        fs:  `cpe:2.3:a:apple:cups:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.49`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:2.50`,
        fs:  `cpe:2.3:a:apc:powerchute:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.1`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.2`,
        fs:  `cpe:2.3:h:hp:scanjet_4500c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.3`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.4`,
        fs:  `cpe:2.3:o:ibm:linux_on_zseries:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.5`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1130ag:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.6`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.7`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.7.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.0.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1.0.3`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp3:advanced_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1.0.4`,
        fs:  `cpe:2.3:a:tamos:commtraffic:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1.0.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.07.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1.2`,
        fs:  `cpe:2.3:a:umn:mapserver:6.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1.3`,
        fs:  `cpe:2.3:a:microsoft:project_server:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1.3.1`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:3.1.4`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:5.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.362:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.0.6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.0.8`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0b.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.0.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.0.11`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.1`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.3.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.1.1`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.2.2`,
        fs:  `cpe:2.3:a:google:picasa:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.3.0`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control_host:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.3.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.3.2`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.4.0`,
        fs:  `cpe:2.3:a:mollify:mollify:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.4.1`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.4.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.4.3`,
        fs:  `cpe:2.3:h:cisco:callmanager_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.5`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.5.2`,
        fs:  `cpe:2.3:a:digium:asterisk:11.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.5.3`,
        fs:  `cpe:2.3:a:ibm:interact:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.5.4`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.5.5`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-rc2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.6`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.7`,
        fs:  `cpe:2.3:a:emc:legato_networker:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.7.2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.7.3`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:4.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.7.5`,
        fs:  `cpe:2.3:a:jcore:jcore:1.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.7.6`,
        fs:  `cpe:2.3:a:facebook:fire_equipments_screen_lock:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.8.0`,
        fs:  `cpe:2.3:h:hp:5100_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.8.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.8.3`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.1`,
        fs:  `cpe:2.3:o:cisco:catos:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.2`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.3`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.4`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.0.205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.5`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.6`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.7`,
        fs:  `cpe:2.3:a:teradata:shared_icu_libraries:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.9.8`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.10.0`,
        fs:  `cpe:2.3:a:sas:locale_setup_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:4.0.11.0`,
        fs:  `cpe:2.3:a:smarttech:smart_essentials_for_educators:1.0.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.0.0`,
        fs:  `cpe:2.3:a:redhat:libreport:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.0.1`,
        fs:  `cpe:2.3:a:ibm:security_guardium_database_activity_monitor:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.0.2`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.0.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.0.4`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.0.5`,
        fs:  `cpe:2.3:a:frontend_user_upload_project:frontend_user_upload:0.5.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.0.6`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.0.7`,
        fs:  `cpe:2.3:a:altnet:altnet_download_manager:4.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.1.0`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.1.1`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.1.2`,
        fs:  `cpe:2.3:a:hp:storeonce_4430_backup_system:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.2.0`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.3.0`,
        fs:  `cpe:2.3:a:trillian:trillian:0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.3.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-03-03:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.4.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.4.1`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:3.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.4.2`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:4.67.651.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.4.3`,
        fs:  `cpe:2.3:h:cisco:secure_content_accelerator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.5.0`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerberusftp:ftp_server:5.0.5.1`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.2.068.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:certblaster:certblaster_comptia:5.0.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:certblaster:certblaster_comptia_security:5.0.0`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:certblaster:certblaster_security%2b_2008:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:certificationkits:ip_subnet_calculator:1.0.2`,
        fs:  `cpe:2.3:a:codiad:codiad:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:certmagic:cissp-testengine-certmagic-part1:2.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cerulean_studios:trillian:3.1::~~basic~~~`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cerulean_studios:trillian:3.1::~~pro~~~`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cete:dynamicpdf_for_.net:5.1.2`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.25:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cfdbplugin:contact_form_db:2.8.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cfdbplugin:contact_form_db:2.8.26::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:color_extra_settings_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cfdbplugin:contact_form_db:2.8.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r11b-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgene:security_file_manager:1.0.6:-:~-~pro~android~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgene:security_file_manager:1.0.6:-:~-~trial~android~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi:hotscan:-`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:0.20`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:0.21`,
        fs:  `cpe:2.3:a:intel:prosafe_for_wired_connections:99.99.9999:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.00`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.01`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.02`,
        fs:  `cpe:2.3:a:apache:activemq:5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.03`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.04`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.05`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.10`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.11`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgi_rescue:blobee:1.12`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.1`,
        fs:  `cpe:2.3:a:cisco:virtual_central_office:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.2`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.07.0410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.2.1`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3:pre1`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3:pre2`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.:b`,
        fs:  `cpe:2.3:a:serf_project:serf:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.564:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.3`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.3:pre1`,
        fs:  `cpe:2.3:a:rest-client_project:rest-client:1.7.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.4`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.6`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.0:sp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.3.7`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp3:adv_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.4.1`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.4.2`,
        fs:  `cpe:2.3:o:alcatel:aos:5.4.1.429:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.4.3`,
        fs:  `cpe:2.3:a:boost:boost:1.39.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.1`,
        fs:  `cpe:2.3:a:hp:product_assistant:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.2`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.3`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.4`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.5`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.6`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.7`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.8`,
        fs:  `cpe:2.3:a:inria:ocaml:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.9`,
        fs:  `cpe:2.3:a:web2py:web2py:1.93.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgiirc:cgi%3airc:0.5.10`,
        fs:  `cpe:2.3:a:apache:struts:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgit_project:cgit:0.11.2`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.3.0`,
        fs:  `cpe:2.3:h:dell:truemobile_2300_wireless_broadband_router:5.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.3.1`,
        fs:  `cpe:2.3:a:samba:samba:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.3.2`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.3.3`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.3.4`,
        fs:  `cpe:2.3:a:dell:client_configuration_toolkit:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.4.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.4.1`,
        fs:  `cpe:2.3:a:ibm:lotus_forms_viewer:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.4.2`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:6.0:2m:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.4.3`,
        fs:  `cpe:2.3:a:gcspublishing:wine_making:3.7.15:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.5.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.5.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.6.0`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.6.1`,
        fs:  `cpe:2.3:a:hp:ipfilter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.6.2`,
        fs:  `cpe:2.3:a:buffalotech:whr-g54s_firmware:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.6.3`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:-:*:mainframe_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.6.4`,
        fs:  `cpe:2.3:h:iij:seil_b1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.7.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.7.1`,
        fs:  `cpe:2.3:a:sas:intelligence_platform_object_framework:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.7.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.8.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.482.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.8.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.8.2`,
        fs:  `cpe:2.3:a:netbsd:ftpd:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.8.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.8.4`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.8.5`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.9.0`,
        fs:  `cpe:2.3:h:tropos:1410_wireless_mesh_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.10.0`,
        fs:  `cpe:2.3:a:phpyabs:phpyabs:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.11.0`,
        fs:  `cpe:2.3:o:hp:jg803a:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.12.0`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_firmware:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.12.1`,
        fs:  `cpe:2.3:a:emerson:deltav:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.12.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.480.4.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:3.12.3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:4.0.0`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:4.0.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.6.0.6090:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:4.3.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:4.3.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:4.3.2`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:4.3.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1\(1.7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:4.3.4`,
        fs:  `cpe:2.3:a:sap:hybris:5.3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cgminer_project:cgminer:4.3.5`,
        fs:  `cpe:2.3:a:google:chrome:12.0.731.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chainfire:supersu:1.69::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:automake:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamanet:chamacargo:7.0000`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamberme:so._co._business_partnership:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.8.6.2`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.8.7`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.8.7.1`,
        fs:  `cpe:2.3:a:plone:plone:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.8.8.2`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.8.8.4`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.8.8.6`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.9.0`,
        fs:  `cpe:2.3:o:huawei:echo_life_hg8247_firmware:v1r006c00s120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.9.2`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.9.4`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(3a\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo:chamilo_lms:1.9.6`,
        fs:  `cpe:2.3:a:atlassian:jira:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo_integration_project:chamilo_integration:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chamilo_integration_project:chamilo_integration:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.326:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:jre:6.0.270:update27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:a:docker:docker:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:beta4:~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(p1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:isc:kea:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:netscape:certificate_management_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ipswitch:imail_server:12.4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:atlassian:jira:2.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:o:honeywell:excel_web_xl_1000c100_104_i\/o:2.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins:git:3.4.0:alpha-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:f5:arx_data_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:gnu:anubis:3.9.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:openpkg:openpkg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.12::~~~drupal~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.194:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.13::~~~drupal~~`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.77:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:6.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:wdc:smartware:1.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:sabreairlinesolutions:crew_services:2010.2.12.20008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.0:alpha4:~~~drupal~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:atlassian:jira:2.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.14:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(13\)aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.6:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chaos_tool_suite_project:ctools:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:php:php:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chat_room_project:chat_room:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chat_room_project:chat_room:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:apple:apple_tv:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:1.0`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:1.2`,
        fs:  `cpe:2.3:a:sysaid:sysaid:15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:2.0`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:2.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:2.1.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:2.2`,
        fs:  `cpe:2.3:a:redhat:sysreport:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\)ea4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:2.4`,
        fs:  `cpe:2.3:o:emc:data_domain:5.7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:2.6`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.0`,
        fs:  `cpe:2.3:a:jasper_project:jasper:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.1.1`,
        fs:  `cpe:2.3:a:google:v8:3.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.1.2`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.1.3`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.1.4`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.1.5`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.1.6`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.411:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.1`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.2`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p4_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.5`,
        fs:  `cpe:2.3:a:fusetalk.:fusetalk:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.6`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.7`,
        fs:  `cpe:2.3:o:freebsd:freebsd:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.8`,
        fs:  `cpe:2.3:a:google:v8:3.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.9`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_laptops_desktops:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.10`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.2:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.11`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.12`,
        fs:  `cpe:2.3:o:huawei:ar_firmware:v200r005c30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.13`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.2.14`,
        fs:  `cpe:2.3:o:siemens:scalance_x-200_series_firmware:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.1`,
        fs:  `cpe:2.3:a:phusion:passenger:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.2`,
        fs:  `cpe:2.3:a:apple:apple_tv:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.3`,
        fs:  `cpe:2.3:a:digium:asterisk:11.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.5`,
        fs:  `cpe:2.3:a:hp:software_security_core:6.20.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.6`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.53.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.7`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.8`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4501_series_software:4.3\(2.18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.9`,
        fs:  `cpe:2.3:h:asus:rt-ac66u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.10`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.12`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.13`,
        fs:  `cpe:2.3:a:xavoc:xepan_cms:1.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.14`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.15`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.16`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.4b.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.17`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.3.18`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.17.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.1`,
        fs:  `cpe:2.3:a:wephoneapp:wephone_-_phone_calls_vs_skype:1.03.00:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.2`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.3`,
        fs:  `cpe:2.3:a:buffalotech:whr-am54g54_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.5`,
        fs:  `cpe:2.3:a:rpm:rpm:4.9.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.6`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.7`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.8`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.81.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:3.4.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:4.0`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.80:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:4.0.2`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.2.3:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:4.1.1`,
        fs:  `cpe:2.3:a:symantec:encryption_desktop:10.3.2:-:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:4.1.3`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:6.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:4.1.4`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.0`,
        fs:  `cpe:2.3:a:emc:vmware:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.0:beta`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.1`,
        fs:  `cpe:2.3:a:exim:exim:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.3`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.532.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4.4`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4.5`,
        fs:  `cpe:2.3:h:tvt:dvr:td-2308ss-b:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4.6`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4.7`,
        fs:  `cpe:2.3:a:google:v8:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.4.9`,
        fs:  `cpe:2.3:a:alex_barth:data:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.5`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.6`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.7`,
        fs:  `cpe:2.3:h:hp:jetdirect_615n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.7.1`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.7.2`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.7.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.336:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.7.4`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.7.5`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:5.8.1`,
        fs:  `cpe:2.3:o:oracle:opensolaris:snv_98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.0`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.1`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.1.1`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.1.2`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0573:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.1.3`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.1.4`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.2`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.3`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.4`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.5`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.6`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.7`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.10`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.11`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:6.2.12`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.1_b15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:7.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.335:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chatelao:php_address_book:8.2.5`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chattanoogastate:elearn:1.0.649.1194::~~~android~~`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:check_diskio_project:check_diskio:3.2.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.4`,
        fs:  `cpe:2.3:a:ca:etrust_secure_content_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.4:p1`,
        fs:  `cpe:2.3:a:elefantcms:elefantcms:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.4:p2`,
        fs:  `cpe:2.3:o:f5:tmos:9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.4:p3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.4:p4`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.4:p5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.5:i1`,
        fs:  `cpe:2.3:a:canon:canoscan_toolbox:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.5:i2`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.5:i3`,
        fs:  `cpe:2.3:a:adobe:coldfusion_.net_integration_services:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.5:i4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.5:i5`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.5:i5p1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p252:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.5:i5p2`,
        fs:  `cpe:2.3:a:roxio:easy_cd_\&amp;_dvd_creator:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b1`,
        fs:  `cpe:2.3:a:hp:sitescope:11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b10`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b11`,
        fs:  `cpe:2.3:a:ibm:spss_data_collection:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b3`,
        fs:  `cpe:2.3:a:mcafee:agent:4.0.0.1180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b4`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.4p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b5`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b6`,
        fs:  `cpe:2.3:a:drupal:drupal:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b7`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b8`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:b9`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.16:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p10`,
        fs:  `cpe:2.3:a:avast\!:avast\!_internet_security:5.0:*:*:*:korean_trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p11`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p12`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2.4:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p13`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p14`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p15`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p16`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p17`,
        fs:  `cpe:2.3:o:bluecoat:sgos:5.4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p18`,
        fs:  `cpe:2.3:h:symantec:gateway_security_5200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p19`,
        fs:  `cpe:2.3:a:ibm:os2_ftp_server:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p2`,
        fs:  `cpe:2.3:a:hans_alshoff:minalic:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p20`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.3\(0.99\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p21`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p22`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p23`,
        fs:  `cpe:2.3:a:oracle:communications_user_data_repository:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p24`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.1.528992:*:*:*:winpre2k:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.14:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p4`,
        fs:  `cpe:2.3:a:compaq:armada_insight_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p5`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p6`,
        fs:  `cpe:2.3:a:citrix:gotomeeting:5.0.799.1238:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p8`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.2.8:p9`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b2`,
        fs:  `cpe:2.3:h:lexmark:x36x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b3`,
        fs:  `cpe:2.3:a:hitachi:jp1\/it_desktop_management-manager:10-00-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b4`,
        fs:  `cpe:2.3:a:x:libxcb:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b5`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.7.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b6`,
        fs:  `cpe:2.3:h:f5:big-ip_11050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b7`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b8`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.3:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:b9`,
        fs:  `cpe:2.3:a:libarchive:libarchive:3.1.901a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:p6`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:p7`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:p8`,
        fs:  `cpe:2.3:a:checkpoint:remote_access_clients:e75.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:check_mk_project:check_mk:1.4.0:p9`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:check_point_integrity_client:-`,
        fs:  `cpe:2.3:o:microsoft:windows_98:-:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:check_point_integrity_client:4.5.122.000`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:check_point_integrity_client:5.1.556.166`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:connectra_ngx:-`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.592:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:connectra_ngx:r60`,
        fs:  `cpe:2.3:a:redmine:redmine:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:connectra_ngx:r62`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_connect:r73`,
        fs:  `cpe:2.3:a:ca:directory:r12:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security:e80:-:vpn_blade`,
        fs:  `cpe:2.3:a:lrzip_project:lrzip:0.631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security:e80.10:-:vpn_blade`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security:e80.20:-:vpn_blade`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security:e80.30:-:vpn_blade`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security:e80.40:-:vpn_blade`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security:e80.41:-:vpn_blade`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security:e80.50:-:vpn_blade`,
        fs:  `cpe:2.3:a:xnview:xnview:1.91.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security:r73`,
        fs:  `cpe:2.3:a:devsaran:clean_theme:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security_mi_server_r73:3.0.0:hfa2.5`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:endpoint_security_vpn:r75`,
        fs:  `cpe:2.3:o:yamaha:rta54i:4.04.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:express:-`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:express:ci_r57`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:-`,
        fs:  `cpe:2.3:a:google:chrome:5.0.360.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:3.0`,
        fs:  `cpe:2.3:a:luracast:restler:0.9.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:3.0b`,
        fs:  `cpe:2.3:a:oracle:report_manager:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.0`,
        fs:  `cpe:2.3:a:vips:vips:7.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1:sp1`,
        fs:  `cpe:2.3:a:erlang:crypto:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1:sp2`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1:sp3`,
        fs:  `cpe:2.3:a:hp:dynrootdisk:a.1.0.18.245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1:sp4`,
        fs:  `cpe:2.3:a:deltek:open_plan_professional:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1:sp5`,
        fs:  `cpe:2.3:a:apple:xcode:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1:sp5a`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1:sp6`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:4.1_build_41439`,
        fs:  `cpe:2.3:a:apache:subversion:0.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:r55w`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.0.899:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:r55w:hfa1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_performance_manager:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:firewall-1:r55w:hfa2`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.2:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:checkpoint:gaia_os:r70.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:checkpoint:gaia_os:r71.0`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:checkpoint:gaia_os:r75.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:checkpoint:gaia_os:r76.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:checkpoint:gaia_os:r77.0`,
        fs:  `cpe:2.3:a:veritas:enterprise_administrator:3.0.2.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:checkpoint:ipso_os:6.2`,
        fs:  `cpe:2.3:o:cisco:content_services_switch_11500:7.10_\(05.07\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:management_server:r75.47`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:next_generation:-`,
        fs:  `cpe:2.3:a:samba:samba:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:ng-ai:-`,
        fs:  `cpe:2.3:a:teradata:visual_explain:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:ng-ai:r54`,
        fs:  `cpe:2.3:a:daily_green_project:daily_green:2014.07:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:ng-ai:r55`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:provider-1:-`,
        fs:  `cpe:2.3:a:sun:jre:1.3.0:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:provider-1:4.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:provider-1:4.1:sp1`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:provider-1:4.1:sp2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:provider-1:4.1:sp3`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:provider-1:4.1:sp4`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:remote_access_clients:e75`,
        fs:  `cpe:2.3:a:nobexrc:abram_radio_groove\!:3.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:remote_access_clients:e75.10`,
        fs:  `cpe:2.3:a:microchip_technology_inc.:mplab_tools:8.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:remote_access_clients:e75.20`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:secure_platform_ng:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:secureclient_ng:-`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:secureclient_ng:r54`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:secureclient_ng:r56`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r71.00`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r71.45`,
        fs:  `cpe:2.3:a:aipluspro:asset_inventory_plus:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r75`,
        fs:  `cpe:2.3:a:gnu:glibc:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r75.20`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r75.40:vs`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r75.45`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.39:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r75.46`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r75.47`,
        fs:  `cpe:2.3:a:farm_frenzy_gold_project:farm_frenzy_gold:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r76`,
        fs:  `cpe:2.3:o:google:android:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r77`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:security_gateway:r77.10`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:session_authentication_agent:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:4.1`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:4.1:sp1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:4.1:sp2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:4.1:sp3`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:4.1:sp4`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:4.1:sp5`,
        fs:  `cpe:2.3:a:authorsontourlive:authors_on_tour_-_live\!:4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:4.1:sp5a`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1:4.1:sp6`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_xgs_firmware:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1:-`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1:4.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1:4.1`,
        fs:  `cpe:2.3:a:apache:rave:0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1:4.1:sp4`,
        fs:  `cpe:2.3:a:symantec:altiris_it_management_suite:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1:4.1:sp5`,
        fs:  `cpe:2.3:a:gnome:evolution:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1:4.1:sp5a`,
        fs:  `cpe:2.3:h:huawei:te60:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1:4.1:sp6`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:fp0`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:fp1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.387.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:fp2`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:fp3`,
        fs:  `cpe:2.3:a:canon:canoscan_toolbox:4.9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:r54`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:2.1.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:r55`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:r55p`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_next_generation:r55w`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall-1_vsx:-`,
        fs:  `cpe:2.3:a:sun:grid_engine:6.0:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall_1:-`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall_1:4.1.0`,
        fs:  `cpe:2.3:a:intra-mart:webplatform\/appframework:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall_1:4.1.0:sp1`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall_1:4.1.0:sp2`,
        fs:  `cpe:2.3:a:apache:mod_auth_radius:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall_1:4.1.0:sp3`,
        fs:  `cpe:2.3:a:mozilla:firefox:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall_1:4.1.0:sp4`,
        fs:  `cpe:2.3:a:emc:watch4net:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall_1:4.1.0:sp5`,
        fs:  `cpe:2.3:h:ibm:security_access_manager_for_mobile_appliance:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_firewall_1:4.1.0:sp5a`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_secureclient:-`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_secureclient:4.0`,
        fs:  `cpe:2.3:a:vmware:server:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:vpn-1_secureclient:4.1`,
        fs:  `cpe:2.3:a:combodo:itop:2.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:web_intelligence:-`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm:-`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm:5.0.63.0`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm:6.1.744.001`,
        fs:  `cpe:2.3:a:wpsymposium:wp_symposium:15.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm:7.0.337.0`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:8.0.298.000`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:8.0.298.035`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5603:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:8.0.400.020`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:9.0.083.000`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:9.0.114.000`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:9.1.008.000`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:9.1.507.000`,
        fs:  `cpe:2.3:a:icz:sencha_sns:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:9.1.603.000`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:9.3.014.000`,
        fs:  `cpe:2.3:a:apple:itunes:10.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:9.3.037.000`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.0.240.000`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.0.241.000`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.0.243.000`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.0.250.000`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.7.1\(4864\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.1.056.000`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.1.065.000`,
        fs:  `cpe:2.3:a:symantec:network_access_control:12.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.1.079.000`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.2.068.000`,
        fs:  `cpe:2.3:a:cybozu:office:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.2.072.000`,
        fs:  `cpe:2.3:a:yahoo:yui:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.2.073.000`,
        fs:  `cpe:2.3:a:php:php:5.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_extreme_security:10.2.074.000`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:101dl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_security_suite:-`,
        fs:  `cpe:2.3:a:microsoft:powerpoint_viewer:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_security_suite:5.5.062.004`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-05-07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpoint:zonealarm_security_suite:6.5.737`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpw_project:checkpw:1.02`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:checkpw_project:checkpw:1.03`,
        fs:  `cpe:2.3:a:rsa:access_manager_agent_for_iis_5.0\/6.0:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chemssou_blink_project:chemssou_blink:1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherokee-project:cherokee:1.2.2`,
        fs:  `cpe:2.3:a:htc:evo_design_4g_software:2.12.651.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherokee-project:cherokee:1.2.98`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherokee-project:cherokee:1.2.99`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherokee-project:cherokee:1.2.101`,
        fs:  `cpe:2.3:a:ajsquare:aj_auction_pro-oopd:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherokee-project:cherokee:1.2.102`,
        fs:  `cpe:2.3:a:gnu:bash:1.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherokee-project:cherokee:1.2.103`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.4-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherry-design:wikipad:1.6.0`,
        fs:  `cpe:2.3:h:hp:jg823a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherry-software:photopad:1.2.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherrypy:cherrypy:2.2.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.15.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherrypy:cherrypy:3.0.0`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cherrypy:cherrypy:3.0.1`,
        fs:  `cpe:2.3:a:php_kobo:photo_gallery_cms_free:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chickensys:instrument_manager:5.57`,
        fs:  `cpe:2.3:o:cisco:ios:11.2gs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chifro:chifro_kids_coloring_game:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:solarwinds:tftp_server:9.1.0.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:childrens:help_for_doc:1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chilkat_software:chilkat_crypt_activex_control:2.1`,
        fs:  `cpe:2.3:a:redhat:network_satellite_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chilkat_software:chilkat_xml_activex_control:3.0.3.0`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chilkatsoft:chilkat_smtpq:3.3.0`,
        fs:  `cpe:2.3:a:famatech:advanced_port_scanner:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chillcreations:mod_ccnewsletter:1.0.7`,
        fs:  `cpe:2.3:h:xerox:workcentre_40_color:01.02.058.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chillcreations:mod_ccnewsletter:1.0.8`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chillcreations:mod_ccnewsletter:1.0.9`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chillingo:flying_fox:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:chiyu:bf-660c:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chkrootkit:chkrootkit:0.49`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:choice-wireless:wixfmr-111:-`,
        fs:  `cpe:2.3:a:samba:samba:3.0.21c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:choiceoflove:free_dating_heart_col:2.6.1::~~~android~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christian_johansson:restrict_node_page_view:7.x-1.0`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christian_johansson:restrict_node_page_view:7.x-1.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:christian_johansson:restrict_node_page_view:7.x-1.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christian_kindahl:tugzip:3.5`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christiancafe:christian_dating_cafe:1.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:umn:mapserver:5.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christoph_dorn:firephp:0.2.1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christoph_dorn:firephp:0.3.1`,
        fs:  `cpe:2.3:a:sonicwall:aventail_access_manager:10.1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christophe_thibault:k-meleon:0.8`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christophe_thibault:k-meleon:1.0`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christophe_thibault:k-meleon:1.1`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:5.1.1700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christophe_thibault:k-meleon:1.5`,
        fs:  `cpe:2.3:h:polycom:viewstation_h.323:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christopher_mitchell:smart_breadcrumb:6.x-1.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christopher_mitchell:smart_breadcrumb:6.x-1.1`,
        fs:  `cpe:2.3:a:acobot_live_chat_\&amp;_contact_form_project:acobot_live_chat_\&amp;_contact_form:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:christopher_mitchell:smart_breadcrumb:6.x-1.2`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christopher_mitchell:smart_breadcrumb:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:sun:java_system_portal_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.00`,
        fs:  `cpe:2.3:a:roxio:cd_creator:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.01`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.02`,
        fs:  `cpe:2.3:a:f5:big-iq_device:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.03`,
        fs:  `cpe:2.3:o:yamaha:rtw65i:5.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.04`,
        fs:  `cpe:2.3:a:web2py:web2py:1.85.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.05`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.06`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.07`,
        fs:  `cpe:2.3:a:dupehunter:dupehunter:9.0.0.3911:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.08`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.09`,
        fs:  `cpe:2.3:a:microsoft:outlook.com:7.8.2.11.48.4848:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.10`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.11`,
        fs:  `cpe:2.3:o:xen:xen:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.12`,
        fs:  `cpe:2.3:o:cisco:aironet_access_point_software:7.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.13`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.15`,
        fs:  `cpe:2.3:a:gnome:evolution:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.16`,
        fs:  `cpe:2.3:a:samba:samba:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.17`,
        fs:  `cpe:2.3:a:samba:samba:4.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.18`,
        fs:  `cpe:2.3:a:i-escorts:i-escorts_directory_script:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:christos_zoulas:file:5.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chromium:chromium:11.0.696.64`,
        fs:  `cpe:2.3:a:hp:device_discovery:90.0.205.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chromium:chromium:40.0.2214.94`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:chyrp:chyrp:2.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p151:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cibc:cibc_mobile_banking:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:groove_server:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cimon:cmnview:2.14.0.1`,
        fs:  `cpe:2.3:a:mislav_marohnic:will_paginate:3.0.3:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cimon:ultimateaccess:3.00`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cimon:ultimateaccess:3.01`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwknop:2.0`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta__dpr\/epr2320:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwknop:2.0.1`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwknop:2.0.2`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwknop:2.0.3`,
        fs:  `cpe:2.3:a:apache:poi:3.5:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.5`,
        fs:  `cpe:2.3:a:roxio:creator_audio:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.6`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.6.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.6.2`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.6.3`,
        fs:  `cpe:2.3:a:iss:realsecure_server_sensor:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.6.4`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:7.70.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.6.5`,
        fs:  `cpe:2.3:a:vim:vim:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.7.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.8.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.8.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.8.2`,
        fs:  `cpe:2.3:a:rsa:rsaref:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:0.9.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.0`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.0.1`,
        fs:  `cpe:2.3:a:addsoft:storebot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.0.2`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.0.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.0.4`,
        fs:  `cpe:2.3:a:djangoproject:django:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.0.5`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.0.6`,
        fs:  `cpe:2.3:h:huawei:access_router:v200r002spc003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.5`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.48.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.6`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.6.1`,
        fs:  `cpe:2.3:a:netgenius:multilink:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.6.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.6.3`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.6.4`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cipherdyne:fwsnort:1.6.5`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ciphertrust:ironmail:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ciphertrust:ironmail:4.1`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ciphertrust:ironmail:4.5.1`,
        fs:  `cpe:2.3:h:axis:2420-ir_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ciphertrust:ironmail:4.5.2`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ciphertrust:ironmail:5.0.1`,
        fs:  `cpe:2.3:a:actualtests:exin_ex0-1_in_exam_engine_format:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ciphertrust:ironmail:6.1.1`,
        fs:  `cpe:2.3:a:sun:jre:1.2.2:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cir:circa_news:2.1.3::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:1000v_virtual_ethernet_module_%28vem%29:4.0%284%29:sv1%281%29`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:1000v_virtual_ethernet_module_%28vem%29:4.0%284%29:sv1%282%29`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:1000v_virtual_ethernet_module_%28vem%29:4.0%284%29:sv1%283%29`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.05.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:1000v_virtual_ethernet_module_%28vem%29:4.0%284%29:sv1%283a%29`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.009.20079:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:1000v_virtual_ethernet_module_%28vem%29:4.0%284%29:sv1%283b%29`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:12000_router:-`,
        fs:  `cpe:2.3:h:asus:rt-n10\&#43;d1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1801_integrated_service_router:-`,
        fs:  `cpe:2.3:a:animalcenter:light_for_pets:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1802_integrated_service_router:-`,
        fs:  `cpe:2.3:h:cisco:ip_phone_7940:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1803_integrated_service_router:-`,
        fs:  `cpe:2.3:a:vicidial:vicidial:2.8:403a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1811_integrated_service_router:-`,
        fs:  `cpe:2.3:a:winzip:winzip:12.1.8519:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1812_integrated_service_router:-`,
        fs:  `cpe:2.3:a:apache:subversion:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1841_integrated_service_router:-`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1861_integrated_service_router:-`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1921_integrated_services_router:-`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1941_integrated_services_router:-`,
        fs:  `cpe:2.3:a:digium:asterisk:10.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:1941w_integrated_services_router:-`,
        fs:  `cpe:2.3:a:adobe:robohelp:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2000_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:3.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2100_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_mail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2106_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2112_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2125_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2500_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:apache:solr:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2504_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2700_wireless_location_appliance:-`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2700_wireless_location_appliance:1.1.73.0`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2900_integrated_service_router:-`,
        fs:  `cpe:2.3:a:hp:business_availability_center:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2901_integrated_services_router:-`,
        fs:  `cpe:2.3:o:mandriva:linux:2008.0:*:x86_64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2911_integrated_services_router:-`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2921_integrated_services_router:-`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-10-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:2951_integrated_services_router:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p201:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:300_series_managed_switch_firmware:1.4.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:3660_router:-`,
        fs:  `cpe:2.3:a:emulex:common_san_management:32.0.1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:3925_integrated_services_router:-`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:3925e_integrated_services_router:-`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:3945_integrated_services_router:-`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:3945e_integrated_services_router:-`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:4100_wireless_lan_controller:-`,
        fs:  `cpe:2.3:o:huawei:s3300_firmware:v100r006c03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:4400_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:4400_wireless_lan_controller:4.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.6.602.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:4400_wireless_lan_controller:4.2`,
        fs:  `cpe:2.3:o:google:android:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:4400_wireless_lan_controller:5.0`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.03y-1.16:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:4400_wireless_lan_controller:5.2`,
        fs:  `cpe:2.3:a:nestler:ultimate_christian_radios:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:4402_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:emc:networker:8.1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:4404_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:php:php:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:500_series_switch_firmware:1.2.0.92`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:5500_adaptive_security_appliance:7.2:2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:5500_series_adaptive_security_appliance:-`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:5500_series_adaptive_security_appliance:7.2`,
        fs:  `cpe:2.3:a:samba:samba:1.9.17:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:5500_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.7.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:5508_wireless_controller:-`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.48:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:6400_nrp:-`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:6400_nrp:12.2`,
        fs:  `cpe:2.3:a:tmobile:webconnect_manager:2.5.55.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:6400_nrp_2:-`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:6400_nrp_2:12.1dc`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:675_router:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7100_router:-`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7200_router:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7300_router:-`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0f_pk8_bl22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7500_router:-`,
        fs:  `cpe:2.3:o:asus:dsl-n56u_firmware:3.0.0.4.364:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7500_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7600_router:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7920_wireless_ip_phone:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7920_wireless_ip_phone:1.0%288%29`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)ey3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7920_wireless_ip_phone:2.0`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.3.12s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7940_router:-`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:7960_router:-`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:80-7111-01_for_the_unity-svrx255-1a:-`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:80-7112-01_for_the_unity-svrx255-2a:-`,
        fs:  `cpe:2.3:h:seikoinstruments:smart_label_printer_430:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:8500_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:8.5.2-027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:861_integrated_services_router:-`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:867_integrated_services_router:-`,
        fs:  `cpe:2.3:a:divx:player:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:880_3g_integrated_services_router:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:881_integrated_services_router:-`,
        fs:  `cpe:2.3:a:ostenta:yawpp:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:886_integrated_services_router:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:886va-w_integrated_services_router:-`,
        fs:  `cpe:2.3:a:david_king:vino:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:886va_integrated_services_router:-`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:887_integrated_services_router:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.393:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:887v_integrated_services_router:-`,
        fs:  `cpe:2.3:a:symantec:unified_logging:2.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:887va-w_integrated_services_router:-`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:887va_integrated_services_router:-`,
        fs:  `cpe:2.3:a:acronis:true_image_agent:9.7.8206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:888_integrated_services_router:-`,
        fs:  `cpe:2.3:a:ca:service_desk_manager:12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:891_integrated_services_router:-`,
        fs:  `cpe:2.3:o:oracle:linux:6:6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:892_integrated_services_router:-`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:access_registrar:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:access_server:-`,
        fs:  `cpe:2.3:a:apple:safari:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:accesspath:-`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:accesspath:ls-3`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:accesspath:ts-3`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:accesspath:vs-3`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance:a5%281.0%29`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance:a5%281.1%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance:a5%281.2%29`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance:a5%282.0%29`,
        fs:  `cpe:2.3:a:netscape:collabra_server:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance:a5%282.1%29`,
        fs:  `cpe:2.3:a:faailkhair:faailkhair:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance:a5%282.1e%29`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance:a5%283.0%29`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance:a5_base`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a1:7`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a1:7a`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.14:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a1:7b`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(3\)es61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a1:8.0`,
        fs:  `cpe:2.3:a:hp:http_server:5.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a1:8.0a`,
        fs:  `cpe:2.3:a:david_king:vino:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a3:1.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.28.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.2`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.3`,
        fs:  `cpe:2.3:a:google:checkout-php:1.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.5`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.6`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.7`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-2.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a4:1.0`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a4:1.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a4:2.0`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a4:2.1a`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a4:2.2`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a4:2.3`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a5:3.1a`,
        fs:  `cpe:2.3:a:mindless_behavior_fan_base_project:mindless_behavior_fan_base:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a5:3.1b`,
        fs:  `cpe:2.3:h:ibm:messagesight:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a5:3.2`,
        fs:  `cpe:2.3:a:redhat:lv:4.49.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_4700_series_application_control_engine_appliance_a5:3.3`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.525:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a1:7a`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a1:7b`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1076.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a1:8.0`,
        fs:  `cpe:2.3:a:hp:process_resource_manager:c.02.01.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a1:8.0a`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a3:1.0`,
        fs:  `cpe:2.3:a:perl:perl:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a3:2.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a3:2.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a3:2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a3:2.4`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a3:2.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a3:2.6`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5192-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a3:2.7`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a4:1.0`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a4:1.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.2:*:*:*:base:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a4:2.0`,
        fs:  `cpe:2.3:a:progress:database:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a4:2.1a`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a4:2.2`,
        fs:  `cpe:2.3:a:conky:conky:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a4:2.3`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:1.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:1.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:2.0`,
        fs:  `cpe:2.3:a:oracle:iplanet_web_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:2.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:2.1e`,
        fs:  `cpe:2.3:a:autodesk:material_library_2011:2.0.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:3.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:3.1a`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:3.1b`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:3.2`,
        fs:  `cpe:2.3:a:lsoft:listserv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ace_application_control_engine_module_a5:3.3`,
        fs:  `cpe:2.3:a:mandrakesoft:mandrake_multi_network_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ace_application_controle_engine_module:-`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:acs_for_windows:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:acs_for_windows:4.1`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.1.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:acs_solution_engine:-`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:acs_solution_engine:4.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_appliance:-`,
        fs:  `cpe:2.3:a:red-gate:sql_doc:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.0`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_appliance:7.0%280%29`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_appliance:7.0%282%29`,
        fs:  `cpe:2.3:a:apple:cups:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_appliance:7.0%284%29`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.2.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.0%284%29`,
        fs:  `cpe:2.3:a:apple:cups:1.4:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.0%285%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.0%285.2%29`,
        fs:  `cpe:2.3:a:php:php:5.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.0%286.7%29`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.0.1.4`,
        fs:  `cpe:2.3:a:agilebits:knox:2.0.8:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.0.4.3`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_appliance:7.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.4:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.1%282%29`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5500:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.1%282.5%29`,
        fs:  `cpe:2.3:h:apple:imac:ma064xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.1%282.27%29`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.1%282.48%29`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.1%282.49%29`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc10:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.1%285%29`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_appliance:7.2`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_appliance:7.2:2`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%281%29`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%281.22%29`,
        fs:  `cpe:2.3:a:koha:koha:3.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282%29`,
        fs:  `cpe:2.3:a:ncircle:configuration_compliance_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.5%29`,
        fs:  `cpe:2.3:o:apple:mac_os_appleshare_ip:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.7%29`,
        fs:  `cpe:2.3:o:cisco:sn_5428_storage_router:2.5.1-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.8%29`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.10%29`,
        fs:  `cpe:2.3:a:microsoft:microsoft_forefront_protection_2010:-:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.14%29`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.15%29`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.16%29`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.17%29`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.19%29`,
        fs:  `cpe:2.3:o:dlink:des-3810_firmware:r2.15.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:7.2%282.48%29`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance:8.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.0:beta0001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_appliance:8.0`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-182_with_network_printer_kit_firmware:t282cn0j421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_clientless_ssl_vpn:-`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_cx_context-aware_security_software:-`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:-`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.0.1`,
        fs:  `cpe:2.3:a:scilab:scilab:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.0.2`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.0.4`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.0.5`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.0.6`,
        fs:  `cpe:2.3:a:gnu:bash:3.2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.0.7`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.0.8`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.0.9`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.1.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:vista:sp1:x64-home_premium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.1.2`,
        fs:  `cpe:2.3:a:phparena:panews:2.0b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.2.1`,
        fs:  `cpe:2.3:a:winzip:winzip:15.5.9579:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.2.2`,
        fs:  `cpe:2.3:a:adobe:onlocation_cs3:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.2.3`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.2.4`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.2.5`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:5.2.53`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.0.2`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.0.3`,
        fs:  `cpe:2.3:a:exim:exim:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.1.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.1.3`,
        fs:  `cpe:2.3:a:apache:solr:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.1.5`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/rs_firmware:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.1.5.51`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.2.1`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.2.3`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.5.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.2.5`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.3.1`,
        fs:  `cpe:2.3:a:civicrm:civicrm_private_report:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.3.2`,
        fs:  `cpe:2.3:a:ca:anti-spyware:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_device_manager:6.3.3`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:-`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0`,
        fs:  `cpe:2.3:a:netsarang:xmanager:3.0.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%280%29`,
        fs:  `cpe:2.3:a:novell:groupwise:7.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%281%29`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%282%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%284%29`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%285%29`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30172:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%285.2%29`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%286%29`,
        fs:  `cpe:2.3:a:redhat:analog_real-time_synthesizer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%286.7%29`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%287%29`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0%288%29`,
        fs:  `cpe:2.3:a:hp:marketresearch:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.1`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:8.5.6-073:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.1.4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.2`,
        fs:  `cpe:2.3:h:cisco:telepresence_video_communication_server:-:*:expressway:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.3`,
        fs:  `cpe:2.3:a:redhat:kdelibs_sound:2.2-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.4`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.4.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.4.3`,
        fs:  `cpe:2.3:h:cisco:content_services_switch_11503:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.5`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.5.12`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.5450:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(9a\)bc6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.6.4`,
        fs:  `cpe:2.3:a:hp:storageworks_common_services_xp:1.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.6.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.6.18`,
        fs:  `cpe:2.3:a:f5:big-ip:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.6.22`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.6.26`,
        fs:  `cpe:2.3:a:amd:power_monitor:1.0.1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.6.29`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.6.32`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:4.3r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p181:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.7.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.7.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.7.9`,
        fs:  `cpe:2.3:o:hp:tru64:4.0g_pk4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.7.12`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.5.1.527:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)t14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.8:interim`,
        fs:  `cpe:2.3:a:wordbox:algeria_radio:2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.8.2`,
        fs:  `cpe:2.3:h:nortel:optical_metro_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.8.8`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.0:beta-4:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.8.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.0.8.13`,
        fs:  `cpe:2.3:a:avsmedia:dvd_copy:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1`,
        fs:  `cpe:2.3:a:actualtests:comptia_n10-004_in_exam_engine_format:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1%282%29`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1%282.5%29`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1%282.27%29`,
        fs:  `cpe:2.3:o:centos:centos:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1%282.48%29`,
        fs:  `cpe:2.3:a:adobe:jrun:4.0:sp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1%282.49%29`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1%285%29`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.1`,
        fs:  `cpe:2.3:a:oracle:retail_xstore_point_of_service:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2`,
        fs:  `cpe:2.3:a:philips:xper_information_management_vascular_monitoring_5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.16`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.20`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.24`,
        fs:  `cpe:2.3:a:apple:itunes:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.28`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.35.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.38`,
        fs:  `cpe:2.3:a:actividentity:corestreet_validation_authority:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.42`,
        fs:  `cpe:2.3:a:x:libxxf86vm:1.0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.46`,
        fs:  `cpe:2.3:a:cisco:telepresence_advanced_media_gateway:1.1\(1.34\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.49`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.53`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.61`,
        fs:  `cpe:2.3:a:mollify:mollify:1.6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.64`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.72`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.1.2.81`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%281%29`,
        fs:  `cpe:2.3:a:sonicwall:aventail_web_proxy_agent:10.52.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%281.22%29`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282%29`,
        fs:  `cpe:2.3:a:omeka:omeka:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.5%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.7%29`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.8%29`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.10%29`,
        fs:  `cpe:2.3:h:enterasys:xsr-1805:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.14%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.16.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.15%29`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.16%29`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.17%29`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.18%29`,
        fs:  `cpe:2.3:a:cisco:icdn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.19%29`,
        fs:  `cpe:2.3:a:cyberlink:power2go:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%282.48%29`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(8\)e2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%283%29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%284%29`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2%285%29`,
        fs:  `cpe:2.3:a:openstack:grizzly:2013.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.1`,
        fs:  `cpe:2.3:a:dell:sonicwall_global_management_system:7.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.1.9`,
        fs:  `cpe:2.3:a:rockwellautomation:factorytalk_services_platform:cpr9:sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.1.13`,
        fs:  `cpe:2.3:a:intel:wimax_network_service:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.1.19`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.1.24`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.9:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.2`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_3_firmware:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.2.6`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.2.10`,
        fs:  `cpe:2.3:h:meinberg:lantime_m600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.2.14`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.2:rev33971:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.2.18`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.2.19`,
        fs:  `cpe:2.3:h:ibm:power_5:9115-505:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.2.22`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.2.34`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r2.14_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.3`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.3.1`,
        fs:  `cpe:2.3:a:erlang:crypto:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.3.12`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.3.16`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.4`,
        fs:  `cpe:2.3:a:macromedia:sitespring:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.4.6`,
        fs:  `cpe:2.3:a:ca:unicenter_autosys_jm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.4.9`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.4.18`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.4.25`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1.3:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.4.27`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.0:betax:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.4.30`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.4.33`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)yp1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.5.2`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.5.4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.51:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.5.7`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.5.8`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144nh_firmware:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.5.10`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:7.2.5.12`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0%282%29`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0%283%29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0%284%29`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0%285%29`,
        fs:  `cpe:2.3:a:inclind:custom_pub:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0%285.28%29`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0%285.31%29`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.1.2`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.2`,
        fs:  `cpe:2.3:a:curtis_galloway:libexif:0.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.2.11`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:3.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.2.15`,
        fs:  `cpe:2.3:a:apache:struts:2.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.3`,
        fs:  `cpe:2.3:h:cisco:unified_computing_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.3.6`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.2.0:cp05:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.3.12`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.328:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.3.19`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4`,
        fs:  `cpe:2.3:a:hp:photo_gallery:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert5:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p165:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.16`,
        fs:  `cpe:2.3:a:hp:7500_7600_7700_help:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.23`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.25`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.28`,
        fs:  `cpe:2.3:a:hp:solution_center:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.31`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.32`,
        fs:  `cpe:2.3:a:apple:cups:1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.4.33`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.5.20`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.5.23`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.47.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.5.25`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.5.27`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:-:pulse:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.5.28`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.0.5.31`,
        fs:  `cpe:2.3:a:login_security_project:login_security:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/a:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.0.104`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.1`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.1.6`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.15:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.13`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.15`,
        fs:  `cpe:2.3:a:google:chrome:7.0.547.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.16`,
        fs:  `cpe:2.3:o:juniper:junos:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.19`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.23`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.24`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.49`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.2.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.50`,
        fs:  `cpe:2.3:a:hulihanapplications:amethyst:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.55`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.1.2.56`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.71:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%281%29`,
        fs:  `cpe:2.3:a:jruby:jruby:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%282%29`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%283%29`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_service:3.3.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%283.9%29`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%284%29`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%284.1%29`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%284.4%29`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%285%29`,
        fs:  `cpe:2.3:a:citrix:cloudplatform:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%285.35%29`,
        fs:  `cpe:2.3:o:cisco:catos:7.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2%285.38%29`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.498.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.1.11`,
        fs:  `cpe:2.3:a:google:chrome:7.0.536.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.2:interim`,
        fs:  `cpe:2.3:a:nextbbs:nextbbs:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.3`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.5.52`,
        fs:  `cpe:2.3:a:mollify:mollify:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.5.55`,
        fs:  `cpe:2.3:a:9.dotpp.net:megalith:27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.5.57`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.3.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.2.5.59`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_security_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.3%281%29`,
        fs:  `cpe:2.3:a:roderick_baier:weberknecht:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.3%282%29`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.3%282.34%29`,
        fs:  `cpe:2.3:a:gentoo:rootkit_hunter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.3%282.37%29`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.3.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.5.0.880:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.3.1:interim`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.3.2`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.3.2.44`,
        fs:  `cpe:2.3:a:google:chrome:14.0.807.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.1%29`,
        fs:  `cpe:2.3:o:cisco:ios_xr:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.1.3%29`,
        fs:  `cpe:2.3:o:smoothwall:smoothwall:3.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.1.11%29`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpx\/epx2100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.2%29`,
        fs:  `cpe:2.3:h:hp:storageworks_p2000_g3_10gbe_iscsi_dual_controller_sff_array_system:aw597a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.2.1%29`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.30.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.2.8%29`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.3%29`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:5.0.8:-:limited:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.3.8%29`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144nh_firmware:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.3.9%29`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.4%29`,
        fs:  `cpe:2.3:a:ca:asset_management_performance_liteagent:11.2.7277:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.4.1%29`,
        fs:  `cpe:2.3:a:isc:dhcpd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.4.3%29`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.4.5%29`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.4.9%29`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.5%29`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.5.6%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.6%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.7%29`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.7.3%29`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%28.7.15%29`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%281%29`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%281.11%29`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.8:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%282%29`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%282.11%29`,
        fs:  `cpe:2.3:a:gomiso:miso:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%283%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p101:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%284.11%29`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%285%29`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4%286%29`,
        fs:  `cpe:2.3:a:opscode:chef:0.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.0`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.1`,
        fs:  `cpe:2.3:a:akamai:netsession:1.9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.1.3`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.1.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p231_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.2.1`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.2.8`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.3`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.3.8`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.3.9`,
        fs:  `cpe:2.3:a:jextn:com_jefaqpro:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.4.1`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.4.3`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.4.5`,
        fs:  `cpe:2.3:h:hp:j9311a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.4.9`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.366:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.5`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.5.6`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.13:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.6`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.7`,
        fs:  `cpe:2.3:a:apple:remote_desktop:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.7.3`,
        fs:  `cpe:2.3:a:mediacodec:windows_essentials_media_codec_pack:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.7.15`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.7.22`,
        fs:  `cpe:2.3:h:enterasys:1h582-51:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.7.23`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.7.26`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.7.28`,
        fs:  `cpe:2.3:a:openssl:openssl:1.1.0e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.4.7.29`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.5`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.5%281%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.5%281.4%29`,
        fs:  `cpe:2.3:a:coreftp:core_ftp:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.5%281.17%29`,
        fs:  `cpe:2.3:a:jenkins:git:0.9.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.6`,
        fs:  `cpe:2.3:o:redhat:linux:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.6%281%29`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.6%281.2%29`,
        fs:  `cpe:2.3:a:adobe:flash_player:20.0.0.235:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.6%281.3%29`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.6%281.10%29`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.12:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:8.6.1.12`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.432:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.7`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.7%281.1%29`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.7%281.3%29`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.7.1`,
        fs:  `cpe:2.3:a:apache:solr:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.7.1.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.7.1.8`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je069a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:8.7.1.17`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.2:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%28.1%29`,
        fs:  `cpe:2.3:h:juniper:mx40:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%28.2.10%29`,
        fs:  `cpe:2.3:a:ca:output_management_web_viewer:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%28.3%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%28.3.6%29`,
        fs:  `cpe:2.3:a:redhat:kdelibs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%28.3.8%29`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%28.4%29`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%28.4.1%29`,
        fs:  `cpe:2.3:a:roxio:drag-to-disc:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%281%29`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%282%29`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp2:media_center:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0%283%29`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0.3%286%29`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-355_firmware:t470sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0.4.24`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0.4.26`,
        fs:  `cpe:2.3:h:3com:3crwe754g72-a:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0.4.29`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0.4.37`,
        fs:  `cpe:2.3:a:cisco:unified_presence_server:1.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0.4.40`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.0.4.42`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1%28.2%29`,
        fs:  `cpe:2.3:a:redhat:daredevil_skk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1%28.3%29`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:6.2.x_ee:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1%28.5%29`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1%281%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1%281.7%29`,
        fs:  `cpe:2.3:a:symantec:data_insight:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1%282%29`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1%283%29`,
        fs:  `cpe:2.3:h:zyxel:n300_netusb_nbg-419n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.1`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.593:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.1.4`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.2.8`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.3.2`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.4`,
        fs:  `cpe:2.3:a:mono:mono:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.4.5`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.4.5`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.5.10`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.5.12`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.5.12`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.5.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.1.5.21`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.5.21`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.6`,
        fs:  `cpe:2.3:o:cisco:catos:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.6.8`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.6.10`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.7.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p214:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.7.6`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.7.7`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.7.9`,
        fs:  `cpe:2.3:a:apache:juddi:0.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.7.11`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.1.7.12`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.21m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2%280.0%29`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.5a:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2%280.104%29`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_manager:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2%283.1%29`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.2.1`,
        fs:  `cpe:2.3:a:citrix:metaframe_conferencing_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.2.2`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.13:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.2.2.4`,
        fs:  `cpe:2.3:a:nokia:ggsn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.2.2.7`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.2.7`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.2.8`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.2.2.8`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.2.3`,
        fs:  `cpe:2.3:a:pervasive:data_integrator:9.0.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.3.3`,
        fs:  `cpe:2.3:a:hp:mercury_performance_center_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4`,
        fs:  `cpe:2.3:a:linux-sottises:board-tnk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.77:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.4`,
        fs:  `cpe:2.3:a:isc:bind:9.8.1:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.8`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.10`,
        fs:  `cpe:2.3:a:openafs:openafs:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.13`,
        fs:  `cpe:2.3:a:isc:bind:9.7.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.14`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.16`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.17`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.18`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.6j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.2.4.19`,
        fs:  `cpe:2.3:a:informatica:powercenter:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3%28.2%29`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3%281.50%29`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3%282.243%29`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3%283%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.462:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.3.1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.3.1.1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.2`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.3.2`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:adaptive_security_appliance_software:9.3.2.2`,
        fs:  `cpe:2.3:a:websense:websense_web_filter:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xb4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.3.5`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.3.6`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.3.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.3.10`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.3.11`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.3.5`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4%281%29`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:pre.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4%281.1%29`,
        fs:  `cpe:2.3:a:php:php:5.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.1`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:5.2:r1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.1.1`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.1.2`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.1.3`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.1.5`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak3:3.0.0:beta29:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.2`,
        fs:  `cpe:2.3:a:husdawg:system_requirements_lab_for_intel:4.4.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.2.3`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:8.6.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.3.4`,
        fs:  `cpe:2.3:a:clamav:clamav:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.3.6`,
        fs:  `cpe:2.3:h:cisco:catalyst_2948g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.3.8`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.3.11`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.6.4.634:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.3.12`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.4.4`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_38:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.2`,
        fs:  `cpe:2.3:o:compaq:tru64:5.0_pk4_bl18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.2.6`,
        fs:  `cpe:2.3:a:apple:safari:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.2.10`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.2.14`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.3`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.3.1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.4:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.3.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1x\(l\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.3.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.3.6`,
        fs:  `cpe:2.3:a:openx:openx:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.5.3.7`,
        fs:  `cpe:2.3:a:microsoft:internet_authentication_service_helper_com_component:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.0`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnitouch_8660_my_teamwork:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.1`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.1.3`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.1.5`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.3.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.1.10`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.2`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.12:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.2.1`,
        fs:  `cpe:2.3:a:avast:file_server_security:8.0.1606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.2.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.2.3`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_appliance_software:9.6.2.7`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_device_manager:-`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:adaptive_security_device_manager:5.2.53`,
        fs:  `cpe:2.3:a:niif:shibboleth_authentication:6.x-4.2rc1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_idm_launcher:1.5.31`,
        fs:  `cpe:2.3:a:iirf:ionic\&#39;s_isapi_rewrite_filter:2.1.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_idm_launcher:1.5.41`,
        fs:  `cpe:2.3:a:emc:networker:8.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_idm_launcher:1.5.45`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.0:rc1:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_idm_launcher:1.5.47`,
        fs:  `cpe:2.3:a:emailarchitect:emailarchitect_email_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_idm_launcher:1.5.49`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1661.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_idm_launcher:1.5.50`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_launcher:1.5.20`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_launcher:1.5.24`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:adaptive_security_device_manager_launcher:1.5.30`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:agent_desktop:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:agent_desktop:80.2.9`,
        fs:  `cpe:2.3:a:litronic:argus:4.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:air-ct5760:-`,
        fs:  `cpe:2.3:a:ibm:interact:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aireos:4.1_base`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aireos:7.4:120.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aireos:7.5_base`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.256:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aireos:7.6:100.0`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:airespace_4000_wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:vips:vips:7.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:airespace_6500:-`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_1040:-`,
        fs:  `cpe:2.3:a:wondercms:wondercms:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_1140:-`,
        fs:  `cpe:2.3:h:samsung:series_5_550_chromebook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_1260:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_1830e:-`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_1830i:-`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_1850e:-`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.47.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_1850i:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_3500:-`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_3600:-`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_3600e:-`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:i7_quad_sinit_51.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_3600i:-`,
        fs:  `cpe:2.3:a:intel:mpfmgr:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_3600p:-`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_600_office_extend:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.414:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aironet_access_point_software:7.2_base`,
        fs:  `cpe:2.3:h:hp:color_inkjet_cp1160:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aironet_access_point_software:7.3_base`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:10.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aironet_access_point_software:7.4_base`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aironet_access_point_software:8.1%2815.14%29`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aironet_access_point_software:8.1%28112.3%29`,
        fs:  `cpe:2.3:o:cisco:content_services_switch_11500_firmware:8.20.4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aironet_access_point_software:8.1%28112.4%29`,
        fs:  `cpe:2.3:a:dell:banctec_service_agreement:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aironet_access_point_software:8.2%28121.12%29`,
        fs:  `cpe:2.3:a:johnsoncontrols:pegasys_p2000_server_software:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:aironet_access_point_software:8.4%281.82%29`,
        fs:  `cpe:2.3:a:google:chrome:15.0.865.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1100:-`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1130ag:-`,
        fs:  `cpe:2.3:a:oracle:field_service:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1131:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u6\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1200:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1230ag:-`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1240:-`,
        fs:  `cpe:2.3:a:oracle:agile_product_lifecycle_management:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1240ag:-`,
        fs:  `cpe:2.3:a:roxio:dvdmax_player:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1300:-`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap1400:-`,
        fs:  `cpe:2.3:a:nortel:net_direct_client:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap340:-`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap340:11.21`,
        fs:  `cpe:2.3:h:hp:jg735a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap350:-`,
        fs:  `cpe:2.3:o:juniper:junos_t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_ap350:11.21`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:aironet_bridge_350:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:anomaly_guard_module:-`,
        fs:  `cpe:2.3:h:avocent:kvm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:anomaly_guard_module:5.0%281%29`,
        fs:  `cpe:2.3:o:cisco:epc3928_docsis_3.0_8x4_wireless_residential_gateway_with_embedded_digital_voice_adapter:5.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:anomaly_guard_module:5.0%283%29`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:-`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:-::~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.0`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ebv:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.2`,
        fs:  `cpe:2.3:a:teradata:wintools:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.2.128`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.2.133`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.2.136`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.3\(2\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.2.140`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x4470:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.3.185`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.3.254`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.3.2016`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4::~~~symbian_os~~`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4.0202`,
        fs:  `cpe:2.3:a:debian:apt-cacher:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4.1012`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_mid_tier:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4.4004::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4.4014::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:winzip:winzip_command_line_support_add-on:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4.5004::~~~symbian_os~~`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:10.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4.7030::~~~android~~`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.4.7073::~~~android~~`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.0217`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.1025`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.2001`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.2006`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.2010`,
        fs:  `cpe:2.3:a:cisco:security_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.2011`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.2014`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.2017`,
        fs:  `cpe:2.3:a:apple:ichat_av:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.2018`,
        fs:  `cpe:2.3:a:yuba:u5cms:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.2019`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.3041`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.3046`,
        fs:  `cpe:2.3:h:fortinet:fortigate-3000d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.3051`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.3054`,
        fs:  `cpe:2.3:a:openttd:openttd:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.3055`,
        fs:  `cpe:2.3:a:webmin:usermin:1.480:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.5112::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.5116::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.5118::~~~android~~`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.5125::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.5130::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.5131::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:2.5.6005`,
        fs:  `cpe:2.3:a:debian:amaya:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.28.0:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0::~~~~x64~`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.2:*:*:*:*:aix:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.0629`,
        fs:  `cpe:2.3:a:netty_project:netty:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.1047`,
        fs:  `cpe:2.3:h:utc:utc_fire_\&amp;_security_ge-mc100-ntp\/gps-zb_master_clock_device:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.2052`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)yq4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.3050`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.3054`,
        fs:  `cpe:2.3:a:cybird:romeo_and_juliet:1.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.4235`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.5075`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.5080`,
        fs:  `cpe:2.3:a:david_king:vino:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.07059`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)e7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.08057`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sy3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.08057::~~~~x64~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.0.08066`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:1464:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.1%28.02043%29`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.1%28.07021%29`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.1%2860%29`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.1.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.4:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.1.00495`,
        fs:  `cpe:2.3:a:sgi:propack:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:3.2.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.0%28.00048%29`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.0%28.00051%29`,
        fs:  `cpe:2.3:a:emc:networker:7.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.0%282049%29`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.1.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.0.00052`,
        fs:  `cpe:2.3:a:emc:rsa_netwitness:9.8.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.0.00057`,
        fs:  `cpe:2.3:a:binarymoon:wordthumb:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.0.00061`,
        fs:  `cpe:2.3:a:serf_project:serf:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.1.00028`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_security_suite:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.1.02011`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.1.04011`,
        fs:  `cpe:2.3:a:php:php:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.1.06013`,
        fs:  `cpe:2.3:a:datemill:etano:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.1.06020`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.1.08005`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.2.00096`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.2.01022`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.2.01035`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.2.02075`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.2.03013`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(33\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.2.04018`,
        fs:  `cpe:2.3:a:david_king:vino:2.27.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.2.05015`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.7.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.2.06014`,
        fs:  `cpe:2.3:a:pansi:pansi_sms:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.3.02039`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.3.03086`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2009.925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_secure_mobility_client:4.3.04027`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_vpn_client:2.2.136`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_vpn_client:2.4.1012`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_vpn_client:2.5.2019`,
        fs:  `cpe:2.3:h:hp:8550_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_vpn_client:2.5.3041`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.13:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_vpn_client:2.5.3046`,
        fs:  `cpe:2.3:a:adobe:photoshop:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:anyconnect_vpn_client_start_before_login_components:2.4.1012`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(14a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:4.0.3`,
        fs:  `cpe:2.3:a:topline_systems:opportunity_form:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:4.1.1`,
        fs:  `cpe:2.3:o:d-link:dcs-2132l_firmware:2.12.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:4.1.3`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:4.2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:4.2.7`,
        fs:  `cpe:2.3:a:compaq:insight_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:4.2.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(2\)xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:4.2.11`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:5.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.3:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:5.0.1`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:5.0.3`,
        fs:  `cpe:2.3:a:webkit:webkit:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:5.0.5`,
        fs:  `cpe:2.3:a:garip_ve_ilginc_olaylar_project:garip_ve_ilginc_olaylar:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:5.0.17.5`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:4.1.91.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:5.1`,
        fs:  `cpe:2.3:a:novell:netmail:3.10c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:5.1.11.5`,
        fs:  `cpe:2.3:a:jollygiant:qws3270_secure:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_software:5.2`,
        fs:  `cpe:2.3:a:vmware:infrastructure_update:2.5.0.64207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:4.1.3`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:4.2.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:4.2.5`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.8.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:4.2.7.3`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:4.2.9.3`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:3.0:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:4.2.11.5`,
        fs:  `cpe:2.3:a:qemu:qemu:0.11.0-rc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:4.2.13.1`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:13.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.3.5`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.5.9`,
        fs:  `cpe:2.3:a:novell:zenworks_desktops:3.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.7.10`,
        fs:  `cpe:2.3:a:logitech:quickcam:11.0.1218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.9.9`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.11.6`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.13.2`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.15.1`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.0.17.6`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.1.1.3`,
        fs:  `cpe:2.3:a:optimizepress:optimizepress:1.60:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.1.3.15`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.1.5.2`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.1.7.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.1.9.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.1.11.6`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-400e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.1.13.7`,
        fs:  `cpe:2.3:a:boost:boost:1.52.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.1.15.5`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.07.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.4`,
        fs:  `cpe:2.3:a:apple:webkit:416.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.4.1.10`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.4.3.17`,
        fs:  `cpe:2.3:a:apple:safari:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.4.5.7`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.4.7.3`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5`,
        fs:  `cpe:2.3:h:hp:jc613a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5%289%29`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:8.0.50.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.1.7`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.3.1`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.5.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.7.7`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.9.9`,
        fs:  `cpe:2.3:a:security_questions_project:security_questions:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.11.2`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:r55w:hfa1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.13.7`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.15.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.17`,
        fs:  `cpe:2.3:a:scudetto_project:scudetto:2.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.19`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.21`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.23`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.25`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.27`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.29`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.29.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)bc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_and_content_networking_system_software:5.5.31`,
        fs:  `cpe:2.3:h:huawei:s5700:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a1%287%29`,
        fs:  `cpe:2.3:o:juniper:junos:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a1%287a%29`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a1%287b%29`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a1%288%29`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a1%288a%29`,
        fs:  `cpe:2.3:a:redhat:kdelibs_devel:3.0.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a3%281.0%29`,
        fs:  `cpe:2.3:o:bluecoat:cacheos_sa:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a3%282.1%29`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a3%282.2%29`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a3%282.3%29`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a3%282.4%29`,
        fs:  `cpe:2.3:a:open-emr:openemr:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a3%282.5%29`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a3%282.6%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.0sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a3%282.7%29`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:9.2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a4%281.0%29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a4%281.1%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)xq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a4%282.0%29`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a4%282.1%29`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a4%282.2%29`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5580_firmware:v29.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a4%282.3%29`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta57:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a5%281.0%29`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a5%281.1%29`,
        fs:  `cpe:2.3:a:apache:cxf:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a5%281.2%29`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a5%282.0%29`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a5%282.1%29`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a5%282.1e%29`,
        fs:  `cpe:2.3:a:apple:apple_tv:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_control_engine_software:a5%283.0%29`,
        fs:  `cpe:2.3:a:buffalotech:whr-g54s_firmware:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_networking_manager:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller:1.0%281e%29`,
        fs:  `cpe:2.3:a:cisco:as5200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller:1.0%281h%29`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.0.1198:unknown:online_windows_2000:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller:1.0%281k%29`,
        fs:  `cpe:2.3:a:ibm:egatherer:2.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller:1.0%281n%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller:1.0%282j%29`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:01-01-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller:1.0%282m%29`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller:1.0%283f%29`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller:1.1%280.920a%29`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller_enterprise_module:1.0.%281%29`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller_enterprise_module:1.0.10`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller_enterprise_module:1.0_ga`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_policy_infrastructure_controller_enterprise_module:1.1_base`,
        fs:  `cpe:2.3:a:watch4net:apg:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_velocity_system:-`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:application_velocity_system:5.0.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:application_velocity_system_3110:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:application_velocity_system_3110:4.0`,
        fs:  `cpe:2.3:a:jesse_vincent:extension\:\:mobileui:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:application_velocity_system_3110:5.0`,
        fs:  `cpe:2.3:h:siemens:santis_50:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:application_velocity_system_3120:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:application_velocity_system_3120:5.0`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7940:8.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:application_velocity_system_3180:-`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_cluster_suite:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:application_velocity_system_3180a:-`,
        fs:  `cpe:2.3:a:microsoft:forefront_client_security:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:arrowpoint:-`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:98:scd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:as5200:-`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.84.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:as5200:-`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.1.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:as5300:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:as5350:-`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:as5350:12.2%2811t%29`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:as5400_universal_gateway:-`,
        fs:  `cpe:2.3:a:embarcadero:dbartisan:8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:as5400hpx_universal_gateway:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.487.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:as5400xm_media_gateway:-`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:as5400xm_universal_gateway:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:0.082:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:as5800:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_1000v_cloud_firewall:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500:-`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500:6.3`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500:7.0`,
        fs:  `cpe:2.3:a:bean_project:bean:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500:7.0%284%29`,
        fs:  `cpe:2.3:a:google:v8:3.23.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500:7.0.4.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500:7.1`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500:7.2`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500:7.2%282%29`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_5500-x_series_ips_ssp_software:7.1`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5500_csc-ssm:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_5500_csc-ssm_firmware:6.6.1125.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_5585-x:-`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asa_aip_security_services_module:-`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.0.1`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.3.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.0.1-40`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.0.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.11.030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.0.2-68`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.49a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.0_base`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.5:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.1.2-29`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.1.2-42`,
        fs:  `cpe:2.3:a:splunk:splunk:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.1.3-8`,
        fs:  `cpe:2.3:h:ibm:system_x_idataplex_dx360_m2_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.1.3-10`,
        fs:  `cpe:2.3:a:clamav:clamav:0.92.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.1.3-13`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.2.1-1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.2.1-2`,
        fs:  `cpe:2.3:a:activestate:komodo_edit:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.2.1-3`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.2.1-4`,
        fs:  `cpe:2.3:h:perle:jetstream_serial_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.2.2-1`,
        fs:  `cpe:2.3:a:menalto:gallery:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3%281.1.112%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.4ya:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.1-1`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.2-1`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.3.1-13`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.4-1`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.4-2`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:0.97.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.4-3`,
        fs:  `cpe:2.3:h:hp:jf235a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.4-4`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.1.9139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.4-5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3.4-6`,
        fs:  `cpe:2.3:a:citrix:access_management_console_report_center:4.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_cx_context-aware_security_software:9.3_base`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p411:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_with_firepower_services:5.3.1`,
        fs:  `cpe:2.3:a:ca:embedded_entitlements_manager:8.4.406:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_with_firepower_services:5.3.1.1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asa_with_firepower_services:5.4.0`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:5.4.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)yu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:5.4.0.1`,
        fs:  `cpe:2.3:a:vmware:capacity_planner:2.6.2.22938:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:5.4.0.2`,
        fs:  `cpe:2.3:o:windriver:bsdos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:5.4.0.3`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:5.4.0.4`,
        fs:  `cpe:2.3:a:hp:http_communication:6.10.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:5.4.0.5`,
        fs:  `cpe:2.3:a:xangati:xangati_software_release:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:5.4.0.6`,
        fs:  `cpe:2.3:a:microsoft:powerpoint_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:6.0.0`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asa_with_firepower_services:6.0.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xh2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1001:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1001-x:-`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.6p4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1001_router:-`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1002:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1002-x:-`,
        fs:  `cpe:2.3:a:packetfence:packetfence:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1002-x_router:-`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1002_fixed_router:-`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1002_router:-`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1004:-`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1004_router:-`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.90:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1006:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1006_router:-`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.5:sp0b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1013:-`,
        fs:  `cpe:2.3:a:netiq:privileged_user_manager:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1013_router:-`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_1023_router:-`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.9:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_5000:-`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.150.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:-`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:15.0%28912%29`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:15.0%28935%29`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:15.0%28938%29`,
        fs:  `cpe:2.3:a:hp:alm_synchronizer:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:16.5.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:17.2.0.59184`,
        fs:  `cpe:2.3:a:qlogic:sansurfer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:17.7.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:18.0.l059219`,
        fs:  `cpe:2.3:a:php:php:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:18.4.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:19.0.1`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:19.3.0`,
        fs:  `cpe:2.3:a:sun:openoffice.org_installer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_series_software:20.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:17.2.0`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.4.3820.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:17.2.0.59184`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:17.3.1`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller:1.0\(3f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:17.7.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.0.0.57828`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.0.0.59167`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr1604hf-u-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.0.0.59211`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.3.2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.0.l0.59219`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.1.0`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.1.0.59776`,
        fs:  `cpe:2.3:a:yysun:git_source_control_provider:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.1.0.59780`,
        fs:  `cpe:2.3:a:apache:camel:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.1_base`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.3.0`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.3_base`,
        fs:  `cpe:2.3:a:php:php:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:18.4.0`,
        fs:  `cpe:2.3:a:artifex:ghostscript_fonts:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:19.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:19.0.m0.60828`,
        fs:  `cpe:2.3:a:iwcn:stark_crm:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:19.0.m0.61045`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.10.186:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:19.1.0`,
        fs:  `cpe:2.3:a:sgi:propack:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:19.3.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:asr_5000_software:20.0.0`,
        fs:  `cpe:2.3:a:ca:inoculateit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_5500:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.341:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_5700:-`,
        fs:  `cpe:2.3:a:combodo:itop:1.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_9000_rsp440_router:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.453.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_9001:-`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix:20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_9006:-`,
        fs:  `cpe:2.3:a:opnet:sp_guru_network_planner_documentation:16.0.0.10353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_9010:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(18\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_9904:-`,
        fs:  `cpe:2.3:h:hp:jetdirect_310x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_9912:-`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:asr_9922:-`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asyncos:-`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:asyncos:9.7.0-125`,
        fs:  `cpe:2.3:a:cisco:ciscosecure_acs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ata-186:-`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:b200_m3:-`,
        fs:  `cpe:2.3:a:phppgadmin_project:phppgadmin:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:b200_m4:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)sy3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:b22_m3:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:b230_m2:-`,
        fs:  `cpe:2.3:a:lxml:lxml:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:b260_m4:-`,
        fs:  `cpe:2.3:a:snort:snort:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:b420_m3:-`,
        fs:  `cpe:2.3:a:opensolution:quick.cms.lite:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:b440_m2:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:b460_m4:-`,
        fs:  `cpe:2.3:a:exim:exim:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:backup_and_restore_system:4.0.14000`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:bams:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:bpx_switch:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:br:-`,
        fs:  `cpe:2.3:o:sun:solaris:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:broadband_access_center_telco_wireless_software:-`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:broadband_access_center_telco_wireless_software:3.8.0.1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:broadband_operating_system:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:broadband_operating_system:2.3.8`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.0:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:broadband_operating_system:2.4.1`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:building_broadband_service_manager:-`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:6.26.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:building_broadband_service_manager:5.0`,
        fs:  `cpe:2.3:a:apache:solr:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:business_edition_3000:-`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_3000_software:8.6%281%29`,
        fs:  `cpe:2.3:a:novell:zenworks_remote_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_3000_software:8.6%281a%29`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_3000_software:8.6%282a%29`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_xi:r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_3000_software:8.6.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_3000_software:8.6.3`,
        fs:  `cpe:2.3:a:openssh:openssh:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:business_edition_5000:-`,
        fs:  `cpe:2.3:a:tradehero:tradehero:2.2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_5000_software:8.5`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_5000_software:8.5%281%29`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_direct_user_interface:1.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_5000_software:8.6`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_5000_software:8.6%281%29`,
        fs:  `cpe:2.3:a:apache:camel:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_5000_software:8.6%281a%29`,
        fs:  `cpe:2.3:a:mozilla:mozilla_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_5000_software:8.6%282%29`,
        fs:  `cpe:2.3:a:novell:web_search:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_5000_software:8.6%282a%29`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.3:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_5000_software:8.6%282a%29su1`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:business_edition_6000:-`,
        fs:  `cpe:2.3:o:fortinet:fortiadc_firmware:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.5%281%29`,
        fs:  `cpe:2.3:a:dell:edoc_viewer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.5%281%29su1`,
        fs:  `cpe:2.3:a:xmltooling_project:xmltooling:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.5%281%29su2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.5%281%29su3`,
        fs:  `cpe:2.3:a:roxio:central_data:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.5%281-2011o%29`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.6%281%29`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.6%281a%29`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.6%282%29`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.5:p1-beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.6%282a%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:business_edition_6000_software:8.6%282a%29su1`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2:rc_2a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c1721:-`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c200_m1:-`,
        fs:  `cpe:2.3:a:copadata:zenon_dnp3_ng_driver:7.11:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c200_m2:-`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c210_m2:-`,
        fs:  `cpe:2.3:a:bluecoat:proxysg_va-20:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c22_m3:-`,
        fs:  `cpe:2.3:a:drupal:drupal:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c220_m3:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c220_m4:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c24_m3:-`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c240_m3:-`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_server:6.0_build_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c240_m4:-`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c250_m1:-`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c250_m2:-`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnitouch_8660_my_teamwork:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c260_m2:-`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_2421:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c3160:-`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c3640:-`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c420_m2:-`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c420_m3:-`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.4:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c4500m:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c460_m1:-`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c460_m2:-`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c460_m4:-`,
        fs:  `cpe:2.3:a:drupal:drupal:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c5000rsm:-`,
        fs:  `cpe:2.3:a:web2py:web2py:1.79.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:c881w_integrated_services_router:-`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cable_router:-`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_505:-`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:16.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_505:2.2.0`,
        fs:  `cpe:2.3:a:condor_project:condor:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_505:2.4.0`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_505:3.0`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_505:3.0.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_505:4.0.0`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_505:4.1.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.5:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_550:-`,
        fs:  `cpe:2.3:a:moxa:oncell_central_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_550:2.2.0`,
        fs:  `cpe:2.3:h:3com:3c39024-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_550:2.4.0`,
        fs:  `cpe:2.3:a:radware:fireproof:2.20.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_550:3.0`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:-`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:2.2.0`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:2.2.0.0`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:2.4.0`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:3.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:3.0.0`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.10:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:4.0.0`,
        fs:  `cpe:2.3:o:mandriva:linux:2008.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:4.1.0`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.3054:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cache_engine_570:570`,
        fs:  `cpe:2.3:h:hp:c2s11a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:-`,
        fs:  `cpe:2.3:a:gentoo:xnview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:1.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.8.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:2.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.0`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.1`,
        fs:  `cpe:2.3:a:novell:sentinel_log_manager:1.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.1%282%29`,
        fs:  `cpe:2.3:a:apple:itunes:4.7.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.1%283a%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.2`,
        fs:  `cpe:2.3:a:emc:avamar_plugin:6.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%283%29`,
        fs:  `cpe:2.3:a:ca:brightstor_storage_resource_manager:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%283%29es61`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%284%29es25`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%285%29`,
        fs:  `cpe:2.3:a:persits:xupload:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%285%29es30`,
        fs:  `cpe:2.3:a:tenable:web_ui:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%285%29sr1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%285%29sr2`,
        fs:  `cpe:2.3:a:apple:safari:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%285%29sr2a`,
        fs:  `cpe:2.3:a:mozilla:firefox:22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:3.3%285%29sr2b`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.0%282a%29es40`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2007-06-26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.0%282a%29es62`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:4.0.0.4000:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.0%282a%29sr2b`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1%282%29es33`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1%282%29es55`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1%283%29es07`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.098:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1%283%29es32`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1%283%29sr1`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1%283%29sr2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p206:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1%283%29sr3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.1%283%29sr4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.2%281%29`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.2%282%29`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0591:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.2%283%29`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.2%283%29sr1`,
        fs:  `cpe:2.3:a:devicelock:devicelock:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.2%283%29sr2`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.3`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.1.1.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.3%281%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.191:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:4.3%281%29sr1`,
        fs:  `cpe:2.3:a:rubyonrails:html_sanitizer:1.0.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:call_manager:5.1.1.3000`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:callmanager_express:-`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:callmanager_express:3.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.2.3`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.1.30214.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.2.4`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.2.6`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.3.0`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.3.1`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.3.2`,
        fs:  `cpe:2.3:a:oracle:agile_engineering_data_management:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.3.4`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.0d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.3.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.4.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.18:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.4.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.7.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.4.2`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.4.3`,
        fs:  `cpe:2.3:a:debian:adequate:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.5.2`,
        fs:  `cpe:2.3:h:advantech:eki-1362:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.5.3`,
        fs:  `cpe:2.3:a:markus_blaschke:tq_seo:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.5.4`,
        fs:  `cpe:2.3:a:alvaro_herrera:pl\/php:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.6.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.0.878:online_windows_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.6.2`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.6.3`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.7.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.7.1`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.8.0`,
        fs:  `cpe:2.3:h:lucent:access_point_service_router_300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.8.1`,
        fs:  `cpe:2.3:a:webmin:usermin:1.440:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.8.2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.8.3`,
        fs:  `cpe:2.3:a:intervideo:home_theater:2.5.13.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.8.4`,
        fs:  `cpe:2.3:a:perl:pathtools:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.9.0`,
        fs:  `cpe:2.3:a:gnu:radius:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.9.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p149:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.9.2`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.5.1052.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:3.9.3`,
        fs:  `cpe:2.3:a:apple:xcode:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:4.0.0`,
        fs:  `cpe:2.3:h:qnap:ts-459u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:4.0.1`,
        fs:  `cpe:2.3:a:zope:zope:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:4.0.3`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2003:-:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:4.0.4`,
        fs:  `cpe:2.3:a:combodo:itop:1.2.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:4.1.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:4.1.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.772.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:4.1.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:5.1.3`,
        fs:  `cpe:2.3:a:apple:cups:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:5.1.4`,
        fs:  `cpe:2.3:a:atmail:atmail:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:carrier_routing_system:5.1_base`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_12xx_supervisor_software:-`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_12xx_supervisor_software:4.29`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2820:-`,
        fs:  `cpe:2.3:a:jurpo:jurpopage:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2820:9.0_0.07`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2900:-`,
        fs:  `cpe:2.3:a:gajim:gajim:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2900:lre_xl`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2900:xl`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.701:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2900_vlan:-`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2900xl:-`,
        fs:  `cpe:2.3:a:realflex:realwindemo:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2901:-`,
        fs:  `cpe:2.3:a:app_maker_ks:buy_books:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2902:-`,
        fs:  `cpe:2.3:a:dell:openmanage:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2920:-`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2926:-`,
        fs:  `cpe:2.3:a:nokia:intellisync_wireless_email_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2926f:-`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:004sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2926gl:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sq.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2926gs:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tc4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2926t:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.08.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2940:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)ea2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2948:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2948-ge-tx:-`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2948g:-`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2948g-l3:-`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2950:-`,
        fs:  `cpe:2.3:a:honeywell:enterprise_buildings_integrator:r410.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2950_lre:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ys:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2955:-`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2970:-`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2980g:-`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.152.25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_2980g-a:-`,
        fs:  `cpe:2.3:h:crossbeamsystems:x80:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_29xx_supervisor_software:-`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.5.1:-:-:en-us:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_29xx_supervisor_software:1.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2_1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_29xx_supervisor_software:2.1.5`,
        fs:  `cpe:2.3:a:adobe:fonts_all:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_29xx_supervisor_software:2.1.501`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_29xx_supervisor_software:2.1.502`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3000:-`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110727:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3200:-`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3500:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p115:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3500_xl:-`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_server:3.6:ecd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3500xl:-`,
        fs:  `cpe:2.3:a:redaxo:redaxo:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3550:-`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3560:-`,
        fs:  `cpe:2.3:a:oracle:api_gateway:11.1.2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3560-e:-`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3560-x:-`,
        fs:  `cpe:2.3:a:tabtale:enchanted_fashion_crush:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3750:-`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3750-e:-`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3750-x:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3750_metro:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3750g:-`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_3900:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4000:-`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4200:-`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4224:-`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4232:-`,
        fs:  `cpe:2.3:a:sap:businessobjects_explorer:14.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4232-13:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4500:-`,
        fs:  `cpe:2.3:a:samba:samba:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4503:-`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4503-e:-`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4506:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4506-e:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.1.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4507r:-`,
        fs:  `cpe:2.3:a:git-scm:git:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4507r%2be:-`,
        fs:  `cpe:2.3:a:pearson:esis_enterprise_student_information_system:3.3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4507r-e:-`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.8:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4510r:-`,
        fs:  `cpe:2.3:a:pcre:pcre:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4510r%2be:-`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4510r-e:-`,
        fs:  `cpe:2.3:a:mohachat:moha_chat:0.1b7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4840g:-`,
        fs:  `cpe:2.3:a:gnome:evolution:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4908g-l3:-`,
        fs:  `cpe:2.3:a:ibm:rational_system_architect_suite:11.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4912g:-`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_4948:-`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_5000:-`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_5500:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_5505:-`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_5509:-`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_5xxx_supervisor_software:-`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.135.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_5xxx_supervisor_software:1.0`,
        fs:  `cpe:2.3:a:divx:converter:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_5xxx_supervisor_software:2.1.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.68.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_5xxx_supervisor_software:2.1.501`,
        fs:  `cpe:2.3:o:cisco:ios:12.2so:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_5xxx_supervisor_software:2.1.502`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6000:-`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.1_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:catalyst_6000_intrusion_detection_system_module:-`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6000_ws-svc-nam-1:2.2%281a%29`,
        fs:  `cpe:2.3:a:coupons:coupon_printer_for_windows:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6000_ws-svc-nam-1:3.1%281a%29`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6000_ws-svc-nam-2:2.2%281a%29`,
        fs:  `cpe:2.3:o:freebsd:freebsd:9.2:prerelease:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6000_ws-svc-nam-2:3.1%281a%29`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6000_ws-x6380-nam:2.1%282%29`,
        fs:  `cpe:2.3:h:htc:sensation_z710e:gri40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6000_ws-x6380-nam:3.1%281a%29`,
        fs:  `cpe:2.3:a:google:chrome:42.0.2311.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6500:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6500_ws-svc-nam-1:2.2%281a%29`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6500_ws-svc-nam-1:3.1%281a%29`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6500_ws-svc-nam-2:2.2%281a%29`,
        fs:  `cpe:2.3:h:linksys:wag200g:1.01.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6500_ws-svc-nam-2:3.1%281a%29`,
        fs:  `cpe:2.3:a:oracle:database_server:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6500_ws-x6380-nam:2.1%282%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6500_ws-x6380-nam:3.1%281a%29`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6503-e:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6504-e:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6506-e:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6509-e:-`,
        fs:  `cpe:2.3:a:gnu:emacs:20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6509-neb-a:-`,
        fs:  `cpe:2.3:a:aimluck:aipo:5.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6509-v-e:-`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6513:-`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62r:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6513-e:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6608:-`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.6.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_6624:-`,
        fs:  `cpe:2.3:h:cisco:4402_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_7600:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_7600_ws-svc-nam-1:2.2%281a%29`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_7600_ws-svc-nam-1:3.1%281a%29`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_7600_ws-svc-nam-2:2.2%281a%29`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144n_firmware:1.46:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_7600_ws-svc-nam-2:3.1%281a%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.299:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_7600_ws-x6380-nam:2.1%282%29`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_7600_ws-x6380-nam:3.1%281a%29`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-28c-pwr-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_8500:-`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_8510csr:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.674.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_8510msr:-`,
        fs:  `cpe:2.3:a:vodafone:vodafone_avantaj_cepte:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_8540csr:-`,
        fs:  `cpe:2.3:a:mistelix:mistelix:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_8540msr:-`,
        fs:  `cpe:2.3:a:gnu:screen:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:catalyst_ws-c2924-xl:-`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:-`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%281%29`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%282%29`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%283%29`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%284%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%285%29`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%286%29`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%287%29`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%288%29`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%289%29`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.56:devel:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%2810%29`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%2811%29`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.1%2812%29`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.2%281%29`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.2%282%29`,
        fs:  `cpe:2.3:a:bareftp:bareftp:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.3%281%29`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.4%281%29`,
        fs:  `cpe:2.3:a:google:chrome:9.0.587.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.4%282%29`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.4%283%29`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.4%284%29`,
        fs:  `cpe:2.3:a:gnu:emacs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.4%285%29`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:2.4%285a%29`,
        fs:  `cpe:2.3:a:google:chrome:5.0.321.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.0%287%29`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.1%281%29`,
        fs:  `cpe:2.3:a:hp:solution_center_and_imaging_support_tools:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.1%282%29`,
        fs:  `cpe:2.3:a:lexmark:markvision_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.1%282a%29`,
        fs:  `cpe:2.3:a:php:bloq:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%281%29`,
        fs:  `cpe:2.3:a:oxide_project:oxide:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%281b%29`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%282%29`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%283%29`,
        fs:  `cpe:2.3:a:nttdata:terasoluna_server_framework_for_java_web:2.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%284%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%285%29`,
        fs:  `cpe:2.3:a:nessoft:multiping:2.10.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%286%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%287%29`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:3.2%288%29gdr`,
        fs:  `cpe:2.3:h:huawei:ar_g3:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.1%281%29`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.1%282%29`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.1%283%29`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.2%281%29`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.2%282%29`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.3%281a%29`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.4%281%29`,
        fs:  `cpe:2.3:a:fortinet:forticlient:-:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%281%29`,
        fs:  `cpe:2.3:a:emc:networker:8.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%282%29`,
        fs:  `cpe:2.3:a:mollify:mollify:1.6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%283%29`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%284%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%284b%29`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%285%29`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%286%29`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%286a%29`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%287%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(55\)se7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%288%29`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%289%29`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%2810%29`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%2811%29`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%2812%29`,
        fs:  `cpe:2.3:a:suse:suse_sled_beagle:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%2812a%29`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%2813%29`,
        fs:  `cpe:2.3:a:altiris:carbon_copy:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%2813a%29`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5%2814%29`,
        fs:  `cpe:2.3:h:korenix:jetport:5601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:4.5.10`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.1`,
        fs:  `cpe:2.3:h:hp:jd667a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.1%281%29`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.1%281%29csx`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.1%281a%29`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.1%281a%29csx`,
        fs:  `cpe:2.3:a:tryton:trytond:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.1%282a%29`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.1%282b%29`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2`,
        fs:  `cpe:2.3:a:skype:skype:5.1.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%281%29`,
        fs:  `cpe:2.3:a:opsview:opsview:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%281%29csx`,
        fs:  `cpe:2.3:h:xerox:workcentre_32_color:01.00.060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%281a%29`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%282%29`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.9:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%282%29csx`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%283%29`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%283%29csx`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%283a%29csx`,
        fs:  `cpe:2.3:a:openpkg:openpkg:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%284%29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%285%29`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_access:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%286%29`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%287%29`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.2%287a%29`,
        fs:  `cpe:2.3:a:thycotic:secret_server:8.6.000010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%281%29csx`,
        fs:  `cpe:2.3:a:gnu:gdb:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%281a%29csx`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%282%29csx`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%283%29csx`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%284%29csx`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%285%29csx`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%285a%29csx`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%286%29csx`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.9.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.3%286a%29csx`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.4`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.7.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.4%281%29`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.2\(2h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.4%281%29deferred`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.4%282%29`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.4%282a%29`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.4%283%29`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.4%284%29`,
        fs:  `cpe:2.3:a:koyotesoft:free_easy_burner:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.4%284a%29`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5`,
        fs:  `cpe:2.3:a:google:chrome:48.0.2564.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%281%29`,
        fs:  `cpe:2.3:h:cisco:c220_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%281a%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%282%29`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%283%29`,
        fs:  `cpe:2.3:a:opensis:opensis:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%284%29`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%284a%29`,
        fs:  `cpe:2.3:a:telos:xacta_hostinfo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%284b%29`,
        fs:  `cpe:2.3:o:netgear:d3600_firmware:1.0.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%285%29`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%286%29`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%286a%29`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%287%29`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%287a%29`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%288%29`,
        fs:  `cpe:2.3:a:netiq:security_manager:6.5.3.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%288a%29`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%288a%29cv`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%289%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2810%29`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2810a%29`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2811%29`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2811a%29`,
        fs:  `cpe:2.3:a:cisco:ssl_vpn_client:1.1.4.179:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2812%29`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-181_with_network_printer_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2812a%29`,
        fs:  `cpe:2.3:a:php:php:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2813%29`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2813.5%29`,
        fs:  `cpe:2.3:a:bsalsa:embeddedwb:14.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2813a%29`,
        fs:  `cpe:2.3:a:winzip:winzip:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2814%29`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2815%29`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2816%29`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_server:6.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2816.2%29`,
        fs:  `cpe:2.3:a:rpm:rpm:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2817%29`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-72-\/e:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2818%29`,
        fs:  `cpe:2.3:a:drupal:drupal:6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:5.5%2819%29`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.1.887:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%281%29`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%281a%29`,
        fs:  `cpe:2.3:o:juniper:junos:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%281b%29`,
        fs:  `cpe:2.3:a:sendmail:multi_switch:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%281c%29`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%281d%29`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%281e%29`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%282%29`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%282.13%29`,
        fs:  `cpe:2.3:a:tenable:nessus:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%282a%29`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%283%29`,
        fs:  `cpe:2.3:a:evernote:evernote:4.5.1.5432:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%283a%29`,
        fs:  `cpe:2.3:a:oracle:database_server:11.1.0.6.0:enterprise:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%284%29`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:3.4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1%284b%29`,
        fs:  `cpe:2.3:a:microsoft:sql_server_desktop_engine:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.1.2`,
        fs:  `cpe:2.3:a:ntp:ntp:p94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2%280.110%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2%280.111%29`,
        fs:  `cpe:2.3:a:oracle:opensso_enterprise:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2%281%29`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2%281a%29`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2%282%29`,
        fs:  `cpe:2.3:a:x:libxrandr:1.2.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2%282a%29`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2%283%29`,
        fs:  `cpe:2.3:a:cisco:meeting_manager_for_internet_explorer:7.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.2%283a%29`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3`,
        fs:  `cpe:2.3:a:trillian:trillian:0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%280.7%29pan`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%281%29`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%281a%29`,
        fs:  `cpe:2.3:h:cisco:sg300-10p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%282%29`,
        fs:  `cpe:2.3:a:microsoft:asp.net:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%282a%29`,
        fs:  `cpe:2.3:a:hp:print_screen_utility:5.40.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%283%29`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%283%29x`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%283%29x1`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%283a%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%284%29`,
        fs:  `cpe:2.3:a:1024cms:1024_cms:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%284a%29`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%285%29`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%285.10%29`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%286%29`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%287%29`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%288%29`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%288.3%29`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%289%29`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.3%2810%29`,
        fs:  `cpe:2.3:h:hp:laserjet_4240:q7785a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4`,
        fs:  `cpe:2.3:a:vmware:capacityiq:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4%281%29`,
        fs:  `cpe:2.3:a:mozilla:firefox:20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4%282%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4%283%29`,
        fs:  `cpe:2.3:a:tigo:tigo_copa_mundial_fifa_2014:3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4%284a%29`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.4\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4%285%29`,
        fs:  `cpe:2.3:a:collectivecolors:taxonomy_view_integrator_module:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4%286%29`,
        fs:  `cpe:2.3:a:prettybook:prettyformmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4%287%29`,
        fs:  `cpe:2.3:a:kryo:iodine:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:6.4%288%29`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.1%281%29`,
        fs:  `cpe:2.3:a:yahoo:messenger:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.1%281a%29`,
        fs:  `cpe:2.3:a:samba:samba:4.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.1%282%29`,
        fs:  `cpe:2.3:a:ssh:ssh2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.1%282a%29`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.2%280.65%29`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.2%281%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.17.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.2%282%29`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_sametime:8.0.80407:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.3`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.3%281%29`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.3%282%29`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.4`,
        fs:  `cpe:2.3:a:winzip:winzip:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.4%280.2%29clr`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:3.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.4%280.63%29`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.4%281%29`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.4%282%29`,
        fs:  `cpe:2.3:a:tenable:nessus:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.4%283%29`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2009.113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.5`,
        fs:  `cpe:2.3:a:ibm:websphere_extended_deployment_compute_grid:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.5%281%29`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.6`,
        fs:  `cpe:2.3:a:sun:cluster:3.1:4_04:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.6%281%29`,
        fs:  `cpe:2.3:a:google:chrome:4.0.259.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.6%282%29`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.6%283%29`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.6%284%29`,
        fs:  `cpe:2.3:a:click2sell:click2sell_suite_module:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.6%285%29`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:7.6%286%29`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.22:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.1%282%29`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.1%283%29`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.2%281%29`,
        fs:  `cpe:2.3:a:libraw:libraw:0.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.2%281%29glx`,
        fs:  `cpe:2.3:a:kodak:image_viewer:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.3`,
        fs:  `cpe:2.3:a:att:communication_manager:7.02.0610.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.3%281%29glx`,
        fs:  `cpe:2.3:a:novell:zenworks_endpoint_security_management:3.5.0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.3glx`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.480.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.4`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.4%282%29glx`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:catos:8.5`,
        fs:  `cpe:2.3:a:nobexrc:joint_radio_blues:3.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cg-os:cg4`,
        fs:  `cpe:2.3:a:codiad:codiad:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cg-os:cg4%281%29`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cg-os:cg4%282%29`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cg-os:cg4%283%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cgr_1120:-`,
        fs:  `cpe:2.3:a:dave_thomas:rdoc:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cgr_1240:-`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cisco_nexus_1000v_intercloud:5.2%281%29ic1%281.2%29::~~~vmware~~`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cisco_ons_15454_system_software:9.0`,
        fs:  `cpe:2.3:a:samedia:landshop:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cisco_ons_15454_system_software:9.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cisco_ons_15454_system_software:9.2`,
        fs:  `cpe:2.3:a:isc:inn:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cisco_ons_15454_system_software:9.2.1`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cisco_ons_15454_system_software:9.2.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cisco_ons_15454_system_software:9.3`,
        fs:  `cpe:2.3:a:x:libxrandr:1.2.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cisco_ons_15454_system_software:9.4`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:cisco_ons_15454_system_software:9.6`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cisco_policy_suite:7.0.1.3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cisco_policy_suite:7.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cisco_policy_suite:7.0.2-att`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cisco_policy_suite:7.0.3-att`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cisco_policy_suite:7.0.4-att`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cisco_policy_suite:7.0.5`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cisco_technical_support:3.7.1::~~~android~~`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscosecure_acs:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks:-`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ciscoworks_1105_hosting_solution_engine:-`,
        fs:  `cpe:2.3:a:mysql:community_server:5.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ciscoworks_1105_wireless_lan_solution_engine:-`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20010610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_2000_service_management_solution:-`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_access_control_list_manager:-`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_access_control_list_manager:1.5`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_access_control_list_manager:1.6`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_management_foundation:-`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_management_foundation:2.0`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_management_foundation:2.1`,
        fs:  `cpe:2.3:h:foundrynet:bigiron_4000_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_management_foundation:2.2`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:-`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:1.0`,
        fs:  `cpe:2.3:a:gajennings:this:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:2.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.0.3`,
        fs:  `cpe:2.3:a:sunil_nanda:blue_wrench_video_widget:1.0.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.0.4`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.0.5`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.1:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.0.6`,
        fs:  `cpe:2.3:a:hp:productcontext:50.0.206.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.1`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.50.5145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.1.1`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.2`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:3.3`,
        fs:  `cpe:2.3:a:adobe:after_effects:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:4.0`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_common_services:4.0.1`,
        fs:  `cpe:2.3:h:ovislink:airlive_od-2060hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_lan_management_solution:2.6:update`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_lan_management_solution:3.0`,
        fs:  `cpe:2.3:a:redhat:openshift:2.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_lan_management_solution:3.0:december_2007`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_lan_management_solution:3.1`,
        fs:  `cpe:2.3:a:krisonav:krisonav:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_lan_management_solution:3.2`,
        fs:  `cpe:2.3:a:ibm:java:5.0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_lms:-`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:021:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_lms:1.3`,
        fs:  `cpe:2.3:a:marked_project:marked:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_management_center_for_ids_sensors:-`,
        fs:  `cpe:2.3:a:plone:plone:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_management_center_for_ids_sensors:2.0`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_management_center_for_ids_sensors:2.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_management_center_for_ips_sensors:-`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_management_center_for_ips_sensors:2.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.621.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_monitoring_center_for_security:-`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:4.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_monitoring_center_for_security:1.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_monitoring_center_for_security:2.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_monitoring_center_for_security:2.1`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_network_compliance_manager:7.50.0.0`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:11.2.202.559:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_server:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)seb3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_server:2.6`,
        fs:  `cpe:2.3:a:serf_project:serf:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_user_tracking_utility:1.1`,
        fs:  `cpe:2.3:o:siemens:apogee_insight:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_user_tracking_utility:1.1.1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_vpn_security_management_solution:-`,
        fs:  `cpe:2.3:a:google:chrome:13.0.781.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ciscoworks_windows:-`,
        fs:  `cpe:2.3:a:emc:avamar:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ciscoworks_windows_wug:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)ea:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cius:-`,
        fs:  `cpe:2.3:a:sun:jre:1.3.0:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cius:7-at-k9`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cius:7-k9`,
        fs:  `cpe:2.3:a:adobe:creative_suite_4_master_collection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cius_software:9.2`,
        fs:  `cpe:2.3:a:pocketmags:outdoor_design_and_living:\@7f080181:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cius_software:9.2%281%29`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cius_software:9.2%281%29sr1`,
        fs:  `cpe:2.3:a:apple:apple_application_support:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cius_software:9.2%281%29sr2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cius_software:9.2%282%29`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cius_software:9.2%282%29at`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_redundant_controller_firmware:20.055:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:clean_access:-`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3`,
        fs:  `cpe:2.3:a:smarttech:smart_notebook:10.6.94.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s_3.3.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.3`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.4`,
        fs:  `cpe:2.3:a:apache:httpclient:4.2:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.5`,
        fs:  `cpe:2.3:a:iss:realsecure_server_sensor:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.6`,
        fs:  `cpe:2.3:o:oneplus:oxygenos:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.7`,
        fs:  `cpe:2.3:o:cisco:spa300_firmware:7.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.8`,
        fs:  `cpe:2.3:a:intel:network_connections:13.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.3.9`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.4`,
        fs:  `cpe:2.3:a:analogx:proxy:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.4.1`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.4.2`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_81:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.4.3`,
        fs:  `cpe:2.3:a:libpng:libpng:0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.4.4`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.4.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.39.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.5`,
        fs:  `cpe:2.3:a:ca:etrust_secure_content_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.5%289%29`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.5.1`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:4.0:unknown:unknown:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.5.2`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.5.3`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6cca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.5.4`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.5.5`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.5.9`,
        fs:  `cpe:2.3:a:sparxsystems:enterprise_architect:7.0.817:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.6.0.1`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.6.1.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:3.6.4.0.1`,
        fs:  `cpe:2.3:a:quest:toad_for_data_analysts:2.7.0.348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:clean_access:4.0.4.2`,
        fs:  `cpe:2.3:a:gnome:gdk-pixbuf:2.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:clean_access_agent:4.5.0.0`,
        fs:  `cpe:2.3:a:zencast:zencast:1.02.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:clean_access_agent_stub:4.1.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_network_automation_provisioner:1.0%280%29`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:-`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.64:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:9.1:sp1`,
        fs:  `cpe:2.3:a:ca:etrust_siteminder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:9.1:sp2`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:9.1:sp3`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:9.3`,
        fs:  `cpe:2.3:a:apache:openoffice.org:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:9.3.1`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:9.3.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30392:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:9.4`,
        fs:  `cpe:2.3:a:e2fsprogs_project:e2fsprogs:1.42.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:9.4.1`,
        fs:  `cpe:2.3:a:python:python:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:2008.3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:2008.3:sp6`,
        fs:  `cpe:2.3:a:symantec:endpoint_encryption:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:2008.3:sp7`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:2008.3:sp8`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloud_portal:2008.3:sp9`,
        fs:  `cpe:2.3:a:hp:software_deployment:6.20.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloudcenter_orchestrator:4.4.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloudcenter_orchestrator:4.5.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.106.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloudcenter_orchestrator:4.6.0`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cloudcenter_orchestrator:4.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:-`,
        fs:  `cpe:2.3:h:hp:jd657a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0.1`,
        fs:  `cpe:2.3:a:nero:disc_copy_gadget:1.53.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0.2`,
        fs:  `cpe:2.3:a:tsutaya:tsutaya:5.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0.3`,
        fs:  `cpe:2.3:a:google:v8:5.2.360:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0.5`,
        fs:  `cpe:2.3:a:arellia:arellia_application_control_language_pack:6.1.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0.5.2`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0.5.3`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.0.5.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.8.0\(160\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.1`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.1.1`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.1.1.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_hosted:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.1.1.2`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:6.1.1.3`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:cns_network_registrar:7.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.11:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:conference_connection:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p138:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:conference_connection:1.1%281%29`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:conference_connection:1.2`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:connected_grid_network_management_system:3.0%280.35%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:connected_grid_network_management_system:3.0%280.54%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:connected_streaming_analytics:1.1.1_base`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.12.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_distribution_manager:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_distribution_manager_4630:-`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_distribution_manager_4630:4.0`,
        fs:  `cpe:2.3:h:supermicro:h8scm-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_distribution_manager_4630:4.1`,
        fs:  `cpe:2.3:a:stage_file_proxy_project:stage_file_proxy:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_distribution_manager_4650:-`,
        fs:  `cpe:2.3:o:iodata:ts-wlcam\/v_camera_firmware:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_distribution_manager_4650:4.0`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_distribution_manager_4650:4.1`,
        fs:  `cpe:2.3:a:nmap:nmap:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_distribution_manager_4670:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_router_4430:-`,
        fs:  `cpe:2.3:a:redhat:freeipa:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:content_router_4430:4.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.3\(3.109\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:content_router_4430:4.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_router_4450:-`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_security_management_appliance:-`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.23_host_agent_files:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_security_management_appliance:8.3.6-039`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:12.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_security_management_appliance:9.1.0-31`,
        fs:  `cpe:2.3:a:websupporter:wp_amasin_-_the_amazon_affiliate_shop:0.9.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_security_management_appliance:9.1.0-103`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_security_management_appliance:9.6.6-068`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_security_management_appliance:9.7.0-006`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_security_management_virtual_appliance:8.4.0.0150`,
        fs:  `cpe:2.3:a:openstack:juno:2014.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_security_management_virtual_appliance:9.0.0.087`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d62:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:content_security_management_virtual_appliance:9.1.0-033`,
        fs:  `cpe:2.3:a:hp:slideshow:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_gateway:-`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_switch_11000:-`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_switch_11050:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p395:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_switch_11150:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_switch_11500:-`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:content_services_switch_11500:7.10_%2805.07%29s`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:content_services_switch_11500:7.20_%2803.09%29s`,
        fs:  `cpe:2.3:a:symantec:host_ids:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:content_services_switch_11500:7.20_%2803.10%29s`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.21.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:content_services_switch_11500:7.30_%2800.08%29s`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:content_services_switch_11500:7.30_%2800.09%29s`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:content_services_switch_11500_firmware:8.20.4.02`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_switch_11501:-`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_switch_11503:-`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_switch_11506:-`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_services_switch_11800:-`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_switching_module_with_ssl:-`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:content_switching_module_with_ssl:2.1`,
        fs:  `cpe:2.3:a:ucontrol:ucontrol_smart_home_automation:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:context_directory_agent:-`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:crs_performance_route_processor:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p159:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cs-mars:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cs-mars:4.1`,
        fs:  `cpe:2.3:a:supportpro:supportdesk:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cs-mars:4.1.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.05.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cs-mars:4.1.3`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:cs-mars:4.1.5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:customer_response_solutions:6.0.1068.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:customer_response_solutions_patch_install:1.1.28.0`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:desktop_administrator:80.2.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:desktop_agent:6.1.3.3`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:desktop_base:6.1.3.3`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:desktop_supervisor:6.1.3.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:diagnostic_anyconnect_reporting_tool:2.5.0`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.3:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:digital_content_manager:15.0.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:digital_media_manager:-`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:distributed_director:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.509.4:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:dpc2203:-`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:dpc2203_cable_modem_firmware:r1_customer_image_base`,
        fs:  `cpe:2.3:a:webmin:usermin:1.050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:dpc3010:-`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:dpc3212:-`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:dpc3825:-`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:dpc3925:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:dpc3939_wireless_residential_voice_gateway:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:dpc3939_wireless_residential_voice_gateway_firmware:121109acmcst_base`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:dpc3939_wireless_residential_voice_gateway_firmware:130514acmcst_base`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:dpc3941_wireless_residential_voice_gateway:-`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance:a5\(2.1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:dpq3925:-`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:dpq3925_8x4_docsis_3.0_wireless_residential_gateway_with_embedded_digital_voice_adapter:5.5.2`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2404hf-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:dpq3925_8x4_docsis_3.0_wireless_residential_gateway_with_embedded_digital_voice_adapter:r1_base`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.2614.3500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:dx_series_ip_phones_firmware:9.3%282%29`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:e-mail_manager:-`,
        fs:  `cpe:2.3:a:clusterlabs:pacemaker:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:eap-fast_module:2.2.14`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(4\)sv1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:edge_340:-`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:edge_340_firmware:1.0.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0:-:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:edge_340_firmware:1.1.0`,
        fs:  `cpe:2.3:a:schneider-electric:ofs_test_client_tlxcdsuofs33:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:edge_bluebird_operating_system:1.2`,
        fs:  `cpe:2.3:h:hp:ibrix_x9320:qp331b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:8.5.6-073`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:8.5.6-106`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:8.5.6-113`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:9.0.0-461`,
        fs:  `cpe:2.3:o:cisco:catos:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:9.1.0-032`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:9.1.1-000`,
        fs:  `cpe:2.3:h:linksys:rt31p2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:9.5.0-201`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:9.6.0-000`,
        fs:  `cpe:2.3:a:cibc:cibc_mobile_banking:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:9.6.0-051`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:email_security_appliance:9.7.0-125`,
        fs:  `cpe:2.3:a:openstack:kilo:2015.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:email_security_appliance:9.7.1-hp2-207`,
        fs:  `cpe:2.3:a:symantec:network_access_control:11.0.6300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:email_security_appliance:9.8.5-085`,
        fs:  `cpe:2.3:a:jease:jease:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:-`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:3.3.1-09`,
        fs:  `cpe:2.3:h:hp:jg411a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.1.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.1.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_business_service_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.1.2`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.1.3`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.15.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.1.4`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1444.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.1.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12.02\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.3.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.3.2`,
        fs:  `cpe:2.3:a:wave:embassy_security_center:4.0.0.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.5.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.6:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.5.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.5.2`,
        fs:  `cpe:2.3:o:d-link:dcs-932l_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.5.2-201`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:0.93.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.6.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.6.1-gpl-022`,
        fs:  `cpe:2.3:a:phpvms:phpvms:2.1.934:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.6.2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.10:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.6.3-025`,
        fs:  `cpe:2.3:a:pimcore:pimcore:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:7.8.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:8.5.6-073`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:8.5.6-106`,
        fs:  `cpe:2.3:a:qlogic:sansurfer:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:8.5.6-113`,
        fs:  `cpe:2.3:a:isc:bind:9.3.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:9.0.0-461`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:9.1.0-032`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:9.1.1-000`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:9.5.0-201`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:9.6.0-000`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:9.6.0-051`,
        fs:  `cpe:2.3:a:docker:docker:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:email_security_appliance_firmware:9.7.0-125`,
        fs:  `cpe:2.3:h:hp:mt42_mobile_thin_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:email_security_virtual_appliance:8.0.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:email_security_virtual_appliance:8.5.6`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:email_security_virtual_appliance:8.5.7`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:email_security_virtual_appliance:9.0.0`,
        fs:  `cpe:2.3:a:ntop:ntopng:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:emergency_responder:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:emergency_responder:1.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:emergency_responder:10.5%281.10000.5%29`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:emergency_responder:10.5%281a%29`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_lights_out:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:emergency_responder:10.5%283.10000.9%29`,
        fs:  `cpe:2.3:a:iss:realsecure_network_sensor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:emergency_responder:11.5%280.99833.5%29`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:emergency_responder:11.5%282.10000.5%29`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2018:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:1.1`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-2.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:2.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:2.5.3`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.1:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:2.5.5`,
        fs:  `cpe:2.3:a:andrew_levine:multiblock:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:2.5.6`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update1:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:3.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:3.0.1`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:3.0.2`,
        fs:  `cpe:2.3:h:konicaminolta:bizhub_200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:4.0`,
        fs:  `cpe:2.3:a:mcafee:securitycenter_agent:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_content_delivery_network_software:4.1`,
        fs:  `cpe:2.3:a:huawei:espace_7910:v200r002c00spc700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:enterprise_data_integration:2.2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:epc2203:-`,
        fs:  `cpe:2.3:h:ibm:m66:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:epc2203_cable_modem_firmware:r1_customer_image_base`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:epc3010:-`,
        fs:  `cpe:2.3:a:perl:perl:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:epc3212:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je073a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:epc3825:-`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:epc3925:-`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.625:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:epc3928:-`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.26.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:epc3928_docsis_3.0_8x4_wireless_residential_gateway_with_embedded_digital_voice_adapter:5.5.10`,
        fs:  `cpe:2.3:a:google:v8:3.22.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:epc3928_docsis_3.0_8x4_wireless_residential_gateway_with_embedded_digital_voice_adapter:5.5.11`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.74:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:epc3928_docsis_3.0_8x4_wireless_residential_gateway_with_embedded_digital_voice_adapter:5.7.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:epc3928_firmware:-`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ethernet_subscriber_solution_engine:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(3c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:evolved_programmable_network_manager:1.2.1.3`,
        fs:  `cpe:2.3:h:hp:laserjet_4250:q5400a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:evolved_programmable_network_manager:1.2.200`,
        fs:  `cpe:2.3:a:ibm:security_guardium:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:evolved_programmable_network_manager:1.2.300`,
        fs:  `cpe:2.3:h:huawei:quidway_s9300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:evolved_programmable_network_manager:1.2.400`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:evolved_programmable_network_manager:1.2.500`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:expressway:x8.7.2`,
        fs:  `cpe:2.3:h:radiothermostat:ct80:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:expressway:x8.8.3`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:expressway_software:x7.2.3`,
        fs:  `cpe:2.3:a:adobe:breeze_licensed_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:expressway_software:x8.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:expressway_software:x8.1.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:expressway_software:x8.2.1`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:-`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.892:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:8.5%281%29_base`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:fp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:8.5%282%29_base`,
        fs:  `cpe:2.3:a:apache:wss4j:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:8.5%283%29_base`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:8.5%284%29_base`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:fp2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:8.5%285%29_base`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:8.6%281%29_base`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.0%281%29_base`,
        fs:  `cpe:2.3:a:gnu:tar:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.0%282%29_base`,
        fs:  `cpe:2.3:a:x:libdmx:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.1%281%29_base`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.1%281%29_es1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.1%281%29_es2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120621:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.1%281%29_es3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.1%281%29_es4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.0.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.1%281%29_es5`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.1%281%29_su1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p187:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:9.1%281%29_su1.1`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.0%281%29_base`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.0%281%29_su1`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.0%281%29_su1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.5%281%29_base`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.5%281%29_es1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.338:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.5%281%29_es2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.5%281%29_es3`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.5%281%29_es4`,
        fs:  `cpe:2.3:a:telos:amhs:11.4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.5%281%29_su1`,
        fs:  `cpe:2.3:a:mcafee:protectionpilot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.5%281%29_su1.1`,
        fs:  `cpe:2.3:a:samba:samba:3.0.26:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.5%281%29_su1.7`,
        fs:  `cpe:2.3:a:barracuda:web_filter:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.6%281%29_base`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30355:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.6%281%29_su1`,
        fs:  `cpe:2.3:a:x:x_display_manager:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:10.6%281%29_su2`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:finesse:11.0%281%29_base`,
        fs:  `cpe:2.3:a:yahoo:messenger:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower:5.4.0.1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:firepower_extensible_operating_system:1.1%281.86%29`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:firepower_extensible_operating_system:1.1%281.160%29`,
        fs:  `cpe:2.3:o:cisco:vpn_500_concentrator:5.2.23.0003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:firepower_extensible_operating_system:1.1.1`,
        fs:  `cpe:2.3:a:hp:web_registration:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:4.10.3.9`,
        fs:  `cpe:2.3:a:sharetronix:sharetronix:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.3.0.2`,
        fs:  `cpe:2.3:a:duplicator_project:duplicator:0.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.3.0.3`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.3.0.4`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.3.1.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.3.1.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.3.1.5`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.3.1.6`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.3_base`,
        fs:  `cpe:2.3:a:ez:ez_publish:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-16c-si_ls-s3100-16c-si-ac-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.0.2`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.1.1`,
        fs:  `cpe:2.3:a:redhat:dogtag_certificate_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.1.3`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.1.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.1.5`,
        fs:  `cpe:2.3:a:xnview:xnview:1.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4.1.6`,
        fs:  `cpe:2.3:a:logitech:umvplstandalone:10.0.1439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:5.4_base`,
        fs:  `cpe:2.3:a:google:v8:3.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:6.0.0`,
        fs:  `cpe:2.3:a:bioinformatics:ordersys:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:6.0.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:6.0.1`,
        fs:  `cpe:2.3:a:avaya:predictive_dialer_system:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_management_center:6.0_base`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_threat_defense:5.3.0`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_threat_defense:5.4.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_threat_defense:6.0.0`,
        fs:  `cpe:2.3:a:microsoft:isa_server:2004:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_threat_defense:6.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firepower_threat_defense:6.1.0`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.40.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.2`,
        fs:  `cpe:2.3:a:perl:perl:5.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.2.1`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.2.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.2.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.294:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.2.4`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.0.899:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.2.5`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.0.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3`,
        fs:  `cpe:2.3:h:cisco:telepresence_ex90:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.2`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.3`,
        fs:  `cpe:2.3:a:redhat:libtirpc:0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.4`,
        fs:  `cpe:2.3:a:hp:openvms_secure_web_server:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.5`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.6`,
        fs:  `cpe:2.3:a:shopware:shopware:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.7`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.8`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.9`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:4.10.3.10`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.0`,
        fs:  `cpe:2.3:a:ibm:rational_performance_tester:8.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.0.1`,
        fs:  `cpe:2.3:a:dolphin-browser:dolphin_browser_cn:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.0.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2_1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.0.3`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1`,
        fs:  `cpe:2.3:a:yahoo:yui:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.1`,
        fs:  `cpe:2.3:a:ibm:sterling_secure_proxy:3.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.2`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.4`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.5`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.6`,
        fs:  `cpe:2.3:a:juniper:network_connect:7.1.0.18193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.8`,
        fs:  `cpe:2.3:a:mailbird:mailbird:2.0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.9`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.10`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.1.1.11`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.2.0`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.2.0.1`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.2.0.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.2.0.3`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.2.0.4`,
        fs:  `cpe:2.3:h:cisco:wvc200_wireless-g_ptz_internet_video_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.2.0.5`,
        fs:  `cpe:2.3:a:cisco:openh264:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.2.0.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.2.0.8`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.0`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.0.1`,
        fs:  `cpe:2.3:a:juniper:connect_tools:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.0.2`,
        fs:  `cpe:2.3:a:quest:intrust_server:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.0.3`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.007:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.0.4`,
        fs:  `cpe:2.3:a:microsoft:office_converter_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.0.5`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.0.6`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.290:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.0.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.1`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.1.2`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.1.3`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.1.4`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.1.5`,
        fs:  `cpe:2.3:h:alcatel:adsl_modem_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.1.6`,
        fs:  `cpe:2.3:a:microsoft:jet:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.3.1.7`,
        fs:  `cpe:2.3:a:ioserver:ioserver:1.0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.0.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.356:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.0.2`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.0.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.0.4`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.0.5`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.54:bpet54u:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.0.6`,
        fs:  `cpe:2.3:a:justsystems:hanako_police:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.1.2`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.6.1818.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.1.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:5.4.1.4`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:6.0.0`,
        fs:  `cpe:2.3:a:apache:commons_email:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:6.0.0.1`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:6.0.1`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firesight_system_software:6.1.0`,
        fs:  `cpe:2.3:a:skype:skype:1.3.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:-`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:1.1.2`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:1.1.3`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.5:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:1.1_%283.005%29`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:2.1_%280.208%29`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:2.3`,
        fs:  `cpe:2.3:a:apache:camel:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:2.3%281%29`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:3.1`,
        fs:  `cpe:2.3:a:mcafee:siteadvisor_enterprise:1.7.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:3.1%285%29`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:3.1%286%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:3.2`,
        fs:  `cpe:2.3:h:brocade:silkworm_3900_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:3.2%281%29`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5606:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:3.2%282%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p130:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:firewall_services_module:3.2%283%29`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.3:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%282%29`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%283%29`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%284%29`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.9.9:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%285%29`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%286%29`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%287%29`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%288%29`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.30.020.1181:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%289%29`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2810%29`,
        fs:  `cpe:2.3:o:redhat:fedora_core:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2811%29`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2812%29`,
        fs:  `cpe:2.3:a:sympa:sympa:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2813%29`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2814%29`,
        fs:  `cpe:2.3:o:huawei:s9306_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2815%29`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2816%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_management_framework:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2817%29`,
        fs:  `cpe:2.3:h:enterasys:smartswitch_ssr8000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2818%29`,
        fs:  `cpe:2.3:a:ipswitch:instant_messaging:2.0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2819%29`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2820%29`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.1%2821%29`,
        fs:  `cpe:2.3:a:google:chrome:12.0.720.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%281%29`,
        fs:  `cpe:2.3:h:belden:hirschmann_l3e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%282%29`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%283%29`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%284%29`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%285%29`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%286%29`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.1.4.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%287%29`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%288%29`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%289%29`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.62:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2810%29`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2811%29`,
        fs:  `cpe:2.3:a:opera:opera_mobile:12.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2812%29`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2813%29`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2814%29`,
        fs:  `cpe:2.3:a:google:chrome:12.0.705.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2815%29`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2816%29`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2817%29`,
        fs:  `cpe:2.3:o:mozilla:firefoxos:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2818%29`,
        fs:  `cpe:2.3:a:hp:business_availability_center:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2819%29`,
        fs:  `cpe:2.3:a:quranedu:quran_abu_bakr_ashshatiri_free:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2820%29`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-00-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2821%29`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2822%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2823%29`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(1\)ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2824%29`,
        fs:  `cpe:2.3:a:emc:networker:8.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2825%29`,
        fs:  `cpe:2.3:a:avaya:visual_vector_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2826%29`,
        fs:  `cpe:2.3:a:imperva:securesphere:9.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2827%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.7_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:3.2%2828%29`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%281%29`,
        fs:  `cpe:2.3:a:samba:samba:3.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%282%29`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%283%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p80:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%284%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.14.1:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%285%29`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%286%29`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%287%29`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%288%29`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:5.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%2810%29`,
        fs:  `cpe:2.3:h:avaya:4602sw_ip_phone:r2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%2811%29`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%2812%29`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%2813%29`,
        fs:  `cpe:2.3:a:avaya:communication_manager:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%2814%29`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.0%2815%29`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_manager:12.1:ru6-mp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%281%29`,
        fs:  `cpe:2.3:a:apache:subversion:0.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%282%29`,
        fs:  `cpe:2.3:a:juniper:host_checker:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%283%29`,
        fs:  `cpe:2.3:h:hp:d3l09a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%284%29`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%285%29`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:2016.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%286%29`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%287%29`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r7:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%288%29`,
        fs:  `cpe:2.3:a:apache:mod_python:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%289%29`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%2810%29`,
        fs:  `cpe:2.3:h:grandstream:gxv3662hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%2811%29`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%2812%29`,
        fs:  `cpe:2.3:a:novell:groupwise:7.03:hp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%2813%29`,
        fs:  `cpe:2.3:a:bilyoner:bilyoner:2.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%2814%29`,
        fs:  `cpe:2.3:a:livezilla:livezilla:4.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:firewall_services_module_software:4.1%2815%29`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:9.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:fog_director:1.0%280%29`,
        fs:  `cpe:2.3:h:htc:desire:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:fwsm:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:gigabit_switch_router_12008:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:6.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:gigabit_switch_router_12012:-`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:gigabit_switch_router_12016:-`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:global_site_selector:-`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:gss_4480_global_site_selector:-`,
        fs:  `cpe:2.3:a:david_king:vino:2.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:gss_4490_global_site_selector:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:gss_4491_global_site_selector:-`,
        fs:  `cpe:2.3:a:payment_for_webform_project:payment_for_webform:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:gss_4492r_global_site_selector:-`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.4.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:guard:-`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:guard:5.0%281%29`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:guard:5.0%283%29`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:guard_ddos_mitigation_appliance:-`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:guard_ddos_mitigation_appliance:5.1%285%29`,
        fs:  `cpe:2.3:h:hp:jd662a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:headend_digital_broadband_delivery_system:-`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:headend_system_release:-`,
        fs:  `cpe:2.3:a:spip:spip:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:headend_system_release:2.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:headend_system_release:2.7`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:headend_system_release:3.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:headend_system_release:3.5`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:headend_system_release:3.7`,
        fs:  `cpe:2.3:a:xml-dt_project:xml-dt:0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:headend_system_release:i4.3`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:-`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:8.0%282%29_base`,
        fs:  `cpe:2.3:o:tp-link:tl-wr841n_\(9.0\)_firmware:150104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:8.6%281%29_base`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd3.mxxx0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:8.6%282%29_base`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(1.22\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:8.6.2`,
        fs:  `cpe:2.3:a:vmware:workstation:4.5.2_build_8848:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:9.0%281%29_base`,
        fs:  `cpe:2.3:a:digium:asterisk:11.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:9.1%281%29_base`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:9.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:9.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:9.2%281%29:su1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_newspad:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:9.2%281%29_base`,
        fs:  `cpe:2.3:a:animoca:bunny_run:1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:9.5%281%29_base`,
        fs:  `cpe:2.3:a:hp:jetadmin:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:10.0`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:10.0%281%29_base`,
        fs:  `cpe:2.3:a:cafuego:simple_document_management_system:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:10.1%281%29_base`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:10.1%282%29_base`,
        fs:  `cpe:2.3:a:splunk:splunk:6.4.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:10.5%281%29_base`,
        fs:  `cpe:2.3:a:web2py:web2py:1.94.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:10.6%282%29_base`,
        fs:  `cpe:2.3:o:debian:debian_linux:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:10.6%283%29_base`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hosted_collaboration_solution:10.6_base`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:hosting_solution_engine:-`,
        fs:  `cpe:2.3:a:divx:divx_codec:6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:hosting_solution_engine:-`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:hosting_solution_engine:1.7`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:hosting_solution_engine:1.7.0`,
        fs:  `cpe:2.3:a:dell:openmanage_management_station:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:hosting_solution_engine:1.7.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:hosting_solution_engine:1.7.2`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.4916-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:hosting_solution_engine:1.7.3`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hostscan_engine:3.1%28.05183%29`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:hsrp:-`,
        fs:  `cpe:2.3:a:e107:e107:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:icdn:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.681.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:icdn:2.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:identity_services_engine:-`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine:1.3%280.876%29`,
        fs:  `cpe:2.3:o:cisco:wrvs4400n_firmware:1.1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:-`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.0`,
        fs:  `cpe:2.3:a:namazu:namazu:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.0.4.573`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.0_base`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.0_mr_base`,
        fs:  `cpe:2.3:a:macromedia:flash_player:6.0.79.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1`,
        fs:  `cpe:2.3:h:barracudanetworks:spam_\&amp;_virus_firewall_600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1%284.1%29`,
        fs:  `cpe:2.3:a:python:python:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.1`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.1:p1`,
        fs:  `cpe:2.3:h:polycom:mgc-25:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.1:p2`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.1:p3`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.11:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.1:p4`,
        fs:  `cpe:2.3:a:mcafee:security_center:6.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.1:p5`,
        fs:  `cpe:2.3:a:ibm:api_management:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.1:p6`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p1`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p2`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p3`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p4`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p5`,
        fs:  `cpe:2.3:a:ibm:security_qradar_incident_forensics:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p6`,
        fs:  `cpe:2.3:h:perle:cs9000_console_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p7`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.2:p9`,
        fs:  `cpe:2.3:a:samba:samba:4.2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.3:p1`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.3:p2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.14:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.3:p3`,
        fs:  `cpe:2.3:h:d-link:dap-3662:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.3:p4`,
        fs:  `cpe:2.3:h:cisco:spa_509g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.3:p5`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.3:p6`,
        fs:  `cpe:2.3:a:ibm:storwize:v7000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.3:p7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.4`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.4:p1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.12:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.4:p2`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.4:p3`,
        fs:  `cpe:2.3:a:persits:xupload:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.4:p4`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.023.20070:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.4:p5`,
        fs:  `cpe:2.3:o:cisco:ios:12.4ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.4:p6`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1.4:p7`,
        fs:  `cpe:2.3:a:atlassian:jira:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.1_base`,
        fs:  `cpe:2.3:a:hp:quicktest_professional:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2`,
        fs:  `cpe:2.3:h:cisco:asr_1013_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2%280.747%29`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2%280.793%29`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.423:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2%280.899%29`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2%281.198%29`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2%281.901%29`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.0.899:p1`,
        fs:  `cpe:2.3:a:oracle:openjdk:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.0.899:p14`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.50.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.0.899:p2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p230:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.0.899:p3`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.0.899:p4`,
        fs:  `cpe:2.3:a:totalseminars:network\&#43;_2009_book_demo:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.0.899:p5`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.0.899:p6`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.7260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.1`,
        fs:  `cpe:2.3:a:apache:cordova:3.9.1:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.1:p1`,
        fs:  `cpe:2.3:h:supermicro:x8dtu-6tf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2.1:p2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.2_base`,
        fs:  `cpe:2.3:a:apache:opennlp:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.3%280.722%29`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je108a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.3%280.876%29`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.3%28106.146%29`,
        fs:  `cpe:2.3:a:google:update_helper:1.3.21.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.3%28120.135%29`,
        fs:  `cpe:2.3:a:plainblack:webgui:6.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.4`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.4%280.109%29`,
        fs:  `cpe:2.3:a:plone:plone:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.4%280.181%29`,
        fs:  `cpe:2.3:a:analog:soundmax:6.10.2.7260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.4%280.253%29`,
        fs:  `cpe:2.3:a:cisco:webns:7.20.1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:1.4%280.876%29`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:2.0%280.147%29`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:identity_services_engine_software:2.0%280.169%29`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ids:-`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids:4.1%285b%29`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids_4210:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids_4215:-`,
        fs:  `cpe:2.3:a:apple:keynote:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids_4220:-`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.29.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids_4230:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids_4235:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids_4250:-`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ids_4250_xl:-`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ids_device_manager:-`,
        fs:  `cpe:2.3:o:juniper:junos:13.1x50:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ids_device_manager:3.1.1`,
        fs:  `cpe:2.3:a:hp:insight_control_performance_management:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ids_sensor_software:4.0%281%29e0`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ids_sensor_software:4.1%281%29e0`,
        fs:  `cpe:2.3:h:hp:laserjet_2300dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ids_sensor_software:4.1%284%29e0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ids_sensor_software:4.1%285b%29`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ids_sensor_software:4.1%285c%29`,
        fs:  `cpe:2.3:a:winscp:winscp:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:idsm-2:-`,
        fs:  `cpe:2.3:h:hp:0235a299:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-16gt4g-e:-`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-16t4g-e:-`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-4gc4gp4g-e:-`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-4gs8gp4g-e:-`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-4s8p4g-e:-`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71-\/g:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-4t4p4g-e:-`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.1.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-4tc4g-e:-`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-8gs4g-e:-`,
        fs:  `cpe:2.3:o:opensuse:leap:42.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-8gt4g-e:-`,
        fs:  `cpe:2.3:a:xchat:xchat:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-8gt8gp4g-e:-`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-8s4g-e:-`,
        fs:  `cpe:2.3:a:digium:asterisk:12.7.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-4000-8t4g-e:-`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-5000-12s12p-10g:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ie-5000-16s12p:-`,
        fs:  `cpe:2.3:a:buffalotech:whr-amg54_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:information_server:6.2_base`,
        fs:  `cpe:2.3:o:samsung:printer_firmware:20121031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:integrated_management_controller_supervisor:1.0.0.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:integrated_management_controller_supervisor:1.0.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p267:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:integrated_services_router_800:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:integrated_services_router_819:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:integrated_services_router_829:-`,
        fs:  `cpe:2.3:a:apache:poi:3.5:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:12.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr2`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr3`,
        fs:  `cpe:2.3:a:sympa:sympa:0.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr4`,
        fs:  `cpe:2.3:o:moxa:miineport_e2_4561_firmware:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr5`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_1300-65:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr7`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr8`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr9`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr10`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr11`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr12`,
        fs:  `cpe:2.3:a:labelgate:mora_downloader:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29_sr13`,
        fs:  `cpe:2.3:a:isc:bind:8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:5.0%280%29a`,
        fs:  `cpe:2.3:a:horde:imp:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr1`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr2`,
        fs:  `cpe:2.3:a:sympa:sympa:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr5`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr6`,
        fs:  `cpe:2.3:a:alcatel-lucent:voice_mail_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr8`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr9`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29_sr10`,
        fs:  `cpe:2.3:h:cisco:c460_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29a`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intelligent_contact_manager:6.0%280%29a%281%29`,
        fs:  `cpe:2.3:a:redhat:rhmask:1.0-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intercloud_fabric:2.2.1_base`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intercloud_fabric:2.3.1_base`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intercloud_fabric:3.1.1_base`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:internet_service_node:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:internet_streamer_content_delivery_system:2.0`,
        fs:  `cpe:2.3:a:kelly_d._redding:kelredd-pruview:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:internet_streamer_content_delivery_system:2.6`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:internet_streamer_content_delivery_system:2.6.3.b50`,
        fs:  `cpe:2.3:h:ge:multilink_ml810:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:internet_streamer_content_delivery_system:3.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:internet_streamer_content_delivery_system:3.1.2b54`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:intrusion_prevention_system:-`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:4.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.0%281%29`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.0%282%29`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.0%286%29p1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:5.1`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.1%281%29`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0a2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.1%281a%29`,
        fs:  `cpe:2.3:a:freso:languageicons:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.1%281b%29`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.1%281c%29`,
        fs:  `cpe:2.3:a:pocoproject:poco_c\&#43;\&#43;_libraries:1.4.6:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.1%281d%29`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.1%281e%29`,
        fs:  `cpe:2.3:a:ibm:ds_storage_manager_host_software:10.60.x5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:intrusion_prevention_system:5.1%28p1%29`,
        fs:  `cpe:2.3:a:cisco:webex_advanced_recording_format_player:27.21.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:6.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:6.0.2.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%281%29e3`,
        fs:  `cpe:2.3:a:adobe:creative_suite_5_web_premium:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%282%29e3`,
        fs:  `cpe:2.3:a:tincan:phplist:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%282%29e4`,
        fs:  `cpe:2.3:a:cisco:unity_connection:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%283%29e4`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%284%29e4`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%285a%29e4`,
        fs:  `cpe:2.3:a:microsoft:security_compliance_manager:2.5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%286%29e4`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_database_control:11.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%287%29e4`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%288%29e4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.0%289%29e4`,
        fs:  `cpe:2.3:a:isc:bind:9.10.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.1`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.2%281%29e4`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.2%282%29e4`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:intrusion_prevention_system:7.3%282%29e4`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite_sql-server:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:%284%29st`,
        fs:  `cpe:2.3:a:apple:quicktime:6.4.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:-`,
        fs:  `cpe:2.3:a:autodesk:design_review_2012:12.0.0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.0se`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.0xo`,
        fs:  `cpe:2.3:a:promotic:promotic:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.1se`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.1xo`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.2se`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6a:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.2xo`,
        fs:  `cpe:2.3:a:pcre:perl-compatible_regular_expression_library:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.3se`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.4se`,
        fs:  `cpe:2.3:a:digium:asterisk:13.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.3.5se`,
        fs:  `cpe:2.3:a:bandainamcogames:madomagi-ip_android:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.5.0e`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd240a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.5.1e`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.5.2e`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(7c\)1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.5.3e`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.6.0e`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.6.1e`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.6.2ae`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.6.2e`,
        fs:  `cpe:2.3:a:arabia2000:car_wallpapers_hd:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.6.3e`,
        fs:  `cpe:2.3:a:lenovo:thinkpad_bluetooth_with_enhanced_data_rate_software:6.4.0.2900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.6.4e`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.7.0e`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.56:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.7.1e`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ea2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.7.2e`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:3.7.3e`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:4.1`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:4.1.1`,
        fs:  `cpe:2.3:a:apache:ranger:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:4.1.2`,
        fs:  `cpe:2.3:h:xerox:workcentre:m133:unknown:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:8.2`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:8.3`,
        fs:  `cpe:2.3:o:emc:data_domain:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:9.0`,
        fs:  `cpe:2.3:a:acmailer:acmailer:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:9.1`,
        fs:  `cpe:2.3:a:schneider-electric:accutech_manager:2.00.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:9.14`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:10.0`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:10.3`,
        fs:  `cpe:2.3:h:hp:j9639a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:10.3%283.3%29`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:10.3%283.4%29`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:10.3%284.2%29`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:10.3%284.3%29`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.2:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:10.3%2816%29`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l23e-qbfc1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:10.3%2819a%29`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11`,
        fs:  `cpe:2.3:a:anywherepad:anywhere_pad-meet_collaborate:4.0.1031:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0%2812%29`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0%2817%29`,
        fs:  `cpe:2.3:a:nuance:paperport:9.2.814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0%2817%29bt`,
        fs:  `cpe:2.3:a:novell:zenworks:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0%2818%29`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0%2820.3%29`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:7.31_.xd8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0%2822a%29`,
        fs:  `cpe:2.3:a:docker:docker:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0%2822b%29`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0%28x%29`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.0.12%28a%29bt`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.3:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%285%29`,
        fs:  `cpe:2.3:h:axis:2401_video_server:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%287%29`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%287%29aa`,
        fs:  `cpe:2.3:a:netscape:navigator:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%287%29ca`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%289%29ia`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2811%29`,
        fs:  `cpe:2.3:a:mail_on_update_project:mail_on_update:5.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2812%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2813%29`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2813%29aa`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2813%29ca`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_enterprise_client:9.31:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2813%29ia`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.4p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2814%29`,
        fs:  `cpe:2.3:a:xerox:docushare:6.5.3:patch6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2815%29`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2815%29aa`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2815%29ca`,
        fs:  `cpe:2.3:a:userfriendlymedia:mills-hazel_property_mgmt:3.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2815%29ia`,
        fs:  `cpe:2.3:a:sun:ray_windows_connector:1.1:*:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2816%29`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2816%29aa`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2816%29ia`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2817%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2817%29cc`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2817%29ct`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.0.0.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2818%29`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2820%29aa4`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2822%29`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2824%29`,
        fs:  `cpe:2.3:a:epiqo:email:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2824a%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2824b%29`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2824c%29`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2828a%29ct`,
        fs:  `cpe:2.3:a:cisco:jabber:9.0:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2828a%29ia`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:-:opscenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2836%29ca2`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2836%29ca4`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.6.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2836%29cc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1%2836%29cc4`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_enterprise_client:2.02:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1aa`,
        fs:  `cpe:2.3:a:appsgeyser:btd5_videos:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1ca`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1cc`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.a5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1ct`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.1ia`,
        fs:  `cpe:2.3:a:snaplion:kavita_ks:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%284%29`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.7:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%284%29f`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%284%29f1`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_xgs_firmware:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%284%29xa`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent_option:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%284%29xaf`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.00c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%288%29`,
        fs:  `cpe:2.3:a:deer_hunting_calls_\&#43;_guide_project:deer_hunting_calls_\&#43;_guide:4.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%288%29p`,
        fs:  `cpe:2.3:a:ca:anti-spyware_for_the_enterprise:r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%288%29sa1`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma609xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%288%29sa3`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%288%29sa5`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%288.2%29sa6`,
        fs:  `cpe:2.3:a:analogx:simpleserver_shout:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%288.9%29sa6`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%289%29p`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%289%29xa`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2810%29`,
        fs:  `cpe:2.3:h:cisco:unity_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2810%29bc`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2811%29`,
        fs:  `cpe:2.3:a:optipng:optipng:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2811b%29t2`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2814%29gs2`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2815%29g`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(6\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2815a%29p`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2815b%29`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2816%29`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2816%29p`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2817%29`,
        fs:  `cpe:2.3:a:apache:axis:1.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2818%29`,
        fs:  `cpe:2.3:a:ca:unicenter_asset_portfolio_management:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2819%29gs0.2`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2819a%29gs6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p224:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2823a%29bc1`,
        fs:  `cpe:2.3:h:hp:2260_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2826%29p2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.46:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2826%29p5`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2826a%29`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l1_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2826b%29`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2%2826e%29`,
        fs:  `cpe:2.3:o:cisco:nx-os_1000v_switch:4.0\(4\)sv1\(3c\):*:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2bc`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2f`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2gs`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2p`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2sa`,
        fs:  `cpe:2.3:a:rack_project:rack:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2wa3`,
        fs:  `cpe:2.3:a:perl:perl:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2wa4`,
        fs:  `cpe:2.3:h:avtech:avn801_dvr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.2xa`,
        fs:  `cpe:2.3:a:erlang:crypto:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%281%29`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%281%29ed`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%281%29t`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.17:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%282%29xa`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%287%29db1`,
        fs:  `cpe:2.3:a:ibm:soliddb:4.5.169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%288%29db2`,
        fs:  `cpe:2.3:a:ask:ask.com:2.2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%288%29t1`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%2811%29b`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%2811b%29`,
        fs:  `cpe:2.3:a:rocklobster:contact_form_7:3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%2811b%29t2`,
        fs:  `cpe:2.3:a:php:php:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%2811c%29`,
        fs:  `cpe:2.3:a:oracle:jdk:6.0:update_141:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3%2811d%29`,
        fs:  `cpe:2.3:a:synology:download_station:3.8.4-3468:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3aa`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3da`,
        fs:  `cpe:2.3:a:emc:networker:7.4:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3db`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2005-09-22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3ha`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-07:-:enterprise:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3ma`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3na`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3t`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3wa4`,
        fs:  `cpe:2.3:a:mahara:mahara:17.04:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:11.3xa`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.2.8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0`,
        fs:  `cpe:2.3:a:boeing:imis_application_suite:5.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%281%29`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%281%29s`,
        fs:  `cpe:2.3:a:sybase:easerver:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%281%29st`,
        fs:  `cpe:2.3:a:zope:zope:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%281%29w`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%281%29xa3`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%281%29xb`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%281%29xe`,
        fs:  `cpe:2.3:a:magzter:woodcraft_magazine:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%282%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%282%29xc`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%282%29xd`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%282%29xe`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.9:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%282%29xf`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%282%29xg`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%282a%29`,
        fs:  `cpe:2.3:a:apple:safari:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%282b%29`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.020.20042:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%283%29`,
        fs:  `cpe:2.3:a:f5:big-ip:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%283%29t2`,
        fs:  `cpe:2.3:h:cisco:sg500x-24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%283%29xe`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%283.2%29`,
        fs:  `cpe:2.3:a:pro_quoter_plugin_project:pro_quoter:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%283.3%29s`,
        fs:  `cpe:2.3:a:lxml:lxml:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%283.4%29t`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%283.6%29w5%289.0.5%29`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.3:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%283d%29`,
        fs:  `cpe:2.3:o:cisco:catos:8.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%284%29`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-07:-:standard:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%284%29s`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%284%29t`,
        fs:  `cpe:2.3:a:unrealircd:unrealircd:3.2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%284%29xe`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.2.4:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%284%29xe1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%284%29xm`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp2:adv_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%284%29xm1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29s`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5:b2:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29t`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29t1`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0a6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29t2`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc2`,
        fs:  `cpe:2.3:a:microsoft:infopath:2010:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc2b`,
        fs:  `cpe:2.3:a:adobe:photodeluxe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc3`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc3b`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:4.2.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc5a`,
        fs:  `cpe:2.3:a:wimleers:cdn:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2805%29wc8`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc9`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc9a`,
        fs:  `cpe:2.3:a:cybozu:office:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc11`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wc13`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:58.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29wx`,
        fs:  `cpe:2.3:a:esri:arcsde:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29xe`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29xk`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29xk2`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29xn`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29xn1`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29xs`,
        fs:  `cpe:2.3:a:bestpractical:rt-extension-mobileui:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29xu`,
        fs:  `cpe:2.3:a:sagelighteditor:sagelight:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285%29yb4`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0528:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285.1%29xp`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.287:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285.2%29xu`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285.3%29wc1`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285.4%29wc1`,
        fs:  `cpe:2.3:a:quest:litespeed_for_sql_server:5.2.0.1240:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%285a%29e`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%286%29`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%286b%29`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29db2`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29dc1`,
        fs:  `cpe:2.3:h:d-link:dcs-5222l_:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29s1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29sc`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:0.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29t`,
        fs:  `cpe:2.3:a:moodle:moodle:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29t2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.805:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29t3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29wx5%2815a%29`,
        fs:  `cpe:2.3:a:python:python:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29xe`,
        fs:  `cpe:2.3:a:jenkins:git:1.0.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29xe2`,
        fs:  `cpe:2.3:a:133:flight_manager:4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29xf`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.9.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29xf1`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29xk`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:4.3.0:cp06:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29xk2`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29xk3`,
        fs:  `cpe:2.3:a:contenido:contendio:4.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287%29xv`,
        fs:  `cpe:2.3:a:symantec:advanced_threat_protection:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287.4%29s`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%287a%29`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2955:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%288%29`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%288%29s1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.608:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%288.0.2%29s`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%288.3%29sc`,
        fs:  `cpe:2.3:a:ecava:integraxor:3.6.4000.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%288a%29`,
        fs:  `cpe:2.3:a:roxio:cd_creator:6.1.1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%289%29`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%289%29s`,
        fs:  `cpe:2.3:a:usaf:accm:1.0.0.1066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%289%29s8`,
        fs:  `cpe:2.3:a:citrix:ica_client:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%289a%29`,
        fs:  `cpe:2.3:h:dell:precision_mobile_m6600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2810%29`,
        fs:  `cpe:2.3:h:cisco:dpc3010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2810%29s3b`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2810%29s7`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2810%29s8`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2810%29w5`,
        fs:  `cpe:2.3:a:python:pillow:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2810%29w5%2818f%29`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2810%29w5%2818g%29`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2810a%29`,
        fs:  `cpe:2.3:a:vips:vips:7.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2811%29s6`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.67.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2811%29st4`,
        fs:  `cpe:2.3:o:google:android:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2811a%29`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2812%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2812%29s3`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2812%29s4`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2812a%29`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2813%29s6`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1\(3\)sr3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2813%29s8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2813%29w5%2819c%29`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2813%29wt6%281%29`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2813a%29`,
        fs:  `cpe:2.3:a:drupal:drupal:7.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2814%29`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:4.1.0.17435:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2814%29s7`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.4.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2814%29s8`,
        fs:  `cpe:2.3:a:hp:performance_access:10.50.225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2814%29st`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_basic_runtime_for_visual_studio_2008:10.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2814%29st3`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2814%29w5%2820%29`,
        fs:  `cpe:2.3:a:nagios:nagios:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2814a%29`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:8.0:-:*:*:*:windows_7:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2815%29s`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2815%29s3`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:7.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2815%29s6`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2815%29s7`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2815%29sc`,
        fs:  `cpe:2.3:h:hp:8100c_digital_sender:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2815%29sl`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.3.300.262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2815a%29`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29s`,
        fs:  `cpe:2.3:a:invensys:wonderware_historian:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29s8`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_discovery_for_distributed:7.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29s8a`,
        fs:  `cpe:2.3:o:google:android:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29s10`,
        fs:  `cpe:2.3:a:galsila:il_brillo_parlante:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29sc`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29sc3`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29st`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29st1`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816%29w5%2821%29`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.130:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816.06%29s`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2816a%29`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29s`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29s4`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29s7`,
        fs:  `cpe:2.3:a:avonesoft:video_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29sl`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29sl2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.277.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29sl6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.466:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29sl9`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.824:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29st1`,
        fs:  `cpe:2.3:h:hp:storageworks_p2000_g3_msa_fc\/iscsi_dual_combo_controller_lff_array_system:aw567a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29st5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817%29st8`,
        fs:  `cpe:2.3:a:apache:mod_python:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2817a%29`,
        fs:  `cpe:2.3:h:hp:0235a0g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2818%29s`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2818%29s5`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2818%29s5a`,
        fs:  `cpe:2.3:a:monotone:monotone:0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2818%29s7`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2818%29sl`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2818%29st1`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2818%29w5%2822b%29`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2818b%29`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29s`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.8:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29s2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29s2a`,
        fs:  `cpe:2.3:a:dell:system_e-support_tool:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29s4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29sl`,
        fs:  `cpe:2.3:h:nortel:alteon_acedirector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29sl4`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29sp`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)t9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29st`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29st2`,
        fs:  `cpe:2.3:a:cyberlink:streamauthor:4.0:build3308:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819%29st6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2819a%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820%29sl`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820%29sp`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820%29sp1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820%29st2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.0.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820%29st6`,
        fs:  `cpe:2.3:a:gajennings:this:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820%29st7`,
        fs:  `cpe:2.3:a:horde:imp:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820%29sx`,
        fs:  `cpe:2.3:a:openttd:openttd:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820%29w5%2822b%29`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820.4%29sp`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2820a%29`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.5e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29s`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29s1`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29s3`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29s4a`,
        fs:  `cpe:2.3:h:xerox:workcentre:m123:unknown:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29s5a`,
        fs:  `cpe:2.3:a:git-scm:git:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29s6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2008.225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29s7`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:4.0.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29sl`,
        fs:  `cpe:2.3:a:sun:jre:6.0.120:update12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29st`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.23_pre-release:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29st6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29st7`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821%29sx`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2821a%29`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2822%29s`,
        fs:  `cpe:2.3:a:ca:brightstor_storage_resource_manager:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2822%29s4`,
        fs:  `cpe:2.3:a:novell:groupwise_webaccess:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2822%29s5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2822%29sy`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2823%29s2`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:2.1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2823%29s3`,
        fs:  `cpe:2.3:h:fujitsu:arrows_kiss_f-03d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2823%29s4`,
        fs:  `cpe:2.3:a:cisco:cisco_policy_suite:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2823%29s5`,
        fs:  `cpe:2.3:a:xoops:xoops:2.5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2823%29s6`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.6.100.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2823%29sx`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.4:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2823%29sz`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2824%29s1`,
        fs:  `cpe:2.3:a:skype:skype:0.96.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2824%29s2`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:7.5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2824%29s4`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2824%29s5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2824%29s6`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2824.2%29s`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2825%29s1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2825%29w5%2827%29`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_4_firmware:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2825%29w5%2827c%29`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.56:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2825%29w5-27d`,
        fs:  `cpe:2.3:a:mochiweb_project:mochiweb:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2825.4%29s1`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:001dl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2826%29`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2826%29s`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2826%29s1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2826%29s2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2826%29s6`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2826%29w5%2828%29`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2826%29w5%2828a%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2827%29`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2827%29s`,
        fs:  `cpe:2.3:a:altiris:client_task_management:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2827%29s1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2827%29sv`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2827%29sv1`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2827%29sv2`,
        fs:  `cpe:2.3:h:huawei:s5306:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2828%29`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_2500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2828%29s3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2828%29s5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)sz1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2828%29w5%2831a%29`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2828%29w5-30b`,
        fs:  `cpe:2.3:o:xen:xen:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2828%29w5-32a`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2828c%29`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.28.5039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2828d%29`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2830%29s1`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2830%29s2`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2830%29s4`,
        fs:  `cpe:2.3:o:dell:sonicwall_netextender_firmware:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2831%29s`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2831%29s1`,
        fs:  `cpe:2.3:a:macromedia:contribute_publishing_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2832%29s12`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2832%29s13`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2832%29sy8`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2832%29sy9`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2833%29s3`,
        fs:  `cpe:2.3:a:ibm:java:7.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0%2833%29s4`,
        fs:  `cpe:2.3:h:axis:700_network_document_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0da`,
        fs:  `cpe:2.3:a:apache:tomcat:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0db`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0dc`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0ev`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.50.4:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0s`,
        fs:  `cpe:2.3:a:google:v8:3.24.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.0sc`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0sc`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0sl`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp2:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0sp`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.4.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0st`,
        fs:  `cpe:2.3:a:hrblock:taxcut_premium\&#43;efile_2008:8.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0sv`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0sx`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0sy`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_41:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0sz`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0t`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.6-212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0w`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0w5`,
        fs:  `cpe:2.3:a:anixis:password_policy_enforcer:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0wc`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0wt`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0wx`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xa`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xb`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xc`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xd`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xe`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xf`,
        fs:  `cpe:2.3:a:google:chrome:6.0.466.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xg`,
        fs:  `cpe:2.3:a:apache:subversion:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xh`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:03-00-07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xi`,
        fs:  `cpe:2.3:a:gemalto:gemezdiag:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xj`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.539:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xk`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xl`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xm`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xn`,
        fs:  `cpe:2.3:h:hp:3com_router:5231:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xp`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xq`,
        fs:  `cpe:2.3:h:hp:laserjet_9500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xr`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.11:ga6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xs`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.11:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xt`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xu`,
        fs:  `cpe:2.3:a:google:chrome:5.0.322.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xv`,
        fs:  `cpe:2.3:h:schneider-electric:bmxnoe0110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.0xw`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281%29`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(3\)m1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281%29db`,
        fs:  `cpe:2.3:a:clamav:clamav:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281%29db2`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281%29dc`,
        fs:  `cpe:2.3:a:websense:websense_web_filter:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281%29dc2`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281%29e5`,
        fs:  `cpe:2.3:h:huawei:acu:v200r001c00spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281%29ex`,
        fs:  `cpe:2.3:a:google:chrome:13.0.776.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281%29t`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281.3%29t`,
        fs:  `cpe:2.3:a:riken:xoonips:3.40:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281a%29t1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%281c%29`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%282%29e1`,
        fs:  `cpe:2.3:a:onesolutionapps:reds_anytime_bail:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%282%29t`,
        fs:  `cpe:2.3:a:hp:serviceguard:a.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%282%29xf`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%282%29xf4`,
        fs:  `cpe:2.3:a:kadu:kadu:0.5:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%282%29xf5`,
        fs:  `cpe:2.3:h:xerox:workcentre_m165:6.47.30.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%282b%29`,
        fs:  `cpe:2.3:a:autodesk:sketchbook_pro:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29`,
        fs:  `cpe:2.3:a:oi:minha_oi:1.15.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29db1`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_xi:11.5.3.41727:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29dc2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29t`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29xi`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29xp`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29xp4`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29xq`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29xt`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)bc2h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283%29xt3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283a%29`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:1.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283a%29e7`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283a%29e8`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283a%29t4`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283a%29t7`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283a%29xi8`,
        fs:  `cpe:2.3:h:htc:evo_3d:gri40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%283b%29`,
        fs:  `cpe:2.3:h:cisco:multiservice_platform_2651xm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29`,
        fs:  `cpe:2.3:a:sympa:sympa:3.1b.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29db`,
        fs:  `cpe:2.3:a:otrs:otrs:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29db1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29db2`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.00:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29dc`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29dc2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29e3`,
        fs:  `cpe:2.3:h:cisco:vpn_3030_concentator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29ea1e`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yg2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29xm4`,
        fs:  `cpe:2.3:a:cisco:business_edition_5000_software:8.6\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29xz`,
        fs:  `cpe:2.3:a:ftpshell:ftpshell_server:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284%29xz7`,
        fs:  `cpe:2.3:h:hp:laserjet_9050_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284.3%29t`,
        fs:  `cpe:2.3:o:windriver:vxworks:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%284a%29`,
        fs:  `cpe:2.3:a:schneider-electric:opc_factory_server:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29da1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29db1`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29dc`,
        fs:  `cpe:2.3:a:sap:netweaver:7.3:ehp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29dc2`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29ey`,
        fs:  `cpe:2.3:a:7t:aquis:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29t`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29t9`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.06:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29t12`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29t15`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xg5`,
        fs:  `cpe:2.3:a:hp:deskjet_taplugin:60.0.196.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xm`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xm4`,
        fs:  `cpe:2.3:h:hp:jg518a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xm7`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xr2`,
        fs:  `cpe:2.3:a:spip:spip:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xs`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xs2`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xu1`,
        fs:  `cpe:2.3:a:debian:reprepro:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xv`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xv3`,
        fs:  `cpe:2.3:a:phpwebscripts:easy_banner_free:2009.05.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xv4`,
        fs:  `cpe:2.3:a:oracle:agile_product_lifecycle_management_framework:9.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xv5`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-51:-:standard:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29xy6`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29ya`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29ya2`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.9.219863.2196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yb`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yb4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yb5`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yc`,
        fs:  `cpe:2.3:a:teradata:sql_assistant:12.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yc1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.5.12\(3701\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yc2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.271.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yd`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yd2`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:2.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yd6`,
        fs:  `cpe:2.3:a:atutor:atutor:1.6.1:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yf`,
        fs:  `cpe:2.3:a:microsoft:office:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yf2`,
        fs:  `cpe:2.3:a:schoolmation:schoolmation:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yf4`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:9.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yh`,
        fs:  `cpe:2.3:a:google:chrome:9.0.587.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yh3`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.localization:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yi`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285%29yi1`,
        fs:  `cpe:2.3:a:canon:imagerunner_5020:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285a%29e`,
        fs:  `cpe:2.3:a:google:chrome:14.0.832.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285c%29`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285c%29e12`,
        fs:  `cpe:2.3:a:stillbreathing:bannerman:0.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285c%29ex`,
        fs:  `cpe:2.3:a:corel:coreldraw_lang_br:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%285e%29`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29e8`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29e12`,
        fs:  `cpe:2.3:a:ca:etrust_internet_security_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ea1`,
        fs:  `cpe:2.3:a:apple:safari:3.0.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ea1a`,
        fs:  `cpe:2.3:a:citrix:access_management_console_knowledge_base:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ea2`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2962:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ea2a`,
        fs:  `cpe:2.3:h:hp:color_laserjet_9500_mfp:c8549a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ea2b`,
        fs:  `cpe:2.3:a:humhub:humhub:0.20.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ea2c`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ey`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ez1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286%29ez2`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286.5%29`,
        fs:  `cpe:2.3:o:ge:multilink_ml1600_firmware:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286.5%29ec3`,
        fs:  `cpe:2.3:a:7725:7725.com_three_kingdoms:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%286a%29`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287%29`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287%29cx`,
        fs:  `cpe:2.3:a:bernhard_wymann:torcs:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287%29da2`,
        fs:  `cpe:2.3:a:etoshop:dynamic_biz_website_builder_quickweb:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287%29da3`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287%29ec`,
        fs:  `cpe:2.3:a:microsoft:office:2010:sp2:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287a%29e6`,
        fs:  `cpe:2.3:a:hp:productcontext:47.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287a%29ey`,
        fs:  `cpe:2.3:a:fleugel:myu-s:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287a%29ey3`,
        fs:  `cpe:2.3:a:vmware:tools:9.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%287b%29`,
        fs:  `cpe:2.3:h:logitech:cordless_itouch_keyboard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288%29`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288%29aa1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288%29e`,
        fs:  `cpe:2.3:a:cisco:sc2200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288%29ea`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288%29ea1b`,
        fs:  `cpe:2.3:h:3com:3c16450-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288%29ea2b`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288a%29e`,
        fs:  `cpe:2.3:a:google:talk:1.0.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288a%29ew`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288a%29ew1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288a%29ex`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288b%29e8`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288b%29e9`,
        fs:  `cpe:2.3:a:clamav:clamav:0.70:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288b%29e14`,
        fs:  `cpe:2.3:a:apache:axis2:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288b%29e15`,
        fs:  `cpe:2.3:a:radius_extension_project:radius:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288b%29e16`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288b%29e18`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd943a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288b%29e20`,
        fs:  `cpe:2.3:a:haxx:curl:7.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288b%29ex4`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0b.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%288c%29`,
        fs:  `cpe:2.3:a:pip-installer:pip:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%289%29`,
        fs:  `cpe:2.3:a:debian:lintian:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%289%29aa`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%289%29e`,
        fs:  `cpe:2.3:h:hp:jetdirect_680n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%289%29e3`,
        fs:  `cpe:2.3:a:mauro_lorenzutti:wfqbe:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%289%29ea`,
        fs:  `cpe:2.3:a:microsoft:visio:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%289%29ex`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%289%29ex3`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%289a%29`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.0:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810%29`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810%29aa`,
        fs:  `cpe:2.3:a:microsoft:asp.net_signalr:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810%29e`,
        fs:  `cpe:2.3:a:zope:zope:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810%29e4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810%29ec`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810%29ec1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810%29ex`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810%29ey`,
        fs:  `cpe:2.3:h:lexmark:n70xxe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810.5%29ec`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2810a%29`,
        fs:  `cpe:2.3:a:gnu:bash:1.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811%29`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811%29e`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:p8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811%29ea1`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811%29ec`,
        fs:  `cpe:2.3:a:exim:exim:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811.5%29e`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.9.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811a%29`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811b%29`,
        fs:  `cpe:2.3:a:xnview:xnview:1.70.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811b%29e`,
        fs:  `cpe:2.3:a:90meter:cac_smartcard_manager-90:1.2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811b%29e12`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2811b%29e14`,
        fs:  `cpe:2.3:a:exim:exim:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812%29`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812%29e`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812a%29`,
        fs:  `cpe:2.3:h:grandstream:gxv3611hd\/ll:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812b%29`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812c%29`,
        fs:  `cpe:2.3:o:dell:sonicwall_uma_em5000_firmware:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812c%29e7`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812c%29ec`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.50401.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812c%29ev01`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2812c%29ew4`,
        fs:  `cpe:2.3:a:belarc:belmonitor_client_components:8.1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p323:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29ay`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.9:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29e1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29e3`,
        fs:  `cpe:2.3:o:netgear:r6250_firmware:1.0.4.6_10.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29e7`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29e9`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.3:5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29e12`,
        fs:  `cpe:2.3:a:google:v8:3.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29e13`,
        fs:  `cpe:2.3:a:cisco:unified_ccx:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29e17`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29ea1`,
        fs:  `cpe:2.3:o:toshibacommerce:4690_point_of_sale_operating_system:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29ea1c`,
        fs:  `cpe:2.3:a:gnu:bash:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29ew`,
        fs:  `cpe:2.3:o:microsoft:windows:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29ew4`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813%29ex2`,
        fs:  `cpe:2.3:a:projectforge:projectforge:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2813.4%29e`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2814%29`,
        fs:  `cpe:2.3:a:digia:qt:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2814%29e1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.2:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2814%29e4`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2814%29e9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2814%29e10`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2814%29ea1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.5:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2814%29eb`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:8.0:r2:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2814.5%29`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2815%29bc1`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2816%29`,
        fs:  `cpe:2.3:a:google:chrome:7.0.515.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2818%29`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2818.4%29`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819%29`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.6\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819%29e`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819%29e1`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819%29e6`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819%29ec`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819%29ew`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819%29ew3`,
        fs:  `cpe:2.3:a:ibm:db2:9.8:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819%29fc1`,
        fs:  `cpe:2.3:a:civicrm:civicrm_private_report:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2819.3%29e`,
        fs:  `cpe:2.3:a:intel:proset_wireless:13.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29e`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29e1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.8.800.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29e2`,
        fs:  `cpe:2.3:a:condor_project:condor:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29e3`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29e5`,
        fs:  `cpe:2.3:a:apple:cups:1.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ea1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.12s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ea1a`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ec`,
        fs:  `cpe:2.3:a:e107:e107:0.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ec1`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ec2`,
        fs:  `cpe:2.3:a:hp:webes_service_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29eo`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29eo1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.624.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29eo3`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2013:cumulative_update_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ew`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ew1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ew2`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2820%29ew4`,
        fs:  `cpe:2.3:a:nokia:electronic_documentation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29e1`,
        fs:  `cpe:2.3:a:cisco:system_controller_3640:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29e3`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29ea3`,
        fs:  `cpe:2.3:a:codewrights:hart_device_type_manager:1.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29ea4`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29ea4a`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29ea5a`,
        fs:  `cpe:2.3:a:apple:itunes:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29ea6`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2822%29eb`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:b:commercial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2823%29e1`,
        fs:  `cpe:2.3:a:telos:amhs:12.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2823%29e4`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2007:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2826%29e1`,
        fs:  `cpe:2.3:a:oracle:commerce_platform:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2826%29e3`,
        fs:  `cpe:2.3:a:neotys:neoload:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2826%29eb1`,
        fs:  `cpe:2.3:a:adam_zaninovich:sounder:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2827%29`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1%2827b%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1aa`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ax`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.1ay`,
        fs:  `cpe:2.3:a:spip:spip:3.1.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ay`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1az`,
        fs:  `cpe:2.3:a:apple:bonjour:1.0.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1cx`,
        fs:  `cpe:2.3:a:ibm:content_manager:8.5:*:*:*:*:enterprise:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1da`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1db`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1dc`,
        fs:  `cpe:2.3:a:compaq:open_san_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1e`,
        fs:  `cpe:2.3:a:symantec:veritas_dmp_dsm_solution:5.1.11000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ea`,
        fs:  `cpe:2.3:h:lexmark:c6160:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1eb`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ec`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1eo`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.06b43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1eu`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ev`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ew`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.2m1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ex`,
        fs:  `cpe:2.3:a:apple:safari:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ey`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ez`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ga`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1gb`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1m`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.1.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1s`,
        fs:  `cpe:2.3:a:cisco:vpn_client:4.0.2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1sec`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1t`,
        fs:  `cpe:2.3:a:ca:license_software:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1x%28l%29`,
        fs:  `cpe:2.3:a:apple:keynote:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xa`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xb`,
        fs:  `cpe:2.3:a:apple:itunes:12.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xc`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xd`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xe`,
        fs:  `cpe:2.3:a:ibm:platform_symphony:6.1.0:*:*:*:developer:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xf`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2010.910.2122.36517:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xg`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xh`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xi`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xj`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xk`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xl`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xm`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xp`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je068a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xq`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xr`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xs`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xt`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xu`,
        fs:  `cpe:2.3:a:barebones:textwrangler:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xv`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xw`,
        fs:  `cpe:2.3:o:fli4l:fli4l:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xx`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xy`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r75.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1xz`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_39:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ya`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1yb`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1yc`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1yd`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1ye`,
        fs:  `cpe:2.3:o:google:android:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1yf`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.4.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1yh`,
        fs:  `cpe:2.3:h:sun:fire_x4140_server:sw_2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1yi`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r14a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.1yj`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29`,
        fs:  `cpe:2.3:o:ibm:aix:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29dx`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29s`,
        fs:  `cpe:2.3:h:sierra_wireless:sierra_wireless_aircard_762s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29t`,
        fs:  `cpe:2.3:a:sybase:pylon_anywhere:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xa`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.7:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xd`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xd1`,
        fs:  `cpe:2.3:a:google:v8:3.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xd3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xd4`,
        fs:  `cpe:2.3:h:intel:enterprise_southbridge_2_bmc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xe`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xe2`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xe3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xh`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0059:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xq`,
        fs:  `cpe:2.3:a:ilove:ilove_-_free_dating_\&amp;_chat_app:1.3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xs`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281%29xs1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281.1%29`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281.1%29pi`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281.4%29s`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281b%29`,
        fs:  `cpe:2.3:a:web2py:web2py:1.76.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281b%29da1`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%281d%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29b`,
        fs:  `cpe:2.3:a:sun:java_system_directory_proxy_server:5.2:2004q2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29bx`,
        fs:  `cpe:2.3:a:nero:startsmart:9.0.9.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29by`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29by2`,
        fs:  `cpe:2.3:a:iss:blackice_agent_server:3.6ecd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29dd3`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29t`,
        fs:  `cpe:2.3:a:ibm:rational_performance_tester:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29t1`,
        fs:  `cpe:2.3:o:huawei:s7706_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29t4`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xa`,
        fs:  `cpe:2.3:a:krisonav:krisonav:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xa1`,
        fs:  `cpe:2.3:o:scientificlinux:scientificlinux:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xa5`,
        fs:  `cpe:2.3:a:nih:libzip:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xb`,
        fs:  `cpe:2.3:a:oracle:interaction_blending:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xb3`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xb4`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xb11`,
        fs:  `cpe:2.3:a:pixman:pixman:0.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xb14`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xb15`,
        fs:  `cpe:2.3:h:3com:webbngss3nbxnts:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xf`,
        fs:  `cpe:2.3:a:joomla-cbe:com_cbe:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xg`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xh`,
        fs:  `cpe:2.3:a:hummingbird:cyberdocs:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xh2`,
        fs:  `cpe:2.3:a:anixis:password_policy_client:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xh3`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xi`,
        fs:  `cpe:2.3:a:adobe:graphics_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xi1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xi2`,
        fs:  `cpe:2.3:a:apache:http_server:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xj`,
        fs:  `cpe:2.3:a:google:v8:3.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xj1`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xk`,
        fs:  `cpe:2.3:a:twistedmatrix:twisted:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xk2`,
        fs:  `cpe:2.3:a:platform:lsadmin:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xn`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xr`,
        fs:  `cpe:2.3:a:debian:adequate:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xt`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xt3`,
        fs:  `cpe:2.3:a:teamquest:view:10.1_pf_20080815:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xu`,
        fs:  `cpe:2.3:a:microsoft:system.net.http.winhttphandler:4.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29xu2`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:1.9.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282%29yc`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%282.2%29t`,
        fs:  `cpe:2.3:a:versentbooks:versent_books:1.1.99:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%283%29`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%283.4%29bp`,
        fs:  `cpe:2.3:a:emc:networker:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%283d%29`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.43:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29`,
        fs:  `cpe:2.3:a:perl:perl:0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29b`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jpc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29b1`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnitouch_8460_advanced_communication_server:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29b2`,
        fs:  `cpe:2.3:o:asus:rt-ac68u_firmware:3.0.0.4.374.5047:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29b3`,
        fs:  `cpe:2.3:a:php:php:5.5.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29b4`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29bc1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29bc1a`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29bx`,
        fs:  `cpe:2.3:a:isc:bind:8.2.3:t9b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ja`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ja1`,
        fs:  `cpe:2.3:h:ibm:power_5:9406-520:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29mb3`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29mb12`,
        fs:  `cpe:2.3:a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29mb13b`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29mb13c`,
        fs:  `cpe:2.3:a:is_my_json_valid_project:is_my_json_valid:2.12.3:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29mx`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.b0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29mx1`,
        fs:  `cpe:2.3:a:cisco:acs_for_windows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29t`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29t1`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29t3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29t6`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29xl`,
        fs:  `cpe:2.3:o:juniper:junose_j:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29xl4`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29xm`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29xm2`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper_live_streaming_integration:4.27.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29xr`,
        fs:  `cpe:2.3:a:microsoft:excel:2013:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29xw`,
        fs:  `cpe:2.3:a:avg:secure_search_toolbar:18.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29xw1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ya`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ya1`,
        fs:  `cpe:2.3:a:xfree86:xfree86:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ya7`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ya8`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ya9`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0078:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ya10`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.3\(1.200\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29ya11`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%284%29yb`,
        fs:  `cpe:2.3:a:redmine:redmine:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%285%29`,
        fs:  `cpe:2.3:h:cisco:ips_nme:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%285%29ca1`,
        fs:  `cpe:2.3:h:hp:color_laserjet_2500l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%285d%29`,
        fs:  `cpe:2.3:o:f5:tmos:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%286.8%29t0a`,
        fs:  `cpe:2.3:a:sun:java_dynamic_management_kit:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%286.8%29t1a`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%286.8a%29`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%286c%29`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%287%29`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%287%29da`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%287.4%29s`,
        fs:  `cpe:2.3:a:roy_baxter:better_revisions:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%287a%29`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.4794-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%287b%29`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%287c%29`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29bc1`,
        fs:  `cpe:2.3:h:hp:ce993a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29ja`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29t`,
        fs:  `cpe:2.3:h:cisco:sf300-48pp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29t10`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_redundant_controller_firmware:20.050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29tpc10a`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:10.5\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29yd`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29yw2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29yw3`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29yy`,
        fs:  `cpe:2.3:o:cisco:staros:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29yy3`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%288%29zb7`,
        fs:  `cpe:2.3:a:psi-plus:psi:0.15.5122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%289%29s`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%289.4%29da`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2810%29da2`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2810%29da4`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2810.5%29s`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2810g%29`,
        fs:  `cpe:2.3:a:siemens:sinema_server:12.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29bc3c`,
        fs:  `cpe:2.3:a:gentoo:xnview:1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29ja`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29ja1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.2.0-beta:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29t`,
        fs:  `cpe:2.3:a:arg0:encfs:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29t2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29t3`,
        fs:  `cpe:2.3:a:brocade:smi_agent:120.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29t8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29t9`,
        fs:  `cpe:2.3:a:gnome:tomboy:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29yp1`,
        fs:  `cpe:2.3:a:justsystems:atok_flat-rate_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29yu`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29yv`,
        fs:  `cpe:2.3:a:shavlik:netchk_configure:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29yx1`,
        fs:  `cpe:2.3:a:palosanto:elastix:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2811%29yz2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812%29`,
        fs:  `cpe:2.3:a:altiris:connector_solution_documentation:6.5.1026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812%29da3`,
        fs:  `cpe:2.3:o:juniper:junos:14.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812%29da8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1eu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812%29da9`,
        fs:  `cpe:2.3:a:opnet:model_library:15.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812.02%29s`,
        fs:  `cpe:2.3:a:gfi:gfi_languard:9.6.2010.1113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812.02%29t`,
        fs:  `cpe:2.3:a:samba:samba:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812.05%29`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812.05%29s`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812.05%29t`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812b%29`,
        fs:  `cpe:2.3:a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.4:1:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812c%29`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812g%29`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1026:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812h%29`,
        fs:  `cpe:2.3:o:huawei:s2300_firmware:v100r006c01spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812i%29`,
        fs:  `cpe:2.3:a:schedmd:slurm:17.02.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2812m%29`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29ja1`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:1.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29mc1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29t`,
        fs:  `cpe:2.3:a:ideamk:eps_viewer:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29t1`,
        fs:  `cpe:2.3:a:isc:dhcp:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29t9`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29t14`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.0.1:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29t16`,
        fs:  `cpe:2.3:a:symantec:veritas_update:1.0.5629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zc`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(10\)s8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zd`,
        fs:  `cpe:2.3:a:tenable:securitycenter:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zd3`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zd4`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29ze`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zf`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.62:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zg`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zh`,
        fs:  `cpe:2.3:a:directadmin:directadmin:1.403:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zh3`,
        fs:  `cpe:2.3:a:gnu:ksymoops:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zh8`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zj`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zk`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813%29zl`,
        fs:  `cpe:2.3:o:hp:futuresmart_firmware:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813.03%29b`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813a%29`,
        fs:  `cpe:2.3:a:redhat:network_satellite:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2813e%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29s`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.6p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29s13`,
        fs:  `cpe:2.3:a:exim:exim:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29s14`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.7.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29s15`,
        fs:  `cpe:2.3:a:twiki:twiki:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29su2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29sx1`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29sy`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29sy1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.0:pr:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29sy03`,
        fs:  `cpe:2.3:a:isc:bind:9.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29sz`,
        fs:  `cpe:2.3:a:ultraseek:ultraseek:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29sz1`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.0e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29sz2`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29za`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29za2`,
        fs:  `cpe:2.3:a:shawn_bradley:php_volunteer_management:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814%29za8`,
        fs:  `cpe:2.3:a:skype:skype:4.2.0.158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814.5%29`,
        fs:  `cpe:2.3:a:gnu:less:358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2814.5%29t`,
        fs:  `cpe:2.3:a:ibm:rational_service_tester:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29b`,
        fs:  `cpe:2.3:a:ca:unicenter_nsm:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29bc`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29bc1`,
        fs:  `cpe:2.3:a:adobe:robohelp:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29bc1f`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29bc2f`,
        fs:  `cpe:2.3:a:xnview:xnview:1.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29bc2h`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29bc2i`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29bx`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29bz`,
        fs:  `cpe:2.3:a:google:sketchup:7.1:maintenance_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29cx`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29cz3`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29jk2`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29jk4`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29jk5`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-02-16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29mc1`,
        fs:  `cpe:2.3:a:autodesk:autocad_architecture_2010:6.0.56.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29mc2c`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29mc2e`,
        fs:  `cpe:2.3:a:iss:proventia_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29sl1`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29t`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29t5`,
        fs:  `cpe:2.3:a:winscp:winscp:3.8_beta:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29t7`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_m1216nfh_mfp:ce843a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29t8`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.1\(1.96\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29t9`,
        fs:  `cpe:2.3:a:php:php:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29t15`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(8a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29t16`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29t17`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2009.925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29xr`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29xr2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29ys`,
        fs:  `cpe:2.3:a:nih:libzip:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29ys_1.2%281%29`,
        fs:  `cpe:2.3:o:novell:suse_linux:11:*:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zj`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zj1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zj2`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zj3`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages:1.8.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zk`,
        fs:  `cpe:2.3:a:jazeeraairways:jazeera_airways:2.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zl`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.0.2:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zl1`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zn`,
        fs:  `cpe:2.3:a:intel:graphics_accelerator_driver:6.14.10.4308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815%29zo`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2815.1%29s`,
        fs:  `cpe:2.3:a:bluecoat:k9_web_protection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2816%29b`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.1:rc1v:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2816%29b1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1690.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2816%29bx`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2816.1%29b`,
        fs:  `cpe:2.3:a:firejail_project:firejail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2816.5%29s`,
        fs:  `cpe:2.3:a:apple:itunes:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2816f%29`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817%29`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817%29a`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817%29zd3`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817a%29`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817a%29sxa`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817b%29sxa`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817d%29`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817d%29sx`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.1.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817d%29sxb`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5502:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817d%29sxb7`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.6200.754:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817d%29sxb8`,
        fs:  `cpe:2.3:a:concord:ehealth_trapexploder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817d%29sxb10`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2817f%29`,
        fs:  `cpe:2.3:h:yokogawa:ejxmvtool:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29ew`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29ew2`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29ew3`,
        fs:  `cpe:2.3:a:opensis:opensis:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29ew5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29ewa`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29s`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29s6`,
        fs:  `cpe:2.3:a:mymobileday1:my_mobile_day:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29s8`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29s9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29s10`,
        fs:  `cpe:2.3:a:bea:weblogic_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29se`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.11:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29so4`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sv`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-50c-pwr-ei_ls-5100-50c-pwr-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sv3`,
        fs:  `cpe:2.3:a:koz.com:ichat_rooms_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sw`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxd1`,
        fs:  `cpe:2.3:a:nokia:3210:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxd4`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxd5`,
        fs:  `cpe:2.3:a:samba:samba:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxd6`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxd7`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxe`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxe1`,
        fs:  `cpe:2.3:a:quest:intrust_administrative_report_pack:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxe3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxf`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.0:update_2_rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxf4`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxf7`,
        fs:  `cpe:2.3:a:hp:loadrunner:9.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818%29sxf8`,
        fs:  `cpe:2.3:a:tablefield_project:tablefield:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2818.2%29`,
        fs:  `cpe:2.3:a:ca:unicenter_management_portal:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2819%29`,
        fs:  `cpe:2.3:a:rack_project:rack:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2819%29b`,
        fs:  `cpe:2.3:a:netscape:communicator:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29eu`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.70.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29eu1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-71-\/g:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29eu2`,
        fs:  `cpe:2.3:a:oracle:configurator:11.5.6.16.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29ew`,
        fs:  `cpe:2.3:a:apple:webkit:419:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29ew2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.306:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29ew3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.20.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29ewa`,
        fs:  `cpe:2.3:a:condor_project:condor:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29ewa2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29ewa3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.603.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29s`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29s1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29s2`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29s4`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29s7`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29s8`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f2-s1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29s9`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2820%29se3`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.827:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2821%29`,
        fs:  `cpe:2.3:a:google:chrome:7.0.536.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2821a%29`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2821b%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2822%29ea6`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.44:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2822%29s`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2822%29s2`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2822%29sv1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2823%29`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2823%29sv1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2823%29sw`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2823.6%29`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2823a%29`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2823f%29`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.037:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2824%29`,
        fs:  `cpe:2.3:a:arellia:arellia_file_inventory_solution:6.1.1312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2824%29sv`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2824%29sv1`,
        fs:  `cpe:2.3:a:openbsd:libressl:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ewa`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ewa1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ewa3`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ewa4`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ex`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ey`,
        fs:  `cpe:2.3:a:safenet-inc:protectpack:2.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ey2`,
        fs:  `cpe:2.3:a:vips:vips:7.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ey3`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ez`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29ez1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29fx`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29fy`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29s`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29s1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29s3`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29s4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29s6`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29se`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29seb`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29seb2`,
        fs:  `cpe:2.3:a:google:chrome:11.0.679.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29seb3`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29seb4`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sec1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sec2`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:11.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sed`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r2.13_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sg`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sv2`,
        fs:  `cpe:2.3:a:samba:samba:3.0.21b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sw`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sw3a`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sw4`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2825%29sw4a`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2826%29sv`,
        fs:  `cpe:2.3:a:ubnt:unifi_controller:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2826%29sv1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2826b%29`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2827%29sbc`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2827%29sv1`,
        fs:  `cpe:2.3:a:homepage_decorator:perltreebbs:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2827b%29`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb`,
        fs:  `cpe:2.3:a:apploi:apploi_job_search-_find_jobs:4.19:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb1`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb3`,
        fs:  `cpe:2.3:a:haxx:curl:7.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb4`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.4:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb5`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb6`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.4-57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb7`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb8`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb9`,
        fs:  `cpe:2.3:a:tryton:trytond:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb10`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update5:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb11`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(13b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb12`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828%29sb13`,
        fs:  `cpe:2.3:a:projectforge:projectforge:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2828c%29`,
        fs:  `cpe:2.3:a:apache:sentry:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2829a%29`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.341:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2830%29s1`,
        fs:  `cpe:2.3:a:hp:alm-platform_loader:11.0.5373.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb2`,
        fs:  `cpe:2.3:a:ibm:tivoli_secureway_policy_director:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb3`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.2:rp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb3x`,
        fs:  `cpe:2.3:a:hp:lp6940_help:60.0.196.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb5`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb6`,
        fs:  `cpe:2.3:a:hp:device_discovery:100.0.190.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb7`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb9`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.9:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb10`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb11`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb12`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta41:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb13`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb14`,
        fs:  `cpe:2.3:a:drupal:drupal:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb15`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb16`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb17`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb19`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb20`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2831%29sb21`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29ird1`,
        fs:  `cpe:2.3:a:invage:views:6.x-2.16:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29ire3`,
        fs:  `cpe:2.3:h:huawei:campus_s9300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb`,
        fs:  `cpe:2.3:h:linksys:befw11s4:1.40.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb2`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:6.5.4:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb3`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb4`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb5`,
        fs:  `cpe:2.3:h:buffalotech:whr-300hp2_firmware:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb6`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpq\/epq2160:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb7`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb8`,
        fs:  `cpe:2.3:a:field_display_label_project:field_display_label:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb8a`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sb9`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29scj1a`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29scj1b`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29scj2`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29scj2a`,
        fs:  `cpe:2.3:a:hp:hppfonts:1.1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sre`,
        fs:  `cpe:2.3:a:gnu:enscript:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sre0a`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sre1`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.14:beta:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sre2`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3204a:a.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sre3`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh`,
        fs:  `cpe:2.3:a:google:v8:3.24.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh1`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh2`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh2a`,
        fs:  `cpe:2.3:a:microsoft:virtual_pc:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh3`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh3a`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh5`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh6`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.09.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh7`,
        fs:  `cpe:2.3:a:microsoft:excel_rt:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh8`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh8a`,
        fs:  `cpe:2.3:a:adobe:flash_player:8.0.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxh8b`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2008:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi1`,
        fs:  `cpe:2.3:o:tp-link:tl-wrd841nd_\(9.0\)_firmware:150104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi2`,
        fs:  `cpe:2.3:a:bullguard:internet_security:14.1.287:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi2a`,
        fs:  `cpe:2.3:h:cisco:ubr924:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi3`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi4b`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi5`,
        fs:  `cpe:2.3:h:lexmark:x782e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi6`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxi7`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxj`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29sxj8`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2833%29xn1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2844%29ex`,
        fs:  `cpe:2.3:a:apache:camel:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2844%29ex1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2844%29sq1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2846%29se`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2846%29se1`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2846%29se2`,
        fs:  `cpe:2.3:o:apple:watchos:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29se`,
        fs:  `cpe:2.3:a:inria:ocaml:3.07:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29se1`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29se2`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29se3`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29se4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29se5`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.4:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29sy`,
        fs:  `cpe:2.3:a:ca:cleverpath_aion:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29sy1`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29sy2`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29sy3`,
        fs:  `cpe:2.3:a:citrix:ica_program_neighborhood_client:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2850%29sy4`,
        fs:  `cpe:2.3:a:hp:ibrix:6.1.249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2852%29se`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2852%29se1`,
        fs:  `cpe:2.3:a:redhat:cloudforms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2853%29sg3`,
        fs:  `cpe:2.3:o:netbsd:netbsd:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2855%29se`,
        fs:  `cpe:2.3:a:zope:zope:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2855%29se3`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2855%29se4`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2855%29se5`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2855%29se6`,
        fs:  `cpe:2.3:a:bamboosolutions:bamboo_license_manager:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2855%29se7`,
        fs:  `cpe:2.3:a:google:chrome:16.0.881.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2855%29se8`,
        fs:  `cpe:2.3:a:openbsd:openbsd:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2855%29se9`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2858%29se`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_real-time_information_portal:3.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2858%29se2`,
        fs:  `cpe:2.3:a:apache:jakarta_slide:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2858%29ses`,
        fs:  `cpe:2.3:o:d-link:dcs-5009l_firmware:1.07.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2860%29ez10`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2%2860%29ez11`,
        fs:  `cpe:2.3:a:devsaran:professional_theme:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2b`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2bc`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2bw`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2bx`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:11.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2by`,
        fs:  `cpe:2.3:a:splunk:splunk:6.4.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2bz`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ca`,
        fs:  `cpe:2.3:a:isc:dnsco_bind:9.9.3:s1-p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2cx`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2cy`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2cz`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2da`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2dd`,
        fs:  `cpe:2.3:a:ni:teststand:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2dx`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2e`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2eu`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ew`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ewa`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ex`,
        fs:  `cpe:2.3:o:f5:tmos:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ey`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_broker:1.1.0-b96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ez`,
        fs:  `cpe:2.3:a:phpipam:phpipam:1.1.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2f`,
        fs:  `cpe:2.3:a:qemu:qemu:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2fx`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.03b27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2fy`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2fz`,
        fs:  `cpe:2.3:a:aol:aolserver:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ira`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2irb`,
        fs:  `cpe:2.3:a:lynx:lynx:2.8.8:dev.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2irc`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.2.2-19.rhel5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ird`,
        fs:  `cpe:2.3:a:mcafee:change_control:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ire`,
        fs:  `cpe:2.3:a:python-gnupg_project:python-gnupg:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2irf`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ixa`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.9.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ixb`,
        fs:  `cpe:2.3:a:ibm:license_metric_tool:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ixc`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ixd`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ixe`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(5.38\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ixf`,
        fs:  `cpe:2.3:a:samsung:kies:2.3.2.12074_13_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ixg`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ixh`,
        fs:  `cpe:2.3:a:php:php:5.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.2ja`,
        fs:  `cpe:2.3:a:netscape:navigator:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ja`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.2jk`,
        fs:  `cpe:2.3:a:orcacle:retail_point-of-service:13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2jk`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2jx`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-00-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2mb`,
        fs:  `cpe:2.3:a:augeas:augeas:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.2mc`,
        fs:  `cpe:2.3:a:oracle:communications_operations_monitor:3.3.92.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2mc`,
        fs:  `cpe:2.3:a:mybb:mybb:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2mra`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62u:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2mrb`,
        fs:  `cpe:2.3:a:freerdp_project:freerdp:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2mx`,
        fs:  `cpe:2.3:a:tryton:trytond:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2n`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2pb`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2pi`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2s`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sa`,
        fs:  `cpe:2.3:a:hp:hppiofiles:1.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sb`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.14:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sbc`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sca`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2scb`,
        fs:  `cpe:2.3:a:ultimus:adaptive_bpm_suite:8.2_cp3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2scc`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2scd`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sce`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)xm4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2se`,
        fs:  `cpe:2.3:a:tibco:spotfire_analytics_platform_for_aws:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sea`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2seb`,
        fs:  `cpe:2.3:a:ca:unicenter_asset_management:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sec`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.7.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sed`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:5.2:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2see`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sef`,
        fs:  `cpe:2.3:a:microsoft:word:2010:sp1:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2seg`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert1_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sg`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sga`,
        fs:  `cpe:2.3:a:apache:subversion:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sh`,
        fs:  `cpe:2.3:o:comcast:xfinity_home_security_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sm`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.2so`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.16.8:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2so`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sq`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sra`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2srb`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2src`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.7.11-4:beta-25.14.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2srd`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sre`,
        fs:  `cpe:2.3:a:intsig:innote:1.0.3.20131119:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ste`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2su`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)ewa2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sv`,
        fs:  `cpe:2.3:a:apache:wicket:6.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sva`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2svc`,
        fs:  `cpe:2.3:a:keepass:keepass:1.19:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2svd`,
        fs:  `cpe:2.3:a:ibm:global_retention_policy_and_schedule_management:6.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sve`,
        fs:  `cpe:2.3:a:emc:rsa_authentication_agent:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sw`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sx`,
        fs:  `cpe:2.3:o:ibm:vios:2.1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sxa`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sxb`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.373:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sxd`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sxe`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sxf`,
        fs:  `cpe:2.3:a:digium:asterisk:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sxh`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sxi`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sxj`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sy`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:6.1.x_ee:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2sz`,
        fs:  `cpe:2.3:a:altiris:monitor_solution_for_dell_servers_documentation:6.1.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2t`,
        fs:  `cpe:2.3:h:samsung:ps50c7700_television:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2tpc`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.00:release_candidate:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2x`,
        fs:  `cpe:2.3:o:huawei:s6700_firmware:v200r009c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xa`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xb`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xc`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xd`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xe`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xf`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xg`,
        fs:  `cpe:2.3:a:hummingbird:bi_query:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xh`,
        fs:  `cpe:2.3:h:dell:wyse_p25:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xi`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xj`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.0_mr_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xk`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xl`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xm`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.1\(4.206\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xn`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xna`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xnb`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:gold:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xnc`,
        fs:  `cpe:2.3:a:apache:camel:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xnd`,
        fs:  `cpe:2.3:a:emerson:deltav_workstation:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xne`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xnf`,
        fs:  `cpe:2.3:a:citrix:xenapp_group_policy_management_experience:1.0.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xo`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xq`,
        fs:  `cpe:2.3:a:oracle:application_object_library:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xr`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.5:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xs`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.82.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xt`,
        fs:  `cpe:2.3:a:macromedia:jrun:3.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xu`,
        fs:  `cpe:2.3:h:hp:laserjet_m4555f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xv`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xw`,
        fs:  `cpe:2.3:a:sun:java_system_messenger_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2xz`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:sp1a:developer:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ya`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yb`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00-\/e:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yc`,
        fs:  `cpe:2.3:a:tumbleweed:mailgate_email_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yd`,
        fs:  `cpe:2.3:a:embedthis:goahead:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ye`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yf`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(6a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yg`,
        fs:  `cpe:2.3:a:openstack:grizzly:2013.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yh`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yj`,
        fs:  `cpe:2.3:o:schneider-electric:tburjr900_firmware:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yk`,
        fs:  `cpe:2.3:a:rom_walton:boinc:6.12.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yl`,
        fs:  `cpe:2.3:a:almas:compiere:j300_a02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ym`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.3:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yn`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yo`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yp`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p341:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yq`,
        fs:  `cpe:2.3:a:google:kubernetes:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yr`,
        fs:  `cpe:2.3:a:busybox:busybox:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ys`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yt`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.57:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yu`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yv`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yw`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yx`,
        fs:  `cpe:2.3:a:microsoft:ie:4.40.520:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yy`,
        fs:  `cpe:2.3:a:x:libxres:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2yz`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p249:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2za`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zb`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zc`,
        fs:  `cpe:2.3:a:adobe:photoshop:16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zd`,
        fs:  `cpe:2.3:a:horde:groupware:5.0.2:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2ze`,
        fs:  `cpe:2.3:a:omeka:omeka:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zf`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zg`,
        fs:  `cpe:2.3:h:siemens:sinamics_g120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zh`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zi`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zj`,
        fs:  `cpe:2.3:a:iss:realsecure_server_sensor:7.0:sr4.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zk`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zl`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1665.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zm`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zn`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zo`,
        fs:  `cpe:2.3:h:softbank:disney_mobile_android_smartphone:dm012sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zp`,
        fs:  `cpe:2.3:a:nagios:nagios:4.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zq`,
        fs:  `cpe:2.3:a:sun:iplanet_messaging_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zu`,
        fs:  `cpe:2.3:h:canon:eos_d60:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zx`,
        fs:  `cpe:2.3:a:google:chrome:6.0.481.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zy`,
        fs:  `cpe:2.3:a:parsagostar:parsaweb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.2zya`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.0:sbs4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%281a%29`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29ja`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29ja5`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29jk`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.3.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29jk1`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29t3`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29t8`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29xa4`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.0.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29xa5`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.00.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29xc1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29xc2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd353a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29xc3`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.d1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29xc4`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.5:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29xe3`,
        fs:  `cpe:2.3:a:google:v8:3.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%282%29xe4`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%283e%29`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%283h%29`,
        fs:  `cpe:2.3:a:gentoo:libsndfile:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%283i%29`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29eo1`,
        fs:  `cpe:2.3:a:jason_moore:amadou:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29ja`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29ja1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29t`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.15a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29t1`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29t2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29t3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29t4`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29t8`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29tpc11a`,
        fs:  `cpe:2.3:a:google:chrome:5.0.382.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xd`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass_guest:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xd1`,
        fs:  `cpe:2.3:a:goo:dj_brad_h:0.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xd2`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xe4`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xg1`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:2.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xg2`,
        fs:  `cpe:2.3:a:xymon:xymon:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xg4`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xg5`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xh`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xk`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xk1`,
        fs:  `cpe:2.3:h:irz:ruh2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xk3`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xk4`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:1.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xq`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%284%29xq1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285%29`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285%29b1`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285a%29`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285a%29b`,
        fs:  `cpe:2.3:h:tp-link:tl-sc3130g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285a%29b2`,
        fs:  `cpe:2.3:o:sun:solaris:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285a%29b5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285b%29`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285c%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:2.1\(1.33\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285e%29`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%285f%29`,
        fs:  `cpe:2.3:a:samba:samba:3.0.27:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%286%29`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%286a%29`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%286d%29`,
        fs:  `cpe:2.3:a:ca:etrust_audit_irecorder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%286e%29`,
        fs:  `cpe:2.3:a:ca:unicenter_software_delivery:3.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%286f%29`,
        fs:  `cpe:2.3:h:y-cam:ycb004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29ja`,
        fs:  `cpe:2.3:a:spip:spip:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29ja1`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29jx`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29t`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)sl2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29t4`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29t8`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29t9`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.9:bundle26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29t10`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29t12`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29xi3`,
        fs:  `cpe:2.3:a:acquia:commons:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29xi4`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29xi7`,
        fs:  `cpe:2.3:a:ldap-account-manager:ldap_account_manager:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29xr3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3jl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29xr4`,
        fs:  `cpe:2.3:h:hp:service_manager:9.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287%29xr6`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%287.7%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29ja`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29ja1`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.2_build172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29t4`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29t7`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phones_9900_series_firmware:9.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29t8`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29t9`,
        fs:  `cpe:2.3:a:redaxo:redaxo:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29t11`,
        fs:  `cpe:2.3:a:cognos:go\!_office:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29xu2`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29xy4`,
        fs:  `cpe:2.3:a:twilio_project:twilio:7.x-1.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29xy5`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29xy6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29ya1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yd`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yf`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(8.2\)sa6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yg`,
        fs:  `cpe:2.3:a:adobe:after_effects:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yg1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yg2`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.10.2:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yg3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yh`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(7.4\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yi`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yi1`,
        fs:  `cpe:2.3:a:commons_wikis_project:commons_wikis:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%288%29yi3`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%289%29`,
        fs:  `cpe:2.3:a:haxx:curl:7.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%289a%29bc`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%289a%29bc2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%289a%29bc6`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%289a%29bc7`,
        fs:  `cpe:2.3:h:netgear:dg834gt:1.01.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%289d%29`,
        fs:  `cpe:2.3:a:netty_project:netty:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%289e%29`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2810%29`,
        fs:  `cpe:2.3:a:microsoft:ie:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2810c%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2810d%29`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2810e%29`,
        fs:  `cpe:2.3:a:gnu:libtasn1:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29`,
        fs:  `cpe:2.3:a:emc:powerpath:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29t`,
        fs:  `cpe:2.3:h:dell:poweredge_r720:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29t4`,
        fs:  `cpe:2.3:a:artifex:ghostscript:8_64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29t5`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.0\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29t6`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29t8`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29t9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29xl`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29xl3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p124:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yf`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yf2`,
        fs:  `cpe:2.3:h:nortel:ip_phone_1120e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yf3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yf4`,
        fs:  `cpe:2.3:a:opsview:opsview:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yj`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yk`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yk1`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_m1536dnf_multifunction_printer:ce538a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yk2`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yl`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yn`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yr`,
        fs:  `cpe:2.3:o:cisco:300_series_managed_switch_firmware:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29ys`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29ys1`,
        fs:  `cpe:2.3:a:bizagi:business_process_management_suite:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2811%29yw`,
        fs:  `cpe:2.3:a:apple:iphoto:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2812%29`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2812b%29`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1043:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2812e%29`,
        fs:  `cpe:2.3:a:winpcap:winpcap:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2813%29`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.26:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2813a%29`,
        fs:  `cpe:2.3:a:nvidia:install_application:2.275.80.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2813a%29bc`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2813a%29bc1`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2813b%29`,
        fs:  `cpe:2.3:a:alberto_trujillo_gonzalez:protest:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29t`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29t2`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.8.1.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29t4`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29t5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29ym4`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29yq`,
        fs:  `cpe:2.3:a:busybox:busybox:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29yq1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.24:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29yq3`,
        fs:  `cpe:2.3:a:citrix:metaframe:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29yq4`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29yt`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29yt1`,
        fs:  `cpe:2.3:a:hp:asset_manager:9.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29yu`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2814%29yu1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2815%29`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.12:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2815b%29`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3%2816%29`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3b`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:7.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3bc`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3bw`,
        fs:  `cpe:2.3:a:quest:messagestats:6.5.1.1276:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3j`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3ja`,
        fs:  `cpe:2.3:a:isc:bind:9.2.4:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3jea`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3jeb`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3jec`,
        fs:  `cpe:2.3:a:apache:activemq:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3jed`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router:1.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3jk`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3jl`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3jx`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:2.2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3t`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3tpc`,
        fs:  `cpe:2.3:a:emc:web_publishers:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3va`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xa`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xb`,
        fs:  `cpe:2.3:a:apple:cups:1.1.20:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xc`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xd`,
        fs:  `cpe:2.3:a:microsoft:office:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xe`,
        fs:  `cpe:2.3:a:invensys:wonderware_inbatch:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xf`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.5:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xg`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xh`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xi`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(2m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.3xj`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xj`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xk`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xl`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xm`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xn`,
        fs:  `cpe:2.3:a:rsa:access_manager_server:6.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xq`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.992_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xr`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xs`,
        fs:  `cpe:2.3:a:ca:common_services:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xt`,
        fs:  `cpe:2.3:a:hp:document_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xu`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xv`,
        fs:  `cpe:2.3:a:red-gate:sql_packager:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xw`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xx`,
        fs:  `cpe:2.3:a:adobe:winsoft_linguistics_plugin:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xy`,
        fs:  `cpe:2.3:a:7-zip:p7zip:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3xz`,
        fs:  `cpe:2.3:a:gnu:gdb:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3ya`,
        fs:  `cpe:2.3:a:bluecoat:proxyclient:3.4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yb`,
        fs:  `cpe:2.3:a:openstack:juno:2014.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yc`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yd`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3ye`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yf`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yg`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yh`,
        fs:  `cpe:2.3:a:cisco:vspt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.3yi`,
        fs:  `cpe:2.3:a:quest:spotlight_on_oracle:7.6.0.1559:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yi`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yj`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yk`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yl`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3ym`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_unix_and_openvms:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yn`,
        fs:  `cpe:2.3:h:brickom:osd-040e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yq`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yr`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.23.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3ys`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yt`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yu`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yw`,
        fs:  `cpe:2.3:a:exim:exim:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yx`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:1.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3yz`,
        fs:  `cpe:2.3:a:solarwinds:real-time_bandwidth_monitor:1.0.0.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.3za`,
        fs:  `cpe:2.3:a:mcafee:agent:4.6.0.3258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4`,
        fs:  `cpe:2.3:a:ibm:iss_proventia_desktop:1780:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%281%29`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%281b%29`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%281c%29`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29mr`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:02-50-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29mr1`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29t`,
        fs:  `cpe:2.3:h:hp:jg517a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29t1`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29t2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29t3`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29t4`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29xa`,
        fs:  `cpe:2.3:h:cisco:nexus_9236c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29xb`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%282%29xb2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp3:datacenter_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%283%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%283%29t2`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6-9-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%283a%29`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%283b%29`,
        fs:  `cpe:2.3:o:tropos:mesh_os:7.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%283d%29`,
        fs:  `cpe:2.3:a:hrblock:taxcut_deluxe_\&#43;_efile_\&#43;_state_2010:10.4.6402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%284%29mr`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%284%29t`,
        fs:  `cpe:2.3:a:connections_project:connections:0.5.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%284%29t2`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%285%29`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.6:pre8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%285b%29`,
        fs:  `cpe:2.3:a:x.org:libx11:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%286%29t`,
        fs:  `cpe:2.3:a:emc:documentum_digital_asset_manager:6.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%286%29t1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2.2\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%287%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.581:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%287a%29`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%288%29`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%289%29t`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2811%29md`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_manager:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2815%29md`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.0.4:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2815%29xq1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2822%29md`,
        fs:  `cpe:2.3:a:citrix:netscaler:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2822%29mda`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2823%29`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2823%29jy`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29md`,
        fs:  `cpe:2.3:a:atlassian:jira:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29md1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29md2`,
        fs:  `cpe:2.3:a:debian:mime-support:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29md3`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29md4`,
        fs:  `cpe:2.3:a:ibm:daeja_viewone:4.1.5.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda`,
        fs:  `cpe:2.3:h:supermicro:x7spe-h-d525:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda6`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_415_382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda7`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda8`,
        fs:  `cpe:2.3:a:microsoft:visio_2000:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda9`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda10`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda11`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda12`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mda13`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb5`,
        fs:  `cpe:2.3:a:tasofro:touhou-hisouten:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb5a`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.4:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb7`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb8`,
        fs:  `cpe:2.3:a:gentoo:media-libs_jpeg:6b:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.9:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb10`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb11`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb12`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb13`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb14`,
        fs:  `cpe:2.3:a:python:python:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb15`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29mdb16`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2824%29t1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2825e%29jam1`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2825e%29jam6`,
        fs:  `cpe:2.3:a:cisco:vpn_client:4.0.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2825e%29jao5m`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2825e%29jap1m`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2825e%29jap10`,
        fs:  `cpe:2.3:a:gnome:glib:2.44.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%2825e%29jaz1`,
        fs:  `cpe:2.3:a:digium:asterisk:11.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4%28122%29t`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4gc`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4ja`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4jda`,
        fs:  `cpe:2.3:a:searchblox:searchblox:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4jdc`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:sv:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4jdd`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.9.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4jk`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4jl`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1652.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4jma`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4jmb`,
        fs:  `cpe:2.3:a:ontariosystems:artiva_architect:3.2:mr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4jx`,
        fs:  `cpe:2.3:a:cisco:catalyst_29xx_supervisor_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4md`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4mda`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4mda12`,
        fs:  `cpe:2.3:a:hrblock:taxcut_maryland_2010:1.10.2401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4mdb`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4mr`,
        fs:  `cpe:2.3:a:ibm:mashups_center:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4mra`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4mrb`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4sw`,
        fs:  `cpe:2.3:a:icinga:icinga:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4t`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xa`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xb`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xc`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xd`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xe`,
        fs:  `cpe:2.3:a:openstack:havana:havana-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.4xf`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xf`,
        fs:  `cpe:2.3:a:pythonware:python_imaging_library:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xg`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xj`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xk`,
        fs:  `cpe:2.3:a:google:v8:3.24.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ios:12.4xl`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xl`,
        fs:  `cpe:2.3:h:cisco:sf500-48p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xm`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xn`,
        fs:  `cpe:2.3:a:symantec:raptor_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xp`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p112:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xq`,
        fs:  `cpe:2.3:o:yamaha:rta54i:4.04.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xr`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xt`,
        fs:  `cpe:2.3:a:microsoft:onenote:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xv`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.0.0:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xw`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xy`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_web_premium:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4xz`,
        fs:  `cpe:2.3:a:citrix:xenapp_server_configuration_tool:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4ya`,
        fs:  `cpe:2.3:a:google:chrome:11.0.654.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4yb`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4yd`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4ye`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:12.4yg`,
        fs:  `cpe:2.3:a:hp:jg786a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%281%29ey`,
        fs:  `cpe:2.3:a:youmail:youmail_visual_voicemail_plus:2.1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%281%29ey1`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.1_beta:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%281%29ey2`,
        fs:  `cpe:2.3:a:jruby:jruby:1.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%281%29se`,
        fs:  `cpe:2.3:a:oracle:right_now_service_cloud:8.2.3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29ea1`,
        fs:  `cpe:2.3:a:teradata:tdput:3.5.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29eb`,
        fs:  `cpe:2.3:a:cisco:finesse:8.5\(5\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29ed1`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29ey`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29ey1`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29ey2`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.1.2:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29ey3`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se1`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se2`,
        fs:  `cpe:2.3:o:datumsystems:snip:-:*:*:*:*:*:psm-4500:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se3`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se5`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se6`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se7`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se8`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se9`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se10a`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:4.0.0.12305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29se11`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29sqd5`,
        fs:  `cpe:2.3:a:honeywell:symmetre:r310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282%29sqd6`,
        fs:  `cpe:2.3:h:cisco:ios:12.3yi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0%282a%29se9`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0dpa`,
        fs:  `cpe:2.3:a:sybase:pylon_anywhere:6.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0dpb`,
        fs:  `cpe:2.3:a:oracle:commerce_platform:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0m`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0mr`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0mra`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0s`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4.1012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0sa`,
        fs:  `cpe:2.3:a:gnome:gcab:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0sg`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0sid`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.20.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0xa`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.0xo`,
        fs:  `cpe:2.3:a:digium:asterisk:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1`,
        fs:  `cpe:2.3:a:python:pillow:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29s`,
        fs:  `cpe:2.3:h:nvidia:nvs_315:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29s1`,
        fs:  `cpe:2.3:a:php:pear:1.3b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29s2`,
        fs:  `cpe:2.3:a:samba:samba:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29sg`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29sg1`,
        fs:  `cpe:2.3:a:docker:docker:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29sg2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29sy`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29sy1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29sy2`,
        fs:  `cpe:2.3:a:lightscribe:lightscribe:1.4.74.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29sy3`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%281%29sy6`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1015:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29s`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29s1`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.2.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29s2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg`,
        fs:  `cpe:2.3:a:divx:divx_converter:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg1`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.54:bpet54p:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg2`,
        fs:  `cpe:2.3:a:pocketmags:pony_magazine:\@7f080193:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg3`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg4`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg5`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.210:update21:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg6`,
        fs:  `cpe:2.3:a:microsoft:office:97:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg7`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg7a`,
        fs:  `cpe:2.3:a:gnu:queue:1.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sg9`,
        fs:  `cpe:2.3:a:emc:documentum_digital_asset_manager:6.5:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sng`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29snh`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sni`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sni1`,
        fs:  `cpe:2.3:o:dell:idrac7_firmware:1.00.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sy`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sy1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sy2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p394:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sy3`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sy6`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sy7`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sy8`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282%29sy10`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%282a%29sg7`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29mr`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29mra`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29mra1`,
        fs:  `cpe:2.3:a:hp:hpztlbxfx:2.2.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29mra2`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.4.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29mra3`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29mra4`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:cf08:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s0a`,
        fs:  `cpe:2.3:a:ektron:ektron_content_management_system:9.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s1`,
        fs:  `cpe:2.3:o:tp-link:tl-wr740n_\(5.0\)_firmware:141217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s2`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_management_center_for_ids_sensors:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s3`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s5`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.10.3:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s5a`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29s6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%283%29svf4a`,
        fs:  `cpe:2.3:a:sybase:powerdesigner_repository_proxy_:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%284%29m2`,
        fs:  `cpe:2.3:a:php:php:7.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1%284%29m12a`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1ey`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.39:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1gc`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p357:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1m`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1s`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1sg`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1t`,
        fs:  `cpe:2.3:a:adobe:acrobat:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.1xb`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%281%29ex`,
        fs:  `cpe:2.3:a:python:pyxdg:0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%281%29ey`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%281%29sy4`,
        fs:  `cpe:2.3:h:cisco:gss_4491_global_site_selector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29e`,
        fs:  `cpe:2.3:o:schneider-electric:tburjr900_firmware:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29e1`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29e3`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29e5a`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29e5b`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1049:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29e6`,
        fs:  `cpe:2.3:a:telos:amhs:13.1.0.550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29e7`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ios:15.2%282%29ea`,
        fs:  `cpe:2.3:a:ashok88:jja-_juvenile_justice_act_1986:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ios:15.2%282%29ea1`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29ea2`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29ea3`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ios:15.2%282%29eb`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ios:15.2%282%29eb1`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29gc`,
        fs:  `cpe:2.3:h:supermicro:x9drh-7tf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29ja`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29ja1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jax`,
        fs:  `cpe:2.3:h:hp:755_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jax1`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jb`,
        fs:  `cpe:2.3:a:s3-video_project:s3-video:0.983:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jb1`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jb2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jb3`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jb4`,
        fs:  `cpe:2.3:a:polycom:dma_system_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jn1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29jn2`,
        fs:  `cpe:2.3:a:stefan_tannhaeuser:tv21_talkshow:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29sy3`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29t`,
        fs:  `cpe:2.3:h:linksys:befvp41:1.40.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29t1`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29t2`,
        fs:  `cpe:2.3:a:wdc:drive_manager:2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29t3`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%282%29t4`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%283%29e3`,
        fs:  `cpe:2.3:h:hp:jg821a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%283%29e5`,
        fs:  `cpe:2.3:a:google:chrome:7.0.535.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%283%29t`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%283m%29e8`,
        fs:  `cpe:2.3:a:cisco:finesse:10.6\(1\)_su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29e`,
        fs:  `cpe:2.3:h:hp:h3c_router:sr8805:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29e1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.3:1005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29e3`,
        fs:  `cpe:2.3:a:david_king:vino:2.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29e4`,
        fs:  `cpe:2.3:a:oracle:customer_intelligence:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29ea`,
        fs:  `cpe:2.3:a:skype:skype:3.5.0.229:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29ea1`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_mobile:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29ea3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29ea4`,
        fs:  `cpe:2.3:a:ipswitch:imail:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29ec`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29ec1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29ec2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29m4`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29pi`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284%29st`,
        fs:  `cpe:2.3:a:microsoft:expression_design:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284m%29e3`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284n%29e2`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284o%29e2`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%284p%29e1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.15:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285%29e1`,
        fs:  `cpe:2.3:a:hp:network_automation:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285%29e2`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285%29e2a`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71-\/g:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285%29e2c`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285%29ea`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285%29ex`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285%29st`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285a%29e`,
        fs:  `cpe:2.3:a:payment_for_webform_project:payment_for_webform:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285a%29e1`,
        fs:  `cpe:2.3:o:cray:unicos_mk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285b%29e`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.2%285c%29e`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%281%29s1`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%281%29s2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p257:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%281%29sy2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.325:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%282%29s`,
        fs:  `cpe:2.3:a:sun:jre:6.0.110:update11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%282%29s0a`,
        fs:  `cpe:2.3:a:devsaran:professional_theme:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%282%29s1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%282%29s2`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%282%29t3`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.767:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29ja`,
        fs:  `cpe:2.3:a:apple:bonjour:2.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29ja1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29ja1m`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.4.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29ja1n`,
        fs:  `cpe:2.3:a:qemu:qemu:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29ja10`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta36:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jaa`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jab`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jab1`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jn`,
        fs:  `cpe:2.3:a:emc:documentum_digital_asset_manager:6.5:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jnb`,
        fs:  `cpe:2.3:h:snapgear:720:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jnc2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jnc3`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jnd`,
        fs:  `cpe:2.3:a:nero:mediahome_ce:1.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jnp3`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jpb1`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jpb2`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.13:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jpc`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jpc1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:08-00:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29jpc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29m`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29m1`,
        fs:  `cpe:2.3:a:quagga:quagga:0.98.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29m2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.366.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29s`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29s0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29s1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29s2`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5108he:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29s3`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0\(2c\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29s4`,
        fs:  `cpe:2.3:a:b-e-soft:artweaver:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%283%29s5`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3%28100%29m`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.5:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3m`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.2\(2\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.3s`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29s`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc7:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29s1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p308:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29s2`,
        fs:  `cpe:2.3:a:david_king:vino:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29s3`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29sy`,
        fs:  `cpe:2.3:h:nortel:vpn_router_portfolio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29sy1`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29sy2`,
        fs:  `cpe:2.3:a:omeka:omeka:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29t`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29t1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29t2`,
        fs:  `cpe:2.3:o:juniper:junos:16.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29t3`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281%29t4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%281.13%29s`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%282%29s`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd7.d4xxxt5f_firmware:1.24.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%282%29s1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%282%29s2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_newspad:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%282%29t`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%282%29t1`,
        fs:  `cpe:2.3:a:vmware:infrastructure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%282%29t2`,
        fs:  `cpe:2.3:a:cisco:firepower_threat_defense:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%282%29t3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%283%29m2.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5\)e2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%283%29m7`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.0.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%283%29s`,
        fs:  `cpe:2.3:a:oracle:webcenter_sites:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%283%29s1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%283%29s7`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4%283%29sn1`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4s`,
        fs:  `cpe:2.3:h:axis:2460_network_dvr:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4sn`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.4t`,
        fs:  `cpe:2.3:a:in-mediakg:filterftp:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%281%29s`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%281%29s2`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.06.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%281%29s3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%281%29s4`,
        fs:  `cpe:2.3:a:profile2_privacy_project:profile2_privacy:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%281%29sy`,
        fs:  `cpe:2.3:a:vmware:player:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%281%29t`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%281%29t1`,
        fs:  `cpe:2.3:a:novell:client:4.83:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%281%29t3`,
        fs:  `cpe:2.3:h:hp:pa-risc:-:-:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%282%29s`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%282%29s1`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%282%29s2`,
        fs:  `cpe:2.3:a:apache:struts:2.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%282%29s3`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%282%29s4`,
        fs:  `cpe:2.3:a:postfix:postfix:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%282%29t`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29m`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.558:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29m0a`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29m1`,
        fs:  `cpe:2.3:h:sun:fire_x4500_server:sw_1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29m4`,
        fs:  `cpe:2.3:a:web2py:web2py:1.81.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29m5`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29m6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)jk2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29s`,
        fs:  `cpe:2.3:h:cisco:catalyst_2980g-a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29s0a`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29s1`,
        fs:  `cpe:2.3:a:adobe:photoshop:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29s1a`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5%283%29sn`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5s`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.5t`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%280.17%29t`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%281%29t0a`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%282%29sn`,
        fs:  `cpe:2.3:a:cisco:clean_access_agent_stub:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%282%29sp`,
        fs:  `cpe:2.3:a:google:v8:3.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%282%29sp1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.54:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%283%29m`,
        fs:  `cpe:2.3:a:ibm:dashdb_local:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%283%29m1b`,
        fs:  `cpe:2.3:a:google:chrome:13.0.776.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%283%29m2`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%283%29m2a`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios:15.6%283%29m3`,
        fs:  `cpe:2.3:h:cisco:ubr920:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.1.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_tools:8.46:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.1.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.1.2`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.2.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.2.2`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.002:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p197:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.3.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.3.0t`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.3.1`,
        fs:  `cpe:2.3:a:schneider-electric:interactive_graphical_scada_system:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.3.1t`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.3.2`,
        fs:  `cpe:2.3:a:hp:info_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.4.0`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.4.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.4.2`,
        fs:  `cpe:2.3:a:microsoft:word:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.4.3`,
        fs:  `cpe:2.3:a:libav:libav:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.4.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.5%28.0%29`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.5.0`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.5.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.5.2`,
        fs:  `cpe:2.3:o:yahama:rta55i:4.06.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.6%28.0%29`,
        fs:  `cpe:2.3:o:yahama:rt56v:4.07.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.6%28.1%29`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.6%28.2%29`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.6.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.08:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.6.1`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.6.2`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:2.6.2a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p194:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1.0s`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1.0sg`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1.1s`,
        fs:  `cpe:2.3:o:juniper:junos_e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1.1sg`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1.2s`,
        fs:  `cpe:2.3:a:rubycell:piano_teacher:20140730:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1.3s`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1.4s`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s%28.0%29`,
        fs:  `cpe:2.3:a:ibm:trading_partner_interchange:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s%28.1%29`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s%28.2%29`,
        fs:  `cpe:2.3:a:varnish_http_accelerator_integration_project:varnish:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s%28.3%29`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s.1`,
        fs:  `cpe:2.3:a:vmware:vsphere_host_update_utility:4.0.0.10021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s.2`,
        fs:  `cpe:2.3:a:php:php:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s.3`,
        fs:  `cpe:2.3:a:finansbank:finansbank_cep_subesi:1.1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s.4`,
        fs:  `cpe:2.3:a:squareup:okhttp:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s.4a`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.8:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s.5`,
        fs:  `cpe:2.3:h:cisco:spa300_series_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1s.6`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1sg`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.597:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1sg.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.cors:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.1sg.1`,
        fs:  `cpe:2.3:a:rakus:maildealer:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.00.xo.15.0%282%29xo`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.0s`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.1i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.0sg`,
        fs:  `cpe:2.3:a:google:chrome:11.0.661.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.0xo`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.1s`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.1sg`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.2s`,
        fs:  `cpe:2.3:a:sun:extended_system_control_facility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.2sg`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.3sg`,
        fs:  `cpe:2.3:a:microsoft:office_web_apps:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.4sg`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2.11sg`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2ja`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)st6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2s`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2s%28.0%29`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2s%28.1%29`,
        fs:  `cpe:2.3:a:perl:perl:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2s%28.2%29`,
        fs:  `cpe:2.3:a:gnu:emacs:22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2s.0`,
        fs:  `cpe:2.3:a:ubuntu_developers:apt-xapian-index:0.45ubuntu2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2s.1`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2s.2`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2s.3`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2se`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2se.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2se.1`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2se.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2se.3`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.497:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.3`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.1.528992:*:*:*:solaris:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.4`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.5`,
        fs:  `cpe:2.3:a:redhat:thunderbird:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.6`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.7`,
        fs:  `cpe:2.3:a:samba:samba:3.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.8`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2sg.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2xo`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2xo.0`,
        fs:  `cpe:2.3:a:suse:suse_linux_firewall_live-cd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.2xo.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3.0s`,
        fs:  `cpe:2.3:h:supermicro:x9dax-7tf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3.0sg`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3.1s`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3.1sg`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3.2s`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3.3s`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s%28.0%29`,
        fs:  `cpe:2.3:a:digia:qt:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s%28.1%29`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s%28.2%29`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s.0`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1012.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s.2`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s_3.3.0s`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s_3.3.1s`,
        fs:  `cpe:2.3:o:mandriva:corporate_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3s_3.3.2s`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3se`,
        fs:  `cpe:2.3:a:ibm:tivoli_endpoint_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sg`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sg.0`,
        fs:  `cpe:2.3:a:mcafee:agent:4.0.0.1421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sg.1`,
        fs:  `cpe:2.3:a:panalogic:serial_talk:1.6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sg.2`,
        fs:  `cpe:2.3:a:hp:operations_manager:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sg_3.3.0sg`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sg_3.3.1sg`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sg_3.3.2sg`,
        fs:  `cpe:2.3:a:maxtom:atomymaxsite:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sq`,
        fs:  `cpe:2.3:a:raphael_zschorsch:rzautocomplete:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sq.0`,
        fs:  `cpe:2.3:a:microsoft:ie:7.00.6000.16386:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3sq.1`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports:8.5.0.2176:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3xo`,
        fs:  `cpe:2.3:a:hp:loadrunner:11.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3xo.0`,
        fs:  `cpe:2.3:o:cisco:rvs4000_firmware:2.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3xo.1`,
        fs:  `cpe:2.3:a:iss:internet_scanner:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.3xo.2`,
        fs:  `cpe:2.3:a:commons_wikis_project:commons_wikis:7.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.0as`,
        fs:  `cpe:2.3:a:apple:webkit:417.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.0s`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.1s`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)ay:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.2s`,
        fs:  `cpe:2.3:a:docker:docker:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.3s`,
        fs:  `cpe:2.3:a:game-lion:allies_in_war:1.3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.4s`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.5s`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.7asg`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.5:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.8sg`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.9sg`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.514:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4.xs`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s%28.0%29`,
        fs:  `cpe:2.3:a:zebra_technologies:setup_utilities:1.1.4.838:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s%28.1%29`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s%28.2%29`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s%28.3%29`,
        fs:  `cpe:2.3:a:wpml:wpml:3.1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s%28.4%29`,
        fs:  `cpe:2.3:h:enterasys:6g306-06:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s%28.5%29`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.18:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s%28.6%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p235:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s.0`,
        fs:  `cpe:2.3:a:owncloud:owncloud:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s.0a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.27:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s.2`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s.3`,
        fs:  `cpe:2.3:a:david_king:vino:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s.4`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.1.5:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s.5`,
        fs:  `cpe:2.3:a:hp:software_security_core:6.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s_3.4.0as`,
        fs:  `cpe:2.3:a:apache:subversion:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s_3.4.0s`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7910:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s_3.4.1s`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s_3.4.2s`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s_3.4.3s`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s_3.4.4s`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s_3.4.5s`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4s_3.4.6s`,
        fs:  `cpe:2.3:a:carbonblack:carbon_black:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sg`,
        fs:  `cpe:2.3:h:ibm:proventia_network_ips_gx5008:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sg.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sg.1`,
        fs:  `cpe:2.3:a:egroupware:egroupware_enterprise_line:11.1.20110711-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sg.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:20.0.0.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sg.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.19:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sg.4`,
        fs:  `cpe:2.3:a:canonical:libpam-modules:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sg.5`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sg_3.4.7sg`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sq`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2020-ac-ovs-h3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sq.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.643:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.4sq.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5.0s`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5.1s`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5.2s`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5.4sq`,
        fs:  `cpe:2.3:a:vmware:server:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5.5sq`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5.xs`,
        fs:  `cpe:2.3:a:innominate:mguard_industrial_rs:bd-501020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5e`,
        fs:  `cpe:2.3:a:roxio:face_filter:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5e.0`,
        fs:  `cpe:2.3:a:princetoncorporatesolutions:taking_your_company_public:1.28.44.441:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5e.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5e.2`,
        fs:  `cpe:2.3:a:ftpfs:ftpfs:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5e.3`,
        fs:  `cpe:2.3:a:spip:spip:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5s`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5s%28.0%29`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5s%28.1%29`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5s%28.2%29`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5s.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5s.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p131:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5s.2`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_base_platform:11.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5s_base`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.5sq`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2108hc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6.0s`,
        fs:  `cpe:2.3:a:intel:miwa:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6.1s`,
        fs:  `cpe:2.3:a:adobe:extendscript_toolkit:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6.2s`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6.5ae`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6.5be`,
        fs:  `cpe:2.3:a:aktiv:phantom:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6.5e`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6.6e`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(2\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6.7e`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6e`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6e.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6e.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2011-05-25a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6s`,
        fs:  `cpe:2.3:h:cisco:aironet_3500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6s%28.0%29`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_unified_software:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6s%28.1%29`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6s%28.2%29`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6s.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6s.1`,
        fs:  `cpe:2.3:a:inmatrix:zoom_player:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6s.2`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.6s_base`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7.0s`,
        fs:  `cpe:2.3:a:oracle:database_server:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7.1s`,
        fs:  `cpe:2.3:o:hp:apollo_domain_os:sr10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7.2s`,
        fs:  `cpe:2.3:a:google:chrome:9.0.586.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7.5e`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7e`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7e.0`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7e_3.7.3e`,
        fs:  `cpe:2.3:a:microsoft:psinfo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s%28.0%29`,
        fs:  `cpe:2.3:o:juniper:screenos:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s%28.1%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.479:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s.0`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s.2`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s.4`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_foundation:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s.5`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s.6`,
        fs:  `cpe:2.3:o:opensuse_project:suse_linux_enterprise_software_development_kit:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s.7`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.7s_base`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.8.10:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8.0s`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8.1s`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:2003_se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8.2e`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8.2s`,
        fs:  `cpe:2.3:h:cisco:call_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8e`,
        fs:  `cpe:2.3:a:djangoproject:django:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8e_3.8.1e`,
        fs:  `cpe:2.3:a:altiris:inventory_rule_management_language_pack:6.2.3595:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8ex`,
        fs:  `cpe:2.3:h:logitech:cordless_freedom_navigator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8s`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8s%28.0%29`,
        fs:  `cpe:2.3:a:lenovo:thinkpad_bluetooth_with_enhanced_data_rate_software:6.5.1.2700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8s%28.1%29`,
        fs:  `cpe:2.3:a:erlang:crypto:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8s%28.2%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.6:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8s.0`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8s.1`,
        fs:  `cpe:2.3:a:gnu:phpbook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8s.2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.8s_base`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9.0as`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9.0s`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9.1as`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9.1s`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9.2e`,
        fs:  `cpe:2.3:a:debian:backupninja:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9.2s`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9e`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:a:commercial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9s`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9s.0`,
        fs:  `cpe:2.3:h:hp:trucluster_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9s.1`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.9s.2`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.1:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10`,
        fs:  `cpe:2.3:a:koha:koha:3.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10.0s`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1008:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10.1s`,
        fs:  `cpe:2.3:a:ecolehoangnam:gnam_2013:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10.1s1`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10.1xbs`,
        fs:  `cpe:2.3:a:hp:sitescope_core:11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10.2s`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s.0`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s.0a`,
        fs:  `cpe:2.3:a:intsig:camscanner:1.3.2.20120116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s.1`,
        fs:  `cpe:2.3:a:batavi:batavi:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s.01`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_console:8.1.3.312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s.3`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s.4`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:alpha1.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s.5`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s_3.10.2ts`,
        fs:  `cpe:2.3:a:nih:libzip:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.10s_3.10.7s`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.11s`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.11s.0`,
        fs:  `cpe:2.3:a:e-kiosk:e-kiosk:1.74:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.11s.1`,
        fs:  `cpe:2.3:a:websitepanel:websitepanel:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.11s.2`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.11s.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.11s.4`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.12s`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.5.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.12s.0`,
        fs:  `cpe:2.3:a:oracle:applications_technology_stack:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.12s.1`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.12s.2`,
        fs:  `cpe:2.3:h:hp:3com_router:ss4_5500g-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.12s.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.13s.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.13s.1`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.13s.2`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.14s`,
        fs:  `cpe:2.3:o:franklinfueling:ts-550_evo_firmware:2.0.0.6833:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.14s.0`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.14s.1`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:16.10.0.1036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.14s.2`,
        fs:  `cpe:2.3:o:servision:hvg_video_gateway_firmware:2.2.26a100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.14s.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.14s.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.15.4s`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.15s`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.15s.0`,
        fs:  `cpe:2.3:a:all_video_gallery_plugin_project:all-video-gallery:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.15s.1`,
        fs:  `cpe:2.3:h:d-link:dir-809:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.15s.2`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.16.2bs`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.16s`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.16s.0`,
        fs:  `cpe:2.3:h:huawei:eudemon_8160e:v100r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.16s.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.15.4s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.17.1as`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5092-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.17.2s`,
        fs:  `cpe:2.3:a:saltstack:salt:0.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.17s`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.17s.0`,
        fs:  `cpe:2.3:a:sun:mysql_connector\/j:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.17s.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1067.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.17s_3.17.0s`,
        fs:  `cpe:2.3:a:peoplepc:peoplepal:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.18.0as`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:08-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.18.0s`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:3.18s`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:13.10.2s`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.30:build110920:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:15.4%283%29s`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:16.1.1`,
        fs:  `cpe:2.3:a:gnu:grep:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:16.3.4`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:16.4.2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:16.5.1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe:16.5.1b`,
        fs:  `cpe:2.3:a:siemens:comos:9.2.0.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_16.1:16.1.1`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_16.1:16.1.2`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.3580.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_16.1:16.1.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.15:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.1:2.1.0`,
        fs:  `cpe:2.3:a:hp:storeonce_4420_backup_system:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.1:2.1.1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.1:2.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.1:2.1.3`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.2:2.2.0`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.2:2.2.1`,
        fs:  `cpe:2.3:a:apache:xerces2_java:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.2:2.2.2`,
        fs:  `cpe:2.3:h:cisco:vpn_3015_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.2:2.2.3`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.3:2.3.0`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.3:2.3.0t`,
        fs:  `cpe:2.3:a:oracle:virtualization:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.3:2.3.1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.3:2.3.1t`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.3:2.3.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.4:2.4.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.053:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.4:2.4.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.4:2.4.2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.4:2.4.3`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.5:2.5.0`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.5:2.5.1`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.5:2.5.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.6:2.6.0`,
        fs:  `cpe:2.3:a:adobe:indesign_cs4_icon_handler:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.6:2.6.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.6:2.6.2`,
        fs:  `cpe:2.3:a:apple:installer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_2.6:2.6.2a`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.1sg:3.1.0sg`,
        fs:  `cpe:2.3:a:nishishi:fumy_teachers_schedule_board:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.1sg:3.1.1sg`,
        fs:  `cpe:2.3:a:apache:pdfbox:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.0sg`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.1sg`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.2sg`,
        fs:  `cpe:2.3:a:perl:perl:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.3sg`,
        fs:  `cpe:2.3:a:ioserver:ioserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.4sg`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.5sg`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1678.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.6sg`,
        fs:  `cpe:2.3:a:nvidia:physx_system_software:9.10.514:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.7sg`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.8sg`,
        fs:  `cpe:2.3:a:redhat:rhncfg:5.10.27-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.9sg`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2sg:3.2.10sg`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2xo:3.2.0xo`,
        fs:  `cpe:2.3:o:triplc:nano-10_plc_firmware:r81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.2xo:3.2.1xo`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.829:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.3sq:3.3.0sq`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.3sq:3.3.1sq`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.4sq:3.4.0sq`,
        fs:  `cpe:2.3:a:oracle:retail_applications:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.4sq:3.4.1sq`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.5sq:3.5.0sq`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.5sq:3.5.1sq`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.5sq:3.5.2sq`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.5sq:3.5.3sq`,
        fs:  `cpe:2.3:a:tracking_code_project:tracking_code:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_3.8ex:3.8.0ex`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xe_99.9z:99.9.0z`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:-`,
        fs:  `cpe:2.3:a:jonathan_leung:show_in_browser:0.0.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:2.0`,
        fs:  `cpe:2.3:a:citrix:xenmobile_device_manager_mdm:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:2.0%28.0%29`,
        fs:  `cpe:2.3:a:apache:cxf:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:2.0.0`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a3:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.0%28.0%29`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.0%28.1%29`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.0.0`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.0.1`,
        fs:  `cpe:2.3:a:ubi:uplay_pc:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.1`,
        fs:  `cpe:2.3:a:intel:mdrwifi:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.1.0`,
        fs:  `cpe:2.3:h:hp:0235a396:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2`,
        fs:  `cpe:2.3:a:hp:creativeprojects_dwshrek2albums1:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2%28.0%29`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2%28.1%29`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2%28.2%29`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2%28.3%29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2%28.4%29`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2%28.6%29`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2%28.50%29`,
        fs:  `cpe:2.3:h:linksys:wrt54g:4.00.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2.0`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.20:-:*:*:*:windows_server_2003:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2.1`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2.2`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2.3`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2.6`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.2.50`,
        fs:  `cpe:2.3:a:google:v8:3.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3%28.0%29`,
        fs:  `cpe:2.3:a:meitalk:meitalk:\@7f060012:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3%28.1%29`,
        fs:  `cpe:2.3:a:wikidforum:wikidforum:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3%28.2%29`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3%28.3%29`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3%28.4%29`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3.0`,
        fs:  `cpe:2.3:a:oracle:virtualization_secure_global_desktop:4.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3.2`,
        fs:  `cpe:2.3:h:dell:powerconnect_6248p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3.3`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3.4`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:3.4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.3.5`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4`,
        fs:  `cpe:2.3:a:aimluck:aipo:4.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4%28.0%29`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4%28.1%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview_os_380:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4%28.2%29`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4%28.3%29`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4.1`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.4.3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.1\(4.206\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5%28.0%29`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5%28.1%29`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5%28.2%29`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5%28.3%29`,
        fs:  `cpe:2.3:h:huawei:campus_s2350:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5%28.4%29`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(10a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5.3`,
        fs:  `cpe:2.3:a:citrix:offline_plug-in:6.5.0.6684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.5.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(3f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6`,
        fs:  `cpe:2.3:h:hp:2620-24-poe\&#43;_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6%28.1%29`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.10:ga4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6%28.2%29`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.7:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6%28.3%29`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6.0`,
        fs:  `cpe:2.3:a:logitech:quickcam:11.50.1169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6.2`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6.3`,
        fs:  `cpe:2.3:o:ibm:aix:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.6_base`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7`,
        fs:  `cpe:2.3:h:linksys:wrt54g:3.01.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7%28.1%29`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7%28.2%29`,
        fs:  `cpe:2.3:o:emc:data_domain:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7%28.3%29`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7.0`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.51:-:solaris:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7.3`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.7_base`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8%28.0%29`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8%28.1%29`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8%28.2%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8%28.3%29`,
        fs:  `cpe:2.3:o:cisco:catos:7.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8%28.4%29`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8.0`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8.1`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.3790.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8.2`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8.3`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.8.4`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.9%28.0%29`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.9%28.1%29`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.9%28.2%29`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.0.0:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.9.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.9.1`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.9.2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.7.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:3.9.3`,
        fs:  `cpe:2.3:a:icofx:icofx:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0%28.0%29`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0%28.1%29`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0%28.2%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)xu2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0%28.3%29`,
        fs:  `cpe:2.3:a:htc:evo_design_4g_software:1.19.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0%28.4%29`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0%28.11%29`,
        fs:  `cpe:2.3:h:microsoft:xbox_360:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0.0`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.0:beta_10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0.2`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.12p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0.3`,
        fs:  `cpe:2.3:a:arcananet:opsxml:2.1.1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0.11`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.0_base`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1016.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.5.502.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.1%28.0%29`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.1%28.1%29`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.1%28.2%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.1.0`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.13.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(10\)s3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.1.2`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.1_base`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2%28.0%29`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2%28.1%29`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.0.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2%28.2%29`,
        fs:  `cpe:2.3:a:microsoft:word:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2%28.3%29`,
        fs:  `cpe:2.3:a:silanis:approveit_desktop:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2%28.4%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.19.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2.0`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53_97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2.1`,
        fs:  `cpe:2.3:a:plone:plone:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a7\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2.3`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.2.4`,
        fs:  `cpe:2.3:o:f5:tmos:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.3%28.0%29`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.2.3:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.3.0`,
        fs:  `cpe:2.3:a:ibm:integration_bus:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.3.2`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.3.3`,
        fs:  `cpe:2.3:a:actualtests:comptia_220-701_in_exam_engine_format:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:4.3.4`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.0.0`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.0.1`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.0_base`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:11.0.0.116:*:*:*:freeware:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.1.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.1.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.1.1`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.1.1.k9sec`,
        fs:  `cpe:2.3:h:hp:laserjet_9050_mpf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.1.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.3:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.2.0`,
        fs:  `cpe:2.3:o:suse:suse_linux:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.2.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.2.2`,
        fs:  `cpe:2.3:a:red-gate:sql_backup:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.2.4`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.60.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.3.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.3.0_base`,
        fs:  `cpe:2.3:a:apache:hadoop:0.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:5.3.2`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:6.0.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:6.0.1`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:6.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yi1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:6.0.2.01`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:6.0_base`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(7a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:6.1.0`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:6.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.1:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr:6.2.1`,
        fs:  `cpe:2.3:h:d-link:dir-600l:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_for_crs-1:-`,
        fs:  `cpe:2.3:a:ibm:websphere_developer_for_system_z:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_for_prp:-`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.0.1`,
        fs:  `cpe:2.3:a:oracle:sun_ray_software:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.0.2`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.0.3`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.0.4`,
        fs:  `cpe:2.3:h:hp:laserjet_4300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.0.11`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.1.0`,
        fs:  `cpe:2.3:h:supermicro:x9drd-ef:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.1.1`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.1.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p379:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.1_base`,
        fs:  `cpe:2.3:a:apache:poi:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ios_xr_software:4.2.0`,
        fs:  `cpe:2.3:a:avscripts:av_arcade:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:iox:1.1.0`,
        fs:  `cpe:2.3:a:ssh:tectia_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_call_center_express_enhanced:-`,
        fs:  `cpe:2.3:a:drar-eym:drareym:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_call_center_express_enhanced:3.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_call_center_express_standard:-`,
        fs:  `cpe:2.3:a:hp:ftp_print_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_call_center_express_standard:3.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:-`,
        fs:  `cpe:2.3:a:conky:conky:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0%281%29`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update5:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0%282%29`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0%283%29`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0%284%29`,
        fs:  `cpe:2.3:a:lxml:lxml:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0%285%29`,
        fs:  `cpe:2.3:a:raphael_assenat:libmikmod:3.2.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0%286%29`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf006:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0.3.0`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:7.0.6.0`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:8.6`,
        fs:  `cpe:2.3:a:utage.org:enkai:030511:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:8.6%284%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p188:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_communicator:8.6.1.0`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_contact_center_enterprise:-`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.2.1:b-nuke:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_contact_center_enterprise:5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p458:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_contact_center_enterprise:7.1`,
        fs:  `cpe:2.3:a:moodle:moodle:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_contact_center_express:-`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_contact_center_hosted:-`,
        fs:  `cpe:2.3:h:iij:seil\/x2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_contact_center_hosted:5.0`,
        fs:  `cpe:2.3:a:mcafee:virusscan:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_contact_center_hosted:7.1`,
        fs:  `cpe:2.3:a:suse:suse_linux_database_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_interactive_voice_response:-`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_interactive_voice_response:3.0`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_interoperability_and_collaboration_system:4.0%281%29`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_interoperability_and_collaboration_system:4.5%281%29`,
        fs:  `cpe:2.3:a:apache:struts:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_interoperability_and_collaboration_system:4.6%281%29`,
        fs:  `cpe:2.3:h:f5:big-ip_6900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ip_interoperability_and_collaboration_system:4.7%281%29`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd320b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ip_phone:-`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ip_phone_7800_series_firmware:10.3%281%29`,
        fs:  `cpe:2.3:a:lexmark:markvision:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ip_phone_7902:-`,
        fs:  `cpe:2.3:a:sun:n1_grid_engine:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ip_phone_7905:-`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ip_phone_7912:-`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ip_phone_7940:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ip_phone_7960:-`,
        fs:  `cpe:2.3:a:emc:records_client:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ip_phone_8800:-`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ip_phone_8800_series_firmware:10.2%281%29`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ip_phone_8800_series_firmware:10.2%282%29`,
        fs:  `cpe:2.3:h:google:cr-48_chromebook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ip_phone_8800_series_firmware:10.3`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ip_phone_8800_series_firmware:10.3%282%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ip_phone_8800_series_firmware:11.0%281%29`,
        fs:  `cpe:2.3:o:conectiva:linux:graficas:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ip_video_phone_e20:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4240:-`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4250_sx:-`,
        fs:  `cpe:2.3:a:netiq:sentinel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4255:-`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp0b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4260:-`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4270:-`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4270-20:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4345_sensor:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4360_sensor:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4510_sensor:-`,
        fs:  `cpe:2.3:a:mdickie:hard_time:1.111:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_4520_sensor:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.0:rc.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ips_nme:-`,
        fs:  `cpe:2.3:a:ca:unicenter_web_services_distributed_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:1.0.1`,
        fs:  `cpe:2.3:h:intel:mobile_intel_gs45_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:4.0`,
        fs:  `cpe:2.3:a:apple:cups:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.0`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3205a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.0%281%29`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.0%281%29e0`,
        fs:  `cpe:2.3:a:hp:san\/iq:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.0%282%29`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.0%282%29e0`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.0%286%29p1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%281%29`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.0.2-68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%281a%29`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%281b%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5.xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%281c%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_mse_series_software:4.2\(1.46\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%281d%29`,
        fs:  `cpe:2.3:h:linksys:befw11s4:1.43.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%281e%29`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%284%29e1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.9p22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%286%29e1`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%287%29e0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.09.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%287%29e1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.692.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%288%29e2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.585:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%288%29e3`,
        fs:  `cpe:2.3:a:hp:webinspect:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:5.1%28p1%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.4.0\(279\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.0%281%29e1`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.0%282%29e1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.0%283%29e1`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.0%284%29e1`,
        fs:  `cpe:2.3:h:extremenetworks:blackdiamond_10808:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.0%285%29e2`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.0%285%29e3`,
        fs:  `cpe:2.3:o:hp:tru64:5.1a_pk1_bl1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.0%286%29e3`,
        fs:  `cpe:2.3:a:novell:libzypp:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.0%286%29e4`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.1%281%29e1`,
        fs:  `cpe:2.3:a:apache:libcloud:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.1%281%29e2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.1%281%29e3`,
        fs:  `cpe:2.3:a:aol:aol_toolbar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.1%282%29e3`,
        fs:  `cpe:2.3:a:automatedqa:testcomplete_demo:7.52.678.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.1%283%29e3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.2%281%29e3`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ebj:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.2%282%29e3`,
        fs:  `cpe:2.3:a:informatica:powercenter_connect:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:6.2%282%29e4`,
        fs:  `cpe:2.3:h:juniper:nsm3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.0%281%29e3`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.0%282%29e3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.0%282%29e4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.0%283%29e4`,
        fs:  `cpe:2.3:a:netiq:unix_agent_manager:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.1%281%29e4`,
        fs:  `cpe:2.3:a:tincan:phplist:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.1%282%29e4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.01:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.1%283%29e4`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1676.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.1%284%29e4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.1%285%29e4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.1%286%29e4`,
        fs:  `cpe:2.3:a:apache:ignite:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.1%287%29e4`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.1%288%29e4`,
        fs:  `cpe:2.3:a:biscom:faxcom_suite_for_windows_client:9.6.990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.2%281%29e4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ips_sensor_software:7.2%282%29e4`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ipvc-3510-mcu:-`,
        fs:  `cpe:2.3:h:huawei:e355:ch1e355sm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ipvc-3520-gw-2b:-`,
        fs:  `cpe:2.3:a:plone:plone:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ipvc-3520-gw-2b2v:-`,
        fs:  `cpe:2.3:a:vips:vips:7.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ipvc-3520-gw-2v:-`,
        fs:  `cpe:2.3:a:xfree86:xfree86:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ipvc-3520-gw-4v:-`,
        fs:  `cpe:2.3:a:batavi:batavi:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ipvc-3525-gw-1p:-`,
        fs:  `cpe:2.3:h:belkin:n600_db_wi-fi_dual-band_n\&#43;_router_f9k1102:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ipvc-3530-vta:-`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:iscsi:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:-:-:~~~windows~~`,
        fs:  `cpe:2.3:o:f5:tmos:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.0:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.0%28.0%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)tpc11a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.0%28.1%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.0%28.2%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:adidas:adidas_eyewear:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.0%28.3%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.0%28.4%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.0%28.5%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2za:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.1:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.1%28.0%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.1%28.1%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.1%28.2%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.1%28.3%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.1%28.4%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.1%28.5%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:pedro_cambra:commerce_extra_panes:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.2:-:~-~-~windows~~`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.2%28.0%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.2%28.1%29:-:~-~-~windows~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.6%280%29::~~~windows~~`,
        fs:  `cpe:2.3:a:iss:realsecure_nokia:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.6%281%29::~~~windows~~`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.6%282%29::~~~windows~~`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.6%283%29::~~~windows~~`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.7%280%29::~~~windows~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.7%281%29::~~~windows~~`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.7%282%29::~~~windows~~`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.7%283%29::~~~windows~~`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.7%284%29::~~~windows~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:9.7%285%29::~~~windows~~`,
        fs:  `cpe:2.3:a:hp:smart_web_printing:140.0.213.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber:10.6%282%29::~~~windows~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_guest:-`,
        fs:  `cpe:2.3:o:ibm:sas_raid_module_firmware:1.3.3.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_guest:10.0.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_guest:10.0.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.558.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_guest:10.5.0`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_guest:10.6.8`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_guest:10.6.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:8.6%281%29`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.1\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.0%281%29`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.2%280%29`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.2%281%29`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.2%282%29`,
        fs:  `cpe:2.3:a:drupalauth_project:drupalauth:1.2.1:-:-:*:-:simplesamlphp:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.2%283%29`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.2%284%29`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.2%285%29`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.60.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.2%286%29`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.2%287%29`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_cp1025nw:ce918a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.3%280%29`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.3%281%29`,
        fs:  `cpe:2.3:a:pixman:pixman:0.24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:jabber_software_development_kit:9.3%282%29`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:leap:-`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:leap:1.0.19`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.0.1`,
        fs:  `cpe:2.3:h:axis:250s_video_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.0.2`,
        fs:  `cpe:2.3:a:ni:labwindows:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.0.4`,
        fs:  `cpe:2.3:h:nvidia:geforce_930m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.0.5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.0.6`,
        fs:  `cpe:2.3:a:be-graph:bezip:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.3.20`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.4.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.4.1`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:4.5.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.4.2`,
        fs:  `cpe:2.3:a:cisco:resource_manager_essentials:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.4.4`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.4.5`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3020-ac-poe-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:libsrtp:1.5.2`,
        fs:  `cpe:2.3:a:debian:apt:0.8.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:linksys_playerpt_activex_control:1.0.0.15`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:local_director:-`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:7.2.1010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mds_9000:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(26\)sv1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000:1.3%283.33%29`,
        fs:  `cpe:2.3:a:sun:solaris_answerbook2:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000:1.3%284a%29`,
        fs:  `cpe:2.3:a:intel:network_connections:15.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000:2.0%280.86%29`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_nx-os:4.1`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_nx-os:4.1%281%29`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_nx-os:4.2`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_nx-os:4.2%281%29`,
        fs:  `cpe:2.3:a:codiad:codiad:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_nx-os:5.0%281%29`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_collaboration_server:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_nx-os:6.2%2813%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p210:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_nx-os:7.1%280%29zn%2891.99%29`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_san-os:1.3%283.33%29`,
        fs:  `cpe:2.3:a:sonicwall:aventail_web_proxy_agent:10.1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_san-os:1.3%284a%29`,
        fs:  `cpe:2.3:a:clamav:clamav:0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_san-os:2.0%280.86%29`,
        fs:  `cpe:2.3:a:gameloft:wonder_zoo_-_animal_rescue_\!:1.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_san-os:2.1`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.2\(2\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_san-os:3.0%281%29`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_san-os:3.1%281%29`,
        fs:  `cpe:2.3:a:novell:groupwise:2012:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_san-os:3.2`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mds_9000_san-os:3.2%281%29`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.1.7.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mds_9100:-`,
        fs:  `cpe:2.3:h:ibm:totalstorage_ds400:4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mds_9140:-`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp1:media_center:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mds_9200:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mds_9500:-`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3201a:a.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mds_9700:-`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_experience_engine:3.0.0.0`,
        fs:  `cpe:2.3:a:myvet2pet:ahrah:219426:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.3%281%29`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.11_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.3%282%29`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.3%286%29`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6ece:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.3%287%29`,
        fs:  `cpe:2.3:a:trillian:trillian:0.724:aim_c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.3%288%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.3_base`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.62.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.4%281%29`,
        fs:  `cpe:2.3:a:libpng:libpng:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.4_base`,
        fs:  `cpe:2.3:a:skype:skype:3.8.0.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.5%280%29`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.5%281%29`,
        fs:  `cpe:2.3:o:ibm:aix:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.5_base`,
        fs:  `cpe:2.3:a:vmware:workstation:6.0.1_build_55017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:media_origination_system_suite:2.6_base`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mediasense:-`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.00:-:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mediasense:8.5%283%29`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mediasense:8.5%284%29`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mediasense:9.0%281a%29`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mediasense:9.1%281%29`,
        fs:  `cpe:2.3:a:borland:starteam_cross-platform_client:10.0.63.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mediasense:10.0%281%29`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mediasense:10.5%281%29`,
        fs:  `cpe:2.3:a:icbc:industrial_and_commercial_bank_of_china:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_app:1.8.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1gb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_app:1.9.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_manager_for_firefox%2fnetscape%2fchrome:8.0.4917`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:6.x-3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_manager_for_internet_explorer:7.5.3`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_manager_for_mozilla_firefox%2fnetscape_navigator:7.5.3`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:1.7_base`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.52.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:1.8.15`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:1.8_base`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:1.9.0`,
        fs:  `cpe:2.3:h:polycom:viewstation_v.35:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:1.9.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:1.9_base`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(6.7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.0`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.0\(x\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.4`,
        fs:  `cpe:2.3:a:posh_project:posh:2.1:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.5`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1020.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.6`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.7`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.8`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.0.9`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.7:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.1.0`,
        fs:  `cpe:2.3:a:hp:scannercopy:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meeting_server:2.1.1`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:2.03.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meetingplace:-`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meetingplace_express:-`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meetingplace_web_confrencing:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.8.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meetingplace_web_confrencing:5.3%28235%29`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meetingtime:5.2`,
        fs:  `cpe:2.3:a:roxio:creator_basic_v9:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meetingtime:5.4`,
        fs:  `cpe:2.3:a:gnu:readline:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meetingtime:6.0`,
        fs:  `cpe:2.3:h:cisco:telepresence_codec_c60:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:meraki_mr:-`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp8:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meraki_mr_firmware:2014-09-24`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.6\(0.16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:meraki_ms:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meraki_ms_firmware:2014-09-24`,
        fs:  `cpe:2.3:a:sun:one_application_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:meraki_mx:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:meraki_mx_firmware:2014-09-24`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mgx_8230:1.2.10`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mgx_8230:1.2.11`,
        fs:  `cpe:2.3:a:gnome:glib:2.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mgx_8250:1.2.10`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:mgx_8250:1.2.11`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mobility_services_engine:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.250:update25:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:5.1_base`,
        fs:  `cpe:2.3:h:cisco:integrated_services_router_829:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:5.2_base`,
        fs:  `cpe:2.3:a:snowfoxsoft:snowfox_total_video_converter:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:6.0_base`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.343:*:*:*:esr:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.0_base`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.4.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.4.100.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.4.110.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.4.121.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.4_base`,
        fs:  `cpe:2.3:a:apple:cups:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.5.102.101`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.6.100.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.6.120.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:7.6.132.0`,
        fs:  `cpe:2.3:a:f5:big-ip:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:8.0%28110.0%29`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mobility_services_engine:8.0%28110.0%29`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:mobility_services_engine:8.0_base`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:0.99:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:mobility_services_engine:10.0%280.1%29`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:modular_encoding_platform_d9036:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:modular_encoding_platform_d9036_software:02.00.80`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.74a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:modular_encoding_platform_d9036_software:02.01.50`,
        fs:  `cpe:2.3:a:citrix:edgesight:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:modular_encoding_platform_d9036_software:02.02.30`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:modular_encoding_platform_d9036_software:02.03.30`,
        fs:  `cpe:2.3:h:ibm:flashsystem_9848-ac2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:multiservice_platform_2650:-`,
        fs:  `cpe:2.3:a:dteenergy:dte_energy:3.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:multiservice_platform_2650xm:-`,
        fs:  `cpe:2.3:a:openfabrics:ibutils:1.2-11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:multiservice_platform_2651:-`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:multiservice_platform_2651xm:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg091a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_agent:4.7.1.511`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_agent:4.8.0.32`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_agent:4.8.1.5`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_agent:4.8.2.3`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p5_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:3.6`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.50:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.1`,
        fs:  `cpe:2.3:a:abb:robotstudio:5.61.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.6`,
        fs:  `cpe:2.3:a:gitlist:gitlist:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.7`,
        fs:  `cpe:2.3:a:serf_project:serf:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.7.1`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.7.2`,
        fs:  `cpe:2.3:h:hp:3com_router:5682:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.8`,
        fs:  `cpe:2.3:a:owncloud:owncloud:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_appliance:4.9.2`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nac_guest_server:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.667.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:1.0.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:1.1.0`,
        fs:  `cpe:2.3:a:splunk:splunk:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:1.1.1`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r7:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:1.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:1.1.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:2.0.0`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:2.0.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:2.0.2`,
        fs:  `cpe:2.3:a:dell:asset_manager:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nac_guest_server_software:2.0.3`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:1.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:2.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:3.0`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:3.5`,
        fs:  `cpe:2.3:a:celframe:office_2008:-:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:3.6`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:4.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:5.0`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_agent:mcafee_inc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:netflow_collection_engine:5.0.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1670.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:network_access_control:-`,
        fs:  `cpe:2.3:a:gajim:gajim:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3`,
        fs:  `cpe:2.3:a:barebones:yojimbo:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.11:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.2`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.3`,
        fs:  `cpe:2.3:a:ibm:db2:11.1.0.0:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.4`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.6`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.16.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.7`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.8`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.3.9`,
        fs:  `cpe:2.3:h:cisco:ios:12.3xj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.4.1`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.4.2`,
        fs:  `cpe:2.3:a:barracuda:web_filter:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.4.3`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_unified_software:1.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.4.4`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.5`,
        fs:  `cpe:2.3:a:corel:coreldraw:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.5%289%29`,
        fs:  `cpe:2.3:a:digium:asterisk:13.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.5.1`,
        fs:  `cpe:2.3:h:dell:b2360dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.5.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.5.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.5:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.5.4`,
        fs:  `cpe:2.3:o:conectiva:linux:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.5.5`,
        fs:  `cpe:2.3:a:rack_project:rack:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.5.9`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.6g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.0`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.0.1`,
        fs:  `cpe:2.3:h:tp-link:archer_c9_\(1.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.1`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:9.0.151.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.1.1`,
        fs:  `cpe:2.3:a:intel:high-bandwidth_digital_content_protection:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.2.1`,
        fs:  `cpe:2.3:h:hp:jetdirect_615n_eio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.2.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.4`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.1`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.0`,
        fs:  `cpe:2.3:a:conky:conky:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.0.1`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.11.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.2`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.2.1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.2.2`,
        fs:  `cpe:2.3:a:nancy_wichmann:sitedoc:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.3.1`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.3.2`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.4`,
        fs:  `cpe:2.3:a:redhat:rhmask:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.4.2`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.5`,
        fs:  `cpe:2.3:a:google:checkout-php:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.0.6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.0`,
        fs:  `cpe:2.3:h:cisco:2901_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.0.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.0.2`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.0.2:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.2`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.2.1`,
        fs:  `cpe:2.3:a:canonical:php5:5.3.2-1ubuntu4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.375:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.3.1`,
        fs:  `cpe:2.3:a:qbnz:geshi:1.0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.6`,
        fs:  `cpe:2.3:a:google:v8:3.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.1.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ya10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.5.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.5.1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.6.1`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.7.1`,
        fs:  `cpe:2.3:a:google:v8:3.23.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.7.2`,
        fs:  `cpe:2.3:a:skype:skype:1.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.8.0`,
        fs:  `cpe:2.3:a:hp:ucmdb_browser:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.8.1`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.8.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.8.3`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.8.3.1`,
        fs:  `cpe:2.3:a:adobe:photoshop:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.9.0`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.9.1`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_admission_control_manager_and_server_system_software:4.9.2`,
        fs:  `cpe:2.3:o:y-cam:yceb03_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:network_analysis_module:-`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.6.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:network_analysis_module_software:4.0.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:network_analysis_module_software:4.1.0`,
        fs:  `cpe:2.3:h:apc:smart-ups_2200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:1.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:2.1`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:3.0`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:4.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.0`,
        fs:  `cpe:2.3:a:oracle:solaris_cluster:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.1`,
        fs:  `cpe:2.3:a:gemalto:gempc430:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.5`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.6`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.6.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.495.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.6.2`,
        fs:  `cpe:2.3:h:siemens:synco_ozw_web_server:ozw775:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.6.3`,
        fs:  `cpe:2.3:a:sun:grid_engine:6.0:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.7.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_assistant:5.7.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_equipment_information:1.0.0`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_recording_player:2.3.1109`,
        fs:  `cpe:2.3:a:digium:asterisk:11.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:network_services_manager:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.6:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:nexus_1000v:-`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:-`,
        fs:  `cpe:2.3:a:crea8social:crea8social:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:4.2%281%29_sv1%284%29:-:~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:0.1:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:4.2%281%29_sv1%284a%29:-:~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:4.2%281%29_sv1%284b%29:-:~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:4.2%281%29sv1%285.1%29:-:~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:4.2%281%29sv1%285.1a%29:-:~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:hp:tcp_ip_services_openvms:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:4.2%281%29sv1%285.2%29:-:~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:apple:itunes:7.1.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:4.2%281%29sv1%285.2b%29:-:~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:4.2%281%29vsg1%281%29:-:~~~nexus_1000v~~`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1019.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_1000v:5.2%281%29sm1%285.1%29:-:~~~microsoft_hyper-v~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_2148t_fex_switch:-`,
        fs:  `cpe:2.3:o:hp:palm_webos:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_2224tp_fex_switch:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3ya:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_2232pp_fex_switch:-`,
        fs:  `cpe:2.3:a:nortel:optivity_telephony_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_2232tm_fex_switch:-`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.754.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_2248tp_e_fex_switch:-`,
        fs:  `cpe:2.3:a:microsoft:visual_basic_software_development_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_2248tp_fex_switch:-`,
        fs:  `cpe:2.3:a:mathew_winstone:mobile_tools:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3016:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.472:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3016q:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3048:-`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3064:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3064t:-`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3064x:-`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3132q:-`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3164q:-`,
        fs:  `cpe:2.3:a:hp:hppmsredist:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3172:-`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3524:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_3548:-`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_4001i:-`,
        fs:  `cpe:2.3:a:aol:email_toolbar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5000:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5010:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5010p_switch:-`,
        fs:  `cpe:2.3:a:easing_slider:easing_slider:2.2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5020:-`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5020p_switch:-`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.1.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5548p:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5548p_switch:-`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5548up:-`,
        fs:  `cpe:2.3:a:apache:wicket:6.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5548up_switch:-`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5596t:-`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5596up:-`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5596up_switch:-`,
        fs:  `cpe:2.3:a:websupergoo:abcpdf_asp:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_56128p:-`,
        fs:  `cpe:2.3:h:cisco:fwsm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5624q:-`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5648q:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5672up:-`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_5696q:-`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:9.0.115.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_6001:-`,
        fs:  `cpe:2.3:a:mobileappcity:childcare:1.399:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_6004:-`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_6004x:-`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_7000:-`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_7000_10-slot:-`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_7000_18-slot:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_human_capital_management:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_7000_9-slot:-`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.3046:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_7700:-`,
        fs:  `cpe:2.3:a:apple:itunes:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_92160yc-x:-`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_92304qc:-`,
        fs:  `cpe:2.3:a:codiad:codiad:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9236c:-`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9272q:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_93108tc-ex:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_93120tx:-`,
        fs:  `cpe:2.3:a:airdroid:airdroid:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_93128tx:-`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_93180yc-ex:-`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9332pq:-`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.806:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9336pq_aci_spine:-`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6.9:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9372px:-`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:7.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9372tx:-`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9396px:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.22:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9396tx:-`,
        fs:  `cpe:2.3:a:nancy_wichmann:sitedoc:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9504:-`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9508:-`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:nexus_9516:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:-`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:1.0%281.110a%29`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:1.0%281e%29`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:1.1%281g%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%280%29n1%281a%29`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.0.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%280%29n1%282%29`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:beta4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%280%29n1%282a%29`,
        fs:  `cpe:2.3:o:hp:ignite-ux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%281a%29n1%281%29`,
        fs:  `cpe:2.3:a:pgp:certificate_server:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%281a%29n1%281a%29`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%281a%29n2%281%29`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%281a%29n2%281a%29`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%284%29sv1%281%29`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%284%29sv1%282%29`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:10.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%284%29sv1%283%29`,
        fs:  `cpe:2.3:a:emc:cloud_tiering_appliance_software:10.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%284%29sv1%283a%29`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%284%29sv1%283b%29`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%284%29sv1%283c%29`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.0%284%29sv1%283d%29`,
        fs:  `cpe:2.3:a:microsoft:visio:2002:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281%29`,
        fs:  `cpe:2.3:o:suse:suse_linux:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281b%29`,
        fs:  `cpe:2.3:h:d-link:dcs-5605_ptz_ip_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281c%29`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281d%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281e%29`,
        fs:  `cpe:2.3:a:google:chrome:51.0.2704.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281f%29`,
        fs:  `cpe:2.3:h:hp:ibrix_x9730:qz731a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281g%29`,
        fs:  `cpe:2.3:o:apple:airport_base_station_firmware:7.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281h%29`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_vista:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281i%29`,
        fs:  `cpe:2.3:a:google:chrome:7.0.529.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281j%29`,
        fs:  `cpe:2.3:a:acme:thttpd:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281k%29`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%282%29e1%281m%29`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%283%29n1%281%29`,
        fs:  `cpe:2.3:a:cisco:policy_suite:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%283%29n1%281a%29`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%283%29n2%281%29`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.1.34:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1%283%29n2%281a%29`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1.%282%29`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.40:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1.%283%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1.%284%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.1.%285%29`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.3540.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2`,
        fs:  `cpe:2.3:a:alstom:micom_s1_agile:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%281%29`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%281%29n1%281%29`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%281%29n2%281%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%281%29n2%281a%29`,
        fs:  `cpe:2.3:o:freenas:freenas:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%281%29sv1%284%29`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%281%29sv1%284a%29`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%281%29sv1%285.1%29`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%282%29`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%283%29`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r2:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%284%29`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%286%29`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2%288%29`,
        fs:  `cpe:2.3:a:andrew_levine:multiblock:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:4.2.%282a%29`,
        fs:  `cpe:2.3:a:apple:safari:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%282%29`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.6:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%282%29n1%281%29`,
        fs:  `cpe:2.3:a:serf_project:serf:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%282%29n2%281%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2se.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%282%29n2%281a%29`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%282a%29`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.10:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29`,
        fs:  `cpe:2.3:a:sap:netweaver:7.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29n1%281%29`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29n1%281a%29`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.3.1:fix01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29n1%281b%29`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29n1%281c%29`,
        fs:  `cpe:2.3:a:google:chrome:16.0.884.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29n2%281%29`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29n2%282%29`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29n2%282a%29`,
        fs:  `cpe:2.3:h:schneider-electric:tburjr900:01002dh0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29n2%282b%29`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp6:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u1%281%29`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u1%281a%29`,
        fs:  `cpe:2.3:h:htc:droid_incredible:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u1%281b%29`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u1%281d%29`,
        fs:  `cpe:2.3:a:brian_burton:paypal_pro_payflow_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u1%282%29`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u1%282a%29`,
        fs:  `cpe:2.3:a:pixologic:zbrush:3.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u2%281%29`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u2%282%29`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u2%282a%29`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.173:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u2%282b%29`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u2%282c%29`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u2%282d%29`,
        fs:  `cpe:2.3:a:namazu:namazu:1.0.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u3%281%29`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u3%282%29`,
        fs:  `cpe:2.3:a:freenac:freenac:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u3%282a%29`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u3%282b%29`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u4%281%29`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281%29`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281a%29`,
        fs:  `cpe:2.3:a:sybase:easerver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281b%29`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_agent:4.2.0.254483:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281c%29`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:2.1.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281d%29`,
        fs:  `cpe:2.3:a:unikey:unikey:3.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281e%29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281f%29`,
        fs:  `cpe:2.3:a:piwik:piwik:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281g%29`,
        fs:  `cpe:2.3:a:ca:etrust_access_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%283%29u5%281h%29`,
        fs:  `cpe:2.3:a:ca:ehealth_livehealth:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.0%285%29`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%281%29`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:5.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%281a%29`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.40:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%282%29`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%283%29`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%283%29n1%281%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%283%29n1%281a%29`,
        fs:  `cpe:2.3:a:symantec:workspace_streaming:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%283%29n2%281%29`,
        fs:  `cpe:2.3:a:openstack:telemetry_\(ceilometer\):2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%283%29n2%281a%29`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.0p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%283%29n2%281b%29`,
        fs:  `cpe:2.3:a:ibm:workload_deployer:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%283%29n2%281c%29`,
        fs:  `cpe:2.3:a:apple:itunes:4.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%284%29`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%285%29`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.50.0309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1%286%29`,
        fs:  `cpe:2.3:a:projectforge:projectforge:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.1.3`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2`,
        fs:  `cpe:2.3:a:gnu:bash:2.05:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.5.1.659:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%281%29`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%281a%29`,
        fs:  `cpe:2.3:a:redhat:rhel_virtualization:5:*:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%281b%29`,
        fs:  `cpe:2.3:h:3com:3cp4144:1.1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%282%29`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%282a%29`,
        fs:  `cpe:2.3:a:bareftp:bareftp:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%283%29`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%284%29`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%285%29`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(4j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%286%29`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%287%29`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%288%29`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29n1%288a%29`,
        fs:  `cpe:2.3:a:zope:zope:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29sv3%281.1%29`,
        fs:  `cpe:2.3:a:usebb:usebb:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29sv3%281.3%29`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29sv3%281.5a%29`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29sv3%281.5b%29`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29sv3%281.6%29`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%281%29sv3%281.10%29`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:2.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%283%29`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.174:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%283a%29`,
        fs:  `cpe:2.3:h:nvidia:nvs_310:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%284%29`,
        fs:  `cpe:2.3:h:axis:250s_video_server:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%285%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%287%29`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%289%29`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.2.2:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.2%289%29n1%281%29`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:5.3.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.986:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%281%29`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a6%281%29`,
        fs:  `cpe:2.3:a:jforum:jforum:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a6%282%29`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a6%283%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a6%284%29`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a6%285%29`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a6%286%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a6%287%29`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a6%288%29`,
        fs:  `cpe:2.3:a:symantec:norton_save_and_recovery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a7%281%29`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server_solution_engine:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a7%282%29`,
        fs:  `cpe:2.3:a:process-one:ejabberd:3.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a7%282a%29`,
        fs:  `cpe:2.3:a:google:chrome:5.0.385.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29a8%282%29`,
        fs:  `cpe:2.3:a:emerson:aperture_web_application_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n1%281%29`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n1%282%29`,
        fs:  `cpe:2.3:a:rsa:envision:4.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n1%282a%29`,
        fs:  `cpe:2.3:a:gentoo:mldonkey_ebuild:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%281%29`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%281b%29`,
        fs:  `cpe:2.3:a:openx:openx:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%282%29`,
        fs:  `cpe:2.3:a:oracle:siebel_suite:7.7.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%283%29`,
        fs:  `cpe:2.3:a:openstack:swift:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%284%29`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%285%29`,
        fs:  `cpe:2.3:a:apache:axis:-:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%285a%29`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%286%29`,
        fs:  `cpe:2.3:a:google:earth:5.1.7894.7252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29n2%287%29`,
        fs:  `cpe:2.3:h:nvidia:quadro_m1000m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u1%281%29`,
        fs:  `cpe:2.3:a:microsoft:outlook_web_access:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u1%281a%29`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u1%282%29`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u1%283%29`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:034:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u1%284%29`,
        fs:  `cpe:2.3:h:juniper:srx5800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u2%281%29`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u2%282%29`,
        fs:  `cpe:2.3:h:cisco:application_velocity_system_3110:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u2%283%29`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u2%284%29`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.51:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u2%285%29`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u2%286%29`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u3%281%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3_5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u3%282%29`,
        fs:  `cpe:2.3:a:hp:imc_branch_intelligent_management_system_software_module:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u3%283%29`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u3%284%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u3%285%29`,
        fs:  `cpe:2.3:a:apache:ambari:2.5.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u4%281%29`,
        fs:  `cpe:2.3:a:libav:libav:11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u4%282%29`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u4%283%29`,
        fs:  `cpe:2.3:a:sympa:sympa:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u5%281%29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.1.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u5%281.41%29`,
        fs:  `cpe:2.3:a:uiu4you:universal_imaging_utility:4.6.2.0:*:*:*:live_version:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u5%282%29`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u5%283%29`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u5%284%29`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u6%281%29`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u6%282%29`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u6%283%29`,
        fs:  `cpe:2.3:a:vmware:esx_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u6%284%29`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u6%285%29`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u6%286%29`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.1.91.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u6%287%29`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%282%29u6%288%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p446:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%283%29`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.0%284%29`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1`,
        fs:  `cpe:2.3:a:adobe:robohelp:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%281%29`,
        fs:  `cpe:2.3:a:hp:hpptoocool:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:11:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i2%282%29`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i2%282a%29`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i2%282b%29`,
        fs:  `cpe:2.3:a:apport_project:apport:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i2%283%29`,
        fs:  `cpe:2.3:a:perl:perl:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i3%281%29`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.1.2-42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i3%282%29`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.6.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i3%283%29`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i3%283.78%29`,
        fs:  `cpe:2.3:a:vips:vips:7.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%282%29i3%284%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%283%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%284%29`,
        fs:  `cpe:2.3:a:jasper_project:jasper:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%284a%29`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.1%285%29`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%281%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%281n%29`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%282%29`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%282a%29`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%283%29`,
        fs:  `cpe:2.3:a:buffalotech:wzr-ampg300nh_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%283n%29`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.4.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%285%29`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jn2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%285a%29`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.4:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%286%29`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%286b%29`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%287%29`,
        fs:  `cpe:2.3:a:apache:mod_python:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%288%29`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_designer:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%288a%29`,
        fs:  `cpe:2.3:a:apache:axis2:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%288b%29`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%2810%29`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%2811b%29`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%2812%29`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:6.2%2814%29s1`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%280%29n1%281%29`,
        fs:  `cpe:2.3:a:metago:astro_file_manager_with_cloud:astro-4.4.592:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%281%29n1%281%29`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.2.1:one:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%281%29n1%283%29`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:9.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%282%29n1%281%29`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.31.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%283%29`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%283%29i1%281a%29`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%283%29i1%281b%29`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1045:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%283%29i1%282%29`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.12:build110528:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%283%29i2%280.373%29`,
        fs:  `cpe:2.3:a:eng:spagobi:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%283%29n1%281%29`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%284%29n1%281%29`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%285%29n1%281%29`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%285%29n1%281a%29`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.1.10.801:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%286%29n1%281%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%287%29n1%281%29`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.0%288%29n1%281%29`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:9.3:agee_common_criteria_build:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%280%29n1%281a%29`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%280%29n1%281b%29`,
        fs:  `cpe:2.3:a:c2enterprise:c2_webresource:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%281%29n1%281%29`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.92.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%282%29n1%281%29`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%283%29n1%281%29`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%283%29n1%282%29`,
        fs:  `cpe:2.3:h:intel:wireless_wifi_link_4965agn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%283%29n1%282.1%29`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3c\)1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%283%29n1%283.12%29`,
        fs:  `cpe:2.3:h:fortinet:fortigate-311b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.1%284%29n1%281%29`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.2%280%29n1%280.1%29`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.2%280%29n1%281%29`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.2%280%29zz%2899.1%29`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.2%280%29zz%2899.3%29`,
        fs:  `cpe:2.3:a:intsig:camdictionary:2.3.0.20131118:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.2%281%29n1%281%29`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:i5_i7_dual_sinit_18.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.3%280%29n1%281%29`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.3%280%29zn%280.9%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:fnc9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.3%280%29zn%280.81%29`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_cp1025nw:ce914a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.3%280%29zn%280.83%29`,
        fs:  `cpe:2.3:a:apache:ambari:2.4.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:7.3%282%29n1%280.296%29`,
        fs:  `cpe:2.3:a:ca:license_software:1.62.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:8.0%281%29s2`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:8.3%280%29cv%280.342%29`,
        fs:  `cpe:2.3:a:emc:eroom:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:8.3%280%29cv%280.345%29`,
        fs:  `cpe:2.3:o:cray:unicos:9.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:9.1%281%29sv1%283.1.8%29`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.0%281b%29`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.0%281c%29`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.0%281d%29`,
        fs:  `cpe:2.3:a:hp:openview_radia_management_portal:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.0%281e%29`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.0%282j%29`,
        fs:  `cpe:2.3:a:digia:qt:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.0%282m%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.0%283f%29`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%281c%29`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:004shp3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%281j%29`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%281o%29`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%281r%29`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%281s%29`,
        fs:  `cpe:2.3:a:registeredassistant_project:registeredassistant:0.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%282h%29`,
        fs:  `cpe:2.3:a:cmsjunkie:j-classifiedsmanager:-:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%282i%29`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%283f%29`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%284e%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%284f%29`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2982:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%284g%29`,
        fs:  `cpe:2.3:a:ibm:http_server:2.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%284i%29`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%284l%29`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.1%284m%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.2%281m%29`,
        fs:  `cpe:2.3:a:adastra:trace_mode_data_center:6.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.2%282g%29`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.2%282h%29`,
        fs:  `cpe:2.3:a:oracle:global_order_promising:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.2%282i%29`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.2%283c%29`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.9.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.2%283e%29`,
        fs:  `cpe:2.3:a:citrix:password_manager_console:4.6.91.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.2%283h%29`,
        fs:  `cpe:2.3:a:apache:struts:2.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.3%281i%29`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.5.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.3%282f%29`,
        fs:  `cpe:2.3:a:google:android_api:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.3%282h%29`,
        fs:  `cpe:2.3:a:microsoft:personal_web_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:11.3%282i%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8b\)e8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os:base`,
        fs:  `cpe:2.3:a:php:php:5.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os_1000v_switch:4.0%284%29sv1%281%29::~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_monitor_solution_for_servers:6.0.1112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os_1000v_switch:4.0%284%29sv1%282%29::~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os_1000v_switch:4.0%284%29sv1%283%29::~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os_1000v_switch:4.0%284%29sv1%283a%29::~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os_1000v_switch:4.0%284%29sv1%283b%29::~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os_1000v_switch:4.0%284%29sv1%283c%29::~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-os_1000v_switch:4.0%284%29sv1%283d%29::~~~vmware_vsphere~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:nx-ox:6.0%282%29a7%281%29`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:okena_stormwatch:-`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:okena_stormwatch:3.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15216_optical_add_drop_multiplexer:-`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15216_optical_add_drop_multiplexer:2.2.2`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.2`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.2.1`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.1.3700.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.2.2`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.2.3`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15302_multiservice_customer_access_platform:-`,
        fs:  `cpe:2.3:a:webmin:usermin:1.500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15305_multiservice_customer_access_platform:-`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15310-cl_sonet_multiservice_platform:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15310-ma_sdh_multiservice_platform:-`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15310-ma_sonet_multiservice_platform:-`,
        fs:  `cpe:2.3:a:qemu:qemu:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15327:-`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:3.0`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:3.1`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:3.2`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:3.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:3.4`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.0`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.5m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.0%281%29`,
        fs:  `cpe:2.3:a:vmturbo:operations_manager:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.0%282%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.1%280%29`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.1%281%29`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.1%282%29`,
        fs:  `cpe:2.3:a:netiq:appmanager_diagnostic_console:2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.1%283%29`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.6%280%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.3t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.6%281%29`,
        fs:  `cpe:2.3:h:schneider_electric:sage_3030m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15327:4.14`,
        fs:  `cpe:2.3:a:texasweddingmall:villa_antonia:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15327_sonet_multiservice_platform:-`,
        fs:  `cpe:2.3:a:mblogger_project:mblogger:1.0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15454:-`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_mspp:-`,
        fs:  `cpe:2.3:a:cisco:voice_log_translator:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_mstp:-`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15454_multiservice_transport_platform:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15454_optical_transport_platform:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:2.3%285%29`,
        fs:  `cpe:2.3:h:symantec:gateway_security_5310:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:3.0`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:3.1.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:4.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:3.1_.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.1.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:3.2.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:3.2_.0`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:3.3`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf184a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:3.4`,
        fs:  `cpe:2.3:a:ca:workload_automation_ae:11.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.0`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.0%281%29`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.0%282%29`,
        fs:  `cpe:2.3:a:gnu:a2ps:4.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.1`,
        fs:  `cpe:2.3:a:apple:cups:1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.1%280%29`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.2.133.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.1%281%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.1%282%29`,
        fs:  `cpe:2.3:a:ca:anti-virus_for_the_enterprise:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.1%283%29`,
        fs:  `cpe:2.3:a:synology:cloud_station:2.1-2570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.5`,
        fs:  `cpe:2.3:a:geodesicsolutions:geocore_max:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.6%280%29`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.51.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_optical_transport_platform:4.6%281%29`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15454_sdh_multiservice_provisioning_platform:-`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15454_sonet_multiservice_provisioning_platform:-`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_system_software:9.8`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454_system_software:10.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454e_optical_transport_platform:-`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15454sdh:-`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:2.3%285%29`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:3.1`,
        fs:  `cpe:2.3:h:siemens:enterprise_openscape_branch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:3.2`,
        fs:  `cpe:2.3:a:logitech:camerahelpermsi:13.30.1395.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:3.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:3.4`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.0%280%29`,
        fs:  `cpe:2.3:h:axis:2420_video_server:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.0%281%29`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.0%282%29`,
        fs:  `cpe:2.3:o:conectiva:linux:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.1%280%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)t16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.1%281%29`,
        fs:  `cpe:2.3:h:cisco:pix_firewall_515:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.1%282%29`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.0\(2a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.1%283%29`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.5`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.16.2:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.6%280%29`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v100r006c00spc800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15454sdh:4.6%281%29`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15600:-`,
        fs:  `cpe:2.3:a:intel:network_connections:16.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15600:1.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.1\(2.27\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15600:1.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15600:1.1%280%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15600:1.1%281%29`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:ons_15600:1.3%280%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p268:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15600_multiservice_switching_platform:-`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ons_15600_sdh_multiservice_provisioning_platform:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:11.5\(0.98000.486\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:openh264:1.2.0`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.4.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:1.0`,
        fs:  `cpe:2.3:a:opscode:chef:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:1.0.1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:1.0.2`,
        fs:  `cpe:2.3:o:google:chrome_os:8.0.552.344:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:1.1`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:1.1%280%29`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:1.1%281%29`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:1.3%280%29`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:2.3%285%29`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:3.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.8.5:supplemental_update:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:3.1.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:3.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:3.2.0`,
        fs:  `cpe:2.3:a:ibm:data_protection:6.1:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:3.3.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:3.4.0`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.4235:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:3.4.1`,
        fs:  `cpe:2.3:a:redhat:openssl:0.9.7a-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:3.4.2`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.0%280%29`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.0%281%29`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.0%282%29`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.0.0`,
        fs:  `cpe:2.3:a:vmware:virtualcenter_server:2.5.0.64247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.0.1`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1%280%29`,
        fs:  `cpe:2.3:h:hp:jc655a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1%281%29`,
        fs:  `cpe:2.3:a:logitech:im_video_companion:1.3.0.2041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1%282%29`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1%283%29`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.01.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1.3`,
        fs:  `cpe:2.3:o:ibm:vios:2.1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1.4`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-02-\/g:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.0.1:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1.81`,
        fs:  `cpe:2.3:a:citrix:secure_gateway:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.1.82`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.471:mr8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.5`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.6%280%29`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:7.102.302.203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.6%281%29`,
        fs:  `cpe:2.3:a:avonesoft:photo_to_dvd_maker:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.6.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.6.2`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.6.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:4.6.6`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:5.0.0`,
        fs:  `cpe:2.3:a:emc:unisphere:1.5:-:*:*:*:vmax:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:5.0.2`,
        fs:  `cpe:2.3:a:cabextract:cabextract:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:5.0.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.102.55:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:5.0.6`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:5.0.7`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:5.0.8`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:6.0.0`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:6.0.1`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option_server:07-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:6.0.3`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:6.2.0`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:6.2.2`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:7.0.0`,
        fs:  `cpe:2.3:o:yamaha:rta52i:3.06.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:7.0.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:7.0.4`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:7.0.5`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1043:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:7.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:7.2.0`,
        fs:  `cpe:2.3:h:xerox:workcentre_m35:2.97.20.032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:7.2.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:optical_networking_systems_software:7.2.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:packet_tracer:5.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:packet_tracer:5.3`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:peap_module:1.1.6`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:personal_assistant:-`,
        fs:  `cpe:2.3:a:apache:subversion:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:personal_assistant:1.3%281%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:personal_assistant:1.3%282%29`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:personal_assistant:1.3%283%29`,
        fs:  `cpe:2.3:a:oracle:customer_intelligence:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:personal_assistant:1.3%284%29`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04s:sp11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:personal_assistant:1.4%281%29`,
        fs:  `cpe:2.3:o:cisco:catos:2.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:personal_assistant:1.4%282%29`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:pgw_2200:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:pgw_2200:9.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_500:-`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_asa:-`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:pix_asa_ids:-`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.43.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:pix_firewall:-`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:2.7`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.7:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:3.0`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.3:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:3.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_7600_ws-x6380-nam:2.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.0`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view_appliance_iso:6.3.31-2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.1%286%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.2:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.1%286b%29`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.442:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.2%281%29`,
        fs:  `cpe:2.3:a:quassel-irc:quassel:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.2%282%29`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.2%285%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.3`,
        fs:  `cpe:2.3:h:hp:laserjet_m9050_mpf:cc395a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.4%284%29`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.4%287.202%29`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:4.4%288%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.1%284%29`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.1%284.206%29`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2`,
        fs:  `cpe:2.3:a:altiris:software_delivery_task_server_plug-in_language_pack:6.1.1030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%281%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%282%29`,
        fs:  `cpe:2.3:a:avaya:predictive_dialer_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%283%29`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%283.210%29`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.1\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%284%29`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%285%29`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.8c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%286%29`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%287%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%288%29`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:gold:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.2%289%29`,
        fs:  `cpe:2.3:h:dell:remote_access_card:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.3`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.3790.1830:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.3%281%29`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.3%281.200%29`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.3%282%29`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:5.3%283%29`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.0`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:12.2:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.0%281%29`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:9.5.1.4418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.0%282%29`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.0%283%29`,
        fs:  `cpe:2.3:a:ca:antispyware_for_the_enterprise:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.0%284%29`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.0%284.101%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.1`,
        fs:  `cpe:2.3:a:getpixie:pixie:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.1%281%29`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.70:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.1%282%29`,
        fs:  `cpe:2.3:h:cisco:catalyst_6504-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.1%283%29`,
        fs:  `cpe:2.3:a:f5:big-ip:9.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.1%284%29`,
        fs:  `cpe:2.3:a:ibm:db2:9.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.1%285%29`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp1:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.1.5%28104%29`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.2`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.2%281%29`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.2%282%29`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.2%283%29`,
        fs:  `cpe:2.3:a:serena:teamtrack:6.6.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.2%283.100%29`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall:6.3`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.3`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.3%281%29`,
        fs:  `cpe:2.3:a:libunwind_project:libunwind:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.3%282%29`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1664.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.3%283%29`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.3%283.102%29`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.3%283.109%29`,
        fs:  `cpe:2.3:h:huawei:s7700:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:6.3%285%29`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:7.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:7.1`,
        fs:  `cpe:2.3:a:xml-dt_project:xml-dt:0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:7.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:7.2%282%29`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall:8.0%282%29`,
        fs:  `cpe:2.3:h:avaya:cajun_p550:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall_501:-`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall_506:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.1:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall_506e:-`,
        fs:  `cpe:2.3:a:autonomy:verity_k2:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall_515:-`,
        fs:  `cpe:2.3:a:cisco:finesse:10.5\(1\)_es1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall_515e:-`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall_520:-`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller:1.0\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall_525:-`,
        fs:  `cpe:2.3:a:jam-software:treesize:2.2.1:*:*:*:free:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_firewall_535:-`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:pix_firewall_manager:-`,
        fs:  `cpe:2.3:a:microsoft:vbscript:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:pix_firewall_manager:4.3%282%29g`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.2:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:-`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:2.7`,
        fs:  `cpe:2.3:a:icofx:icofx:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:3.0`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:17.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:3.1`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.0`,
        fs:  `cpe:2.3:a:adobe:setup:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.1%286%29`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.1%286b%29`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.2`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.2%281%29`,
        fs:  `cpe:2.3:a:microsoft:excel:2003:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.2%282%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.2%285%29`,
        fs:  `cpe:2.3:h:cisco:wireless_control_system:3.2\(40\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.3`,
        fs:  `cpe:2.3:a:oracle:human_capital_management:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.4`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.4%284%29`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.4%287.202%29`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:4.4%288%29`,
        fs:  `cpe:2.3:a:niif:shibboleth_authentication:7.x-4.2:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.1%284%29`,
        fs:  `cpe:2.3:a:debian:apt:0.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.1%284.206%29`,
        fs:  `cpe:2.3:a:ca:systemedge:5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.1.0.488:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%281%29`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%282%29`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%283%29`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.891:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%283.210%29`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%284%29`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_3016_poe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%285%29`,
        fs:  `cpe:2.3:a:isc:bind:9.2.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%286%29`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%287%29`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%288%29`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.2%289%29`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.3%281%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.3%281.200%29`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.3%282%29`,
        fs:  `cpe:2.3:a:yahoo:messenger:7.0.0.426:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:5.3%283%29`,
        fs:  `cpe:2.3:a:equis:metastock:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.0`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.0%281%29`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.0%282%29`,
        fs:  `cpe:2.3:a:poll_chart_block_project:poll_chart_block:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.0%283%29`,
        fs:  `cpe:2.3:h:oleumtech:wio_dh2_wireless_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.0%284%29`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.0%284.101%29`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.1`,
        fs:  `cpe:2.3:a:cisco:webns:7.50.0.09s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.1%281%29`,
        fs:  `cpe:2.3:a:microsoft:windows_live_onecare:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.1%282%29`,
        fs:  `cpe:2.3:a:websense:triton:7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.1%283%29`,
        fs:  `cpe:2.3:a:percona:percona_server:5.7.10-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.1%284%29`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.1%285%29`,
        fs:  `cpe:2.3:h:3com:tippingpoint_sms_server:2.2.1.4477:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.1.5%28104%29`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.0.1060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.2`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04s:sp7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.2%281%29`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.2%282%29`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.2%283%29`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.7:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.2%283.100%29`,
        fs:  `cpe:2.3:h:cisco:sg500x-48:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.3`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.3%281%29`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.3%282%29`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.3%283%29`,
        fs:  `cpe:2.3:a:netkit:netkit:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.3%283.102%29`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.3%283.109%29`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:6.3%285%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:7.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:7.1`,
        fs:  `cpe:2.3:h:emerson:roc_800l_remote_terminal_unit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:7.2`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:7.2%282%29`,
        fs:  `cpe:2.3:a:gnu:texinfo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:pix_firewall_software:8.0%282%29`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:pix_private_link:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:pix_private_link:4.1%286%29`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:pix_vpn_accelerator_card%2b:-`,
        fs:  `cpe:2.3:a:barebones:yojimbo:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:policy_suite:10.0.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1042.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:policy_suite:10.1.0`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:policy_suite:11.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution:-`,
        fs:  `cpe:2.3:a:sun:ray_windows_connector:2.0:*:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution_assurance:1.0`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.6.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution_assurance:1.0.1`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution_assurance:8.6`,
        fs:  `cpe:2.3:h:ibm:power_5:9131-52a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution_assurance:9.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution_assurance:9.1`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution_assurance:9.1.1`,
        fs:  `cpe:2.3:a:tforum:tforum:b0.915:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution_assurance:9.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_central_for_hosted_collaboration_solution_assurance:10.6%282%29`,
        fs:  `cpe:2.3:a:redhat:rhel_virtualization:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration:-`,
        fs:  `cpe:2.3:a:getpixie:pixie:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration:9.0.0`,
        fs:  `cpe:2.3:a:ansys:mechanical:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration:9.0.5`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.340:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration:10.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:5.5\(0.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration:10.5%281%29`,
        fs:  `cpe:2.3:a:canal44:canal_44:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration:11.0.0`,
        fs:  `cpe:2.3:a:redhat:lha:1.14i-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_assurance:10.5.1`,
        fs:  `cpe:2.3:a:ca:unicenter_browser_interface:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_assurance:10.6.0`,
        fs:  `cpe:2.3:a:ca:ehealth_for_voice:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_assurance:11.0.0`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_deployment:10.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_deployment:10.5.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_deployment:11.0_base`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_deployment:11.5.0`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_provisioning:10.6.2`,
        fs:  `cpe:2.3:h:hp:storageworks_san_switch:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_provisioning:11.0.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_provisioning:11.1.0`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0.1:test2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_collaboration_provisioning:11.5.0`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:4.1%282%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:4.1%283%29`,
        fs:  `cpe:2.3:h:hp:3com_switch_taa_compliant:5500g-ei-sfp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:4.1%284%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:4.1%285%29`,
        fs:  `cpe:2.3:a:joyent:node.js:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:4.2%281%29`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:4.2%283%29`,
        fs:  `cpe:2.3:a:posh_project:posh:2.1:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:4.2.%283%29`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r12.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.0%282%29`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.0%283%29`,
        fs:  `cpe:2.3:a:umn:mapserver:4.8:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.1%281%29`,
        fs:  `cpe:2.3:a:nos:nos_alive:5.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.1%282%29`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp1:srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.1%283u%29`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.2%282%29`,
        fs:  `cpe:2.3:a:python:python:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.2%282a%29`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.2%282b%29`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.2%282c%29`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:5.2%282e%29`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.1`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.1%281%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.1%281a%29`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.1%281b%29`,
        fs:  `cpe:2.3:h:cisco:wireless_lan_controller:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.2%281%29`,
        fs:  `cpe:2.3:o:hp:hp-ux:7.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.2%283%29`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.2%285%29`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.2%285a%29`,
        fs:  `cpe:2.3:a:roxio:creator:10.1.299:*:*:*:business_edition_gold:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.3%281%29`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:6.3%282%29`,
        fs:  `cpe:2.3:h:polycom:viewstation_v.35:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:7.0%281%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_data_center_network_manager:7.0%282%29`,
        fs:  `cpe:2.3:a:perl:perl:2.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_home:5.0_base`,
        fs:  `cpe:2.3:a:dell:help_and_support_customization:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_home:5.1_base`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:-`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.16.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:1.2.0`,
        fs:  `cpe:2.3:h:xerox:document_centre_420:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:1.2.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:1.3.0`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:1.3.0.20-2`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:1.4.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:08-00-01:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:1.4.0.45-2`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:1.4.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:2.0.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:2.0.0.0.294-2`,
        fs:  `cpe:2.3:a:apache:activemq:5.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:2.1`,
        fs:  `cpe:2.3:o:lenovo:thinkserver_rd650_firmware:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:2.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:2.2%282%29`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:2.2.0`,
        fs:  `cpe:2.3:a:apple:itunes:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:3.0.0`,
        fs:  `cpe:2.3:a:emc:web_publishers:6.5:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:3.0_base`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:3.1.0`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_infrastructure:3.1_base`,
        fs:  `cpe:2.3:a:wp-easybooking_plugin_project:wp-easybooking:1.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.1_base`,
        fs:  `cpe:2.3:o:eucalyptus:eustore:emi_2425352071:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.2.1`,
        fs:  `cpe:2.3:a:splunk:splunk:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.2.2`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.7.c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.2.3`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.2.4`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.2.5`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.514:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_lan_management_solution:4.2_base`,
        fs:  `cpe:2.3:a:oracle:application_server:11i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_control_system:-`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:6.1.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:6.1.6`,
        fs:  `cpe:2.3:a:alstom:micom_s1_studio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:6.2.3`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:6.2.4`,
        fs:  `cpe:2.3:a:bea:weblogic_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:6.3`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:6.3.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:6.3.2`,
        fs:  `cpe:2.3:a:siemens:comos:9.2.0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:6.3.3`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.0`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.0.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.1`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.1.1`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.1.2.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.1.3`,
        fs:  `cpe:2.3:a:ca:anti-virus_for_the_enterprise:r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.2.0.1`,
        fs:  `cpe:2.3:a:dell:openmanage_remote_access_components:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.2.1`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a5:3.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.2.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:7.2.3`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.0`,
        fs:  `cpe:2.3:a:oracle:right_now_service_cloud:8.4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.1`,
        fs:  `cpe:2.3:a:microsoft:help_file_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.1.1`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.1.2`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.1.3`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:8.0.0:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.2.0`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.2.0.1`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution_assurance:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.2.0.2`,
        fs:  `cpe:2.3:a:innominate:mguard_blade:hw-104050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.2.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.2.1.1`,
        fs:  `cpe:2.3:a:hp:application_information_optimizer:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.2.2`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.2.2.1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_explorer:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.3.0`,
        fs:  `cpe:2.3:o:google:android:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_registrar:8.3.1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_network_services_controller:3.0.0`,
        fs:  `cpe:2.3:a:oracle:developer_suite:10.1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_optical:10.0`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.0`,
        fs:  `cpe:2.3:a:vmware:ovf_tool:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.0.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-48p-ei_ls-5100-48p-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.0.1-40`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.0.2-68`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.1`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.1.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.1.2-29`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.1.2-42`,
        fs:  `cpe:2.3:a:autodesk:revit:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.1.3-8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.1.3-10`,
        fs:  `cpe:2.3:o:siemens:synco_ozw_web_server_firmware:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.1.3-13`,
        fs:  `cpe:2.3:a:bea:weblogic_mobility_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.2`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.2.0`,
        fs:  `cpe:2.3:h:nortel:vpn_router_1050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.2.1-1`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_security_manager:9.2.1-2`,
        fs:  `cpe:2.3:a:tenable:nessus:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_service_catalog:9.4.1_vortex`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.1.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_service_catalog:10.0%28r2%29_base`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_service_catalog:10.0_base`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1b_pk2_bl22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_service_catalog:10.1_base`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:prime_service_catalog:11.0_base`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:qos_policy_manager:4.0`,
        fs:  `cpe:2.3:a:arcsoft:totalmedia_backup:1.1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:qos_policy_manager:4.0.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:qos_policy_manager:4.0.2`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:quad:-`,
        fs:  `cpe:2.3:a:apache:derby:10.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:remote_access_plugins_for_adaptive_security_appliance:1.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:remote_access_plugins_for_adaptive_security_appliance:1.1.1`,
        fs:  `cpe:2.3:a:apache:struts2-showcase:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:remote_monitoring_suite_option:-`,
        fs:  `cpe:2.3:a:trendmicro:interscan_web_security_virtual_appliance:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:resource_manager:-`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta37:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:resource_manager:1.0`,
        fs:  `cpe:2.3:a:mobile4social:exposed_filter_data:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:resource_manager:1.1`,
        fs:  `cpe:2.3:h:sendmail:sentrion:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:resource_manager_essentials:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:resource_manager_essentials:2.0`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:resource_manager_essentials:2.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:resource_manager_essentials:2.2`,
        fs:  `cpe:2.3:a:plone:plone:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:router_2500:-`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:router_2600:-`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:router_3600:-`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:router_4000:-`,
        fs:  `cpe:2.3:a:adastra:trace_mode_data_center:6.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:router_7200:-`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.1:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:router_7500:-`,
        fs:  `cpe:2.3:h:xerox:workcentre_m35:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:router_web_setup:-`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:router_web_setup:3.3.0_build_30`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.0.2`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.0.30`,
        fs:  `cpe:2.3:a:aol:aim:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.1.9`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_software_development_kit:12.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.2.6`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.3.10`,
        fs:  `cpe:2.3:a:cisco:application_networking_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.4.10`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.4.14`,
        fs:  `cpe:2.3:a:lina_wolf:seo_pack_for_tt_news:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.5.4.%28gd%29`,
        fs:  `cpe:2.3:a:microsoft:directx:8.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.5.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:1.26.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.5.8`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.0.6.6`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.1.0.9`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv_series_router_firmware:1.2.0.2`,
        fs:  `cpe:2.3:a:intel:pro_alerting_agent:12.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv016_multi-wan_vpn_firmware:4.0.0.7`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:12:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv016_multi-wan_vpn_firmware:4.0.2.8`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:7.4.100.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv016_multi-wan_vpn_firmware:4.0.5.0`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv016_multi-wan_vpn_router:-`,
        fs:  `cpe:2.3:a:apple:safari:3.1.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv042_dual_wan_vpn_router:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv042_dual_wan_vpn_router_firmware:4.0.2.8`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce_suite_start:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv042g_dual_gigabit_wan_vpn_firmware:4.0.0.7`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.2052:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv042g_dual_gigabit_wan_vpn_firmware:4.2.2.7`,
        fs:  `cpe:2.3:a:skype:skype:2.6.0.105:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv042g_dual_gigabit_wan_vpn_firmware:4.2.2.8`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv042g_dual_gigabit_wan_vpn_router:-`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv082_dual_wan_vpn_router:-`,
        fs:  `cpe:2.3:a:perl:perl:5.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv082_dual_wan_vpn_router_firmware:4.0.0.7`,
        fs:  `cpe:2.3:a:arg0:encfs:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:rv082_dual_wan_vpn_router_firmware:4.0.2.8`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv110w_firmware:1.1.0.9`,
        fs:  `cpe:2.3:a:exim:exim:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv110w_firmware:1.2.0.10`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv110w_firmware:1.2.1.4`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.0.0_t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv110w_wireless-n_vpn_firewall:-`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.26-25.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv110w_wireless-n_vpn_firewall_firmware:1.1.0.9`,
        fs:  `cpe:2.3:a:adobe:color_common_settings:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv110w_wireless-n_vpn_firewall_firmware:1.2.0.9`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv110w_wireless-n_vpn_firewall_firmware:1.2.0.10`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv110w_wireless-n_vpn_firewall_firmware:1.2.1.4`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.0\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv120w_wireless-n_vpn_firewall:-`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv130_vpn_router:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p188:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv130w:-`,
        fs:  `cpe:2.3:a:sayakbanerjee:sticky_notes:0.2.27052012.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv130w_firmware:1.0.0.21`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv130w_firmware:1.0.1.3`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.1:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv130w_firmware:1.0.2.7`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv130w_wireless-n_multifunction_vpn_router:-`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv130w_wireless-n_multifunction_vpn_router_firmware:1.0.0.21`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv130w_wireless-n_multifunction_vpn_router_firmware:1.0.1.3`,
        fs:  `cpe:2.3:h:linksys:wrt54g:2.02.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv130w_wireless-n_multifunction_vpn_router_firmware:1.0.2.7`,
        fs:  `cpe:2.3:a:compaq:openvms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv180_vpn_router:-`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv180w_wireless-n_multifunction_vpn_router:-`,
        fs:  `cpe:2.3:a:emc:control_center:5.2:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_firmware:1.1.0.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.18b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_firmware:1.2.0.14`,
        fs:  `cpe:2.3:a:microsoft:expression_media:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_firmware:1.2.0.15`,
        fs:  `cpe:2.3:h:cisco:router_7200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_firmware:1.3.0.7`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv215w_wireless-n_vpn_router:-`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite_sql-server:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_wireless-n_vpn_router_firmware:1.1.0.5`,
        fs:  `cpe:2.3:a:redmine:redmine:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_wireless-n_vpn_router_firmware:1.1.0.6`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_wireless-n_vpn_router_firmware:1.2.0.14`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_wireless-n_vpn_router_firmware:1.2.0.15`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rv215w_wireless-n_vpn_router_firmware:1.3.0.7`,
        fs:  `cpe:2.3:a:opsview:opsview:4.0:-:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv220w_wireless_network_security_firewall:-`,
        fs:  `cpe:2.3:a:gimp:gimp:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv320_dual_gigabit_wan_vpn_router:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv320_dual_gigabit_wan_wf_vpn_router:-`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv325_dual_gigabit_wan_wf_vpn_router:-`,
        fs:  `cpe:2.3:a:horde:groupware:1.1.5:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rv325_dual_wan_gigabit_vpn_router:-`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:3.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rvl200_4-port_ssl_ipsec_vpn_router:-`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rvs4000:-`,
        fs:  `cpe:2.3:a:simplerealtytheme:advanced_text_widget_plugin:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:rvs4000_4-port_gigabit_security_router_-_vpn:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(1a\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rvs4000_firmware:1.3.2.0`,
        fs:  `cpe:2.3:h:y-cam:ycw001:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rvs4000_firmware:1.3.3.5`,
        fs:  `cpe:2.3:a:microsoft:windows_explorer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rvs4000_firmware:2.0.0.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rvs4000_firmware:2.0.2.7`,
        fs:  `cpe:2.3:a:tek:phaserlink:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:rvs4000_firmware:2.0.3.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sa520:2.2.07`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sa520w:2.2.07`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sa540:2.2.07`,
        fs:  `cpe:2.3:a:google:cityhash:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:sc2200:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.1.33:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:sc2200:7.4`,
        fs:  `cpe:2.3:h:3com:3c840-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta__dpr%2fepr2320:-`,
        fs:  `cpe:2.3:a:allplayer:allplayer:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:scientific_atlanta__dpr%2fepr2320_firmware:2.0.2:r1262-090417`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta__dpr2325:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.20.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:scientific_atlanta__dpr2325_firmware:2.0.2:r1262-090417`,
        fs:  `cpe:2.3:a:busybox:busybox:1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc_3208:-`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc2100:-`,
        fs:  `cpe:2.3:a:dell:wyse_device_manager:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc2202:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc2203:-`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc2325:-`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc2425:-`,
        fs:  `cpe:2.3:a:hp:storageworks_secure_path:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc2434:-`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc2505:-`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc3010:-`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.01:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc%2fepc3212:-`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_services:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc2420:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc3000%2fepc3000:-`,
        fs:  `cpe:2.3:a:cisco:meetingtime:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc3008%2fepc3008:-`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc3825:-`,
        fs:  `cpe:2.3:a:brian_altenhofel:slidebox:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpc3925:-`,
        fs:  `cpe:2.3:a:joshics:contact_form_fields:6.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpq%2fepq2160:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpq2202:-`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpq2425:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpq3212:-`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.91\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpq3925:-`,
        fs:  `cpe:2.3:a:jquery:jquery:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpr362:-`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpw700:-`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpw730:-`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpw939:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpw941:-`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.04.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpx%2fepx2100:-`,
        fs:  `cpe:2.3:h:selinc:sel-3505:r123-v0-z002001-d20130117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpx%2fepx2203:-`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpx%2fepx2203c:-`,
        fs:  `cpe:2.3:a:namazu:namazu:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpx100%2f120:-`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpx110:-`,
        fs:  `cpe:2.3:a:python:python:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpx130:-`,
        fs:  `cpe:2.3:a:novell:groupwise:7.02:hp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpx213:-`,
        fs:  `cpe:2.3:h:buffalotech:wex-300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_dpx2213:-`,
        fs:  `cpe:2.3:o:cisco:vpn_3015_concentrator:4.7.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_epc2420:-`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.9:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_epc3825:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4-0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_epc3925:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:scientific_atlanta_wag310g:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p342:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:secure_access_control_server:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.1:-:windows`,
        fs:  `cpe:2.3:h:huawei:s5600:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.1%284%29:-:windows`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(10\)s7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.3:-:windows`,
        fs:  `cpe:2.3:a:procmail:procmail:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.3%281%29:-:windows`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.3%282%29:-:windows`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.4`,
        fs:  `cpe:2.3:a:atlassian:jira_service_desk:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.4:-:windows`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.4%281%29:-:windows`,
        fs:  `cpe:2.3:a:cisco:ip_contact_center_enterprise:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.5`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.5:-:windows`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.5:-:windows-nt`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.1:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.6`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.6-60.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.6:-:windows`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.6.2`,
        fs:  `cpe:2.3:o:cisco:ons_15327:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.6.2:-:windows`,
        fs:  `cpe:2.3:a:ibm:java:6.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.6.3`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.6.3:-:windows`,
        fs:  `cpe:2.3:a:apple:iphoto:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.6.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:2.6.4:-:windows`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.0`,
        fs:  `cpe:2.3:a:macromedia:flash_player:7.0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.0:-:windows`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3k:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.0.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.0.1:-:windows`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.0.2:-:windows`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.0.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.0.3:-:windows`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.0.4:-:windows`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.1:-:windows`,
        fs:  `cpe:2.3:a:redhat:network_proxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:11.10.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.1.1:-:windows`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.1.2:-:windows`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.0.08s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2`,
        fs:  `cpe:2.3:a:cob\&#39;s_products:cobime:0.9.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2:-:windows`,
        fs:  `cpe:2.3:a:oracle:developer_suite:10.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%281%29`,
        fs:  `cpe:2.3:a:microsoft:excel:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%281%29:-:windows`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%281.20%29`,
        fs:  `cpe:2.3:a:quest:intrust_manager:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%281.20%29:-:windows`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%282%29`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%282%29:-:windows`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%282%29:build15:windows`,
        fs:  `cpe:2.3:a:redhat:subscription_asset_manager:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%282%29_build_15`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%283%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.21.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2%283%29:-:windows`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2.1`,
        fs:  `cpe:2.3:o:maygion:ip_camera_firmware:05.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2.1:-:windows`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2.2`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2.2:-:windows`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.2.3:-:windows`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3:-:windows`,
        fs:  `cpe:2.3:a:capasystems:performance_guard:6.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3%281%29`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3%281%29:-:windows`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3.1:-:windows`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3.2:-:windows`,
        fs:  `cpe:2.3:a:ctihub:ct_ihub:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3.3:-:windows`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p426:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:3.3.4:-:windows`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.0`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.0:-:windows`,
        fs:  `cpe:2.3:a:woothemes:woocommerce:2.2.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.0.1`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.16:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.0.1:-:windows`,
        fs:  `cpe:2.3:a:kingsoft:office_2013:9.1.0.4256:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.1:-:windows`,
        fs:  `cpe:2.3:o:d-link:dcs-930l_firmware:1.15.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.1.2:-:windows`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.1.3:-:windows`,
        fs:  `cpe:2.3:a:webservice-dic:yoyaku:41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.1.4:-:windows`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.1.4.13:-:windows`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.4:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2`,
        fs:  `cpe:2.3:a:cisco:vpn_client:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2:-:windows`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1:-:windows`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.0`,
        fs:  `cpe:2.3:h:symantec:gateway_security_5400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.1`,
        fs:  `cpe:2.3:a:xymon:xymon:4.1.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.2`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.112.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.4`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.6`,
        fs:  `cpe:2.3:a:chilkatsoft:chilkat_smtpq:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.7`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.8`,
        fs:  `cpe:2.3:a:oracle:mysql_installer:1.0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.9`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.10`,
        fs:  `cpe:2.3:a:commvault:continuous_data_replicator:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:4.2.1.15.11`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.08.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:5.0`,
        fs:  `cpe:2.3:a:sigmatel:c-major_audio:5.10.4600.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:5.1`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:5.2`,
        fs:  `cpe:2.3:a:quagga:quagga:0.96.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:5.3`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:5.5%280.1%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server:5.5%280.46.2%29`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:secure_access_control_server_solution_engine:-`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server_solution_engine:3.3`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server_solution_engine:3.3.1`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server_solution_engine:3.3.2`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server_solution_engine:4.0`,
        fs:  `cpe:2.3:h:korenix:jetport:5604:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server_solution_engine:5.4.0.46.6`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server_solution_engine:5.5.0.36`,
        fs:  `cpe:2.3:a:apache:hadoop:0.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_server_solution_engine:5.5.0.46.4`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:-`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.1`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.2`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_hmi\/scada_cimplicity:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.453.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.4`,
        fs:  `cpe:2.3:h:perle:833_remote_access_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.5`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.6`,
        fs:  `cpe:2.3:a:adobe:svg_viewer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.7`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.8`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.3.0.40.9`,
        fs:  `cpe:2.3:a:browserweb:whizz:1.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.4.0.46.1`,
        fs:  `cpe:2.3:a:pixabay_images_project:pixabay_images:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.4.0.46.2`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.14.2:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.4.0.46.3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.4.0.46.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p2_rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.4.0.46.5`,
        fs:  `cpe:2.3:a:nuance:caere_scan_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.4.0.46.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.3:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.5%280.1%29`,
        fs:  `cpe:2.3:a:google:chrome:15.0.871.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.5.0.46`,
        fs:  `cpe:2.3:a:gnome:evolution:2.30.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_access_control_system:5.7%280.15%29`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_acs:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_acs_for_unix:-`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_acs_for_windows_nt:-`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_acs_for_windows_server:-`,
        fs:  `cpe:2.3:a:openssl:openssl:1.1.0d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_acs_solution_engine:-`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:secure_content_accelerator:-`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:-`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.0_base`,
        fs:  `cpe:2.3:a:dell:dw_wlan_card_utility:5.100.235.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.1`,
        fs:  `cpe:2.3:a:sap:erp_central_component:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.1.0.31`,
        fs:  `cpe:2.3:h:ge:bently_nevada_3500\/22m_serial:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.1.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.1.1.27`,
        fs:  `cpe:2.3:a:radiohead_fan_project:radiohead_fan:4.6.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.1.1.33`,
        fs:  `cpe:2.3:o:juniper:junos:12.3r12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.1.1.45`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.1_base`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.2`,
        fs:  `cpe:2.3:a:apache:hbase:0.92.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.2.0.136`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.2.1`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.2.1.103`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.2.1.126`,
        fs:  `cpe:2.3:a:monotone:monotone:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.2_base`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:05-05-\/p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.3.0.118`,
        fs:  `cpe:2.3:a:gnu:coreutils:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.3.0.151`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.3_base`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.4`,
        fs:  `cpe:2.3:a:iss:realsecure_server_sensor:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.4.1`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.4.2`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050717:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.4.0373`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.4.1108`,
        fs:  `cpe:2.3:a:ca:license_software:1.80.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.4.2048`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.4_base`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.6-169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.5`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.5.841`,
        fs:  `cpe:2.3:a:teamquest:model:10.2.2280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.5.1077`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.5.2001`,
        fs:  `cpe:2.3:o:cisco:ios:12.1t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.5.2003`,
        fs:  `cpe:2.3:a:shavlik:netchk_compliance:3.1.0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.5.2008`,
        fs:  `cpe:2.3:h:cisco:1941w_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.5_base`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.181`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.185`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.1001`,
        fs:  `cpe:2.3:h:cisco:catalyst_3550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.2002`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p156:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.3002`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.4021`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.5005`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.6020`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.04d-2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.6104`,
        fs:  `cpe:2.3:h:samsung:shr-5082:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.6203`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp10:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.6210`,
        fs:  `cpe:2.3:a:acm.org:er_assistant:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.6228`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.6234`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6.6249`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.896:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_desktop:3.6_base`,
        fs:  `cpe:2.3:a:gnu:grep:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_intrusion_detection_system:-`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:secure_pix_firewall:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_services_client:-`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_services_client:4.0`,
        fs:  `cpe:2.3:a:compaq:insight_management_agent:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_services_client:4.0.5`,
        fs:  `cpe:2.3:a:tribunenews365:john_macarthur:1.0.26:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:secure_services_client:4.0.51`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:-`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:2.1`,
        fs:  `cpe:2.3:a:cisco:cisco_nexus_1000v_intercloud:5.2\(1\)ic1\(1.2\):*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:3`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.0`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.0.1`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.0.2`,
        fs:  `cpe:2.3:a:trick_question_project:trick_question:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.0.3`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.0.3.728`,
        fs:  `cpe:2.3:a:justin_dodge:hotblocks:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.5.0`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.5.1`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5192-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.5.1.639`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.5.1.657`,
        fs:  `cpe:2.3:a:debian:debian-goodies:0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:4.5.1.659`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:5.0`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:5.0.0.201`,
        fs:  `cpe:2.3:a:quantum:adic_management_console:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:5.0.193`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:5.1`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:5.1.79`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.1xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent:5.2.0.282`,
        fs:  `cpe:2.3:a:ca:unicenter_application_server_managment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent_management_center:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_agent_management_center:5.1`,
        fs:  `cpe:2.3:h:cisco:1921_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_device_manager:-`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:-`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.0.2`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.1`,
        fs:  `cpe:2.3:a:posh_project:posh:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.1.1`,
        fs:  `cpe:2.3:h:sony:snc_ch140:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.1.1:sp3`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.2:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2:sp1`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2:sp2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2.1:sp1`,
        fs:  `cpe:2.3:a:microsoft:excel_viewer:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2.2:-`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2.2:sp1`,
        fs:  `cpe:2.3:a:apple:cups:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2.2:sp2`,
        fs:  `cpe:2.3:a:pervasive:data_integrator_integration_server:9.0.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2.2:sp3`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.2.2:sp4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.3:-`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.3:sp1`,
        fs:  `cpe:2.3:a:emil_stjerneman:linkit:7.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.3:sp2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s_3.4.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.3.1:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.3.1:sp1`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.3.1:sp2`,
        fs:  `cpe:2.3:a:gnu:libtool:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.3.1:sp3`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:3.3.1:sp4`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.0:-`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.0:sp1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)xw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.0.1:-`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.6005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.0.1:sp1`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.0.1:sp2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.1`,
        fs:  `cpe:2.3:h:micronet:sp916bm:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.1:sp1`,
        fs:  `cpe:2.3:a:apache:activemq:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.1:sp2`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.2:-`,
        fs:  `cpe:2.3:a:tappocket:dino_zoo:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.2:sp1`,
        fs:  `cpe:2.3:a:elsop:linkscan:11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.3:-`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.3:sp1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.3:sp2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.4:-`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.16f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.4:sp1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd394a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.4:sp2`,
        fs:  `cpe:2.3:a:digium:asterisk:11.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.5`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.6`,
        fs:  `cpe:2.3:a:apple:safari:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager:4.7%280%29:sp1%281%29`,
        fs:  `cpe:2.3:a:inria:ocaml:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:security_manager_client:3.3.0.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:security_monitoring_analysis_and_response_system:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.181.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:server_provisioner:6.4.0:patch_1204040128`,
        fs:  `cpe:2.3:a:mozilla:camino:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:server_provisioner:6.4.0:patch_2-1112122225`,
        fs:  `cpe:2.3:h:siemens:sinamics_g120d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:server_provisioner:6.4.0:patch_3-1208021049`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:server_provisioner:6.4.0:patch_5-1301292331`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:service_portal:9.4.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf300-08:-`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf300-24:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:ga:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf300-24mp:-`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf300-24p:-`,
        fs:  `cpe:2.3:a:cisco:network_services_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf300-24pp:-`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf300-48:-`,
        fs:  `cpe:2.3:a:fusebox:fusebox:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf300-48p:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf300-48pp:-`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.4:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf302-08:-`,
        fs:  `cpe:2.3:a:juniper:junos_space:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf302-08mp:-`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf302-08mpp:-`,
        fs:  `cpe:2.3:a:php:php:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf302-08p:-`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20100509:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf302-08pp:-`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ebk:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf500-24:-`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf500-24p:-`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf500-48:-`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sf500-48p:-`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-10:-`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-10mp:-`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-10mpp:-`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-10p:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-10pp:-`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-10sfp:-`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.66:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-20:-`,
        fs:  `cpe:2.3:a:oracle:database_mobile\/lite_server:11.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-28:-`,
        fs:  `cpe:2.3:a:php:php:5.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-28mp:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-28p:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-28pp:-`,
        fs:  `cpe:2.3:a:csounds:csound:5.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-52:-`,
        fs:  `cpe:2.3:a:gnu:gnumeric:0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-52mp:-`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:2.0.1:rev27876:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg300-52p:-`,
        fs:  `cpe:2.3:a:php:php:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500-28:-`,
        fs:  `cpe:2.3:o:cisco:spa_500_series_ip_phone_firmware:7.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500-28mpp:-`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500-28p:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)za:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500-52:-`,
        fs:  `cpe:2.3:o:redhat:directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500-52mp:-`,
        fs:  `cpe:2.3:o:sitecom:wl-153_router_firmware:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500-52p:-`,
        fs:  `cpe:2.3:a:php:php:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500x-24:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500x-24p:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500x-48:-`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500x-48p:-`,
        fs:  `cpe:2.3:a:ubuntu_developers:language-selector:0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sg500xg-8f8t:-`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-232:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.0%281%29`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.0%282%29`,
        fs:  `cpe:2.3:a:ca:unicenter_performance_management:2.4:sp3:openvms:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.0%282%29:sr1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.0%283%29`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.5:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.0%284%29`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.0%285%29`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.0%289%29`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.1%281%29`,
        fs:  `cpe:2.3:a:libexpat:expat:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.2%281%29`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.3%281%29`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:10:sp4:*:*:ltss:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.3%282%29`,
        fs:  `cpe:2.3:a:google:chrome:5.0.330.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.3%283%29`,
        fs:  `cpe:2.3:a:mcafee:saas_endpoint_protection:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.3%284%29`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.3%284%29:sr1`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.4%281%29`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:1.4%282%29`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.33:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:2.0%280%29`,
        fs:  `cpe:2.3:a:anl:bcfg2:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:2.0%281%29`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.0%280%29`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.0%281%29`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.0%282%29`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.1%281%29`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.1%282%29`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server_administration_snap-in:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.1%283%29`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1022:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.1%284%29`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd329a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.1%286%29`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.1%2810%29`,
        fs:  `cpe:2.3:a:linux-ha:heartbeat:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.1%2811%29`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)m4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.17:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%281%29`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%282%29`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%283%29`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%284%29`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%285%29`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%286%29`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%286a%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_configuration_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%287%29`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_38:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%288%29`,
        fs:  `cpe:2.3:a:imgburn:imgburn:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%289%29`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%2810%29`,
        fs:  `cpe:2.3:h:cisco:asr_5700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%2811%29`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je104a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%2812%29`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%2813%29`,
        fs:  `cpe:2.3:a:libdwarf_project:libdwarf:20160115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%2814%29`,
        fs:  `cpe:2.3:a:php:php:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.2%2815%29`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%282%29`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1023.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%283%29`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%284%29`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%285%29`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%286%29`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%287%29`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%288%29`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%289%29`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%2810%29`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%2811%29`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-30-\/g-:server:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%2812%29`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%2813%29`,
        fs:  `cpe:2.3:a:logitech:lws_help_main:13.30.1396.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%2814%29`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:3.2.5:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%2815%29`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.8:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%2816%29`,
        fs:  `cpe:2.3:a:mozilla:firefox:51.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:3.3%2820%29`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:4.0%280%29`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:4.1%282%29`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:4.1%283%29`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr5060-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:4.1%284%29`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.112.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:4.1%285%29`,
        fs:  `cpe:2.3:a:7-zip:p7zip:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:4.1%286%29`,
        fs:  `cpe:2.3:a:ibm:leads:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:4.1%287%29`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:5.0%280%29`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:5.0%281a%29`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:5.0%283%29`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:5.0%285%29`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:5.0%286%29`,
        fs:  `cpe:2.3:a:apache:hadoop:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:5.0%287%29`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:6.0%280%29`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:9.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:6.0%282%29:sr2`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:6.0%283%29`,
        fs:  `cpe:2.3:a:castech:ezusb_smart_card_reader_setup_for_windows_2000_xp_2003:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:6.0%283%29:sr1`,
        fs:  `cpe:2.3:a:oracle:applications:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:6.0%284%29`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:007sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:6.0%285%29`,
        fs:  `cpe:2.3:a:augeas:augeas:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:6.1%280%29`,
        fs:  `cpe:2.3:a:facebook:hiphop_virtual_machine:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:6.1%281%29`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:7.0%281%29`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:7.0%282%29`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:7.0%282%29:sr1`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:7.0%283%29`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:7.1%282%29`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:7.2%282%29`,
        fs:  `cpe:2.3:a:f5:big-iq_security:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:7.2%283%29`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:7.2%284%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11.5\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%281%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%282%29`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%283%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%284%29`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:22.0.0.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%284%29:sr1`,
        fs:  `cpe:2.3:a:samba:samba:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%284%29:sr3a`,
        fs:  `cpe:2.3:a:combodo:itop:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%285%29`,
        fs:  `cpe:2.3:a:sun:enterprise_authentication_mechanism:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%286%29`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%287%29`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%288%29`,
        fs:  `cpe:2.3:a:openstack:swift:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%289%29`,
        fs:  `cpe:2.3:a:avas\!t:avast\!_mobile_security:2.0.4304:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.0%2810%29`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.1%281%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.1%282%29`,
        fs:  `cpe:2.3:a:apple:xserve_lights-out_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.2%281%29`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.2%282%29:sr1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.2%282%29:sr2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.2%282%29:sr3`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.2%282%29:sr4`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(8a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.3%281%29`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:3.0:sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.3%282%29`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.3%282%29:sr1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.3%283%29`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.3%283%29:sr1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.3%283%29:sr2`,
        fs:  `cpe:2.3:a:sortir-en-alsace:sortir_en_alsace:0.5b:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.3%285%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.4%281%29`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.4%281%29:sr2`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.4%282%29`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.5.2:-:-:en-us:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.4%283%29`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.09:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.4%284%29`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.5%282%29`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.5%282%29:sr1`,
        fs:  `cpe:2.3:a:aol:aim:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.5%283%29`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.5%283%29:sr1`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.5%284%29`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:8.70`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:9.0%282%29:sr1`,
        fs:  `cpe:2.3:a:pi-soft:spoonftp:1.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:9.0%282%29:sr2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.25:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:skinny_client_control_protocol_software:9.0%283%29`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:small_business_ip_phone:spa525g`,
        fs:  `cpe:2.3:a:wildpackets:omnipeek:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:small_business_ip_phone:spa525g2`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.1.7`,
        fs:  `cpe:2.3:a:yoshinori_tahara:mycaljp:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.2.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:21.0.0.242:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.3.5`,
        fs:  `cpe:2.3:h:hp:d7p71a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.4.3`,
        fs:  `cpe:2.3:o:openvas:greenbone_security_assistant:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.4.4`,
        fs:  `cpe:2.3:a:instantsoft:instantcms:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.4.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.4.6`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.4.7`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.4.8`,
        fs:  `cpe:2.3:a:apache:libcloud:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:small_business_ip_phone_firmware:7.4.9`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:small_business_wireless_access_points_firmware:1.0.4.4`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.16.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sn_5420_storage_router:-`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_command_center:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router:1.1%282%29`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router:1.1%283%29`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_windows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router:1.1%284%29`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router:1.1%285%29`,
        fs:  `cpe:2.3:a:avg:anti-virus_plus_firewall:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router:1.1%287%29`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router:1.1.3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.26:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router_firmware:1.1%282%29`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2.8:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router_firmware:1.1%283%29`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router_firmware:1.1%284%29`,
        fs:  `cpe:2.3:a:bscw:bscw:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router_firmware:1.1%285%29`,
        fs:  `cpe:2.3:h:intel:mobile_intel_qs57_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router_firmware:1.1%287%29`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:4.2.0:cp09:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5420_storage_router_firmware:1.1.3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:sn_5428_storage_router:-`,
        fs:  `cpe:2.3:a:mgsasia:qin_story:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5428_storage_router:2-3.3.1-k9`,
        fs:  `cpe:2.3:a:hp:universal_cmbd_foundation:10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5428_storage_router:2-3.3.2-k9`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5428_storage_router:2.5.1-k9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5428_storage_router:3.2.1-k9`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5428_storage_router:3.2.2-k9`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2_sp2:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5428_storage_router:3.3.1-k9`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd240b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:sn_5428_storage_router:3.3.2-k9`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:socialminer:-`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:socialminer:10.0%281%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(55\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_301:-`,
        fs:  `cpe:2.3:a:dmca:dmca_watermarker:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_301_1_line_ip_phone:-`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_302d:-`,
        fs:  `cpe:2.3:a:oracle:sysfw:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_302dkit:-`,
        fs:  `cpe:2.3:a:ibm:http_server:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_303:-`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_303_3_line_ip_phone:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa_500_series_ip_phone_firmware:7.3.7`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa_500_series_ip_phone_firmware:7.4.3`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa_500_series_ip_phone_firmware:7.4.4`,
        fs:  `cpe:2.3:a:ibm:monitoring_server_\(ms\)_and_shared_libraries_\(ax\):6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa_500_series_ip_phone_firmware:7.4.6`,
        fs:  `cpe:2.3:a:ibm:db2_content_manager_toolkit:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa_500_series_ip_phone_firmware:7.4.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.449:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa_500_series_ip_phone_firmware:7.4.8`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa_500_series_ip_phone_firmware:7.4.9`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa_500_series_ip_phone_firmware:7.5.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.78:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_500ds:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_500s:-`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_501g:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_501g_8-line_ip_phone:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:5.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_502g:-`,
        fs:  `cpe:2.3:a:google:v8:3.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_502g_1-line_ip_phone:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_504g:-`,
        fs:  `cpe:2.3:a:emc:networker:7.5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_504g_4-line_ip_phone:-`,
        fs:  `cpe:2.3:a:hp:jetadmin:5.5.177:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_508g:-`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_508g_8-line_ip_phone:-`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_509g:-`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:4.0.3:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_509g_12-line_ip_phone:-`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_512g:-`,
        fs:  `cpe:2.3:a:garagesale_project:garagesale:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_512g_1-line_ip_phone:-`,
        fs:  `cpe:2.3:o:huawei:s5310hi_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_514g:-`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:58.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_514g_4-line_ip_phone:-`,
        fs:  `cpe:2.3:a:isc:bind:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_525g_5-line_ip_phone:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_secureway_policy_director:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_525g2:-`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa_525g2_5-line_ip_phone:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa2102_phone_adapter_with_router:-`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:-:cloud:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.5`,
        fs:  `cpe:2.3:a:plone:plone:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.10`,
        fs:  `cpe:2.3:a:acme:thttpd:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.12`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.13`,
        fs:  `cpe:2.3:a:flurry:flurry-analytics-android:3.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa300_firmware:7.5.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa300_firmware:7.5.7`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa300_series_ip_phone:-`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa300_series_ip_phone_firmware:7.5.7%286%29`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa3102_voice_gateway_with_router:-`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:12.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa3102_voice_gateway_with_router_firmware:3.3.6`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa3102_voice_gateway_with_router_firmware:5.1.7`,
        fs:  `cpe:2.3:h:cisco:sg300-28pp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa3102_voice_gateway_with_router_firmware:5.1.10`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa3102_voice_gateway_with_router_firmware:5.2.13`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa500_firmware:7.5.5`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa500_firmware:7.5.7`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa500_series_ip_phone:-`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa500_series_ip_phone_firmware:7.5.7%286%29`,
        fs:  `cpe:2.3:a:emc:networker:7.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa8000_8-port_ip_telephony_gateway:-`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa8000_8-port_ip_telephony_gateway_firmware:5.1.12`,
        fs:  `cpe:2.3:h:hp:0235a269:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa8000_8-port_ip_telephony_gateway_firmware:6.1.3`,
        fs:  `cpe:2.3:a:hp:network_virtualization:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa8000_8-port_ip_telephony_gateway_firmware:6.1.10`,
        fs:  `cpe:2.3:a:biebernoticias:bieber_news_now:12.0.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa8000_8-port_ip_telephony_gateway_firmware:6.1.11`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)s1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa8800_8-port_ip_telephony_gateway_firmware:6.1.7`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.22:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:spa8800_8-port_ip_telephony_gateway_firmware:6.1.11`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa8800_ip_telephony_gateway:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:0.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa901_1-line_ip_phone:-`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa922_1-line_ip_phone_with_1-port_ethernet:-`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa941_4-line_ip_phone_with_1-port_ethernet:-`,
        fs:  `cpe:2.3:a:zlib:pigz:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa942_4-line_ip_phone_with_2-port_switch:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:spa962_6-line_ip_phone_with_2-port_switch:-`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:spark:2015-06_base`,
        fs:  `cpe:2.3:a:process-one:ejabberd:1.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:spark:2015-07-04`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:spark:2015-07-04_base`,
        fs:  `cpe:2.3:a:symantec:protection_for_sharepoint_servers:6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ssl_vpn_client:1_1_2_169`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ssl_vpn_client:1.1.4.179`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.138:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:11.0_base`,
        fs:  `cpe:2.3:a:corel:fontnav:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:12.0`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:12.0.0`,
        fs:  `cpe:2.3:a:cogentdatahub:datahub_quicktrend:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:12.1_base`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:12.2%28300%29`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:12.2_base`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:14.0%28600%29`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:14.0.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:15.0%28912%29`,
        fs:  `cpe:2.3:o:f5:tmos:9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:15.0%28935%29`,
        fs:  `cpe:2.3:a:webcreate:web_mart:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:15.0%28938%29`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:15.0_base`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:16.0%28900%29`,
        fs:  `cpe:2.3:a:hp:hp-ux_containers:a.03.01.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:16.0.0`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:16.1.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:16.1.1`,
        fs:  `cpe:2.3:a:appsgeyser:competition_information:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:16.1.2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:16.5.0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:16.5.2`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:17.2.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:17.2.0.59184`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:17.3.0`,
        fs:  `cpe:2.3:a:firebird:firebird:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:17.3.1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.1:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:17.3_base`,
        fs:  `cpe:2.3:h:cisco:c881w_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:17.7.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.0.0`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.0.0.57828`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-50-\/b:-:standard:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.0.0.59167`,
        fs:  `cpe:2.3:a:divx:converter:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.0.0.59211`,
        fs:  `cpe:2.3:a:umn:mapserver:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.0.l0.59219`,
        fs:  `cpe:2.3:h:meinberg:ims-lantime_m3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.1.0`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.1.0.59776`,
        fs:  `cpe:2.3:o:cisco:staros:18.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.1.0.59780`,
        fs:  `cpe:2.3:a:google:v8:3.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.1_base`,
        fs:  `cpe:2.3:a:sun:sdk:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(23\)sx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.3_base`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:18.4.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:19.0.1`,
        fs:  `cpe:2.3:a:corel:coreldraw_draw:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:19.0.m0.60737`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:19.0.m0.60828`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:19.0.m0.61045`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:19.1.0`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:10.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:19.1.0.61559`,
        fs:  `cpe:2.3:a:google:chrome:5.0.369.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:19.2.0`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:19.3.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.499.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.1.0`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.1.a0`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.1.v0`,
        fs:  `cpe:2.3:h:hp:arcsight_connector_appliance:c3400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.2.3`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:4.7-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.2.3.65026`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.2.v1`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.m0.62842`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.m0.63229`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:20.0.v0`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.1:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:staros:21.0_base`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ecg:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:storage_router:-`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.03.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:subscriber_edge_services_manager:-`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:supervisor_desktop:80.2.9`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.77b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:support_tools:-`,
        fs:  `cpe:2.3:a:c-icap_project:c-icap:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:system_controller_3640:-`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:system_unified_contact_center_enterprise:-`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tac_plus:-`,
        fs:  `cpe:2.3:a:aimluck:aipo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tacacs%2b:f4.0.2alpha`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tacacs%2b:f4.0.3alpha`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tacacs%2b:f4.0.4alpha`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:tandberg_2000_mxp:-`,
        fs:  `cpe:2.3:a:cpe17:autorun_killer:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:tandberg_550_mxp:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:tandberg_770_mxp:-`,
        fs:  `cpe:2.3:a:apache:ranger:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:tandberg_880_mxp:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:tandberg_990_mxp:-`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_advanced_media_gateway:1.0%28.1.13%29`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_advanced_media_gateway:1.1%28.1.14%29`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_advanced_media_gateway:1.1%281.34%29`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_advanced_media_gateway:1.1%281.40%29`,
        fs:  `cpe:2.3:a:simplerealtytheme:advanced_text_widget_plugin:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_codec_c40:-`,
        fs:  `cpe:2.3:h:xerox:document_centre_430:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_codec_c60:-`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_cluster_suite:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_codec_c90:-`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.051:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_conductor:xc2.4:prealpha0`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_conductor:xc3:prealpha0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:te2.2`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:te2.2.1`,
        fs:  `cpe:2.3:a:jojocms:jojo-cms:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:te4.0.0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:te4.1.0`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:te4.1.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:te4.1.1-cucm`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:01-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:tenc4.0.0`,
        fs:  `cpe:2.3:a:smarty:smarty:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:tenc4.1.0`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup_agent:-:*:sap:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:tenc4.1.1`,
        fs:  `cpe:2.3:o:samsung:ps50c7700_television_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_e20_software:tenc4.1.1-cucm`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_ex60:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p295:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_ex90:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_ip_gateway:2.0.1.7`,
        fs:  `cpe:2.3:a:hp:openview_security_core:2.20.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_ip_gateway:2.0.1.11`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.017.20050:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_ip_gateway:2.0.3.34`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.11:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_ip_vcr_1.0_converter:1.0%281.9%29`,
        fs:  `cpe:2.3:a:haxx:curl:7.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_ip_vcr_2.4:1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_ip_vcr_3.0:1.22`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_ip_vcr_3.0:1.24`,
        fs:  `cpe:2.3:a:pizzahut:pizza_hut_japan_official_order_application:1.1.1:a:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gateway_software:2.1%281.43%29`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gateway_software:2.1%281.49%29`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30279:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gateway_software:2.1%281.56%29`,
        fs:  `cpe:2.3:a:emc:powerpath:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gateway_software:2.1%281.79%29`,
        fs:  `cpe:2.3:a:tincan:phplist:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gw_3241:2.0%281.51%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gw_3241:2.1%281.22%29`,
        fs:  `cpe:2.3:a:hp:operations_agent:11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gw_3241:2.1%281.43%29`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gw_3241:2.1%281.49%29`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_isdn_gw_3241:2.1%281.56%29`,
        fs:  `cpe:2.3:a:att:connect_participant_application:9.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_ix5000:-`,
        fs:  `cpe:2.3:a:python:python:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_ix5200:-`,
        fs:  `cpe:2.3:a:opentext:livelink_remote_search:1.2.0.448:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_management_suite:-:-:~~~~x64~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_management_suite:13.0`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:6.30.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_management_suite:13.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_management_suite:14.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:108.2146.2565.38893:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_management_suite:14.3%28.1%29`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_management_suite:14.3%28.2%29`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.554:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.1.0.0`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.1.0.0%28209%29`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.2.0.0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.2.0.0%28200%29`,
        fs:  `cpe:2.3:a:hp:operations_manager:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.3.2%28466%29`,
        fs:  `cpe:2.3:a:netiq:appmanager_agent:7.0.25020.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.4.0%28279%29`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.5.1%28420%29`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:2:ur2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.5.2%28423%29`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.3:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.6.0%28220%29`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.6.2%2864%29`,
        fs:  `cpe:2.3:a:4you-studio:com_jphone:1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.6.3%28113%29`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.251:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.6.5%28167%29`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.7.1%28732%29`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.7.2%28256%29`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.7.3.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.7.4`,
        fs:  `cpe:2.3:a:x.org:libx11:1.4.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.7.5%2862%29`,
        fs:  `cpe:2.3:a:apple:safari:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.8.0%28582%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p485_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.8.1%28682%29`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_manager:1.9.0%28198%29`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-8p-si_ls-5100-8p-si-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4500_series_software:4.1%281.51%29`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4500_series_software:4.1%281.59%29`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4500_series_software:4.2%281.43%29`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4500_series_software:4.2%281.46%29`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.11:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4500_series_software:4.2%281.50%29`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4500_series_software:4.3%281.68%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4500_series_software:4.3%282.18%29`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4500_series_software:4.5%281.45%29`,
        fs:  `cpe:2.3:a:autodesk:sketchbook:6.2.5:*:*:*:copic:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_mcu_4501:-`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4501_series_software:4.1%281.51%29`,
        fs:  `cpe:2.3:a:netiq:appmanager_control_center:7.0.40469.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4501_series_software:4.1%281.59%29`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4501_series_software:4.2%281.43%29`,
        fs:  `cpe:2.3:a:horde:imp:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4501_series_software:4.2%281.46%29`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4501_series_software:4.2%281.50%29`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.415:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4501_series_software:4.3%281.68%29`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_4501_series_software:4.3%282.18%29`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_mcu_4505:-`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_mcu_4510:-`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_mcu_4515:-`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_mcu_4520:-`,
        fs:  `cpe:2.3:a:apache:subversion:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_mcu_mse_8510:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_mse_series_software:4.1%281.51%29`,
        fs:  `cpe:2.3:a:symantec:i-gear:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_mse_series_software:4.1%281.59%29`,
        fs:  `cpe:2.3:a:barebones:yojimbo:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_mse_series_software:4.2%281.43%29`,
        fs:  `cpe:2.3:a:novaboard:novaboard:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_mse_series_software:4.2%281.46%29`,
        fs:  `cpe:2.3:a:seikousa:smart_label_printer:7.0.418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_mse_series_software:4.2%281.50%29`,
        fs:  `cpe:2.3:a:apple:itunes:10.4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_mse_series_software:4.3%281.68%29`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_mse_series_software:4.3%282.18%29`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.1%281.51%29`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.1%281.59%29`,
        fs:  `cpe:2.3:h:hp:jf430a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.2%281.43%29`,
        fs:  `cpe:2.3:o:oracle:vm_server:3.2:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.2%281.46%29`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.2%281.50%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.3%281.68%29`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jnp3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.3%282.30%29`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.3%282.32%29`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.4%283.42%29`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_mcu_software:4.4%283.49%29`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_multipoint_switch:-`,
        fs:  `cpe:2.3:a:digium:asterisk:13.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.0.4.0`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.0.4.0%2821%29`,
        fs:  `cpe:2.3:a:limewire:limewire:4.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(11b\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.1.0%28254%29`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.1.1`,
        fs:  `cpe:2.3:a:netscape:personalization_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.1.1%2830%29`,
        fs:  `cpe:2.3:a:revouninstaller:uninstaller:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.1.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(3\)n2\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.1.2%286%29`,
        fs:  `cpe:2.3:a:vine_mv_project:vine_mv:2015-09-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.0`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.0%28222%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.1`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.1%282%29`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.2`,
        fs:  `cpe:2.3:h:xerox:workcentre_m175:6.47.33.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.2%2821%29`,
        fs:  `cpe:2.3:a:oracle:common_applications_calendar:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.3`,
        fs:  `cpe:2.3:a:libav:libav:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.3.12`,
        fs:  `cpe:2.3:h:cisco:catalyst_2950_lre:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.4`,
        fs:  `cpe:2.3:a:hp:install_network_printer_wizard:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.4%284%29`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.3:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.5`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.16:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.5%281%29`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.6`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.5.6%281%29`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(15\)xq1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.0%28108%29`,
        fs:  `cpe:2.3:a:yahoo:yui:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.1%282%29`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.2`,
        fs:  `cpe:2.3:a:ibm:initiate_master_data_service:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.2%283%29`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.3`,
        fs:  `cpe:2.3:a:nec:expresscluster_x:3.3:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.3%282%29`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.6.4%283%29`,
        fs:  `cpe:2.3:a:raoul_proenca:gnew:2013.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.7.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1.5es33.32900-33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.7.0.1%285%29`,
        fs:  `cpe:2.3:a:cabletron:spectrum_enterprise_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.7.1%2815%29`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.7.2%2875%29`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.7.3%282%29`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.8.0`,
        fs:  `cpe:2.3:a:ssh:tectia_manager:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.8.0%281026%29`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.1.0.825a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.8.1%281041%29`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.8.2`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.8.2%282%29`,
        fs:  `cpe:2.3:a:apple:quicktime:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.8.3%289%29`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.9.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_multipoint_switch_software:1.9.0%28127%29`,
        fs:  `cpe:2.3:a:mysql:mysql:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_mx200:-`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:9.5.0-201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_mx300:-`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_profile_55:-`,
        fs:  `cpe:2.3:a:ibm:http_server:2.0.42.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_profile_65:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_quick_set_c20:-`,
        fs:  `cpe:2.3:a:gajim:gajim:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_quick_set_sx20:-`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_readiness_assessment_manager:1.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.6.1%282%29`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.6.2%2831%29`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_41:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.6.3%284%29`,
        fs:  `cpe:2.3:a:sigong_ebook_project:sigong_ebook:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.7.0%28190%29`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:preview4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.7.1%2822%29`,
        fs:  `cpe:2.3:a:apache:poi:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.7.2.1`,
        fs:  `cpe:2.3:a:mcafee:mcafee_agent:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.7.3%283%29`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.8.0%28160%29`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_endpoints:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.8.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1043.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_recording_server:1.8.1%285%29`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_serial_gateway:1.0.1.23`,
        fs:  `cpe:2.3:a:nesvarnik:nesvarnik:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_serial_gateway:1.0.1.34`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_serial_gateway:1.0.1.38`,
        fs:  `cpe:2.3:a:core-apps:ohbm_20th_annual_meeting:6.0.9.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_server_7010:-`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_server_mse_8710:-`,
        fs:  `cpe:2.3:a:redgraphic:sapid_cms:1.2.3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:2.1%281.33%29`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:2.1%281.37%29`,
        fs:  `cpe:2.3:a:autodesk:autocad_map_3d_2009:12.0.048.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:2.2%281.43%29`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:2.2%281.48%29`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp3:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:2.2%281.54%29`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.6.4:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:2.3%281.55%29`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:2.3%281.57%29`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.0%282.24%29`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p160:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.0%282.46%29`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.0%282.48%29`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.0%282.49%29`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(1j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.1%281.80%29`,
        fs:  `cpe:2.3:a:atmail:atmail:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.1%281.82%29`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.1:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.1%281.95%29`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.4.980:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.1%281.96%29`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.1%281.97%29`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:3.1%281.98%29`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:4.0%281.57%29`,
        fs:  `cpe:2.3:h:hp:jg363b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:4.0%282.8%29`,
        fs:  `cpe:2.3:a:lixil:my_satis_genius_toilet:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:4.1%281.40%29`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.1.20913.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:4.2%284.17%29`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:2.0.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_server_software:4.2%284.18%29`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_supervisor_mse_8050_software:2.1%281.18%29`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_supervisor_mse_8050_software:2.2%281.17%29`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-07-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_supervisor_mse_8050_software:2.3%281.32%29`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.8:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_1000:-`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_1000_mxp:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_customer_relationship_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_1100:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_1300:-`,
        fs:  `cpe:2.3:a:typoheads:formhandler:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_1300-65:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_1300_65:-`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1.5:sp0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_1700_mxp:-`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_3000:-`,
        fs:  `cpe:2.3:a:skype:skype:1.4.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_3010:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_3200:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_3210:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_500-32:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_500-37:-`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_codec_3000_mxp:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_codec_6000_mxp:-`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_edge_75_mxp:-`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_edge_85_mxp:-`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_edge_95_mxp:-`,
        fs:  `cpe:2.3:a:atmail:atmail:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:-`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.2.3%281101%29`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-20p-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.3.2%281393%29`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.4.7%282229%29`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.5.1%282082%29`,
        fs:  `cpe:2.3:a:paramore_project:paramore:2.3.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.5.3%282115%29`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.5.10%283648%29`,
        fs:  `cpe:2.3:a:atlassian:confluence:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.5.11%283659%29`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.5.12%283701%29`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20020730:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.5.13%283717%29`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.6.0%283954%29`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.6.2%284023%29`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.6.3%284042%29`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.6.4%284072%29`,
        fs:  `cpe:2.3:a:gnu:glibc:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.6.5%284097%29`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.6.6%284109%29`,
        fs:  `cpe:2.3:a:datadirect:datadirect_connect_odbc:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.6.7%284212%29`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.9:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.6.8%284222%29`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.01:b6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.7.0.1%284764%29`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.7.0.2%284719%29`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.7.1%284864%29`,
        fs:  `cpe:2.3:a:ibm:atlas_ediscovery_process_management:6.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.7.2%284937%29`,
        fs:  `cpe:2.3:a:moodle:moodle:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.7.2.1%282%29`,
        fs:  `cpe:2.3:h:apple:imac:mb388xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.7.4%28270%29`,
        fs:  `cpe:2.3:a:horde:imp:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.7.5%2842%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.7.6%284%29`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.8.0%2855%29`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1498.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.8.0u%29`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.8.1%2834%29`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.8.2%2811%29`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.8.3%284%29`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.8.4%2813%29`,
        fs:  `cpe:2.3:a:extplorer:com_extplorer:2.1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.8.5%284%29`,
        fs:  `cpe:2.3:a:foolabs:xpdf:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.8.14%29`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.0%2846%29`,
        fs:  `cpe:2.3:a:progress:openedge:10.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.0.1%283%29`,
        fs:  `cpe:2.3:a:google:talk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.1%2868%29`,
        fs:  `cpe:2.3:a:finalbeta:mywebsearch:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.2`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_hmi\%2fscada_cimplicity:8.2:sim24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.2%2819%29`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd429b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.3`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.3%2844%29`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.4`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.08.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.4%2819%29`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.5`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.5%287%29`,
        fs:  `cpe:2.3:a:microsoft:dynamics_ax:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.6`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.8.1.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.6%282%29`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.9.6.1%283%29`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp1:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.10.0`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.10.0%28259%29`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.10.1`,
        fs:  `cpe:2.3:a:sourcegear:diffmerge:3.3.1.1118:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.10.1%2843%29`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.10.2%2842%29`,
        fs:  `cpe:2.3:h:sun:storedge_3310_scsi_array:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:1.10.3%2841%29`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:4.0.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:6.0.0.1%284%29`,
        fs:  `cpe:2.3:h:siemens:ccmw3025:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:6.0.1%2850%29`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:6.0.2%2828%29`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:6.0.3%2833%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:6.0.4%2811%29`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:6.0.5%285%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:6.1.0%2890%29`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:f9.0.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.586:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:f9.0.2`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:f9.1.0`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_command_center:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:f9.1.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.50:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:f9.1.2`,
        fs:  `cpe:2.3:h:swann:swnvw-470cam_firmware:1022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:f9.3`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:f9.3.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:fnc9.1.0`,
        fs:  `cpe:2.3:a:ultraplayer:ultraplayer_media_player:2.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:fnc9.1.1`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd3.t666:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:fnc9.1.2`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:fnc9.3`,
        fs:  `cpe:2.3:a:autodesk:autocad_architecture_2011_language_pack:18.1.49.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:fnc9.3.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tc3.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:11.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tc3.1.4`,
        fs:  `cpe:2.3:a:mybb:mybb:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tc3.1.5`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tc4.1.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tc5.1.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tcu4.0.3`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.3.0:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tcu4.1.0`,
        fs:  `cpe:2.3:a:cadpage:cadpage:1.7.44:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tcu4.2.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tt4.0.3`,
        fs:  `cpe:2.3:h:huawei:6700ei:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:tt4.1.0`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:2.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:x5.2`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:x6.0`,
        fs:  `cpe:2.3:a:vips:vips:7.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:x6.1`,
        fs:  `cpe:2.3:o:ibm:aix:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:x7.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:x7.0.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:x7.0.2`,
        fs:  `cpe:2.3:a:icofx:icofx:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_system_software:x7.0.3`,
        fs:  `cpe:2.3:a:microsoft:small_business_server:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:telepresence_system_software_ix:8.0.0`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:telepresence_system_software_ix:8.0.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.3.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_t3:-`,
        fs:  `cpe:2.3:h:supermicro:x9drff-7\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_t3:-::custom`,
        fs:  `cpe:2.3:a:red-gate:sql_backup:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_tx1300_47:-`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_tx1310_65:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_tx9000:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_system_tx9200:-`,
        fs:  `cpe:2.3:a:etghosting:etg_hosting:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:3.1.5`,
        fs:  `cpe:2.3:a:hummingbird:exceed:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:3.1_base`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.0.0`,
        fs:  `cpe:2.3:h:f5:big-ip_access_policy_manager:10.2.4:*:*:*:*:*:*:standalone`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.0.1`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_database_control:10.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.0.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.1.0`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router_firmware:1.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.1_base`,
        fs:  `cpe:2.3:a:netscape:navigator:4.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.2.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.2.1`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.2.2`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-400_cpu_416f-3_pn\/dp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.2.3`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.2.4`,
        fs:  `cpe:2.3:a:pcre:perl-compatible_regular_expression_library:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:4.2_base`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.0.0`,
        fs:  `cpe:2.3:a:microsoft:visio_viewer:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.0.1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.0.2`,
        fs:  `cpe:2.3:o:huawei:honor_6_firmware:h60-l21c00b850:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.0.2-cucm`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update7:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.0_base`,
        fs:  `cpe:2.3:a:ibm:worklight:6.1.0.0:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.0`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.1`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.11:*:*:*:*:*:rs950g:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.2`,
        fs:  `cpe:2.3:a:hummingbird:bi_query:9.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.3`,
        fs:  `cpe:2.3:a:md-systems:simplenews:7.x-1.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.3-cucm`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.4`,
        fs:  `cpe:2.3:a:starbucks:starbucks:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.4-cucm`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.5`,
        fs:  `cpe:2.3:a:qemu:qemu:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.5-cucm`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2000i:sp2:locked:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.6`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.6-cucm`,
        fs:  `cpe:2.3:a:cristian_gafton:pam_userdb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.7`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1.7-cucm`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.6.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:5.1_base`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.0.0`,
        fs:  `cpe:2.3:a:lxml:lxml:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.0.0-cucm`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.0.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.0.1-cucm`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.4\(3.49\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.0.2`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.35:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.0.3`,
        fs:  `cpe:2.3:h:selinc:sel-2241:r123-v0-z002001-d20130117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.0_base`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:8.5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1.0-cucm`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1.1`,
        fs:  `cpe:2.3:o:iij:seil\%2fturbo_firmware:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1.1-cucm`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1.2`,
        fs:  `cpe:2.3:a:rix_go_locker_theme_project:rix_go_locker_theme:1.20.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1.2-cucm`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1.3`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1.4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.22:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.1_base`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass_guest:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.2.0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.2.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.3.0`,
        fs:  `cpe:2.3:h:cisco:xr_12404:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.3.1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.3.2`,
        fs:  `cpe:2.3:a:teradata:fastload:13.10.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.3.3`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.3.4`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:6.3_base`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.1.1`,
        fs:  `cpe:2.3:a:pgp:personal_privacy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.1.2`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.1.3`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.1.4`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.2.0`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:3.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.2.1`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:telepresence_tc_software:7.2_base`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.3.0`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.3.1`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.3.2`,
        fs:  `cpe:2.3:a:google:toolbar_for_internet_explorer:7.2.2318.1946:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_tc_software:7.3.3`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_command_center:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:4.1.0`,
        fs:  `cpe:2.3:a:mikejolley:download_monitor:1.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:4.1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:4.1.2`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:4.1.3`,
        fs:  `cpe:2.3:a:canon:imagerunner_2620:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:6.0`,
        fs:  `cpe:2.3:a:news_search_project:news_search:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:6.0.0`,
        fs:  `cpe:2.3:a:tom_m8te_plugin_project:tom-m8te_plugin:1.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:6.0.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:6.0.2`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.7100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_te_software:6.0_base`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_video_communication_server:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:-::~~control~~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:-::~~expressway~~~`,
        fs:  `cpe:2.3:a:oracle:mysql_workbench_ce:5.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_video_communication_server:-::control`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(24\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_video_communication_server:-::expressway`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ya9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:telepresence_video_communication_server:-::starter_pack_express`,
        fs:  `cpe:2.3:a:cisco:web_collaboration_option:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.1.1`,
        fs:  `cpe:2.3:a:canonical:telepathy-idle:0.1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.1.2`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.1.4.6324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.1_base`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.632:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.2.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.309.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.2.2`,
        fs:  `cpe:2.3:a:isc:bind:9.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.2_base`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.5:rc4`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.4.3860.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.5.0`,
        fs:  `cpe:2.3:a:huawei:campus_series_switch_software:v200r001sph013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.5.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.5.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)t8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server:x8.6.1`,
        fs:  `cpe:2.3:o:d-link:dcs-2136l_firmware:1.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x6.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x6.1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x7.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x7.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x7.2.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x7.2.2`,
        fs:  `cpe:2.3:a:cisco:accesspath:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x7.2.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.6.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.1`,
        fs:  `cpe:2.3:a:stanford:protege:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.1::~~base~~~`,
        fs:  `cpe:2.3:a:sun:jre:6.0.180:update18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.1.1`,
        fs:  `cpe:2.3:a:schneider-electric:device_type_manager:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.1.2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.25:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.1_base`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.3.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.2::~~base~~~`,
        fs:  `cpe:2.3:a:subsplash:first_assembly_nlr:2.8.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.2.1`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.2.2`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.2_base`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.5:rc4`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.5.0`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.5.2`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.5.2::~~expressway~~~`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.6`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.6::~~expressway~~~`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.6.0`,
        fs:  `cpe:2.3:a:oracle:sysfw:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.6.1`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l36erm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.7::~~base~~~`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_server_software:x8.7_base`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_servers_software:x7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_servers_software:x7.0.1`,
        fs:  `cpe:2.3:a:cisco:jabber:9.6\(1\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_servers_software:x7.0.2`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.41.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_video_communication_servers_software:x7.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_vx_clinical_assistant:1.00`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_vx_clinical_assistant:1.2`,
        fs:  `cpe:2.3:h:nortel:nautica_marlin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_vx_clinical_assistant:1.10`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:telepresence_vx_clinical_assistant:1.21`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tftp_server:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tftp_server:1.1`,
        fs:  `cpe:2.3:a:gentoo:rootkit_hunter:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:threat_response:-`,
        fs:  `cpe:2.3:a:hp:app_studio:140.0.95.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:3.0.0`,
        fs:  `cpe:2.3:a:apple:itunes:7.7.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:3.0.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:5.2.2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:5.3.0`,
        fs:  `cpe:2.3:a:veritas:netbackup:4.5.0:mp6:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:5.3.1`,
        fs:  `cpe:2.3:a:color:icclib:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:6.0.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:6.0.1`,
        fs:  `cpe:2.3:h:netgear:wg602:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:6.0.2`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:6.0.3`,
        fs:  `cpe:2.3:a:oracle:sun_middleware_products:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:tidal_enterprise_scheduler:6.1.0`,
        fs:  `cpe:2.3:a:docker:docker:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:traffic_anomaly_detector_module:-`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:traffic_anomaly_detector_module:5.0%281%29`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:traffic_anomaly_detector_module:5.0%283%29`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:transport_controller:-`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:1.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:transport_gateway_installation_software:4.0`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:trust_agent:-`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:trust_agent:1`,
        fs:  `cpe:2.3:a:kktalk:kktalk:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:trust_agent:1.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:trust_agent:2.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:trust_agent:2.0.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:trust_agent:2.1`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.2.0:beta_r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:trust_agent:2.1.103.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)xy6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ubr10012:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.6.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ubr7200:-`,
        fs:  `cpe:2.3:a:apple:xcode:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ubr920:-`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ubr924:-`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ubr925:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ucs_director:4.0.0.0`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ucs_director:4.0.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ucs_director:4.0.0.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ucs_director:4.0.0.3`,
        fs:  `cpe:2.3:a:rabidhamster:r2\/extreme:1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ucs_director:4.1.0.0`,
        fs:  `cpe:2.3:a:modpagespeed:mod_pagespeed:0.10.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ucs_director:4.1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:ucs_director:4.1.0.2`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7975g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_application_environment_application_server:2.5.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_application_environment_media_engine:2.5.1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_application_environment_platform_services:2.5.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_border_element:-`,
        fs:  `cpe:2.3:a:opsview:opsview:4.3:-:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_call_manager:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:-`,
        fs:  `cpe:2.3:a:qemu:qemu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%282%29`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:s1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%282%29spb`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_bootable_media_builder:10.0.13762:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%282%29spc`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.2018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%283%29`,
        fs:  `cpe:2.3:a:pantech:uml290_end_user_upgrade:16.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%283%29sr1`,
        fs:  `cpe:2.3:a:haxx:curl:7.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%283%29sr4`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%284%29`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%284%29sr1a`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%285%29`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:enterprise_x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%285%29sr1`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%285%29sr1a`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%285%29sr2`,
        fs:  `cpe:2.3:a:hp:hpztlbxfx:5.13.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%285%29sr2a`,
        fs:  `cpe:2.3:a:apache:poi:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:3.3%285%29sr3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p1_beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1%282%29`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1%283%29`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1%283%29sr1`,
        fs:  `cpe:2.3:a:f5:enterprise_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1%283%29sr2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1%283%29sr3`,
        fs:  `cpe:2.3:a:bestpractical:rtfm:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1%283%29sr4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1%283%29sr5`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.1%283%29sr5b`,
        fs:  `cpe:2.3:a:polycom:rmx_system_software:4.5.0.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.2`,
        fs:  `cpe:2.3:a:google:talk_plugin:2.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.2%283%29sr1`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.3`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.3.1`,
        fs:  `cpe:2.3:a:ibm:content_navigator:2.0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:4.3.2000`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d55:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:5.0`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:5.0%281%29`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:5.0%282%29`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:5.0%283%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:5.0%283a%29`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:5.0%284%29`,
        fs:  `cpe:2.3:a:m2_technologies:optimalsite:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager:9.1%282.1000.28%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_callmanager_bulk_administration_tool:4.6.104`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:update1:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ccx:6.0%281%29`,
        fs:  `cpe:2.3:a:goforandroid:go_sms_pro:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ccx:7.0%281%29`,
        fs:  `cpe:2.3:o:debian:debian_linux:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ccx:7.0%282%29`,
        fs:  `cpe:2.3:a:apple:safari:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ccx:8.0%281%29`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ccx:8.0%282%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ccx:8.5%281%29`,
        fs:  `cpe:2.3:o:cisco:mds_9000_nx-os:7.1\(0\)zn\(91.99\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ccx_editor:8.0.1161.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ccx_historical_reports:1.0.0.0`,
        fs:  `cpe:2.3:a:fedup_project:fedup:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_cdm_application_software:8.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_cdm_application_software:8.1.4`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_cdm_application_software:10.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_cdm_platform_software:4.4`,
        fs:  `cpe:2.3:h:cisco:unified_ip_interactive_voice_response:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_cdm_platform_software:4.4.2`,
        fs:  `cpe:2.3:o:d-link:dcs-2310l_firmware:2.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:-`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:4.4.1`,
        fs:  `cpe:2.3:h:linksys:wrt54gs:4.50.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:4.4.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:4.4.3`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:4.4.4`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20140313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:7.4`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.0.1`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.0.2`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.1`,
        fs:  `cpe:2.3:a:apache:struts:2.3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.1%28.1%29`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.1%28.2%29`,
        fs:  `cpe:2.3:a:piwik:piwik:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.1%28.3%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.1%28.4%29`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.1%284%29er1`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.1.4er1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:8.6%28.2%29`,
        fs:  `cpe:2.3:a:login_security_project:login_security:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:9.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:9.0%28.1%29`,
        fs:  `cpe:2.3:a:moodle:moodle:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:10.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:10.5%281.98991.13%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:10.6.1`,
        fs:  `cpe:2.3:a:corel:paintshop_pro_x6:16.0.0.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_domain_manager:10.6_base`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.6.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p219:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:3.3%285%29`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:3.3%285%29sr1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:3.3%285%29sr2a`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.1%283%29`,
        fs:  `cpe:2.3:o:juniper:junos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.1%283%29sr1`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.1%283%29sr2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.1%283%29sr3`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.1%283%29sr4`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.2`,
        fs:  `cpe:2.3:a:f5:linerate:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.2.1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.2.2`,
        fs:  `cpe:2.3:a:ibm:license_metric_tool_tad4d_agent:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.2.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.2.3sr1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.2.3sr2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.2.3sr2b`,
        fs:  `cpe:2.3:a:cisco:webns:6.10_b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:4.3%281%29`,
        fs:  `cpe:2.3:a:redhat:network_proxy:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:12.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1`,
        fs:  `cpe:2.3:a:logitech:mvision:10.51.2027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%281%29`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%281b%29`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%281c%29`,
        fs:  `cpe:2.3:a:openx:openx:2.7.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%282%29`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%282a%29`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%282b%29`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%283%29`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%283a%29`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%283c%29`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%283d%29`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1%283e%29`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:5.1.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.0`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.0%281%29`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.13.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.0%281a%29`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.0%281b%29`,
        fs:  `cpe:2.3:a:exim:exim:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%281%29`,
        fs:  `cpe:2.3:a:elemata:elemata_cms:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%281a%29`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.2.110.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%281b%29`,
        fs:  `cpe:2.3:a:ca:license_software:1.62.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%282%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%282%29su1`,
        fs:  `cpe:2.3:a:google:v8:3.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%282%29su1a`,
        fs:  `cpe:2.3:h:hp:jg777a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%283%29`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%283a%29`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%283b%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%283b%29su1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%284%29`,
        fs:  `cpe:2.3:a:openx:openx:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%284%29su1`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%284a%29`,
        fs:  `cpe:2.3:a:google:chrome:12.0.719.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%284a%29su2`,
        fs:  `cpe:2.3:a:google:chrome:10.0.628.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%285%29`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%285%29su1`,
        fs:  `cpe:2.3:a:anl:bcfg2:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%285%29su2`,
        fs:  `cpe:2.3:a:spip:spip:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:6.1%285%29su3`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.0%281%29su1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.0%281%29su1a`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.0%282%29`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.0%282a%29`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.0%282a%29su1`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.0%282a%29su2`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%282a%29`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%282a%29su1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%282b%29`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.137:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%282b%29su1`,
        fs:  `cpe:2.3:h:seil:b1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%283%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zh8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%283a%29`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%283a%29su1`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%283a%29su1a`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.32:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%283b%29`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%283b%29su1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%283b%29su2`,
        fs:  `cpe:2.3:a:microsoft:visual_database_tools_database_designer:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285%29`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.52.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285%29su1`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285%29su1a`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285a%29`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285b%29`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285b%29su1`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:45.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285b%29su1a`,
        fs:  `cpe:2.3:a:google:chrome:5.0.390.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285b%29su2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285b%29su3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.0:beta0001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285b%29su4`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285b%29su5`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:7.1%285b%29su6`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0`,
        fs:  `cpe:2.3:a:ibm:daeja_viewone:4.1.5:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%281%29`,
        fs:  `cpe:2.3:a:ibm:java:7.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%282%29`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%282a%29`,
        fs:  `cpe:2.3:h:enterasys:1h582-25:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%282b%29`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%282c%29`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.9:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%282c%29su1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%283%29`,
        fs:  `cpe:2.3:a:biscom:faxcom_server:5.5.13.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%283a%29`,
        fs:  `cpe:2.3:a:apache:commons_email:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%283a%29su1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%283a%29su2`,
        fs:  `cpe:2.3:h:y-cam:yck004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0%283a%29su3`,
        fs:  `cpe:2.3:a:synology:download_station:3.8.1-3420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.0_base`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5`,
        fs:  `cpe:2.3:h:3com:3crwe754g72-a:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5%281%29`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5%281%29su1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5%281%29su2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.254:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5%281%29su3`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5%281%29su4`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.13f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5%281%29su5`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5.1`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.5_base`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_lights_out:1.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%281%29`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%281a%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%282%29`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.3:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%282a%29`,
        fs:  `cpe:2.3:a:digium:asterisk:10.11.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%282a%29su1`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%282a%29su2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.532:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%282a%29su3`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpx2213:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%283%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6%284%29`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6.2`,
        fs:  `cpe:2.3:a:netscape:communications_server:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:8.6_base`,
        fs:  `cpe:2.3:a:isc:bind:9.9.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:9.0%281%29`,
        fs:  `cpe:2.3:a:microsoft:ie:8.0.6001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:9.1%281%29`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.3:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:9.1%281a%29`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:9.1%282%29`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:9.1%282.10000.28%29`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:1.0.1.8j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:9.1.1%28a%29`,
        fs:  `cpe:2.3:a:vmware:ace:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:9.9%289%29st1.9`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.0`,
        fs:  `cpe:2.3:h:fortinet:fortigate-100d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.0%281%29`,
        fs:  `cpe:2.3:a:exoticpetnetwork:tortoise_forum:3.5.16:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.0_base`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.2.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.5%280.98000.88%29`,
        fs:  `cpe:2.3:h:cisco:ips_4360_sensor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.5%281.98991.13%29`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.5%282.10000.5%29`,
        fs:  `cpe:2.3:a:samba:samba:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.5%282.12901.1%29`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.5%282.13900.9%29`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5:b3:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.5%283.10000.9%29`,
        fs:  `cpe:2.3:a:winscp:winscp:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:10.5_base`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.0.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:11.0%280.98000.225%29`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing:10.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:11.0%281.10000.10%29`,
        fs:  `cpe:2.3:a:siemens:wincc:5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:11.5%280.98000.480%29`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:11.5%280.98000.486%29`,
        fs:  `cpe:2.3:h:dell:powerconnect_5324:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:11.5%281.12000.1%29`,
        fs:  `cpe:2.3:h:fortinet:fortigate-1000c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:11.5.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.6:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager:12.0%280.99000.9%29`,
        fs:  `cpe:2.3:o:sun:solaris:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager_im_and_presence_service:9.0%281%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager_im_and_presence_service:10.5%281%29`,
        fs:  `cpe:2.3:a:david_king:vino:2.23.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_communications_manager_im_and_presence_service:10.5%282%29`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_computing_system:-`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.0%282k%29`,
        fs:  `cpe:2.3:a:digium:asterisk:13.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.0_base`,
        fs:  `cpe:2.3:a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.1%281m%29`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.1_base`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.2%281a%29`,
        fs:  `cpe:2.3:a:isobuster:isobuster:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.2%281d%29`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.2_base`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281c%29`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.3\(120.135\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281m%29`,
        fs:  `cpe:2.3:a:themelogik:cmslogik:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281n%29`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_inotes_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281o%29`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281p%29`,
        fs:  `cpe:2.3:o:cisco:spa300_series_ip_phone_firmware:7.5.7\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281q%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:f9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281t%29`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.21:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281w%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_common_reporting:2.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3%281y%29`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.1.410.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.3_base`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4`,
        fs:  `cpe:2.3:a:verizon:vzaccess_manager:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%281c%29`,
        fs:  `cpe:2.3:a:horde:gollem:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%281i%29`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:12.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%281j%29`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:b6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%281m%29`,
        fs:  `cpe:2.3:h:cisco:ipvc-3520-gw-4v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%282%29`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283c%291`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283c%292`,
        fs:  `cpe:2.3:a:trick_question_project:trick_question:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283i%29`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283j%29`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283k%29`,
        fs:  `cpe:2.3:a:nokia:6310i:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283l%29`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.230:update23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283m%29`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283p%29`,
        fs:  `cpe:2.3:a:videowhisper:video_posts_webcam_recorder:1.55.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283p%295`,
        fs:  `cpe:2.3:a:j\!extensions_store:jchatsocial:2.2:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283q%29`,
        fs:  `cpe:2.3:a:mnt-tech:wp-facethumb:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283s%29`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283u%29`,
        fs:  `cpe:2.3:o:sun:sunos:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%283y%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%284a%29`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%284a%291`,
        fs:  `cpe:2.3:o:dell:bios:a17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%284f%29`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%284g%29`,
        fs:  `cpe:2.3:a:informant-systems:snmp_informant:2010.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%284i%29`,
        fs:  `cpe:2.3:a:david_king:vino:2.99.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%284j%29`,
        fs:  `cpe:2.3:a:mit:kerberos:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%284k%29`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%285b%291`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%285e%29`,
        fs:  `cpe:2.3:a:adobe:device_central_cs4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%285g%29`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%285g%292`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.5:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%285h%29`,
        fs:  `cpe:2.3:h:tek:phaser_network_printer_930:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%285j%29`,
        fs:  `cpe:2.3:a:iss:realsecure:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%286c%29`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2_1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%286d%29`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1016:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%287b%291`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%287c%291`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4%287h%29`,
        fs:  `cpe:2.3:o:cisco:virtualization_experience_client_6000_series_firmware:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_1i`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_1j`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_1m`,
        fs:  `cpe:2.3:a:lepton-cms:lepton:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_3i`,
        fs:  `cpe:2.3:h:cisco:1812_integrated_service_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_3l`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_3m`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_3q`,
        fs:  `cpe:2.3:a:isc:bind:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_3s`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_3u`,
        fs:  `cpe:2.3:a:suse:suse_linux_imap_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_3y`,
        fs:  `cpe:2.3:a:redhat:freeipa:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_4f`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_4g`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.7.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_4i`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_4j`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_4k`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.40.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_4l`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.4_base`,
        fs:  `cpe:2.3:a:clamav:clamav:0.67-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.5%283%29`,
        fs:  `cpe:2.3:o:d-link:dir-645_firmware:1.03:b08:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.5_base`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.6%280.16%29`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:1.6_base`,
        fs:  `cpe:2.3:a:emberjs:ember.js:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%281m%29`,
        fs:  `cpe:2.3:a:nlnetlabs:unbound:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%281q%29`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.2.6.4786:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%281s%29`,
        fs:  `cpe:2.3:a:crunchify:foursquare-checkins:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%281t%29`,
        fs:  `cpe:2.3:a:python:python:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%281w%29`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120301:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%281x%29`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%282m%29`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%282q%29`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%282r%29`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_agent_framework:3.3.929:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%283a%29`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%283b%29`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%283c%29`,
        fs:  `cpe:2.3:a:samba:samba:4.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%284a%29`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_software_virtualization_solution_for_windows:2.1.1026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%284b%29`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%284d%29`,
        fs:  `cpe:2.3:a:citrix:web_interface:5.4.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%285a%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%285b%29`,
        fs:  `cpe:2.3:a:netscape:communications_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0%285c%29`,
        fs:  `cpe:2.3:a:vips:vips:7.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_1q`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_1s`,
        fs:  `cpe:2.3:o:extremenetworks:extremeware_xos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_1t`,
        fs:  `cpe:2.3:a:janetter:janetter:2.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_1w`,
        fs:  `cpe:2.3:a:chamilo_integration_project:chamilo_integration:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_1x`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_2m`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_2q`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_2r`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_3a`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_3b`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_3c`,
        fs:  `cpe:2.3:a:microsoft:pocket_internet_explorer:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_4a`,
        fs:  `cpe:2.3:a:avaya:vpnremote:4.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_4b`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_4d`,
        fs:  `cpe:2.3:a:baseurl:yum:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_5a`,
        fs:  `cpe:2.3:h:siemens:scalance_w744-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_5b`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_21.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_5c`,
        fs:  `cpe:2.3:a:ibm:filenet_content_engine:4.5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_5d`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_5e`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_5f`,
        fs:  `cpe:2.3:a:ritecms:ritecms:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.0_base`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1%281a%29`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1%281b%29`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:2.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1%281d%29`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.5.807.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1%281e%29`,
        fs:  `cpe:2.3:a:spip:spip:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1%281f%29`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1%282a%29`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1%283f%29`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_1a`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.02:pl5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_1b`,
        fs:  `cpe:2.3:a:ciphertrust:ironmail:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_1d`,
        fs:  `cpe:2.3:a:phorum:phorum:3.1.1:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_1e`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_1f`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_2a`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_2c`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_2d`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_3a`,
        fs:  `cpe:2.3:a:aol:browser:1.7:-:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_3b`,
        fs:  `cpe:2.3:o:oracle:sunos:5.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_3c`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je088a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_3d`,
        fs:  `cpe:2.3:o:cisco:asyncos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_3e`,
        fs:  `cpe:2.3:a:skype:skype:1.0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_3f`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.00.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.1_base`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%281b%29`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp1:compute_cluster:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%281c%29`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%281d%29`,
        fs:  `cpe:2.3:h:huawei:campus_s6300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%281e%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%281f%29`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%281g%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%281h%29`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%282c%29`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%282c%29a`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(5\)sr2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%282d%29`,
        fs:  `cpe:2.3:h:cisco:asr_9912:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%282e%29`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%283a%29`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%283b%29`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%283c%29`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.0:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%283d%29`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.22.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%283e%29`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%283f%29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system:2.2%283f%29a`,
        fs:  `cpe:2.3:h:lg:l-03e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%283g%29`,
        fs:  `cpe:2.3:a:invage:views:7.x-3.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%284b%29`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5105-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%284c%29`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%285a%29`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system:2.2%285b%29a`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%285b%29a`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd239b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2%288b%29`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.2\(3\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2_1b`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2_1c`,
        fs:  `cpe:2.3:a:ibm:db2:11.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2_1d`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2_1e`,
        fs:  `cpe:2.3:a:cisco:jabber:9.2:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2_2c`,
        fs:  `cpe:2.3:a:sqlbuddy:sql_buddy:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2_2d`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle_common:2.5.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2_2e`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:2.2_base`,
        fs:  `cpe:2.3:a:yaml-fuer-drupal:linkchecker:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:3.0%281c%29`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:3.0%281d%29`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.961:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:3.0%281e%29`,
        fs:  `cpe:2.3:a:mozilla:firefox:38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:3.0%282c%29`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp1:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:3.0%282d%29`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system:3.1%282c%29b`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_computing_system_6120xp_fabric_interconnect:-`,
        fs:  `cpe:2.3:a:ibm:dashdb_local:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_computing_system_6140xp_fabric_interconnect:-`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_computing_system_6248up_fabric_interconnect:-`,
        fs:  `cpe:2.3:a:winscp:winscp:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_computing_system_6296up_fabric_interconnect:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.6a.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.0%281a%29`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.0_base`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.1%281a%29`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.1%281b%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.1_base`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.2%281a%29`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.2%281d%29`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.2%281e%29`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.2%281f%29`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.3%280.1%29`,
        fs:  `cpe:2.3:a:splunk:splunk:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.3%280.99%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_central_software:1.4%281a%29`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.0`,
        fs:  `cpe:2.3:a:opentext:exceed_ondemand:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.0%282k%29`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.1`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.1%281m%29`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.2`,
        fs:  `cpe:2.3:h:ibm:system_x3550_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.2%281%29`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:15.0.4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.2%281a%29`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.2%281d%29`,
        fs:  `cpe:2.3:h:extremenetworks:alpine:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281c%29`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281m%29`,
        fs:  `cpe:2.3:a:microsoft:ie:4.0.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281n%29`,
        fs:  `cpe:2.3:a:digium:asterisk:13.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281o%29`,
        fs:  `cpe:2.3:a:dnovus:navy_drug_screening_program:5.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281p%29`,
        fs:  `cpe:2.3:a:eeye:enterprise_update_server:2.2.0.426:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281q%29`,
        fs:  `cpe:2.3:h:tecvoz:cmnc-200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281t%29`,
        fs:  `cpe:2.3:a:conectiva:ecommerce:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281w%29`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3%281y%29`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%281j%29`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%281m%29`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%283i%29`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%283l%29`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%283m%29`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(1\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%283q%29`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v100r006c03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%283s%29`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%283u%29`,
        fs:  `cpe:2.3:a:ultimate_target-armored_sniper_project:ultimate_target-armored_sniper:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%283y%29`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%284f%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%284g%29`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%284i%29`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%284j%29`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:sp1:x32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4%284k%29`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:28.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%281q%29`,
        fs:  `cpe:2.3:a:ibm:db2:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%281s%29`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.5.3.9130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%281t%29`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.15:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%281w%29`,
        fs:  `cpe:2.3:a:wamba:dating_for_everyone_-_mamba\!:3.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%281x%29`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%282m%29`,
        fs:  `cpe:2.3:o:oracle:linux:7:0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%282q%29`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%282r%29`,
        fs:  `cpe:2.3:a:apache:camel:2.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%283a%29`,
        fs:  `cpe:2.3:a:samba:samba:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%283b%29`,
        fs:  `cpe:2.3:a:samba:samba:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%283c%29`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%284a%29`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:582:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%284b%29`,
        fs:  `cpe:2.3:a:pyyaml:libyaml:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%284d%29`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.8.1\(1041\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0%285a%29`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_computing_system_integrated_management_controller:-`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_performance_manager:1.0_base`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_performance_manager:1.1.0`,
        fs:  `cpe:2.3:h:cisco:867_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_performance_manager:1.1.1`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_performance_manager:2.0.0`,
        fs:  `cpe:2.3:a:keepass:keepass:0.99:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_platform_emulator:2.5%282%29ts4`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_platform_emulator:3.0%282c%29a`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_platform_emulator:3.0%282c%29ts9`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_software:1.4`,
        fs:  `cpe:2.3:h:axis:neteye_200\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_computing_system_software:2.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p96:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:4.6%282%29:sr1`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:4.6%282%29:sr2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:4.6%282%29:sr3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:4.6%282%29:sr4`,
        fs:  `cpe:2.3:a:kde:plasma-desktop:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:4.6%282%29:sr5`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:4.6%282%29:sr6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:4.6.2`,
        fs:  `cpe:2.3:a:csc:ddoeserviceclient:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr10`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr11`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr12`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr13`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr2`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr3`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr5`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.3.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr7`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall_1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr8`,
        fs:  `cpe:2.3:a:php:php:5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:5.0%280%29:sr9`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr1`,
        fs:  `cpe:2.3:a:oracle:database_server:11.1.0.7.0:enterprise:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr10`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr11`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr12`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr2`,
        fs:  `cpe:2.3:a:microsoft:picture_it:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr3`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr4`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr5`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:0.079:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr7`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr8`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:6.0%280%29:sr9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.0%280%29:sr1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.0%280%29:sr2`,
        fs:  `cpe:2.3:a:busybox:busybox:0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.0%280%29:sr3`,
        fs:  `cpe:2.3:o:cisco:virtualization_experience_client_6000_series_firmware:11.2\(27.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.0%280%29:sr4`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_mse_series_software:4.1\(1.51\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.1%282%29`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.1%283%29`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.0:beta_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.1%284%29`,
        fs:  `cpe:2.3:a:3com:3c16115-us:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.1%285%29`,
        fs:  `cpe:2.3:a:apache:couchdb:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.1.0`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_microsoft_iis:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.2%281%29`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.2%282%29`,
        fs:  `cpe:2.3:a:microsoft:frontpage:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.2%283%29`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.2%284%29`,
        fs:  `cpe:2.3:a:google:chrome:9.0.591.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.2%285%29`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.2%286%29`,
        fs:  `cpe:2.3:a:nuance:paperport:10.4.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.2%287%29`,
        fs:  `cpe:2.3:a:hp:productcontextnpi:71.0.215.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%282%29`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:6.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%283%29`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%284%29`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%285%29`,
        fs:  `cpe:2.3:a:suse:linux_enterprise_debuginfo:11:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%286%29`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%287%29`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%288%29`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%289%29`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:7.5%2810%29`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:8.0%282%29`,
        fs:  `cpe:2.3:a:ibm:aix_parallel_systems_support_programs:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:8.0%283%29`,
        fs:  `cpe:2.3:a:perl:perl:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:8.5%281%29`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:8.5%282%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:8.5%283%29`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:8.5%284%29`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:9.0%282%29`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:9.0%283%29`,
        fs:  `cpe:2.3:a:gnu:libtool:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:9.0%284%29`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s7503e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:10.0%281%29`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:10.0%282%29`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.22.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:10.5%281%29`,
        fs:  `cpe:2.3:a:debian:apt:0.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_enterprise:10.5%282%29`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:7.20.020.3398:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_contact_center_express:-`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_express:10.0%281%29`,
        fs:  `cpe:2.3:a:safer-networking:spybot_search_and_destroy:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_express:10.5%281%29`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_express:10.6%281%29`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc2300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_express:11.0%281%29`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_express_editor_software:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_hosted:-`,
        fs:  `cpe:2.3:a:microsoft:pocket_ie:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_hosted:5.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_contact_center_hosted:7.1`,
        fs:  `cpe:2.3:a:openstack:compute:2013.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:3.0:sr1`,
        fs:  `cpe:2.3:a:python_bugzilla_project:python-bugzilla:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:3.0:sr2`,
        fs:  `cpe:2.3:a:ati:skins:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:3.6%2810%29:es01`,
        fs:  `cpe:2.3:a:paratrooper-newrelic_project:paratrooper-newrelic:1.0.1:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:4.0`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:4.0%282%29`,
        fs:  `cpe:2.3:h:lexmark:ms811dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:4.0%282%29:sr1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:4.1`,
        fs:  `cpe:2.3:a:citrix:online_plug-in:13.0.0.6684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:7.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:7.0%282%29`,
        fs:  `cpe:2.3:a:corel:paintshop_pro_x5:15.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:8.0%281%29`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:8.5%281%29`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:9.0`,
        fs:  `cpe:2.3:a:tag1consulting:support_timer:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:9.0%281%29`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_customer_voice_portal:10.5%281%29`,
        fs:  `cpe:2.3:h:brocade:silkworm_24000_director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_icm_hosted:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_intelligence_center:10.0%281%29`,
        fs:  `cpe:2.3:a:apple:itunes:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_intelligence_center:10.6%281%29`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.12:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_intelligent_contact_management_enterprise:-`,
        fs:  `cpe:2.3:a:ocaml:ocaml:4.02.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_conference_station_7935:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_supply_chain_management_order_management:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_conference_station_7935:3.2%2815%29`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_conference_station_7936:-`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_conference_station_7936:3.2%2815%29`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_conference_station_7936:3.3%2812%29`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_conference_station_7937g:-`,
        fs:  `cpe:2.3:a:apple:safari:1.0.3:85.8.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_interactive_voice_response:-`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ip_ivr:6.0%281%29`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:-:pre4:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ip_ivr:7.0%281%29`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:r55w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ip_ivr:7.0%282%29`,
        fs:  `cpe:2.3:a:yourtango:your_tango:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ip_ivr:8.0%281%29`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ip_ivr:8.0%282%29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_ip_ivr:8.5%281%29`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_6900_series_firmware:9.3%282%29`,
        fs:  `cpe:2.3:a:hp:unload_support:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_6901:-`,
        fs:  `cpe:2.3:a:google:chrome:9.0.571.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_6911:-`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_6921:-`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_6941:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_6961:-`,
        fs:  `cpe:2.3:a:blackberry:qnx_momentics_tool_suite:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_7900_series_firmware:9.9%289.99001.1%29`,
        fs:  `cpe:2.3:h:cisco:asr_1004_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_7900_series_firmware:9.9_base`,
        fs:  `cpe:2.3:a:gnome:glib:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7902g:-`,
        fs:  `cpe:2.3:a:clamav:clamav:0.91.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7905g:-`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7906g:-`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7906g:8.0%284%29`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.830:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_7906g:8.0%284%29:sr1`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7910g%2bsw:-`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7911g:-`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7911g:8.0%284%29`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_7911g:8.0%284%29:sr1`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.06.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7912g:-`,
        fs:  `cpe:2.3:a:att:communication_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7931g:-`,
        fs:  `cpe:2.3:o:buffalotech:wmr-433_firmware:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7940g:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7941g:-`,
        fs:  `cpe:2.3:a:python_bugzilla_project:python-bugzilla:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7941g:8.0%284%29`,
        fs:  `cpe:2.3:a:tbelmans:mm_forms_community:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_7941g:8.0%284%29:sr1`,
        fs:  `cpe:2.3:a:ibm:security_appscan:6.0.2.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7941g-ge:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7942g:-`,
        fs:  `cpe:2.3:a:ibm:jre:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7945g:-`,
        fs:  `cpe:2.3:a:busybox:busybox:1.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7960g:-`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.13.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7961g:-`,
        fs:  `cpe:2.3:o:yahama:rta54i:4.04.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7961g:8.0%284%29`,
        fs:  `cpe:2.3:a:google:v8:3.22.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_7961g:8.0%284%29:sr1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.343:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7961g-ge:-`,
        fs:  `cpe:2.3:a:hp:openview_deployment:2.10.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7962g:-`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7965g:-`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.43:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7970g:-`,
        fs:  `cpe:2.3:a:acme:thttpd:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7970g:8.0%284%29`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_7970g:8.0%284%29:sr1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7971g:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7971g:8.0%284%29`,
        fs:  `cpe:2.3:a:pfsense:suricata_package:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_7971g:8.0%284%29:sr1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7971g-ge:-`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7975g:-`,
        fs:  `cpe:2.3:a:teradata:bootdiskmon:2.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_7985g:-`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.0%281%29sr1`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:644:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.0%283%29`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.5.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.0%284%29`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.1%281%29sr1`,
        fs:  `cpe:2.3:a:emc:avamar:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.1%282%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.2%281%29`,
        fs:  `cpe:2.3:a:mahara:mahara:17.04:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.2%282%29`,
        fs:  `cpe:2.3:a:codiad:codiad:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.2%282%29sr1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(14\)ea1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.2%283%29`,
        fs:  `cpe:2.3:a:happyworm:jplayer:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.2%284%29`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.3%281%29`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1666.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.3%282%29`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:7.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.3%282%29sr1`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.3%284%29`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.4%281%29`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.21-25.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.4%281%29sr1`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_8900_series_firmware:9.4%282%29`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_8945:-`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_8961:-`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_9951:-`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_9951_firmware:9.4%28.1%29`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:11.0.7170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_9971:-`,
        fs:  `cpe:2.3:a:siemens:automation_license_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_9971_firmware:9.4%28.1%29`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_expansion_module_7914:-`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_expansion_module_7915:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_ip_phone_expansion_module_7916:-`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_firmware:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phone_firmware:9.3:%282%29`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phones_9900_series_firmware:-`,
        fs:  `cpe:2.3:a:umn:mapserver:4.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_ip_phones_9900_series_firmware:9.3%282%29`,
        fs:  `cpe:2.3:a:samba:samba:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:-`,
        fs:  `cpe:2.3:a:ibm:java:5.0.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:5.4`,
        fs:  `cpe:2.3:h:mcdata:intrepid_6140_director_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:6.0`,
        fs:  `cpe:2.3:a:apache:hadoop:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:6.1`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.08.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:7.0`,
        fs:  `cpe:2.3:a:avsmedia:tv_box:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:7.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:7.0.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:7.0.2:mr1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0001_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:7.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gateway_software:2.1\(1.56\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:7.0.3:mr2`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:7.1:mr1`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.0`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_client_apppack:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.0:mr1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.5`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.5.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.5.2`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.5.3`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.5.4`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.750.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.6%281.2%29`,
        fs:  `cpe:2.3:a:gnu:screen:3.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace:8.6%281.9%29`,
        fs:  `cpe:2.3:a:ninjaforms:ninja_forms:2.8.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_express:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:-`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:5.4`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:6.0.417.0`,
        fs:  `cpe:2.3:a:openstack:horizon:juno-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:6.0_base`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:7.0%281%29`,
        fs:  `cpe:2.3:a:roxio:video_capture_usb:1.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:7.0%282%29`,
        fs:  `cpe:2.3:a:perl:perl:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:7.0%282%29_sr1`,
        fs:  `cpe:2.3:a:vmware:vcloud_automation_center:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:7.0%283%29`,
        fs:  `cpe:2.3:a:roxio:central_audio:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:7.1%281%29`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:7.1%282%29`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.326:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.0%281%29`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.0%281%29_sr1`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.0%282%29`,
        fs:  `cpe:2.3:a:emc:networker:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.5%281%29`,
        fs:  `cpe:2.3:h:hp:sn6000_stackable_8gb_24-port_dual_power_fibre_channel_switch:aw576b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.5%282%29`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x4170:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.5%282%29_sr1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.10:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.5%282%29_sr2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.5%283%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_meetingplace_web_conferencing:8.5%284%29`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-50-09:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_operations_manager:-`,
        fs:  `cpe:2.3:a:google:chrome:16.0.882.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_operations_manager:2.0.1`,
        fs:  `cpe:2.3:h:meinberg:lantime_m100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_operations_manager:2.0.2`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_operations_manager:2.0.3`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_personal_communicator:-`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_presence_server:-`,
        fs:  `cpe:2.3:a:canon:imageprograf_firmware_update_tool:3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_presence_server:1.0`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.0.0:rc2:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_presence_server:1.0%281%29`,
        fs:  `cpe:2.3:a:digitiliti:digilibe:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_presence_server:1.0%282%29`,
        fs:  `cpe:2.3:a:redhat:bigmem_kernel:2.4.20-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_presence_server:1.0%283%29`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_presence_server:9.1%281%29`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_provisioning_manager:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_service_monitor:-`,
        fs:  `cpe:2.3:a:ibm:aix_5l:5.3:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_service_monitor:2.0.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_sip_phone_3900_firmware:8.1%281b%29`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_sip_phone_3900_firmware:8.1%282%29`,
        fs:  `cpe:2.3:o:juniper:junos:15.1r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_sip_phone_3900_firmware:8.1%282%29sr1`,
        fs:  `cpe:2.3:a:corel:coreldraw_visual_basic_for_applications:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_sip_phone_3900_firmware:8.1%283%29`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_sip_phone_3900_firmware:8.1%284%29`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:5.0:r1c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_sip_phone_3900_firmware:9.2%281%29`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_sip_phone_3900_firmware:9.2%282%29`,
        fs:  `cpe:2.3:a:schoolmation:schoolmation:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_sip_phone_3911:-`,
        fs:  `cpe:2.3:a:atlassian:jira:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_sip_phone_3951:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_video_advantage:-`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_lldp:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_videoconferencing:-`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.0:*:aix:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_videoconferencing_manager:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_web_and_e-mail_interaction_manager:-`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.09:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_web_and_e-mail_interaction_manager:9.0%282%29`,
        fs:  `cpe:2.3:a:aiadp:guess_the_pixel_character_quiz:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unified_web_and_e-mail_interaction_manager:11.0%281%29`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_wireless_ip_phone_7920:-`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_wireless_ip_phone_7920_firmware:1.0%285%29`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_wireless_ip_phone_7920_firmware:1.0%286%29`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_wireless_ip_phone_7920_firmware:1.0%287%29`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_wireless_ip_phone_7920_firmware:1.0%288%29`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_wireless_ip_phone_7920_firmware:1.0%289%29`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_wireless_ip_phone_7920_firmware:1.0_base`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:unified_wireless_ip_phone_7920_firmware:2.0_base`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.7-p1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_wireless_ip_phone_7921g:-`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention:7.0.601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unified_wireless_ip_phone_7925g:-`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:-`,
        fs:  `cpe:2.3:a:spamtitan:webtitan:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.1%281%29`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.1%281%29_es1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.1%281%29_es12`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:beta:pulse:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.1%281%29_sr1`,
        fs:  `cpe:2.3:a:cisco:finesse:8.5\(3\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.2`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.2%281%29`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.2%281%29_es65`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.2%281%29sr2`,
        fs:  `cpe:2.3:a:aol:browser:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:1.2_base`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.0`,
        fs:  `cpe:2.3:a:ibm:monitoring_agent_for_unix_logs:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.0%281%29`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.0_base`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.11.0:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1`,
        fs:  `cpe:2.3:a:microsoft:malware_protection_engine:1.1.10600.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%281%29`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%282%29`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%283%29`,
        fs:  `cpe:2.3:a:samba:samba:4.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%283b%29su1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%284%29`,
        fs:  `cpe:2.3:a:microsoft:office_compatibility_pack:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%284%29su1`,
        fs:  `cpe:2.3:o:silex:sx-2000wg_firmware:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%284a%29`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-8p-pwr-ei_ls-5100-8p-pwr-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%284a%29su2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%285%29`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%285%29su1`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%285%29su2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1%285%29su3`,
        fs:  `cpe:2.3:h:enterasys:xsr-1850:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:2.1_base`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-28p-pwr-si_ls-3600-28p-pwr-si-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:6.1%283b%29su1`,
        fs:  `cpe:2.3:a:spice_project:spice:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.0`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.0%282%29`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.0%282a%29su2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.0%282a%29su3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.0_base`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%281%29`,
        fs:  `cpe:2.3:a:netgenius:multilink:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%282%29`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%282a%29`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%282a%29su1`,
        fs:  `cpe:2.3:a:vmware:workstation:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%282b%29`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_sprint:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%282b%29su1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%283%29`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%283a%29`,
        fs:  `cpe:2.3:a:tenable:nessus:6.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%283a%29su1`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%283a%29su1a`,
        fs:  `cpe:2.3:a:skype:skype:1.1.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%283b%29`,
        fs:  `cpe:2.3:a:ca:etrust_audit_datatools:1.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%283b%29su1`,
        fs:  `cpe:2.3:a:john_morrissey:mod_ldap_userdir:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%283b%29su2`,
        fs:  `cpe:2.3:a:x:libxt:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285%29`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285%29su1a`,
        fs:  `cpe:2.3:a:atlassian:jira:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285a%29`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285b%29`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285b%29su2`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285b%29su3`,
        fs:  `cpe:2.3:a:cisecurity:security_scoring_tool_windows_nt_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285b%29su4`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285b%29su5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285b%29su6`,
        fs:  `cpe:2.3:a:gnu:a2ps:4.13b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1%285b%29su6a`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1.5es33.32900-33`,
        fs:  `cpe:2.3:a:lianja:lianja_sql_server:1.0:rc5.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:7.1_base`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0`,
        fs:  `cpe:2.3:a:adobe:contribute:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0%282c%29`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0%282c%29su1`,
        fs:  `cpe:2.3:h:dell:powervault_tl2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0%283%29`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2010.0211.1740.31663:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0%283a%29`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd313b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0%283a%29su1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0%283a%29su2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0%283a%29su3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.0_base`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.5`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.5%281%29`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.5.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.5%281%29su1`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.5%281%29su2`,
        fs:  `cpe:2.3:a:buffercode:random_banner:1.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.5%281%29su3`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.5%281%29su6`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.5_base`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6:%281%29`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.5.4.743:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6:%282%29`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6:%282a%29su1`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6:%282a%29su2`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6:%282a%29su3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6%281a%29`,
        fs:  `cpe:2.3:a:cisco:transport_gateway_installation_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6%282a%29`,
        fs:  `cpe:2.3:a:citrix:offline_plug-in:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6.2`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:8.6_base`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:9.0`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:9.1%281.10%29`,
        fs:  `cpe:2.3:a:google:v8:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:9.5`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:10.0.0`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:10.0.5`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:10.5%282%29`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:10.5%282.3009%29`,
        fs:  `cpe:2.3:o:huawei:s9312e_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:10.5_base`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.14.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:11.0%280.98000.225%29`,
        fs:  `cpe:2.3:a:adobe:flash_player:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:11.0%280.98000.332%29`,
        fs:  `cpe:2.3:a:trusteer:rapport:3.5.1108.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:11.0_0`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.12:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:11.5%280.98%29`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:11.5%280.199%29`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection:11.5_base`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection_8.5:base`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection_8.6:base`,
        fs:  `cpe:2.3:a:ruby-i18n:i18n:0.6.7:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_connection_software:11.0.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_express:-`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_express:1.1.1`,
        fs:  `cpe:2.3:o:cisco:staros:19.1.0.61559:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_express:2.1.1`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.6b.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_express:2.2.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:1.1.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:1.1.2`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:2.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(1r\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:2.1`,
        fs:  `cpe:2.3:a:ca:introscope:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:2.1.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1037.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:2.1.2`,
        fs:  `cpe:2.3:o:hp:laserjet_pro_cp1025nw_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:2.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:2.2.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:2.3`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:3.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:3.1`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:3.2`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:7.0`,
        fs:  `cpe:2.3:a:juniper:smartpass:7.7:mr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:7.1`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:7.2`,
        fs:  `cpe:2.3:a:apache:traffic_server:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:7.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.14:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:7.4`,
        fs:  `cpe:2.3:a:kvirc:kvirc:3.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:8.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:8.5`,
        fs:  `cpe:2.3:a:projectforge:projectforge:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:unity_express_software:8.6`,
        fs:  `cpe:2.3:a:cyrus:imap:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:-`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:2.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd349a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:2.1`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:2.2`,
        fs:  `cpe:2.3:a:apple:quicktime:7.69.80.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:2.3`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:2.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:2.46`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:3.0`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:5.x-0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:3.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:3.2`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:3.3`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:10.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:unity_server:4.0`,
        fs:  `cpe:2.3:a:bzip:bzip2:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r2.12_base`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r2.13_base`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r2.14_base`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r2.15_base`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r2.16_base`,
        fs:  `cpe:2.3:a:google:chrome:6.0.478.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r2.17_base`,
        fs:  `cpe:2.3:a:pixman:pixman:0.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r3.2_base`,
        fs:  `cpe:2.3:a:novell:iprint:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r3.3_base`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r3.4_1.1`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2.7:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r3.4_2.1`,
        fs:  `cpe:2.3:a:adobe:robohelp:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r3.4_2.17`,
        fs:  `cpe:2.3:a:microsoft:word_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r3.4_base`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_firmware:r3.5_base`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l3_controller_firmware:21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:universal_small_cell_series_firmware:-`,
        fs:  `cpe:2.3:a:nancy_wichmann:taxonomy_list:6.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:user_registration_tool:-`,
        fs:  `cpe:2.3:a:zarafa:zarafa:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vc240_network_bullet_camera:-`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_2421:-`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_2500:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_2600:-`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.17:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_4000_ip_cameras:-`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_4300e_ip_cameras:-`,
        fs:  `cpe:2.3:a:xnview:xnview:1.82.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_4500e_ip_cameras:-`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2010:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_indoor_fixed_dome_ip_hd_camera:5010`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:6.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_indoor_fixed_dome_ip_hd_camera:5011`,
        fs:  `cpe:2.3:a:php-fusion:expanded_calendar_module:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_ip_gateway_encoder_decoder:-`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_ip_gateway_encoder_decoder:1.8.1`,
        fs:  `cpe:2.3:a:apache:spamassassin:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_operations_manager:-`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5b\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:1.1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:1.2.1`,
        fs:  `cpe:2.3:a:symantec:sms-smtp-xml_mm:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.1`,
        fs:  `cpe:2.3:a:quest:toad_for_data_analysts:2.7:*:*:*:trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.1.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.1.3`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.1.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.1.6`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.1.7`,
        fs:  `cpe:2.3:a:gapless_player:simzip:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.3.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:2.3.1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:4.0.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_software:4.2.0`,
        fs:  `cpe:2.3:a:nih:libzip:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_sp_isp:-`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_sp_isp:1.23.7`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_sp_isp_decoder_software:-`,
        fs:  `cpe:2.3:a:hp:matrix_operating_environment:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:video_surveillance_sp_isp_decoder_software:1.11.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:video_surveillance_vc220_network_dome_camera:-`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_delivery_system_for_internet_streamer:1.0.0`,
        fs:  `cpe:2.3:a:mobile_domain_project:mobile_domain:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_delivery_system_for_internet_streamer:3.2.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:4.2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_delivery_system_for_internet_streamer:3.2.1`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_delivery_system_for_internet_streamer:3.2.1.b9`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_delivery_system_origin_server:1.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:1.0.0`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.0%281%29`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.765.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.0%283%29`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.2%281%29`,
        fs:  `cpe:2.3:a:isc:bind:9.3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.4%281%29`,
        fs:  `cpe:2.3:h:apple:imac:mb952xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.4%283%29`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.4%285%29`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5%281%29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5%283%29`,
        fs:  `cpe:2.3:a:adobe:flash_player:14.0.0.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5%287%29`,
        fs:  `cpe:2.3:a:sendmail:sendmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5%289%29`,
        fs:  `cpe:2.3:a:ibm:global_retention_policy_and_schedule_management:6.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5%2811%29`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6%281%29`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6%283%29`,
        fs:  `cpe:2.3:a:altiris:power_scheme_task:6.0.1015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6%283%29_b26`,
        fs:  `cpe:2.3:a:digium:asterisk:11.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6%283%29_b35`,
        fs:  `cpe:2.3:a:horde:imp:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6%283%29_b39`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6%283%29_b45`,
        fs:  `cpe:2.3:a:solarwinds:server_and_application_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6%283%29_b47`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6%283%29_b50`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.0.0`,
        fs:  `cpe:2.3:a:suse:suse_iptables:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b17`,
        fs:  `cpe:2.3:a:oracle:configurator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b26`,
        fs:  `cpe:2.3:a:perl:perl:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b34`,
        fs:  `cpe:2.3:a:apple:quicktime:7.3.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b54`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b60`,
        fs:  `cpe:2.3:a:invensys:wonderware_inbatch:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.0`,
        fs:  `cpe:2.3:a:gajennings:this:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.0_b26`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.7:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.1`,
        fs:  `cpe:2.3:a:adastra:trace_mode_data_center:6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.1_b9`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.1_b15`,
        fs:  `cpe:2.3:h:ibm:system_x3530_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.1_b20`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.0:r1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.29.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r2`,
        fs:  `cpe:2.3:a:apple:cups:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r4`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r5`,
        fs:  `cpe:2.3:a:tigertext:tigertext:3.1.402:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r6`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:4.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:4.0.0:r1`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp2:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:4.0.0:r2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:4.0.0:r3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_for_internet_streaming:4.1.0`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_optimization_engine:1.0.0`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_optimization_engine:1.0.1`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.4.4:*:*:*:*:*:*:permissive`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_broker:1.0.0`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.1:ur1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_broker:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_broker:1.0_base`,
        fs:  `cpe:2.3:a:macromedia:flash_player:6.0.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_broker:1.1.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_broker:1.1.0-b96`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_broker:1.1_base`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_manager:3.0.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.tc8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_manager:3.1.0`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.10.1004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_manager:3.2.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_manager:3.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yh3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:videoscape_distribution_suite_service_manager:3.4.0`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:virtual_central_office:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10.1s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:virtual_central_office_4000:5.1.3`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:virtualization_experience_client_6000:-`,
        fs:  `cpe:2.3:a:juniper:network_connect:6.5.0.16091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:virtualization_experience_client_6000_series_firmware:-`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:virtualization_experience_client_6000_series_firmware:8.6`,
        fs:  `cpe:2.3:a:businessobjects:data_insight:12.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:virtualization_experience_client_6000_series_firmware:8.7`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:virtualization_experience_client_6000_series_firmware:9.0`,
        fs:  `cpe:2.3:a:bean_project:bean:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:virtualization_experience_client_6000_series_firmware:9.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:virtualization_experience_client_6000_series_firmware:11.2%2827.4%29`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:virtualization_experience_client_6215:-`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voice_gateway:-`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voice_gateway_as5800:-`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:10.04.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:voice_log_translator:2.5.14`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7910:-`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6ecg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:voip_phone_cp-7910:3.0`,
        fs:  `cpe:2.3:a:owncloud:owncloud:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:voip_phone_cp-7910:3.1`,
        fs:  `cpe:2.3:a:dovestones:ad_self_password_reset:3.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:voip_phone_cp-7910:3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7940:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7940:3.0`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.11:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7940:3.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7940:3.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7940:8.6`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7940:8.70`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.1.20125.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7960:-`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:voip_phone_cp-7960:3.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:voip_phone_cp-7960:3.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:voip_phone_cp-7960:3.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:voip_phone_cp-7960:8.70`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3000_concentrator:-`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:2.0`,
        fs:  `cpe:2.3:h:viewsonic:vg2427wm_24\&#34;_lcd_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:2.5.2.a`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:2.5.2.b`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:2.5.2.c`,
        fs:  `cpe:2.3:a:apple:quicktime:7.71.80.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:2.5.2.d`,
        fs:  `cpe:2.3:a:ca:etrust_intrusion_detection:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:2.5.2.f`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.0`,
        fs:  `cpe:2.3:h:3com:3cp4144:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.0%28rel%29`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.0.3.a`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.0.3.b`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.13:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.0.4`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(7\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.1`,
        fs:  `cpe:2.3:h:huawei:quidway_service_process_unit_board_s7700:v200r001c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.1%28rel%29`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.16:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.1.1`,
        fs:  `cpe:2.3:a:kth:snack_sound_toolkit:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.1.2`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:2.0.3:rev28734:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.1.4`,
        fs:  `cpe:2.3:o:hp:tru64:4.0f_pk8_bl22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.5%28rel%29`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.5.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.5.2`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.5.3`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.5.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.5.5`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.6%28rel%29`,
        fs:  `cpe:2.3:a:acme:thttpd:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.6.1`,
        fs:  `cpe:2.3:a:adobe:fonts_all:2.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.6.7`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:3.6.7d`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.0`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.0\(6\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.0.1`,
        fs:  `cpe:2.3:a:commvault:owa_proxy_enabler:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.0.5.b`,
        fs:  `cpe:2.3:a:apc:switched_rack_pdu_firmware:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.1.5.b`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.1.7.a`,
        fs:  `cpe:2.3:a:atlassian:jira:3.11:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.1.7.b`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.7_pre2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.1.7.l`,
        fs:  `cpe:2.3:a:apache:solr:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.7`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.7.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.7.1.f`,
        fs:  `cpe:2.3:o:f5:tmos:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator:4.7.2.f`,
        fs:  `cpe:2.3:a:moip_project:moip:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:2.0`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:2.5.2.a`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:2.5.2.b`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:2.5.2.c`,
        fs:  `cpe:2.3:a:umn:mapserver:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:2.5.2.d`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:2.5.2.f`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sru:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.0`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.0%28rel%29`,
        fs:  `cpe:2.3:a:samba:samba:3.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.0.3.a`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.0.3.b`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.7.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.0.4`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.2.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.1`,
        fs:  `cpe:2.3:a:python:python:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.1%28rel%29`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.1.1`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.1.2`,
        fs:  `cpe:2.3:a:hp:ftp_print_server:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.1.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.5%28rel%29`,
        fs:  `cpe:2.3:a:plone:plone:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.5.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.5.2`,
        fs:  `cpe:2.3:a:redhat:gdk_pixbuf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.5.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.3.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.5.4`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.5.5`,
        fs:  `cpe:2.3:a:kazakhstan_radio_project:kazakhstan_radio:2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6`,
        fs:  `cpe:2.3:a:isc:bind:9.8.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6%28rel%29`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.1`,
        fs:  `cpe:2.3:a:umn:mapserver:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.3`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.5`,
        fs:  `cpe:2.3:a:ca:cleverpath_olap:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.7`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.7.a`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.7.b`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.7.c`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.300:update30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.7.d`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.7.f`,
        fs:  `cpe:2.3:a:emc:avamar:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:3.6.7d`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.0.1`,
        fs:  `cpe:2.3:a:isc:bind:9.3.1:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.0.2`,
        fs:  `cpe:2.3:a:albasit_artes_y_danza_project:albasit_artes_y_danza:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.0.5.b`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.1.5.b`,
        fs:  `cpe:2.3:o:seil:b1_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.1.7.a`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.1.7.b`,
        fs:  `cpe:2.3:a:apport_project:apport:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.1.7.l`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.7`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.7%28rel%29`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.7.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.7.1.f`,
        fs:  `cpe:2.3:a:aspen:aspen:0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.7.2`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.7.2.a`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3000_concentrator_series_software:4.7.2.f`,
        fs:  `cpe:2.3:a:canon:imagerunner_c3200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3001_concentrator:-`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_3002_hardware_client:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.437:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3005_concentrator:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p84:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:3.6.3`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.2:5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:3.6.5`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:3.6.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:3.6.7.a`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:3.6.7.b`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:3.6.7.c`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.337:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:3.6.7.d`,
        fs:  `cpe:2.3:a:perl:perl:5.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:3.6.7.f`,
        fs:  `cpe:2.3:a:oracle:essbase_server:11.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.0`,
        fs:  `cpe:2.3:a:oracle:oracle_berkeley_db:11.2.5.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.0.1`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.1.7.l`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.63:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.7`,
        fs:  `cpe:2.3:a:haxx:curl:7.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.7%28rel%29`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.7.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.383:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.7.1.f`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.7.2`,
        fs:  `cpe:2.3:a:sendmail:advanced_message_server:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.7.2.a`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator:4.7.2.f`,
        fs:  `cpe:2.3:a:samba:jitterbug:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3005_concentrator_software:4.0.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp4:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3015_concentrator:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3015_concentrator:4.1.7.l`,
        fs:  `cpe:2.3:a:radius_extension_project:radius:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3015_concentrator:4.7`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3015_concentrator:4.7%28rel%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3.3s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3015_concentrator:4.7.1`,
        fs:  `cpe:2.3:a:samba:samba:3.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3015_concentrator:4.7.1.f`,
        fs:  `cpe:2.3:o:d-link:dsr-250_firmware:1.08b31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3015_concentrator:4.7.2`,
        fs:  `cpe:2.3:a:samba:samba:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3015_concentrator:4.7.2.a`,
        fs:  `cpe:2.3:a:vips:vips:7.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3015_concentrator:4.7.2.f`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2011:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3020_concentrator:-`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3020_concentrator:4.1.7.l`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3020_concentrator:4.7`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3020_concentrator:4.7%28rel%29`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3020_concentrator:4.7.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3020_concentrator:4.7.1.f`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3020_concentrator:4.7.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.952.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3020_concentrator:4.7.2.a`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3020_concentrator:4.7.2.f`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3030_concentator:-`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.0.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.1.7.l`,
        fs:  `cpe:2.3:a:rayburn_davis:duplicate_commander:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.7`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.7%28rel%29`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.7.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.7.1.f`,
        fs:  `cpe:2.3:a:augeas:augeas:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.7.2`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.7.2.a`,
        fs:  `cpe:2.3:a:mozilla:firefox:45.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3030_concentator:4.7.2.f`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3060_concentrator:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.927.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3060_concentrator:3.5.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3060_concentrator:4.7`,
        fs:  `cpe:2.3:a:cisco:unified_personal_communicator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3060_concentrator:4.7%28rel%29`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3a\)t7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3060_concentrator:4.7.1`,
        fs:  `cpe:2.3:h:oracle:sparc_t4-1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3060_concentrator:4.7.1.f`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:beta.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3060_concentrator:4.7.2`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3060_concentrator:4.7.2.a`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_3080_concentrator:-`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_server:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3080_concentrator:4.1.7.l`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3080_concentrator:4.7`,
        fs:  `cpe:2.3:a:apache:wicket:6.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3080_concentrator:4.7%28rel%29`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3080_concentrator:4.7.1`,
        fs:  `cpe:2.3:h:apple:imac:mb950xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3080_concentrator:4.7.1.f`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3080_concentrator:4.7.2.a`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_3080_concentrator:4.7.2.f`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_500_concentrator:-`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_500_concentrator:5.2.23.0003`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_500_concentrator:6.0.21.0002`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_5000_client:-`,
        fs:  `cpe:2.3:a:gnu:coreutils:5.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:vpn_5000_concentrator:-`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_5000_concentrator_series_software:5.2.23.0003`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_5000_concentrator_series_software:6.0.15`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.2.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_5000_concentrator_series_software:6.0.16`,
        fs:  `cpe:2.3:a:ca:unicenter_serviceplus_service_desk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_5000_concentrator_series_software:6.0.18`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_5000_concentrator_series_software:6.0.19`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_5000_concentrator_series_software:6.0.20`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_5000_concentrator_series_software:6.0.21.0001`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:vpn_5000_concentrator_series_software:6.0.21.0002`,
        fs:  `cpe:2.3:a:webmin:usermin:1.090:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p246:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:2.0`,
        fs:  `cpe:2.3:h:hp:j9575a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.0`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.0.5`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.5.1`,
        fs:  `cpe:2.3:h:avaya:s3400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.5.1c`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.7:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.5.2`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.5.2b`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.14:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.5.4`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.6`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:1.1.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:3.6.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:4.0`,
        fs:  `cpe:2.3:h:hp:a2w77a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:4.0.2a`,
        fs:  `cpe:2.3:a:synology:diskstation_manager:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:4.0.2c`,
        fs:  `cpe:2.3:a:python:pillow:2.9.0:dev2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:4.7.00.0000`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.491:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:4.8.00.0000`,
        fs:  `cpe:2.3:a:memcached:memcached:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:4.8.1`,
        fs:  `cpe:2.3:a:saltstack:salt:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0`,
        fs:  `cpe:2.3:a:omeka:omeka:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.01`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.01.0600`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.3.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.2.0090`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.02.0090`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.03.0530`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.15:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.03.0560`,
        fs:  `cpe:2.3:o:sun:solaris:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.04.0300`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.5`,
        fs:  `cpe:2.3:a:symantec:workspace_virtualization:6.4.1895.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.05.0290`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.6`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.06.0160`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.7`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.07.0290`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.07.0410`,
        fs:  `cpe:2.3:a:nortel:symposium_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vpn_client:5.0.07.0440`,
        fs:  `cpe:2.3:a:dell:openmanage:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vsc3000:-`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vsc3000:9.1`,
        fs:  `cpe:2.3:a:justsystems:hanako:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:vspt:-`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.0:pre10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wan_manager:-`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wap4410n:-`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wap4410n_firmware:2.0.2.1`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wap4410n_firmware:2.0.3.3`,
        fs:  `cpe:2.3:a:x.org:libx11:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wap4410n_firmware:2.0.4.2`,
        fs:  `cpe:2.3:a:digia:qt:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wap4410n_firmware:2.0.6.1`,
        fs:  `cpe:2.3:a:serf_project:serf:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_collaboration_option:-`,
        fs:  `cpe:2.3:a:atutor:acontent:1.2:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:web_security_appliance:-`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:10.1\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:7.1.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:7.1.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:7.1.2`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:7.1.3`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:7.1.4`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:7.5.2-hp2-303`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:7.7.0-608`,
        fs:  `cpe:2.3:a:oracle:customer_relationship_management_technical_foundation:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:7.7.5-835`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:8.0.5_hp1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:8.0.7`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg246a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:8.5.0-000`,
        fs:  `cpe:2.3:o:sun:sunos:5.10:-:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:web_security_appliance:8.5.0-497`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.3:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:8.5.2-027`,
        fs:  `cpe:2.3:a:debian:debmake:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:8.5.3-055`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:8.5_base`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:8.8.0-000`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:web_security_appliance:9.0.0-193`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:9.0.0-193`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:5.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:9.0_base`,
        fs:  `cpe:2.3:a:metaclassy:byword:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:9.1.0-000`,
        fs:  `cpe:2.3:h:hp:jc124b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:9.1_base`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:9.5.0-235`,
        fs:  `cpe:2.3:h:mrv:lx-4000t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:9.5.0-444`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_appliance:9.5_base`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.2:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.1.0`,
        fs:  `cpe:2.3:h:dell:powervault_ml6000:41u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.1.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.1.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.1.3`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.1.4`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.5.1`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.7`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:7.7.5`,
        fs:  `cpe:2.3:a:altova:xmlspy_2009:0.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:8.0.5`,
        fs:  `cpe:2.3:h:f5:firepass_4100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:8.5.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.12.336:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:8.5.1`,
        fs:  `cpe:2.3:a:mercurial:mercurial:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:8.6.0`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:web_security_virtual_appliance:8.7.0`,
        fs:  `cpe:2.3:a:apache:camel:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex:4.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex:11.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_advanced_recording_format_player:27.11.26`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l33er:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_advanced_recording_format_player:27.21.10`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_advanced_recording_format_player:27.25.10`,
        fs:  `cpe:2.3:a:schneider-electric:powerlogic_scada:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_advanced_recording_format_player:27.32.1`,
        fs:  `cpe:2.3:h:tp-link:archer_c7_\(2.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_advanced_recording_format_player:28.0.0`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_advanced_recording_format_player:t27ld`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_advanced_recording_format_player:t28`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_advanced_recording_format_player:t29`,
        fs:  `cpe:2.3:a:vmware:vcenter_chargeback_manager:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meeting_center:-`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meeting_center:base`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meeting_center_for_firefox_or_chrome:8.5.1106`,
        fs:  `cpe:2.3:a:phorum:phorum:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meeting_center_for_firefox_or_chrome:8.23.2504`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meeting_center_for_firefox_or_chrome:8.29.3000`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings:8.0_base::~~~android~~`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.1.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:-`,
        fs:  `cpe:2.3:a:vmware:workstation:12.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:1.0`,
        fs:  `cpe:2.3:a:utorrent:utorrent:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:1.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:1.5`,
        fs:  `cpe:2.3:h:netgear:wg602:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:1.5%28.1.6%29`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:1.5%28.1.131%29`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:2.5`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:2.5%281%29`,
        fs:  `cpe:2.3:a:sqlstress:sqlstress:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:2.5.0.997`,
        fs:  `cpe:2.3:a:python:python:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:2.5.1.5`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetings_server:2.6.0`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.36:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_meetmenow:-`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_node_for_mcs:-`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_productivity_tools:2.20.2200`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_productivity_tools:2.40.5001.10012`,
        fs:  `cpe:2.3:a:huawei:campus_series_switch_software:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recorder_and_player:3.17.2109`,
        fs:  `cpe:2.3:a:ibm:application_support_facility:3.4.0:-:*:*:*:aix:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:27.11.26`,
        fs:  `cpe:2.3:a:antoine_beaupre:hostmaster:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:27.21.10`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:27.25.10`,
        fs:  `cpe:2.3:a:apple:bonjour:2.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:27.32.1`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:27.32.10`,
        fs:  `cpe:2.3:a:mcafee:epo_mcafee_virtual_technician:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:28.0.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:28.4`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:t27ld`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:t28`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_recording_format_player:t29`,
        fs:  `cpe:2.3:a:magiciso:magic_iso_maker:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_sales_center:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_social:-`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_social:3.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_training_center:-`,
        fs:  `cpe:2.3:a:themepunch:showbiz_pro:1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webex_training_manager_for_firefox_or_chrome:5.26.2802`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:-`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:4.0_1.053s`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:5.0_0.038s`,
        fs:  `cpe:2.3:a:apple:java_1.4:0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:5.0_1.012s`,
        fs:  `cpe:2.3:a:qnap:signage_station:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:5.0_2.005s`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:5.1_0.0.10`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.07.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:5.10.0.01`,
        fs:  `cpe:2.3:a:trend_micro:hijackthis:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:5.20.0.01`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.3\(0.722\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:5.20.0.06a`,
        fs:  `cpe:2.3:a:secure_password_hashes_project:secure_passwords_hashes:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:6.10`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:6.10_b4`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_laptops_desktops:11.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.1_0.1.02`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.1_0.2.06`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.2_0.0.03`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.12.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.0`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.0.03`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:1.32.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.0.06a`,
        fs:  `cpe:2.3:a:cisco:cius_software:9.2\(2\)at:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.2.06a`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.3.05`,
        fs:  `cpe:2.3:a:hp:hpztlbxfx:1.2.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.4.05`,
        fs:  `cpe:2.3:a:logitech:high_quality_video:12.0.1280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.4.07s`,
        fs:  `cpe:2.3:a:paperthin:commonspot_content_server:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.5.04`,
        fs:  `cpe:2.3:a:gentoo:app-crypt_pinentry:0.7.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10.05.07s`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10_%2805.07%29s`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20040218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.10_.0.06s`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20.0.3`,
        fs:  `cpe:2.3:a:yokogawa:b\/m9000cs_software:5.05.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20.1.04`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cbd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20.2.206`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20.3.05`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20.03.09s`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20.4.05`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20.5.03`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20_%2803.09%29s`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update6:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.20_%2803.10%29s`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.0.5`,
        fs:  `cpe:2.3:a:sybase:sql_anywhere:10.0.1.3619:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.0.08s`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.1.06`,
        fs:  `cpe:2.3:a:mozilla:firefox:43.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.2.03`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:10.1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.3.03`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.3.05s`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.3.12s`,
        fs:  `cpe:2.3:a:novell:groupwise:8.02:hp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.3.14s`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30.4.02`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30_%2800.08%29s`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.30_%2800.09%29s`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.40.0.04`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.40.1.03`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_5600_software:9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.40.1.05s`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.40.1.13s`,
        fs:  `cpe:2.3:a:hp:openview_configuration_management:4.2i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.40.1.17s`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.40.1.19s`,
        fs:  `cpe:2.3:o:xen:xen:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.40.2.02`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.0.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.40.3.05`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.50.0.04`,
        fs:  `cpe:2.3:o:novell:suse_linux:11:sp1:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.50.0.09s`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.50.0.11s`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.21.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.50.1.03`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:hu:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.50.1.05s`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.50.2.05`,
        fs:  `cpe:2.3:a:condor_project:condor:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:7.50.3.03`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.10.1.06`,
        fs:  `cpe:2.3:a:cisco:security_agent:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.10.2.05`,
        fs:  `cpe:2.3:a:opscode:chef:0.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.10.3.01`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.10.4.01`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.10.5.03`,
        fs:  `cpe:2.3:a:att:communication_manager:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.10.6.02`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.20.0.1`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.20.1.01`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.20.2.01`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.581:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.20.3.03`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:webns:8.20.4.02`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wide_area_application_engine:-`,
        fs:  `cpe:2.3:a:openstack:heat:2013.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wide_area_application_engine_nm-wae-502:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.3`,
        fs:  `cpe:2.3:a:roxio:dvdmax_player:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.7`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.9`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.11`,
        fs:  `cpe:2.3:h:sun:fire_x4600m2_server:sw_2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.13`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.17`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.19`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.21`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.23`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.25`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:4.0.27`,
        fs:  `cpe:2.3:a:novell:zenworks_servers:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1`,
        fs:  `cpe:2.3:a:apache:zookeeper:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1%28.1%29`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:7.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1%28.1a%29`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1%28.1b%29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1%28.1c%29`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.02:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1%28.1d%29`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1%28.1e%29`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1%28.1f%29`,
        fs:  `cpe:2.3:a:acquia:mollom:6.x-2.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1.1`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1.1a`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1.1b`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1.1c`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.8.1392.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.1.1d`,
        fs:  `cpe:2.3:a:ibm:data_server_client:9.5.500.784:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.2`,
        fs:  `cpe:2.3:a:boost:boost:1.43.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.2%28.1%29`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.2.1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.2_base`,
        fs:  `cpe:2.3:a:axiosys:bento4:1.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3`,
        fs:  `cpe:2.3:a:autodesk:dwf_viewer:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3%28.1%29`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3%28.3%29`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.3.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3%28.5%29`,
        fs:  `cpe:2.3:o:juniper:junos:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3%28.5a%29`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.1`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.3`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.5`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.5a`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.5b`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.5c`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.5d`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.5e`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:5.3.5f`,
        fs:  `cpe:2.3:h:ibm:system_x3250_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:6.0%281%29`,
        fs:  `cpe:2.3:a:djangoproject:django:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:6.1.0`,
        fs:  `cpe:2.3:h:lexmark:cs725de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:6.1.1`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:6.2.1`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0581:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services:6.2.1a`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.3.1`,
        fs:  `cpe:2.3:o:huawei:e3236_firmware:webui-13.100.10.00.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.3.4`,
        fs:  `cpe:2.3:a:pinnaclesys:studio:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.4`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.4.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p52:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.5.0`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.5.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.5.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.5.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xu1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.5.4`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wide_area_application_services_mobile:3.5.5`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wip310_wireless-g_ip_phone:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1658.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_control_system:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_control_system:3.2%2840%29`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_control_system:3.2%2851%29`,
        fs:  `cpe:2.3:a:pydio:pydio:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_control_system:4.0`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_control_system:4.0%281%29`,
        fs:  `cpe:2.3:a:redhat:rhel_extras:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_control_system:4.0.95`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.2.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_control_system:4.1.91.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:2.5.2.d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:3.2.78.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.0.155.5`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.372:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.1.83.0`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.1.91.0`,
        fs:  `cpe:2.3:a:vmware:airwatch:7.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.1.171.0`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0586:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.1.191.xm`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.1.192.xm`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.62.0`,
        fs:  `cpe:2.3:a:adobe:graphics_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.62.11`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.81.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.18:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.97.0`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.110.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.128.0`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.130.0`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.173.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:4.2.209.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2010.1125.2142.38865:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.0.56.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.0.56.2`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.0.148.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.339:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.1.64.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:9.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.1.65.4`,
        fs:  `cpe:2.3:a:openstack:compute:2013.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.1.151.0`,
        fs:  `cpe:2.3:a:sddm_project:sddm:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.2.110.0`,
        fs:  `cpe:2.3:a:smarttech:pmt250_risk:2.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.2.125.0`,
        fs:  `cpe:2.3:a:intel:network_connections:14.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.2.130.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.2.148.0`,
        fs:  `cpe:2.3:a:sap:mobile_infrastructure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:5.2.157.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:6.0`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:6.0.132.0`,
        fs:  `cpe:2.3:a:sympa:sympa:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:6.0.170.0`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:6.0.181.0`,
        fs:  `cpe:2.3:a:libav:libav:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:6.0.182.0`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:6.0.188.0`,
        fs:  `cpe:2.3:a:schneider-electric:software_update_utility:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:7.0.164.0`,
        fs:  `cpe:2.3:a:yahoo:yui:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:7.0.164.3`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:7.0.172.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:7.0.220.0`,
        fs:  `cpe:2.3:a:ibm:http_server:8.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_control_system_software:7.0.230.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_lan_controller:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller:3.2`,
        fs:  `cpe:2.3:a:kvirc:kvirc:3.4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller:3.2.116.21`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller:4.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller:4.0.155.0`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller:4.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_6000_ws-x6380-nam:2.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_lan_controller:4.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_lan_controller:4.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_lan_controller:4.2.173.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_lan_controller:5.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wireless_lan_controller:5.2`,
        fs:  `cpe:2.3:a:david_king:vino:2.7.4.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller:7.3%28103.8%29`,
        fs:  `cpe:2.3:a:digium:asterisk:11.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller:7.4%28110.0%29`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:3.0`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:5.2.0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:3.2`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:3.2.116.21`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bbet64g:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.108`,
        fs:  `cpe:2.3:a:emc:navisphere_agent:26.0.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.155.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.155.5`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.15.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.179.8`,
        fs:  `cpe:2.3:a:gunhillwireless:verizon:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.179.11`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:5.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.196`,
        fs:  `cpe:2.3:a:reviewboard:djblets:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.206.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.217.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.0.219.0`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.1`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:ccd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.1.171.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.1.181.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.1.185.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(14\)s8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.1m`,
        fs:  `cpe:2.3:a:intel:graphics_driver:15.40.4404:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.61.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.99.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.12:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.112.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.117.0`,
        fs:  `cpe:2.3:a:hp:universal_cmbd_foundation:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.130.0`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.173.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.174.0`,
        fs:  `cpe:2.3:a:altiris:computer_management_language_pack:6.2.3533:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.176.0`,
        fs:  `cpe:2.3:a:geo_mashup_project:geo_mashup:1.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2.182.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:4.2m`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.0.148.0`,
        fs:  `cpe:2.3:h:hp:h3c_processor_module:msr_50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.0.148.2`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.1.151.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p374:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.1.152.0`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.1.160.0`,
        fs:  `cpe:2.3:o:ibm:aix:430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.2.157.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:5.2.169.0`,
        fs:  `cpe:2.3:a:salome-platform:salome:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:6.0`,
        fs:  `cpe:2.3:h:supermicro:x8dtu-6f\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:6.0.182.0`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_sun_solaris:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:6.0.188.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:6.0.196.0`,
        fs:  `cpe:2.3:a:plone:plone:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:6.0.199.0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:6.0.199.4`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.0`,
        fs:  `cpe:2.3:a:sun:java_studio_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.0%28240.0%29`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.0.98.0`,
        fs:  `cpe:2.3:o:bluecoat:sgos:6.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.0.98.218`,
        fs:  `cpe:2.3:a:nasir_khan:asaancart:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.0.116.0`,
        fs:  `cpe:2.3:a:qemu:qemu:0.15.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.0.220.0`,
        fs:  `cpe:2.3:o:ibm:i:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.0.235.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.16.1.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.0_base`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.1`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.1.91.0`,
        fs:  `cpe:2.3:a:rpm:rpm:4.0.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.2`,
        fs:  `cpe:2.3:a:ca:unicenter_management_websphere_mq:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.2.103.0`,
        fs:  `cpe:2.3:a:symantec:antivirus:10.1.6000.6:*:*:*:*:*:ia64:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.2.110.0`,
        fs:  `cpe:2.3:h:cisco:nexus_3164q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.3.101.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:7.4.1.1`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:7.4.1.19`,
        fs:  `cpe:2.3:a:opscode:chef:0.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.4.1.54`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.4.100`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:7.4.100.60`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.4.110.0`,
        fs:  `cpe:2.3:h:f5:firepass_1000:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.4.121.0`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.4_base`,
        fs:  `cpe:2.3:a:myupb:ultimate_php_board:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.5.102.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.5.102.11`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0.1984:online_windows_server_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:7.6.1.62`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:7.6.100.0`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-06:-:enterprise:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:7.6.110.0`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:7.6.120.0`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:7.6.130.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wireless_lan_controller_software:8.0.72.140`,
        fs:  `cpe:2.3:h:kyocera:ah-k3002v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.0.72.140`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:2.1_\(0.208\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.0.100`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.0.115.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.0.120.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.0_base`,
        fs:  `cpe:2.3:a:cisco:cloudcenter_orchestrator:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.1.0`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.1.104.37`,
        fs:  `cpe:2.3:h:apple:imac:ma590xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.1.111.0`,
        fs:  `cpe:2.3:a:gnome:evolution:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controller_software:8.1.122.0`,
        fs:  `cpe:2.3:a:oracle:sysfw:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_controllers:-`,
        fs:  `cpe:2.3:h:intel:express_520t:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.0`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.1`,
        fs:  `cpe:2.3:a:apache:mod_auth_radius:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.3`,
        fs:  `cpe:2.3:a:dx_library_project:dx_library:3.16b:*:*:*:*:borland_c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.4`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.5`,
        fs:  `cpe:2.3:a:location_module_project:location:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.6`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.7`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_webscan:1.1.0.1047:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.8`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.9`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:06-70-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.10`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:11.50.xc9w2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.11`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.12`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:2.13`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisco:wireless_lan_solution_engine:4.1.91.0`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wrv200_wireless-g_vpn_router_-_rangebooster:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wrv210_wireless-g_vpn_router_-_rangebooster:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:177:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wrvs4400n:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wrvs4400n_firmware:1.1.03`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wrvs4400n_firmware:1.1.13`,
        fs:  `cpe:2.3:a:debian:trousers:0.2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wrvs4400n_firmware:2.0.1.3`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cisco:wrvs4400n_firmware:2.0.2.1`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wrvs4400n_wireless-n_gigabit_security_router_-_vpn_v2.0:-`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ws-c3850:-`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:ws-c3860:-`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:wvc200_wireless-g_ptz_internet_video_camera:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:xr_12404:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:xr_12406:-`,
        fs:  `cpe:2.3:a:gentoo:file:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:xr_12410:-`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cisco:xr_12416:-`,
        fs:  `cpe:2.3:a:netscout:ngenius_trace_analyzer_integrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisecurity:security_scoring_tool_windows_nt_2000:-`,
        fs:  `cpe:2.3:a:jamroom:search_module:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.0::~~~aix~~`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.1`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1207.101.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.1::~~~aix~~`,
        fs:  `cpe:2.3:a:hp:virtual_connect_enterprise_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.2`,
        fs:  `cpe:2.3:a:jenkins:git:0.8.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.2::~~~aix~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.3`,
        fs:  `cpe:2.3:a:bluecoat:proxysg_va-10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.3::~~~aix~~`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.4`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.4::~~~aix~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.5`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cisofy:lynis:1.5.5::~~~aix~~`,
        fs:  `cpe:2.3:a:rsa:securid_web_agent:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:hercules:-`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:hercules:3.5`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:hercules:4.0`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.17-65.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:hercules_remediation_client_for_windows:3.5.1`,
        fs:  `cpe:2.3:a:cisco:prime_network_control_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:hercules_remediation_client_for_windows:4.0.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:hercules_remediation_client_for_windows:4.5.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:smtp:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.18:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:smtp:7.10`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:-`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:7.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:5.90`,
        fs:  `cpe:2.3:a:xnview:xnview:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:5.91`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-11-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:6.07`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:6.08`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_redundant_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:6.14`,
        fs:  `cpe:2.3:a:hitachi:cosminexux_client:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:6.23`,
        fs:  `cpe:2.3:a:kofax:virtualrescan:4.10.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:6.24`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:6.26`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:ux:6.27`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:webcit:-`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citadel:webcit:7.10`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_client_for_metaframe:4.0.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_essentials:-`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_essentials:1.0`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_essentials:1.5`,
        fs:  `cpe:2.3:h:huawei:s6700:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_essentials:2.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway:-`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway:4.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(1\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway:4.2`,
        fs:  `cpe:2.3:a:ntp:ntp:p92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway:4.5`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.5:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway:4.5:hf1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway:4.5:hf1:advanced`,
        fs:  `cpe:2.3:a:ca:erwin_data_model_validator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway:4.5.5`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway_plug-in:9.0::~~enterprise~windows~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway_plug-in:9.1::~~enterprise~windows~~`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_91:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway_plug-in:9.2::~~enterprise~windows~~`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:2.0.0.7971:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway_plug-in:9.3::~~enterprise~windows~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway_plug-in:9.3:57-5:~~enterprise~windows~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway_plug-in:10.0::~~enterprise~windows~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_gateway_plug-in:10.0:69.4:~~enterprise~windows~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console:5.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_diagnostics:4.5.1.0`,
        fs:  `cpe:2.3:a:file_project:file:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_diagnostics:4.6.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_diagnostics:4.8.0.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_diagnostics:5.0.1.0`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_framework:4.5.2.0`,
        fs:  `cpe:2.3:o:siemens:simatic_s7-1500_cpu_firmware:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_framework:4.5.3.0`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_framework:5.0.1.0`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_knowledge_base:4.5.0.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_knowledge_base:4.6.0.0`,
        fs:  `cpe:2.3:a:microsoft:remote_desktop_connection:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_knowledge_base:4.8.0.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_knowledge_base:5.0.1.0`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_legacy_tools:4.5.0.0`,
        fs:  `cpe:2.3:h:juniper:router_m10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_legacy_tools:4.8.0.0`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_legacy_tools:5.0.1.0`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.1.1.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_report_center:4.5.0.0`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:2.3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_report_center:4.6.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_report_center:4.8.0.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p222:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_report_center:5.0.1.0`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:3.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_web_interface:4.5.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_web_interface:4.6.0.0`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_web_interface:5.0.1.0`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.2:*:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:access_management_console_web_interface:5.0.2.0`,
        fs:  `cpe:2.3:a:getgosoft:getgo_download_manager:4.4.5.502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:app_delivery_setup_tools:1.0.1.211`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:application_gateway:6.0`,
        fs:  `cpe:2.3:a:tincan:phplist:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:citrix:application_gateway:6.0`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:7.0.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:citrix:application_gateway_for_avaya:-`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:citrix:application_gateway_for_cisco:-`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:citrix:application_gateway_for_nortel:-`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:13.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:broadcast_server:2.0::avaya`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:broadcast_server:6.0::cisco`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.6:*:pro:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:broadcast_server:6.1::cisco`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(14\)e10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:cloudplatform:3.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:cloudplatform:3.0.3`,
        fs:  `cpe:2.3:a:status:statusnet:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:cloudplatform:3.0.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:cloudplatform:3.0.5`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:cloudplatform:3.0.6`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:cloudportal_services_manager:10.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:cloudportal_services_manager:10.0:cu2`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:command_center:5.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp5:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:command_center:5.1:35.4`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.416:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:command_center:5.2`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:command_center:5.2:43.19`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:common_commands:1.0.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_r5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:common_commands:1.1.2.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:common_commands:1.3.0.0`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_4_firmware:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:delivery_client:11.0.0.5284`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs2:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:delivery_services_console_diagnostics:4.7.0.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:delivery_services_console_framework:5.0.2.0`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:delivery_services_console_knowledge_base:4.7.0.0`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:delivery_services_console_legacy_tools:4.7.0.0`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:delivery_services_console_report_center:4.7.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:desktop_server:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.18:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:desktop_server:1.0`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_endpoints:-`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_endpoints:4.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_endpoints:4.5`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_netscaler:-`,
        fs:  `cpe:2.3:a:ultimus:ultimus_business_process_management_suite:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_netscaler:1.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_netscaler:1.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_presentation_server:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.4:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_presentation_server:4.2`,
        fs:  `cpe:2.3:a:limny:limny:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_presentation_server:4.5`,
        fs:  `cpe:2.3:h:intel:d845bg_motherboard:p03-0021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:edgesight_for_xenapp_agent:5.3.4132.2`,
        fs:  `cpe:2.3:a:hp:oracle_for_openview:9.1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:endpoint_analysis_client:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:enhanced_desktop_experience:1.0.0`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:gotoassist:8.0.0.514`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:gotoassist_corporate:9.1.0.615`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je093a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:gotomeeting:5.0.799.1238:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:group_policy_client-side_extension:1.0.0.416::~~~~x64~`,
        fs:  `cpe:2.3:h:ibm:power_5:9406-570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:group_policy_client-side_extension:1.5.0.0::~~~~x64~`,
        fs:  `cpe:2.3:h:symantec:gateway_security_300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:group_policy_management:1.5.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:hdx_mediastream_for_flash_server:1.0.0.0`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:hdx_mediastream_for_flash_server:1.1.0.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:hdx_mediastream_for_flash_server:2.0.0.0`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.48.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:hdx_wmi_provider:2.0.0.0`,
        fs:  `cpe:2.3:h:linksys:befsr11:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:hmr_test_pack:2.0.0.0`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:ica_client:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.10:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:ica_client:6.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:ica_program_neighborhood_client:-`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:ica_program_neighborhood_client:9.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(4\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:ica_web_client:-`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:ica_web_client:6.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:ica_web_client:9.15`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:license_configuration_tool:1.1.0.0`,
        fs:  `cpe:2.3:a:tiger-fish:fancy_slide:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:license_server_administration:4.5.1.0`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:license_server_administration:4.7.0.0`,
        fs:  `cpe:2.3:a:emc:networker:8.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:license_server_administration:4.8.0.0`,
        fs:  `cpe:2.3:a:phorum:phorum:5.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:license_server_administration:5.0.1.0`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:licensing:6.7.9019`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:licensing:6.8.9020`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:licensing:7.1.10007`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:licensing:7.5.0.11007`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:licensing:7.6.0.11011`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:management_console_for_citrix_presentation_server:4.5.1`,
        fs:  `cpe:2.3:o:qnap:ts-469u_firmware:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:management_console_for_citrix_presentation_server:4.5.2`,
        fs:  `cpe:2.3:h:ibm:s54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:management_console_for_metaframe_presentation_server:4.0.1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe:-`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe:1.0`,
        fs:  `cpe:2.3:a:real:realplayer:11_build_6.0.14.748:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe:1.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)s4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe:1.8:sp3`,
        fs:  `cpe:2.3:o:foscam:ip_camera_firmware:11.37.2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe:3.0`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.1:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe:4.0`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_access_suite_licensing:2.0.0`,
        fs:  `cpe:2.3:h:hp:3com_switch:e4210-24g-poe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_conferencing_manager:-`,
        fs:  `cpe:2.3:a:hp:loadrunner:12.01:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_conferencing_manager:3.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_password_manager:-`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_password_manager:2.0`,
        fs:  `cpe:2.3:h:cisco:4400_wireless_lan_controller:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_password_manager:2.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server:-`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server:3.0`,
        fs:  `cpe:2.3:a:mcafee:internet_security_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server:4.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.575.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server:4.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server:10.100`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server_administration_snap-in:2.0.0`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server_client:9.150.39151`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server_for_windows:4.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_presentation_server_for_windows:4.0.7`,
        fs:  `cpe:2.3:h:hp:jf812a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_secure_access_manager:-`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_secure_access_manager:2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_secure_access_manager:2.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:metaframe_secure_access_manager:2.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:netscaler:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p3_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:netscaler:8.0`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:netscaler:8.0_build_47.8`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:netscaler:10.5`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9.2-5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:citrix:netscaler_access_gateway:-:-:enterprise`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:7.0`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:8.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:8.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:9.0`,
        fs:  `cpe:2.3:a:automon:mikeius:1.4.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:9.1`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:9.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_virtualization_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:9.3`,
        fs:  `cpe:2.3:a:hp:centralized_management_console_software:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:9.3:agee_common_criteria_build`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_command_center:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:9.3.53.6:agee_common_criteria_build`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:9.3.61.5`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:9.3.62.4`,
        fs:  `cpe:2.3:a:ati:communication_opt-in:2.02.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:10.0`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_plant_applications:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:10.0.74.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:10.1`,
        fs:  `cpe:2.3:a:sun:openoffice.org:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_access_gateway_firmware:10.1.123.9`,
        fs:  `cpe:2.3:a:harris:stat_scanner:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:citrix:netscaler_application_delivery_controller:-`,
        fs:  `cpe:2.3:a:hp:laserjet_professional_m1210_mfp_series_toolbox:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:9.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:9.3`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.6:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:9.3%281%29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:9.3.e`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.0`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.0.e`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.120.1316.e`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.121`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller_enterprise_module:1.0.\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.122`,
        fs:  `cpe:2.3:a:hp:veritas_recordnow:3.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.123`,
        fs:  `cpe:2.3:h:sun:fire_x2100_m2:3.19:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.124`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.125`,
        fs:  `cpe:2.3:h:xerox:document_centre_255:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.126`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.127`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.128`,
        fs:  `cpe:2.3:a:emc:networker:8.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.1.129`,
        fs:  `cpe:2.3:a:oracle:mysql_workbench_ce:5.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.5`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.5.50.10`,
        fs:  `cpe:2.3:o:cisco:vpn_5000_concentrator_series_software:5.2.23.0003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_application_delivery_controller_firmware:10.5.51.10`,
        fs:  `cpe:2.3:a:oracle:service_bus:12.2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.120.1316.e`,
        fs:  `cpe:2.3:h:hp:cf069a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.121`,
        fs:  `cpe:2.3:a:combodo:itop:1.1.181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.122`,
        fs:  `cpe:2.3:a:percona:percona_server:5.7.12-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.123`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.1125.2141.38865:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.124`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.125`,
        fs:  `cpe:2.3:a:piwik:piwik:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.126`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.127`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.128`,
        fs:  `cpe:2.3:o:cisco:ios_xe:16.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.1.129`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.5`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.5.50.10`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.5.51.10`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.5.1681:online_windows_2000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:citrix:netscaler_gateway_firmware:10.5e`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:nfuse:-`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:nfuse:1.5`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:nfuse:1.6`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:nfuse:1.51`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:offline_plug-in:5.2.0.1227`,
        fs:  `cpe:2.3:o:microsoft:windows:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:offline_plug-in:6.0.0.1304`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:offline_plug-in:6.0.2.9`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:offline_plug-in:6.5`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:5.6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:offline_plug-in:6.5.0.6684`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_pulse:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:online_plug-in:11.2.0.31560`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:online_plug-in:12.0.0.6410`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:online_plug-in:12.0.3.6`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.65:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:online_plug-in:12.1.0.30`,
        fs:  `cpe:2.3:a:hp:version_control_agent:6.3.0.870:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:online_plug-in:12.1.44.1`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:online_plug-in:13.0.0.6684`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:online_plug-in:13.0.0.6685`,
        fs:  `cpe:2.3:a:synology:cloud_station:3.0-3109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:password_manager_console:4.6.91.0`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.893:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:password_manager_plugin:4.6.264.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:password_manager_plugin:4.6.269.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.20.2:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:password_manager_plugin:4.6.270.0`,
        fs:  `cpe:2.3:a:emerson:deltav:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:password_manager_plugin:4.6.271.0`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server:-`,
        fs:  `cpe:2.3:h:belden:hirschmann_l2b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server:4.0`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_administration_snap-in:4.5.0.0`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_administration_snap-in:4.6.0.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_administration_snap-in:4.6.2.0`,
        fs:  `cpe:2.3:a:bastian_kleineidam:linkchecker:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_administration_snap-in:4.6.5.0`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_client:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_client:9.200`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_client:10.0`,
        fs:  `cpe:2.3:h:axis:m1011-w_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_client:10.00.52110`,
        fs:  `cpe:2.3:a:drupal:drupal:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_client:10.100.55836`,
        fs:  `cpe:2.3:h:cisco:aironet_bridge_350:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_client:10.150.58643`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_client:10.200.2650`,
        fs:  `cpe:2.3:a:hp:deskjet_single_function_software:90.0.200.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_document_center:4.0.0`,
        fs:  `cpe:2.3:a:brocade:network_advisor:11.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_document_center:4.5.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_document_center:4.5.1`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_for_windows:4.5.2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_for_windows:4.5.6`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_for_windows:4.5.7`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_for_windows:4.5.8`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_presentation_server_reports:4.5.0.0`,
        fs:  `cpe:2.3:o:cisco:aironet_access_point_software:8.1\(112.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:presentation_server_presentation_server_reports:4.6.0.0`,
        fs:  `cpe:2.3:o:huawei:s7703_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:program_neighborhood_client:-`,
        fs:  `cpe:2.3:o:adb:p.dga4001n_firmware:pdg_tef_sp_4.06l.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:program_neighborhood_client:9.1`,
        fs:  `cpe:2.3:a:x:libdmx:1.0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:provisioning_services:5.0`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:provisioning_services:5.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:provisioning_services:5.6`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:provisioning_services:5.6:sp1`,
        fs:  `cpe:2.3:h:cisco:telepresence_mcu_mse_8510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:provisioning_services:5.6:sp2`,
        fs:  `cpe:2.3:h:juniper:srx1400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:provisioning_services:5.6:sp3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:provisioning_services:6.0`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:provisioning_services:6.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver:13.0.0.6684`,
        fs:  `cpe:2.3:o:toshiba:4690_operating_system:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver:13.0.0.6685`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.05.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_aero:13.0.0.6684`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_aero:13.0.0.6685`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:8.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_dv:13.0.0.6684`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_dv:13.0.0.6685`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_enterprise:13.0.0.6685`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_hdx_flash_redirection:13.0.0.6684`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_hdx_flash_redirection:13.0.0.6685`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_inside:3.0.0.56418`,
        fs:  `cpe:2.3:a:zed_shaw:mongrel:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_pna:13.0.0.6685`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_sson:13.0.0.6685`,
        fs:  `cpe:2.3:a:sun:java_db:10.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_usb:13.0.0.6684`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ea1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:receiver_usb:13.0.0.6685`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway:-`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway:3.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway:3.1.2`,
        fs:  `cpe:2.3:h:cisco:wrv210_wireless-g_vpn_router_-_rangebooster:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway:3.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway:3.1.5`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway:3.2.0`,
        fs:  `cpe:2.3:a:tibco:spotfire_deployment_kit:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway:3.2.1`,
        fs:  `cpe:2.3:h:logitec:lan-w300n\/ru2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway:3.3.0`,
        fs:  `cpe:2.3:a:flexymind:president_clicker:1.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:secure_gateway_for_metaframe_secure_ticket_authority:2.0.0`,
        fs:  `cpe:2.3:a:nero:advertising_center:0.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:sharefile_mobile:2.4::~~~android~~`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:sharefile_mobile:2.4.4::~~~android~~`,
        fs:  `cpe:2.3:a:liftweb:lift:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:sharefile_mobile_for_tablets:2.4::~~~android~~`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:sharefile_mobile_for_tablets:2.4.4::~~~android~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:single_sign-on_console:4.8.6410.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:single_sign-on_console:5.0.0.6684`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.2:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.3.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:223:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.3.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.3.2`,
        fs:  `cpe:2.3:a:sun:jsse:1.0.3_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.3.3`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.3.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.3.5`,
        fs:  `cpe:2.3:o:huawei:s12712_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.3.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.4.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.0\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.4.2`,
        fs:  `cpe:2.3:a:digium:asterisk:13.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:vdi-in-a-box:5.4.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6.5\)ec3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:-`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:2.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:3.0`,
        fs:  `cpe:2.3:a:oracle:database_server:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:4.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:4.2`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:4.5.1`,
        fs:  `cpe:2.3:a:inclind:custom_pub:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:4.6.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.21.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:5.3.0.34`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface:5.4.0.59`,
        fs:  `cpe:2.3:o:huawei:mate_7_firmware:mt7-ul00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:web_interface_for_metaframe_presentation_server:4.0.45083%2328412`,
        fs:  `cpe:2.3:a:citrix:endpoint_analysis_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:winframe:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp:5.0.0.0`,
        fs:  `cpe:2.3:a:php:php:7.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp:5.0.2`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp:6.0.0.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp:6.5.0.0`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.30.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_administration:4.7.0.0`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.3.4:community:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_administration:4.7.2.0`,
        fs:  `cpe:2.3:a:spip:spip:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_administration:4.8.0.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_administration:5.0.1.0`,
        fs:  `cpe:2.3:h:att:status:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_advanced_configuration:4.5.6`,
        fs:  `cpe:2.3:a:goforandroid:go_fbwidget:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_advanced_configuration:4.5.7`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jnc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_advanced_configuration:4.5.8`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_advanced_configuration:5.0.0`,
        fs:  `cpe:2.3:a:phorum:phorum:3.3.2:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_commands:6.0.0.0`,
        fs:  `cpe:2.3:a:citrix:web_interface:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_commands:6.1.2.0`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_commands:6.5.0.0`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.7.609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_commands_ctp3:5.0.1.1`,
        fs:  `cpe:2.3:a:bluecatnetworks:adonis_management_console:5.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_document_library:5.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_feature_pack_enabler:4.5.6.0`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_group_policy_management_experience:1.0.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_group_policy_management_experience:1.0.2.0::~~~~x64~`,
        fs:  `cpe:2.3:h:oracle:netra_sparc_t3-1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_management:6.0.0.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_management:6.5.0.0`,
        fs:  `cpe:2.3:h:supermicro:x9dax-7f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_migration:6.5.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_plugin_for_hosted_apps:11.0.0.5357`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.4.7:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_plugin_for_hosted_apps:11.0.150.5357`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_plugin_for_streamed_apps:1.2.5357`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_plugin_for_streamed_apps:5.0.0.5357`,
        fs:  `cpe:2.3:a:ibm:rational_appscan_source:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_power_and_capacity_management_agent:2.0.0.22`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_reports:4.7.0.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_reports:4.8.0.0`,
        fs:  `cpe:2.3:a:canon:imagerunner_5000i:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_reports:5.0.1.0`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:15.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_server_configuration_tool:1.0.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ew2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_server_configuration_tool:1.1.1.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_server_configuration_tool:1.1.3.0`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-s39:3.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_server_configuration_tool:1.2.0.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_server_role_manager:1.0.0.0`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_server_role_manager:1.1.0.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_server_sdk:6.1.2.0`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.5.32:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenapp_web_plugin:11.0.0.5357`,
        fs:  `cpe:2.3:a:sympa:sympa:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenappprep:3.0.0.0`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenclient_xt:2.1.2`,
        fs:  `cpe:2.3:a:tenable:nessus:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenclient_xt:3.0.0`,
        fs:  `cpe:2.3:a:adobe:photoshop:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenclient_xt:3.1.3`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.23:pre9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:4.0:fp1`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.089:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:4.0:fp2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:5.0`,
        fs:  `cpe:2.3:o:novell:opensuse:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:5.0:sp1`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:5.6`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:5.6:fp1`,
        fs:  `cpe:2.3:a:david_king:vino:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:5.6.300`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r12.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:7.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:7.1`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xendesktop:7.5`,
        fs:  `cpe:2.3:a:clamav:clamav:0.98.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenmobile_device_manager:8.5`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenmobile_device_manager:8.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.23:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenmobile_device_manager_mdm:8.0.1`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:10.0.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:5.0`,
        fs:  `cpe:2.3:a:openstack:compute:2014.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:5.5`,
        fs:  `cpe:2.3:a:microsoft:java_virtual_machine:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:5.6`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:5.6:fp1`,
        fs:  `cpe:2.3:a:apache:solr:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:5.6:sp2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:beta.9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:6.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:6.0.2`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:6.2.0:sp1`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.0.1232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:6.5:sp1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citrix:xenserver:7.0`,
        fs:  `cpe:2.3:a:bir.gov.ph:alphalist_data_entry_and_validation:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:citystar:city_star_me:1::~~~android~~`,
        fs:  `cpe:2.3:a:aisquared:zoomtext:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:3.1.0`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.0.5`,
        fs:  `cpe:2.3:a:percipientstudios:imagen:2.5.3:-:*:*:*:umbraco_cms:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.1.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.1.1`,
        fs:  `cpe:2.3:a:isc:inn:1.4sec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.1.2`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.08.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.1.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(2\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.1.4`,
        fs:  `cpe:2.3:h:siemens:synco_ozw_web_server:ozw772.250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.1.5`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.1.6`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.0`,
        fs:  `cpe:2.3:h:nvidia:quadro_p6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.1`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:fp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.2`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.4`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.5`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.1.0.485:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.6`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.7`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.8`,
        fs:  `cpe:2.3:a:ecava:integraxor:3.5.3900.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.9`,
        fs:  `cpe:2.3:a:divx:divx_web_player:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.10`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.18f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.12`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.13`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.2.14`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_4_firmware:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.0`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.2`,
        fs:  `cpe:2.3:a:skype:skype:3.1.0.147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.3`,
        fs:  `cpe:2.3:a:john_albin:zen:6.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.4`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.5`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.6`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.6:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.7`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.3.8`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4:alpha1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4:alpha2`,
        fs:  `cpe:2.3:a:macromedia:flash_player:7.0.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4:alpha3`,
        fs:  `cpe:2.3:h:hp:laserjet_m3035_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4:beta1`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4:beta2`,
        fs:  `cpe:2.3:a:oracle:database_server:11.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4:beta3`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4:beta4`,
        fs:  `cpe:2.3:o:juniper:junos:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4.1`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm:4.4.2`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:6.00.2900.5512:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm_private_report:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm_private_report:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm_private_report:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm_private_report:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civicrm:civicrm_private_report:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:sap:hybris:5.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civitasmedia:logan_banner:1.0010.b0010::~~~android~~`,
        fs:  `cpe:2.3:a:spip:spip:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civitasmedia:mt._airy_news:1.0069.b0069::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.9.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:civitasmedia:press-leader:1.0011.b0011::~~~android~~`,
        fs:  `cpe:2.3:a:apache:hadoop:0.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.1`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.3`,
        fs:  `cpe:2.3:a:trivantis:coursemill_learning_management_system:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.4`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.5`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.7`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.8`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.366:*:*:*:esr:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:vips:vips:7.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.0`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_client:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:wpslideshow:image_news_slider:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.3`,
        fs:  `cpe:2.3:a:krisonav:krisonav:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.4`,
        fs:  `cpe:2.3:a:x:libxi:1.5.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.5`,
        fs:  `cpe:2.3:h:dell:precision_m6400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.7`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.8`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.9`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:ckeditor:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:2.6.10`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:2.6.11`,
        fs:  `cpe:2.3:a:apache:poi:3.8:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.1`,
        fs:  `cpe:2.3:a:broadvision:command_center:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.1:beta`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.4:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.1:beta2`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.2`,
        fs:  `cpe:2.3:a:buffalotech:whr-ampg_firmware:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.2-1`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3`,
        fs:  `cpe:2.3:a:sap:netweaver:7.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3:beta`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3:beta2`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3:rc1`,
        fs:  `cpe:2.3:a:foliovision:foliopress_wysiwyg:2.6.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3:rc2`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3:rc3`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3:rc5`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3:rc6`,
        fs:  `cpe:2.3:a:ibm:websphere_extended_deployment_compute_grid:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.3:rc7`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.4`,
        fs:  `cpe:2.3:h:compaq:proliant_bl_e-class_integrated_administrator_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.4:rc1`,
        fs:  `cpe:2.3:a:synology:video_station:1.5-0763:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.4:rc2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:nih:libzip:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:gwt_mobile_phonegap_showcase_project:gwt_mobile_phonegap_showcase:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:alpha3`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:alpha4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:alpha5`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:beta1`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:beta3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.3:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:beta4`,
        fs:  `cpe:2.3:a:autodesk:civil_design:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:rc1`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.0:rc2`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.1`,
        fs:  `cpe:2.3:a:bradesco_gateway_plugin_project:bradesco_gateway:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.1:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(46\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.2`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.2:rc1`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.4.734:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.3`,
        fs:  `cpe:2.3:o:netbsd:netbsd:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ckeditor:fckeditor:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:-`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.01`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.02`,
        fs:  `cpe:2.3:a:boeing:drs_wiring_illuminator_web:1.14.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.03`,
        fs:  `cpe:2.3:h:upc:ireland_cisco_epc2425:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.3`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.05`,
        fs:  `cpe:2.3:a:atanasoft:atanasuite_2010:8.1.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.8:rc3`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.9:rc1`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.10`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.12`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.13`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.14`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.14:pre`,
        fs:  `cpe:2.3:a:cisco:jabber:9.2\(.1\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.15`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.20`,
        fs:  `cpe:2.3:a:drupal:drupal:7.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.21`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.22`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.23`,
        fs:  `cpe:2.3:a:apple:apple_tv:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.24`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.5.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.51`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.52`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.8sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.53`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.22-71.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.54`,
        fs:  `cpe:2.3:a:macromedia:breeze:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.60`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:6.0.182.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.60p`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.65`,
        fs:  `cpe:2.3:a:debian:debian-goodies:0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.66`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.3:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.67`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.67-1`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.68`,
        fs:  `cpe:2.3:h:nvidia:quadro_m4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.68.1`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.70`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r4:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.70:rc`,
        fs:  `cpe:2.3:a:quagga:quagga:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.71`,
        fs:  `cpe:2.3:a:nero:vcredistsetup:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.72`,
        fs:  `cpe:2.3:a:ingumadev:bokken:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.73`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.74`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.75`,
        fs:  `cpe:2.3:a:labanquepostale:labanquepostale:3.2:-:-:-:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.75.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.80`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.80:rc`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.80:rc1`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.80:rc2`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.38:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.80:rc3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.3\(44\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.80:rc4`,
        fs:  `cpe:2.3:a:intel:mdriver:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.80_rc`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.81`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.81:rc1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.82`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.83`,
        fs:  `cpe:2.3:a:foecms:foecms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.84`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.00.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.84:rc1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.84:rc2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.85`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.85.1`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(5\)sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.86`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:11:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.86:rc1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.86.1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.86.2`,
        fs:  `cpe:2.3:a:serve:american_express_serve:\@7f0901e4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.87`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.87.1`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88`,
        fs:  `cpe:2.3:a:symantec:norton_security_scan:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.1`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.2`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.3`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.5`,
        fs:  `cpe:2.3:a:novell:groupwise:8.00:hp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.7`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.7_p0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.88.7_p1`,
        fs:  `cpe:2.3:o:oracle:sun_products_suite_sysfw:8.2.0.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-3500c_firmware:t380sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90:rc1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90:rc1.1`,
        fs:  `cpe:2.3:a:emc:networker:7.5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90:rc2`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90:rc3`,
        fs:  `cpe:2.3:o:cisco:catos:2.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90.1_p0`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62y:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90.2`,
        fs:  `cpe:2.3:a:vips:vips:7.11.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90.2_p0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90.3`,
        fs:  `cpe:2.3:a:seamons:net-server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90.3_p0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.90.3_p1`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.91`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner:15.0.0.8631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.91:rc1`,
        fs:  `cpe:2.3:a:nero:startsmart_help:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.91:rc2`,
        fs:  `cpe:2.3:a:openstack:compute:2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.91.1`,
        fs:  `cpe:2.3:a:systemtools:hyena:8.50.2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.91.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.91.2_p0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.92`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20140813:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.92.1`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.08b77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.92_p0`,
        fs:  `cpe:2.3:o:vmware:esxi:4.0:3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.93`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.1.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.93.1`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.93.2`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.93.3`,
        fs:  `cpe:2.3:a:blackberry:good_control_server:2.2.511.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.94`,
        fs:  `cpe:2.3:h:cooperindustries:smp_4_gateway_\(data_concentrator\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.94.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.85.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.94.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.95`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.95:rc1`,
        fs:  `cpe:2.3:h:huawei:nip200:v100r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.95:rc2`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.95:src1`,
        fs:  `cpe:2.3:a:nortel:cs1000s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.95:src2`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.95.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s_3.4.6s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.95.2`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.95.3`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.96`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.0.1176.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.96:rc1`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.2:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.96:rc2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.226:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.96.1`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.96.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.96.3`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.96.4`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.96.5`,
        fs:  `cpe:2.3:a:skype:skype:4.2.0.166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)t12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97:rc`,
        fs:  `cpe:2.3:a:color:icclib:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97.2`,
        fs:  `cpe:2.3:a:cisco:webns:7.20.4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97.3`,
        fs:  `cpe:2.3:o:freebsd:freebsd:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97.4`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97.5`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97.6`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.97.7`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.98.4`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.98.5`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clamav:clamav:0.99.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.12b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claris:claris_emailer:2.0v2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tcu4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.9`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.10`,
        fs:  `cpe:2.3:a:adgjm:angel_browser:1.47b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11`,
        fs:  `cpe:2.3:a:htc:evo_3d_software:2.08.651.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11.2`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11.3`,
        fs:  `cpe:2.3:a:trillian:trillian:0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11.4`,
        fs:  `cpe:2.3:a:sun:storedge_enterprise_backup_software:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11.5`,
        fs:  `cpe:2.3:a:isc:bind:9.10.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11.6`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11.7`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:10.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11.8`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claroline:claroline:1.11.9`,
        fs:  `cpe:2.3:a:freshdirect:freshdirect:2.7.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:clausmuus:spitfire:1.0436`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.6`,
        fs:  `cpe:2.3:a:rpm:rpm:4.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.9`,
        fs:  `cpe:2.3:a:lxml:lxml:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.11`,
        fs:  `cpe:2.3:a:avast:business_security:11.1.2253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.12`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.13`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.14`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb990xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.15`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:5.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.99`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:1.9.100`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.0.0`,
        fs:  `cpe:2.3:a:pressit:expressit:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.1.0`,
        fs:  `cpe:2.3:a:dadabik:dadabik:2.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.1.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.2.0`,
        fs:  `cpe:2.3:a:schneider-electric:twidosuite:2.31.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.2.1`,
        fs:  `cpe:2.3:a:nuance:paperport_image_printer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.2.2`,
        fs:  `cpe:2.3:a:astaro:security_gateway_software:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.2.3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.3.0`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.3.1`,
        fs:  `cpe:2.3:a:microsoft:outlook:2010:sp2:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.4.0`,
        fs:  `cpe:2.3:a:pluck-cms:pluck:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.5.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.5.1`,
        fs:  `cpe:2.3:h:supermicro:x9sca-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.5.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.5.3`,
        fs:  `cpe:2.3:a:rbfcu:rbfcu_mobile:3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.5.4`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.5.5`,
        fs:  `cpe:2.3:a:x:x.org-xserver:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.5.6`,
        fs:  `cpe:2.3:a:zend:zendto:4.10-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.6.0`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.6.1`,
        fs:  `cpe:2.3:a:apple:cups:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.7.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.7.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30280:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.7.2`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.24.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.8.0`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.8.1`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.9.0`,
        fs:  `cpe:2.3:a:codiad:codiad:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.9.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.9.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:2.10.0`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.3.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.3.1`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.4.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.469.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.5.0`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.6.0`,
        fs:  `cpe:2.3:o:siemens:reliant_unix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.6.1`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.8:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yf2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.3`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.9.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.5`,
        fs:  `cpe:2.3:a:projectsend:projectsend:100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.7`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.8`,
        fs:  `cpe:2.3:a:visionsolutions:double-take:4.3.4.0.1271.s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.9`,
        fs:  `cpe:2.3:a:tqdm_project:tqdm:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.7.10`,
        fs:  `cpe:2.3:a:twitter_liveblog_project:twitter_liveblog:1.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.8.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.8.1`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:claws-mail:claws-mail:3.9.3`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cleaninternet:clean_internet_browser:1.36::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clearfishing:pesca_de_carpa_lite:1.0::~~~android~~`,
        fs:  `cpe:2.3:o:ibm:aix:5.3_l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clearfishing:pescuit_crap_lite:1::~~~android~~`,
        fs:  `cpe:2.3:a:mcafee:application_control:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clearone:converge_console:5.2`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clearone:converge_console:5.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:click_project:click:-`,
        fs:  `cpe:2.3:a:google:chrome:14.0.818.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:click2sell:click2sell_suite_module:6.x-1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.8:gamma:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clickdesk:clickdesk_live_support-live_chat_plugin:2.0`,
        fs:  `cpe:2.3:a:reviewboard:djblets:0.7.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clientresponse_project:clientresponse:4.1`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clip-bucket:clipbucket:-`,
        fs:  `cpe:2.3:a:php:php:5.6.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clip-bucket:clipbucket:2.6`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.3:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clip-bucket:clipbucket:2.7:rc3`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clip-bucket:clipbucket:2.8.1`,
        fs:  `cpe:2.3:a:symantec:norton_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clipbucket_project:clipbucket:2.8.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clonemonster:social_book_facebook_clone_monster:2010`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:closeprotectionworld:cpworld_close_protection_world:3.4.4::~~~android~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.8.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudacl:safe_browser_-_the_web_filter:1.2.5::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.301`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.302`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.303`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.304`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.305`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.306`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.307`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.308`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.309`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.310`,
        fs:  `cpe:2.3:a:storagetek:santricity:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.311`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.312`,
        fs:  `cpe:2.3:a:suse:kiwi:4.98.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.313`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.314`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.1.3.31:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.315`,
        fs:  `cpe:2.3:a:siemens:ugslicensing:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.316`,
        fs:  `cpe:2.3:a:pdfforge:pdfcreator:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.317`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.318`,
        fs:  `cpe:2.3:a:oracle:mysql_connector_c:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.319`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.320`,
        fs:  `cpe:2.3:a:teamviewer:teamviewer:5.0.8703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.321`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.322`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.323`,
        fs:  `cpe:2.3:a:doodlegod:doodle_devil_free:2.1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.324`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.325`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.326`,
        fs:  `cpe:2.3:a:samsung:net-i_viewer:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.327`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.328`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.329`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.03:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.330`,
        fs:  `cpe:2.3:a:apple:safari:2.0.3:417.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.331`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.362:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.332`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.333`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.334`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.335`,
        fs:  `cpe:2.3:o:novell:netware:6.5:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.336`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.337`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:5.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.338`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1041.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.339`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.9:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.340`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.341`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.342`,
        fs:  `cpe:2.3:a:gnu:emacs:21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.343`,
        fs:  `cpe:2.3:a:cairographics:cairo:1.12.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.344`,
        fs:  `cpe:2.3:a:google:v8:3.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.345`,
        fs:  `cpe:2.3:o:ibm:aix:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.346`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.347`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.348`,
        fs:  `cpe:2.3:a:clamav:clamav:0.86.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.349`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.5130:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.350`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.351`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.352`,
        fs:  `cpe:2.3:a:tridium:niagra_ax_framework:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.353`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.354`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.355`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.48:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.356`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.357`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.23.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.358`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.359`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.360`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.361`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.362`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.363`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.364`,
        fs:  `cpe:2.3:a:supmua:sup:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.365`,
        fs:  `cpe:2.3:a:e107:e107:0.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.366`,
        fs:  `cpe:2.3:a:microsoft:excel:95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.367`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.368`,
        fs:  `cpe:2.3:a:ibm:powerkvm:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.369`,
        fs:  `cpe:2.3:h:cisco:modular_encoding_platform_d9036:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.370`,
        fs:  `cpe:2.3:a:hp:status:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.371`,
        fs:  `cpe:2.3:o:huawei:s9303_firmware:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.372`,
        fs:  `cpe:2.3:a:david_king:vino:2.21.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.373`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.374`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.375`,
        fs:  `cpe:2.3:a:openttd:openttd:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.376`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg241a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.377`,
        fs:  `cpe:2.3:a:scott_reynen:node_embed:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.378`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.379`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.8.5:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.380`,
        fs:  `cpe:2.3:a:activestate:komodo_edit:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.382`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.383`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.10:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.384`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.386`,
        fs:  `cpe:2.3:o:huawei:s12700_firmware:v200r009c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.387`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.388`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.389`,
        fs:  `cpe:2.3:a:pluck-cms:pluck:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.390`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.391`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.392`,
        fs:  `cpe:2.3:o:ibm:aix:-:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.393`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.394`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.395`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.396`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.397`,
        fs:  `cpe:2.3:h:axis:700_network_document_server:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.398`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.399`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.400`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.401`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.402`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.403`,
        fs:  `cpe:2.3:a:administration_views_project:administration_views:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.404`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.0.00:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.405`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.406`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.407`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.2.7:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.408`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.409`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.409.1::lts`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.409.1:-:lts`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.409.2::lts`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.409.2:-:lts`,
        fs:  `cpe:2.3:a:gnome:glib:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.409.3:-:lts`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.410`,
        fs:  `cpe:2.3:h:linksys:wrt54gl:4.30.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.411`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.412`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:8.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.413`,
        fs:  `cpe:2.3:a:cosmoshop:cosmoshop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.414`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.2\(1\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.415`,
        fs:  `cpe:2.3:a:borland:jbuilder_2005:11.0.0.0:*:*:*:developer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.416`,
        fs:  `cpe:2.3:a:saltstack:salt:0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.417`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.418`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d48.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.419`,
        fs:  `cpe:2.3:a:mautic:mautic:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.420`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.5.0:-:-:en-us:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.421`,
        fs:  `cpe:2.3:a:hp:storage_management_software:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.422`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.423`,
        fs:  `cpe:2.3:a:caucho:resin:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424`,
        fs:  `cpe:2.3:a:libpng:libpng:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.0.2:-:enterprise`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.7.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.0.4:-:enterprise`,
        fs:  `cpe:2.3:a:dotcms:dotcms:1.9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.1:-:lts`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.1.1:-:enterprise`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.2:-:lts`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u5\(1.41\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.2.1:-:enterprise`,
        fs:  `cpe:2.3:a:clamav:clamav:0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.3:-:lts`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p83:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.4:-:lts`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.4.1:-:enterprise`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.5:-:lts`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.5.1:-:enterprise`,
        fs:  `cpe:2.3:a:qemu:qemu:0.11.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.6:-:lts`,
        fs:  `cpe:2.3:a:apprain:apprain:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.6.1:-:enterprise`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.93:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.424.6.11:-:enterprise`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.425`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.426`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.427`,
        fs:  `cpe:2.3:a:apple:cups:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.428`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.429`,
        fs:  `cpe:2.3:a:umn:mapserver:4.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.430`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.431`,
        fs:  `cpe:2.3:h:supermicro:x7spa-hf-d525:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.432`,
        fs:  `cpe:2.3:h:d-link:dir-505l_shareport_mobile_companion:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.433`,
        fs:  `cpe:2.3:a:apache:struts:2.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.434`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:20050820:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.435`,
        fs:  `cpe:2.3:a:hp:storage_management_software:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.436`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.437`,
        fs:  `cpe:2.3:a:isc:bind:9.7.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.447.1:-:lts`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.0\(0\):sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.447.1.1:-:enterprise`,
        fs:  `cpe:2.3:a:citystar:city_star_me:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.447.2:-:lts`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.447.2.2:-:enterprise`,
        fs:  `cpe:2.3:a:digium:asterisk:11.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.447.3.1:-:enterprise`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.447.6.1:-:enterprise`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.447.7.1:-:enterprise`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ronan_dowling:node_hierarchy:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.1:-:lts`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.1.2:-:enterprise`,
        fs:  `cpe:2.3:a:libexpat:expat:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.2:-:lts`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.2.1:-:enterprise`,
        fs:  `cpe:2.3:a:adobe:photoshop_album:3.2:-:starter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.10.1:-:enterprise`,
        fs:  `cpe:2.3:a:xmlswf:com_picsell:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.12.1:-:enterprise`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.6.1818.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.13.1:-:enterprise`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.14.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.451:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.466.14.1:-:enterprise`,
        fs:  `cpe:2.3:a:redhat:kdelibs_devel:3.0.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.480::~~enterprise~~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.10.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.480.3.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.480.3.1:-:enterprise`,
        fs:  `cpe:2.3:a:gnome:glib:2.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.480.4.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.0.0.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.480.4.1:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.501`,
        fs:  `cpe:2.3:a:video-lead-form:uk-cookie:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.509`,
        fs:  `cpe:2.3:a:apple:webkit:418.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.509:-:enterprise`,
        fs:  `cpe:2.3:a:pizzahut:pizza_hut:2.0.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.509.1::~~lts~~~`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.513`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.514`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.523`,
        fs:  `cpe:2.3:a:gnu:automake:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.625.1::lts`,
        fs:  `cpe:2.3:a:torrnad0:sprint_jump:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.639`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.2.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:1.651.1::~~lts~~~`,
        fs:  `cpe:2.3:o:apple:os_x_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins:2.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudbees:jenkins1.381:-`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.0.0`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.0.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.1.0`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.1.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.1.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.1.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.01:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.1.4`,
        fs:  `cpe:2.3:a:xoops:xoops:2.5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.1.5`,
        fs:  `cpe:2.3:h:samsung:galaxy_s4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.2.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.2.1`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.2.2`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.3.0`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.3.1`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.63:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.3.2`,
        fs:  `cpe:2.3:a:hp:status:53.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.4.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:4.5.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1273.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.0.0:beta`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.2.2:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.2.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.2.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.2.2`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:sp1a:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.2.3`,
        fs:  `cpe:2.3:a:raphael_zschorsch:rzautocomplete:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.2.4`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.0:cf02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.2.5`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.2.6`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.0`,
        fs:  `cpe:2.3:a:elipse:e3:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.032_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.2`,
        fs:  `cpe:2.3:a:drupal:drupal:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.4`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.5`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.6`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:dev2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.7`,
        fs:  `cpe:2.3:a:hp:support_assistant:8.1.40.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.8`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.9`,
        fs:  `cpe:2.3:a:google:chrome:7.0.503.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.3.10`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:unstable6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.1`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.3`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.5`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.6`,
        fs:  `cpe:2.3:a:cisco:meeting_server:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.7`,
        fs:  `cpe:2.3:a:mysql:mysql:3.20.32a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.8`,
        fs:  `cpe:2.3:o:cisco:catos:3.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.9`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:03-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.10`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.4.11`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.5.0`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.5.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.5.2`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.5.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.5.4`,
        fs:  `cpe:2.3:a:isc:dhcp:4.0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.5.5`,
        fs:  `cpe:2.3:a:djangoproject:piston:0.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.5.6`,
        fs:  `cpe:2.3:a:sun:java_system_content_delivery_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.6.0`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.6.1`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.7.0`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.7.1`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.1.0:rev30003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.7.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cdh:5.8.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.3-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_cdh:cdh3:0`,
        fs:  `cpe:2.3:a:gnu:findutils:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_cdh:cdh3:1`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_cdh:cdh3:2`,
        fs:  `cpe:2.3:a:f5:arx:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.0::enterprise`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.0::free`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.1::enterprise`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.1::free`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.2::enterprise`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.2::free`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.3::enterprise`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p187:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.3::free`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.4:*:*:*:*:aix:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.4::enterprise`,
        fs:  `cpe:2.3:a:jquery:jquery:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.4::free`,
        fs:  `cpe:2.3:a:hp:all-in-one:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.5::enterprise`,
        fs:  `cpe:2.3:a:teamst:testlink:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:3.7.5::free`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:4.0.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:4.0.4`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:4.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:4.7.0`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:4.7.1`,
        fs:  `cpe:2.3:a:yumenomachi:demaecan:2.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:4.7.3`,
        fs:  `cpe:2.3:a:ibm:network_appliance_data_ontap:7.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.0.0:beta1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.0.0:beta2`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.0.2`,
        fs:  `cpe:2.3:h:lucent:dslterminator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.0.5`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.1.0`,
        fs:  `cpe:2.3:h:hp:jg788a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.1.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.464:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.1.2`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.1.3`,
        fs:  `cpe:2.3:a:ibm:rational_change:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.1.4`,
        fs:  `cpe:2.3:a:clamav:clamav:0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.2.0`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.2.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update2:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.2.2`,
        fs:  `cpe:2.3:a:php:php:5.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.2.4`,
        fs:  `cpe:2.3:o:y-cam:yck002_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_manager:5.3.0`,
        fs:  `cpe:2.3:h:hp:laserjet_9040:q7697a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:cloudera_service_and_configuration_manager:3.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:hadoop:0.20-sbin`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:hadoop:0.20.1%2b169`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:hadoop:0.20.2%2b923`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudera:hadoop:0.20.2%2b923.197`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.7.0`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.8.0`,
        fs:  `cpe:2.3:a:google:chrome:39.0.2171.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.9.0`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_epc2420:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.10.0`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.11.0`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:003sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.12.0`,
        fs:  `cpe:2.3:a:foxitsoftware:enterprise_reader:7.1.3.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.13.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.14.0`,
        fs:  `cpe:2.3:a:teradata:tvi-proxy:7.0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.15.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.16.0`,
        fs:  `cpe:2.3:a:google:checkout-php:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.17.0`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.50.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.18.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.19.0`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.20.0`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.21.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.22.0`,
        fs:  `cpe:2.3:a:apple:safari:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.23.0`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle_common:1.0.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.24.0`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_technology_for_dds:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.25.0`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-20-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.26.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.27.0`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.28.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.29.0`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.4p5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.30.0`,
        fs:  `cpe:2.3:a:conky:conky:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.31.0`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.32.0`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.33.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.34.0`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.35.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.36.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:capi-release:1.37.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:141`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4500_series_software:4.1\(1.51\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:142`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:143`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc374xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:144`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:145`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.0.362:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:146`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:147`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:148`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:149`,
        fs:  `cpe:2.3:a:gnu:fileutils:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:150`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:151`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:152`,
        fs:  `cpe:2.3:o:cisco:modular_encoding_platform_d9036_software:02.03.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:153`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:154`,
        fs:  `cpe:2.3:a:ibm:lotus_protector_for_mail_security:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:155`,
        fs:  `cpe:2.3:a:ibm:trading_partner_interchange:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:156`,
        fs:  `cpe:2.3:a:testa:online_test_management_system:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:157`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.220:update22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:158`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:159`,
        fs:  `cpe:2.3:a:web-dorado:web-dorado_spider_video_player:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:160`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:161`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:162`,
        fs:  `cpe:2.3:o:cisco:aironet_access_point_software:8.1\(112.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:163`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.49.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:164`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_command_center:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:165`,
        fs:  `cpe:2.3:o:hp:hotspot_laserjet_pro_m1218nfs_mfp_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:166`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:167`,
        fs:  `cpe:2.3:a:businessobjects:webintelligence:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:168`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:169`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:2.5.2.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:170`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:171`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:172`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:173`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:174`,
        fs:  `cpe:2.3:a:apache:archiva:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:175`,
        fs:  `cpe:2.3:a:vanilla_perl_project:strawberry_perl:5.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:176`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:177`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:178`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:179`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.051:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:180`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:181`,
        fs:  `cpe:2.3:o:cisco:catos:7.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:182`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:183`,
        fs:  `cpe:2.3:h:ibm:power_5:9133-55a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:184`,
        fs:  `cpe:2.3:h:ibm:power_5:9406-525:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:185`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.3:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:186`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:187`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:188`,
        fs:  `cpe:2.3:a:mozilla:mozilla_suite:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:189`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.5.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:190`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:191`,
        fs:  `cpe:2.3:a:apple:itunes:7.7.1:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:192`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:193`,
        fs:  `cpe:2.3:h:huawei:s2700:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:194`,
        fs:  `cpe:2.3:a:winzip:winzip:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:195`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.2.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:196`,
        fs:  `cpe:2.3:a:ibm:traveler:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:197`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.17.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:198`,
        fs:  `cpe:2.3:a:babybus:babybus:3.91:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:199`,
        fs:  `cpe:2.3:o:sun:sunos:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:200`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:201`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:202`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:203`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:204`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:205`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:206`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:207`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:208`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:209`,
        fs:  `cpe:2.3:o:sophos:web_appliance_firmware:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:210`,
        fs:  `cpe:2.3:a:xnview:xnview:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:211`,
        fs:  `cpe:2.3:a:mozilla:mozilla:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:212`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30352:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:213`,
        fs:  `cpe:2.3:a:magzter:identity:3.01:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:214`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.0.1069:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:215`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:216`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:217`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:218`,
        fs:  `cpe:2.3:a:promotic:promotic:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:219`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.9.0\(127\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:220`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:221`,
        fs:  `cpe:2.3:a:jetbrains:resharper:6.1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:222`,
        fs:  `cpe:2.3:o:redhat:linux:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:223`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:-:x32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:224`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router_firmware:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:225`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:226`,
        fs:  `cpe:2.3:a:citrix:xendesktop:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:227`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:228`,
        fs:  `cpe:2.3:a:python:python:2.7.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:245`,
        fs:  `cpe:2.3:a:freeradius:freeradius:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:246`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8b\)e20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:247`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:248`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:249`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:250`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:251`,
        fs:  `cpe:2.3:a:rsa:authentication_client:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:252`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0.1.27038:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:253`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(22\)sv1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:254`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:255`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:0.7.0:beta_8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:256`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:257`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.283:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:258`,
        fs:  `cpe:2.3:a:freemind:freemind:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:259`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:260`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:261`,
        fs:  `cpe:2.3:a:microsoft:windows_live_messenger:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:262`,
        fs:  `cpe:2.3:a:androkera:las_vegas_lottery_scratch_off:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:263`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:264`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:265`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac_afr:6.1.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:266`,
        fs:  `cpe:2.3:a:google:toolbar_for_internet_explorer:7.2.2308.2056:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:267`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:268`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_base_platform:11.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudfoundry:cf-release:269`,
        fs:  `cpe:2.3:a:powerdns:authoritative:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cloudwords:cloudwords_for_multilingual:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:ni:labview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clubpersonal:club_personal:2.6::~~~android~~`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:5.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clusterlabs:pacemaker:1.1.10`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clutter_project:clutter:-`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:clutter_project:clutter:1.16.0`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmcm:cm_backup_-restorecloudphoto:1.1.0.135::~~~android~~`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmcm:cm_browser_-_fast_%26_secure:5.0.50::~~~android~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cminds:enhanced-tooltipglossary:3.2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms-center:simple_web_content_management_system:1.1`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dimastr:outlook_spy:3.0.0.2457:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.1a::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p233_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:teradata:pci_configurator:1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:lotus_quickr_for_domino:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-455:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:sun:solaris:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.4.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x:x.org_x11:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.1:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:spa3102_voice_gateway_with_router_firmware:5.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_server:3.6:ecb:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.5.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.8.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:tizen:tizen:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oneorzero:action_and_information_management_system:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:huawei:utps_firmware:23.009.09.00.983:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.1:cf1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:flatpress:flatpress:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p133:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x:libxvmc:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:debian:reprepro:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.13::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:menalto:gallery:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:buffalotech:wzr-ampg300nh_firmware:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.17::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.18::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.3ha:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.7.20::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(3h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:virtual_infrastructure_remote_command_line_interface:.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sun:jsse:1.0.3_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.1.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x:libdmx:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:solidworks:product_data_management:2014:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:protection_engine:7.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:13.0.2896:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.13::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.8.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:0.10.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:zyxel:p-660h-d1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.3.5:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:12.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_hydravision_full:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:v8:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/ru2_firmware:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.13::~~~wordpress~~`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.16::~~~wordpress~~`,
        fs:  `cpe:2.3:h:canon:network_camera_server_vb150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.19.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.18::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:j7x28a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.70.020.1372:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:word:97:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cms_tree_page_view_project:cms_tree_page_view:1.2.21::~~~wordpress~~`,
        fs:  `cpe:2.3:a:progress:objectstore:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:-`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.820:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.00`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.00:final`,
        fs:  `cpe:2.3:a:bigfix:discovery_platform:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.01`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_3010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.02`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.02.1`,
        fs:  `cpe:2.3:a:nancy_wichmann:sitedoc:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.10`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.20`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.21`,
        fs:  `cpe:2.3:a:show_do_milhao_2014_project:show_do_milhao_2014:1.4.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.22`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:rc4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.23`,
        fs:  `cpe:2.3:a:netscape:messaging_server:4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:1.24`,
        fs:  `cpe:2.3:o:hp:tru64:5.1af:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.0`,
        fs:  `cpe:2.3:a:netty_project:netty:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.00`,
        fs:  `cpe:2.3:a:oracle:forms:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.0:alpha_1`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:9.40.xc7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.0:alpha_2`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_hp:14.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.00:beta`,
        fs:  `cpe:2.3:a:cisco:expressway_software:x8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.00:release_candidate`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.41:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.01`,
        fs:  `cpe:2.3:a:avaya:ip_office_phone_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.02`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.03`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.04`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.05`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.06`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.08`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmscout:cmscout:2.09`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsdevelopment:business_card_web_builder:-`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsdevelopment:business_card_web_builder:0.99`,
        fs:  `cpe:2.3:a:samba:samba:4.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsdevelopment:business_card_web_builder:2.3:beta`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsdevelopment:business_card_web_builder:2.5:beta`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsimple:cmsimple_classic:3.5.4`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsjunkie:j-classifiedsmanager:-::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:websitebaker:websitebaker:2.8.3:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:-`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.1`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.4b.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.2.1`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.3`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.3.1`,
        fs:  `cpe:2.3:a:ca:etrust_admin:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.3.2`,
        fs:  `cpe:2.3:a:netgear:readynas_surveillance:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.4`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.4.1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.5.1`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.6`,
        fs:  `cpe:2.3:o:brocade:fabric_os:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.6.1`,
        fs:  `cpe:2.3:h:huawei:s5306:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.6.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.6.3`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.7`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.7.1`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.7.2`,
        fs:  `cpe:2.3:a:expressjs:express:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.7.3`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:11.0:sp1:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.8`,
        fs:  `cpe:2.3:h:supermicro:h8dgi-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.8.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.8.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.304:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.9`,
        fs:  `cpe:2.3:a:microsoft:visio:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.9.1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.9.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.10`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.10.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p7_rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.10.2`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.10.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.10.4`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.9.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.11`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.11.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.11.2`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_redundant_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.12`,
        fs:  `cpe:2.3:a:apple:quicktime:7.68.75.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.12.1`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.12.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:0.13`,
        fs:  `cpe:2.3:h:morpho:itemiser_3:8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp1:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0.3`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0.4`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0.5`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0.6`,
        fs:  `cpe:2.3:a:foxitsoftware:phantompdf:7.3.0.118:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0.7`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.0.8`,
        fs:  `cpe:2.3:a:justsystems:hanako:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.1.1`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.1.2`,
        fs:  `cpe:2.3:o:cisco:wap4410n_firmware:2.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.1.3`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.1.3.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.1.4`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.1.4.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.2`,
        fs:  `cpe:2.3:a:sap:hybris:5.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.2.2`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.2.3`,
        fs:  `cpe:2.3:a:cisco:internet_streamer_content_delivery_system:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.2.4`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.1.8.7:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.2.5`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.3`,
        fs:  `cpe:2.3:a:gnu:wget:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.3:beta1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.3:beta2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.3.1`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.4`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.4.1`,
        fs:  `cpe:2.3:a:iii:encore_discovery_solution:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.5`,
        fs:  `cpe:2.3:o:barracudanetworks:spam_\&amp;_virus_firewall_600_firmware:4.0.1.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.5.1`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.5.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.5.3`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.5.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.1`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.18c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.3`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20160930:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.4`,
        fs:  `cpe:2.3:a:krisonav:krisonav:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.5`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:2.5.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.6`,
        fs:  `cpe:2.3:h:hp:proliant_sl2x170z_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.7`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.8`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.0\(6\)p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.9`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.6.10`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.7`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.7.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(5.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.8`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.8.1`,
        fs:  `cpe:2.3:a:cisco:ip_interoperability_and_collaboration_system:4.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.8.2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.9`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.9.1`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.9.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.9.3`,
        fs:  `cpe:2.3:h:lucent:ascend_max_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.9.4`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.9.4.1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.9.4.2`,
        fs:  `cpe:2.3:a:cisco:expressway_software:x8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.9.4.3`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.10`,
        fs:  `cpe:2.3:a:cisco:mediasense:8.5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.10.1`,
        fs:  `cpe:2.3:h:dell:poweredge_r610:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.10.2`,
        fs:  `cpe:2.3:a:symantec:brightmail_antispam:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.10.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:9.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.2`,
        fs:  `cpe:2.3:a:isc:bind:9.4:*:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.2.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.3`,
        fs:  `cpe:2.3:a:busybox:busybox:1.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.4`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0a6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:7:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.6`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.7`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.9`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.10`,
        fs:  `cpe:2.3:a:apache:camel:2.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.11`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.12`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.2.04018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.11.13`,
        fs:  `cpe:2.3:h:ibm:system_x3500_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.12`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:1.12.1`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.0:beta1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.0:beta2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.279:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.0:beta3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.0:beta4`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.0.1`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.0.1.1`,
        fs:  `cpe:2.3:a:projectsprouts:sprout:0.7.246:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.1.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.1.2`,
        fs:  `cpe:2.3:a:hp:procurve_manager:3.20:*:*:*:*:plus:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.2:beta1`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.2:beta2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.11.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.2:beta3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je015a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.2:beta4`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_enterprise_single_sign-on:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.3:beta1`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.3:beta2`,
        fs:  `cpe:2.3:a:cisco:jabber:9.1\(.5\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.3:beta3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.645:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.3:beta4`,
        fs:  `cpe:2.3:a:adgjm:angel_browser:1.62b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.3:beta5`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.4:beta1`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.4:beta2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.4:beta3`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.4:beta4`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.4:beta5`,
        fs:  `cpe:2.3:h:lexmark:c78x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsmadesimple:cms_made_simple:2.7`,
        fs:  `cpe:2.3:a:google:chrome:17.0.953.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmsproducts:bounceback_ultimate:9.2.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:carnegie_mellon_silicon_valley:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:1.5.28`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:2.1.19`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:2.1.20`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:6.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:2.1.21`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3b.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:2.1.22`,
        fs:  `cpe:2.3:a:microsoft:commercial_internet_system:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:2.1.23`,
        fs:  `cpe:2.3:a:trend_micro:trend_micro_portalprotect:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:2.1.24:rc1`,
        fs:  `cpe:2.3:a:ca:brightstor_mobile_backup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:2.1.25`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus-sasl:2.1.26`,
        fs:  `cpe:2.3:o:vmware:esxi:5.0:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.0.17`,
        fs:  `cpe:2.3:h:3com:3cb9e16:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.1.16`,
        fs:  `cpe:2.3:a:novell:groupwise:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.1.17`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.1.18`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.2.8`,
        fs:  `cpe:2.3:a:gnu:mailutils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.2.9`,
        fs:  `cpe:2.3:a:php:pear:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.2.10`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.2.11`,
        fs:  `cpe:2.3:a:google:v8:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.2.12`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.2.13`,
        fs:  `cpe:2.3:a:vmware:fusion:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.2.13p1`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.1`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:9.40.tc5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.2`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.4`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.5`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.5.55810.432:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.6`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.7`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.14.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.8`,
        fs:  `cpe:2.3:a:perl:perl:5.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.9`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.10`,
        fs:  `cpe:2.3:a:digium:asterisk:13.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.11`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.92.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.12`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:5.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.12:p1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.12:p2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.298:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.12p1`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:08-11-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.12p2`,
        fs:  `cpe:2.3:a:apache:poi:3.10:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.13`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.29:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.14`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.15`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.3.16`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.0`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.2:rp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.1`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.2`,
        fs:  `cpe:2.3:a:nec:universal_raid_utility:2.31:rev_1492:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.3`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.4`,
        fs:  `cpe:2.3:a:gnu:realtime_linux_security_module:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.5`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.17:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.7`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.8`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.9`,
        fs:  `cpe:2.3:a:ibm:infosphere_business_glossary:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:cyrus_imap_server:2.4.10`,
        fs:  `cpe:2.3:a:horde:groupware:5.1.1:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:flite:1.4`,
        fs:  `cpe:2.3:a:djangoproject:django:1.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:isilk:0.1.6`,
        fs:  `cpe:2.3:a:hummingbird:collaboration:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cmu:isilk:0.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cnectd:cnectd:2.0.0`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cnectd:cnectd:2.1.0`,
        fs:  `cpe:2.3:a:nortel:meridian_option_11c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cnectd:cnectd:2.1.5`,
        fs:  `cpe:2.3:a:location_module_project:location:7.x-4.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cnectd:cnectd:3.1.0`,
        fs:  `cpe:2.3:a:jruby:jruby:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cnn:cnnmoney_portfolio:1.03::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cnn:cnnmoney_portfolio_for_stocks:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cob%27s_products:cobime:0.9.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cob%27s_products:cobime:0.9.3:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cobbler_project:cobbler:2.2.1`,
        fs:  `cpe:2.3:a:microsoft:excel:2000:sr1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cobblerd:cobbler:2.4.0:-`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cobblerd:cobbler:2.4.0:1`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cobblerd:cobbler:2.4.1`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cobblerd:cobbler:2.4.2`,
        fs:  `cpe:2.3:o:sun:sunos:4.1.3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cobblerd:cobbler:2.4.3`,
        fs:  `cpe:2.3:o:dell:sonicwall_sonicos:7.5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cobblerd:cobbler:2.4.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cobblerd:cobbler:2.6.0`,
        fs:  `cpe:2.3:a:castlerock:snmpc:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cocodigi:martial_arts_battle_card:1.0.9::~~~android~~`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_technology_for_python:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:code-crafters:ability_mail_server:3.1.1`,
        fs:  `cpe:2.3:a:bil_simser:sharepointforums:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codeasily:grand_flagallery:1.56::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:2.6.29`,
        fs:  `cpe:2.3:a:plone:plone:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:2.6.32.62`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.206:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:2.6.32.63`,
        fs:  `cpe:2.3:a:apple:cups:1.5:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.54`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.55`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.56`,
        fs:  `cpe:2.3:a:webtrends:analysis:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.57`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.58`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8v:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.59`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.60`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.61`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.2.62`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_pdf_sdk_dll:3.1.1.2927:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.72`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.73`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.74`,
        fs:  `cpe:2.3:a:school_administration_project:school_administration:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.75`,
        fs:  `cpe:2.3:a:google:chrome:6.0.415.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.76`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.77`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.78`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.79`,
        fs:  `cpe:2.3:a:php:php:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.80`,
        fs:  `cpe:2.3:h:cisco:sg300-28:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.81`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.185.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.82`,
        fs:  `cpe:2.3:a:nancy_wichmann:announcements:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.83`,
        fs:  `cpe:2.3:a:otrs:otrs:1.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.84`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.11:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.85`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p1_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.86`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.7.4050.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.87`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.88`,
        fs:  `cpe:2.3:a:atlassian:jira:2.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.89`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.05.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.90`,
        fs:  `cpe:2.3:a:apple:cups:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.91`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.92`,
        fs:  `cpe:2.3:a:dotclear:dotclear:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.93`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.94`,
        fs:  `cpe:2.3:o:yahama:rta52i:3.06.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.95`,
        fs:  `cpe:2.3:a:adobe:flash_player:16.0.0.305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.96`,
        fs:  `cpe:2.3:a:apache:jackrabbit:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.97`,
        fs:  `cpe:2.3:o:iij:eil\%2fx2_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.98`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.99`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.100`,
        fs:  `cpe:2.3:a:pharmaguideline:pharmaguideline:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.101`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.102`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.4.103`,
        fs:  `cpe:2.3:a:x:libxrandr:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10`,
        fs:  `cpe:2.3:a:citrix:receiver_dv:13.0.0.6684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.22`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_server:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.23`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.24`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.25`,
        fs:  `cpe:2.3:o:netbsd:netbsd:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.26`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.27`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.28`,
        fs:  `cpe:2.3:a:adobe:device_central_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.29`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:tenc4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.30`,
        fs:  `cpe:2.3:a:adobe:livecycle_es2:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.31`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.32`,
        fs:  `cpe:2.3:a:logitech:camerahelpermsi:13.25.1010.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.33`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.35`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.36`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.37`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.38`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.39`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.40`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.41`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.42`,
        fs:  `cpe:2.3:a:emc:documentum_web_publisher:6.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.43`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_iis:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.44`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.45`,
        fs:  `cpe:2.3:a:docker:docker:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.46`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.47`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.48`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.9502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.49`,
        fs:  `cpe:2.3:a:posh_project:posh:1.5:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.50`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.51`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.52`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.10.53`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.3`,
        fs:  `cpe:2.3:a:rovicorp:sonic_dla:4.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.5`,
        fs:  `cpe:2.3:a:adobe:stock_photos:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.6`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.7`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.8`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.9`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.10`,
        fs:  `cpe:2.3:a:komodia:redirector_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.11`,
        fs:  `cpe:2.3:a:citrix:receiver_aero:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.12`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.13`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.14`,
        fs:  `cpe:2.3:a:e107:e107:0.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.15`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.16`,
        fs:  `cpe:2.3:a:aeroexpress:aeroexpress:2.6.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.17`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.18`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.19`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.20`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.21`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.22`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.23`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.4:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.24`,
        fs:  `cpe:2.3:a:netscape:navigator:8.0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.25`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_client:7.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.12.26`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.03:*:le:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13:rc1`,
        fs:  `cpe:2.3:a:adobe:acrobat:17.011.30059:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13:rc2`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.1:sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13:rc3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.446.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13:rc4`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13:rc5`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13:rc6`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13:rc7`,
        fs:  `cpe:2.3:a:sendmail:message_store_sams:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13:rc8`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.1`,
        fs:  `cpe:2.3:a:apache:hadoop:0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.2`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.3`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2tpc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.5`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.6`,
        fs:  `cpe:2.3:a:ldap_project:ldap:2.8.17:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.7`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.8`,
        fs:  `cpe:2.3:a:vips:vips:7.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.9`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.13.11`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14`,
        fs:  `cpe:2.3:a:koha:koha:3.16.00:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14:rc1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14:rc3`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.0.1065:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14:rc4`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14:rc5`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14:rc6`,
        fs:  `cpe:2.3:a:sun:secure_global_desktop_client:4.41.907:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14:rc7`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14:rc8`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.1`,
        fs:  `cpe:2.3:a:headlines_news_india_project:headlines_news_india:0.21.13219.95110:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.2`,
        fs:  `cpe:2.3:a:jease:jease:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.3`,
        fs:  `cpe:2.3:h:hp:cz245a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.4`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.5`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.1.0:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.7`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.8`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.9`,
        fs:  `cpe:2.3:h:supermicro:h8sml-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.10`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.11`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.12`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.11:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.13`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.14`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.15`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.14.16`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15:rc1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15:rc2`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.0.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15:rc3`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:1.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15:rc4`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15:rc5`,
        fs:  `cpe:2.3:a:digium:asterisk:11.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15:rc6`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15:rc7`,
        fs:  `cpe:2.3:a:ioserver:ioserver:1.0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15:rc8`,
        fs:  `cpe:2.3:a:php:php:5.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.1`,
        fs:  `cpe:2.3:a:trillian:trillian:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.2`,
        fs:  `cpe:2.3:a:nvidia:display_driver:310.00:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.3`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.4`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.6`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5804:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.7`,
        fs:  `cpe:2.3:a:gnome:glib:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.8`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.9`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.15.10`,
        fs:  `cpe:2.3:a:avaya:vsu_10000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16`,
        fs:  `cpe:2.3:a:aol:explorer:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16:rc1`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16:rc2`,
        fs:  `cpe:2.3:a:bananadance:banana_dance:1.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16:rc3`,
        fs:  `cpe:2.3:h:wansview:h.264_hi3510\/11\/12_ip_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16:rc4`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16:rc5`,
        fs:  `cpe:2.3:h:axis:2401_video_server:1.0_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16:rc6`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16:rc7`,
        fs:  `cpe:2.3:a:perl:perl:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.16.1`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1q\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:codeaurora:android-msm:3.17:rc1`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecanyon:phpsound:1.0.5`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.6`,
        fs:  `cpe:2.3:a:novell:gtk\#_for_.net:2.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.7.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.23:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.7.0:-:lite`,
        fs:  `cpe:2.3:o:sun:sunos:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.7.5`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.7.5:-:lite`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.3.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.8.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.8.0:-:lite`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.91.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.8.2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.8.2:-:lite`,
        fs:  `cpe:2.3:a:netscape:communicator:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.8.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.8.4:-:lite`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.9.0`,
        fs:  `cpe:2.3:a:gajim:gajim:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.9.0:-:lite`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.23`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.46`,
        fs:  `cpe:2.3:a:adobe:flash_player:16.0.0.257:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.47`,
        fs:  `cpe:2.3:a:wellintech:kingscada:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.48`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.49`,
        fs:  `cpe:2.3:a:clamav:clamav:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.50`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.51`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.51:-:lite`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.52`,
        fs:  `cpe:2.3:a:otrs:otrs:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.52:-:lite`,
        fs:  `cpe:2.3:a:readplease:readplease_plus:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.60`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:1.60:-:lite`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.21.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:2.0.0`,
        fs:  `cpe:2.3:o:sun:solaris:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:2.0.0:-:lite`,
        fs:  `cpe:2.3:a:blaine_lang:filedepot:6.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:2.0.1`,
        fs:  `cpe:2.3:a:google:v8:3.12.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codecguide:real_alternative:2.0.1:-:lite`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:10.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codedesign:artime_japanese_input:1.1.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.5.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:codeeta:codeeta_coupons:1.0.5::~~~android~~`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codefabrik:ecomat_cms:5.0`,
        fs:  `cpe:2.3:o:corega:cg-wlncm4g_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.0:alpha4`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.0.1`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.0.2`,
        fs:  `cpe:2.3:h:linksys:wrt54g:1.42.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.0.3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.1`,
        fs:  `cpe:2.3:a:apache:camel:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.1.1`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.1.2`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.2`,
        fs:  `cpe:2.3:a:apple:cups:1.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.2:beta1`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v200r005c02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.2:beta2`,
        fs:  `cpe:2.3:h:cisco:sf302-08mp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.2.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:05-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.2.2`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:redback:1.2.3`,
        fs:  `cpe:2.3:a:amanda:amanda:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:xfire:1.2.4`,
        fs:  `cpe:2.3:a:gnu:gnumail:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:xfire:1.2.5`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codehaus:xfire:1.2.6`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codemasters:dirt:1.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:rc2009-01-30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codepeople:com_multicalendar:4.0.2::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codepeople:com_multicalendar:4.8.5::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90.3_p0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codepeople:com_multicalendar:4.9.0::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:codesector:teracopy:2.2`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144nh_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codesector:teracopy:2.12`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codewrights:hart_device_type_manager:1.0.44`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.0.0`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.22.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.0.1`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.1.0`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.1.1`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.1.3`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.1.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_identity_manager_solution:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.1.5`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.1.6`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.907:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.2.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.2.1`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.13560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.2`,
        fs:  `cpe:2.3:a:appbelle:stop_headaches_and_migraines:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.3`,
        fs:  `cpe:2.3:a:google:v8:3.17.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.6`,
        fs:  `cpe:2.3:a:hp:software_core_japanese_localization:6.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.8`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.10`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.11`,
        fs:  `cpe:2.3:a:vmware:vcenter_operations:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.12`,
        fs:  `cpe:2.3:a:otrs:otrs:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.3.13`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.2\(1\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.4.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:6.0.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.4.1`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.4.2`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.5.0`,
        fs:  `cpe:2.3:a:oracle:diagnostics:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.5.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.6.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.7.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.7.5`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.7.8`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.7.9`,
        fs:  `cpe:2.3:a:redhat:docbook_utils:0.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.8.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_rich_text_editor:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.8.1`,
        fs:  `cpe:2.3:a:gnu:libc:5.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.8.2`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.8.3`,
        fs:  `cpe:2.3:a:ca:service_desk:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.8.4`,
        fs:  `cpe:2.3:a:serv-u:serv-u:5.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.9.0`,
        fs:  `cpe:2.3:o:iij:seil\%2fx1_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.9.1`,
        fs:  `cpe:2.3:a:ibm:db2:11.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:1.9.2`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:2.0.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:2.0.2`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:a5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:2.0.4`,
        fs:  `cpe:2.3:a:maxtom:atomymaxsite:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:2.0.6`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:38.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:2.0.7`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codiad:codiad:2.4.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codoforum:codoforum:2.5.1`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.09.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:codologic:com_freichat:9.4::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coffee-inn:coffee_inn:2.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:divx:divx_version_checker:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cascade_datahub:6.4.20`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cascade_datahub:6.4.21`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cascade_datahub:6.4.22`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.0`,
        fs:  `cpe:2.3:o:engardelinux:secure_linux:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.0.2`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.6:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.1.0`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.1.1`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance:a5\(1.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.1.1.63`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.8:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.1.2`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.2.2`,
        fs:  `cpe:2.3:a:cisco:ip_contact_center_enterprise:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.3.0`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:cogent_datahub:7.3.9`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:datahub_quicktrend:7.2.2`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:datahub_quicktrend:7.3.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:opc_datahub:6.4.20`,
        fs:  `cpe:2.3:a:divx:codec:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:opc_datahub:6.4.21`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:3.6ece:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cogentdatahub:opc_datahub:6.4.22`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:cognos_enterprise_planning_client:1.0.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:contributor_client:8.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:developer_client:8.3`,
        fs:  `cpe:2.3:a:novell:kanaka:2.7:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:financial_statement_reporting:6.6.0`,
        fs:  `cpe:2.3:a:kde:kde_sc:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:financial_statement_reporting_database:6.6.0`,
        fs:  `cpe:2.3:a:spumko_project:hapi_server_framework:2.1.1:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:financial_statement_reporting_web_services:6.6.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:go%21_office:1.0.0`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r2.17_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:go%21_office:8.3.146.0`,
        fs:  `cpe:2.3:a:macromedia:flash_player:4.0_r12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:go%21_office:8.4.2155.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:office_connection:8.1.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:planning_client:8.3`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:planning_client_framework:8.4.2058.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:planning_client_framework:8.4.2513.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:planning_client_framework:8.4.6025.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:planning_client_framework:8.4.6035.0`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:rich_client_framework:8.4.4486.104`,
        fs:  `cpe:2.3:a:ftpfs:ftpfs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:series_7:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:series_7:2`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:series_7:3`,
        fs:  `cpe:2.3:a:netscape:directory_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:ticket_server:-`,
        fs:  `cpe:2.3:a:tamalaki:hidden_object_mystery:1.0.65:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cognos:windows_common_logon_server:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0`,
        fs:  `cpe:2.3:a:microsoft:psloglist:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:beta1`,
        fs:  `cpe:2.3:a:microsoft:office:2013:-:-:*:-:-:x86:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:beta2`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:beta3`,
        fs:  `cpe:2.3:a:haxx:curl:7.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:beta4`,
        fs:  `cpe:2.3:a:splunk:splunk:6.5.1:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:beta5`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:rc1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:rc2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(1q\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:rc3`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.0:rc4`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.1`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coleman_watts:webform_civicrm:7.x-3.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios:12.0db:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:automatic_update:1.2`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:scrumworks:5.0:-:professional`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:scrumworks:5.1:-:professional`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.2:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:subversion:1.3.0-r17949`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:subversion:1.4.6`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:subversion:1.4.6-r28521`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:subversion:1.6.17`,
        fs:  `cpe:2.3:a:redhat:certificate_system:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:subversion_client:1.6.12`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:subversion_server:1.6.2`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collabnet:subversion_server:1.6.17`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectd:collectd:5.4.2`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectd:collectd:5.5.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.450.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectiveaccess:pawtucket:1.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectiveaccess:pawtucket:1.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectiveaccess:pawtucket:1.3`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.67:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:collectiveaccess:providence:1.1`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectiveaccess:providence:1.2`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs3_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectiveaccess:providence:1.3`,
        fs:  `cpe:2.3:a:freedomscientific:video_intercept:10.19.760.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:beta1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.1r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:beta2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:beta3`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:beta4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.12:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectivecolors:taxonomy_view_integrator_module:6.x-1.1`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:4.0.0.0619:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:collectivecolors:taxonomy_view_integrator_module:6.x-1.2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:color:icclib:1.23`,
        fs:  `cpe:2.3:a:isc:bind:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:color:icclib:2.00`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:color:icclib:2.02`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:color:icclib:2.03`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:color:icclib:2.11`,
        fs:  `cpe:2.3:o:tenda:a5s_firmware:3.02.05_cn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:color:icclib:2.13`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:colorbox_node:dennis_blake:7.x-2.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:colorbox_node:dennis_blake:7.x-2.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:colorbox_node:dennis_blake:7.x-2.2`,
        fs:  `cpe:2.3:h:cisco:catalyst_8500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:colorscore_project:colorscore:0.0.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:0.7.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:0.7.2`,
        fs:  `cpe:2.3:h:cisco:unified_computing_system_6140xp_fabric_interconnect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:0.8`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:0.8.1.3`,
        fs:  `cpe:2.3:a:curtis_galloway:libexif:0.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:0.9:-`,
        fs:  `cpe:2.3:a:honeywell:enterprise_buildings_integrator:r310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:0.9:beta`,
        fs:  `cpe:2.3:a:novell:groupwise_webaccess:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:0.9.1`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_xi:11.5.8.82627:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.0:-`,
        fs:  `cpe:2.3:h:dell:precision_mobile_m4600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.0:beta`,
        fs:  `cpe:2.3:a:apple:cups:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.0.1:-`,
        fs:  `cpe:2.3:a:fourkitchens:ed_readmore:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.0.2:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.0.2:beta`,
        fs:  `cpe:2.3:a:sharethis:sharethis:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.1:-`,
        fs:  `cpe:2.3:o:cisco:aireos:7.4:120.0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.1:beta`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.1.181`,
        fs:  `cpe:2.3:h:d-link:tm-g5240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.2:-`,
        fs:  `cpe:2.3:a:samba:samba:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.2:beta`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:17.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.2.0:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.2.0:rc282`,
        fs:  `cpe:2.3:a:gnome:evolution:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.2.1:-`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:1.2.1:beta`,
        fs:  `cpe:2.3:a:cisco:webns:4.0_1.053s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:2.0:-`,
        fs:  `cpe:2.3:h:nortel:symposium_express_call_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:2.0:beta`,
        fs:  `cpe:2.3:o:netgear:raidiator:4.2.15:-:-:*:-:-:readynas:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:2.0:beta2`,
        fs:  `cpe:2.3:o:cisco:spa500_firmware:7.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:2.0.1:-`,
        fs:  `cpe:2.3:a:systemtools:hyena:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:2.0.1:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)sl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:2.0.2:-`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:combodo:itop:2.0.2:beta`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:comcast:xfinity_constant_guard_mobile:3.1.140603::~~~android~~`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.60.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:comcast:xfinity_home_security_system:-`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comicsplusapp:comics_plus:1.06::~~~android~~`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commdevices:distributed_database_manager-odbc:4.21.5`,
        fs:  `cpe:2.3:a:apache:hbase:0.92.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commdevices:distributed_database_manager-odbc:4.22.0`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commdevices:distributed_database_manager-odbc:4.27.1`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner_documentation:17.0.0.10655:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commdevices:secure_session_manager:4.22.0`,
        fs:  `cpe:2.3:a:tibco:vault:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.71::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.74::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:deskjet_3820_color_inkjet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.76::~~~wordpress~~`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.80::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81::~~~wordpress~~`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:47.0.2526.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pcre:perl-compatible_regular_expression_library:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.04.314:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional_oem:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:2g_live_tv_project:2g_live_tv:0.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.81.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:meinberg:lantime_m200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:antti_alamki:prh_search:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:die-netzmacher:browser:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:safari:3.0.3:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:002sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pocoproject:poco_c\&#43;\&#43;_libraries:1.4.6:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.5:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:confluence:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gimp:gimp:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.90.9.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:claris_emailer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.91::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.91.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.15.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sendmail:sendmail:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.92.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isode:m-link:14.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.93::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.93.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.93.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.93.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:6677g:girls_games_-_shoes_maker:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.93.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.761::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vips:vips:7.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.762::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.763::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.764::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:ace_2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.765::~~~wordpress~~`,
        fs:  `cpe:2.3:a:xnview:xnview:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.766::~~~wordpress~~`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.767::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rta55i:4.06.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.768::~~~wordpress~~`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:3.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.769::~~~wordpress~~`,
        fs:  `cpe:2.3:a:acrosoftware:cutepdf:3.6.4.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commentluv:commentluv:2.7691::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerce:america%27s_economy_for_phone:1.5.2::~~~android~~`,
        fs:  `cpe:2.3:o:ibm:aix:-:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:commerce_balanced_payments_project:commerce_balanced_payments:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerce_ogone_project:commerce_ogone:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerce_ogone_project:commerce_ogone:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerce_ogone_project:commerce_ogone:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerce_ogone_project:commerce_ogone:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerce_ogone_project:commerce_ogone:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:samba:samba:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2009:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.5.4.4910:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:grape_project:grape:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:opscode:chef:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha4`,
        fs:  `cpe:2.3:a:divx:player:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha4:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha5`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:alpha5:~~~drupal~~`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:beta1`,
        fs:  `cpe:2.3:o:cisco:rv215w_firmware:1.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:beta2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1\(3\)es32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:beta4`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.2:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:beta4:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:netgear:wg111v2_driver:5.1213.6.316:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.0:rc3:~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.1`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:3.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce_reorder:7.x-1.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(2\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce_reorder:7.x-1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commerceguys:commerce_reorder:7.x-1.x:dev`,
        fs:  `cpe:2.3:h:cisco:rv042_dual_wan_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commons_wikis_project:commons_wikis:7.x-3.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commons_wikis_project:commons_wikis:7.x-3.1`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commons_wikis_project:commons_wikis:7.x-3.2`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commons_wikis_project:commons_wikis:7.x-3.x:dev`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commonsensesoftwarellc:bates:1.0::~~professional~~~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commpower:dc_config:2.8.8`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.4.2:pr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commpower:dc_directory_admin:3.0.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commpower:dc_directory_admin:3.9.2`,
        fs:  `cpe:2.3:a:git-scm:git:0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commpower:security_label_server:1.0.0`,
        fs:  `cpe:2.3:a:c3-ilex:eoscada:11.0.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commpower:xml_portal:1.0.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commpower:xml_portal:1.0.2`,
        fs:  `cpe:2.3:o:netbsd:netbsd:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commpower:xml_portal_cp-xp:-`,
        fs:  `cpe:2.3:a:novell:groupwise:2012:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:active_directory_idataagent:9.0.0`,
        fs:  `cpe:2.3:a:sympa:sympa:5.4a.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:base_client:9.0.0`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.26.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:commcell_console:9.0.0`,
        fs:  `cpe:2.3:a:realvnc:realvnc:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:commnet_browser:9.0.0`,
        fs:  `cpe:2.3:h:cisco:application_velocity_system_3180:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:commserve:9.0.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:continuous_data_replicator:9.0.0`,
        fs:  `cpe:2.3:a:moip_project:moip:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:continuous_data_replicator_vss_provider:9.0.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:exchange_database_idataagent:9.0.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.28.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:exchange_mailbox_archiver_agent:9.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool_system_service_monitors:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:exchange_web_proxy_archiver_agent:9.0.0`,
        fs:  `cpe:2.3:h:cisco:ip_phone_8800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:exchange_webproxy_archiver_agent:9.0.0`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:file_system_idataagent:9.0.0`,
        fs:  `cpe:2.3:a:ibm:installation_manager:1.7.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:galaxy:-`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:media_agent:9.0.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:owa_proxy_enabler:9.0.0`,
        fs:  `cpe:2.3:a:news_project:news:3.1.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:resource_pack:9.0.0`,
        fs:  `cpe:2.3:a:david_king:vino:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:sql_server_idataagent:9.0.0`,
        fs:  `cpe:2.3:h:rockwellautomation:flexlogix_1788-enbt_adapter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:srm_exchange_agent:9.0.0`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.0.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:srm_windows_file_system_agent:9.0.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:vss_provider:9.0.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:commvault:windows_file_system_idataagent:9.0.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:backup:4.4.1`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.5.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.14.276`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.15.277`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.16.295`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.7.5\(62\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.17.304`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.7.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.18.309`,
        fs:  `cpe:2.3:a:adobe:flash_player:21.0.0.213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.19.318`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:beta7:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.20.320`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.22.349`,
        fs:  `cpe:2.3:a:hp:service_manager_web_client:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.23.364`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.24.368`,
        fs:  `cpe:2.3:a:nginx:nginx:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.0.25.378`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.5.53896.424`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.5.54375.427`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11b\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.5.55810.432`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jb2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.5.57173.439`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.8.64263.468`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.4410-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.8.64739.471`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.8.65951.477`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.9.95478.509`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.10.102363.531`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.11.108364.552`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.12.111745.560`,
        fs:  `cpe:2.3:a:adcillc:simplemeta:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.13.121240.574`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.13.125662.579`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:3.14.130099.587`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:4.0.138377.779`,
        fs:  `cpe:2.3:o:cisco:rv215w_wireless-n_vpn_router_firmware:1.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:4.0.141842.828`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:4.1.150349.920`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.0.163652.1142`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.3.174622.1216`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control_client_agent_service:6.9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.3.175888.1227`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.3.176757.1236`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.3.181415.1237`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.4.189822.1355`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.5.195786.1383`,
        fs:  `cpe:2.3:a:ibm:db2:10.1:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.8.211697.2124`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.8.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.8.213334.2131`,
        fs:  `cpe:2.3:a:tony_freixas:ubercart_product_keys:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.9.219863.2196`,
        fs:  `cpe:2.3:a:digium:asterisk:13.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.9.221665.2197`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:comodo_internet_security:5.10.228257.2253`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:comodo:geekbuddy:4.18.120`,
        fs:  `cpe:2.3:a:corel:paintshop_pro_x6:15.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:compal_broadband_networks:cg6640e_wireless_gateway:1.0`,
        fs:  `cpe:2.3:a:trendmicro:interscan_web_security_virtual_appliance:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:compal_broadband_networks:ch664oe_wireless_gateway:1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compal_broadband_networks:firmware:ch6640-3.5.11.7-nosh`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:acms:-`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:acms:4.3`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:acms:4.4`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:armada_insight_manager:-`,
        fs:  `cpe:2.3:h:iij:seil\/x1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:armada_insight_manager:4.20`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.596.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:armada_insight_manager:4.20j`,
        fs:  `cpe:2.3:a:compaq:smartstart:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:compaqhttpserver:-`,
        fs:  `cpe:2.3:a:yahoo:messenger:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:easy_access_keyboard_software:-`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:easy_access_keyboard_software:1.3`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.19:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:enterprise_volume_manager-command_scripter:1.0`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:enterprise_volume_manager-command_scripter:1.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:enterprise_volume_manager_command_scripter:-`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:foundation_agents:-`,
        fs:  `cpe:2.3:a:google:earth_plug-in:6.0.2.2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:foundation_agents:1.0`,
        fs:  `cpe:2.3:a:adrian_chadd:rtg:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:foundation_agents:2.1`,
        fs:  `cpe:2.3:a:isc:bind:9.7.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:foundation_agents:4.0`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:9.0.114.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:foundation_agents:4.90`,
        fs:  `cpe:2.3:a:sodahead:sodahead_polls:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_management_agent:-`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_management_agent:3.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)dc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_management_agent:4.2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_management_agent:4.20`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_management_agent:4.37`,
        fs:  `cpe:2.3:a:cobblerd:cobbler:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_management_agent:4.37e`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_management_desktop_web_agent:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_management_desktop_web_agent:3.7`,
        fs:  `cpe:2.3:h:cisco:spa_500ds:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.30:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager:7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_lc:-`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_lc:1.50a`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_xe:-`,
        fs:  `cpe:2.3:a:ibm:sterling_connect:4.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_xe:1.0`,
        fs:  `cpe:2.3:o:iij:seil\%2fb1_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_xe:1.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1664.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_xe:1.21`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_xe:2.1`,
        fs:  `cpe:2.3:h:siemens:scalance_w747-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_xe:2.1b`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_xe:2.1c`,
        fs:  `cpe:2.3:a:gnu:automake:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:insight_manager_xe:2.2`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:intelligent_cluster_administrator:-`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:intelligent_cluster_administrator:1.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:intelligent_cluster_administrator:2.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:management_agents:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(3.4\)bp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:management_agents_for_servers:-`,
        fs:  `cpe:2.3:o:cisco:unified_wireless_ip_phone_7920_firmware:1.0\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:open_san_manager:-`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:open_san_manager:1.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.3:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:openvms:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p181:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:power_management:-`,
        fs:  `cpe:2.3:o:redhat:linux_advanced_workstation:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:compaq:proliant_bl_e-class_integrated_administrator_firmware:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:sanworks_resource_monitor:-`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:sanworks_resource_monitor:1.0`,
        fs:  `cpe:2.3:a:arellia:arellia_common:6.0.1417:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:smartstart:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:smartstart:4.50`,
        fs:  `cpe:2.3:a:cisco:jabber_guest:10.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:storage_allocation_reporter:-`,
        fs:  `cpe:2.3:a:realnetworks:realupgrade:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:storage_allocation_reporter:1.0`,
        fs:  `cpe:2.3:o:cisco:nx-os_1000v_switch:4.0\(4\)sv1\(2\):*:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:survey_utility:-`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:survey_utility:2.17`,
        fs:  `cpe:2.3:a:phusion:passenger:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:survey_utility:2.18`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:survey_utility:2.33`,
        fs:  `cpe:2.3:a:samba:samba:3.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:system_healthcheck:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:system_healthcheck:3.0`,
        fs:  `cpe:2.3:a:php:php:5.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:-`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r4-p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0b`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0d`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0d_pk9_bl17`,
        fs:  `cpe:2.3:a:apache:traffic_server:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0e`,
        fs:  `cpe:2.3:a:openstack:neutron:juno2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0f`,
        fs:  `cpe:2.3:h:hp:procurve_switch_4000m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0f_pk6_bl17`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_database_control:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0f_pk7_bl18`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0f_pk8_bl22`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0g`,
        fs:  `cpe:2.3:h:siemens:synco_ozw_web_server:ozw772.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0g_pk3`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.12:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0g_pk3_bl17`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:4.0g_pk4_bl22`,
        fs:  `cpe:2.3:a:openstack:horizon:2014.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.0`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.0_pk4_bl17`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.0_pk4_bl18`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.0a`,
        fs:  `cpe:2.3:a:teradata:shared_icu_libraries:12.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.0a_pk3`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.0a_pk3_bl17`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.0f`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1_pk3_bl17`,
        fs:  `cpe:2.3:a:mozilla:firefox:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1_pk4_bl18`,
        fs:  `cpe:2.3:a:skype:skype:2.6.0.97:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1_pk5`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.13.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1_pk5_bl19`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1_pk6_bl20`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1a`,
        fs:  `cpe:2.3:a:ninjaforge:com_ninjaxplorer:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1a_pk1_bl1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1a_pk2_bl2`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1a_pk3_bl3`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1a_pk4_bl21`,
        fs:  `cpe:2.3:a:exim:exim:4.80.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1a_pk5_bl23`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_os_deployment:5.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1b`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:1.7.2007.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1b_pk1_bl1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.11.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:compaq:tru64:5.1b_pk2_bl22`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:trucluster:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:trucluster:1.5`,
        fs:  `cpe:2.3:a:ni:labwindows:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:version_control_agent:-`,
        fs:  `cpe:2.3:a:mod_nss_project:mod_nss:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:version_control_agent:1`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:7.4.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compaq:web-enabled_management:-`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compfight_project:compfight:1.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:componentone:flexgrid:-`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:componentone:flexgrid:7.1`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:componentone:flexgrid:7.1_light`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:componentone:sizerone:8.0.20081.140`,
        fs:  `cpe:2.3:o:juniper:junos:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:componentone:vsflexgrid:7.0.1.151`,
        fs:  `cpe:2.3:a:cognos:rich_client_framework:8.4.4486.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:componentone:vsflexgrid:8.0.20072.239`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compuware:applicationvantage_agent:10.2.277`,
        fs:  `cpe:2.3:h:y-cam:ycblb3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:compuware:servervantage_agent:10.2.734`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:conceptronic:c54apm:v2`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conceptronic:c54apm_firmware:1.26`,
        fs:  `cpe:2.3:a:ca:brightstor_hierarchical_storage_manager:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:conceptronic:cipcamptiwl:1.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conceptronic:cipcamptiwl_1.0_firmware:21.37.2.49`,
        fs:  `cpe:2.3:a:hp:laserjet_p3010_series_screen_fonts:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concord:ehealth_console:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concord:ehealth_trapexploder:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concord:ehealth_trapexploder:1.3`,
        fs:  `cpe:2.3:a:jellytap:free_app_icons_\&amp;_icon_packs:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.5.0:-:-:en-us`,
        fs:  `cpe:2.3:a:redaxo:redaxo:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.5.1:-:-:en-us`,
        fs:  `cpe:2.3:a:vmware:workstation:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.5.1:-:-:ja-jp`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.5.2:-:-:en-us`,
        fs:  `cpe:2.3:a:opnet:license_server:16.0.0.10353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.5.2:-:-:ja-jp`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.5.2.1:-:-:en-us`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.5.2.1:-:-:ja-jp`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.0:-:-:en-us`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.0.1:-:-:en-us`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.0.2:-:-:en-us`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.1`,
        fs:  `cpe:2.3:a:cisco:videoscape_delivery_system_for_internet_streamer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.1.2`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.2`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.2.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.3`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.3.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.3.3`,
        fs:  `cpe:2.3:a:perl:perl:5.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.6.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.22:pre10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.7.3.1`,
        fs:  `cpe:2.3:a:apache:subversion:0.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concrete5:concrete5:5.8.1.0`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concursive:concursive:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concursive:modsim_connected:2::~~~android~~`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:concursive:vermont_powder:4.1::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.2.0`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.2.1`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.2.2`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.2.3`,
        fs:  `cpe:2.3:a:coreftp:core_ftp_le:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.2.4`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.50.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.2.5`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.3.0`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.3.1`,
        fs:  `cpe:2.3:a:google:search_appliance_software:7.2.0.g.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.3.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_hpc_node_eus:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.4.0`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.4.1`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.6100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.4.2`,
        fs:  `cpe:2.3:o:hp:jg835a:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.5.4`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.0`,
        fs:  `cpe:2.3:a:iojs:io.js:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.3`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.4`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:unstable5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.6`,
        fs:  `cpe:2.3:h:hp:procurve_router:jc147a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.7`,
        fs:  `cpe:2.3:a:juniper:vpn:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.8`,
        fs:  `cpe:2.3:a:google:chrome:12.0.701.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.9`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.6.10`,
        fs:  `cpe:2.3:a:sap:bi_universal_data_integration:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.7.0`,
        fs:  `cpe:2.3:a:cdsoft:cdsoft:0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.7.1`,
        fs:  `cpe:2.3:a:microsoft:publisher:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.7.2`,
        fs:  `cpe:2.3:h:okidata:c5400_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.7.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.7.4`,
        fs:  `cpe:2.3:a:boeing:drs_data_courier_web:2.14.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.7.5`,
        fs:  `cpe:2.3:a:busybox:busybox:0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.7.6`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.8.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.8.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.8.2`,
        fs:  `cpe:2.3:a:symantec:system_center:10.1.6000.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.8.3`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.8.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.8.5`,
        fs:  `cpe:2.3:a:hp:openview_select_access:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:7.9.0`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condor_project:condor:8.0.0`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper:9.0.532::~~server_standard~~~`,
        fs:  `cpe:2.3:a:oracle:jre:6.0:update_141:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper:10.0.593::~~server_enterprise~~~`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper:10.0.593::~~server_standard~~~`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper:10.0.608::~~server_enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper:10.0.608::~~server_standard~~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.26:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2007:11.0.703.32::~~server~~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2007:11.0.709.32::~~server~~~`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2008:12.0.758.32::~~server~~~`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2008:12.0.781.32::~~server~~~`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2008:12.0.781.64::~~server~~~`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2009:13.0.835.32::~~server~~~`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2009:13.0.835.64::~~server~~~`,
        fs:  `cpe:2.3:a:mcafee:virusscan_mobile_enterprise:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2009:13.0.844.32::~~server~~~`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.5:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2009:13.0.844.64::~~server~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2010:14.0.896.64::~~server~~~`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.14.276:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2010:14.0.903.32::~~server~~~`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2010:14.0.903.64::~~server~~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2010:14.0.909.32::~~professional~~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(4\)sv1\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2010:14.0.913.64::~~professional~~~`,
        fs:  `cpe:2.3:a:corel:coreldraw_ipm:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2010:14.0.913.64::~~server~~~`,
        fs:  `cpe:2.3:a:nuuo:crystal:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2011:15.0.954.64::~~server~~~`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:condusiv:diskeeper_2011:15.0.956.32::~~pro_premier~~~`,
        fs:  `cpe:2.3:a:nq:antivirus_free:7.2.16.02:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:conectiva:ecommerce:-`,
        fs:  `cpe:2.3:a:otrs:otrs:0.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:-`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_management_foundation:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:1.0.0`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:4.0`,
        fs:  `cpe:2.3:a:canon:mp_navigator_ex:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:4.0es`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)da1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:4.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:4.2`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:5.0`,
        fs:  `cpe:2.3:a:autodesk:autodesk_backburner:2016.0.0.2150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:5.1`,
        fs:  `cpe:2.3:a:umn:mapserver:4.4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:6.0`,
        fs:  `cpe:2.3:a:redmine:redmine:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:8.0`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:7.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:9.0`,
        fs:  `cpe:2.3:a:radware:fireproof:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:10`,
        fs:  `cpe:2.3:a:google:v8:3.22.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:10.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:ecommerce`,
        fs:  `cpe:2.3:a:corel:painter:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:graficas`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(6\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:conectiva:linux:prg_graficos`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7970g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conga:conga:-`,
        fs:  `cpe:2.3:a:analog:soundmax:5.12.02.5280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.1`,
        fs:  `cpe:2.3:a:roxio:express_labeler:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.2`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.91:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.3.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.3.1`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.3.2`,
        fs:  `cpe:2.3:a:symantec:installation_manager:7.1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.3.3`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.3.4`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.3.5`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.0`,
        fs:  `cpe:2.3:a:avaya:predictive_dialer_system:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.1`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.2`,
        fs:  `cpe:2.3:o:juniper:junos:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.3`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:31.6.6086:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.4`,
        fs:  `cpe:2.3:a:shopware:shopware:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.5`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.6`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.7`,
        fs:  `cpe:2.3:a:gnu:automake:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.8`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1230ag:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.4.9`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.5.1`,
        fs:  `cpe:2.3:a:apache:batik:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.6.0`,
        fs:  `cpe:2.3:a:web2py:web2py:1.81.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.6.1`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.7.0`,
        fs:  `cpe:2.3:a:samba:samba:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.7.1`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.7.1.1`,
        fs:  `cpe:2.3:a:nancy_wichmann:sitedoc:6.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.7.2`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.8.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.0\(108\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conky:conky:1.8.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0077:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.0`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.11.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.1`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.2`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.5`,
        fs:  `cpe:2.3:a:tinytap:math_for_kids_-_subtraction:1.2.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.6`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.9:*:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.7`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.8`,
        fs:  `cpe:2.3:a:cafuego:simple_document_management_system:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.9`,
        fs:  `cpe:2.3:o:debian:debian_linux:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.9.1`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:rc3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.10`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.11`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-400_cpu_412-2_pn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:1.12`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.0`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.0.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.1`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.1.1`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:f9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.4`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.5`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.6`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.7`,
        fs:  `cpe:2.3:a:isc:bind:8.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.8`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.9`,
        fs:  `cpe:2.3:a:phplist:phplist:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.10`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.10.1`,
        fs:  `cpe:2.3:a:solarwinds:netflow_realtime:10.7.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.11.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.12.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.13.0`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.1.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.13.1`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.14`,
        fs:  `cpe:2.3:a:rpm:rpm:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.15`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.15.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.15.2`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.16`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.20:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.17`,
        fs:  `cpe:2.3:a:autodesk:autocad:2005:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.17.1`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.17.2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.18`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.18.1`,
        fs:  `cpe:2.3:a:ni:lookout:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.18.2`,
        fs:  `cpe:2.3:a:rgsmartapps:colormania_-_color_quiz_game:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.19`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.19.1`,
        fs:  `cpe:2.3:a:isc:bind:9.6.1:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.20`,
        fs:  `cpe:2.3:o:microsoft:windows_2000_terminal_services:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.21`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.22`,
        fs:  `cpe:2.3:a:bluemarblegeo:global_mapper:14.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.22.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je090a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.23`,
        fs:  `cpe:2.3:a:apple:itunes:12.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.24`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.25`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.26`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:2.26.1`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.0`,
        fs:  `cpe:2.3:a:php:pear:1.0b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.1`,
        fs:  `cpe:2.3:a:apple:java_1.4:2:16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.1.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.55.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sce:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.2.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.2.2`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.3`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.4`,
        fs:  `cpe:2.3:a:pocoproject:poco_c\&#43;\&#43;_libraries:1.4.6:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.6`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.7`,
        fs:  `cpe:2.3:a:mybb:mybb:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.8`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.8.1`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.8.2`,
        fs:  `cpe:2.3:a:oracle:industry_applications:10.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.9`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.9.1`,
        fs:  `cpe:2.3:a:quantum:quantum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.9.2`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:3.10`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.0`,
        fs:  `cpe:2.3:a:hp:proliant_smart_array_device_manager_extension:6.2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.0.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.1.1`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.2`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.3`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.3.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.5`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.6`,
        fs:  `cpe:2.3:a:keepass:keepass:0.98:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.8`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.9`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.10`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.11`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.11.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.11.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.12`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)ea4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.13`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:50.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.13.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.1:-:surround:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.14`,
        fs:  `cpe:2.3:o:asus:rt-n65u_firmware:3.0.0.4.342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.15`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.15.1`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.16`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.15:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.16.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.16.2`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.17`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.18`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.19`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.20`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.21`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.22`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.23`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.24`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.25`,
        fs:  `cpe:2.3:a:debian:apt:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.26`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.27.5031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.26.1`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.27`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.27.1`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.28`,
        fs:  `cpe:2.3:a:vmware:esx_server:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.29`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.30`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:15.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.31`,
        fs:  `cpe:2.3:h:hp:designjet_5500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.31.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jpc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.32`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.33`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.34`,
        fs:  `cpe:2.3:a:gnu:glibc:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.34.1`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.34.2`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connect2id:nimbus_jose%2bjwt:4.35`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.4`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.7`,
        fs:  `cpe:2.3:a:carbonite:online_backup_setup:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.8`,
        fs:  `cpe:2.3:a:mark_evans:fog-dragonfly:0.8.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.9`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.10`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.11`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_xi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.22`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)xc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.23`,
        fs:  `cpe:2.3:a:tridentsw:powerzip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.2.24`,
        fs:  `cpe:2.3:a:perl:perl:5.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.3.2`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.3.3`,
        fs:  `cpe:2.3:a:serf_project:serf:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.5.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.7.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.5.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.5.47`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.5.48`,
        fs:  `cpe:2.3:a:sun:iplanet_messaging_server_messenger_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)mra2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.6.2`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ebw:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.6.2.1`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.0.0`,
        fs:  `cpe:2.3:a:hp:solution_center:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.326:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.0.2`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.4\(1\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.0.3`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.0.4`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2010:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.1.1`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.1.2`,
        fs:  `cpe:2.3:a:agilebits:knox:2.0.0:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.1.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.1.4`,
        fs:  `cpe:2.3:a:plataformatec:devise:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.1.5`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.1.6`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.2.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p68:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.2.2`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.2.3`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.3.14s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.2.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.2.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.2.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(9a\)bc7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.2.7`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a1:7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.3`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.3.2`,
        fs:  `cpe:2.3:a:magzter:menaka_-_marathi:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.3.4`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp6:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connections_project:connections:0.7.3.5`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5:beta_pr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connectiva:linux:-`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:11.10c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connectiva:linux:6.0`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connectiva:linux:7.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.50.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connectiva:linux:8.0`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:connman:connman:1.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conntrack-tools_project:conntrack-tools:1.4.2`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cononical:ubuntu:14.10`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:conrad_hotel_project:conrad_hotel:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p72:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:consona:servicedesk_online:11.0`,
        fs:  `cpe:2.3:a:x.org:libx11:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:construtiva:cis_manager_cms:-`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.425a:mr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:consulo:ip_alarm:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:hp:serviceguard:a.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactgenie:contactgenie_exporter_basic:1.1.21`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2610-24\/12pwr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ford:ford_credit_account_manager:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0.3\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:ocr_software_by_i.r.i.s:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contactus:contact_form_7_integrations:1.3.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:vista:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.0:beta-rc1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.0:beta-rc2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.0:beta-rc3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.1`,
        fs:  `cpe:2.3:a:php:php:5.6.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.2`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator_installer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.3`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.4`,
        fs:  `cpe:2.3:o:hp:thinpro:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.6`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_secureway_policy_director:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.8`,
        fs:  `cpe:2.3:a:adobe:pagemaker:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.9`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.10`,
        fs:  `cpe:2.3:a:sprint:smartview:2.27.64.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.11`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.12`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.13`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2003_server:6.3.1702:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.14`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.15`,
        fs:  `cpe:2.3:h:nortel:vpn_router_1750:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.16`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.17`,
        fs:  `cpe:2.3:a:schneems:wicked:0.1.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.18`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.19`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.20`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:5.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.21`,
        fs:  `cpe:2.3:a:rpm:rpm:4.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.1.22`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.0`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.1`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3:rc_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.3`,
        fs:  `cpe:2.3:h:ibm:storwize_v3500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.4`,
        fs:  `cpe:2.3:a:nokia:affix:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.5`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.6`,
        fs:  `cpe:2.3:h:linksys:befw11s4_v4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.8`,
        fs:  `cpe:2.3:a:appnitro:machform:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.9`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.10`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.11`,
        fs:  `cpe:2.3:a:shopware:shopware:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.2.12`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.3.0`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.6203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.3.1`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.3.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:6.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.3.3`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.3.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.332:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4:beta`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.1:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4.0`,
        fs:  `cpe:2.3:a:reality66:cart66_lite:1.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4.1`,
        fs:  `cpe:2.3:h:huawei:honor_6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4.2`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4.3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4.4`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4.5`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4.6`,
        fs:  `cpe:2.3:a:web2py:web2py:1.81.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.4.7`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5:beta`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5:beta-rc2`,
        fs:  `cpe:2.3:a:utorrent:utorrent:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.0`,
        fs:  `cpe:2.3:a:yahoo:messenger:11.0.0.2014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.1`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.2`,
        fs:  `cpe:2.3:a:apache:subversion:0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.3`,
        fs:  `cpe:2.3:h:ibm:system_x3690_x5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.5`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.6`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.7`,
        fs:  `cpe:2.3:a:apache:org.apache.sling.servlets.post:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.8`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.5.9`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_upgrade_tool:10.0.11639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6:beta`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_21.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6:beta2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.1`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.2`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.3`,
        fs:  `cpe:2.3:a:symantec:norton_pc_checkup:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.4`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:9.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.6`,
        fs:  `cpe:2.3:a:google:v8:3.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.7`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.6.8`,
        fs:  `cpe:2.3:a:apple:itunes:11.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7:rc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7:rc2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7.0`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7.2`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7.3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7.4`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.4p4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7.5`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7.6`,
        fs:  `cpe:2.3:a:huge-it:image_gallery:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.7.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.8:rc1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.8:rc2`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:9.0.48.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.8.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:10.5\(1.98991.13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.8.1`,
        fs:  `cpe:2.3:a:apache:knox:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.8.2`,
        fs:  `cpe:2.3:a:rsa:authentication_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.8.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.8.4`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.9:beta1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.9:rc1`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.9.0`,
        fs:  `cpe:2.3:a:oracle:interaction_blending:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.9.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.9.2`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.9.3`,
        fs:  `cpe:2.3:a:ienvisage:pakistan_cricket_news:1.21.38.6504:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.9.4`,
        fs:  `cpe:2.3:a:cisco:intercloud_fabric:2.3.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.9.5`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.10:beta1`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.1.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.10:rc1`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:5.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.10.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.10.1`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contao:contao_cms:2.10.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sg.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contenido:contendio:4.9.0`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contenido:contendio:4.9.1`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contenido:contendio:4.9.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contenido:contendio:4.9.3`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contenido:contendio:4.9.4`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x48:d15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contenido:contendio:4.9.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contenido:contendio:4.9.6`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_for_.net_framework_2.0:10.2.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:justsystems:ichitaro_viewer:20.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:v8:3.22.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:management_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:symantec:netbackup_opscenter:7.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_construction_kit_project:content_construction_kit:6.x-2.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_rating_extbase_project:content_rating_extbase:2.0.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:novell:libzypp:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:content_rating_project:content_rating:1.0.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:contentlion:contentlion_alpha:1.3`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:context_project:context:7.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:context_project:context:7.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12c\)ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:context_project:context:7.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.9.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:context_project:context:7.x-3.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:news_project:news:3.2.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:context_project:context:7.x-3.4::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:context_project:context:7.x-3.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.1.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2005:0`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:sp3_alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2005:1.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u2\(2c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2007:0`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management:9.1:*:*:*:collaborative:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2007:0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p225:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2007:0.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:17.011.30066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2007:1.0`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2007:1.1`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:5.2.1:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2007:1.2`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2007:1.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(2\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2007:1.4`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2009:1.0`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.18.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2009:1.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2009:1.2`,
        fs:  `cpe:2.3:a:namazu:namazu:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2009:1.3`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2009:2.0`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2009:2.1`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:controlmicrosystems:clearscada_2009:2.2`,
        fs:  `cpe:2.3:o:cisco:staros:11.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.601.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.612.0`,
        fs:  `cpe:2.3:h:huawei:me60:v600r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.623.0`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.720.0`,
        fs:  `cpe:2.3:a:siemens:wincc:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.801.0`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.813.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.901.0`,
        fs:  `cpe:2.3:o:redhat:desktop_workstation:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.3540.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.3560.0`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.0.3580.0`,
        fs:  `cpe:2.3:a:adobe:after_effects:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.1.3600.0`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.1.3674.0`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.1.3700.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.2.3730.0`,
        fs:  `cpe:2.3:a:redmine:redmine:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.2.3800.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.4.3820.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.010.20060:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.4.3830.0`,
        fs:  `cpe:2.3:a:cybozu:office:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.4.3850.0`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:5.5.1302.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.4.3860.0`,
        fs:  `cpe:2.3:a:cybozu:garoon:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.4.3880.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.4.3900.0`,
        fs:  `cpe:2.3:a:drupal:drupal:7.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.4.4000.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.315:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.7.4050.0`,
        fs:  `cpe:2.3:h:hp:officejet_7300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:1.7.5000.0`,
        fs:  `cpe:2.3:a:compaq:intelligent_cluster_administrator:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.0.4115.0`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.0.4115.1`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.1.4386.0`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.1.4560.0`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.5.4770.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp1:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.5.4770.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.5.4912.0`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.5.5050.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:controlsystemworks:csworks:2.5.5233.0`,
        fs:  `cpe:2.3:a:crunchify:all-in-on-webmaster:7.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:convergine:file_king_advanced_file_management:1.4`,
        fs:  `cpe:2.3:a:lucent:vitalsuite:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:convert-in:pdf-to-word:3.1_demo`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cookpad:android_activities:1.5.16`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_row:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cookpad:android_activities:1.5.17`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cookpad:android_mykitchen:1.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cookpad:android_mykitchen:1.1.2`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.01:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cool_video_gallery_project:cool_video_gallery:1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coolpdf:coolpdf:3.0.2.256`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cooperindustries:dnp3_master_opc_server:-`,
        fs:  `cpe:2.3:h:linksys:wap11:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cooperindustries:smp_16_gateway_%28data_concentrator%29:-`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.0.241.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cooperindustries:smp_4%2fdp_gateway_%28data_concentrator%29:-`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:cooperindustries:smp_4_gateway_%28data_concentrator%29:-`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2010:-:government:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:copadata:zenon_dnp3_ng_driver:7.10`,
        fs:  `cpe:2.3:a:yahoo:music_jukebox:2.2.2.056:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:copadata:zenon_dnp3_ng_driver:7.11:-`,
        fs:  `cpe:2.3:a:divx:player:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:copadata:zenon_dnp3_ng_driver:7.11:sp0_build_10238`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:copadata:zenon_dnp3_process_gateway:7.11:sp0_build_10238`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_set:07-50-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.0`,
        fs:  `cpe:2.3:a:canon:canoscan_toolbox:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.0:rc3`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.1`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:3400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.1:beta_2`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.1.0`,
        fs:  `cpe:2.3:a:ad-minister_project:ad-minister:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.2`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.2.0`,
        fs:  `cpe:2.3:a:plone:plone:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.2.0:rc2`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.2.1`,
        fs:  `cpe:2.3:a:eventsentry:eventsentry:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.2.1:b`,
        fs:  `cpe:2.3:a:oracle:communications_eagle_local_number_portability_application_processor:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.2.1:b-nuke`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd332a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.3.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.3.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.3.2`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.3.3`,
        fs:  `cpe:2.3:o:yahama:rta52i:3.06.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.3.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.3.5`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4:beta`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.0`,
        fs:  `cpe:2.3:a:php:php:5.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.0:alpha`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.0:beta`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.61:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.03.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.1:beta`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.2`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.3`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.4`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.5`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.6`,
        fs:  `cpe:2.3:a:hp:tcp_ip_services_openvms:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.7`,
        fs:  `cpe:2.3:a:debian:dpkg:1.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.8`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.4:rc3:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.9`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(4i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.10`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.11`,
        fs:  `cpe:2.3:a:novell:netware_client:4.91:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.12`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1280.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.13`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.14`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.16`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.17`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.3.1:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.18`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.19`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.20`,
        fs:  `cpe:2.3:a:lucent:vitalnet:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.21`,
        fs:  `cpe:2.3:h:hp:b5l07a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.22`,
        fs:  `cpe:2.3:a:oracle:oracle_and_sun_systems_product_suite:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.23`,
        fs:  `cpe:2.3:a:ipposan:memetan:1.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.24`,
        fs:  `cpe:2.3:a:splunk:splunk:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.25`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.26`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.4.27`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.1:alpha`,
        fs:  `cpe:2.3:o:apple:apple_tv:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.2:beta`,
        fs:  `cpe:2.3:a:boa:boa:0.94.14.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.3:rc`,
        fs:  `cpe:2.3:a:codesector:teracopy:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.4`,
        fs:  `cpe:2.3:a:psyced:psyced:20090617:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.6`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.8`,
        fs:  `cpe:2.3:a:phorum:phorum:3.3.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.10`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.12`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.0.4.0\(21\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.14`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.16`,
        fs:  `cpe:2.3:a:citrix:xenapp_server_role_manager:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.18`,
        fs:  `cpe:2.3:a:x:libxtst:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.20`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.34`,
        fs:  `cpe:2.3:a:vips:vips:7.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coppermine-gallery:coppermine_photo_gallery:1.5.36`,
        fs:  `cpe:2.3:a:google:v8:3.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:aihce_2014:6.1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:bowl_expo_2014:6.1.1.5::~~~android~~`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:digital_content_newfronts_2014:6.0.7.6::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2003:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:eage_amsterdam_2014:6.1.1.2::~~~android~~`,
        fs:  `cpe:2.3:h:huawei:ar_19\/29\/49:r2207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:ira%27s_59th_annual_conference:6.0.7.6::~~~android~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp10:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:ismrm-esmrmb_2014:6.0.8.5::~~~android~~`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.8.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:ohbm_20th_annual_meeting:6.0.9.2::~~~android~~`,
        fs:  `cpe:2.3:a:acquia:commons:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:rims_2014_annual_conference:6.0.7.4::~~~android~~`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:core-apps:vmware_vforums_2014:6.0.9.4::~~~android~~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:ga:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coreftp:core_ftp:1.2`,
        fs:  `cpe:2.3:h:hp:3com_switch:4200g-ntg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coreftp:core_ftp:2.1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coreftp:core_ftp:2.2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coreftp:core_ftp_le:2.1`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:corega:cg-wlbaragm_firmware:-`,
        fs:  `cpe:2.3:a:airdroid:airdroid:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:corega:cg-wlbargmh:-`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:corega:cg-wlbargmh_firmware:-`,
        fs:  `cpe:2.3:a:sendmail:message_store_sams:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:corega:cg-wlbargnl:-`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:corega:cg-wlbargnl_firmware:-`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:corega:cg-wlbargs_firmware:-`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:corega:cg-wlncm4g_firmware:-`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:activecgm_browser:-`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:corelcad:2014`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw:11`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw:12`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw:x3`,
        fs:  `cpe:2.3:a:funny_photo_color_editor_project:funny_photo_color_editor:0.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw:x4`,
        fs:  `cpe:2.3:a:splunk:splunk:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw:x5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_capture:x4`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.11.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_content:x4`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_draw:x4`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_filters:x4`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:9.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_fontnav:x4`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.1.0-110.sles10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_ica:x4`,
        fs:  `cpe:2.3:a:nagios:nagios:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_ipm:x4`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_lang_br:x4`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_lang_en:x4`,
        fs:  `cpe:2.3:a:samba:samba:4.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_lang_es:x4`,
        fs:  `cpe:2.3:a:google:chrome:4.0.261.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_lang_fr:x4`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.6234:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_photo_paint:x4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_visual_basic_for_applications:6.2`,
        fs:  `cpe:2.3:a:php:xhprof:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_visual_basic_for_applications:x4`,
        fs:  `cpe:2.3:a:iscripts:easybiller:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:coreldraw_windows_shell_extension:x4`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:fastflick:-`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:fontnav:5.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:iconhandler:2.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:corel:linux:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:corel:linux:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_photo_album:5.21`,
        fs:  `cpe:2.3:a:hp:business_availability_center:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro:-`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro:6.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro:7.0.0`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro:7.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro:8.0.0`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro:8.10.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro:11.20`,
        fs:  `cpe:2.3:a:kvirc:kvirc:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro_studio:1.0.0::~~dell~~~`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_supportcenter_plus:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paint_shop_pro_studio:1.0.0::~~dell_editon~~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter:11.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.6.602.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter:11.2`,
        fs:  `cpe:2.3:a:isode:m-link:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter:12.0`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter:12.1`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter:2015`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter_ica:11.0`,
        fs:  `cpe:2.3:a:zenprise:zenprise_device_manager:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter_ipm:11.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_base_services:7.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter_ipm:11.2`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:painter_ix:9.50`,
        fs:  `cpe:2.3:a:lsoft:listserv:1.8c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paintshop_pro_x5:15.2.0.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paintshop_pro_x5:16.0.0.113`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.05\/22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paintshop_pro_x6:15.2.0.2`,
        fs:  `cpe:2.3:a:myheritage:sequeryobject_activex_control:1.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:paintshop_pro_x6:16.0.0.113`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:pdf_fusion:1.11`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_ops_center:12.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:quattro_pro_x6:16.0.0.388::~~standard~~~`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:11.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:shell_extension:14.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:update_manager:4.60`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:videostudio_pro:x7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:wordperfect:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:wordperfect:8`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:wordperfect:11`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:wordperfect:12`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:wordperfect:13.0.0.565`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:wordperfect:2002`,
        fs:  `cpe:2.3:h:hp:jg410a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:wordperfect:x3`,
        fs:  `cpe:2.3:a:oracle:reports:10g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corel:wordperfect_office:11.0.0.233`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corestreet:certificate_validation_software:-`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc3300:a6900a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corner_project:corner:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.231:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corosync:corosync:2.0.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corosync:corosync:2.0.1`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corosync:corosync:2.0.2`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corosync:corosync:2.0.3`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corosync:corosync:2.1.0`,
        fs:  `cpe:2.3:a:debian:apt:0.7.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corosync:corosync:2.1.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corosync:corosync:2.2.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corosync:corosync:2.3.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:corporater:epm_suite:-`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cosmoshop:cosmoshop:-`,
        fs:  `cpe:2.3:a:jenkins:git:3.3.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:cososys:endpoint_protector:4.3.0.4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cososys:endpoint_protector:4.4.0.2`,
        fs:  `cpe:2.3:a:apache:axis:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.0`,
        fs:  `cpe:2.3:a:roderick_braun:ya_googlesearch:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.1`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.2`,
        fs:  `cpe:2.3:a:polycom:rss_system_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.3`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.4`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.5`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p171:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.7`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.8`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.9`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:10.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.10`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p396:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.12`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.1.1:-:-:-:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cotonti:cotonti_siena:0.9.13`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.37:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:counterintuition:counter_intuition:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:-:compact:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:couponcabin_-_coupons_%26_deals_project:couponcabin_-_coupons_%26_deals:3.6::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:couponphp:couponphp:1.1.0`,
        fs:  `cpe:2.3:a:emc:networker:7.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:coupons:coupon_printer_for_windows:5.0.0.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:courion:access_risk_management_suite:8.0:9`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:courseforum:projectforum:7.0.1.3038`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:covechurch:cove:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:covetfashion:covet_fashion_-_shopping_game:2.14.40::~~~android~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.12:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cp_multi_view_event_calendar_project:cp_multi_view_event_calendar:1.0.1::~~wordpress~~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cpe17:autorun_killer:1.7.1`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cpe17:autorun_killer:1.8.6`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cpuid:cpu-z:1.53.1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cpuminer_project:cpuminer:2.4.0`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cracklib_project:cracklib:-`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_barratt:backuppc:3.0.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1678.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_barratt:backuppc:3.1.0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_barratt:backuppc:3.2.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_barratt:backuppc:3.2.1`,
        fs:  `cpe:2.3:a:emc:networker:8.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.7.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.7.1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.8.0`,
        fs:  `cpe:2.3:a:ibm:packaging_utility:1.8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.8.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:0.080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.8.2`,
        fs:  `cpe:2.3:a:atmail:atmail:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.8.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.8.3.1`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.9.0`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.9.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:0.9.2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.0.1`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.0.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(4\)sv1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.0.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.4:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.1.0`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.1.1`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.1.2`,
        fs:  `cpe:2.3:h:lexmark:e23x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.1.3`,
        fs:  `cpe:2.3:a:justin_klein:wp-vipergb:1.3.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.2.0`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.2.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_drummond:cantata:1.2.2`,
        fs:  `cpe:2.3:a:modpagespeed:mod_pagespeed:0.10.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.0:rc2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.0:rc3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.1.1`,
        fs:  `cpe:2.3:a:k7computing:k7av_sentry_device_driver:12.8.0.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.1.2`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3a12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.1.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.604:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.1.4`,
        fs:  `cpe:2.3:a:c-icap_project:c-icap:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.1.5`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:4.0.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.1.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2:b1`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.5:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2.0`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2.1`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.13.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2.2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2.3`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2.4`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2.5`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2.6`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-6520c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_knudsen:webcalendar:1.2.7`,
        fs:  `cpe:2.3:a:hp:web_registration:110.0.180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:craig_peterson:turbopower_abbrevia:3.05`,
        fs:  `cpe:2.3:a:microsoft:psexec:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cramerdev:document_library:5.8.5`,
        fs:  `cpe:2.3:h:sun:storedge_6130_arrays:06.12.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:2.0.0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:2.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:2.1.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(8b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:2.2.0`,
        fs:  `cpe:2.3:a:symantec:on_command_ccm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:2.3.0`,
        fs:  `cpe:2.3:a:sqlite:sqlite:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:2.4.0`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:2.4.5`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.338:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.0.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.20:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.0.0:rc2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.0.0:rc3`,
        fs:  `cpe:2.3:a:tridium:niagra_ax_framework:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.0.0:rc4`,
        fs:  `cpe:2.3:h:fortinet:fortigate-3810a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.0.0:rc5`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.0.0:rc6`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.12.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.1.0`,
        fs:  `cpe:2.3:a:apple:itunes:8.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.2.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.2.0:rc4`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.2.0:rc5`,
        fs:  `cpe:2.3:a:opsview:opsview:3.8:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.2.0:rc7`,
        fs:  `cpe:2.3:a:cisco:nac_agent:4.7.1.511:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.2.0:rc8`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.3.0`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.3.0:rc1`,
        fs:  `cpe:2.3:a:gnu:glibc:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.3.0:rc2`,
        fs:  `cpe:2.3:a:hp:product_assistant:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.3.1`,
        fs:  `cpe:2.3:a:endian:firewall:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.5.0`,
        fs:  `cpe:2.3:a:novell:netware_client:4.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.5.0:beta1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.5.0:beta2`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.2:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.5.0:rc1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.5.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.5.0:rc3`,
        fs:  `cpe:2.3:a:altiris:software_delivery_for_mac_documentation:6.1.1020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.5.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.6.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.5.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p366:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.6.0`,
        fs:  `cpe:2.3:a:datadynamics:activereports:2.5.0.1314:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.6.0:beta1`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.6.0:rc1`,
        fs:  `cpe:2.3:a:docker:docker:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawlability:vbseo:3.6.0:rc2`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:95:osr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.0.1`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.0.2`,
        fs:  `cpe:2.3:a:microsoft:ie:5.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.1.0`,
        fs:  `cpe:2.3:a:intel:proset_wireless:13.1.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.1.1`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.2.0`,
        fs:  `cpe:2.3:h:hp:laserjet_9000mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.3.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.3.1`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.4.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.15.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.4.1`,
        fs:  `cpe:2.3:o:asus:rt-n66u_firmware:3.0.0.4.272:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(26\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.5.1`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.6.0`,
        fs:  `cpe:2.3:a:vmware:workstation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.7.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:1.7.1`,
        fs:  `cpe:2.3:a:ca:license_software:1.90.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:2.0.0`,
        fs:  `cpe:2.3:a:isc:bind:9.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:2.1.0`,
        fs:  `cpe:2.3:h:schneider_electric:sage_1430:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:2.2.0`,
        fs:  `cpe:2.3:a:janetter:janetter:3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:2.2.1`,
        fs:  `cpe:2.3:a:atlassian:jira:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:2.3.0`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.0.0`,
        fs:  `cpe:2.3:o:sun:solaris:1.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.1.0`,
        fs:  `cpe:2.3:a:paloaltonetworks:globalprotect:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.1.1`,
        fs:  `cpe:2.3:a:quest:spotlight_on_oracle:6.1.0.1433:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.1.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.3d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.1.3`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5101:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.3`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.4`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.23pi_ia_host_agent_files:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.5`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.6:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.6`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.0:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.8`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.2.9`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crawltrack:crawltrack:3.3.0`,
        fs:  `cpe:2.3:a:horde:groupware:5.0.0:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:-`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:6.0`,
        fs:  `cpe:2.3:a:marconi:forethought:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:6.0e`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.511:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:6.1`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:5.x-1.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:7.0`,
        fs:  `cpe:2.3:a:cisco:expressway:x8.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:8.0`,
        fs:  `cpe:2.3:a:ipswitch:imail:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:8.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:9.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.6:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:9.0.2.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:9.0.2.5`,
        fs:  `cpe:2.3:a:netscape:navigator:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:9.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:9.2.0.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos:9.2.4`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos_lc:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ewa4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos_max:1.3`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos_max:1.3.0.5`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cray:unicos_mk:-`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crazybrowser:crazybrowser:1.0.5`,
        fs:  `cpe:2.3:a:typo3:typo3:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crazybrowser:crazybrowser:2.0.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crazybrowser:crazybrowser:3.0.0`,
        fs:  `cpe:2.3:a:apple:itunes:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crea8social:crea8social:2.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crear.ne.jp:al-mail32:1.01`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crear.ne.jp:al-mail32:1.10`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crear.ne.jp:al-mail32:1.11`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crear.ne.jp:al-mail32:1.12`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crear.ne.jp:al-mail32:1.13`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crear.ne.jp:al-mail32:1.13:a`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crear.ne.jp:al-mail32:1.13:c`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crear.ne.jp:al-mail32:1.13:d`,
        fs:  `cpe:2.3:a:last:last.fm:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:createdineden:buy_yorkshire_conference:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.329:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:creatingahaven:compassion_satisfaction:0.75.13440.35155::~~~android~~`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:creative_core:app_lock:1.6.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.370:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:creative_core:app_lock:1.7.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:creative_core:app_lock:1.7.5`,
        fs:  `cpe:2.3:a:busybox:busybox:0.60.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:creative_core:app_lock:1.7.6`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:creative_core:app_lock:1.7.7`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:creative_minds:cm_download_manager:2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:creston:dm-txrx-100-str:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:creston:dm-txrx-100-str_firmware:1.2866.00026`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crgroup-lb:c.r._group:1::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cristian_gafton:pam_userdb:-`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.12:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:croogo:croogo:2.2.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.8:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cross-rss_plugin_project:wp-cross-rss:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:jd431a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:crossbeamsystems:x40:-`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:crossbeamsystems:x45:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:crossbeamsystems:x80:-`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crossmo:crossmo_calendar:1.7.1::~~~android~~`,
        fs:  `cpe:2.3:a:perl:perl:5.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crossslide_jquery_project:crossslide_jquery:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:cru-inc:ditto_forensic_fieldstation:-`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.5:-:email_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cru-inc:ditto_forensic_fieldstation_firmware:2013jun30a`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.3.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:cru-inc:ditto_forensic_fieldstation_firmware:2013oct15a`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:12.0.0.1548:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crumbs_project:crumbs:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:server_provisioner:6.4.0:patch_3-1208021049:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crumbs_project:crumbs:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crumbs_project:crumbs:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.10.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:all-in-on-webmaster:7.7.7`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:all-in-on-webmaster:8.0.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:all-in-on-webmaster:8.1`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:all-in-on-webmaster:8.2`,
        fs:  `cpe:2.3:a:adobe:robohelp:2015.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:all-in-on-webmaster:8.2.1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:all-in-on-webmaster:8.2.2`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:all-in-on-webmaster:8.2.3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:4.5.3`,
        fs:  `cpe:2.3:a:webgate:webgate_embedded_standard_protocol_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:4.6`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:4.6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:4.7`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:5.0`,
        fs:  `cpe:2.3:a:apache:activemq:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:5.0.1`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:5.0.2`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.5.2.611:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:5.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.1:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:facebook_members:5.0.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.1g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:foursquare-checkins:1.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:foursquare-checkins:1.1`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:foursquare-checkins:1.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:crunchify:foursquare-checkins:1.3`,
        fs:  `cpe:2.3:a:microsoft:grpconv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cryptopp:crypto%2b%2b:5.6.4`,
        fs:  `cpe:2.3:a:debian:apt:0.8.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:.1.3.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:.1.3.2`,
        fs:  `cpe:2.3:a:solarwinds:kiwi_cattools:3.6.0__\(service_edition\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:.1.3.3`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:.1.3.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:1.3.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:1.3.2`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:1.3.3`,
        fs:  `cpe:2.3:a:gnome:glib:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:1.3.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.5`,
        fs:  `cpe:2.3:a:buffalotech:whr-am54g54_firmware:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.6`,
        fs:  `cpe:2.3:a:buffalotech:wer-am54g54_firmware:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.7`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:11.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.9`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.10`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.11`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.4.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.12`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.13`,
        fs:  `cpe:2.3:a:redhat:directory_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.14`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.0.15`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.1`,
        fs:  `cpe:2.3:a:oracle:jai:1.1.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.1.1`,
        fs:  `cpe:2.3:a:redhat:rhel_global_file_system:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.1.2`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.1.3`,
        fs:  `cpe:2.3:a:google:v8:3.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.1.4`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.2.2`,
        fs:  `cpe:2.3:a:adobe:photoshop:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.2.3`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.2.4`,
        fs:  `cpe:2.3:a:quest:spotlight:6.0.0.1325:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:2.2.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:3.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.273:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:3.0.2`,
        fs:  `cpe:2.3:a:emc:networker:8.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:3.0.3`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:3.0.4`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.00:-:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:3.0.5`,
        fs:  `cpe:2.3:a:redhat:jboss_a-mq:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:3.0.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p218:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:4.0`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:4.0.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:4.0.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cs-cart:cs-cart:4.2.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:ddoe_cryptoprovider:1.0.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:ddoeserviceclient:1.5.3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:ddoeserviceclient:1.9.3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:ddoeserviceclient:1.9.4`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:ddoewebservice:1.2.9`,
        fs:  `cpe:2.3:a:apache:commons_email:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:e-tes_scheduled_reminder:2.1.0`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.6.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:mqmonitorinstaller:1.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.521:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:serviceclient:1.2.9`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:ssoserviceclient:1.2.8`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:ssoserviceclient:1.9.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:ssowebservice:1.2.9`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:tsrserviceclient:1.2.8`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:tsrserviceclient:1.6.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:tsrwebservice:1.2.9`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6cce:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csc:xmlwebservice:1.2.9`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:csilvers:gperftools:0.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csilvers:gperftools:0.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csilvers:gperftools:0.3`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.10`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.10.1`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_management_foundation:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.11`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.7:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.11.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p447:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.12`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.12.1`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.12.3`,
        fs:  `cpe:2.3:a:boeing:drs_web_configuration_manager:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.12.4`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.13.0`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0070:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.13.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.14.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.14.1`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.14.2`,
        fs:  `cpe:2.3:a:mobilecraft:bilgi_yarisi:1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.15.0`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.16`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.16.1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.16.6`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.17`,
        fs:  `cpe:2.3:a:hp:application_lifecycle_management:11.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csounds:csound:5.17.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.335:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:1.0`,
        fs:  `cpe:2.3:a:socialknowledge:forest_river_forums:3.7.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:1.0.1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.1`,
        fs:  `cpe:2.3:a:redhat:linux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.2`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.3`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:b.03.01.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.4`,
        fs:  `cpe:2.3:a:yoshinori_tahara:mycaljp:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.5`,
        fs:  `cpe:2.3:h:lenel:lnl-3300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.1.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.1`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.2`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.2.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.3`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.3.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.399:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:csphere:clansphere:2011.4`,
        fs:  `cpe:2.3:h:hp:j9868a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ctb:asvab_preparation:1.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ctb:tabe-pc:-`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ctb:tabe-pc:5.2`,
        fs:  `cpe:2.3:a:ibm:filenet_content_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ctdb_project:ctdb:2.0`,
        fs:  `cpe:2.3:o:f5:tmos:9.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ctdb_project:ctdb:2.1`,
        fs:  `cpe:2.3:a:novell:netmail:3.0.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ctdb_project:ctdb:2.2`,
        fs:  `cpe:2.3:a:adobe:golive:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ctdb_project:ctdb:2.3`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ctihub:ct_ihub:1::~~~android~~`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cts_projects%26software:classad:3.0`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:-`,
        fs:  `cpe:2.3:o:asus:dsl-n56u_firmware:1.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-10:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.2`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:3.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.3`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.4`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-28c-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.5`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.3ye:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.7`,
        fs:  `cpe:2.3:h:hp:laserjet_9050mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7a\)ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.9`,
        fs:  `cpe:2.3:a:apple:safari:3.1.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.10`,
        fs:  `cpe:2.3:a:redhat:analog_real-time_synthesizer:2.1.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.11`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.12`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.13`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.14`,
        fs:  `cpe:2.3:a:extensoft:mfc_runtime_files:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.15`,
        fs:  `cpe:2.3:h:hp:laserjet_enterprise_color_flow_m575c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.16`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.17`,
        fs:  `cpe:2.3:a:ca:single_sign-on:r12.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.18`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p125:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.19`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:3.0.20`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.0.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.0.0:beta2`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.0.0:beta3`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.0.0:rc1`,
        fs:  `cpe:2.3:a:plone:plone:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.0.1`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.0.2`,
        fs:  `cpe:2.3:o:f5:tmos:9.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.0.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.1.0`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.1.0:rc1`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.4.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.1.0:rc2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.1p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.1.1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.2.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.2.1`,
        fs:  `cpe:2.3:a:docker:docker:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.2.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.2.3`,
        fs:  `cpe:2.3:h:motorola:defy_xt:-:-:-:*:-:-:-:republic_wireless`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.0`,
        fs:  `cpe:2.3:a:goahead:goahead_webserver:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.1`,
        fs:  `cpe:2.3:a:pass4sure:questions_and_answers_for_comptia_sy0-301:4.0.13061:*:*:*:demo:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.2`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-01-15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.3`,
        fs:  `cpe:2.3:h:juniper:netscreen-idp:3.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.4`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.5`,
        fs:  `cpe:2.3:a:cacti:cacti:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.6`,
        fs:  `cpe:2.3:a:verizon_instant_refills_24\/7_project:verizon_instant_refills_24\/7:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.7`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.8`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.3.9`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_it360:10.3.3:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:4.4.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.0`,
        fs:  `cpe:2.3:a:google:v8:3.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.16.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.2`,
        fs:  `cpe:2.3:a:libssh:libssh:0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.3`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.5`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.6`,
        fs:  `cpe:2.3:a:adobe:reader:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.7`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.8`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.9`,
        fs:  `cpe:2.3:h:dell:kvm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.12`,
        fs:  `cpe:2.3:a:illinois:ncsa_mosaic:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.13`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.14`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.3:3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:5.2.15`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.49:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:6.0.0`,
        fs:  `cpe:2.3:a:keepass:keepass:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:6.0.1`,
        fs:  `cpe:2.3:a:exim:exim:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:6.0.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:6.0.3`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110621:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:6.0.4`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.0.2:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:6.0.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubecart:cubecart:6.0.6`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubettechnologies:cloud_manager:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubicfactory:cubic_cms:5.1.1`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubicfactory:cubic_cms:5.1.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cubicfactory:cubic_cms:5.2`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cuoftexas:credit_union_of_texas_mobile:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1038.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cuore:help:1.3.5::~~~ec-cube~~`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cupidsystems:cis_webserver:-`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf229a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cupidsystems:cis_webserver:3.5.13`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.2_build_9.0.2.1000:mr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.0.1`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.0.2`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.0.3`,
        fs:  `cpe:2.3:o:thecus:n8800_nas_server_firmware:5.03.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.0.4`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:941p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.1.0`,
        fs:  `cpe:2.3:a:ibm:filenet_panagon:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.1.1`,
        fs:  `cpe:2.3:h:rockwellautomation:ab_micrologix_controller:1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.1.2`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.1.3`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.2.0`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.2.1`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:01-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cups-pk-helper_project:cups-pk-helper:0.2.2`,
        fs:  `cpe:2.3:a:apple:webobjects:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curecos:cure_viewer:1.03::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:ip_call_center_express_enhanced:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curitel:pc_card_software:2.0.8.406`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:exif:0.6.9`,
        fs:  `cpe:2.3:a:hitachi:jp1\/performance_management-manager_web_option:07-54:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:exif:0.6.15`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:exif:0.6.16`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:exif:0.6.17`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.11.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:exif:0.6.18`,
        fs:  `cpe:2.3:a:alstom:micom_s1_agile:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:exif:0.6.19`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:exif:0.6.20`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:exif:0.6.21`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd356a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:libexif:0.6.14`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:sp1a:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:libexif:0.6.15`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:libexif:0.6.16`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:libexif:0.6.18`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2010.302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:libexif:0.6.19`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:libexif:0.6.20`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curtis_galloway:libexif:0.6.21`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curvycorners:curvycorners:6.x-1.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:curvycorners:curvycorners:7.x-1.0`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_banners_plugin_project:custom_banners:1.2.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.64:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:git-scm:git:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.34.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:novell:imanager:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:visio_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.9::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:6.x-1.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:qpid:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:citrix:secure_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:symantec:platform_and_solutions:7.1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:jextn:jextn_question_and_answer:3.1.0:*:*:*:*:joomla:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:john_catania:server_scripts_setup:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.1.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:energyscripts:simple_download:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:bookx_plugin_project:bookx:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.10::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.1:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:dell:powervault_ml6000_firmware:585g.gs003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.12::~~~drupal~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:custom_search_project:custom_search:7.x-1.13::~~~drupal~~`,
        fs:  `cpe:2.3:a:tiomobilepay:tio_mobilepay_-_bill_payments:1.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cutesite:cutesite_cms:1.2.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.272:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cutesite:cutesite_cms:1.5.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.02.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cws:sahab-alkher.com:2.4.9.7::~~~android~~`,
        fs:  `cpe:2.3:a:hp:icewall_federation_agent:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cwt_frontend_edit_project:cwt_frontend_edit:1.2.4::~~~typo3~~`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyber-will:social-button_premium:1.0::~~~ec-cube~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:labelprint:2.5.3602`,
        fs:  `cpe:2.3:a:gnu:bash:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:power2go:7.0`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:power2go:7.0.0.0816`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:power2go:8.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.454.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdirector:7.0`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-05-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdirector:8.00.3022`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall_1:4.1.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:1.0`,
        fs:  `cpe:2.3:a:oracle:hyperion_interactive_reporting:11.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:2.0`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:2.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:2.55`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:3.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:4.0`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:5.0`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.229:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:5.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:6.0`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:6.5`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:6.6`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.7.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:7.0`,
        fs:  `cpe:2.3:a:x:libxi:1.6.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:7.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:7.2`,
        fs:  `cpe:2.3:a:luracast:restler:1.5.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:7.3`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.30.020.1818:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:8.0`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:8.1`,
        fs:  `cpe:2.3:o:huawei:5700hi_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:9.0`,
        fs:  `cpe:2.3:a:niif:shibb_auth:7.x-4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:9.5.1.3225`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:11.0:sp2:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:9.5.1.3426`,
        fs:  `cpe:2.3:o:arubanetworks:instant_access_point_firmware:4.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:9.5.1.4418`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:9.50.0`,
        fs:  `cpe:2.3:a:crunchify:all-in-on-webmaster:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:10.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd:11.0`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd_dx:8.2.5024`,
        fs:  `cpe:2.3:a:smarty:smarty:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd_dx:8.3.5424`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:powerdvd_se:5.0.2214`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.7-p1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:streamauthor:4.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberlink:streamauthor:4.0:build3308`,
        fs:  `cpe:2.3:a:emc:networker:7.6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybernetikz:easy_social_icons:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyberoperations:pro-defense:5.5`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:178:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybird:girls_calendar_period%26weight:3.2.2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybird:romeo_and_juliet:1.0.6::~~~android~~`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit-32:12.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:cybozu_live:1.0.4:-:~~~android~~`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:cybozu_live:2.0.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:cybozu_live:2.0.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:cybozu_office:9.3.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:cybozu_office:9.3.1`,
        fs:  `cpe:2.3:a:jabber2:jabberd2:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:cybozu_office:9.9.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:cybozu_office:10.3.0`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.0.0`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.0.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.4:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.0.2`,
        fs:  `cpe:2.3:a:nih:libzip:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.0.3`,
        fs:  `cpe:2.3:o:xen:xen:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.0.4`,
        fs:  `cpe:2.3:a:r-company:unzipper:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.0.5`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.0.6`,
        fs:  `cpe:2.3:a:busybox:busybox:0.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.0.7`,
        fs:  `cpe:2.3:a:digia:qt:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:dezie:8.1.0`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.0.0`,
        fs:  `cpe:2.3:a:halgame:dk_online_beta:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.1.0`,
        fs:  `cpe:2.3:a:ireadercity:a_very_short_history_of_japan:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.1.1`,
        fs:  `cpe:2.3:a:phpnuke:web_links_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.1.2`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1033:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.1.3`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.5.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.5.1`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.5.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.5.3`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.4.1.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:2.5.4`,
        fs:  `cpe:2.3:o:freebsd:freebsd:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.0.0`,
        fs:  `cpe:2.3:a:emc:networker_module_for_microsoft_applications:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.0.1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.0.2`,
        fs:  `cpe:2.3:a:python:python:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.6.7\(4212\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.1.0`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6ebr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.1.1`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.0:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.1.2`,
        fs:  `cpe:2.3:a:intel:shiva_access_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.1.3`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.5.0`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.5.1`,
        fs:  `cpe:2.3:o:oracle:fujitsu_m10_firmware:2290:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.5.2`,
        fs:  `cpe:2.3:a:google:chrome:7.0.522.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.5.3`,
        fs:  `cpe:2.3:a:adobe:golive_cs2:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.5.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.5.5`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.7:sp1`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.7:sp2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.7:sp3`,
        fs:  `cpe:2.3:a:e-search_project:e-search:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.7.0`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc10:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.7.2`,
        fs:  `cpe:2.3:a:google:v8:5.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.7.4`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.10:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:3.7.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)e6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:4.0.1`,
        fs:  `cpe:2.3:a:apple:itunes:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:4.0.2`,
        fs:  `cpe:2.3:a:justsystems:shuriken:2007:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:4.2.0`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:garoon:4.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)mb13c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.0.3::~~~iphone_os~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2by:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.0.3.1::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.0.4::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.0.5::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.0.5:-:~~~android~~`,
        fs:  `cpe:2.3:a:emc:rsa_data_loss_prevention:9.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.0.6:-:~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6a:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.1.0::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.1.1::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:elxis:elxis_cms:2006.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:2.1.3::~~~android~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0._5::~~~iphone_os~~`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:11.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.0::~~~iphone_os~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.1::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:sympa:sympa:0.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.2::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.3::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.3e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.4::~~~iphone_os~~`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg9000-5:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.6::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.8p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.0.7::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:vmware:tools:9.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.1.0::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.260.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.1.1::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.1.2::~~~iphone_os~~`,
        fs:  `cpe:2.3:h:linksys:befsx41:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.1.3::~~~iphone_os~~`,
        fs:  `cpe:2.3:o:cru-inc:ditto_forensic_fieldstation_firmware:2013oct15a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.1.4::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.450.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai:3.1.5::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ecos:embperl:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:kunai_browser_for_remote_service:-:beta:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:15.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:mailwise:4.0`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:mailwise:5.0.4`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:mailwise:5.0.5`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:mailwise:5.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:9.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:9.1.0`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:9.2.0`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:9.2.1`,
        fs:  `cpe:2.3:o:nokia:ipso:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:9.3.0`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:9.3.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:9.3.2`,
        fs:  `cpe:2.3:a:decisions_project:decisions:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:9.9.0`,
        fs:  `cpe:2.3:h:sendmail:sentrion:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:10.0.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:10.0.1`,
        fs:  `cpe:2.3:a:bitdefender:gravityzone:5.1.5.386:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:10.0.2`,
        fs:  `cpe:2.3:h:cisco:unity_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:10.1.0`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:10.1.2`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:10.2.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.910.2121.36517:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:office:10.3.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:2.2.0`,
        fs:  `cpe:2.3:a:apple:cups:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:2.2.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:2.2.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:2.3.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:3.0.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:3.0.1`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:3.1.0`,
        fs:  `cpe:2.3:h:huawei:cx300:v100r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:3.1.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cybozu:remote_service_manager:3.1.2`,
        fs:  `cpe:2.3:a:avg:internet_security:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyclingforfun:cycling_manager_game_cff:1::~~~android~~`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.992_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cygnacom:visualspif:1.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cypherix:cryptainer_le:6.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cypherpunks:libotr:3.1.0`,
        fs:  `cpe:2.3:h:tp-link:tl-wdr3600_\(1.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cypherpunks:libotr:3.2.0`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cypherpunks:libotr:3.2.1`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cypherpunks:pidgin-otr:3.2.0`,
        fs:  `cpe:2.3:a:bareftp:bareftp:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cypherpunks:pidgin-otr:3.2.1`,
        fs:  `cpe:2.3:o:apple:watchos:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p282:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.225.2152.39091:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.2`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.3`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.5`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.6`,
        fs:  `cpe:2.3:a:libtiff_project:libtiff:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.7`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.8`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.44.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.9`,
        fs:  `cpe:2.3:a:sunil_nanda:blue_wrench_video_widget:1.0.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.10`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:2.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.11`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.12`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.13`,
        fs:  `cpe:2.3:a:skype:skype:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.14`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.15`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.16`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.17`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.04.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.3.18`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.0`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.1`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:11.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.14s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.5`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.6`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.7`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.8`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.9`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.10`,
        fs:  `cpe:2.3:a:sun:jsse:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.11`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.12`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.19:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.13`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.03:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.14`,
        fs:  `cpe:2.3:a:adobe:illustrator:16.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.15`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.16`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:cf04:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.4.17`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.5.0`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.5.1`,
        fs:  `cpe:2.3:a:color:icclib:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:cyrus:imap:2.5.3`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.2`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.372:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.4`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.4.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.4.2::~~~~~permissive`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.4.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.4.4::~~~~~permissive`,
        fs:  `cpe:2.3:a:php:go-pear.php:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.4.6`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.4.6::~~~~~permissive`,
        fs:  `cpe:2.3:a:mcafee:application_control:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.6`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.1:preflight0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.8`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.10`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.12`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.14`,
        fs:  `cpe:2.3:h:intel:express_510t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.16`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.9:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.18`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.20`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.22`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.24`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.26`,
        fs:  `cpe:2.3:a:adobe:illustrator:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.28`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus\/opentp1_web_web_front-endset:02-70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.2.30`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.3.0`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-255p_firmware:t470sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.3.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.1:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.642.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.1`,
        fs:  `cpe:2.3:a:apple:webobjects:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.4`,
        fs:  `cpe:2.3:h:hp:color_laserjet_9500_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.6`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.8`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:8.0.298.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.10`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.12`,
        fs:  `cpe:2.3:a:oracle:jd_edwards_products:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.14`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.16`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.18`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.20`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.1.1.377:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.22`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.5.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.24`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.4.26`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.5.0`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.5.2`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.5.4`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.5.6`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.5.8`,
        fs:  `cpe:2.3:a:idevspot:isupport:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.5.10`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.5.12`,
        fs:  `cpe:2.3:a:roxio:cineplayer:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.0`,
        fs:  `cpe:2.3:a:microsoft:visual_foxpro:8.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.4`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.8`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.10`,
        fs:  `cpe:2.3:a:iss:realsecure_server_sensor:7.0:sr4.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.12`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.14`,
        fs:  `cpe:2.3:a:apache:camel:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.16`,
        fs:  `cpe:2.3:a:vdstech:aspmap:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.18`,
        fs:  `cpe:2.3:o:freebsd:freebsd:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.20`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.22`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.12.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.24`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.26`,
        fs:  `cpe:2.3:a:onesolutionapps:woodward_bail:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.6.28`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.7.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.7.2`,
        fs:  `cpe:2.3:a:apache:cxf:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.7.4`,
        fs:  `cpe:2.3:h:hp:laserjet_m725f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.7.6`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.8.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.8.2`,
        fs:  `cpe:2.3:a:ddsn:cm3_acora_content_management_system:5.5.7\/12b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.8.4`,
        fs:  `cpe:2.3:a:acidcat:acidcat_cms:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.8.6`,
        fs:  `cpe:2.3:h:cisco:catalyst_6500_ws-svc-nam-2:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.8.8`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.8.10`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.8.12`,
        fs:  `cpe:2.3:a:openstack:horizon:2014.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.8.14`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.9.0`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.9.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.9.4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.9.6`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-bus_project:d-bus:1.9.8`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-coda:contactme:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-link:camera_stream_client_activex_control:1.0.0.4519`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.70.020.1426:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-1320:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-1320_firmware:1.11`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf284a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-1350:rev._a1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-1350_firmware:1.10`,
        fs:  `cpe:2.3:a:itt:spectrum_xxi_management_utility:2.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-1350_firmware:1.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12\)da9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-1360:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d-link:dap-1360_firmware:2.5.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-2230:-`,
        fs:  `cpe:2.3:a:docker:docker:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-2230_firmware:1.02`,
        fs:  `cpe:2.3:o:hp:officejet_pro_8500_firmware:dlm1fn1344ar:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-2310:-`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-2310_firmware:2.06`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2012:r2:-:-:*:datacenter:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-2330:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.7.0.1\(4764\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-2330_firmware:1.06`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-2360:-`,
        fs:  `cpe:2.3:a:hp:customer_participation_program:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-2360_firmware:2.06`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-2553:-`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-2553_firmware:3.05`,
        fs:  `cpe:2.3:a:intel:network_connections:15.5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-2660:-`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-2660_firmware:1.11`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:unknown:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-2690:-`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-2690_firmware:3.15`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b2_pk4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-2695:-`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-2695_firmware:1.16`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-3320:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-3320_firmware:1.00`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap-3662:-`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap-3662_firmware:1.01`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dap_1150:-`,
        fs:  `cpe:2.3:a:vmware:workstation_player:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dap_1150_firmware:1.2.94`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.24.368:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-2132l:-`,
        fs:  `cpe:2.3:o:cisco:wrvs4400n_firmware:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2132l_firmware:1.08.01`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2132l_firmware:2.12.00`,
        fs:  `cpe:2.3:a:google:chrome:54.0.2840.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-2136l:-`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2136l_firmware:1.04.01`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-2210l:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)s9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2210l_firmware:1.03.01`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd655a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-2230l:-`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2230l_firmware:1.03.01`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-2310l:-`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2310l_firmware:1.08.01`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.7.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2310l_firmware:2.03.00`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r5_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-2330l:-`,
        fs:  `cpe:2.3:h:netgear:dg834gt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2330l_firmware:1.13.00`,
        fs:  `cpe:2.3:a:intel:driver_update_utility:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-2332l:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2332l_firmware:1.08.01`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-2530l:-`,
        fs:  `cpe:2.3:a:apple:safari:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-2530l_firmware:1.00.21`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.7.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5000l:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-5000l_firmware:1.02.02`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5009l:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-5009l_firmware:1.07.05`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5010l:-`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-5010l_firmware:1.13.05`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5020l:-`,
        fs:  `cpe:2.3:a:hp:tcp_ip_services_openvms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-5020l_firmware:1.13.05`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5025l:-`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-5025l_firmware:1.02.10`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5029l:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-5029l_firmware:1.12.00`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5030l:-`,
        fs:  `cpe:2.3:a:hp:instant_printing_utility:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-5030l_firmware:1.01.06`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5222l_:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-5222l__firmware:2.12.00`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-5605_ptz_ip_network_camera:-`,
        fs:  `cpe:2.3:a:apple:itunes:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-6010l:-`,
        fs:  `cpe:2.3:a:oracle:advanced_collections:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-6010l_firmware:1.15.01`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-6212l:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-6212l_firmware:1.00.12`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-7000l:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-7000l_firmware:1.04.00`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-7010l:-`,
        fs:  `cpe:2.3:a:e107:e107:0.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-7010l_firmware:1.08.01`,
        fs:  `cpe:2.3:a:adobe:flash_player:12.0.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-930l:-`,
        fs:  `cpe:2.3:a:web2py:web2py:1.76.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-930l_firmware:1.15.04`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-930l_firmware:2.13.15`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-931l:-`,
        fs:  `cpe:2.3:a:cisco:meeting_manager_for_firefox\/netscape\/chrome:8.0.4917:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-931l_firmware:1.04`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-931l_firmware:1.13.05`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-932l:-`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110616:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-932l_camera:-`,
        fs:  `cpe:2.3:a:redaxo:redaxo:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-932l_camera_firmware:1.00`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r11_b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-932l_camera_firmware:1.02`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-932l_firmware:1.00`,
        fs:  `cpe:2.3:a:david_king:vino:2.27.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-932l_firmware:1.02`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-932l_firmware:1.13.04`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:10.0.xc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-932l_firmware:2.13.15`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-933l:-`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-933l_firmware:1.13.05`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-934l:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-934l_firmware:1.04.15`,
        fs:  `cpe:2.3:a:boopsie:deschutes_public_mobilelibrary:4.5.110:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dcs-942l:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-942l_firmware:1.27`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dcs-942l_firmware:2.11.03`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-00-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:di-524up:-`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:di-604%2b:-`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:di-604s:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:di-604up:-`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:11:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:di-624s:-`,
        fs:  `cpe:2.3:h:avaya:s8500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-100:-`,
        fs:  `cpe:2.3:a:projectsend:projectsend:405:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-120:-`,
        fs:  `cpe:2.3:h:ge:multilink_ml2400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-505l_shareport_mobile_companion:a1`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-505l_shareport_mobile_companion_firmware:1.01`,
        fs:  `cpe:2.3:a:redhat:kdelibs_devel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-600l:a1`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-600l:b1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-600l_firmware:1.15`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-600l_firmware:2.05`,
        fs:  `cpe:2.3:a:apache:traffic_server:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-601:-`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-601_firmware:1.02na`,
        fs:  `cpe:2.3:h:lexmark:x20x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-605l:a1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-605l:b1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-605l_firmware:1.13`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-605l_firmware:2.04`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-619l:a1`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-619l:b1`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-619l_firmware:1.15`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.11.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-619l_firmware:2.03`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-645:a1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-645_firmware:1.03:b08`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-645_firmware:1.04:b11`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.08:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-809:a1`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-809:a2`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-809_firmware:1.02`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-816l:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-816l_firmware:2.05.b02`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-826l_wireless_n600_cloud_router:a1`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:2.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-826l_wireless_n600_cloud_router_firmware:1.02`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir-905l:a1`,
        fs:  `cpe:2.3:h:hp:laserjet_4350dtn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir-905l_firmware:1.02`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dir505_shareport_mobile_companion:a1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir505_shareport_mobile_companion_firmware:1.07`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dir505l_shareport_mobile_companion_firmware:1.01`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1682.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsl-2640r:-`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsl-2641r:-`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.45.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsl-2730b:c1`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsl-2730b:ge_1.01`,
        fs:  `cpe:2.3:h:meizu:mx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsl-2730b_firmware:ge_1.01`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.397:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsl-2730u:-`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsl-2760u-e1:-`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.6:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsl2740u:-`,
        fs:  `cpe:2.3:a:apc:powerchute_network_shutdown:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsl2750u:-`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsp-w215:a1`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsp-w215_firmware:1.01:b06`,
        fs:  `cpe:2.3:a:altiris:alert_manager:6.0.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsr-1000:-`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.01b50`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.02b11`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1.1sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.02b25`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.03b12`,
        fs:  `cpe:2.3:a:vmware:vcenter_update_manager:4.0.0.3194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.03b23`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.03b27`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.03b36`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.03b43`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.04b58`,
        fs:  `cpe:2.3:a:microsoft:visio:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.06b43`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.06b53`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000_firmware:1.08b77`,
        fs:  `cpe:2.3:a:gnu:libc:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsr-1000n:-`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:5.4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.01b50`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.02b11`,
        fs:  `cpe:2.3:a:netgear:readynas_surveillance:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.02b25`,
        fs:  `cpe:2.3:h:zyxel:p-660h-d3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.03b12`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.03b23`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.03b27`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.03b36`,
        fs:  `cpe:2.3:a:vmware:infrastructure_client:2.5.0.64258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.03b43`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.04b58`,
        fs:  `cpe:2.3:a:ibm:rational_service_tester:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.06b43`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3j:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.06b53`,
        fs:  `cpe:2.3:a:adobe:connect:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.08b51`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-1000n_firmware:1.08b77`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsr-150:-`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-150_firmware:1.05b29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-150_firmware:1.05b35`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.345:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-150_firmware:1.05b46`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-150_firmware:1.05b50`,
        fs:  `cpe:2.3:a:buffalotech:wer-am54g54_firmware:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-150_firmware:1.08b29`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-150_firmware:1.08b44`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsr-150n:-`,
        fs:  `cpe:2.3:a:ati:skins:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-150n_firmware:1.05b48`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.1.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-150n_firmware:1.05b64`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsr-250:-`,
        fs:  `cpe:2.3:a:icinga:icinga:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250_firmware:1.01b46`,
        fs:  `cpe:2.3:a:canon:imagerunner_9070:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250_firmware:1.01b56`,
        fs:  `cpe:2.3:a:x:libxt:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250_firmware:1.05b20`,
        fs:  `cpe:2.3:a:apache:ambari:2.4.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250_firmware:1.05b53`,
        fs:  `cpe:2.3:a:google:v8:3.22.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250_firmware:1.08b31`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_3l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250_firmware:1.08b39`,
        fs:  `cpe:2.3:a:services_project:services:6.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250_firmware:1.08b44`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsr-250n:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250n_firmware:1.01b46`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250n_firmware:1.01b56`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250n_firmware:1.05b20`,
        fs:  `cpe:2.3:h:cisco:nexus_2224tp_fex_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250n_firmware:1.05b53`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250n_firmware:1.08b31`,
        fs:  `cpe:2.3:h:ge:snmp\/web_adapter_1024746:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250n_firmware:1.08b39`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.8.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-250n_firmware:1.08b44`,
        fs:  `cpe:2.3:a:vmware:workstation:3.2.1:patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsr-500:-`,
        fs:  `cpe:2.3:a:lxml:lxml:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.02b11`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.02b25`,
        fs:  `cpe:2.3:a:redhat:docker:1.5.0-27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.03b12`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.03b23`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.03b27`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.03b36`,
        fs:  `cpe:2.3:h:enterasys:6g306-6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.03b43`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2008:12.0.758.32:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.04b58`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.12:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.06b43`,
        fs:  `cpe:2.3:a:apple:cups:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.06b53`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.68:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.08b51`,
        fs:  `cpe:2.3:o:bluecoat:sgos:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500_firmware:1.08b77`,
        fs:  `cpe:2.3:a:cisco:network_equipment_information:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:dsr-500n:-`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.02b11`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.50.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.02b25`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.03b12`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.03b23`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.03b27`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.03b36`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.03b43`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.04b58`,
        fs:  `cpe:2.3:a:honeywell:symmetre:r410.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.06b43`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.06b53`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.08b51`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:d-link:dsr-500n_firmware:1.08b77`,
        fs:  `cpe:2.3:a:mcafee:host_data_loss_prevention:3.0.100.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:d-link:tm-g5240:-`,
        fs:  `cpe:2.3:h:schneider-electric:bmxpra0100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:d.r.commander:libjpeg-turbo:1.2.0`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.0:beta`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.0.1:beta`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.4:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.0.2:beta`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.0.3:beta`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.0.4:beta`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.7p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.0.5:beta`,
        fs:  `cpe:2.3:a:awesome_antivirus_2014_project:awesome_antivirus_2014:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.1:beta`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.5`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.5b`,
        fs:  `cpe:2.3:h:huawei:s5300:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.6`,
        fs:  `cpe:2.3:a:hp:sockd:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.7`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.0:rc2:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.8`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.9`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:1.9.1`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:2.0:beta`,
        fs:  `cpe:2.3:a:adobe:camera_raw:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:2.0.1:beta`,
        fs:  `cpe:2.3:a:lumension:patchlink_update_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:2.1:beta`,
        fs:  `cpe:2.3:a:aprelium:abyss_web_server_x1:2.3.2:-:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:2.1b:beta`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:*:x32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:2.2:beta`,
        fs:  `cpe:2.3:a:freedesktop:libdbus:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:2.2.1`,
        fs:  `cpe:2.3:a:apache:hadoop:2.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:2.2.1:beta`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:3.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.49.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:3.0:beta`,
        fs:  `cpe:2.3:a:google:checkout-php:1.2.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:3.1:beta`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:3.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:3.2:beta`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.0`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.0:alpha`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.2.06a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.0:beta`,
        fs:  `cpe:2.3:a:analogx:proxy:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.0:beta2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.1`,
        fs:  `cpe:2.3:a:dell:openmanage_remote_access_components:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.1:beta`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.1:rc1`,
        fs:  `cpe:2.3:o:moxa:edr_g903_firmware:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.1:rc2`,
        fs:  `cpe:2.3:a:finalbeta:mywebsearch:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.1:rc3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(24\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.2`,
        fs:  `cpe:2.3:a:avast:free_antivirus:11.1.2260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.2:beta`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.3:alpha`,
        fs:  `cpe:2.3:a:jakweb:gecko_cms:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.3:beta`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.3:beta_rc1`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dadabik:dadabik:4.3:beta2`,
        fs:  `cpe:2.3:a:microsoft:digital_image:2006:unknown:starter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daemontools:daemon_tools:3.47.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daemontools:daemon_tools_lite:4.40.2.131`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daemontools:daemon_tools_lite:4.41.3.173`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.457:mr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daemontools:daemon_tools_toolbar:1.1.2.185`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2009:13.0.844.32:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daemontools:daemon_tools_toolbar:1.1.8.285`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:dahuasecurity:dvr_firmware:2.608.0000.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dahuasecurity:dvr_firmware:2.608.gv00.0`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0404hd-a:-`,
        fs:  `cpe:2.3:a:juniper:junos_internet_software:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0404hd-l:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0404hd-s:-`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0404hd-u:-`,
        fs:  `cpe:2.3:a:exim:exim:4.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0404hf-a-e:-`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0404hf-al-e:-`,
        fs:  `cpe:2.3:h:htc:evo_4g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0404hf-s-e:-`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0404hf-u-e:-`,
        fs:  `cpe:2.3:a:inmatrix:zoom_player:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0804:-`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0804hd-l:-`,
        fs:  `cpe:2.3:a:adobe:connect_addin_checker:9.3.139.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0804hd-s:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0804hf-a-e:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.1.30:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0804hf-al-e:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0804hf-l-e:-`,
        fs:  `cpe:2.3:a:feeds_project:feeds:7.x-2.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0804hf-s-e:-`,
        fs:  `cpe:2.3:a:microsoft:virtual_server:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr0804hf-u-e:-`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.2\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr1604hd-l:-`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(2.13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr1604hd-s:-`,
        fs:  `cpe:2.3:a:ibm:client_security_password_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr1604hf-a-e:-`,
        fs:  `cpe:2.3:a:sympa:sympa:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr1604hf-al-e:-`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.40:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr1604hf-l-e:-`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr1604hf-s-e:-`,
        fs:  `cpe:2.3:o:hp:700_series_firmware:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr1604hf-u-e:-`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.44.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2104c:-`,
        fs:  `cpe:2.3:a:veritas:backup_exec:15.1180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2104h:-`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2104hc:-`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.13:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2104he:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p200:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2108c:-`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2108h:-`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2108hc:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2108he:-`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2116c:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.12s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2116h:-`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:8.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2116hc:-`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2116he:-`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2404hf-s:-`,
        fs:  `cpe:2.3:a:oracle:virtualization:4.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2404lf-al:-`,
        fs:  `cpe:2.3:a:ca:ccc_harvest:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr2404lf-s:-`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr3204hf-s:-`,
        fs:  `cpe:2.3:h:3com:3c16479:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr3204lf-al:-`,
        fs:  `cpe:2.3:o:apple:mac_os:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr3204lf-s:-`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr3224l:-`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr3232l:-`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5104c:-`,
        fs:  `cpe:2.3:h:omron:ns15_hmi_terminal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5104h:-`,
        fs:  `cpe:2.3:a:google:v8:3.24.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5104he:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5108c:-`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5108h:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5108he:-`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5116c:-`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5116h:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5116he:-`,
        fs:  `cpe:2.3:a:amtelco:misecuremessages:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5204a:-`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5204l:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5208a:-`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5208l:-`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5216a:-`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5216l:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5404:-`,
        fs:  `cpe:2.3:a:skype:skype:1.1.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5408:-`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5416:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5804:-`,
        fs:  `cpe:2.3:a:symantec:protection_for_sharepoint_servers:6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5808:-`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr5816:-`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dahuasecurity:dvr6404lf-s:-`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daiki_ueno:libfep:0.0.5`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daiki_ueno:libfep:0.0.6`,
        fs:  `cpe:2.3:a:webmin:usermin:1.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daiki_ueno:libfep:0.0.7`,
        fs:  `cpe:2.3:a:narr8:knights_of_the_void:2.1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:daiki_ueno:libfep:0.0.8`,
        fs:  `cpe:2.3:a:ibm:parallel_environment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daiki_ueno:libfep:0.0.9`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daiki_ueno:libfep:0.1.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daily_green_project:daily_green:2014.07::~~~android~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dakshaa:neeku_naaku_dash_dash:1::~~~android~~`,
        fs:  `cpe:2.3:a:polycom:rss_system_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.03`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.1.10000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.04`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.05`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.06`,
        fs:  `cpe:2.3:a:iain:gypsy:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.07`,
        fs:  `cpe:2.3:a:libpng:libpng:0.89c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.08`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.09`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.00_11.11_host_agent_files:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.10`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.20`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.0:*:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.21`,
        fs:  `cpe:2.3:a:alkacon:opencms:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.22`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.429c:mr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.22:sp2`,
        fs:  `cpe:2.3:a:store_locator_project:store_locator:3.3.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.22:sp3`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.22:sp4`,
        fs:  `cpe:2.3:h:oracle:sun_blade_x6440_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.22:sp5`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.22:sp6`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.22:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.22:sp7`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:r16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.31`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.32`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.33`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.34`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.35`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dalbum:dalbum:1.44:174`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:4.5.0.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.593.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:4.9.0.0`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:4.0.0:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:4.9.2.6`,
        fs:  `cpe:2.3:a:hp:event_monitoring_service:a.04.20.31.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.0.0.5`,
        fs:  `cpe:2.3:a:mcafee:epo_mcafee_virtual_technician:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.0.0.6`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.0.0.7`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.388:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.0.1.0`,
        fs:  `cpe:2.3:a:novell:groupwise:7.0.3:hp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.0.1.5`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.0.1.7`,
        fs:  `cpe:2.3:a:sun:java_system_communications_express:2004q2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.0.1.8`,
        fs:  `cpe:2.3:a:oracle:oracle_berkeley_db:12.1.6.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.1.0.0`,
        fs:  `cpe:2.3:a:microsoft:windows_essentials:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.1.1.0`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.1.1.6`,
        fs:  `cpe:2.3:a:zonelabs:imsecure:1.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.1.1.8`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.1.3.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:5.5.0.0`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.0.0.2`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.03b12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.0.0.3`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:7.1.102.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.0.0.5`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.0.0.7`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.25:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.0.0.9`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.0.1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.0.1.5`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.2.0.0`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.3.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.3.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.4.0.0`,
        fs:  `cpe:2.3:a:php:php:5.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.4.0.1`,
        fs:  `cpe:2.3:a:google:chrome:16.0.904.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.4.0.5`,
        fs:  `cpe:2.3:a:tibco:spotfire_professional:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.5.0.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.6.0.0`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.6.0.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.6.0.5`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.6.0.7`,
        fs:  `cpe:2.3:a:saltstack:salt:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.6.0.8`,
        fs:  `cpe:2.3:a:hp:sitescope:10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.6.1.1`,
        fs:  `cpe:2.3:a:canadapps:central_east_lhin_news:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.6.2.0`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120425:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.6.2.1`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_network_discovery_solution:6.0.1026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.7`,
        fs:  `cpe:2.3:a:symantec:reporting_agents:1.0.248.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.7.0.2`,
        fs:  `cpe:2.3:a:hp:thinpro_linux:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.7.0.4`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.7.0.5`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.7.0.6`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.7.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.7.0.8`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.7.0.9`,
        fs:  `cpe:2.3:a:google:chrome:17.0.928.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.8`,
        fs:  `cpe:2.3:a:cfdbplugin:contact_form_db:2.8.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.8.0.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.8.0.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.8.0.4`,
        fs:  `cpe:2.3:a:ca:alert_notification_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.8.0.8`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.8.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.8.1.4`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.9.0.0`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:6.9.0.4`,
        fs:  `cpe:2.3:a:sun:jre:6.0.170:update17:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.0.1`,
        fs:  `cpe:2.3:h:ibm:sas_connectivity_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.0.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.0.3`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.1`,
        fs:  `cpe:2.3:a:jease:jease:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.2`,
        fs:  `cpe:2.3:a:apc:apcupsd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.1.1`,
        fs:  `cpe:2.3:a:attachmate:reflection_x:14.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.2`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.5`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.5.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.6`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.6.0`,
        fs:  `cpe:2.3:a:dotcms:dotcms:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.6.1`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.8`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.9`,
        fs:  `cpe:2.3:a:avast:pro_antivirus:11.1.2253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control:7.5.9.1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.992_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:mini_remote_control_client_agent_service:6.9.0.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:4.5.0.0`,
        fs:  `cpe:2.3:a:hp:workload_manager:a.02.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:4.7.0.0`,
        fs:  `cpe:2.3:a:searchblox:searchblox:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:4.9.2.2`,
        fs:  `cpe:2.3:a:hp:ocr_software_by_i.r.i.s:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:5.0.0.2`,
        fs:  `cpe:2.3:a:oracle:customer_interaction_history:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:5.1.1.6`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:5.1.1.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:5.5.0.0`,
        fs:  `cpe:2.3:a:ca:unicenter_dsm_agent_\&#43;_asset_management_plugin:11.2.4000.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:6.8.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.53.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:6.8.1.4`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:6.9.0.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.07:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:6.9.0.4`,
        fs:  `cpe:2.3:o:mediabridge:medialink_mwn-wapr300n_firmware:5.07.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:7.5.6.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:nt_utilities:7.5.9.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:remote_support:9.0.1.247`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dameware:remote_support:10.0.0.372`,
        fs:  `cpe:2.3:a:sony:sonicstage_mastering_studio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:0.93`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:0.94`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:0.95`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:0.96`,
        fs:  `cpe:2.3:a:denki:juggle\!_free:3.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:0.97`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:0.98`,
        fs:  `cpe:2.3:o:netgear:prosafe_firmware:5.4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:0.99`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.00`,
        fs:  `cpe:2.3:a:emc:networker:7.5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.01`,
        fs:  `cpe:2.3:a:symantec:workspace_streaming:7.5.0.749:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.10`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.3:4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.11`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.20`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd328a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.21`,
        fs:  `cpe:2.3:h:intel:3450_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.25`,
        fs:  `cpe:2.3:a:postfix:postfix:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.26`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.28`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.30`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.31`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.8ex:3.8.0ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.32`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.33`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.34`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.40`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.95.f1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.41`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.06.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.42`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.50`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.51`,
        fs:  `cpe:2.3:a:ayatana_project:unity:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.52`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.53`,
        fs:  `cpe:2.3:a:apache:openjpa:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.54`,
        fs:  `cpe:2.3:a:tenmiles:helpdesk_pilot:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.55`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.56`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.57`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.2.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.58`,
        fs:  `cpe:2.3:a:vmware:infrastructure_update:2.5.0.64247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.59`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.60`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.61`,
        fs:  `cpe:2.3:a:x:x.org-xserver:1.7.6.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.62`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.338:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.63`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.64`,
        fs:  `cpe:2.3:a:michael_vogt:ubuntu-system-service:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.65`,
        fs:  `cpe:2.3:a:hp:software_update:2.0.38.20040107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.66`,
        fs:  `cpe:2.3:a:hp:product_detection:9.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.67`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.12:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.68`,
        fs:  `cpe:2.3:a:abbyy:finereader_sprint:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.69`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.70`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.71`,
        fs:  `cpe:2.3:a:avaya:communication_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.72`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.73`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:eca:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.74`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.75`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.76`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.77`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.0.0:incubating:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.78`,
        fs:  `cpe:2.3:a:hp:scan:140.0.80.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.79`,
        fs:  `cpe:2.3:a:sap:crystal_reports:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.80`,
        fs:  `cpe:2.3:a:altiris:dell_client_configuration_utility:3.0.1213.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.81`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.82`,
        fs:  `cpe:2.3:a:debian:apt:0.8.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.83`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.0\(6\)p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.84`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:8:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.85`,
        fs:  `cpe:2.3:o:yahama:rta54i:4.05.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.86`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050325:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.87`,
        fs:  `cpe:2.3:a:burnsy:jbshop_plugin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.88`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.89`,
        fs:  `cpe:2.3:h:nortel:wlan_handset_2211:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.90`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.91`,
        fs:  `cpe:2.3:h:siemens:synco_ozw_web_server:ozw672.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.92`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.93`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.94`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.95`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.96`,
        fs:  `cpe:2.3:a:tribulant:tibulant_slideshow_gallery:1.4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.97`,
        fs:  `cpe:2.3:h:juniper:infranet_controller_4500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.98`,
        fs:  `cpe:2.3:a:cisco:trust_agent:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:1.99`,
        fs:  `cpe:2.3:a:novaboard:novaboard:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.01`,
        fs:  `cpe:2.3:a:atlassian:jira:3.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.02`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.03`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.04`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.05`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.06`,
        fs:  `cpe:2.3:a:djangoproject:django:1.10.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.07`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.08`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.1.3600.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.09`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.10`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert12:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.11`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.12`,
        fs:  `cpe:2.3:a:hp:hpztlbxfx:4.17.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.13`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.14`,
        fs:  `cpe:2.3:a:cdotech:baseline_validator:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.15`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.16`,
        fs:  `cpe:2.3:a:amd:app_sdk_runtime:2.5.684.213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.17`,
        fs:  `cpe:2.3:h:cisco:sn_5420_storage_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.18`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.19`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.20`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.21`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.22`,
        fs:  `cpe:2.3:a:jdm_lifestyle_project:jdm_lifestyle:6.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.23`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.24`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.25`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.26`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.05:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.27`,
        fs:  `cpe:2.3:a:apache:roller:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.28`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.29`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)scj2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.30`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.20d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.31`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.32`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.33`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.34`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.35`,
        fs:  `cpe:2.3:a:ca:unicenter_application_performance_monitor:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.36`,
        fs:  `cpe:2.3:a:ibm:infosphere_guardium:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.37`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.38`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.39`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.63:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.40`,
        fs:  `cpe:2.3:h:hp:cf235a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.41`,
        fs:  `cpe:2.3:a:olivetoast:documents_pro_file_viewer:1.11:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.42`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.7:1013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.43`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kogai:encode_module:2.44`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:51.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.2`,
        fs:  `cpe:2.3:h:supermicro:x9drt-ibqf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.5`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.6`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.7`,
        fs:  `cpe:2.3:a:cherokee-project:cherokee:1.2.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.8`,
        fs:  `cpe:2.3:a:apache:struts:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.9`,
        fs:  `cpe:2.3:a:gnu:automake:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.10`,
        fs:  `cpe:2.3:a:nuance:paperport:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.11`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.12`,
        fs:  `cpe:2.3:a:corel:coreldraw_lang_es:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.13`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.14`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.15`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dan_kubb:extlib:0.9.16`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dandyid_services_project:dandyid_services:1.5.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.4:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:0.5.0`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:0.6.4`,
        fs:  `cpe:2.3:a:microsoft:virtual_pc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:0.7.0`,
        fs:  `cpe:2.3:h:cisco:telepresence_quick_set_c20:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:0.9.9`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.2.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.2.1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.2.3`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.2.5`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.2.6`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.2.7`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.14.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.3.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.3.1`,
        fs:  `cpe:2.3:h:enterasys:roamabout_ap3000:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.3.3`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:3.1_.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.3.5`,
        fs:  `cpe:2.3:h:hp:pusb_thermal_receipt_printer_fk224aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.4`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.4.1`,
        fs:  `cpe:2.3:a:quest:activeroles_management_shell_for_active_directory:1.4.0.2139:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.4.2`,
        fs:  `cpe:2.3:h:ibm:ts3200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.4.3`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.5`,
        fs:  `cpe:2.3:a:openstack:neutron:juno1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.6`,
        fs:  `cpe:2.3:a:gentoo:linux_eix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.6.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.7`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.8`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.9`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.10`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.10.1`,
        fs:  `cpe:2.3:a:isc:bind:9.9.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)se3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.11.1`,
        fs:  `cpe:2.3:a:open-emr:openemr:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.11.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.12`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.13`,
        fs:  `cpe:2.3:h:dell:powervault_tl4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.14`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.2479.0006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daniel_friesel:feh:1.14.1`,
        fs:  `cpe:2.3:h:ibm:sas_raid_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.0`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.1`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:5.0.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.2`,
        fs:  `cpe:2.3:a:ibm:cognos_command_center:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.4`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.6`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.7`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.10:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.8`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:019:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:cool_aid:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.13:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.5.51.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:h:lexmark:c53x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha10`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha11`,
        fs:  `cpe:2.3:a:digium:asterisk:11.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha12`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha13`,
        fs:  `cpe:2.3:o:netgear:raidiator:4.2.20:-:-:*:-:-:readynas:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha14`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha15`,
        fs:  `cpe:2.3:a:orcacle:webcenter_sites:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha16`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha17`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha18`,
        fs:  `cpe:2.3:o:apple:iphone_os:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha19`,
        fs:  `cpe:2.3:o:novell:netware:6.5:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.220:update22:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha20`,
        fs:  `cpe:2.3:a:perl:perl:0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha21`,
        fs:  `cpe:2.3:a:happycloud:happy:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha22`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha23`,
        fs:  `cpe:2.3:a:icofx:icofx:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha24`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_unified_software:1.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha25`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.48.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha26`,
        fs:  `cpe:2.3:a:online-solutions:online_solutions_security_suite:1.5.14905.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha27`,
        fs:  `cpe:2.3:h:hp:jf808a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha28`,
        fs:  `cpe:2.3:a:isode:m-link:14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha4`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha5`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha6`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha7`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha8`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-51-\/k:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:alpha9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p205:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:beta1`,
        fs:  `cpe:2.3:o:mandriva:corporate_server:3.0:*:x86_64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p202:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:beta3`,
        fs:  `cpe:2.3:a:semantictitle_project:semantictitle:-:*:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(23\)sz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:rc2`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3060-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:rc3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:rc4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:unstable0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:unstable1`,
        fs:  `cpe:2.3:h:dell:w5300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:unstable2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:unstable3`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:unstable4`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:unstable5`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:unstable6`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.0:unstable7`,
        fs:  `cpe:2.3:a:ibm:social_media_analytics:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.1`,
        fs:  `cpe:2.3:h:cisco:dpc3941_wireless_residential_voice_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.2`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.3`,
        fs:  `cpe:2.3:a:adobe:captivate:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.4`,
        fs:  `cpe:2.3:a:cpe17:autorun_killer:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17d\)sx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.7`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.8`,
        fs:  `cpe:2.3:h:cisco:sg300-10mpp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.9`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.10`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.11`,
        fs:  `cpe:2.3:h:hp:storevirtual_4530:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.12`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.13`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.14`,
        fs:  `cpe:2.3:a:google:chrome:17.0.936.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.15`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.16`,
        fs:  `cpe:2.3:a:livetecs:timeline:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.17`,
        fs:  `cpe:2.3:a:apache:http_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.18`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.19`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.20`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.21`,
        fs:  `cpe:2.3:a:vmware:horizon_view:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.23`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.24`,
        fs:  `cpe:2.3:a:fasttoggle_project:fasttoggle:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:6.x-1.x-dev`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-1.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-1.1`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:5.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-1.2`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs4:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-1.3`,
        fs:  `cpe:2.3:h:axis:2130_ptz_network_camera:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-1.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-1.5`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-1.6`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.40a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-2.0:alpha2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.70.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-2.0:alpha3`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.3.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-2.0:alpha4`,
        fs:  `cpe:2.3:a:libraw:libraw:0.16.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-2.0:alpha5`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.2:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-2.0:alpha6`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:danielb:finder:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielkorte:nodeaccesskeys:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danielkorte:nodeaccesskeys:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.0.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.1.2`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:9.0.383:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.1.3`,
        fs:  `cpe:2.3:a:microsoft:data_engine:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.1.4`,
        fs:  `cpe:2.3:a:apache:subversion:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.1.5`,
        fs:  `cpe:2.3:a:cybozu:mailwise:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.1.6`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.1.7`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.1.8`,
        fs:  `cpe:2.3:a:electric_cloud:electriccommander:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.1.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.2.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.2.2`,
        fs:  `cpe:2.3:a:gnu:enscript:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.2.3`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.2.4`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.2.5`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.2.6`,
        fs:  `cpe:2.3:o:cisco:ons_15454_mstp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.2.7`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.2.8`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.3.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.3.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.3.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.4.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_4550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:danny_morris:lazy_seo:1.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.1`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.4`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.5`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.6`,
        fs:  `cpe:2.3:a:adobe:captivate_quiz_results_analyzer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:5.8`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.20:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.1`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.2`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.4`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.1:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.565.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.7`,
        fs:  `cpe:2.3:a:webmin:usermin:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:darold:squidclamav:6.8`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dart:dart_ziplite_compression:1.8.5.3`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dart:powertcp_ftp_for_activex:2.0.2.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dart:powertcp_zip_compression:1.8.5.3`,
        fs:  `cpe:2.3:h:softbank:panasonic_3g_handset:942p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dasanzhone:znid_2426a_firmware:s3.0.501`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadirect:datadirect_connect_odbc:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadirect:datadirect_connect_odbc:5.1`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activebar:-`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activebar:2.5`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activebar:3.1`,
        fs:  `cpe:2.3:a:amazon:kindle_for_pc:1.3.0.30884:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activereports:-`,
        fs:  `cpe:2.3:a:php:php:5.4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activereports:2.0`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activereports:2.5`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activereports:2.5.0.1314`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activereports:2.5.0.1314:-:pro`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datadynamics:activereports:2.5.0.1314:_nil_:pro`,
        fs:  `cpe:2.3:a:theflip:flipshare:5.0.5.52727:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dataload:dataload:5.2.0.0`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datanamic:dezign_for_databases:3.4.1`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dataparadigm:acn2go:1.7::~~~android~~`,
        fs:  `cpe:2.3:a:sigmatel:c-major_audio:42xx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datatechgroup:telecommunication_inventory_and_billing_information_data_pump:2.0.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.56:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datawatch:monarch:6.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datawatch:monarch:8.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datawatch:monarch:10.5::~~professional~~~`,
        fs:  `cpe:2.3:a:digium:asterisk:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datawatch:monarch_pro:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.586:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datawatch:monarch_pro:6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datawatch:monarch_pro:7`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datawatch:monarch_pro:8`,
        fs:  `cpe:2.3:a:digium:asterisk:10.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:date_project:date:7.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:datemill:etano:1.22`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:349.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dattch:dattch_-_the_lesbian_app:0.3::~~~android~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:datumsystems:snip:-::~~~~psm-4500~`,
        fs:  `cpe:2.3:a:gentoo:app-crypt_pinentry:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:datumsystems:snip:-::~~~~psm-500~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daum:daum_maps_-_subway:3.9.1::~~~android~~`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daum_communications:daumgame_activex_control:1.1.0.4`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daum_communications:daumgame_activex_control:1.1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.553.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:daumcorp:daum_cloud:1.6.18::~~~android~~`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f2-s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:-`,
        fs:  `cpe:2.3:a:conky:conky:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:1.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:1.1.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:1.1.2`,
        fs:  `cpe:2.3:a:roy_baxter:better_revisions:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:1.1.3`,
        fs:  `cpe:2.3:o:dlink:dir865l_firmware:1.05b07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:1.1.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:1.1.5`,
        fs:  `cpe:2.3:a:apple:xcode:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:1.1.6`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_airlie:pam_smb:2.0_rc4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.2`,
        fs:  `cpe:2.3:a:erlang:crypto:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.3`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.4`,
        fs:  `cpe:2.3:a:digia:qt:4.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.7`,
        fs:  `cpe:2.3:h:cisco:cache_engine_505:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.8`,
        fs:  `cpe:2.3:a:foliovision:foliopress_wysiwyg:2.6.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_coffin:dcraw:0.8.9`,
        fs:  `cpe:2.3:a:google:v8:3.22.24.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_thomas:rdoc:2.3.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_thomas:rdoc:3.12`,
        fs:  `cpe:2.3:a:rsa:rsaref:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dave_thomas:rdoc:4.0.0`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_alkire:drag_%26_drop_gallery:6.x-1.5`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:0.12`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:0.14`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7`,
        fs:  `cpe:2.3:a:ibm:lotus_mobile_connect:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7.3`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7.3.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7.4.90`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7.4.91`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.1r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7.90`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:04-11-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7.91`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.60.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.7.92`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.8`,
        fs:  `cpe:2.3:a:sap:hybris:5.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.8.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.8.0.1`,
        fs:  `cpe:2.3:a:filehold:filehold_desktop_application:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.8.1`,
        fs:  `cpe:2.3:a:ca:license_software:0.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.9`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.6.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.9.2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.10`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.11`,
        fs:  `cpe:2.3:a:f5:linerate:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.11.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.11.1.1`,
        fs:  `cpe:2.3:a:openx:openx:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.11.1.2`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.11.90`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.11.92`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.13`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.13.5`,
        fs:  `cpe:2.3:h:axis:m1054_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.14`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p74:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.15`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.2:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.16`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.17`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.17.2`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:9.0.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.17.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.17.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:11.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.17.92`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.445:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.18`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.11:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.18.1`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.19`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.19.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.11.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.19.90`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.19.92`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.20`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.20.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.295:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.21`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:11.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.21.1`,
        fs:  `cpe:2.3:a:logitech:quickcam_for_enterprise:11.72.1069:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.21.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p41:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.21.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.21.90`,
        fs:  `cpe:2.3:a:cisco:emergency_responder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.21.91`,
        fs:  `cpe:2.3:a:adobe:robohelp:9.0.1.232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.21.92`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:2.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.22`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.22.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.22.2`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.23.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)ym4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.23.90`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_1700_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.23.91`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.23.92`,
        fs:  `cpe:2.3:h:cisco:br:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.24`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.24.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.6:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.25`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04:sp19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.25.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.25.4`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.25.5`,
        fs:  `cpe:2.3:a:icofx:icofx:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.25.90`,
        fs:  `cpe:2.3:a:artifex:mupdf:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.25.91`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.43:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.25.92`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.26`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.26.1`,
        fs:  `cpe:2.3:a:luracast:restler:1.4.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.26.2`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.27`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.2:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.27.5`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.27.90`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.16:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.27.91`,
        fs:  `cpe:2.3:a:mcafee:visual_trace:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.27.92`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.97a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.28`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.28.1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.1:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.28.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.23a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.28.3`,
        fs:  `cpe:2.3:a:bamboosolutions:bulk_import_application:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.31.4`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.31.91`,
        fs:  `cpe:2.3:a:debian:dpkg:1.15.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.32.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.32.1`,
        fs:  `cpe:2.3:a:rsa:authentication_agent_for_web:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.32.2`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.99.0`,
        fs:  `cpe:2.3:h:xerox:copycentre_c90:1.001.02.0715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.99.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.2.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.99.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.99.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.99.4`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.65.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:2.99.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.0.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-52c-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.0.2`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.0.3`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1.1`,
        fs:  `cpe:2.3:a:w-cms:w-cms:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1.2`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7931g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1.3`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1.4`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1.5`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1.90`,
        fs:  `cpe:2.3:a:netshinesoftware:com_netinvoice:2.0.10:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1.91`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.9m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.1.92`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.2.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.2.2`,
        fs:  `cpe:2.3:a:red-gate:sql_multiscript:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.3.1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.3.3`,
        fs:  `cpe:2.3:a:ibm:net.commerce_hosting_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.3.92`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.4.0`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.4.1`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.4.2`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.5.2`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_server:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.5.90`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.5.92`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.6.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.6.1`,
        fs:  `cpe:2.3:a:php:pear:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.6.2`,
        fs:  `cpe:2.3:h:hp:scanjet_3670c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_king:vino:3.7.3`,
        fs:  `cpe:2.3:a:mochiweb_project:mochiweb:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_leonard:pkstat:1.8.5`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_noguera_gutierrez:dalogin:2.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_noguera_gutierrez:dalogin:2.2.5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.2.7`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.3.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.238:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.4.0`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.4.1`,
        fs:  `cpe:2.3:a:trusteer:rapport:3.5.1108.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.4.2`,
        fs:  `cpe:2.3:a:dell:wyse_device_manager:4.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.0`,
        fs:  `cpe:2.3:h:cisco:ios:12.2ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.2`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.3`,
        fs:  `cpe:2.3:a:quagga:quagga:0.98.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.4`,
        fs:  `cpe:2.3:a:luke_herrington:stickynote:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.5`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:6.0:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.6`,
        fs:  `cpe:2.3:a:hp:network_automation:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.7`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.8`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.002:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.5.9`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.6.0`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.7.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.6.2`,
        fs:  `cpe:2.3:a:emerson:deltav:11.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.7.0`,
        fs:  `cpe:2.3:a:nobexrc:musica_de_barrios_sonideros:3.3.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.7.1`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:3.00.0633:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.7.1:beta3`,
        fs:  `cpe:2.3:a:cisco:finesse:9.1\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_paleino:wicd:1.7.2`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.2.0`,
        fs:  `cpe:2.3:h:hp:j9640a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.2.1`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.7:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.2.2`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.3.6`,
        fs:  `cpe:2.3:a:hp:color_laserjet_cp1210_series_toolbox:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.3.7`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.4.3`,
        fs:  `cpe:2.3:a:divx:directshowdemuxfilter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.5.0`,
        fs:  `cpe:2.3:a:altiris:energy_saver_toolkit:6.0.1214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.5.2`,
        fs:  `cpe:2.3:o:d-link:dsr-250n_firmware:1.01b46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.6.0`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.6.1`,
        fs:  `cpe:2.3:a:jenkins:git:2.6.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.6.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.6.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.546:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.6.4`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.6.5`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:6.1\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.7.0`,
        fs:  `cpe:2.3:a:plumtree:plumtree_foundation:6.0.1.218452:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.7.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.15.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.7.2`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.1`,
        fs:  `cpe:2.3:a:filemaker:filemaker_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.4`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.4:rc1`,
        fs:  `cpe:2.3:a:codiad:codiad:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.4:rc2`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.4:rc3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.5`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.6`,
        fs:  `cpe:2.3:a:simple_retail_menus_plugin_project:simple-retail-menus:4.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.7`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.8`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.9`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.a`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.b`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator_lite:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.c`,
        fs:  `cpe:2.3:a:apple:cups:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_shadoff:mednafen:0.8.d`,
        fs:  `cpe:2.3:a:rarlab:winrar:5.30:beta_4:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:david_stosik:comment_moderation:6.x-1.0`,
        fs:  `cpe:2.3:a:esri:arcgis:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:david_stosik:comment_moderation:6.x-1.x-dev`,
        fs:  `cpe:2.3:a:alhazai:leadership_newspapers:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.16:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.0b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:eby:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cypherpunks:pidgin-otr:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:cs2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gdb:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:perl:perl:5.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:yassl:cyassl:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:adobe_air:13.0.0.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:yaml-fuer-drupal:linkchecker:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:516:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.01:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.118:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.8.109.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:3.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:less:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:gentoo:linux:2.1.30:r9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:justsystems:hanako:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:rockwellautomation:flexlogix_l34_controller_firmware:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davidsneal:simple_share_buttons_adder:4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.0`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.1`,
        fs:  `cpe:2.3:a:lxml:lxml:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.2`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.2.1`,
        fs:  `cpe:2.3:a:apache:activemq:5.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.2.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.2.3`,
        fs:  `cpe:2.3:a:j2k-codec:j2k-codec:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.3`,
        fs:  `cpe:2.3:a:dojotoolkit:dojo:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.4`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.4.1`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-02-18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.4.2`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.14-62.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.4.3`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.4.4`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.4.5`,
        fs:  `cpe:2.3:a:crawlability:vbseo:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.4.6`,
        fs:  `cpe:2.3:a:digia:qt:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.23a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.2`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.3`,
        fs:  `cpe:2.3:o:huawei:s9312_firmware:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.5`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.6`,
        fs:  `cpe:2.3:a:webmin:webmin:1.640:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.7`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.8`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.9`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.10`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.11`,
        fs:  `cpe:2.3:h:hp:pa-risc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.12`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:davistribe:google_doc_embedder:2.5.13`,
        fs:  `cpe:2.3:a:moodle:moodle:1.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:db_backup_project:db_backup:4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:16.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0000_0`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0001_1`,
        fs:  `cpe:2.3:a:altiris:software_virtualization_solution:2.1.3062:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0001_2`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0001_3`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0002_1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.7\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0002_2`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0002_3`,
        fs:  `cpe:2.3:a:atlassian:confluence:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0002_4`,
        fs:  `cpe:2.3:a:mozilla:firefox:34.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0002_5`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0003_1`,
        fs:  `cpe:2.3:a:juniper:networks_mobility_system_software:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0004_1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0005`,
        fs:  `cpe:2.3:h:cisco:2100_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0005_1`,
        fs:  `cpe:2.3:a:ibm:system_data_repository:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0007_2`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0008_1`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_3_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:3.0009_1`,
        fs:  `cpe:2.3:a:ttfreeware:tigertoms_chat_room:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.00`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.001`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.10:build110519:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.002`,
        fs:  `cpe:2.3:a:microsoft:project_multilingual_user_interface_pack:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.003`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.004`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.005`,
        fs:  `cpe:2.3:h:huawei:s5700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.006`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.565.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.007`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.008`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.009`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.010`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.011`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.179.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.012`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a1:7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.013`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.014`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.015`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.480:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.016`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.017`,
        fs:  `cpe:2.3:a:hp:client_automation_core:7.80.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.018`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.019`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sru:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.020`,
        fs:  `cpe:2.3:a:freemind:freemind:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.021`,
        fs:  `cpe:2.3:a:altiris:power_scheme_task_language_pack:6.0.1002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.022`,
        fs:  `cpe:2.3:h:hp:jg402a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.023`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.024`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_epc3825:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.025`,
        fs:  `cpe:2.3:a:apache:apr-util:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.026`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.027`,
        fs:  `cpe:2.3:a:ibm:java_sdk:8.0.2.11:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.028`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.029`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.030_01`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.030_02`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.031`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.032`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.032_01`,
        fs:  `cpe:2.3:a:sunil_nanda:blue_wrench_video_widget:1.0.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.032_02`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.032_03`,
        fs:  `cpe:2.3:a:python:python:3.3.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.033`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2008.225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.033_01`,
        fs:  `cpe:2.3:a:actividentity:corestreet_server_validation_extension_dod_settings:1.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.033_02`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.5:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.033_03`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:57.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.034`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.035`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.035_01`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.035_02`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.035_03`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.036`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta50:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.037`,
        fs:  `cpe:2.3:a:absolutefuturity:af_imagegrabber:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.037_01`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.038`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.038_01`,
        fs:  `cpe:2.3:a:chickensys:instrument_manager:5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.039`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dbd-mysql_project:dbd-mysql:4.040`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dcraw_project:dcraw:7.00`,
        fs:  `cpe:2.3:a:productcart:productcart:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ddsn:cm3_acora_content_management_system:5.5.0%2f1b-p1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ddsn:cm3_acora_content_management_system:5.5.7%2f12b`,
        fs:  `cpe:2.3:h:hp:jg836a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ddsn:cm3_acora_content_management_system:6.0.2%2f1a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p353:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ddsn:cm3_acora_content_management_system:6.0.6%2f1a`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deakin:deakin_university:1.1.729.1694::~~~android~~`,
        fs:  `cpe:2.3:o:hp:mpe_ix:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.1.1`,
        fs:  `cpe:2.3:a:knowledgetree:knowledgetree:3.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.2.1`,
        fs:  `cpe:2.3:a:emc:rsa_data_protection_manager:20130918:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.3.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1012:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.4`,
        fs:  `cpe:2.3:a:x:libxtst:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.4.1`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.4.2`,
        fs:  `cpe:2.3:a:microsoft:project:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.4.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.4.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.5.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.5.2`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.5.3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.6`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.7`,
        fs:  `cpe:2.3:a:macromedia:jrun:4.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.7.1`,
        fs:  `cpe:2.3:a:authentec:atmininstall:7.10.0.1129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.8`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.8.1`,
        fs:  `cpe:2.3:a:ibm:monitoring_server_\(ms\)_and_shared_libraries_\(ax\):6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.8.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:adequate:0.9`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:amaya:-`,
        fs:  `cpe:2.3:a:tryton:trytond:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:amaya:9.2.1.6`,
        fs:  `cpe:2.3:a:oracle:database_server:9.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apache:-`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apache:1.3.34.4`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.0`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.1`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.1.1:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.2-0.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.10`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.11`,
        fs:  `cpe:2.3:a:typemoon:fate\/hollow_ataraxia:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.12`,
        fs:  `cpe:2.3:a:sophos:enterprise_console:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.13`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.14`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.15`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.15:exp1`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.15:exp2`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.4.254:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.15:exp3`,
        fs:  `cpe:2.3:a:hp:fortify_software_security_center:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.16`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.17`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.17:exp1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.17:exp2`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.17:exp3`,
        fs:  `cpe:2.3:a:freedownloadmanager:free_download_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.17:exp4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.18`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.19`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.20`,
        fs:  `cpe:2.3:o:juniper:junos:16.1:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.20.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.20.2`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.21`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.22`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.22.1`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.5.1:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.22.2`,
        fs:  `cpe:2.3:a:isc:dhcp_client:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.23`,
        fs:  `cpe:2.3:a:janusys:gridex_activex_control:2000b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.23.1`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.7.24`,
        fs:  `cpe:2.3:a:isc:bind:9.7.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.0:pre1`,
        fs:  `cpe:2.3:a:apache:struts:2.3.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.0:pre2`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.10.620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.3:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.10`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.10.1`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.10.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.10.3`,
        fs:  `cpe:2.3:a:digium:asterisk:12.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.11`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.11.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.11.2`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3040-ac-ovs-h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.11.3`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.11.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.11.5`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.12`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.13`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.13.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.13.2`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.14`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.14.1`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15`,
        fs:  `cpe:2.3:o:apple:os_x_server:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15:exp1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15:exp2`,
        fs:  `cpe:2.3:a:openproject:openproject:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15:exp3`,
        fs:  `cpe:2.3:a:oracle:mysql:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15.1`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15.6`,
        fs:  `cpe:2.3:a:apache:struts:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15.7`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15.8`,
        fs:  `cpe:2.3:a:gnome:glib:2.31.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15.9`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.15.10`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:0.8.16`,
        fs:  `cpe:2.3:a:apache:http_server:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:1.0.3`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt:1.0.4`,
        fs:  `cpe:2.3:a:symantec:data_insight:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt-cacher:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt-cacher:0.9.4`,
        fs:  `cpe:2.3:a:apache:struts:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt-cacher:0.9.9`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt-listchanges:-`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt-listchanges:2.81`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:-:pre7:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:apt-setup:-`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:axiom:20100701-1.1`,
        fs:  `cpe:2.3:a:apache:mod_python:1.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:backupninja:-`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:backupninja:0.8`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.16.0.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:base-config:-`,
        fs:  `cpe:2.3:a:mcafee:mcafee_virtual_technician:6.3.0.1911:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:base-config:2.53.10`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.1`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.2`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.3`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.4`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.7.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.5`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.6`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.7`,
        fs:  `cpe:2.3:a:redmine:redmine:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.8`,
        fs:  `cpe:2.3:a:skype:skype:0.94.0.19:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p256:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.10`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.0.1:-:ipad:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.11`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.12`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.13`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsdmainutils:6.0.14`,
        fs:  `cpe:2.3:a:otrs:otrs:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsmtpd:-`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.5116:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:bsmtpd:2.3`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.5.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:cfingerd:1.4.3-3`,
        fs:  `cpe:2.3:a:wave:wave_infrastructure_installer:7.2.40.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:cifs-utils:6.3`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control_option:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debian-goodies:-`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_performance_manager:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debian-goodies:0.27`,
        fs:  `cpe:2.3:h:lexmark:x646:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debian-goodies:0.33`,
        fs:  `cpe:2.3:a:kayako:fusion:4.50.1581:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debian-goodies:0.34`,
        fs:  `cpe:2.3:a:powerarchiver:powerarchiver:14.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:-`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:0.9.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:0.9.2`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.15.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:0.9.3`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.1:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:0.9.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg249a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:0.93`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:1.1`,
        fs:  `cpe:2.3:a:rewardingyourself:rewardingyourself:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:1.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:1.3`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:1.3.1`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.11:gamma:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:2.0`,
        fs:  `cpe:2.3:h:siemens:sinamics_s110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:2.0.5`,
        fs:  `cpe:2.3:a:emc:rsa_authentication_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:2.0.34`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:2.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.1.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:2.1.8.8.p3-1.1`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.3.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:2.2`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:2.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:3.0`,
        fs:  `cpe:2.3:o:cisco:headend_system_release:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:3.0.18`,
        fs:  `cpe:2.3:a:openstack:grizzly:2013.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:3.0.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:3.1`,
        fs:  `cpe:2.3:o:yahama:rtw65b:5.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:3.2.4`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:4.0`,
        fs:  `cpe:2.3:h:cisco:unified_computing_system_6296up_fabric_interconnect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:5.0`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:5.0.9`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:6.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:6.0.14`,
        fs:  `cpe:2.3:o:asus:rt-n10\&#43;d1_firmware:2.1.1.1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:6.2`,
        fs:  `cpe:2.3:a:getnycelightworks:get_nyce_lightworks:0.84.13506.98953:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:7.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random_2:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:7.1`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg510-20:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:8.0`,
        fs:  `cpe:2.3:a:pluxml:pluxml:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:debian:debian_linux:9.0`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(6\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debmake:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debmake:3.6`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debmake:3.6.9`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:7.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debmake:3.7`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.14:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:debmake:3.7.6`,
        fs:  `cpe:2.3:a:john_koleszar:libvpx:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.0`,
        fs:  `cpe:2.3:a:juniper:netscreen-security_manager_2004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.1`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:1.2.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_it_asset_management_for_it:7.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.3`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.4`,
        fs:  `cpe:2.3:a:google:chrome:7.0.521.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.5`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.6`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.7`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.8`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd7.d4xxv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.9`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.10`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.11`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.12`,
        fs:  `cpe:2.3:a:cisco:bams:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.13`,
        fs:  `cpe:2.3:h:huawei:s9300:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.3.14`,
        fs:  `cpe:2.3:a:web2py:web2py:1.87.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0`,
        fs:  `cpe:2.3:a:veritas:backup_exec_remote_agent:10.0.5484:sp3:windows_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.4`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.5`,
        fs:  `cpe:2.3:a:aol:aolserver:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.6`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.7`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.8`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd662a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.9`,
        fs:  `cpe:2.3:a:f5:big-iq_security:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.10`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.2.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.11`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.12`,
        fs:  `cpe:2.3:a:cisco:telepresence_management_suite:13.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.13`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.14`,
        fs:  `cpe:2.3:a:exim:exim:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.15`,
        fs:  `cpe:2.3:a:condor_project:condor:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.16`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.17`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.0.0-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.18`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.19`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.20`,
        fs:  `cpe:2.3:a:c4plans:k-tool:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.5.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.22`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.23.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.23.2`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.24`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.25`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.26`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.26.0.1`,
        fs:  `cpe:2.3:a:apple:quicktime:7.5.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.27`,
        fs:  `cpe:2.3:h:cisco:wireless_lan_controller:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.28`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.29`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.52:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.30`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.0.31`,
        fs:  `cpe:2.3:a:simgear:simgear:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.1`,
        fs:  `cpe:2.3:h:hp:cp1700_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.2`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.3`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.4`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.5`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.6`,
        fs:  `cpe:2.3:a:spip:spip:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.7`,
        fs:  `cpe:2.3:h:schneider-electric:bmxnor0200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.8`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.10:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.9`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.10`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.12`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.13`,
        fs:  `cpe:2.3:a:rovicorp:sonic_recordnow\!_plus:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.14`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.15`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.16`,
        fs:  `cpe:2.3:a:schneems:wicked:0.1.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.17`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30198:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.18`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.4.1.19`,
        fs:  `cpe:2.3:a:realvnc:realvnc:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.2`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.05.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.5`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.6`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.7`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.8`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:27.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.9`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.10`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.11`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.12`,
        fs:  `cpe:2.3:a:openstack:swift:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.12.99`,
        fs:  `cpe:2.3:a:hp:scannercopy:5.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.6.13`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.7.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.01.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.7.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.7.2`,
        fs:  `cpe:2.3:a:microsoft:access:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.8.0`,
        fs:  `cpe:2.3:a:martin_lee:multi-lingual_e-commerce_system:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.8.1`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:5.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.8.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.8.2`,
        fs:  `cpe:2.3:h:cisco:catalyst_8540msr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.8.3`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.8.3.1`,
        fs:  `cpe:2.3:a:docker:docker:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.9.0`,
        fs:  `cpe:2.3:a:vips:vips:7.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.9.4`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.10.10`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20140708:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.15.8.10`,
        fs:  `cpe:2.3:a:dlguard:dlguard:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.15.8.11`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.15.8.12`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.15.8.13`,
        fs:  `cpe:2.3:a:couponcabin_-_coupons_\&amp;_deals_project:couponcabin_-_coupons_\&amp;_deals:3.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.15.9`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.15.10`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.0.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1021:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)eu1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.0.3`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.1`,
        fs:  `cpe:2.3:a:fujitsu:interstage_studio:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.1.1`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.37:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.1.2`,
        fs:  `cpe:2.3:a:fortinet:fortimail:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.2`,
        fs:  `cpe:2.3:a:sun:grid_engine:5.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.3`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.4`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.2.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.4.1`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.15a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.4.2`,
        fs:  `cpe:2.3:a:david_king:vino:2.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.4.3`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.5`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.6`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.7`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.8`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.9`,
        fs:  `cpe:2.3:h:avocent:dsr2035:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.10`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.11`,
        fs:  `cpe:2.3:h:mcafee:web_gateway:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.12`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62f:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.14`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.16.15`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.0`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.1`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.2`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.3`,
        fs:  `cpe:2.3:h:hp:h3c_routing_switch:s9505e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.4`,
        fs:  `cpe:2.3:a:websense:websense_web_filter:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.5`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.6`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_4300e_ip_cameras:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.7`,
        fs:  `cpe:2.3:a:apple:apple_tv:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.8`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.9`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.10`,
        fs:  `cpe:2.3:a:webtrends:webservices:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.11`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.12`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.13`,
        fs:  `cpe:2.3:a:apple:cups:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.14`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp1:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.15`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.16`,
        fs:  `cpe:2.3:a:andrew_levine:multiblock:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.17`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.18`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.19`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.20`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.0-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.21`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.22`,
        fs:  `cpe:2.3:a:google:v8:3.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.23`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.24`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.17.25`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.0`,
        fs:  `cpe:2.3:h:htc:evo_design_4g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.3`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.4`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.5`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.6`,
        fs:  `cpe:2.3:a:citrix:access_management_console_knowledge_base:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.7`,
        fs:  `cpe:2.3:h:netgear:fvs318:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.8`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.35.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.9`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.0.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.10`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.11`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.12`,
        fs:  `cpe:2.3:a:cisco:application_velocity_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.13`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.14`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.15`,
        fs:  `cpe:2.3:h:cisco:7600_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.16`,
        fs:  `cpe:2.3:a:sympa:sympa:0.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.17`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p174:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.18`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.19`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.20`,
        fs:  `cpe:2.3:a:oracle:life_sciences_data_hub:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.21`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:6.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.22`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:dpkg:1.18.23`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:duplicity:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:duplicity:0.4.3-1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:elvis_tiny:-`,
        fs:  `cpe:2.3:a:samba:rsync:3.1.1:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:elvis_tiny:1.4.9`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:fsp:-`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:fsp:2.81.b18`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:fuse:2.9.3-14`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.17a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:gfax:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:gfax:0.4.2`,
        fs:  `cpe:2.3:h:zyxel:p-660hw-t1_2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:guilt:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je007a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:guilt:0.27`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:iceape:1.0.9`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:internet_message:-`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:internet_message:133-0`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:internet_message:141-0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.297:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:kde4libs:-`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:kernel-patch-vserver:-`,
        fs:  `cpe:2.3:a:gnu:aspell_dictionary:0.50-2:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:kernel-patch-vserver:1.9.5.5`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.2:-:commercial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:kernel-patch-vserver:2.2`,
        fs:  `cpe:2.3:a:google:updater:2.4.1536.6592:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:ldapscripts:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30121:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:ldapscripts:1.4`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control_10g:10.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:ldapscripts:1.7`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:libmail-audit-perl:-`,
        fs:  `cpe:2.3:a:logitech:mvision:10.40.1401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:libmail-audit-perl:2.1-5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:lintian:-`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:logol:1.5.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:-`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.7:*:pro:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)sx1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.11`,
        fs:  `cpe:2.3:a:apple:itunes:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.12`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.0.9:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.13`,
        fs:  `cpe:2.3:a:cisco:policy_suite:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.14`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.15`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.16`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.17`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.18`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:*:ru:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.19`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:4.3.0:cp03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.20`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.596.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.21`,
        fs:  `cpe:2.3:a:sap:sql_anywhere:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mime-support:3.52-1`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mit_kerberos:-`,
        fs:  `cpe:2.3:a:icz:sencha_sns:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mit_kerberos:4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mit_kerberos:5.1.2.4`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:mit_openafs:-`,
        fs:  `cpe:2.3:h:hp:ce995a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:netkit:-`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:netkit:0.07`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:netkit:0.17`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:netstd:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:netstd:3.07`,
        fs:  `cpe:2.3:h:axis:storpoint_cd\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:php5-common:5.3.2-1`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:php5-common:5.3.3-7%2bsqueeze4`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-1`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_manager:12.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-b5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-rc1`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-rc2-1`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-rc3-1`,
        fs:  `cpe:2.3:a:privatemsg_project:privatemsg:7.x-2.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-rc4-1`,
        fs:  `cpe:2.3:a:hp:hpssupply:2.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-rc5-1`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_30-60_poe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.0-rc7-1`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.1-1`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.2-1`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.2-2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.2-3`,
        fs:  `cpe:2.3:a:nullsoft:winamp:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.2-4`,
        fs:  `cpe:2.3:a:twibright:links:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.4-1`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg810-20:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.7-p1-1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.7-p1-2`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.7-p1-3`,
        fs:  `cpe:2.3:a:google:chrome:7.0.507.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.7-p1-4`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.7-p1-5`,
        fs:  `cpe:2.3:a:oracle:commerce_platform:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.9-1`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.10-1`,
        fs:  `cpe:2.3:a:web2py:web2py:2.0.1-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.10-2`,
        fs:  `cpe:2.3:a:php:php:5.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.11-1`,
        fs:  `cpe:2.3:a:apple:itunes:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.11-2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.11-3`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_ip_gateway_encoder_decoder:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.11-4`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:15.0.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:phpbb3:3.0.11-5`,
        fs:  `cpe:2.3:h:cisco:building_broadband_service_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:ppthtml:0.5.1`,
        fs:  `cpe:2.3:a:emc:replistor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:ppxp:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.28.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:python-imaging:-`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:qpopper:-`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.20:sp03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:qpopper:4.0.4`,
        fs:  `cpe:2.3:a:hdcar:exercitii_pentru_abdomen:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:qpopper:4.0.5`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reportbug:-`,
        fs:  `cpe:2.3:h:moxa:miineport_e1_4641:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reportbug:2.60`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reportbug:2.61`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reportbug:3.2`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:7.6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reportbug:6.4.4`,
        fs:  `cpe:2.3:a:dopewars:dopewars:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:1.3.0`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:1.3.1`,
        fs:  `cpe:2.3:a:barton:ngircd:20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:2.0.0`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:2.1.0`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.70.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:2.2.0`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:2.2.1`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:2.2.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.268:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:reprepro:2.2.3`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:sgml-tools:-`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow:-`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow:4.0.18.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.3.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.2`,
        fs:  `cpe:2.3:a:roxio:backontrack:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.4`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.4.1`,
        fs:  `cpe:2.3:a:webizz:apostilas_musicais:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.5`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.6`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:4.2\(1\)_sv1\(4a\):-:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.7`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:shadow-utils:4.0.14`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:9.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:strongswan:5.1.2`,
        fs:  `cpe:2.3:a:oracle:hyperion_strategic_finance:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:sympa:-`,
        fs:  `cpe:2.3:h:dell:precision_m6300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:sympa:3.3.3`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_server:6.1_build_21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:tetex-bin:-`,
        fs:  `cpe:2.3:a:hp:marketresearch:130.0.374.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:tetex-bin:2.0.2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:toolchain-source:-`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:toolchain-source:3.0.3-1`,
        fs:  `cpe:2.3:a:mozilla:firefox:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:toolchain-source:3.0.3-2`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:toolchain-source:3.0.3-3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:toolchain-source:3.0.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.2.8`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.2.9`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.2.9.1`,
        fs:  `cpe:2.3:a:microsoft:excel:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.2.9.2`,
        fs:  `cpe:2.3:a:rocomotion:p_link_compact:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.0`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.93:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.3`,
        fs:  `cpe:2.3:a:openproject:openproject:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.4`,
        fs:  `cpe:2.3:a:ca:common_services:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.5`,
        fs:  `cpe:2.3:a:pocketmags:craft_stamper_magazine:\@7f080183:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.6`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.7`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.8`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.9`,
        fs:  `cpe:2.3:a:honda:motolinc:1.6.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:trousers:0.3.10`,
        fs:  `cpe:2.3:a:debian:adequate:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:txt2man:1.5.5-2`,
        fs:  `cpe:2.3:a:hp:openview_select_access:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:txt2man:1.5.5-4`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:unp:-`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:unp:1.0.12`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.0:rollup_patch_1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.2.1-1`,
        fs:  `cpe:2.3:h:supermicro:x9drt-h6ibff:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.2.1-2`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:-:beta_2006.09.09:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.2.1-3`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.2.1-4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3-1`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.b1.3-4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.2-1`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.10:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-2`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-5`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-7`,
        fs:  `cpe:2.3:h:yokogawa:exaplog:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-8`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-9`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-10`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-11`,
        fs:  `cpe:2.3:a:rockwellautomation:factorytalk_services_platform:cpr9:sr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-12`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-13`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-14`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-15`,
        fs:  `cpe:2.3:a:goahead:goahead_webserver:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-16`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-17`,
        fs:  `cpe:2.3:a:google:v8:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-18`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-19`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-20`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.9.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-21`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-22`,
        fs:  `cpe:2.3:h:hp:laserjet_m3027_mfp:cb416a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-23`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-24`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3-25`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-3`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-4`,
        fs:  `cpe:2.3:a:php:ar_memberscript:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-6`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-7`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-8`,
        fs:  `cpe:2.3:a:piwik:piwik:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xbuffy:3.3.bl.3.dfsg-9`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debian:xsabre:0.2.4b`,
        fs:  `cpe:2.3:a:symantec:veritas_gridnode_agent:5.0.281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:debugbar:debugbar_for_internet_explorer:5.4.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deceiver:anahi_a_adopter_fr:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.334:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:decisions_project:decisions:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:server_message_block:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dedecms:dedecms:5.5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.306.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dedecms:dedecms:5.6`,
        fs:  `cpe:2.3:h:cisco:application_velocity_system_3110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deepnetexplorer:deepnet_explorer:1.5.3`,
        fs:  `cpe:2.3:h:cisco:sg300-28p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deer_hunting_calls_%2b_guide_project:deer_hunting_calls_%2b_guide:4.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:defa-online-image-protector_project:defa-online-image-protector:3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:defence:defence.pk:2.4.13.1::~~~android~~`,
        fs:  `cpe:2.3:a:file_project:file:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:degraaff:checkbot:1.75`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:degraaff:checkbot:1.77`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:1.5`,
        fs:  `cpe:2.3:a:mcafee:e-business_server:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:1.6`,
        fs:  `cpe:2.3:a:boost:boost:1.46.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:1.71`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:1.81`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-00-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:1.90`,
        fs:  `cpe:2.3:a:atlassian:jira:3.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:2.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:2.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.4:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:2.1.1`,
        fs:  `cpe:2.3:a:hp:database_and_middleware_automation:10.20.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:2.5`,
        fs:  `cpe:2.3:a:creative_core:app_lock:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:3.0`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:3.2`,
        fs:  `cpe:2.3:a:huawei:vcn500:v100r002c00spc200b010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:3.2.2`,
        fs:  `cpe:2.3:a:redhat:freeipa:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:3.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:3.4`,
        fs:  `cpe:2.3:o:franklinfueling:ts-550_evo_firmware:2.3.1.7492:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:3.5`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:4.0`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:4.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:4.5`,
        fs:  `cpe:2.3:a:hp:software_core_spanish_localization:6.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:4.6`,
        fs:  `cpe:2.3:a:exim:exim:4.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:4.7`,
        fs:  `cpe:2.3:a:ibm:global_retention_policy_and_schedule_management:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:4.8`,
        fs:  `cpe:2.3:h:huawei:ne40:v300r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:5.0`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:5.1`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:5.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg299a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:5.3`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_client:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:5.4`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:5.5`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:5.51`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.06.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:5.52`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:6.0`,
        fs:  `cpe:2.3:a:novell:internet_messaging_system:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:6.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:6.2`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution_assurance:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:6.3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:6.5`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1075.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:6.41`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-03-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.2`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.3`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.4`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.5`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.11`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.51`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.52`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:7.53`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:8.0.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.0`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3015_concentrator:4.1.7.l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.02`,
        fs:  `cpe:2.3:a:drupal:drupal:7.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.2`,
        fs:  `cpe:2.3:h:cisco:asa_5500:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.3`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.4`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.4.1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.4.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.5`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.5.1`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.5.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1.3s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.6`,
        fs:  `cpe:2.3:a:flurry:flurry-analytics-android:4.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.6.1`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.6.2`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:8.7`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.2.3sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:9.0`,
        fs:  `cpe:2.3:a:marekkis:watermark:0.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:9.0:b`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.2:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:9.1`,
        fs:  `cpe:2.3:a:adobe:connect:9.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:9.2`,
        fs:  `cpe:2.3:o:xen:xen:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:9.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.98:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:9.4`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.27.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.186.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.3`,
        fs:  `cpe:2.3:h:linksys:psus4_printserver:6032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.4`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.06.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.5.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.5.2`,
        fs:  `cpe:2.3:a:openstack:swift3:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:10.6`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.0`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.4`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.5`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.6.1`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cforms:11.7`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deliciousdays:cformsii:14.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:2161ds_kvm:2`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:3000cn:-`,
        fs:  `cpe:2.3:a:cairographics:cairo:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:3010cn:-`,
        fs:  `cpe:2.3:a:ibm:websphere_caching_proxy_server:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:3100cn:-`,
        fs:  `cpe:2.3:a:python-requests:requests:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:3110cn:-`,
        fs:  `cpe:2.3:a:projectsend:projectsend:157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:5100cn:-`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:5110cn:-`,
        fs:  `cpe:2.3:a:clamav:clamav:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:all_day_battery_life_configuration:1.1.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:asset_manager:9.0.0`,
        fs:  `cpe:2.3:a:apple:safari:1.0b1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:axim_x3:-`,
        fs:  `cpe:2.3:a:razorcms:razorcms:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:b2360dn:-`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.8.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:banctec_service_agreement:1.0.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:bioapi_framework:1.0.1`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:bioapi_framework:1.0.2`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a10`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.96.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a11`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a12`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a13`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a14`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a17`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a18`,
        fs:  `cpe:2.3:h:hp:procurve_switch_4000m:c.09.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:bios:a20`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_configuration_toolkit:1.0`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_configuration_toolkit:1.0.1`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:8.5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_configuration_toolkit:1.1`,
        fs:  `cpe:2.3:a:serf_project:serf:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_configuration_toolkit:1.2`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_configuration_toolkit:1.2.1`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_configuration_toolkit:2.0`,
        fs:  `cpe:2.3:a:atvise:webmi2ads:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_configuration_toolkit:2.0.1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_manager_agent:2.2.1019`,
        fs:  `cpe:2.3:a:hummingbird:bi_query:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:client_system_update:1.1.1`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:controlpoint_connection_manager:1.4.0`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:controlvault_diagnostics:1.1.38`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:controlvault_host_components_installer:1.7.324.55`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:controlvault_host_components_installer:1.7.450.290`,
        fs:  `cpe:2.3:a:quest:toad_data_modeler:3.4.15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:controlvault_host_components_installer:1.7.459.360`,
        fs:  `cpe:2.3:a:dell:openmanage:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:controlvault_host_components_installer:2.0.20.159`,
        fs:  `cpe:2.3:a:apache:camel:2.0.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:controlvault_host_components_installer:2.1.2.187::~~~~x64~`,
        fs:  `cpe:2.3:a:hp:smart_web_printing:2.15.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:controlvault_host_components_installer:2.2.30.355`,
        fs:  `cpe:2.3:a:emc:rsa_security_analytics:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:dataengine:5.1.0`,
        fs:  `cpe:2.3:a:ibm:security_privileged_identity_manager_virtual_appliance:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:dataengine:5.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:dvdsentry:1.0.0`,
        fs:  `cpe:2.3:a:nokia:affix:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:dw_wlan_card_utility:5.60.48.35`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:dw_wlan_card_utility:5.100.235.13`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.652:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:edoc_viewer:1.0.0`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:embassy_trust_suite_factory_installation:1.0.0`,
        fs:  `cpe:2.3:a:redhat:sendmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:equallogic_host_integration_tools:3.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)s15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:equallogic_host_integration_tools:3.5.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:equallogic_ps4000_firmware:6.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2116hc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:equallogic_san_headquarters:2.1.0.5342`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:help_and_support_customization:1.0.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:ibm_tape_diagnostic_tool:1.2.0.6::~~dell_customer_release~~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(4b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.0`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.1:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.1`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s7510e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.2`,
        fs:  `cpe:2.3:a:batavi:batavi:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.3`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_developer_suite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.5`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.24:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.6`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:idrac6_firmware:1.7`,
        fs:  `cpe:2.3:a:hp:loadrunner:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.7`,
        fs:  `cpe:2.3:a:openstack:icehouse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.8`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac6_firmware:1.95`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:idrac6_modular:3.60`,
        fs:  `cpe:2.3:a:hp:imc_service_operation_management_software_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:idrac6_monolithic:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:idrac6_monolithic:1.97`,
        fs:  `cpe:2.3:a:apple:java_1.6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:idrac7:-`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:idrac7:1.56.55`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac7_firmware:1.00.00`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac7_firmware:1.06.06`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac7_firmware:1.10.10`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac7_firmware:1.20.20`,
        fs:  `cpe:2.3:a:apache:jakarta_isapi_redirector:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac7_firmware:1.23.23`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.0:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac7_firmware:1.37.35`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:idrac7_firmware:1.40.40`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)mra1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:kace_k1000_systems_management_appliance:-`,
        fs:  `cpe:2.3:a:sap:guided_procedures_archive_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:kace_k1000_systems_management_appliance_software:5.4.76847`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:kace_k1000_systems_management_appliance_software:5.5.90545`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(3\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:kace_k1000_systems_management_virtual_appliance:-`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:kace_k1100s_systems_management_appliance:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:kace_k1200s_systems_management_appliance:-`,
        fs:  `cpe:2.3:a:buffalotech:wer-am54g54_firmware:1.12:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:kvm:-`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:kvm_1082ds:-`,
        fs:  `cpe:2.3:a:ca:brightstor_san_manager:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:kvm_2162ds:-`,
        fs:  `cpe:2.3:a:boka:siteengine:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:kvm_dmpu108e:-`,
        fs:  `cpe:2.3:a:macromedia:jrun:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:lasso:3.3.0.26`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:lasso:3.4.0.47`,
        fs:  `cpe:2.3:a:ibm:connections:5.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_2110_netbook:-`,
        fs:  `cpe:2.3:h:cisco:7500_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_d530:-`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_d531:-`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.7i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_d630:-`,
        fs:  `cpe:2.3:a:python:pillow:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_d631:-`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0599:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_d830:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e4200:-`,
        fs:  `cpe:2.3:a:installshield:isscript:3.0.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e4300:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e4310:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e5400:-`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e5410:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.536:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e5420:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e5500:-`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e5510:-`,
        fs:  `cpe:2.3:o:trustix:secure_linux:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e5520:-`,
        fs:  `cpe:2.3:a:compaq:survey_utility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6220:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6320:-`,
        fs:  `cpe:2.3:a:canon:dr-2020u_captureontouch:1.1.109.1119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6400:-`,
        fs:  `cpe:2.3:a:docker:docker:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6400_atg:-`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6400_atg_xfr:-`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6410_atg:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6420_atg:-`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.292:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6420_xfr:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6500:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6510:-`,
        fs:  `cpe:2.3:a:php:php:5.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_e6520:-`,
        fs:  `cpe:2.3:a:ubuntu_developers:language-selector:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_xt2:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_xt3:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.07.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:latitude_z600:-`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:md_storage_software:3.0.0.0`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:107sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:mobile_broadband_card_utility:2.05.07.27`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:networking_guide:1.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:online_diagnostics:2.10`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:online_diagnostics:2.12`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:online_diagnostics:2.15.0`,
        fs:  `cpe:2.3:a:python_bugzilla_project:python-bugzilla:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:online_diagnostics:2.17.0`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:online_diagnostics:2.18.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:-`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:3.2`,
        fs:  `cpe:2.3:a:ibm:sametime_proxy_server_and_web_client:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:3.4`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_deployment:10.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:3.5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:3.7`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:3.7.1`,
        fs:  `cpe:2.3:a:magzter:schon\!_magazine:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:3.8.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:4.1.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.44:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage:4.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(13\)s8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_active_directory_snap-in_utility:5.2.0`,
        fs:  `cpe:2.3:a:emc:networker:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_active_directory_snap-in_utility:6.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_baseboard_management_controller_utilities:4.2.0`,
        fs:  `cpe:2.3:a:social_stats_project:social_stats:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_cd:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_client_instrumentation:7.1.382`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_client_instrumentation:7.5.0.647`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_client_instrumentation:8.0.1.150`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_drac_tools:6.4.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_management_station:5.2.0`,
        fs:  `cpe:2.3:a:adobe:contribute_cs3:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_remote_access_components:3.20`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:2015.008.20082:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_remote_access_components:3.30`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_remote_access_components:3.31`,
        fs:  `cpe:2.3:a:ca:cleverpath_portal:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_remote_access_components:4.0.0`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:1.00.0000`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:4.3.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:4.4.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:4.5.0`,
        fs:  `cpe:2.3:a:kajona:kajona:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:5.0.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:5.1.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:5.1.0.1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.4\(0.876\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:5.2.0`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:5.3.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:5.4.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_data_services_platform:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:5.5.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:5.5.0.1`,
        fs:  `cpe:2.3:a:graphviz:graphviz:2.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:6.2.0`,
        fs:  `cpe:2.3:a:blaine_lang:filedepot:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:6.3.0`,
        fs:  `cpe:2.3:a:tony_freixas:ubercart_product_keys:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:6.4.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:6.5.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:6.5.0.1`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:7.0.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:7.0.0.1`,
        fs:  `cpe:2.3:a:google:earth:6.0.1.2032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:7.1.0`,
        fs:  `cpe:2.3:o:freebsd:freebsd:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:7.1.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_everyplace_server:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:7.2.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator:7.3.0`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.9.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator_installer:1.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator_instrumentation_service:5.1.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator_instrumentation_service:5.2.0`,
        fs:  `cpe:2.3:a:redhat:kon2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_administrator_lite:5.4.1`,
        fs:  `cpe:2.3:a:vmware:vrealize_operations:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.0`,
        fs:  `cpe:2.3:a:apple:cups:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.2.1`,
        fs:  `cpe:2.3:a:citrix:metaframe_secure_access_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.3`,
        fs:  `cpe:2.3:h:hp:3com_router:5640:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.4`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.4.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.5`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.100`,
        fs:  `cpe:2.3:a:abbyy:finereader:10.0:-:site_license:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:openmanage_server_agent:4.120`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:optiplex_390:-`,
        fs:  `cpe:2.3:a:montala:resourcespace:4.1.2567:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:optiplex_790:-`,
        fs:  `cpe:2.3:h:supermicro:x8dtu-6f\&#43;-lr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:optiplex_990:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powerconnect_5324:-`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powerconnect_5324:1.0.0.45`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powerconnect_5324:1.0.0.47`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powerconnect_6224:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powerconnect_6224f:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:597:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powerconnect_6224p:-`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powerconnect_6248:-`,
        fs:  `cpe:2.3:a:atlassian:jira:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powerconnect_6248p:-`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_1950:-`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_2600:-`,
        fs:  `cpe:2.3:a:tumbleweed:desktop_validator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_2800:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_2850:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)se5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_2900:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_2950:-`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.7.22161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:poweredge_diagnostics:2.7`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:poweredge_diagnostics:2.8`,
        fs:  `cpe:2.3:a:rsa:envision:4.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:poweredge_diagnostics:2.9`,
        fs:  `cpe:2.3:a:inboundnow:call_to_action:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_r610:-`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_r710:-`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_r720:-`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_r910:-`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_sc1435:-`,
        fs:  `cpe:2.3:h:hp:3com_router:5009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:poweredge_server_6650:-`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powervault_ml6000:32u`,
        fs:  `cpe:2.3:a:sun:ray_server_software:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powervault_ml6000:41u`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:powervault_ml6000_firmware:585g.gs003`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:powervault_ml6000_firmware:590g.gs00100`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:powervault_ml6000_firmware:i8.2.0.1_%28641g.gs003%29`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd241b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:powervault_ml6000_firmware:i8.2.0.2_%28641g.gs103%29`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powervault_ml6010:5u`,
        fs:  `cpe:2.3:a:digium:asterisk:10.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powervault_ml6020:14u`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powervault_ml6030:23u`,
        fs:  `cpe:2.3:a:sun:rte:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:powervault_modular_disk_storage_manager:3.35.x6.37`,
        fs:  `cpe:2.3:a:php-nuke:news_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:powervault_modular_disk_storage_manager:3.35.x6.50`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.580:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powervault_tl2000:-`,
        fs:  `cpe:2.3:a:saltstack:salt:0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:powervault_tl4000:-`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:pre-boot_authentication_driver:1.0.1.5`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.980:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_m2300:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_m2400:-`,
        fs:  `cpe:2.3:a:gunbroker:gunbroker.com:1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_m4300:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_m4400:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.480.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_m6300:-`,
        fs:  `cpe:2.3:h:sierrawireless:raven_x_ev-do:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_m6400:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_m6500:-`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.0.1_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_mobile_m4500:-`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:8.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_mobile_m4600:-`,
        fs:  `cpe:2.3:a:microsoft:background_intelligent_transfer_service:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_mobile_m6600:-`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_t1600:-`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_t3600:-`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_t5600:-`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:precision_t5600_xl:-`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20080303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:printer_software:1.0.0`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:quest_one_password_manager:5.0`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.1.1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:quickset:7.1.10`,
        fs:  `cpe:2.3:a:pecio-cms:pecio_cms:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:remote_access_card:-`,
        fs:  `cpe:2.3:a:adobe:camera_raw:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:remote_access_card:4`,
        fs:  `cpe:2.3:a:php:php:4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:remote_access_configuration_tool:1.0.0`,
        fs:  `cpe:2.3:a:feedweb:feedweb:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:remote_console_switch_software:3.0.0.16`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:repository_manager:1.1.52`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:repository_manager:1.2.155`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:repository_manager:1.3.124`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:resource_cd:1.0.0`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:resource_cd:1.10.0`,
        fs:  `cpe:2.3:a:avaya:vpnremote:4.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:secureworks:2.0.6::~~~iphone_os~~`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:server_e-support_tool:1.0.19.4`,
        fs:  `cpe:2.3:a:e107:e107:0.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:solution_center:1.0.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_analyzer:7.2`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_analyzer:7.2:sp1`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.43:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_analyzer:8.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_analyzer:8.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_email_security:7.5`,
        fs:  `cpe:2.3:a:red-gate:sql_packager:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_global_management_system:7.0`,
        fs:  `cpe:2.3:a:symantec:ghost_console_client:110.2.1573:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_global_management_system:7.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_global_management_system:7.1:sp1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.328:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_global_management_system:7.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_global_management_system:7.2:sp1`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_global_management_system:8.0`,
        fs:  `cpe:2.3:o:cisco:conference_connection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_global_management_system:8.1`,
        fs:  `cpe:2.3:a:ibm:db2:11.1.0.0:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_netextender_firmware:7.5.1.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_netextender_firmware:8.0.0.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_netextender_firmware:8.0.0.1`,
        fs:  `cpe:2.3:a:phorum:phorum:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_netextender_firmware:8.0.0.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:sonicwall_network_security_appliance_2400:-`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.9:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:8.6.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:8.6.2:-:free`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:9.0.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:9.0.0:-:free`,
        fs:  `cpe:2.3:a:packetfence:packetfence:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:9.0.1`,
        fs:  `cpe:2.3:a:instantphp:jobs_pro:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:9.0.1:-:free`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:9.5.0`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:9.5.0:-:free`,
        fs:  `cpe:2.3:a:physicsforums:physics_forums:3.9.22:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:9.5.2`,
        fs:  `cpe:2.3:a:condor_project:condor:7.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:9.5.2:-:free`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:11.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jb1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer:11.0.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer_with_flow_analytics_module:8.6.2:-:pay`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1654.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer_with_flow_analytics_module:9.0.0:-:pay`,
        fs:  `cpe:2.3:a:microsoft:xml_core_services:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer_with_flow_analytics_module:9.0.1:-:pay`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer_with_flow_analytics_module:9.5.0:-:pay`,
        fs:  `cpe:2.3:a:adobe:graphics_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:sonicwall_scrutinizer_with_flow_analytics_module:9.5.2:-:pay`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_secure_remote_access_firmware:7.5.1.0-38sv`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_secure_remote_access_firmware:8.0.0.1-16sv`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1n:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_sonicos:6.2.2.0`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_sonicos:7.5.0.12`,
        fs:  `cpe:2.3:a:profile2_privacy_project:profile2_privacy:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_uma_em5000_firmware:7.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_uma_em5000_firmware:8.0`,
        fs:  `cpe:2.3:h:fortinet:fortigate-3700d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dell:sonicwall_uma_em5000_firmware:8.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:sonicwall_umaem5000:-`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:5.2.0:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:support:2.1.0.0`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_customization_wizard:1.0.0`,
        fs:  `cpe:2.3:a:zipcar:zipcar:3.4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_e-support_tool:1.4.0`,
        fs:  `cpe:2.3:a:ericsson:drutt_mobile_service_delivery_platform:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_e-support_tool:1.5.0`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.1.0.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_e-support_tool:1.6`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_e-support_tool:1.7`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_e-support_tool:1.8`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_e-support_tool:2.0`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_e-support_tool:2.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_e-support_tool:2.2`,
        fs:  `cpe:2.3:h:cisco:guard:5.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_manager:1.5.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_manager:1.6.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:system_manager:1.7.10000`,
        fs:  `cpe:2.3:a:horde:gollem:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:toolbar:1.8.9.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.1:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1.102.7`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.2.101.215`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.10.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.2.101.216`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.2.101.230`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.1.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1002.101.102`,
        fs:  `cpe:2.3:a:microsoft:office_communicator:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1006.101.111`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.311:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1006.101.118`,
        fs:  `cpe:2.3:h:hp:laserjet_p3005:q7812a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1007.101.210`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.97.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1102.101.102`,
        fs:  `cpe:2.3:h:cisco:c240_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1107.101.210`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1207.101.108`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1207.101.220`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:7.1208.101.116`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:touchpad:version_7.1.101.6`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:truemobile_1300_wlan_mini-pci_card_util_trayapplet:-`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.7.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:truemobile_2300_wireless_broadband_router:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:truemobile_2300_wireless_broadband_router:3.0.0.8`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:truemobile_2300_wireless_broadband_router:5.1.1.6`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20091017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:upek_touchchip_fingerprint_reader:1.2.0`,
        fs:  `cpe:2.3:a:pantech:pc_usb_modem_software:1.2.7000.720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:upek_touchchip_fingerprint_reader:1.2.4`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:w5300:-`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wireless_wlan_card_driver:4.100.15.5`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.52:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wireless_wlan_card_driver:4.100.15.8`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wyse_device_manager:4.7.0`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.0:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wyse_device_manager:4.7.1`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wyse_device_manager:4.7.2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wyse_device_manager:4.8.0`,
        fs:  `cpe:2.3:a:hp:data_protector_media_operations:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wyse_device_manager:4.8.5`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s7503e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wyse_device_manager:4.9.0`,
        fs:  `cpe:2.3:a:zippyyum:subway_ordering_for_california:3.4:-:-:*:-:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:wyse_device_manager:4.9.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dell:wyse_p25:-`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dell:xtalk_management_console:5.4.5.0`,
        fs:  `cpe:2.3:a:sharp:sharpdesk:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deloitte:eitdr_service:1.0.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.10:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:delrina:form_flow:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deltek:open_plan_professional:3.2.0.864`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:*:x32-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deltek:open_plan_professional:3.3.1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.6:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:deltek:open_plan_professional:3.3.2`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deltek:risk_%2b:2.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deltek:winsight:4.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deltek:winsight:5.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deluge-torrent:deluge:1.3.14`,
        fs:  `cpe:2.3:a:hp:6500_e709_edocs:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:demandmedia:pluck_sitelife:5.0.12`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:demandmedia:pluck_sitelife:5.0.13`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:demarque:typing_pal:1.0`,
        fs:  `cpe:2.3:a:carahsoft:jabber_xcp:5.4.0.14409:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:demosphere:agc:3.76`,
        fs:  `cpe:2.3:a:citrix:xenapp_advanced_configuration:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:demosphere:agc:3.80`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:denki:juggle%21_free:3.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dennis_bruecke:jquery_countdown:7.x-1.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:denon:avr-3313ci:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.0.1`,
        fs:  `cpe:2.3:a:sun:embedded_lights_out_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p139:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.0.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.0.4`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.0.5`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.1`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.1.1`,
        fs:  `cpe:2.3:a:ibm:director_agent:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deon_george:phpldapadmin:1.2.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:designsandcode:forget-about-shorcode-buttons:1.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:designtoolkits:blocked_in_free:1::~~~android~~`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:desire2learn_fusion_2014_project:desire2learn_fusion_2014:4.0.729.1748::~~~android~~`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-rc4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:deskroll:deskroll_remote_desktop:0.6::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deskshare:auto_ftp_manager:4.31`,
        fs:  `cpe:2.3:a:apache:camel:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:deskshare:auto_ftp_manager:5.13`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:desktopstandard:policymaker_application_security_client:2.0.114`,
        fs:  `cpe:2.3:a:altiris:console_documentation:6.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:desktopstandard:policymaker_registry_extension:2.5.1117`,
        fs:  `cpe:2.3:a:kde:koffice:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:desktopstandard:policymaker_software_update_client:2.0.133`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dessci:mathplayer:2.1d`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.2.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:beta2:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.3.0.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.3.0.1`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.3.1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.3.2.0`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.3:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.3.2.1`,
        fs:  `cpe:2.3:o:vmware:esx:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.3.2.2`,
        fs:  `cpe:2.3:a:pansi:pansi_sms:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.4.0.0`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.4.0.1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.4.0.2`,
        fs:  `cpe:2.3:o:huawei:p8_firmware:gra-tl00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.4.0.3`,
        fs:  `cpe:2.3:a:php:php:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.4.1.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.768.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.4.2.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.4.3.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_update_manager:4.1.0.5142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.4.3.1`,
        fs:  `cpe:2.3:a:microsoft:activesync:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.5.0.0`,
        fs:  `cpe:2.3:a:apple:mdnsresponder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.6.0.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.6.0.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.0.0`,
        fs:  `cpe:2.3:a:atutor:acontent:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.0.1`,
        fs:  `cpe:2.3:h:hp:officejet_5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.1.0`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.1.1`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.1.2`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.1.3`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.2.0`,
        fs:  `cpe:2.3:h:avaya:sg208:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.2.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_6509-v-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.2.2`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:1.7.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8b\)e14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:2.0.0:b1`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:2.0.0:b2`,
        fs:  `cpe:2.3:a:hp:image_zone_express:1.5.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:2.0.0:b3`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.8:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:2.0.0:b4`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:2.0.0:b5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.374.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:2.0.0:b6`,
        fs:  `cpe:2.3:h:siemens:scalance_x204irt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dest-unreach:socat:2.0.0:b7`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:detlef_pilzecker:proc%3a%3aadaemon-run_perl:0.14`,
        fs:  `cpe:2.3:h:ovislink:airlive_poe250hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dev4press:gd_star_rating:19.22::~~~wordpress~~`,
        fs:  `cpe:2.3:a:interworx:web_control_panel:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devada_project:devada:1.2::~~~android~~`,
        fs:  `cpe:2.3:h:d-link:dcs-6010l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devarai:word_search_free:4.9::~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp2:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:developer_log_project:developer_log:2.11.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:ajax_control_toolkit:15.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.7:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.142.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.3`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.4`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor_le:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-71-\/f:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.6`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.42a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.8`,
        fs:  `cpe:2.3:a:symantec:network_access_control:11.0.6200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.9`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2009.0113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.10`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.4`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.45.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.5`,
        fs:  `cpe:2.3:a:novell:groupwise_webaccess:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.6`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.7`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.67:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.8`,
        fs:  `cpe:2.3:a:jenkins:git:0.9.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.9`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.10`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.11`,
        fs:  `cpe:2.3:a:appeak:poker:2.4.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.12`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.5`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.8`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_24.39:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.10`,
        fs:  `cpe:2.3:o:cisco:ons_15600:1.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.11`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:el:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.12`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.13`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110926:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.14`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf812a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.4`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.9:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.5`,
        fs:  `cpe:2.3:a:iojs:io.js:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.7`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-255:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.8`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.9`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.10`,
        fs:  `cpe:2.3:a:dell:openmanage:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.11`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.2:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.12`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2`,
        fs:  `cpe:2.3:o:hp:openvms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.4`,
        fs:  `cpe:2.3:a:apple:server_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.5`,
        fs:  `cpe:2.3:h:cisco:spa_303_3_line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.6`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.7`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.8`,
        fs:  `cpe:2.3:o:cisco:staros:19.0.m0.60737:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.10`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.11`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.12`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.13`,
        fs:  `cpe:2.3:a:gnome:evolution:2.28.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.15`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_designer:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.16`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.4`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.5`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.04:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.6`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.7`,
        fs:  `cpe:2.3:a:nuance:omnipage:10.0:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.8`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.9`,
        fs:  `cpe:2.3:a:oracle:forms:9i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.10`,
        fs:  `cpe:2.3:a:cisco:webns:8.20.4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.9.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.5`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.6`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.7`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.8`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.9`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devexpress:devexpress_components:2011.1`,
        fs:  `cpe:2.3:a:sap:router:710:029:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:6.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:6.1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:6.1.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.8.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:6.2`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.0.0.4080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:6.2.1`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:6.3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:6.4`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:6.4.1`,
        fs:  `cpe:2.3:a:corel:pdf_fusion:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:7.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devicelock:devicelock:7.1.36106`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.7`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.8`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.9`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.10`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.11`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.12`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.2.77:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.13`,
        fs:  `cpe:2.3:a:haxx:curl:7.38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.14`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:2.0.15`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.0`,
        fs:  `cpe:2.3:a:buddhist_prayer_project:buddhist_prayer:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.1`,
        fs:  `cpe:2.3:a:hp:mercury_monitor_over_firewall:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.2`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.3`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.4`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.15:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.6`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.7`,
        fs:  `cpe:2.3:a:dzcp:dev\!l\&#39;z_clanportal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.8`,
        fs:  `cpe:2.3:h:korenix:jetport:5601f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.9`,
        fs:  `cpe:2.3:a:isc:bind:4.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.10`,
        fs:  `cpe:2.3:a:htc:hero_software:2.27.651.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.11`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:3.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:3.0.12`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.1`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.3`,
        fs:  `cpe:2.3:o:hp:mpe_ix:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)sp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.5`,
        fs:  `cpe:2.3:h:dell:5100cn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.6`,
        fs:  `cpe:2.3:a:juniper:netscreen_remote_vpn_client:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.7`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.8`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.9`,
        fs:  `cpe:2.3:a:apache:struts:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.10`,
        fs:  `cpe:2.3:a:varnish_http_accelerator_integration_project:varnish:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.11`,
        fs:  `cpe:2.3:a:mcafee:application_control:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.12`,
        fs:  `cpe:2.3:a:corel:coreldraw:x3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:4.0.13`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2010.302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.0`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.2`,
        fs:  `cpe:2.3:a:hp:sitescope_server:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.3`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.4`,
        fs:  `cpe:2.3:a:nuance:smart_document_scan_software:2.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.6`,
        fs:  `cpe:2.3:a:openttd:openttd:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.7`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.8`,
        fs:  `cpe:2.3:a:otrs:otrs:1.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.9`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.10`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.11`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.12`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.13`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.14`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.15`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_for_plsql:10.1.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.16`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.17`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator:3.3.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.18`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.19`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devincentiis:gazie:5.20`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:best_responsive:7.x-1.0`,
        fs:  `cpe:2.3:a:kryo:iodine:0.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.0`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.1`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.2`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:5550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.3`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.4`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.5`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.6`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.7`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.8`,
        fs:  `cpe:2.3:o:supermicro:intelligent_platform_management_firmware:2.24:-:-:*:-:-:x9_generation_motherboards:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:business:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:sun:jre:6.0.150:update15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:clean_theme:7.x-1.0`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:clean_theme:7.x-1.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.1.0.0\(209\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:clean_theme:7.x-1.2`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:company:7.x-1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:company:7.x-1.1`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:007sh:kt:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:company:7.x-1.2`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:company:7.x-1.3`,
        fs:  `cpe:2.3:a:oracle:virtualization:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:corporate:7.x-1.0`,
        fs:  `cpe:2.3:a:monotone:monotone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:corporate:7.x-1.1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:corporate:7.x-1.2`,
        fs:  `cpe:2.3:h:hp:jg409a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:corporate:7.x-1.3`,
        fs:  `cpe:2.3:a:keepass:keepass:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:creative:7.x-1.0`,
        fs:  `cpe:2.3:a:samba:samba:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:creative:7.x-1.1`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:fresh:7.x-1.0`,
        fs:  `cpe:2.3:o:cisco:voip_phone_cp-7960:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:fresh:7.x-1.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:fresh:7.x-1.2`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:fresh:7.x-1.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:fresh:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:professional_theme:7.x-1.0`,
        fs:  `cpe:2.3:a:ubi:rayman_legends:1.2.103716:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:professional_theme:7.x-1.1`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:professional_theme:7.x-1.2`,
        fs:  `cpe:2.3:a:novell:client:4.91:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:professional_theme:7.x-1.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:professional_theme:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive:7.x-1.0`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive:7.x-1.1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive:7.x-1.2`,
        fs:  `cpe:2.3:h:hp:6600_firewall_processing_rtr_module:jd250a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive:7.x-1.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive:7.x-1.4`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive:7.x-1.5`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.195:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive_blog:7.x-1.0`,
        fs:  `cpe:2.3:a:dell:online_diagnostics:2.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive_blog:7.x-1.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive_blog:7.x-1.2`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.5\(1\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive_blog:7.x-1.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive_blog:7.x-1.4`,
        fs:  `cpe:2.3:a:microsoft:netmeeting:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devsaran:responsive_blog:7.x-1.5`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.2`,
        fs:  `cpe:2.3:a:apple:xcode:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.4`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.5`,
        fs:  `cpe:2.3:a:adobe:creative_suite_4_web_standard:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.6`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.7`,
        fs:  `cpe:2.3:a:yahoo:yui:2.9.0:pr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.13.8`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:devscripts_devel_team:devscripts:2.14.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dexis:imaging_suite:10.0`,
        fs:  `cpe:2.3:a:namazu:namazu:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dflabs:ptk:1.0.5`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0`,
        fs:  `cpe:2.3:a:rssreader:rssreader:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:alpha1`,
        fs:  `cpe:2.3:o:redhat:linux:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:alpha2`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:alpha3`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta1`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta2`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta3`,
        fs:  `cpe:2.3:h:cisco:ids_4210:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta4`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0-23:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta6`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta7`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta8`,
        fs:  `cpe:2.3:a:webform_invitation_project:webform_invitation:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:beta9`,
        fs:  `cpe:2.3:a:expressjs:express:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:rc1`,
        fs:  `cpe:2.3:a:redhat:rhel_extras:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:rc2`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:rc3`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:rc4`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.11:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.0:rc5`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.1`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.3`,
        fs:  `cpe:2.3:a:dell:openmanage:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.4`,
        fs:  `cpe:2.3:a:symantec:raptor_firewall:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.5`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.6`,
        fs:  `cpe:2.3:a:altiris:symantec_endpoint_protection_integration_component_documentation:6.0.1008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.7`,
        fs:  `cpe:2.3:a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.10`,
        fs:  `cpe:2.3:a:cabextract:cabextract:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.11`,
        fs:  `cpe:2.3:a:lxml:lxml:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.12`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:6.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.13`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.14`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.5.10\(3648\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:4.0.15`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management:10.1:*:*:*:collaborative:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.0.0`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_appliance:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.0.1`,
        fs:  `cpe:2.3:a:emc:avamar_plugin:6.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.0.3`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.30:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.0.4`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.0.6`,
        fs:  `cpe:2.3:a:novell:suse_lifecycle_management_server:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.0.7`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5c\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.0.9`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.1.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.1.1`,
        fs:  `cpe:2.3:a:agi:stk\/kml_utility_for_stk:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.1.2`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.1.3`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.1.4`,
        fs:  `cpe:2.3:a:isc:bind:9.10.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.1.5`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:14-12-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.3`,
        fs:  `cpe:2.3:a:apple:itunes:4.9.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.4`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.5`,
        fs:  `cpe:2.3:a:busybox:busybox:1.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.7`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.8`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.9`,
        fs:  `cpe:2.3:a:ilch:ilch_cms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.10`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.1.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.11`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.2.12`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.5.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.5.1`,
        fs:  `cpe:2.3:a:emc:navisphere_command_line_interface:28.20.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.5.1:test1`,
        fs:  `cpe:2.3:o:dell:powervault_ml6000_firmware:i8.2.0.2_\(641g.gs103\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.5.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-00-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.5.3`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.5.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.5.5`,
        fs:  `cpe:2.3:a:extplorer:com_extplorer:2.1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.5.6`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.1`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.2`,
        fs:  `cpe:2.3:h:f5:firepass_4300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.3`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.4`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.2:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.5`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.6`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.7`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.06.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.6.8`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.99.2`,
        fs:  `cpe:2.3:a:apache:solr:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.99.3`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.99.4`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.10.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.99.5`,
        fs:  `cpe:2.3:a:google:earth:5.1.3533.1731:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.99.6`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:5.99.7`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.0.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.0.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.0.2`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.0.3`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.0.4`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.0.5`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.1.0`,
        fs:  `cpe:2.3:a:bepopapp:like4like\:get_instagram_likes:2.1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.2.0`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.22.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.2.1`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.3.0`,
        fs:  `cpe:2.3:a:utorrent:utorrent:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.3.1`,
        fs:  `cpe:2.3:a:foolabs:xpdf:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.3.2`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.4.0`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.4.1`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.4.2`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.4.3`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhcpcd_project:dhcpcd:6.9.4`,
        fs:  `cpe:2.3:a:varnish_http_accelerator_integration_project:varnish:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhims:ahlta:3.6.0.34`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.4.3:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhtmlx:dhtmlxspreadsheet:1.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:networker:7.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dhtmlx:dhtmlxspreadsheet:2.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diabetes:diabetes_forum:3.9.30::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diabetic_diet_guide_project:diabetic_diet_guide:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diafan:diafan.cms:5.0`,
        fs:  `cpe:2.3:h:3com:3c17300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dialogic:brooktrout_system_software:5.1.3`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dialogic:host_media_processing_software_release:3.0.225:service_update_225`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:die-netzmacher:browser:4.5.0`,
        fs:  `cpe:2.3:a:acquia:commons:7.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:die-netzmacher:browser:4.5.2`,
        fs:  `cpe:2.3:a:scott_reynen:node_embed:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:die-netzmacher:browser:4.5.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:die-netzmacher:browser:4.5.6`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:differencegames:hidden_memory_-_aladdin_free%21:1.0.31::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:7.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:differencegames:hidden_object_-_alice_free:1.0.17::~~~android~~`,
        fs:  `cpe:2.3:h:zyxel:p-660h-61:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:digi:cm:-`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:digi:cm:32`,
        fs:  `cpe:2.3:a:tincan:phplist:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digi:www_server:-`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digi:www_server:compieuw`,
        fs:  `cpe:2.3:a:digium:asterisk:12.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digi:www_server:compieuw:beta1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digi:www_server:compieuw:beta2`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:1.41`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:1.42`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_service:3.3.782:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:1.43`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:1.44`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:1.45`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:2.0.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:2.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.157.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:2.0.2`,
        fs:  `cpe:2.3:a:smarty:smarty:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:3.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xg5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:3.3.1`,
        fs:  `cpe:2.3:a:nagios:nagios:4.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:3.3.2`,
        fs:  `cpe:2.3:a:sap:enterprise_resource_planning:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:3.3.3`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:3.3.4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:3.3.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:3.3.6`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.1.0r3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.0.0`,
        fs:  `cpe:2.3:a:freesshd:freesshd:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.0.1`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.1.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.907.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.1.1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.1.2`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.1.3`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.1.4`,
        fs:  `cpe:2.3:a:redhat:openshift:2.0.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.1.5`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.2`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.0:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.2.0`,
        fs:  `cpe:2.3:h:axis:2400_video_server:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.2.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.2.3`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.3.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.9.4:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.3.2`,
        fs:  `cpe:2.3:o:cisco:cisco_ons_15454_system_software:9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.3.3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.700.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.3.4`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.3.5`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.2:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.4.0`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.4.1`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.4.2`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x51:d21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.4.3`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.5.0`,
        fs:  `cpe:2.3:a:opcsystems:opcsystems.net:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.5.1`,
        fs:  `cpe:2.3:h:hp:jg704a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.5.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.5.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.6.0`,
        fs:  `cpe:2.3:a:docker:docker:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.6.0:rc1`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.6.1`,
        fs:  `cpe:2.3:a:jease:jease:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.6.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.6.4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.6.5`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.6.5:rc`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.7.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.7.1`,
        fs:  `cpe:2.3:a:apple:xsan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.7.2`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:5.6.0.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.7.3`,
        fs:  `cpe:2.3:a:microsoft:isa_server:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.7.4`,
        fs:  `cpe:2.3:h:polycom:converged_management_application_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.7.5`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.7.6`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.1.10411.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.7.6:rc`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.8.0`,
        fs:  `cpe:2.3:a:trihedral:vtscada:8.1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.8.1`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.8.2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-28p-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.8.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.8.4`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:4.8.5`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:5.0.0`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:5.0.1`,
        fs:  `cpe:2.3:a:wp_media_cleaner_project:wp_media_cleaner:2.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:5.0.2`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:5.1.0`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:5.2.0`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:5.2.1`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:5.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digia:qt:5.4.1`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digifi:motoring_classics:1.8.6::~~~android~~`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digimobistudio:qq_copy:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:0.99.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digineo:thumbshooter:0.1.5`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalfruit:mootorratturid_%26_biker.ee:1::~~~android~~`,
        fs:  `cpe:2.3:o:yamaha:rtx1200:10.01.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitaljuice:juicer:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.1`,
        fs:  `cpe:2.3:a:openstack:keystone:2014.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.2`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.3`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:*:x32-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.3.1`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.4.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.4.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.4.5`,
        fs:  `cpe:2.3:a:typo3:typo3:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.4.6`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:1.4.7`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:2.0.4`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:2.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.33.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:2.0.6`,
        fs:  `cpe:2.3:a:pluck-cms:pluck:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalvolcano:duplicate_cleaner:2.1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.7.1\(22\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitalzoomstudio:video_gallery:-:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digitiliti:digilibe:3.4`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-alpha1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.1`,
        fs:  `cpe:2.3:a:microsoft:remote_desktop_connection:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.2`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_sp_isp_decoder_software:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.3`,
        fs:  `cpe:2.3:h:cisco:unified_call_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.3.5:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.5`,
        fs:  `cpe:2.3:a:bluetooth:bluetooth_stack:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.6`,
        fs:  `cpe:2.3:h:huawei:campus_s3700hi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.7`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.8`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.9`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.9.1`,
        fs:  `cpe:2.3:a:commpower:xml_portal_cp-xp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.10`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:20.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.11`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.1.12`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.2`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.2.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.3`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.3.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.4`,
        fs:  `cpe:2.3:a:hp:openssh_services:3.7.1p1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.4.0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.4:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.5.0`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.3.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.7`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_wireless_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.7.0`,
        fs:  `cpe:2.3:o:qnap:ts-ec1679u-rp_firmware:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.7.1`,
        fs:  `cpe:2.3:a:adobe:media_player:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.7.2`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.252:*:smart:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:0.9`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0`,
        fs:  `cpe:2.3:h:cisco:nexus_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0:rc1`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0:rc2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.0`,
        fs:  `cpe:2.3:a:kernel:util-linux:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.1`,
        fs:  `cpe:2.3:h:hp:j9643a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.2`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.3`,
        fs:  `cpe:2.3:a:drupal:drupal:7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.4`,
        fs:  `cpe:2.3:a:apple:bonjour:1.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.5`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.6`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.0:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.7`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.8`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.9`,
        fs:  `cpe:2.3:a:ca:cleverpath_predictive_analysis_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.10`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.28:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.0.11`,
        fs:  `cpe:2.3:a:avonesoft:spynomore:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.0\(222\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.0:beta2`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:9.5.0-444:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.0:rc1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.0:rc2`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.51:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.2:netsec`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.3`,
        fs:  `cpe:2.3:a:opsview:opsview:3.2:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.3:netsec`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.6f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.7`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.8`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.9`,
        fs:  `cpe:2.3:h:hp:laserjet_m5035_mfp:q7829a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.10`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.10:netsec`,
        fs:  `cpe:2.3:a:gnu:zlib:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.11`,
        fs:  `cpe:2.3:a:themelogik:cmslogik:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.11:netsec`,
        fs:  `cpe:2.3:a:easy_banners_plugin_project:easy_banners:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.12:netsec`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.12.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:x64-std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.12.1:netsec`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.13`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.13:netsec`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.14`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.15`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.15:netsec`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:2006.02:-:premium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.16`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:10.2.157.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.16:netsec`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.17`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r3.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.17:netsec`,
        fs:  `cpe:2.3:a:varec:fuelsmanager_defense_dormant_account_manager:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.18`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.18:netsec`,
        fs:  `cpe:2.3:o:vmware:esx:3.5:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.19`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.1:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.19:netsec`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.20`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.48.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.20:netsec`,
        fs:  `cpe:2.3:a:estsoft:alzip:8.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.21`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.21:netsec`,
        fs:  `cpe:2.3:a:yahoo:messenger:11.5.0.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.21.1`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.21.1:netsec`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.22`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.22:netsec`,
        fs:  `cpe:2.3:a:hp:network_node_manager:8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.23`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.23:netsec`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.24`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.9.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.24:netsec`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.25`,
        fs:  `cpe:2.3:a:adobe:framemaker:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.25:netsec`,
        fs:  `cpe:2.3:a:algosec:firewall_analyzer:6.1:b86:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.26`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.26:netsec`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.26.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u6\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.26.1:netsec`,
        fs:  `cpe:2.3:a:citrix:presentation_server_client:9.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.26.2`,
        fs:  `cpe:2.3:a:x.org:x11:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.26.2:netsec`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.27`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)e9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.28`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.28.1`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.29`,
        fs:  `cpe:2.3:a:sendmail:sendmail_pro:8.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.30`,
        fs:  `cpe:2.3:h:cisco:nexus_6004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.30.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.30.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.30.3`,
        fs:  `cpe:2.3:h:juniper:dx:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.30.4`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.31`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.31.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.5:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.32`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.33`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.34`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5\)st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.35`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.11:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.2.36`,
        fs:  `cpe:2.3:a:hp:hph_software_req:70.0.260.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.0`,
        fs:  `cpe:2.3:a:presto-changeo:canadapost:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.0:beta1`,
        fs:  `cpe:2.3:a:yahoo:japan_shopping:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.0:beta2`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.0:beta3`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.0:beta4`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.2`,
        fs:  `cpe:2.3:a:vips:vips:7.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.3`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:4.21.1088:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.4`,
        fs:  `cpe:2.3:a:aegirproject:hostmaster:6.x-3.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.6`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.7`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.7.1`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.8`,
        fs:  `cpe:2.3:a:ldap-account-manager:ldap_account_manager:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.9`,
        fs:  `cpe:2.3:a:posh_project:posh:3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.10`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.10.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p3_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.11`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.12`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.12.1`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.13`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.8.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.14`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.15`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6s\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.16`,
        fs:  `cpe:2.3:a:git-scm:git:2.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.16.1`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_antivirus:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.16.2`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.17`,
        fs:  `cpe:2.3:o:sun:solaris:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.18`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.19`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.19:rc1`,
        fs:  `cpe:2.3:o:sgi:irix:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.19:rc2`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.19:rc3`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.19:rc4`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.19.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_business_service_manager:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.19.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.20`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.20:rc1`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.20:rc2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.20:rc3`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.20.1`,
        fs:  `cpe:2.3:o:iij:seil\%2fx2_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.21`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p49:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.21:rc1`,
        fs:  `cpe:2.3:h:hp:t5740:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.21:rc2`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.21.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.21.2`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.14:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.22`,
        fs:  `cpe:2.3:a:whisper:whisper:4.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.22:rc1`,
        fs:  `cpe:2.3:a:avast:email_server_security:8.0.1606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.22:rc2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1685.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.22:rc3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.22:rc4`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.22:rc5`,
        fs:  `cpe:2.3:h:cisco:unified_wireless_ip_phone_7921g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.22.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.22.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.23`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.23:rc1`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.23:rc2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.23:rc3`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.23:rc4`,
        fs:  `cpe:2.3:h:cisco:887_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.23.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.2:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.23.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.24`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.24:rc1`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.24.1`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.1.6:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.25`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.25:rc1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.25.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26:rc1`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ixh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26:rc3`,
        fs:  `cpe:2.3:a:f5:arx:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26:rc4`,
        fs:  `cpe:2.3:a:atmail:atmail:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26:rc5`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26:rc6`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26.2`,
        fs:  `cpe:2.3:a:koha:koha:3.14.00:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.26.3`,
        fs:  `cpe:2.3:a:gnu:readline:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.27`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.27:rc1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.27:rc2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.27:rc3`,
        fs:  `cpe:2.3:a:openstack:heat:2013.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.27:rc4`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.27:rc5`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.27.1`,
        fs:  `cpe:2.3:a:infohr:hr_human_resource_information_system:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.28`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.6200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.28:rc1`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.29`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.29:rc1`,
        fs:  `cpe:2.3:a:mit:cgiemail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.29.1`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.30`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.30:rc2`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:5.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.30:rc3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.31`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cpj:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.31:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.31:rc2`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.32`,
        fs:  `cpe:2.3:a:lynx:lynx:2.8.8:dev.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.32:rc1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.33`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.33:rc1`,
        fs:  `cpe:2.3:a:apache:camel:2.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.33:rc2`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.5:build120405:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.33.1`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.50.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.34`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.34:rc1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.34:rc2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.05.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.35`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.35:rc1`,
        fs:  `cpe:2.3:a:broadcom:pipa_c211_web_interface:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.36`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.36:rc1`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.37`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.37:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.38`,
        fs:  `cpe:2.3:a:google:chrome:4.0.302.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.38:rc1`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.39`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)ew2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.39:rc1`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.39.1`,
        fs:  `cpe:2.3:a:droboworks:drobo_dashboard:1.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.39.2`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050905:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.40`,
        fs:  `cpe:2.3:h:apple:imac:ma877xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.40:rc1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.40:rc2`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.40:rc3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.40.1`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.833.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.40.2`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.41`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.41:rc1`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.41.1`,
        fs:  `cpe:2.3:a:apache:xalan-java:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.41.2`,
        fs:  `cpe:2.3:h:linksys:spa921:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.42`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.42:rc1`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.42:rc2`,
        fs:  `cpe:2.3:o:huawei:5710hi_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.43`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.4.44`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0`,
        fs:  `cpe:2.3:a:hp:installmicgenerichook:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta1`,
        fs:  `cpe:2.3:a:anixis:password_policy_client:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta2`,
        fs:  `cpe:2.3:h:satechi:smart_travel_router:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta3`,
        fs:  `cpe:2.3:a:9.dotpp.net:megalith:50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta4`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.15.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta5`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta6`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta7`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta7.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8zb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta8`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:beta9`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:rc4`,
        fs:  `cpe:2.3:a:kingsoft:writer_2012:8.1.0.3030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:rc5`,
        fs:  `cpe:2.3:a:sil:graphite2:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0:rc6`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.3.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.8.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.2`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.3`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.3:rc1`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:2.2.4:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.4:rc1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.7`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.8`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.9`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-167_with_network_printer_kit_firmware:t282cn0j421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.10`,
        fs:  `cpe:2.3:a:phpspot:php_bbs_css:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.11`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.11:rc1`,
        fs:  `cpe:2.3:a:citrix:receiver_aero:13.0.0.6684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.11:rc2`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.12`,
        fs:  `cpe:2.3:a:isc:bind:9.7.1:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.13`,
        fs:  `cpe:2.3:o:huawei:s9303e_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.14`,
        fs:  `cpe:2.3:h:hp:3com_switch:4510g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.14:rc1`,
        fs:  `cpe:2.3:a:sparxsystems:enterprise_architect:7.5.850.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.15`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.16`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_firmware:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.16:rc1`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.16:rc2`,
        fs:  `cpe:2.3:a:dart:dart_ziplite_compression:1.8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.17`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.18`,
        fs:  `cpe:2.3:a:jakweb:gecko_cms:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.18:rc1`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.18:rc2`,
        fs:  `cpe:2.3:a:redprairie:redprairie_client:2010.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.18:rc3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.19`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.5:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.20:rc1`,
        fs:  `cpe:2.3:h:cisco:unity_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.21`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.21:rc1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.22`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.23:rc2`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.24`,
        fs:  `cpe:2.3:a:microsoft:visio:2003:sp2:multilingual_user_interface_pack:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.25`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.0.26`,
        fs:  `cpe:2.3:a:hp:photo_creations:1.0.0.2024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1:beta1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.500.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1:beta2`,
        fs:  `cpe:2.3:a:php:php:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1:beta3`,
        fs:  `cpe:2.3:a:google:v8:3.24.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1:beta4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1:rc1`,
        fs:  `cpe:2.3:a:haxx:curl:7.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.0:rc2`,
        fs:  `cpe:2.3:a:symantec:liveupdate:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.0:rc3`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.1.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.0:rc4`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.1.0:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.0:rc5`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.1`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.3:rc1`,
        fs:  `cpe:2.3:a:adobe:jrun:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.4`,
        fs:  `cpe:2.3:a:ibm:forms_viewer:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.5`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.5:rc1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:11.0\(0.98000.332\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.6`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.7:rc1`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.a9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.7:rc2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.8`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.9`,
        fs:  `cpe:2.3:a:qemu:qemu:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.10`,
        fs:  `cpe:2.3:h:hp:3com_taa_switch:5500-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.10:rc1`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:3.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.10:rc2`,
        fs:  `cpe:2.3:a:skype:skype:2.6.0.67:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.10:rc3`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.16:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.11`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.12`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.12:rc1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.13`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.13:rc1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.14`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.15:rc2`,
        fs:  `cpe:2.3:a:emc:avamar:5.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.16`,
        fs:  `cpe:2.3:a:mozilla:firefox:25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.17`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.33.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.18`,
        fs:  `cpe:2.3:h:avaya:4602sw_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.18:rc1`,
        fs:  `cpe:2.3:o:sun:solaris:1.1.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.18:rc2`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.19`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.19:rc1`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.19:rc2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.19:rc3`,
        fs:  `cpe:2.3:a:haxx:curl:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.20`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.20:rc1`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:5.4.104.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.20:rc2`,
        fs:  `cpe:2.3:a:autodesk:design_review_2009_dgn_importer:2.00.071:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.21`,
        fs:  `cpe:2.3:h:securecomputing:smartether_ss6215s_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.22`,
        fs:  `cpe:2.3:a:buffalotech:whr-am54g54_firmware:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.23`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.409.1:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.1.24`,
        fs:  `cpe:2.3:o:hp:tru64:5.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.0`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.0:rc2`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.0:rc3`,
        fs:  `cpe:2.3:a:pass4sure:questions_and_answers_for_comptia_sy0-201:7.7.12912:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.0:rc4`,
        fs:  `cpe:2.3:a:acquia:commons:6.x-2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.0:rc5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.0:rc6`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.0:rc7`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.0:rc8`,
        fs:  `cpe:2.3:a:esoftpro:online_contact_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.1`,
        fs:  `cpe:2.3:a:sympa:sympa:5.0b.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.1:rc1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.3:rc2`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.4`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.5`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.6`,
        fs:  `cpe:2.3:a:etoshop:c2c_forward_auction_creator:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.6:rc1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.6:rc2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.15:rc1`,
        fs:  `cpe:2.3:a:studiohitori:twitrocker2_android:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.16`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.16:rc1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.16.1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.16.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.17`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.17:rc1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.17:rc2`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.17:rc3`,
        fs:  `cpe:2.3:a:netscape:communicator:4.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.17.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(5\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.17.2`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.17.3`,
        fs:  `cpe:2.3:a:isc:bind:9.11.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.18`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.983:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.18:rc1`,
        fs:  `cpe:2.3:a:ubercart_webform_checkout_pane_project:ubercart_webform_checkout_pane:6.x-3.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.18.1`,
        fs:  `cpe:2.3:a:apache:jakarta_slide:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.18.2`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.5:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.19`,
        fs:  `cpe:2.3:a:ibm:traveler:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.19:rc1`,
        fs:  `cpe:2.3:a:haxx:curl:7.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.20`,
        fs:  `cpe:2.3:o:huawei:s5300si_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.21`,
        fs:  `cpe:2.3:a:samba:samba:4.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.22`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.6.2.23`,
        fs:  `cpe:2.3:a:hp:document_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.2.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:beta1`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:7.x-1.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1076.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:beta3`,
        fs:  `cpe:2.3:a:nero:movie_templates_starter_kit:9.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:beta4`,
        fs:  `cpe:2.3:a:cisco:nexus_1000v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:beta5`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1016:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:rc2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:rc3`,
        fs:  `cpe:2.3:a:yahoo:pager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:rc4`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.0:rc5`,
        fs:  `cpe:2.3:a:ssh:tectia_manager:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.1:rc1`,
        fs:  `cpe:2.3:h:hp:laserjet_5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.1.1`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.32:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.1.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.2`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.2.1`,
        fs:  `cpe:2.3:a:\$0.99_kindle_books_project:\$0.99_kindle_books:6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.2.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.2.3`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.2.4`,
        fs:  `cpe:2.3:a:zencast:zencast:1.02.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.3`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.076:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.3:rc1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.3:rc2`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.3:rc3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.0:pre.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.3.1`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.3.2`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.3.3`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.4`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.4:rc1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.4:rc2`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.4:rc3`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.4.1`,
        fs:  `cpe:2.3:a:nero:controlcenter:0.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.4.2`,
        fs:  `cpe:2.3:a:usarmy:viewer_armyifx:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.4.3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.4.4`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.5`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.5:rc1`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.5.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.6.0`,
        fs:  `cpe:2.3:a:aol:aim:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.6.0:rc1`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.41a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.6.0:rc2`,
        fs:  `cpe:2.3:o:ibm:aix:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.6.0:rc3`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:2.0:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.7.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.686.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.7.0:rc2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.66:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.7.1`,
        fs:  `cpe:2.3:a:redgraphic:sapid_cms:1.2.3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.0`,
        fs:  `cpe:2.3:a:activestate:activepython:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.0:-`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.0:patch`,
        fs:  `cpe:2.3:o:yahama:rtx1200:10.01.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.0:rc1`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.0:rc2`,
        fs:  `cpe:2.3:a:yard_radius_project:yard_radius:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.0:rc3`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.0:rc4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.0:rc5`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.8.2`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.9.0`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.8:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.9.0:-`,
        fs:  `cpe:2.3:h:hp:jg512a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.9.0:rc1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p288:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.9.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.9.0:rc3`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.9.1`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.9.2`,
        fs:  `cpe:2.3:a:hp:storage_management_software:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.9.3`,
        fs:  `cpe:2.3:o:google:android:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.10.0`,
        fs:  `cpe:2.3:a:tripadvisor:tripadvisor:6.6:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.10.0:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.10.0:rc1`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.10.0:rc2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.10.0:rc3`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.10.0:rc4`,
        fs:  `cpe:2.3:a:hitachi:job_management_partner_1\/it_desktop_management-manager:10-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.10.1`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.11.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.11.0:-`,
        fs:  `cpe:2.3:a:carbonblack:carbon_black:4.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.11.0:patch`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.11.0:rc2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_supply_chain_management_eprocurement:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.11.0:rc3`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.11.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:0.078:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.11.1:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.11.1:patch`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sw3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.12`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.393:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.12.0`,
        fs:  `cpe:2.3:a:atlassian:jira:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.12.0:-`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.12.0:rc1`,
        fs:  `cpe:2.3:a:roxio:cineplayer_decoder_pack:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.12.0:rc2`,
        fs:  `cpe:2.3:a:redhat:jboss_communications_platform:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.12.0:rc3`,
        fs:  `cpe:2.3:o:conectiva:linux:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.12.1`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.62:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.12.2`,
        fs:  `cpe:2.3:a:acquia:mollom:6.x-2.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.13.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.13.0:rc1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30243:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.13.0:rc2`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.13.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.14.0:-`,
        fs:  `cpe:2.3:a:suse:kiwi:4.98.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.14.0:patch`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.7.2088:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.14.0:rc1`,
        fs:  `cpe:2.3:a:vmware:springsource_spring_security:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.14.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.14.1`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.v0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.14.1:-`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.16:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.14.1:patch`,
        fs:  `cpe:2.3:a:simple_retail_menus_plugin_project:simple-retail-menus:4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.15.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.15.0:-`,
        fs:  `cpe:2.3:a:cisco:information_server:6.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.15.0:rc1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.1.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.15.1`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.16.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.16.0:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.0\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.16.0:rc1`,
        fs:  `cpe:2.3:a:teradata:sql_assistant:13.10.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.16.0:rc2`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.17.0`,
        fs:  `cpe:2.3:a:logitech:lws_videoeffects:13.30.1379.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.17.0:-`,
        fs:  `cpe:2.3:h:willcom-inc:android_smartphone:wx04k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.17.0:patch`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.17.0:rc1`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.17.0:rc2`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.17.0:rc3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.18.0`,
        fs:  `cpe:2.3:a:metroseoul:metro_news:1.6.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.18.0:-`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.18.0:rc1`,
        fs:  `cpe:2.3:a:atlassian:jira:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.18.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.20:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.19.0`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.396:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.19.0:-`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_services:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.19.0:rc1`,
        fs:  `cpe:2.3:a:vmware:vcenter_chargeback_manager:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.19.0:rc3`,
        fs:  `cpe:2.3:h:ibm:system_x_idataplex_dx360_m3_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.19.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.20.0:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:alpha0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.20.0:patch`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.20.0:rc1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.20.0:rc2`,
        fs:  `cpe:2.3:a:auracms:auracms:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.20.1:-`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.20.1:patch`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.20.2:-`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.20.2:patch`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.21.0:-`,
        fs:  `cpe:2.3:a:commvault:vss_provider:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.21.0:rc1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.21.0:rc2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.07:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.22.0:-`,
        fs:  `cpe:2.3:a:raphael_zschorsch:rzautocomplete:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.22.0:rc1`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_cms:4.5.9:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.22.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5e.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.23.0:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.23.0:patch`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.23.0:rc1`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.23.0:rc2`,
        fs:  `cpe:2.3:a:betster_project:betster:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.23.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(15\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.24.0:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.24.0:rc1`,
        fs:  `cpe:2.3:a:nortel:multimedia_communication_server_5100:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.24.0:rc2`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.24.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.25.0:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.39.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.25.0:rc1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.818:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.25.0:rc2`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.0:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.26.0:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.26.0:rc1`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.26.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5b\)su4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.27.0`,
        fs:  `cpe:2.3:a:microsoft:system.text.encodings.web:4.3.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.27.0:rc1`,
        fs:  `cpe:2.3:a:sun:java_system_messenger_express:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.27.0:rc2`,
        fs:  `cpe:2.3:a:gcefcu:gulf_coast_educators_fcu:1.0.27:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.28.0`,
        fs:  `cpe:2.3:a:hp:hppfaxutility:0.105.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.28.0:rc1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.28.1`,
        fs:  `cpe:2.3:a:pawel_jakub_dawidek:geli:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.28.2`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2006-03-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:1.8.32.0::~~lts~~~`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.8.1340.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0::digiumphones`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_it360:10.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:beta1`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:beta1:digiumphones`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:beta2`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:beta2:digiumphones`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:rc1`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:rc1:digiumphones`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:09.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:rc2`,
        fs:  `cpe:2.3:a:emc:unisphere_service_manager:1.1.25.10129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:rc2:digiumphones`,
        fs:  `cpe:2.3:a:gnu:findutils:4.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:rc3`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.51:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.0:rc3:digiumphones`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.0.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.0`,
        fs:  `cpe:2.3:h:d-link:dcs-932l_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.0::digiumphones`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.0:rc1`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.0:rc1:digiumphones`,
        fs:  `cpe:2.3:h:cisco:hosting_solution_engine:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.0:rc2`,
        fs:  `cpe:2.3:a:erlang:crypto:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.0:rc2:digiumphones`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.1`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:m7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.1::digiumphones`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.2`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.1.3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0::digiumphones`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0:rc1`,
        fs:  `cpe:2.3:a:novell:zenworks_desktops:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0:rc1:digiumphones`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:3.0.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0:rc2:digiumphones`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0:rc3`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0:rc3:digiumphones`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0:rc4`,
        fs:  `cpe:2.3:a:macromedia:shockwave:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.0:rc4:digiumphones`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.2.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.3.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.3.0::digiumphones`,
        fs:  `cpe:2.3:a:acme:thttpd:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.3.0:rc2`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_p1606dn:ce749a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.3.0:rc2:digiumphones`,
        fs:  `cpe:2.3:o:cisco:ios:15.4s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.3.0:rc3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.3.0:rc3:digiumphones`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.3.1`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.0::digiumphones`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_wag310g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.0:rc1`,
        fs:  `cpe:2.3:a:phplist:phplist:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.0:rc1:digiumphones`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.0:rc2`,
        fs:  `cpe:2.3:a:yaml-fuer-drupal:linkchecker:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.0:rc2:digiumphones`,
        fs:  `cpe:2.3:a:isc:bind:9.10.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.0:rc3`,
        fs:  `cpe:2.3:o:emc:data_domain:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.1`,
        fs:  `cpe:2.3:a:agilefleet:fleetcommander:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.4.2`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.0`,
        fs:  `cpe:2.3:a:apple:quicktime:6.3.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.0::digiumphones`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.0:rc1`,
        fs:  `cpe:2.3:a:cisco:network_assistant:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.0:rc1:digiumphones`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.8.814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.0:rc2`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.0:rc2:digiumphones`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.19.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.1`,
        fs:  `cpe:2.3:a:emc:rsa_data_loss_prevention:9.6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.1::digiumphones`,
        fs:  `cpe:2.3:h:cisco:content_services_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.5.2::digiumphones`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.6.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.6.0::digiumphones`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.6.0:rc1`,
        fs:  `cpe:2.3:a:ca:systemedge:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.6.0:rc2`,
        fs:  `cpe:2.3:a:tony_freixas:ubercart_product_keys:6.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.6.1`,
        fs:  `cpe:2.3:h:ibm:bladecenter:hs23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.6.1::digiumphones`,
        fs:  `cpe:2.3:a:apache:juddi:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.7.0`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.7.0::digiumphones`,
        fs:  `cpe:2.3:a:samba:samba:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.7.0:rc1`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.7.1`,
        fs:  `cpe:2.3:a:symantec:mail_security:5.1.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.8.0`,
        fs:  `cpe:2.3:a:citrix:access_essentials:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.8.0:rc1`,
        fs:  `cpe:2.3:h:netgear:fm114p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.8.0:rc2`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.9.0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.9.0:rc1`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.2\(1.50\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.9.0:rc2`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.9.0:rc3`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.10.0`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.10.0:rc1`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp8:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.10.0:rc2`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.10.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server_solution_engine:5.4.0.46.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.11.0`,
        fs:  `cpe:2.3:a:isc:bind:9.9.1:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.11.0:rc1`,
        fs:  `cpe:2.3:a:pjtech:goverlan:2000_v3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.11.0:rc3`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.11.1`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.11.1::digiumphones`,
        fs:  `cpe:2.3:a:blynk:clarks_inn:3.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:10.12.0:rc1:digiumphones`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:8.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.0.0`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.0.0:beta1`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.0.0:beta2`,
        fs:  `cpe:2.3:a:h2o_project:h2o:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.0.0:rc1`,
        fs:  `cpe:2.3:a:ingumadev:bokken:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.0.0:rc2`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.0.1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.0.2`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.1.0`,
        fs:  `cpe:2.3:a:vmware:tools:9.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.1.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.1.0:rc2`,
        fs:  `cpe:2.3:a:questionmark:questionmark_secure_browser:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.1.0:rc3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.1.1`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20141126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.1.2`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.2.0:rc1`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.2.1`,
        fs:  `cpe:2.3:a:redhat:jboss_weld:3.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.2.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.821:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.4.0:rc4`,
        fs:  `cpe:2.3:a:cososys:endpoint_protector:4.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.6.0`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.6.0:rc1`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:6.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.6.0:rc2`,
        fs:  `cpe:2.3:o:yamaha:rta52i:3.06.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.6.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p435:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.7.0`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.20:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.7.0:rc1`,
        fs:  `cpe:2.3:a:vandyke:securecrt:6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.7.0:rc2`,
        fs:  `cpe:2.3:a:apache:camel:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.8.0:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p234_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.8.0:rc1`,
        fs:  `cpe:2.3:a:cisco:webns:7.40.1.13s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.8.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:pocket_ie:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.8.0:rc3`,
        fs:  `cpe:2.3:a:process-one:ejabberd:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.8.1`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.9.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.9.0:rc1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.3_p7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.9.0:rc2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.9.0:rc3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.10.0`,
        fs:  `cpe:2.3:a:mitsubishielectric:mx4_scada:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.10.0:rc1`,
        fs:  `cpe:2.3:a:ibm:telelogic_license_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.10.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.10.1:rc1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.959:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.10.2`,
        fs:  `cpe:2.3:o:cisco:catos:6.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.11.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.11.0:rc1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.7.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.12.0`,
        fs:  `cpe:2.3:a:x:libxinerama:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.12.0:rc1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.12.1`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.13.0`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.13.0:rc1`,
        fs:  `cpe:2.3:a:lunarline:continuous_compliance_monitoring_and_reporting:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.13.1`,
        fs:  `cpe:2.3:o:raritan:px:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.14.0::~~lts~~~`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.14.0:rc1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.14.0:rc2`,
        fs:  `cpe:2.3:a:ilearnwith:animals\!_kids_preschool_games:1.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.14.1`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.14.2`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.15.0:rc1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.15.0:rc2`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.15.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.16.0:rc1`,
        fs:  `cpe:2.3:a:webtitan:webtitan:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.17.0:rc1`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.17.1`,
        fs:  `cpe:2.3:a:symantec:vrtsjre:1.5.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.18.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.18.0:rc1`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.15.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.19.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:money:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.20.0:rc1`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.0.841.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.21.0:rc1`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bpet64c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.21.0:rc2`,
        fs:  `cpe:2.3:a:pixman:pixman:0.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.21.1`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.21.2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.47:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.22.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_data_services_platform:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.22.0:rc1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.23.0`,
        fs:  `cpe:2.3:a:tenable:nessus:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.23.0:rc1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.23.1`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.24.0`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.10.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.24.1`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:6.0:2m:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:11.25.0`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.0.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.1.0:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1288.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.1.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.3105.0106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.1.0:rc2`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.1.0:rc3`,
        fs:  `cpe:2.3:a:novell:netmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.1.1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.2.0`,
        fs:  `cpe:2.3:h:xerox:workcentre_m175:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.2.0:rc1`,
        fs:  `cpe:2.3:h:huawei:s9312:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.2.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.257.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.2.0:rc3`,
        fs:  `cpe:2.3:a:ibm:rational_license_server:2.1.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.3.0`,
        fs:  `cpe:2.3:a:garethjmsaunders:psiwin:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.3.0:rc1`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.3.0:rc2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.3.1`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.3.2`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.4.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.4.0:rc1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p116:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.5.0`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.5.0:rc1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.6.0`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.6.0:rc1`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.7.0::~~lts~~~`,
        fs:  `cpe:2.3:a:google:v8:3.23.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.7.0::~~standard~~~`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.7.0:rc1`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.7.0:rc2`,
        fs:  `cpe:2.3:o:vmware:esxi:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.7.1`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.3:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.8.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.8.0:rc1`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.8.0:rc2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p190:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:12.8.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.0.0::~~lts~~~`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.0.0:beta1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.5.0_a:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.0.0:beta2`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.0.0:beta3`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.0.1`,
        fs:  `cpe:2.3:a:crear.ne.jp:al-mail32:1.13:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.0.2`,
        fs:  `cpe:2.3:o:netgear:d6000_firmware:1.0.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.1.0:rc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.1.0:rc2`,
        fs:  `cpe:2.3:o:microsoft:windows_8:-:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.1.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.2.0`,
        fs:  `cpe:2.3:a:microsoft:powerpoint_viewer:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.2.0:rc1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.2.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.04:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.3.0:rc1`,
        fs:  `cpe:2.3:a:teamlava:fashion_story\:_neon_90\&#39;s:1.5.6.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.3.2`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.4.0`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.4.0:rc1`,
        fs:  `cpe:2.3:a:novell:iprint:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.5.0`,
        fs:  `cpe:2.3:a:dandyid_services_project:dandyid_services:1.5.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.5.0:rc1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.70:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.6.0:rc1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.7.0:rc1`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.7.0:rc2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.7.1`,
        fs:  `cpe:2.3:h:huawei:ne80:v300r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.7.2`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.11.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.8.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.23.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.8.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:4.72.3120.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.8.1`,
        fs:  `cpe:2.3:a:microsoft:ie:6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.8.2`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.9.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.9.1`,
        fs:  `cpe:2.3:a:squash:square_squash:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.10.0`,
        fs:  `cpe:2.3:o:samsung:samsung_mobile:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.10.0:rc1`,
        fs:  `cpe:2.3:a:thycotic:secret_server:8.7.000000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.11.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.11.1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.1:beta-6:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.11.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.12`,
        fs:  `cpe:2.3:o:moxa:iologik_firmware:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.12.0`,
        fs:  `cpe:2.3:a:samsung:ipolis_device_manager:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.12.1`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.12.2`,
        fs:  `cpe:2.3:a:mochiweb_project:mochiweb:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.13`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:13.13.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.0.0`,
        fs:  `cpe:2.3:a:sil:graphite2:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.0.0:beta1`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.0.0:beta2`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.63:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.0.0:rc1`,
        fs:  `cpe:2.3:a:mcafee:e-business_server:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.0.0:rc2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.0.1`,
        fs:  `cpe:2.3:h:hp:ibrix_x9730:qz730a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.0.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2se.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.1`,
        fs:  `cpe:2.3:a:redhat:openstack:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.01`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.1.0`,
        fs:  `cpe:2.3:a:adobe:camera_raw:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.1.1`,
        fs:  `cpe:2.3:a:python:pillow:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.1.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.240:update24:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.2`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.02`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(1\)sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:14.2.0`,
        fs:  `cpe:2.3:a:mintboard:mintboard:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:a:-:business`,
        fs:  `cpe:2.3:a:gnome:glib:2.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b:-:business`,
        fs:  `cpe:2.3:a:yahoo:yui:2.8.1:pr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.1.3.2:-:business`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.17493:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.1.3.3:-:business`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.2.0:-:business`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.2.1:-:business`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.3.1:-:business`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.3.2:-:business`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.3.3`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.9:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.3.3:-:business`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.3.4:-:business`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.3.5:-:business`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1a_pk1_bl1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.3.6:-:business`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.0.3.545:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.5.0:-:business`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.5.1:-:business`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.5.2:-:business`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:b.2.5.3:-:business`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro:238:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c:-:business`,
        fs:  `cpe:2.3:a:saltstack:salt:0.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.1.0:beta7:business`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.1.0:beta8:business`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.1.0_beta5`,
        fs:  `cpe:2.3:o:siemens:sinamics_s\/g_family_firmware:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.1.6:-:business`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.95:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.1.6.1:-:business`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.1.6.2:-:business`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.1.8.0:-:business`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.1.8.1:-:business`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.2.3:-:business`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.56:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.0:-:business`,
        fs:  `cpe:2.3:a:protected_pages_project:protected_pages:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.1.0:-:business`,
        fs:  `cpe:2.3:a:icz:sencha_sns:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.1.1:-:business`,
        fs:  `cpe:2.3:a:gentoo:nview:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.2.2:-:business`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:3.5.802:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.2.3:-:business`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.4:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.3.2:-:business`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.5.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.6.2:-:business`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.6.3:-:business`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.6.4:-:business`,
        fs:  `cpe:2.3:o:cisco:ios:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:asterisk:c.3.7.5:-:business`,
        fs:  `cpe:2.3:a:gimp:gimp:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:-`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_m1213nf_mfp:ce845a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:beta1`,
        fs:  `cpe:2.3:a:paperthin:commonspot_content_server:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:beta2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:beta3`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:beta4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_2q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:beta5`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle:7.3.678:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:rc1`,
        fs:  `cpe:2.3:h:hp:laserjet_9500_mpf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:rc2`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:rc3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:rc4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.32.0:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.0.0:rc5`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.1.0:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.1.0:rc1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.2.0:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.672.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.2.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.3.0:-`,
        fs:  `cpe:2.3:a:zope:zope:2.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.3.0:rc1`,
        fs:  `cpe:2.3:a:hp:data_protector_express:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.3.0:rc2`,
        fs:  `cpe:2.3:a:digium:asterisk:14.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.3.0:rc3`,
        fs:  `cpe:2.3:a:gajim:gajim:0.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.4.0:-`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:4.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.4.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.4.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:visual_foxpro:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.4.0:rc3`,
        fs:  `cpe:2.3:h:linksys:befw11s4:1.42.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.5.0:-`,
        fs:  `cpe:2.3:a:globeranger:imotion_edgeware_platform:5.5.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.5.0:rc1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.6.0:-`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.6.0:rc1`,
        fs:  `cpe:2.3:a:trendmicro:interscan_web_security_virtual_appliance:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.6.0:rc2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.6.0:rc3`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.7.0:-`,
        fs:  `cpe:2.3:h:ibm:power_5:9117-570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.7.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.7.0:rc2`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.8.0:-`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.8.0:rc1`,
        fs:  `cpe:2.3:a:conga:conga:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.8.0:rc2`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.8.0:rc3`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1513f-1_pn_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.8.0:rc4`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.8.0:rc5`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.9.0:-`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.5:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.9.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.9.0:rc2`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.9.0:rc3`,
        fs:  `cpe:2.3:a:cisco:resource_manager_essentials:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.10.0:-`,
        fs:  `cpe:2.3:a:polycom:realpresence_media_manager_software:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.10.0:rc1`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.10.0:rc2`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.10.0:rc3`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.10.0:rc4`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert1`,
        fs:  `cpe:2.3:h:enterasys:6h252-17:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert10`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert3`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert4`,
        fs:  `cpe:2.3:h:cisco:catalyst_6500_ws-svc-nam-1:2.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert5`,
        fs:  `cpe:2.3:a:synametrics:xeams:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert6`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(2\)xd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert7`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert8`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11:cert9`,
        fs:  `cpe:2.3:h:moxa:edr-g903:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11.0:-`,
        fs:  `cpe:2.3:a:ca:network_and_systems_management:r3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11.0:rc1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11.0:rc2`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.11.0:rc3`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.12.0:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.12.0:rc1`,
        fs:  `cpe:2.3:a:novell:client:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.12.0:rc2`,
        fs:  `cpe:2.3:a:novell:suse_linux_software_development_kit:11.0:sp3:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.12.0:rc3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.450.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.13.0:-`,
        fs:  `cpe:2.3:a:oracle:knowledge_management:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.13.0:rc1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.13.0:rc2`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.14.0:rc1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.14.0:rc2`,
        fs:  `cpe:2.3:a:ibm:tivoli_firewall_toolbox:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:-`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0.2.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert1`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert1_rc1`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:gold:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert1_rc2`,
        fs:  `cpe:2.3:a:novell:securelogin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert1_rc3`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.18:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert2`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert3`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert4`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.8.1a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert5`,
        fs:  `cpe:2.3:a:piwik:piwik:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.15:cert6`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.28`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:17.012.20098:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.28:cert1:~~lts~~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.28:cert2:~~lts~~~`,
        fs:  `cpe:2.3:a:concord:ehealth_trapexploder:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:1.8.28.0::~~lts~~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.0.0`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.6:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.0.0:rc1`,
        fs:  `cpe:2.3:h:selinc:sel-3530:r100_-v0-z001001-d20090915:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.0.0:rc2`,
        fs:  `cpe:2.3:a:s3graphics:s3_graphics_utilities:3.3201.25d43-0216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.1.0`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2010:14.0.913.64:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.1.0:rc1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.236:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.1.0:rc2`,
        fs:  `cpe:2.3:h:nortel:contivity:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.1.0:rc3`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.3.0`,
        fs:  `cpe:2.3:a:suse:studio_extension_for_system_z:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.3.0:rc1`,
        fs:  `cpe:2.3:a:mozilla:firefox:18.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.3.0:rc2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.4.0`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.4.0:rc1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.4.0:rc2`,
        fs:  `cpe:2.3:a:esri:arcgis_3d_analyst:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.4.0:rc3`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.17.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.5.0`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.5.0:rc1`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.5.0:rc2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p145:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert1`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2610-48:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert1:~~lts~~~`,
        fs:  `cpe:2.3:a:oracle:database_server:11.2.0.1.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert1_rc1`,
        fs:  `cpe:2.3:a:typoheads:formhandler:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert1_rc2`,
        fs:  `cpe:2.3:a:netscout:cdm_agent_firmware_maintenance_release:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert12:~~lts~~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.6.5\(167\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert13:~~lts~~~`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert14:~~lts~~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd379a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert15:~~lts~~~`,
        fs:  `cpe:2.3:o:cisco:web_security_appliance:9.0.0-193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert2`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert2:~~lts~~~`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert3`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert3:~~lts~~~`,
        fs:  `cpe:2.3:a:sir:gnuboard:4.34.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert4:~~lts~~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert5:~~lts~~~`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert6:~~lts~~~`,
        fs:  `cpe:2.3:h:hp:0235a392:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert7:~~lts~~~`,
        fs:  `cpe:2.3:a:x.org:x11:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6:cert8:~~lts~~~`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6.0::~~lts~~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6.0:-`,
        fs:  `cpe:2.3:a:xnview:xnview:1.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.4se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:11.6.0:rc2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.1.0`,
        fs:  `cpe:2.3:a:emc:rsa_authentication_agent:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.1.0:rc1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.1.0:rc2`,
        fs:  `cpe:2.3:a:jiujik:jiu_jik:1.4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.8:cert1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.8:cert1_rc1`,
        fs:  `cpe:2.3:a:concursive:modsim_connected:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.8:cert1_rc2`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.8:cert1_rc3`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.1270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.8:cert2_rc1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.8.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:digium:certified_asterisk:13.8.0:rc1`,
        fs:  `cpe:2.3:a:cisco:ids_sensor_software:4.1\(1\)e0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dimac:jmail.net:1.1.0::~~professional~~~`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dimastr:outlook_redemption:1.0.0`,
        fs:  `cpe:2.3:a:apple:safari:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dimastr:outlook_spy:3.0.0.2457::~~~~x64~`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ding:ding_ezetop._top-up_any_phone:1.3.4::~~~android~~`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144n_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dir2web:dir2web:3.0`,
        fs:  `cpe:2.3:a:instantasp:instantforum:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:directadmin:directadmin:1.30.1`,
        fs:  `cpe:2.3:a:artifex:mupdf:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:directadmin:directadmin:1.30.2`,
        fs:  `cpe:2.3:a:mollify:mollify:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:directadmin:directadmin:1.403`,
        fs:  `cpe:2.3:a:quest:spotlight:7.6.0.1559:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:directfb:directfb:1.4.4`,
        fs:  `cpe:2.3:o:trustix:secure_linux:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:directfb:directfb:1.4.13`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:directwebremoting:direct_web_remoting:2.0.10`,
        fs:  `cpe:2.3:o:vmware:esx:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:directwebremoting:direct_web_remoting:3.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:directwebremoting:direct_web_remoting:3.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dirlist:dirlist_php:0.1.1`,
        fs:  `cpe:2.3:h:cisco:spa_500s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dirphp_project:dirphp:1.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dish:dish_anywhere:3.5.10::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)xy4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disney:maleficent_free_fall:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disney:where%27s_my_perry%3f_free:1.5.1::~~~android~~`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disney:where%27s_my_water%3f_free:1.9.1::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:displaylink:displaylink_core_software:5.5.27257.0`,
        fs:  `cpe:2.3:a:livezilla:livezilla:3.1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:displaylink:displaylink_core_software:6.0.33743.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xd1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:displaylink:displaylink_graphics:5.5.27358.0`,
        fs:  `cpe:2.3:a:hp:storage_vcs_base_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:displaylink:displaylink_graphics:6.0.33809.0`,
        fs:  `cpe:2.3:a:x:libfs:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.40::~~~wordpress~~`,
        fs:  `cpe:2.3:o:google:android:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.41::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.42::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.43::~~~wordpress~~`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.44::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.45::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.46::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-05-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.47::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.48::~~~wordpress~~`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.02:pl4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.49::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netscout:ngenius_client:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.50::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.51::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.52::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.53::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.45.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.54::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:developer_tools_for_visual_studio_.net_help:10.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.55::~~~wordpress~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.60::~~~wordpress~~`,
        fs:  `cpe:2.3:a:samba:samba:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.61::~~~wordpress~~`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.62::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.51a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.63::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:roller:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.64::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.65::~~~wordpress~~`,
        fs:  `cpe:2.3:h:huawei:wlan_ac_6605:v200r001c00spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.66::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digia:qt:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.67::~~~wordpress~~`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.68::~~~wordpress~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.69::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:openjpa:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.70::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/f:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.71::~~~wordpress~~`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.72::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kicksend:kicksend_photo_prints:1.0.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.73::~~~wordpress~~`,
        fs:  `cpe:2.3:a:xerox:device_agent:3.8.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.74::~~~wordpress~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.75::~~~wordpress~~`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.76::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:disqus:disqus_comment_system:2.77::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:distributive:datadrill:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.7.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:krisonav:krisonav:0.9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.23:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.1.151.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:conectiva:linux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:claroline:claroline:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:8.5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1014:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.15::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1058:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:exim:exim:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.21::~~~wordpress~~`,
        fs:  `cpe:2.3:a:avg:internet_security:8.5:-:sbs:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.22::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.23::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.24::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.25::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.26::~~~wordpress~~`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.0.163652.1142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.27::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:c3160:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.28::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.29::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:content_navigator:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.30::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.32::~~~wordpress~~`,
        fs:  `cpe:2.3:a:f5:big-iq_cloud:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.33::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:air:19.0.0.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.34::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.35::~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:netmail:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.36::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.37::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.38::~~~wordpress~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.0.39::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:devsaran:responsive_blog:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(4j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:quest:benchmark_factory_for_databases:6.0.0.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diversesolutions:dsidxpress_idx_plugin:2.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:h:alphanetworks:vdsl_asl-56552:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:aac_decoder:7.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:avi_codec_pack_pro:2.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:5.1.1`,
        fs:  `cpe:2.3:a:codehaus:redback:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:5.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:5.2.1`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.0.3`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.1`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.2`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.20d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.5`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.624:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.6.0`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.6.1`,
        fs:  `cpe:2.3:h:cisco:cache_engine_505:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.7`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.8`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.8.4`,
        fs:  `cpe:2.3:h:hp:elitebook_725_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:codec:6.8.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.267:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:content_uploader:1.0.0`,
        fs:  `cpe:2.3:a:juniper:junos_pulse_access_control_service:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:content_uploader:1.2.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:9.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.12:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.0.3`,
        fs:  `cpe:2.3:h:linksys:befsr81:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.1`,
        fs:  `cpe:2.3:a:mcafee:asset_baseline_monitor_agent:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.1.1`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.2`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.2.1`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.28.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.5`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.5.1`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.0.02:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:6.6`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:converter:7.1`,
        fs:  `cpe:2.3:a:ostenta:yawpp:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:directshowdemuxfilter:-`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_codec:6.8.5`,
        fs:  `cpe:2.3:a:condor_project:condor:7.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_codec:6.9.1`,
        fs:  `cpe:2.3:a:openmrs:openmrs:2.1:*:*:*:standalone:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_converter:7.1.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_player:7.2.0`,
        fs:  `cpe:2.3:a:ca:unicenter_dsm_agent_\&#43;_remote_control_plugin:11.2.4000.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_player:7.2.0.19`,
        fs:  `cpe:2.3:a:google:v8:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_plus_web_player:2.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:48.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_version_checker:7.1.0.2`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_version_checker:7.1.0.9`,
        fs:  `cpe:2.3:a:adobe:camera_raw:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_web_player:-`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:divx_web_player:1.5.0`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.5.c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:h.264_decoder:1.1.0`,
        fs:  `cpe:2.3:h:moxa:iologic_e2212-t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:mkv_splitter:1.0.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.0`,
        fs:  `cpe:2.3:a:citrix:access_management_console_report_center:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.1`,
        fs:  `cpe:2.3:o:microsoft:windows_98:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.1.1`,
        fs:  `cpe:2.3:a:genetechsolutions:pie_register:2.0.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.3`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.3.2`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.4`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.4.1`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.4.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.4.3`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.130.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.5`,
        fs:  `cpe:2.3:a:samba:samba:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.6`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.7`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.8`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:6.8.2`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:7.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:12.0.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:7.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.6.0.599:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:player:7.2`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_entry_client:2.35:-:*:*:*:windows_mobile:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:web_player:1.0.0`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.2.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:web_player:1.1.0`,
        fs:  `cpe:2.3:a:citadel:smtp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:web_player:1.2.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:17.0.0.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:web_player:1.3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel-rt:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:divx:web_player:1.5.0`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diy-cms:diy-cms:1.0`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diychatroom:diychatroom:3.4.0::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:coldfusion:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:diziturky:diziturky_hd_2015:2014::~~~android~~`,
        fs:  `cpe:2.3:a:roguewaveproductionsllc:wild_women_united:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:django-markupfield_project:django-markupfield:1.3.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:0.95`,
        fs:  `cpe:2.3:a:apache:activemq:5.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:0.96`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.0:alpha1`,
        fs:  `cpe:2.3:a:apache:tomcat:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.0:alpha2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.0:beta`,
        fs:  `cpe:2.3:o:arubanetworks:instant_access_point_firmware:4.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.0:beta2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.0.1`,
        fs:  `cpe:2.3:a:sympa:sympa:2.2.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.0.2`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.1`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.1:alpha1`,
        fs:  `cpe:2.3:a:jetbrains:intellij_idea:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.1:beta1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.1:rc1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.1.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:12.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.1.3`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.1.4`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:6.1.4.61696:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2`,
        fs:  `cpe:2.3:a:symas:connexitor_directory_services:3.11.3:*:*:*:silver_edition:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2:beta1`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2:rc1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2-alpha1`,
        fs:  `cpe:2.3:h:cisco:rv320_dual_gigabit_wan_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2.2`,
        fs:  `cpe:2.3:a:redhat:spice-activex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2.4`,
        fs:  `cpe:2.3:a:microsys:promotic:8.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p438:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.31:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.2.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.3`,
        fs:  `cpe:2.3:o:xen:xen:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.3:alpha1`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.3:beta1`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.3.1`,
        fs:  `cpe:2.3:a:e107:e107:0.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.3.2`,
        fs:  `cpe:2.3:a:lxml:lxml:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.3.3`,
        fs:  `cpe:2.3:a:gnome:epiphany:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.3.6`,
        fs:  `cpe:2.3:a:clamav:clamav:0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.15.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.4`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.5`,
        fs:  `cpe:2.3:h:camtron:cmnc-200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.6`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.7`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.8`,
        fs:  `cpe:2.3:a:pkware:pkzip:12.50.0014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.9`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.10`,
        fs:  `cpe:2.3:a:intel:2200bg_proset_wireless:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.11`,
        fs:  `cpe:2.3:a:sun:java_system_access_manager:6.3_2005q4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.13`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.14`,
        fs:  `cpe:2.3:a:perl:perl:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.17`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.19`,
        fs:  `cpe:2.3:a:microsoft:ie:4.70.1215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.20`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.4.21`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5:alpha`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5:beta`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.1`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.2`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction:6.0.1.218452:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.3`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.4`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.5`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.6`,
        fs:  `cpe:2.3:a:ibm:net.data:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.7`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.8`,
        fs:  `cpe:2.3:a:op5:monitor:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.9`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.10`,
        fs:  `cpe:2.3:a:samba-tng:samba-tng:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.11`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.5.12`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:17.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6:-`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.9-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6:beta1`,
        fs:  `cpe:2.3:a:apple:transporter:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6:beta2`,
        fs:  `cpe:2.3:a:pgp:desktop_for_mac:10.0.3:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6:beta3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:4.1.2:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6:beta4`,
        fs:  `cpe:2.3:a:ibm:rational_license_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.1`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.4`,
        fs:  `cpe:2.3:h:cisco:ie-5000-12s12p-10g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.5`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.9.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.6`,
        fs:  `cpe:2.3:a:gnu:gdb:4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.7`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.2:rc1:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.8`,
        fs:  `cpe:2.3:a:ibm:lotus_mobile_connect:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.508:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.6.10`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_server:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7:beta1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7:beta2`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1.\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7:beta3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7:beta4`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7:rc1`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3f:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7:rc2`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7:rc3`,
        fs:  `cpe:2.3:a:websvn:websvn:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.2`,
        fs:  `cpe:2.3:a:cisco:finesse:11.0\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.3`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.4`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.5`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.6`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.7`,
        fs:  `cpe:2.3:a:nortel:helmsman:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.8`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.9`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.7.10`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8:beta1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.361:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.0`,
        fs:  `cpe:2.3:a:php:php:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.0:a1`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.0:b1`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.0:b2`,
        fs:  `cpe:2.3:o:carlosgavazzi:eos-box_photovoltaic_monitoring_system_firmware:1.0.0.1080_2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.0:c1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.1`,
        fs:  `cpe:2.3:a:altiris:monitor_agent_for_unix_and_linux:6.0.3143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.2`,
        fs:  `cpe:2.3:a:lsi:megaraid_storage_manager:2.91.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.4`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:7.0.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.5`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.6`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.9`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.14`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.16`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.9.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.8.17`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9`,
        fs:  `cpe:2.3:a:sympies:wordpress_survey_and_poll:1.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9:a1`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9:b1`,
        fs:  `cpe:2.3:a:janrain:ruby-openid:2.2.2:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9:rc1`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9:rc2`,
        fs:  `cpe:2.3:a:henner_zeller:henplus:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9.1`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.1.2-29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9.2`,
        fs:  `cpe:2.3:a:google:toolbar_for_internet_explorer:7.1.2003.1856:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9.8`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9.9`,
        fs:  `cpe:2.3:a:gnome:glib:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9.11`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.72:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.9.12`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.10.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_2926t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.10.0:a1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.10.0:b1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.10.0:rc1`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_expansion_module_7916:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.10.3`,
        fs:  `cpe:2.3:a:componentone:vsflexgrid:7.0.1.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.10.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.10.5`,
        fs:  `cpe:2.3:a:cool_video_gallery_project:cool_video_gallery:1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:django:1.10.6`,
        fs:  `cpe:2.3:o:yahama:rt56v:4.07.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:piston:0.2.2.0`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djangoproject:tastypie:0.9.9`,
        fs:  `cpe:2.3:a:mckenziecreations:virtual_real_estate_manager:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djinnworks:line_runner_%28free%29:4.0::~~~android~~`,
        fs:  `cpe:2.3:a:freelinking_for_case_tracker_project:freelinking_for_case_tracker:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:djinnworks:stickman_ski_racer:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djogjahotel:liburan_hemat:1::~~~android~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd239a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.1`,
        fs:  `cpe:2.3:a:ca:systems_performance_for_infrastructure_managers:12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.3`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.4`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.5`,
        fs:  `cpe:2.3:a:ibm:installation_manager:1.8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.6`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.7`,
        fs:  `cpe:2.3:a:google:chrome:5.0.337.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.8`,
        fs:  `cpe:2.3:a:isc:bind:4.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.9`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.10`,
        fs:  `cpe:2.3:a:gimp:gimp:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.11`,
        fs:  `cpe:2.3:a:prestosoft:examdiff:1.8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.12`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.13`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1107.101.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.14`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.15`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.16`,
        fs:  `cpe:2.3:a:ca:messaging:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.17`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.18`,
        fs:  `cpe:2.3:a:tenable:nessus:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.19`,
        fs:  `cpe:2.3:a:sybase:easerver:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.20`,
        fs:  `cpe:2.3:a:apple:apple_tv:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.21`,
        fs:  `cpe:2.3:h:hp:sn6000_stackable_8gb_24-port_single_power_fibre_channel_switch:aw575a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.22`,
        fs:  `cpe:2.3:a:commerce_ogone_project:commerce_ogone:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.23`,
        fs:  `cpe:2.3:a:busybox:busybox:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.24`,
        fs:  `cpe:2.3:o:cisco:ons_15600:1.3\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:djvulibre_project:djvulibre:3.5.25`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dkorunic:pam_s%2fkey:-`,
        fs:  `cpe:2.3:h:3com:3c16987a-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-alpha1::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.360.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc1::~~~drupal~~`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.1:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc2::~~~drupal~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.2.1:-:ipad:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc3::~~~drupal~~`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.0.1.12855:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc4::~~~drupal~~`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc5::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:earth:5.0.11733.9347:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc6::~~~drupal~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc7::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc8::~~~drupal~~`,
        fs:  `cpe:2.3:a:emc:solutions_enabler:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc9::~~~drupal~~`,
        fs:  `cpe:2.3:a:wp_php_widget_project:wp_php_widget:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.0-rc10::~~~drupal~~`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:vmware:zimbra_desktop:7.1.2:b10978:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:6.x-1.x-dev::~~~drupal~~`,
        fs:  `cpe:2.3:a:tattyan:tattyan_hptown:5_9_3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:14.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-alpha1::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:excel:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-alpha2::~~~drupal~~`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-alpha3::~~~drupal~~`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-beta1::~~~drupal~~`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-beta2::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-beta3::~~~drupal~~`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.5:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-rc1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-rc2::~~~drupal~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-rc3::~~~drupal~~`,
        fs:  `cpe:2.3:a:owncloud:owncloud:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.0-rc4::~~~drupal~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:19.0.0.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:1.0.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlc_solutions:course:7.x-1.x-dev::~~~drupal~~`,
        fs:  `cpe:2.3:h:d-link:dir-619l:b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dleviet:datalife_engine:9.7`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlguard:dlguard:4.5`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlguard:dlguard:4.6`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6cbz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlguard:dlguard:5.0`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dli.tools:uploader:1.5.4::~~professional~~~`,
        fs:  `cpe:2.3:a:emc:networker:7.5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:dcs-2000:-`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:dcs-5300:-`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2014:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:dcs-900:-`,
        fs:  `cpe:2.3:a:apple:itunes:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:dcs-950g:-`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.08.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:des-3800:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlink:des-3800_firmware:4.00`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.4.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:des-3800_firmware:4.00`,
        fs:  `cpe:2.3:a:cisco:backup_and_restore_system:4.0.14000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlink:des-3800_firmware:4.50`,
        fs:  `cpe:2.3:a:xlabz:sketch_w_friends_free_-tablets:5.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:des-3800_firmware:4.50`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:11.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:des-3810:-`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:9.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:des-3810-28:-`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.6\(1.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:des-3810-28_firmware:r2.20.b017`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:des-3810_firmware:r2.00.009`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:06-71-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:des-3810_firmware:r2.15.004`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:des-3810_firmware:r2.20.011`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:dir865l:-`,
        fs:  `cpe:2.3:a:isc:bind:9.8.1:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:dir865l_firmware:1.00b24`,
        fs:  `cpe:2.3:a:open_source_development_team:sthttpd:2.26.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:dir865l_firmware:1.02`,
        fs:  `cpe:2.3:h:extremenetworks:blackdiamond_8800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:dir865l_firmware:1.03`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:dir865l_firmware:1.05`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:dir865l_firmware:1.05b07`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:dsl-2640b:-`,
        fs:  `cpe:2.3:a:firaxis:sid_meiers_civilization_iii:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:dsl-2640b_firmware:4.00`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:dlink:dsl-2740b_firmware:1.00`,
        fs:  `cpe:2.3:a:git-scm:git:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:dwl-2100ap:-`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlink:dwl-2100ap_firmware:2.50`,
        fs:  `cpe:2.3:a:pdfforge:pdfcreator:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:dlink:dwl-3200ap:-`,
        fs:  `cpe:2.3:a:djangoproject:django:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlink:dwl-3200ap_firmware:2.40`,
        fs:  `cpe:2.3:a:apache:mod_python:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlink:dwl-3200ap_firmware:2.55`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1.2:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.0.1`,
        fs:  `cpe:2.3:a:revive-adserver:revive_adserver:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.0.2`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.1:alpha2`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.9:alpha1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.9:alpha2`,
        fs:  `cpe:2.3:a:humhub:humhub:0.20.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.9:alpha3`,
        fs:  `cpe:2.3:a:avery:avery_wizard:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.9:alpha4`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.9:alpha5`,
        fs:  `cpe:2.3:a:adobe:captivate_reviewer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:1.9:alpha6`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.0`,
        fs:  `cpe:2.3:a:vips:vips:7.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.0.1`,
        fs:  `cpe:2.3:a:splunk:splunk:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.1.0`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.4.0:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.1.0:alpha1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.1.0:alpha2`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.1.0:beta1`,
        fs:  `cpe:2.3:a:paypal:merchant_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(122\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.4`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.4.1`,
        fs:  `cpe:2.3:a:home_made_air_freshener_project:home_made_air_freshener:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.5`,
        fs:  `cpe:2.3:a:mcafee:security_center:6.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlitz:pycrypto:2.6`,
        fs:  `cpe:2.3:h:polycom:soundpoint_ip_601:1.6.3.0067_bootrom_3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.1.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.2.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.4:bundle16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.2.2`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.4.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.4.1`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.4.2`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.6.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.6.1`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.6.2`,
        fs:  `cpe:2.3:a:location_module_project:location:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.6.3`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.7.0`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.7.1`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.0:dev2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.7.2`,
        fs:  `cpe:2.3:a:canon:imagerunner_c6800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.7.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.7.4`,
        fs:  `cpe:2.3:a:apache:geronimo:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.8.0`,
        fs:  `cpe:2.3:a:cisco:prime_home:5.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:0.9.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:1.0.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:1.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:1.1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:1.1.2`,
        fs:  `cpe:2.3:a:unisys:sma_microsoft_lsam_.net:5.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:1.2.0`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:1.2.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(4\)sv1\(3d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dlo:simple_anti_bot_registration_engine_plugin:1.2.2`,
        fs:  `cpe:2.3:a:apache:mod_python:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultracompare:6.00`,
        fs:  `cpe:2.3:a:atmail:atmail:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultracompare:6.10`,
        fs:  `cpe:2.3:a:businessobjects:webintelligence:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultracompare:6.20`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultracompare:6.30`,
        fs:  `cpe:2.3:a:psychology_project:psychology:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultracompare:6.40`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultracompare:6.40.1`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.0:-:viewer:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:1`,
        fs:  `cpe:2.3:a:surfcontrol:superscout:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:8.00`,
        fs:  `cpe:2.3:a:peernet:file_conversion_center:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:8.00a`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:8.00b`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:8.10`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:8.10a`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-71:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:8.10b`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_firmware:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:8.20`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:8.20a`,
        fs:  `cpe:2.3:a:boost:boost:1.48.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.00`,
        fs:  `cpe:2.3:a:apache:hadoop:2.0.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.00a`,
        fs:  `cpe:2.3:a:abu_ali_anasheeds_project:abu_ali_anasheeds:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.00b`,
        fs:  `cpe:2.3:h:huawei:eudemon300:v200r006c02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.00c`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.10`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.10a`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2004:sp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.10b`,
        fs:  `cpe:2.3:a:hitachi:cosminexus\/opentp1_web_web_front-endset:01-01-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.20`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:614:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.20a`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:9.20b`,
        fs:  `cpe:2.3:a:ipswitch:imail:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.00`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.033_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.00a`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.00b`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.00c`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.10`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.10a`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.11:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.10b`,
        fs:  `cpe:2.3:a:samba:samba:4.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.10c`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.20`,
        fs:  `cpe:2.3:a:microsoft:office:98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.20a`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.54:bbet54v:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.20b`,
        fs:  `cpe:2.3:a:microsoft:ie:4.40.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.20c`,
        fs:  `cpe:2.3:a:akiva:webboard:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:10.20d`,
        fs:  `cpe:2.3:a:webmin:usermin:0.930:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:11.00`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:11.00a`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.3:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:11.00b`,
        fs:  `cpe:2.3:a:lvtu99:wisdom:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:11.10`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:11.10a`,
        fs:  `cpe:2.3:a:ibm:java:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:11.10b`,
        fs:  `cpe:2.3:a:redhat:openshift_origin:1.0.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:11.10c`,
        fs:  `cpe:2.3:a:sun:java_enterprise_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:11.20`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cpie:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:12.00`,
        fs:  `cpe:2.3:a:hp:proliant_ilo_monitor_service:3.1.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:12.10`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:12.10a`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:12.10b`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:12.20`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:12.20a`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:12.20b`,
        fs:  `cpe:2.3:a:qemu:qemu:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:13.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:13.00a`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:13.10`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:13.10a`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:13.20`,
        fs:  `cpe:2.3:a:vips:vips:7.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:14.00`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:14.00a`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:14.00b`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:14.2`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:14.10.0`,
        fs:  `cpe:2.3:a:persits:aspupload:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:14.10.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:14.20.0`,
        fs:  `cpe:2.3:a:juniper:netscreen_remote_security_client:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:14.20.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:15.00.0`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:15.10.0`,
        fs:  `cpe:2.3:a:oracle:oracle_berkeley_db:12.1.6.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:15.20.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:16.10.0.1036`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit:16.20.0.1009`,
        fs:  `cpe:2.3:a:qemu:qemu:0.13.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit-32:10.20d%2b`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dm_computer_solutions:ultraedit-32:11.00a`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dmca:dmca_watermarker:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:h:netgear:rt314:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dmca:dmca_watermarker:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dmitry_loac:taxotouch:-`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dmv.ca.gov:ca_dmv:2.0::~~~android~~`,
        fs:  `cpe:2.3:a:citrix:xenapp_administration:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dnb:dnb_trade:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dnovus:navy_drug_screening_program:5.2.6.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.41:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dns-sync_project:dns-sync:0.1.0::~~~node.js~~`,
        fs:  `cpe:2.3:a:webmin:usermin:1.510:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doapps:go_msx_mls:2.3.4.mr3::~~~android~~`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6ccc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docebo:docebolms:2.0.4`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docebo:docebolms:2.0.5`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docebo:docebolms:4.0`,
        fs:  `cpe:2.3:a:exim:exim:4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docebo:docebolms:4.0.4`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.1`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.4.1794:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.2`,
        fs:  `cpe:2.3:a:mozilla:camino:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.3`,
        fs:  `cpe:2.3:a:nullsoft:winamp:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.4`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:4.1:update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.5`,
        fs:  `cpe:2.3:h:siemens:synco_ozw_web_server:ozw672.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.6`,
        fs:  `cpe:2.3:a:mahara:mahara:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.7`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.1.8`,
        fs:  `cpe:2.3:a:google:v8:3.23.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.2.0`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.2.1`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.2.2`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.3.0`,
        fs:  `cpe:2.3:a:pyyaml:libyaml:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.3.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.6:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.3.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.3.3`,
        fs:  `cpe:2.3:a:logilab:logilab-common:0.61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.3.4`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.0`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.4`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.5`,
        fs:  `cpe:2.3:a:python:pillow:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.6`,
        fs:  `cpe:2.3:h:cisco:telepresence_mcu_4501:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.7`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.96:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.4.8`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:sp1a:developer:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.5.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.5.1`,
        fs:  `cpe:2.3:a:winscp:winscp:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.5.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.5.3`,
        fs:  `cpe:2.3:a:cisco:e-mail_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.6.0`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:beta_7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.6.1`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.6.2`,
        fs:  `cpe:2.3:a:datadynamics:activereports:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.6.3`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.6.4`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.6.5`,
        fs:  `cpe:2.3:a:redhat:freeipa:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.6.6`,
        fs:  `cpe:2.3:a:vips:vips:7.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.6.7`,
        fs:  `cpe:2.3:a:python:python:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.7.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.7.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.7.2`,
        fs:  `cpe:2.3:a:atmail:atmail:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.7.3`,
        fs:  `cpe:2.3:a:compaq:enterprise_volume_manager-command_scripter:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.7.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.7:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.7.5`,
        fs:  `cpe:2.3:a:boost:boost:1.46.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.7.6`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.8.0`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.8.1`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.9.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.9.1`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.10.`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.11.`,
        fs:  `cpe:2.3:a:brian_akers:mod_layout:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:0.12.`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.0.0`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ebr:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.0.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.1.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.1.2`,
        fs:  `cpe:2.3:a:intelliants:esyndicat:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.3.0`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.3.1`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.3.2`,
        fs:  `cpe:2.3:h:antlabs:inngate_ig_3.10_g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.3.3`,
        fs:  `cpe:2.3:a:rpm:rpm:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.4.0`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2000i:sp1:unlocked:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.5.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.6`,
        fs:  `cpe:2.3:a:google:chrome:13.0.777.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.6.0`,
        fs:  `cpe:2.3:a:verification_code_for_comments_project:verification_code_for_comments:2.1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.6.1`,
        fs:  `cpe:2.3:a:privoxy:privoxy:3.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.6.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.7.0`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:9.3.014.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.8.0`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.8.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.8.2`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.8.3`,
        fs:  `cpe:2.3:a:rpm:rpm:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.9.0`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.9.1`,
        fs:  `cpe:2.3:a:nicolas_cannasse:ocaml_xml-light_library:r233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.10.0`,
        fs:  `cpe:2.3:a:freebsd:slashem-tty:0.0.6e.4f.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.10.1`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.10.2`,
        fs:  `cpe:2.3:a:apache:solr:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.10.3`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.11.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.11.1`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1:-:small_business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.11.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.12.0`,
        fs:  `cpe:2.3:a:docker:docker:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.12.1`,
        fs:  `cpe:2.3:a:isc:bind:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.12.2`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.12.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.12.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.12.5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.10:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.12.6`,
        fs:  `cpe:2.3:a:ibm:leads:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.13.0`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker:1.13.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.06.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:docker:docker-py:0.5.3`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0577:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:documentcloud:karteek-docsplit:0.5.4`,
        fs:  `cpe:2.3:a:haxx:curl:7.48.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dog_whistle_project:dog_whistle:1.9::~~~android~~`,
        fs:  `cpe:2.3:a:debian:toolchain-source:3.0.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dojotoolkit:dojo:1.1.1`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2005-07-01`,
        fs:  `cpe:2.3:a:vmware:workstation:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2005-07-13`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2005-09-19`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p328:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2005-09-22`,
        fs:  `cpe:2.3:a:codiad:codiad:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2006-03-05`,
        fs:  `cpe:2.3:a:bluecoat:content_analysis_system_software:1.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2006-03-09`,
        fs:  `cpe:2.3:a:gentoo:rootkit_hunter:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2006-11-06`,
        fs:  `cpe:2.3:h:xerox:workcentre:m123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2007-06-26`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2007-07-13`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2008-05-05`,
        fs:  `cpe:2.3:a:citrix:metaframe:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2009-02-14`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2009-02-14b`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2009-12-25c`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.5.57173.439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2010-11-07a`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.2.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2011-05-25`,
        fs:  `cpe:2.3:a:vcccd:myvcccd:1.4.14:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2011-05-25a`,
        fs:  `cpe:2.3:h:cisco:catalyst_6513-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2011-05-25c`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2012-01-25`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2012-01-25a`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2014-05-05c`,
        fs:  `cpe:2.3:a:die-netzmacher:browser:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:2014-09-29b`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:rc2009-01-30`,
        fs:  `cpe:2.3:a:freedownloadmanager:freedownloadmanager:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:rc2009-02-06`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.44:-:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-07-04`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-07-07`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_server:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-07-12`,
        fs:  `cpe:2.3:a:apache:openjpa:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-07-21`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_tray_monitor:11.0.17318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-07-25`,
        fs:  `cpe:2.3:a:esri:arcinfo_workstation:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-08-08`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-08-15a`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-08-22`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-09-12`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-09-25`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-09-30`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-10-19`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-11-01`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-11-02`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2004-11-10`,
        fs:  `cpe:2.3:o:netbsd:netbsd:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-01-14`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-01-15`,
        fs:  `cpe:2.3:a:hp:service_manager:9.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-01-16a`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:17.012.20093:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-02-06`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-02-18`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.7-el6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-05-07`,
        fs:  `cpe:2.3:a:rsa:bsafe_ssl-j_sdk:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-07-01`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-07-13`,
        fs:  `cpe:2.3:a:justsystems:atok:2009:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-09-19`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.13.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2005-09-22`,
        fs:  `cpe:2.3:o:novell:suse_linux:11:*:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2006-03-05`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2006-03-09`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2006-03-09e`,
        fs:  `cpe:2.3:a:pgp:desktop_for_windows:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dokuwiki:dokuwiki:release_2006-06-04`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:2.5.0`,
        fs:  `cpe:2.3:h:huawei:me60:v100r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:2.6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:2.6.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:2.7.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:2.7.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:2.8.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:2.8.1`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:2.9.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ez1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.0.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00-06:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.0.1`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.8:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.1.0`,
        fs:  `cpe:2.3:a:telos:amhs_data:10.11.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.1.0:rc`,
        fs:  `cpe:2.3:a:hp:lefthand_virtual_san_appliance_hydra:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.2.0`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.155:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.2.0:alpha`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.2.1`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.2.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.2.3`,
        fs:  `cpe:2.3:a:tibco:activematrix_policy_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.3.0`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.3.1`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.3.2`,
        fs:  `cpe:2.3:a:ca:license_software:1.54.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.3.3`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.4.0`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_microsoft_excel:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.4.1`,
        fs:  `cpe:2.3:a:borland:ldap_quickstart_manager:10.0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.4.2`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.4.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.5.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.5.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.461.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.5.2`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.5.3`,
        fs:  `cpe:2.3:a:oracle:sparc-opl_service_processor:1121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.5.4`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.14:ga9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:3.8.2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolibarr:dolibarr:4.0.4`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dolphin-browser:dolphin_browser_cn:6.3.1`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2_ms2_2006-08-17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolphin-browser:dolphin_browser_cn:7.2.1`,
        fs:  `cpe:2.3:a:monotone:monotone:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolphin-browser:dolphin_browser_hd:6.2.0`,
        fs:  `cpe:2.3:a:google:v8:3.22.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolphin-browser:dolphin_browser_hd:7.2.1`,
        fs:  `cpe:2.3:a:nagios:plugins:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolphin-browser:dolphin_browser_hd:7.3.0`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolphin-browser:dolphin_browser_hd:7.4.0`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dolphin-browser:dolphin_browser_mini:2.2`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.12.1201:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:5.x-1.0`,
        fs:  `cpe:2.3:a:tincan:phplist:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:5.x-1.0:beta1`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.40:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:5.x-1.0:beta2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:5.x-1.x:dev`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:6.x-1.0`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:6.x-2.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:6.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:gnupg:gpgee:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:6.x-2.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:6.x-2.2`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:8.10:-:*:*:*:windows_server_2008:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:6.x-2.3`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp2:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:7.x-1.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.457.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:7.x-2.0`,
        fs:  `cpe:2.3:a:humhub:humhub:0.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:7.x-2.1`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:7.x-2.3`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:7.x-2.4`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dominique_clause:search_autocomplete:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.0`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.2`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.4`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.5`,
        fs:  `cpe:2.3:a:sylpheo:sylphone:5.3.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.7`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.8`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:1.9`,
        fs:  `cpe:2.3:a:digi:www_server:compieuw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.1`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.2`,
        fs:  `cpe:2.3:a:emc:centerstage:1.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.3`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.4`,
        fs:  `cpe:2.3:a:zope:zope:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.6`,
        fs:  `cpe:2.3:a:orbitscripts:orbit_open_ad_server:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.7`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.8`,
        fs:  `cpe:2.3:o:arubanetworks:instant_access_point_firmware:4.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:2.9`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.0`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.4`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.5`,
        fs:  `cpe:2.3:a:microsoft:asp.net_signalr:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(14\)st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.8`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:3.9`,
        fs:  `cpe:2.3:a:palm:blazer:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.91:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.0.1`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.0.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:2015.006.30060:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.1.1`,
        fs:  `cpe:2.3:h:okidata:3037e_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.1.2`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.2`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.2.2`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.3`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:alpha1:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.4`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.5`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.6`,
        fs:  `cpe:2.3:a:augeas:augeas:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.7`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.7.1`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.7.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.7.3`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.7.5`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3610-28tp_ls-3610-28tp-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.8`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.8.1`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.8.2`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_3210:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.8.5`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.9`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.9.1`,
        fs:  `cpe:2.3:a:amecuae:amgc:6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:4.9.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.0`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.0:beta`,
        fs:  `cpe:2.3:o:emc:data_domain:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.0.2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:2015.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.0.3`,
        fs:  `cpe:2.3:a:juniper:junos_space:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.1`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.1.1`,
        fs:  `cpe:2.3:a:drupal:drupal:7.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.1.3`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.1.4`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.3`,
        fs:  `cpe:2.3:a:sun:solaris_libxfont:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.3.1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.4`,
        fs:  `cpe:2.3:a:busybox:busybox:1.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.4:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.4.1`,
        fs:  `cpe:2.3:a:serf_project:serf:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.4.2`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.4.3`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.cors:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.4.4`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:ccg:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.4.5`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.0\(.00048\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:don_ho:notepad%2b%2b:5.5`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doodlegod:doodle_devil_free:2.1.4::~~~android~~`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doorkeeper_project:doorkeeper:1.4.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:opus-codec:opus:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dopewars:dopewars:1.5.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.1.0`,
        fs:  `cpe:2.3:a:anl:bcfg2:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.2.0`,
        fs:  `cpe:2.3:h:postoaktraffic:awam_bluetooth_reader:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.3.0`,
        fs:  `cpe:2.3:a:webmin:usermin:1.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.3.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.00:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.4.0`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.4.1`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.9:rc1:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.4.3`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.4.4`,
        fs:  `cpe:2.3:a:ipswitch:wincom_lpd:1.00.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doryphores:audio_player:2.0.4.5`,
        fs:  `cpe:2.3:a:pdfforge:pdfcreator:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dosfstools_project:dosfstools:3.0.28`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2012:-:shou:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dot:ccdpa:1.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:1.2.1`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:1.2.2`,
        fs:  `cpe:2.3:a:redhat:rhel_productivity:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:1.2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p243:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:1.2.4`,
        fs:  `cpe:2.3:a:apache:subversion:0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:1.2.5`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:1.2.6`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:1.2.7`,
        fs:  `cpe:2.3:a:borland:starteammpx_services:10.0.57.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:1.2.8`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0`,
        fs:  `cpe:2.3:a:redhat:network_satellite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:beta_2`,
        fs:  `cpe:2.3:a:intel:mcore:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:beta_3`,
        fs:  `cpe:2.3:a:tenable:nessus:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:beta_4`,
        fs:  `cpe:2.3:a:arcsight:arcsight_console:4.0.2.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:beta_5.2`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:beta_5.4`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:beta_6`,
        fs:  `cpe:2.3:a:macromedia:flash_media_server:2.0_r1145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:beta_7`,
        fs:  `cpe:2.3:a:xinhua-news:xinhua_international:5.5.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:rc1`,
        fs:  `cpe:2.3:a:magzter:human_factor:3.01:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:entourage:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.0.2`,
        fs:  `cpe:2.3:a:apple:xcode:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.1`,
        fs:  `cpe:2.3:a:ibm:iss_internet_scanner_software:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.1.1`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.1.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u2\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.1.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.1.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.1.7`,
        fs:  `cpe:2.3:a:ibm:infosphere_guardium:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.2`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.2.1`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.2.2`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.2.3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.3.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.3.1`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.4.2`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers:2.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.4.3`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.4.4`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.5.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.5.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.5.2`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.5.3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.6:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.6:rc`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(1t\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.6.1`,
        fs:  `cpe:2.3:h:linksys:befsr11:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.6.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.436:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.6.3`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotclear:dotclear:2.10.4`,
        fs:  `cpe:2.3:a:google:chrome:12.0.724.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:1.9`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:1.9.2.1`,
        fs:  `cpe:2.3:a:splunk:splunk:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:1.9.5.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.0.1`,
        fs:  `cpe:2.3:a:suse:studio_onsite:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.1.1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.2`,
        fs:  `cpe:2.3:a:billgbennett:bill_g._bennett:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.2.1`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.3.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.3.2`,
        fs:  `cpe:2.3:a:rsa:authentication_agent:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.5.1`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(7\)da:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.5.3`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.0.3.13070:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:2.5.4`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter:4.1.1.6534:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:3.2.1`,
        fs:  `cpe:2.3:a:hp:sitescope_server:11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:3.3`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:3.3.1`,
        fs:  `cpe:2.3:a:act:compass:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:3.5`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:3.6.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotcms:dotcms:3.7.0`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetblogengine:blogengine.net:1.4.5`,
        fs:  `cpe:2.3:h:cisco:c22_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetblogengine:blogengine.net:1.5`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetblogengine:blogengine.net:1.6`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak2:2.0.32.60:-:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetblogengine:blogengine.net:2.0`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.70.020.1425:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetblogengine:blogengine.net:2.5`,
        fs:  `cpe:2.3:a:ca:anti-virus_for_the_enterprise:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetblogengine:blogengine.net:2.6`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetblogengine:blogengine.net:2.7`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetblogengine:blogengine.net:2.8`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:1.0.6`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:1.0.7`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:1.0.8`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:1.0.9`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:1.0.10d`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:1.0.10e`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:2.1.1`,
        fs:  `cpe:2.3:h:intel:netstructure_7110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:2.1.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.03.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:3.0.7`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:3.0.8`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:3.0.11`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:3.1.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:3.3.5`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_xi:11.0.0.128227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1039:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.3.5`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:8.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.4.1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.5.2`,
        fs:  `cpe:2.3:a:teradata:shared_icu_libraries:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.5.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.5.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.6.0`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.6.1`,
        fs:  `cpe:2.3:a:ati:parental_control_\&amp;_encoder:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.6.2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.7.0`,
        fs:  `cpe:2.3:a:atlassian:jira:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.8.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.8.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(15\)ca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.8.2`,
        fs:  `cpe:2.3:a:apache:poi:3.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.8.3`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.8.4`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.1.0:-:-:-:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.9`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.9.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:4.9.2`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:5.0`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.2:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:5.1`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:5.1.1`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:06-70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:5.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:5.1.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.419:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:5.1.4`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:5.05.01`,
        fs:  `cpe:2.3:h:hp:advanced_server_9000:b.04.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:5.06.00`,
        fs:  `cpe:2.3:a:isc:bind:9.6.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.0.1`,
        fs:  `cpe:2.3:a:oracle:retail_xstore_point_of_service:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.1.0`,
        fs:  `cpe:2.3:a:adobe:homesite:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.1.1`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.1.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2\(0.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.1.3`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.1.4`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.1.5`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.0`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.1`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.2`,
        fs:  `cpe:2.3:a:imember360:imember360:3.4.018:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.3`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.4`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.5`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.6`,
        fs:  `cpe:2.3:a:forperfect:csupport:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.7`,
        fs:  `cpe:2.3:a:jijitechnologies:active_directory_cleaner:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:6.2.8`,
        fs:  `cpe:2.3:o:microsoft:windows_10:1511:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:7.0.0`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.14:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:7.0.1`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:7.0.2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:7.0.3`,
        fs:  `cpe:2.3:a:isc:bind:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:7.0.4`,
        fs:  `cpe:2.3:a:citrix:command_center:5.1:35.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:7.0.5`,
        fs:  `cpe:2.3:o:juniper:junos:13.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:7.0.6`,
        fs:  `cpe:2.3:h:supermicro:x9drw-3ln4f\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:7.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:07.03.04`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.141592:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotnetnuke:dotnetnuke:08.00.04`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:1.0.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:1.1.0`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.0.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(8a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.1.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.1.0:a`,
        fs:  `cpe:2.3:h:hp:proliant_dl120_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.1.0:b`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.5.0`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.6.0`,
        fs:  `cpe:2.3:a:w3:jigsaw:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.61.0`,
        fs:  `cpe:2.3:a:pgp:keyserver:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.62.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.63.0`,
        fs:  `cpe:2.3:o:hp:laserjet_pro_m1216nfh_multifunction_printer_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.64.0`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:8.6\(2\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.70.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:2.72.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1653.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.00.0`,
        fs:  `cpe:2.3:a:oracle:http_server:10.1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.01.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_launcher:1.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.05.0`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:14.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.3`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.4`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.5`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.6`,
        fs:  `cpe:2.3:a:hp:application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.7`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.5:i2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.8`,
        fs:  `cpe:2.3:a:lemon-s_php:simple_oekaki_bbs:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.9`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.5.10`,
        fs:  `cpe:2.3:a:hp:http_server:5.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.07.0`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.08.0`,
        fs:  `cpe:2.3:a:goodwinproject:goodwin:1.15:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.10.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.20.0`,
        fs:  `cpe:2.3:a:toyotaownersclub:toyota_oc:3.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.22.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:2.2\(1.48\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.30.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.31.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.35.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:3.36.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:5.8`,
        fs:  `cpe:2.3:h:hp:jf809a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotpdn:paint.net:5.10`,
        fs:  `cpe:2.3:a:newsoftinc:presto\!_bizcard:5.20.51:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dotproject:dotproject:2.1.6`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:double-take_software:double-take:4.5.1.1869.6.s.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:double-take_software:double-take:5.1.0.861.42`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:double-take_software:double-take:5.1.1.1136.11`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:double-take_software:double-take:5.2.2.1852.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doug_poulin:command_school_student_management_system:1.06.01`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:doug_poulin:ommand_school_student_management_system:1.06.01`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.60531.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.0.11`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.1.0`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:11.10c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.1.1`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.1.2`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.1.4`,
        fs:  `cpe:2.3:a:oracle:identity_management_10g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.2.0`,
        fs:  `cpe:2.3:a:mistelix:mistelix:0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.2.1`,
        fs:  `cpe:2.3:a:fujitsu:interstage_studio:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.3.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.3.1`,
        fs:  `cpe:2.3:a:hp:openview_performance_access:10.50.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.4.0`,
        fs:  `cpe:2.3:a:microsoft:lync:2010:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.4.1`,
        fs:  `cpe:2.3:a:likeheroapp:likehero_get_instagram_likes:1.0.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.4.2`,
        fs:  `cpe:2.3:a:hp:openview_process_control:1.50.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.0`,
        fs:  `cpe:2.3:a:appthemes:classipress:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.1`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.2`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.3`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.5.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.4`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.5`,
        fs:  `cpe:2.3:a:php:pear:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.6`,
        fs:  `cpe:2.3:a:microsoft:file_transfer_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.8`,
        fs:  `cpe:2.3:a:mozilla:camino:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dounokouno:transmitmail:1.5.9`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.0`,
        fs:  `cpe:2.3:a:skyarc:autotagging:0.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1029.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.3`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:11.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.4`,
        fs:  `cpe:2.3:a:drupal:drupal:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.5`,
        fs:  `cpe:2.3:o:vmware:esx:3.5:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.6`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.7`,
        fs:  `cpe:2.3:a:cisco:qos_policy_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.8`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.035_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.9`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.6.0:-:ja:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.10`,
        fs:  `cpe:2.3:a:netscape:news_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.11`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.12`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.13`,
        fs:  `cpe:2.3:a:tinc-vpn:tinc:1.1:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.14`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:1.2.15`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0:beta1`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.91.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.0`,
        fs:  `cpe:2.3:a:symantec:opscenter_agent:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.1`,
        fs:  `cpe:2.3:a:isc:bind:9.10.2:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.17b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.3`,
        fs:  `cpe:2.3:h:hp:3com_router:6040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.383.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.5`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.6`,
        fs:  `cpe:2.3:h:hp:network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.7`,
        fs:  `cpe:2.3:h:zte:f660:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.8`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-50:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.9`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.10`,
        fs:  `cpe:2.3:a:google:chrome:8.0.556.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.11`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.12`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.13`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.2.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.14`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.5.2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.0.15`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1:rc1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1:rc2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1y\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1:rc3`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1:rc5`,
        fs:  `cpe:2.3:a:apache:opennlp:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1:rc6`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g_firmware:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1:rc7`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.0`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.2`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.3`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.4`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.5`,
        fs:  `cpe:2.3:a:suse:suse_office_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.6`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ez:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.8`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p212:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.11`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.12`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.13`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.14`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.15`,
        fs:  `cpe:2.3:a:iss:siteprotector_console:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.16`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.1.17`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2:rc1`,
        fs:  `cpe:2.3:a:apache:subversion:m3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2:rc2`,
        fs:  `cpe:2.3:a:emulex:fibre_channel_hbanyware:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2:rc3`,
        fs:  `cpe:2.3:h:supermicro:x9dax-7f-hft:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2:rc4`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2:rc5`,
        fs:  `cpe:2.3:a:apache:struts:2.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2:rc6`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2:rc7`,
        fs:  `cpe:2.3:a:perl:perl:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.0`,
        fs:  `cpe:2.3:a:hp:jg789a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.1`,
        fs:  `cpe:2.3:a:hp:power_manager_remote_agent:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.2`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.3`,
        fs:  `cpe:2.3:a:analogx:proxy:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.4`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_p1102:ce658a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.5`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.6`,
        fs:  `cpe:2.3:a:codehaus:redback:1.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.7`,
        fs:  `cpe:2.3:a:adobe:air:18.0.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.8`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.10`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.13:-`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovecot:dovecot:2.2.13:rc1`,
        fs:  `cpe:2.3:h:d-link:dir-645:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovestones:ad_self_password_reset:3.0.3.0`,
        fs:  `cpe:2.3:a:acme:thttpd:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dovestones:true_last_logon:2.9.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.4:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:case_manager:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:cups:1.7.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:service_manager_server:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.5.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.0.641:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.5.32::~~~wordpress~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:1.5.33::~~~wordpress~~`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:wordperfect_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(21b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:remote_access_to_hp_network:6.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:7.0\(2\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:archiva:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.12::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.13::~~~wordpress~~`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-6530c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.17::~~~wordpress~~`,
        fs:  `cpe:2.3:h:polycom:soundpoint_ip_301:1.4.1.0040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:roxio:file_backup:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.0.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.8.213334.2131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(1n\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openafs:openafs:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:oracle_communications_unified_communications_suite_connector_for_microsoft_outlook:7.3.116.990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openfabrics:ibutils:1.5.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:3.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.815:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x:libxinerama:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.30:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:varec:fuelsmanager_defense:6.0_sp4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.3.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:livetecs:timeline:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dundas:dundas_chart_asp.net:3.5.0.1590:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:activesync:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.4.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:5.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:intel:entry_server_board_se7210tp1-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oscommerce:online_merchant:2.3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:san\/iq:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.8::~~~wordpress~~`,
        fs:  `cpe:2.3:h:siemens:scalance_x414-3e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.9::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:5550_color_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.91::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nextit:activeagent:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.92::~~~wordpress~~`,
        fs:  `cpe:2.3:o:ibm:aix:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.93::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.448:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.94::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:netmeeting:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.95::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.96::~~~wordpress~~`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.97::~~~wordpress~~`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.98::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1688.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.5.99::~~~wordpress~~`,
        fs:  `cpe:2.3:a:context_project:context:7.x-3.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.386.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:laserjet_p4515:cb514a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.5:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:opentext:desktop_viewer_3d\&#43;:8.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:05-01-\/l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.6::~~~wordpress~~`,
        fs:  `cpe:2.3:h:schneider_electric:struxureware_building_operations_automation_server_as-p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.91::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nortel:symposium_web_centre_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.92::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:658250-b21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.93::~~~wordpress~~`,
        fs:  `cpe:2.3:a:intel:network_connections:13.0.42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.94::~~~wordpress~~`,
        fs:  `cpe:2.3:a:thegr:dl:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.95::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:download_manager_project:download_manager:2.6.96::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sdo:youni_sms:2.1.0:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:downton_abbey_fan_portal_project:downton_abbey_fan_portal:1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.245.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dracut_project:dracut:-`,
        fs:  `cpe:2.3:a:emc:replication_manager:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drar-eym:drareym:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:draytek:vigor_2700_router:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:draytek:vigor_2700_router_firmware:2.8.3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drecom:reign_of_dragons%3a_build-battle:2.4.2::~~~android~~`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drei:3kundenzone:2.0::~~~android~~`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dressup:dress_up%21_girl_party:2.0::~~~android~~`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drifty:ionic_view:0.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:driver-soft:driver_genius:10.0::~~professional~~~`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:driveraccess:driveraccess:1.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:43.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:droboworks:drobo_dashboard:1.0.92`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dropbox:dropbox:0.7.110`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-11-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dropbox:lepton:1.2.1`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:1.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:webengage_project:webengage:2.0.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:novell:suse_package_hub_for_suse_linux_enterprise:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:vips:vips:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:revouninstaller:uninstaller:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupac:touch:7.x-1.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:-`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:4.6.10`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:4.7.4`,
        fs:  `cpe:2.3:a:redhat:jboss_web_framework_kit:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je006a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.0:beta1`,
        fs:  `cpe:2.3:a:openbsd:openbsd:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.0:beta2`,
        fs:  `cpe:2.3:a:openbsd:ftpd:5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.0:dev`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.0:rc2`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.1`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.2`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.3`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1497.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.4`,
        fs:  `cpe:2.3:a:homeadvisor:homeadvisor_mobile:3.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.5`,
        fs:  `cpe:2.3:a:bmc:control-m\/server:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.6`,
        fs:  `cpe:2.3:a:gnu:glibc:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.7`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.03:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.8`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:7.2.101.219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.9`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.3\(1.68\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.10`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.11`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:11.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.12`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.13`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.14`,
        fs:  `cpe:2.3:a:irokez:irokez_cms:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.15`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.16`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.17`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.18`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_internet_server:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.19`,
        fs:  `cpe:2.3:a:wp_silverlight_media_player_project:wp_silverlight_media_player:0.8:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.20`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.21`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.22`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:5.23`,
        fs:  `cpe:2.3:a:rsa:ace_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0`,
        fs:  `cpe:2.3:a:x:libxtst:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:beta1`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:beta2`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.762:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:beta3`,
        fs:  `cpe:2.3:a:dell:equallogic_san_headquarters:2.1.0.5342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:beta4`,
        fs:  `cpe:2.3:a:php:php:5.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:dev`,
        fs:  `cpe:2.3:a:microsoft:ie_for_macintosh:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:rc1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:rc2`,
        fs:  `cpe:2.3:o:novell:opensuse:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:rc3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.0:rc4`,
        fs:  `cpe:2.3:a:citrix:nfuse:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.3`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.2.1-jira42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.4`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.5`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:k:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.6`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.7`,
        fs:  `cpe:2.3:a:drupal:drupal:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.8`,
        fs:  `cpe:2.3:a:ca:configuration_automation_grid_node:12.5.8.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.9`,
        fs:  `cpe:2.3:a:invensys:wonderware_inbatch:9.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.10`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.11`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.12`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.13`,
        fs:  `cpe:2.3:a:sap:profile_maintenance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.14`,
        fs:  `cpe:2.3:a:bizagi:business_process_management_suite:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.15`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.16`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.17`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.18`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.2:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.19`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.20`,
        fs:  `cpe:2.3:a:sap:hybris:5.7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.21`,
        fs:  `cpe:2.3:a:piwik:piwik:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.22`,
        fs:  `cpe:2.3:a:beanshell_project:beanshell:2.0b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.23`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.311:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.24`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.25`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_application_server_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.26`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.27`,
        fs:  `cpe:2.3:a:cypherix:cryptainer_le:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.28`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.5.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.29`,
        fs:  `cpe:2.3:a:nagios:nagios:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.30`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.31`,
        fs:  `cpe:2.3:a:novell:iprint:5.90:-:*:*:*:windows_8:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.32`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.33`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.34`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.9.10:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.35`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.36`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:6.37`,
        fs:  `cpe:2.3:a:gnu:zlib:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:alpha1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:alpha2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:alpha3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:alpha4`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf020:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:alpha5`,
        fs:  `cpe:2.3:a:openstack:horizon:2014.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:alpha6`,
        fs:  `cpe:2.3:a:apache:hadoop:0.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:alpha7`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.6b.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:beta1`,
        fs:  `cpe:2.3:a:hp:openview_radia_management_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:beta2`,
        fs:  `cpe:2.3:a:tibco:formvine:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:beta3`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:dev`,
        fs:  `cpe:2.3:a:htc:evo_design_4g_software:2.12.651.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:rc1`,
        fs:  `cpe:2.3:a:mcafee:asap_virusscan:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:rc2`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:rc3`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.0:rc4`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.1`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.3`,
        fs:  `cpe:2.3:h:hp:service_manager_server:9.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.4`,
        fs:  `cpe:2.3:a:tenmiles:helpdesk_pilot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.5`,
        fs:  `cpe:2.3:a:openstack:horizon:2014.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.6`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.7`,
        fs:  `cpe:2.3:a:f5:big-ip_domain_name_system:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.8`,
        fs:  `cpe:2.3:h:cisco:aironet_ap340:11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.9`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.5:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.10`,
        fs:  `cpe:2.3:a:riken:xoonips:3.43:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.11`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.13`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.14`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.15`,
        fs:  `cpe:2.3:a:olivetoast:documents_pro_file_viewer:1.11.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.16`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_secureclient:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.17`,
        fs:  `cpe:2.3:a:surfcontrol:superscout_web_filter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.18`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.19`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(46\)se2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.20`,
        fs:  `cpe:2.3:h:cisco:integrated_services_router_800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.21`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/c:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.22`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.23`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.25`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.26`,
        fs:  `cpe:2.3:a:perl:perl:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.27`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.28`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.29`,
        fs:  `cpe:2.3:a:aimluck:aipo:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.30`,
        fs:  `cpe:2.3:o:cisco:staros:18.0.0.57828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.31`,
        fs:  `cpe:2.3:a:cognos:financial_statement_reporting_database:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.32`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.33`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.34`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.35`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.3:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.36`,
        fs:  `cpe:2.3:a:clamav:clamav:0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.37`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.38`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.40`,
        fs:  `cpe:2.3:a:oracle:mysql_connector_net:6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.41`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.42`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.43`,
        fs:  `cpe:2.3:a:google:chrome:12.0.743.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.44`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.51:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.50`,
        fs:  `cpe:2.3:a:atutor:acontent:1.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.51`,
        fs:  `cpe:2.3:a:adobe:dreamweaver:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:7.x-dev`,
        fs:  `cpe:2.3:o:freebsd:freebsd:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0`,
        fs:  `cpe:2.3:h:ibm:e40:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha10`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha11`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:1.3.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha12`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha13`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha14`,
        fs:  `cpe:2.3:a:symantec:backupexec_system_recovery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha15`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha2`,
        fs:  `cpe:2.3:a:apple:safari:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha4`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(2\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha5`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha6`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha7`,
        fs:  `cpe:2.3:a:isc:bind:9.8.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:alpha9`,
        fs:  `cpe:2.3:h:foundrynet:fes_2402_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta1`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta10`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta11`,
        fs:  `cpe:2.3:a:upasanhar:harivijay:4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta12`,
        fs:  `cpe:2.3:a:oracle:mysql_installer:1.0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta13`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.13:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta14`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta15`,
        fs:  `cpe:2.3:a:atutor:atutor:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta16`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta4`,
        fs:  `cpe:2.3:a:saintcorporation:saintscanner:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta6`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.0:e0101l02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta7`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:beta9`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:rc1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:rc2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:rc3`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(3\)i1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.0:rc4`,
        fs:  `cpe:2.3:a:google:v8:3.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.4`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.0.6`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.0`,
        fs:  `cpe:2.3:a:samba:samba:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.0:beta1`,
        fs:  `cpe:2.3:o:huawei:s6300ei_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.0:beta2`,
        fs:  `cpe:2.3:a:ibm:optim_workload_replay:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.0:rc1`,
        fs:  `cpe:2.3:a:gnu:coreutils:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.1`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.1.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.2`,
        fs:  `cpe:2.3:a:carrierenterprise:carrier_enterprise_hvac_assist:4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.3`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.4`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp11:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.5`,
        fs:  `cpe:2.3:o:vmware:esxi:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.6`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:3.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.7`,
        fs:  `cpe:2.3:a:carbonblack:carbon_black:4.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.8`,
        fs:  `cpe:2.3:a:morbus_iff:activism:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.9`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.1.10`,
        fs:  `cpe:2.3:a:intel:mpfwiz:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.0`,
        fs:  `cpe:2.3:a:hp:care_pack_core:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.0:beta1`,
        fs:  `cpe:2.3:h:hp:h3c_routing_switch:s9508e-v:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.0:beta2`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.0:beta3`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.0:rc1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.0:rc2`,
        fs:  `cpe:2.3:h:hp:0235a38v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.4`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7941g:8.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.5`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.6`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.2.7`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.3.0`,
        fs:  `cpe:2.3:a:dx_library_project:dx_library:3.16b:*:*:*:*:gnu_c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.3.0:alpha1`,
        fs:  `cpe:2.3:a:wolfcms:wolf_cms:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.3.0:beta1`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.3.0:rc1`,
        fs:  `cpe:2.3:o:dahuasecurity:dvr_firmware:2.608.gv00.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:drupal:8.3.0:rc2`,
        fs:  `cpe:2.3:a:ibm:initiate_master_data_service:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal:realname:6.x-1.2`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention:7.0.700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal-id:counter_module:-`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupal-id:counter_module:6.0`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalauth_project:drupalauth:1.2.1:-:~-~-~simplesamlphp~~`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalauth_project:drupalauth:1.2.2:-:~-~-~simplesamlphp~~`,
        fs:  `cpe:2.3:a:emc:alphastor:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-1.0`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-1.0:alpha4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p368:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-1.0:beta2`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.1.64.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-1.1`,
        fs:  `cpe:2.3:a:foxitsoftware:phantompdf:7.1.3.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-2.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-2.1`,
        fs:  `cpe:2.3:a:dattch:dattch_-_the_lesbian_app:0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:drupalisme:tinybox:7.x-2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:drweb:web_security_space:6.0.0.03100:-:professional`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ds3:authentication_server:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dssearchagent_project:dssearchagent:1.0:beta10:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.4.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:dteenergy:dte_energy:3.0.3::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:sn_5428_storage_router:2-3.3.2-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dtsearch:dtsearch:7.66.7936`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dublabs:yulman_stadium:1.4.25::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.0.595:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.7.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.7.1`,
        fs:  `cpe:2.3:a:google:chrome:52.0.2743.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.7.2`,
        fs:  `cpe:2.3:a:novell:suse_lifecycle_management_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.7.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.7.4`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.7.5`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.0:rc0`,
        fs:  `cpe:2.3:a:pearson:esis_enterprise_student_information_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.0:rc1`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.2`,
        fs:  `cpe:2.3:h:cisco:catalyst_2950:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.4`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.5`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.6`,
        fs:  `cpe:2.3:a:hp:color_laserjet_4700_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.7`,
        fs:  `cpe:2.3:a:ca:etrust_siteminder_web_access_manager_administrative_ui:12.0.100.209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.8`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.8:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duckcorp:bip:0.8.9`,
        fs:  `cpe:2.3:a:python:python:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dukapress_project:dukapress:2.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dulwich_project:dulwich:0.9.8`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop_supplementary:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dundas:dundas_chart_asp.net:3.5.0.1590::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.00:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dupehunter:dupehunter:9.0.0.3911`,
        fs:  `cpe:2.3:a:splunk:splunk:108.2.8775:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duplicator_project:duplicator:0.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duplicator_project:duplicator:0.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:duplicator_project:duplicator:0.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0529:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dustincowell:free_simple_cms:1.0`,
        fs:  `cpe:2.3:a:hp:serviceguard:a.11.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dvdshrink:dvdshrink:3.2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.591:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dvs_custom_notification_project:dvs_custom_notification:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dx_library_project:dx_library:3.15e`,
        fs:  `cpe:2.3:a:offertaviaggi:firenze_map:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:dx_library_project:dx_library:3.16b::~~~borland_c%2b%2b~~`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dx_library_project:dx_library:3.16b::~~~gnu_c%2b%2b~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dx_library_project:dx_library:3.16b::~~~visual_c%2b%2b~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dymo:dymo_file:2.0.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dymo:dymo_label:8.2.0.820`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dymo:dymo_label:8.2.2.996`,
        fs:  `cpe:2.3:a:winscp:winscp:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dymo:dymo_label:8.3.0.1242`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dymo:rhino_connect_software:1.3.0.242`,
        fs:  `cpe:2.3:a:deluge-torrent:deluge:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynamixsolutions:arabic_prawn:0.0.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:3.4.0`,
        fs:  `cpe:2.3:a:ibm:spss_analytical_decision_management:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:3.4.4`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.0.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:3.7.0`,
        fs:  `cpe:2.3:a:mcafee:securitycenter_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:3.7.1`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:3.7.2`,
        fs:  `cpe:2.3:a:network-weathermap:.network_weathermap:0.97:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:3.7.3`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:4.0.0`,
        fs:  `cpe:2.3:a:ibm:jdk:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:4.1.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:ga:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:4.1.1`,
        fs:  `cpe:2.3:o:cisco:unified_sip_phone_3900_firmware:9.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:4.2.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.425:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dynpg:dynpg_cms:4.2.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:15.0.0.239:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:dzcp:dev%21l%27z_clanportal:-`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.5.4`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.5.5`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.5.6`,
        fs:  `cpe:2.3:a:barebones:yojimbo:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.5.7`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.5.8`,
        fs:  `cpe:2.3:a:finalbeta:mywebsearch:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.5.9`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.35:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.0`,
        fs:  `cpe:2.3:a:citrix:metaframe_access_suite_licensing:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.3b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.2`,
        fs:  `cpe:2.3:a:faststone_soft:faststone_image_viewer:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.3`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.4`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.5`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.801:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.6`,
        fs:  `cpe:2.3:a:oracle:jai:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.7`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.7.1`,
        fs:  `cpe:2.3:a:apple:xcode:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.8`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.9`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:pre.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.9.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.10`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.11`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.11.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.11.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.11.3`,
        fs:  `cpe:2.3:a:mono:mono:1.1.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.11.4`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.12`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.13`,
        fs:  `cpe:2.3:a:cabextract:cabextract:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.13.1`,
        fs:  `cpe:2.3:a:4t-niagara:tray_minimizer_pro:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.13.6`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-catchup:basercms:1.6.14`,
        fs:  `cpe:2.3:a:postgresql:postgresql_jdbc_driver:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-isg:crystal_installer:1.0.0`,
        fs:  `cpe:2.3:h:huawei:nip1000:v100r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-isg:visual_asset_manager:5.7.5`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-kiosk:e-kiosk:1.74::~~~android~~`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-mail_extractor:e-mail_extractor:2.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.64.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-press:one_office_author:-`,
        fs:  `cpe:2.3:a:oracle:jdk:8.0:update_121:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-press:one_office_e-notetaker:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-press:one_office_e-zip:-`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_direct_user_interface:1.4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-search_project:e-search:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-xoopport:samsara:3.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e-xoopport:samsara:3.1`,
        fs:  `cpe:2.3:a:cisco:connected_streaming_analytics:1.1.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:-`,
        fs:  `cpe:2.3:a:smarttech:smart_notebook:10.7.144.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.438:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.0`,
        fs:  `cpe:2.3:a:saltstack:salt:2014.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.1`,
        fs:  `cpe:2.3:a:extplorer:com_extplorer:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.2`,
        fs:  `cpe:2.3:o:netbsd:netbsd:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.3`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.4`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.5`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a7\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.6`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.7`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:2.2\(1.43\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.8`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.9`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.10`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.11`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-00-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.12`,
        fs:  `cpe:2.3:o:iij:seil\%2fturbo_firmware:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.13`,
        fs:  `cpe:2.3:a:cyrus:imap:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.14`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.03.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.15`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.02:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.16`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:p10-0038:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.17`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.19`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.20`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.21`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.22`,
        fs:  `cpe:2.3:a:atlassian:jira:2.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.24`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:0.7.26`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2009:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:1.0.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:1.0.2`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:1.0.3`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2108h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:1.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:12.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:2.0:alpha1`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0517:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:2.0:alpha2`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e107:e107:2.0.0`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.04:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e2fsprogs_project:e2fsprogs:1.42.11`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e2fsprogs_project:e2fsprogs:1.43.1`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.9.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:e2fsprogs_project:e2fsprogs:1.43.2`,
        fs:  `cpe:2.3:h:cisco:80-7111-01_for_the_unity-svrx255-1a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e2fsprogs_project:e2fsprogs:1.43.3`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e2fsprogs_project:e2fsprogs:1.43.4`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e2fsprogs_project:e2fsprogs:1.43.5`,
        fs:  `cpe:2.3:a:keepass:keepass:0.90:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:e2fsprogs_project:e2fsprogs:1.43.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:19.0.0.245:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:e2fsprogs_project:e2fsprogs:1.43.7`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.7.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:eagletron:dvdriver:1.0.3.26`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eagletron:trackercam:5.3.0.57`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easaa:easaa_baoneng:1::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easing_slider:easing_slider:2.2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:0235a0bx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_banners_plugin_project:easy_banners:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:devada_project:devada:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:virtual_pc:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:winscp:winscp:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.61:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_social_project:easy_social:7.x-2.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:python:python:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_tips_for_glowing_skin_project:easy_tips_for_glowing_skin:1::~~~android~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:easy_video_downloader_project:easy_video_downloader:4.4.1::~~~android~~`,
        fs:  `cpe:2.3:h:huawei:e200e-c:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easymoblog:easymoblog:0.5.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easytimestudio:easy_file_manager:1.1:-:~-~-~iphone_os~~`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-2.1:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.3.2`,
        fs:  `cpe:2.3:a:carel:plantvisor_enhanced:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.3.3`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.1`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.2`,
        fs:  `cpe:2.3:a:infoware:mapsuite:1.1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.3:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.5`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:3.6.7.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.6`,
        fs:  `cpe:2.3:a:hp:copy:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.18`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:easyxdm:easyxdm:2.4.19`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:elcsoft:2.4.01`,
        fs:  `cpe:2.3:a:redmine:redmine:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:4.0`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:7.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.1`,
        fs:  `cpe:2.3:a:apache:httpclient:4.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.3`,
        fs:  `cpe:2.3:a:isc:inn:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.4`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.5`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.6`,
        fs:  `cpe:2.3:a:epiqo:email:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.7`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.3.0:cp04:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.8`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.9`,
        fs:  `cpe:2.3:a:oracle:jd_edwards_products:24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eaton:proview:5.0.10`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ebay-kleinanzeigen:ebay_kleinanzeigen_for_germany:5.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.3.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ebiblio:ebiblio_andalucia:1.6.5::~~~android~~`,
        fs:  `cpe:2.3:a:apache:cxf:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:3.5.3900.5`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:3.5.3900.10`,
        fs:  `cpe:2.3:a:bitrock:bitrock_installbuilder_enterprise:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:3.6.4000.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:3.60.4061`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:3.71`,
        fs:  `cpe:2.3:a:microsoft:ie:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:3.71.4200`,
        fs:  `cpe:2.3:a:microsoft:wins:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:3.72`,
        fs:  `cpe:2.3:a:tecolote:aceit:7.1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.00`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.1`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.1.4340`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:11.0:sp3:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.1.4360`,
        fs:  `cpe:2.3:o:microsoft:windows_10:1703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.1.4369`,
        fs:  `cpe:2.3:a:roxio:easy_cd_\&amp;_dvd_creator:6.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.1.4380`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.1.4390`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.1.4393`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sva:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.1.4450`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecava:integraxor:4.2.4502`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1272.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:echo_project:echo:-::~~~mediawiki~~`,
        fs:  `cpe:2.3:a:sympa:sympa:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:echonewshk:echo_news:beta::~~~android~~`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:echoping_project:echoping:6.0.2`,
        fs:  `cpe:2.3:a:tobias_bathge:wp-table_reloaded:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecitic:china_citic_bank_credit_card:3.3.6::~~~android~~`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.899:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:1.0`,
        fs:  `cpe:2.3:h:ibm:power_5:9406-550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:2.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:2.0.1`,
        fs:  `cpe:2.3:a:cdotech:pod_distribution:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:2.0.2`,
        fs:  `cpe:2.3:a:microsoft:visual_j\&#43;\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:2.1`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.2.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:2.1.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:2.1.2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:2.1.3`,
        fs:  `cpe:2.3:a:comodo:geekbuddy:4.18.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.0`,
        fs:  `cpe:2.3:a:pygments:pygments:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.0.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.0.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update4:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.1.1`,
        fs:  `cpe:2.3:a:titan_framework_project:titan_framework:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.1.2`,
        fs:  `cpe:2.3:a:basketball_news_\&amp;_videos_project:basketball_news_\&amp;_videos:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.2`,
        fs:  `cpe:2.3:a:novell:netmail:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.2.1`,
        fs:  `cpe:2.3:a:roxio:disc_gallery:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.2.2`,
        fs:  `cpe:2.3:a:apache:storm:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.3`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.0.1570:unknown:online_windows_server_2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.3.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.326:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.3.1.1`,
        fs:  `cpe:2.3:a:foliovision:foliopress_wysiwyg:2.6.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.3.2`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.4`,
        fs:  `cpe:2.3:a:redhat:network_proxy:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.4.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.4.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.5`,
        fs:  `cpe:2.3:a:sap:netweaver:7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.5.1`,
        fs:  `cpe:2.3:h:cisco:unified_wireless_ip_phone_7925g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.5.2`,
        fs:  `cpe:2.3:a:redhat:tmpwatch:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:m1`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:m2`,
        fs:  `cpe:2.3:a:digia:qt:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:m3`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:m4`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.0\(3\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:m5`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:m6`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:m7`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100926:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:rc1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:rc2`,
        fs:  `cpe:2.3:a:libimobiledevice:libimobiledevice:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:rc3`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_ha_for_windows:5.1.200:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6:rc4`,
        fs:  `cpe:2.3:a:apple:itunes:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6.1`,
        fs:  `cpe:2.3:a:caucho:resin:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.6.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.392:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.7`,
        fs:  `cpe:2.3:a:kana:iq:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.7.1`,
        fs:  `cpe:2.3:h:siemens:scalance_x-300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.7.2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.8`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.8.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:3.8.2`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.0`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.1.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1676.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.1.2`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2008.717.2343.40629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.2.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.2.2`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.3`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.3.1`,
        fs:  `cpe:2.3:a:microsoft:outlook:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:eclipse_ide:4.3.2`,
        fs:  `cpe:2.3:a:oracle:secure_enterprise_search:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.0:m2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.0:rc0`,
        fs:  `cpe:2.3:a:yuichiro_okuyama:tetra_filer_free:1.5.1:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.0:rc1`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.2`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.3`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.4`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.4:rc0`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.4:rc1`,
        fs:  `cpe:2.3:a:sumaria:afway_cbt:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.5`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.6`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.7`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.7:rc0`,
        fs:  `cpe:2.3:a:logitech:desktop_messenger:2.52.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.7:rc1`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.8`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eclipse:jetty:9.3.8:rc0`,
        fs:  `cpe:2.3:a:wellintech:kingalarm\&amp;event:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecmwf:magics%2b%2b:2.10.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecolehoangnam:gnam_2013:1::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:kernel:2.4.20-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercemajor_project:ecommercemajor:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.0.114`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.0.115`,
        fs:  `cpe:2.3:a:adobe:presenter:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.0.116`,
        fs:  `cpe:2.3:h:oracle:sparc_t3-1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.0.1475.18262`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.0.1495.34683`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.0.1495.34684`,
        fs:  `cpe:2.3:h:hp:deskjet_5850:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1495.34686`,
        fs:  `cpe:2.3:a:maroyaka_simple_board_project:maroyaka_simple_board:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1496.x`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1497.x`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1498.x`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1499.x`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1500.x`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.1`,
        fs:  `cpe:2.3:a:gnu:bash:2.02.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.4`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.5`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.6`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.7`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.8`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.9`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.10`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.11`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.1.1501.x`,
        fs:  `cpe:2.3:a:ibm:sterling_file_gateway:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.0.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.0.1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.0.2`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.0.3`,
        fs:  `cpe:2.3:a:siemens:comos:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.0.4`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.3.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.1.0`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.0`,
        fs:  `cpe:2.3:a:hp:hp-ux_ipfilter:a.11.31.18.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1\(.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.2`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.0.0:*:*:*:*:wotlab_burning_board:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.3`,
        fs:  `cpe:2.3:a:apple:iphoto:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.4`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i2\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.5`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.6`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.7`,
        fs:  `cpe:2.3:a:vmware:vcenter_update_manager:4.1.0.8977:update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.2.8`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecommercesoft:xse_shopping_cart:1.5.3.0`,
        fs:  `cpe:2.3:a:intel:mcore:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecos:embperl:1.3.4`,
        fs:  `cpe:2.3:h:3com:3c17708-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecos:embperl:1.3.6`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ecos:embperl:2.0`,
        fs:  `cpe:2.3:a:telly:telly-watch_the_good_stuff:2.5.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ecryptfs:ecryptfs-utils:-`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:edimax:6114wg:-`,
        fs:  `cpe:2.3:a:apple:safari:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:edimax:6114wg_router_firmware:1.83`,
        fs:  `cpe:2.3:a:option:driver_installer:2.3.0.797:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:edimax:6114wg_router_firmware:2.08`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:edimax:br-6104k:-`,
        fs:  `cpe:2.3:a:barebones:textwrangler:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:edimax:br-6104k_router_firmware:3.21`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1657.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:edimax:print_server_utilities:4.2.9.0`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eduserv:openathens_service_provider:2.0:-:~~~java~~`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:edx:open_edx:2015-01-27`,
        fs:  `cpe:2.3:a:iss:realsecure_event_collector:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:enterprise_update_server:2.2.0.426`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.10.12.1700`,
        fs:  `cpe:2.3:a:buffalotech:as-100_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.11.6.1879`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.11.10.1972`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.11.12.2092`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.11.13.2120`,
        fs:  `cpe:2.3:a:rosettastone:rosettastone:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.11.15.2157`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(4\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.11.16.2163`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.12.1.2272`,
        fs:  `cpe:2.3:a:google:toolbar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.13.0.2389`,
        fs:  `cpe:2.3:a:rsa:bsafe_ssl-j_sdk:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.13.2.2394`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eeye:retina:5.14.1.2510`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efence_project:efence:1.3.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.19.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efendimizin_sunnetleri_project:efendimizin_sunnetleri:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)jx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.1.2`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.1.3`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.1.4`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.0:beta1`,
        fs:  `cpe:2.3:a:nuance:pdf_printer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.0:beta2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.0:beta3`,
        fs:  `cpe:2.3:a:ibm:packaging_utility:1.8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.0:beta4`,
        fs:  `cpe:2.3:o:cisco:ciscoworks_windows_wug:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.2`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:rc.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.5.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.6`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.6.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3020_concentrator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.6.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p486_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.6.10`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.6.11`,
        fs:  `cpe:2.3:a:novell:imonitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.6.14`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efrontlearning:efront:3.6.14.4`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.10:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efssoft:easy_file_sharing_web_server:6.8`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.351:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efstechnology:autoform_pdm_archive:6.9`,
        fs:  `cpe:2.3:a:symantec:i3_listener_agent:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efstechnology:autoform_pdm_archive:6.920`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.11:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:efstechnology:autoform_pdm_archive:7.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efstechnology:autoform_pdm_archive:7.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:efunfun:love_dance:1.2.0626::~~~android~~`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:egroupware:egroupware:1.8.001.20110421:-:community`,
        fs:  `cpe:2.3:a:google:chrome:5.0.326.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:egroupware:egroupware:1.8.001.20110805:-:community`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:egroupware:egroupware_enterprise_line:11.1.20110711-1`,
        fs:  `cpe:2.3:h:arbiter:1094b_gps_substation_clock:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:egroupware:egroupware_enterprise_line:11.1.20110804-1`,
        fs:  `cpe:2.3:a:cisco:prime_network_services_controller:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eigenwinkelapp:kiddie_kinderschoenen:1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:activemq:5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ein_lookup_project:ein_lookup:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ekahau:activator:3`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:ekahau:b4_staff_badge_tag:5.7`,
        fs:  `cpe:2.3:o:sun:sunos:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ekahau:b4_staff_badge_tag_firmware:1.4.52`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ekahau:real-time_location_system_controller:6.0.5-final`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ekiga:ekiga:4.0.0`,
        fs:  `cpe:2.3:a:hp:ocr_software:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ekiga:ekiga:4.0.1`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ektron:ektron_content_management_system:8.5.0`,
        fs:  `cpe:2.3:a:gnu:glibc:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ektron:ektron_content_management_system:8.7.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ektron:ektron_content_management_system:8.7.0:sp1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ektron:ektron_content_management_system:8.7.0.055`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ektron:ektron_content_management_system:8.9.0`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ektron:ektron_content_management_system:9.1:sp1`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elabftw:elabftw:1.7.8`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.1.1`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.2.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.3.7`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.4.0`,
        fs:  `cpe:2.3:a:projectsend:projectsend:514:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.4.0:beta1`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.4.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.4.2`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.4.4`,
        fs:  `cpe:2.3:o:mandriva:linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.5.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.5.1`,
        fs:  `cpe:2.3:a:whoisit:who-is-it\?_lite_name_caller_time_limited_free:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:elasticsearch:1.6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:3.0.0`,
        fs:  `cpe:2.3:a:corosync:corosync:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:3.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:3.1.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.467.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:3.1.1`,
        fs:  `cpe:2.3:a:hp:wbem:a.02.00.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:3.1.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.03:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:3.1.3`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.0.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.363:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.52.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.2`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.3`,
        fs:  `cpe:2.3:a:trillian:trillian:0.6351:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.4`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.5`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.6`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2009:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.7`,
        fs:  `cpe:2.3:a:oracle:e-business_suite_application_management_pack:121020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.8`,
        fs:  `cpe:2.3:o:cisco:asa_5500_csc-ssm_firmware:6.6.1125.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.9`,
        fs:  `cpe:2.3:o:vmware:esx:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.1.11`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.2.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.406:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.2.1`,
        fs:  `cpe:2.3:o:hp:tru64:4.0f_pk8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.2.2`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.6.3`,
        fs:  `cpe:2.3:a:macromedia:dreamweaver:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.6.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.6.5`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:4.6.6`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.3.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:5.0.0`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:6.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:5.6.1`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:5.6.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:5.6.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.394:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:5.6.4`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.0.0`,
        fs:  `cpe:2.3:a:tibco:silver_fabric_enabler_for_spotfire_webplayer:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.0.0:alpha1`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.0.0:alpha2`,
        fs:  `cpe:2.3:a:ibm:db2_recovery_expert:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.0.0:beta1`,
        fs:  `cpe:2.3:a:ca:etrust_secure_content_manager:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.0.0:beta2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s_3.4.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.0.0:rc1`,
        fs:  `cpe:2.3:o:hp:z238_firmware:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.0.0:rc2`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4.7030:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.0.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:kibana:6.1.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp2:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.0.14`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.0.15`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.0.16`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.0.17`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.0.1`,
        fs:  `cpe:2.3:a:naver:nhn_japan_naver_line:3.3.4:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.1`,
        fs:  `cpe:2.3:a:sun:starsuite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.2`,
        fs:  `cpe:2.3:a:citrix:xenapp_plugin_for_hosted_apps:11.0.0.5357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.3`,
        fs:  `cpe:2.3:a:zeptolab:cut_the_rope\:_time_travel:1.3.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.4`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.5`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.6`,
        fs:  `cpe:2.3:o:dell:sonicwall_uma_em5000_firmware:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.7`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.8`,
        fs:  `cpe:2.3:h:cisco:cs-mars:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.9`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(23\)sw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.11`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.12`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.1.13`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.2.1`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.2.2`,
        fs:  `cpe:2.3:a:logitech:lws_webcam_software:13.0.1774.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.3.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.31.373:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.3.1`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.3.2`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.3.3`,
        fs:  `cpe:2.3:a:symantec:ghost_solutions_suite:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.4.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.4.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elasticsearch:logstash:1.4.2`,
        fs:  `cpe:2.3:h:grandstream:gxv3500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eleanor-cms:eleanor_cms:-`,
        fs:  `cpe:2.3:a:nyc:liver_health_-_hepatitis_c:2.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:elecsyscorp:director_dnp3_outstation_kernel:2.6.32.11:ael1`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:elecsyscorp:director_industrial_communication_gateway:-`,
        fs:  `cpe:2.3:a:perl:perl:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:electric_cloud:electriccommander:4.2.5`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:electric_cloud:electriccommander:5.0.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:electric_cloud:electriccommander:5.0.1`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:electric_cloud:electriccommander:5.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elefantcms:elefantcms:1.2.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elefantcms:elefantcms:1.2.1`,
        fs:  `cpe:2.3:h:hp:advanced_server_9000:b.04.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elefantcms:elefantcms:1.2.2`,
        fs:  `cpe:2.3:a:adobe:indesign:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elegant_themes:divi:-::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elemata:elemata_cms:2.4`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:5.0\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elemata:elemata_cms:3.0:rc`,
        fs:  `cpe:2.3:a:citrix:access_gateway_plug-in:9.2:*:*:*:enterprise:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:elephantdrive:elephantdrive:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.4sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elephantdrive:elephantdrive:5.1.0`,
        fs:  `cpe:2.3:h:intel:core_2_duo_e4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.123`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.124`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.125`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.126`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_human_capital_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.127`,
        fs:  `cpe:2.3:a:mike_peachey:authen\:\:externalauth:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.128`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p286:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.129`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.130`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.131`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.132`,
        fs:  `cpe:2.3:a:intergraph:rcc_skills_codes:1.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.133`,
        fs:  `cpe:2.3:o:eucalyptus:eustore:emi_1347115203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.134`,
        fs:  `cpe:2.3:a:wordbox:mahabharata_audiocast:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.135`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.137`,
        fs:  `cpe:2.3:a:gnu:screen:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.138`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.10.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.139`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.140`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2.4:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.141`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.142`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.143`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.144`,
        fs:  `cpe:2.3:h:cisco:vpn_3020_concentrator:4.1.7.l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.145`,
        fs:  `cpe:2.3:a:school_administration_project:school_administration:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.146`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.147`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p455:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.148`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.149`,
        fs:  `cpe:2.3:a:redhat:cloudforms_cloud_engine:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.150`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.151`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.152`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:3.00.0630:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.153`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.154`,
        fs:  `cpe:2.3:o:iij:seil\%2fx86_firmware:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.155`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.156`,
        fs:  `cpe:2.3:a:atlassian:jira:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.157`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.158`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.161`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elfutils_project:elfutils:0.167`,
        fs:  `cpe:2.3:a:hp:trayapp:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.0`,
        fs:  `cpe:2.3:a:debian:logol:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.1`,
        fs:  `cpe:2.3:a:e2fsprogs_project:e2fsprogs:1.43.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.2`,
        fs:  `cpe:2.3:a:apache:subversion:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.3`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.4`,
        fs:  `cpe:2.3:a:hp:creativeprojects_onlineprojectsconfig:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.5`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger_service_for_exchange:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2010.1125.2142.38865:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.7`,
        fs:  `cpe:2.3:a:gnu:fileutils:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.8`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.9`,
        fs:  `cpe:2.3:o:dell:bios:a13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.10`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.11`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:626:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.12`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.13`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.14`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator:3.3.1066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.15`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.16`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.17`,
        fs:  `cpe:2.3:a:pythonware:python_imaging_library:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.7.18`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.0.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.1`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.4`,
        fs:  `cpe:2.3:a:organizer_project:organizer:1.0b:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.5`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.1.192.xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.6`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.7`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.8`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.9`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.10`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.11`,
        fs:  `cpe:2.3:a:flex_project:flex:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2.009.0113.2221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.13`,
        fs:  `cpe:2.3:a:salome-platform:salome:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.14`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.15`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.16`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.17`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elgg:elgg:1.8.18`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elif_keir:knftpd:1.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elinks:elinks:0.12:pre1`,
        fs:  `cpe:2.3:a:justsystems:atok_x3:-:-:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elinks:elinks:0.12:pre2`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elinks:elinks:0.12:pre3`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elinks:elinks:0.12:pre4`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:elinks:elinks:0.12:pre5`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elipse:e3:3.2`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elipse:e3:4.5`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elipse:e3:4.6`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elipse:power:4.6`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.5.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elipse:scada:2.29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.0.0`,
        fs:  `cpe:2.3:a:citrix:xenapp_commands_ctp3:5.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.0.1`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.0.2`,
        fs:  `cpe:2.3:a:pimcore:pimcore:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.576:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.4`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.8p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.5`,
        fs:  `cpe:2.3:a:quest:web_parts_for_sharepoint:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.6`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.localization:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.7`,
        fs:  `cpe:2.3:a:jenkins:git:2.6.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.9`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xb14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.11`,
        fs:  `cpe:2.3:a:piwik:piwik:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.12`,
        fs:  `cpe:2.3:a:realnetworks:rhapsody:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.13`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.14`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_enterprise_client:2.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.15`,
        fs:  `cpe:2.3:o:sun:solaris:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.16`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.17`,
        fs:  `cpe:2.3:a:intel:mcore:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.18`,
        fs:  `cpe:2.3:a:isc:bind:9.11.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.20`,
        fs:  `cpe:2.3:a:facsys:facsys:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.21`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elite-board:elite_bulletin_board:2.1.22`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eliteladders:elite_gaming_ladders:3.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p177:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eliteladders:elite_gaming_ladders:3.2`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eliteladders:elite_gaming_ladders:3.5`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eliteweaver:xclick_cart:1.0.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eliteweaver:xclick_cart:1.0.2`,
        fs:  `cpe:2.3:o:maygion:ip_camera_firmware:09.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elokence:akinator_the_genie_free:2.46::~~~android~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elsio:mapa_da_mina:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:altiris:cmdb:6.5.1126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elsop:linkscan:5.3`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.3.1723:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elsop:linkscan:11.5`,
        fs:  `cpe:2.3:h:cisco:rv016_multi-wan_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elsop:linkscan:11.6`,
        fs:  `cpe:2.3:h:hp:a2w76a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elsop:linkscan:12.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elxis:elxis_cms:2006.1`,
        fs:  `cpe:2.3:a:aol:aim:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elxis:elxis_cms:2006.2`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elxis:elxis_cms:2006.3`,
        fs:  `cpe:2.3:a:apache:struts:2.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elxis:elxis_cms:2006.4`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elxis:elxis_cms:2008.1:revision_2204`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elxis:elxis_cms:2009.2`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:elxis:elxis_cms:2009.3`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:15.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress%3a%3alist_project:email%3a%3aaddress%3a%3alist:0.01`,
        fs:  `cpe:2.3:a:avast:free_antivirus:11.1.2241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress%3a%3alist_project:email%3a%3aaddress%3a%3alist:0.02`,
        fs:  `cpe:2.3:a:logitech:lws_help_main:13.0.1783.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.1::~~~perl~~`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.2::~~~perl~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.3::~~~perl~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.5::~~~perl~~`,
        fs:  `cpe:2.3:a:qemu:qemu:0.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.6::~~~perl~~`,
        fs:  `cpe:2.3:a:rsa:securid_web_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.7::~~~perl~~`,
        fs:  `cpe:2.3:a:pixman:pixman:0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.80::~~~perl~~`,
        fs:  `cpe:2.3:a:agilebits:knox:2.0.4:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.85::~~~perl~~`,
        fs:  `cpe:2.3:a:condusiv:diskeeper:10.0.593:*:*:*:server_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.86::~~~perl~~`,
        fs:  `cpe:2.3:a:isc:bind:9.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.870::~~~perl~~`,
        fs:  `cpe:2.3:a:otrs:faq:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.871::~~~perl~~`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.880::~~~perl~~`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.881::~~~perl~~`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.882::~~~perl~~`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.883::~~~perl~~`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.884::~~~perl~~`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.885::~~~perl~~`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.886::~~~perl~~`,
        fs:  `cpe:2.3:a:vips:vips:7.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.887::~~~perl~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.17.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.888::~~~perl~~`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.889::~~~perl~~`,
        fs:  `cpe:2.3:a:google:chrome:47.0.2526.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.890::~~~perl~~`,
        fs:  `cpe:2.3:a:oracle:jsp:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.891::~~~perl~~`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.892::~~~perl~~`,
        fs:  `cpe:2.3:a:t1lib:t1lib:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.893::~~~perl~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.894::~~~perl~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.895::~~~perl~~`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:3.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.896::~~~perl~~`,
        fs:  `cpe:2.3:o:cisco:spa_500_series_ip_phone_firmware:7.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.897::~~~perl~~`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.898::~~~perl~~`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.899::~~~perl~~`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.900::~~~perl~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.901::~~~perl~~`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:8.0.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.902::~~~perl~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.8:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.903::~~~perl~~`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.904::~~~perl~~`,
        fs:  `cpe:2.3:a:tibco:activematrix_management_agent:1.0.0:*:*:*:*:websphere:*:*`,
    },
     
    {
        uri: `cpe:/a:email%3a%3aaddress_module_project:email%3a%3aaddress:1.905::~~~perl~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emailarchitect:emailarchitect_email_server:10.0`,
        fs:  `cpe:2.3:h:xerox:workcentre_5135:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emailarchitect:emailarchitect_email_server:10.0.0.3`,
        fs:  `cpe:2.3:a:david_king:vino:2.7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emailarchitect:emailarchitect_email_server:10.1`,
        fs:  `cpe:2.3:a:mathew_winstone:mobile_tools:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embarcadero:dbartisan:8.5.4`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:embarcadero:er%2fstudio_data_architect:-`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embarcadero:jbuilder_2008_r2:1.3.0.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:appweb:4.6.5`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:appweb:5.0.0`,
        fs:  `cpe:2.3:a:siemens:wincc:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:appweb:5.1.0`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:appweb:5.2.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:goahead:3.0.0`,
        fs:  `cpe:2.3:a:eeye:retina:5.11.16.2163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:goahead:3.3.1`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:goahead:3.3.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:goahead:3.3.3`,
        fs:  `cpe:2.3:a:tryton:tryton:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:goahead:3.3.4`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:goahead:3.3.5`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:goahead:3.3.6`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:embedthis:goahead:3.4.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.0-15:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ember-entertainment:towers_n%27_trolls:1.6.4::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.2.0`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:19990519:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.2.1`,
        fs:  `cpe:2.3:a:ca:unicenter_tng:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.3.0`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:6.0.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.3.1`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.3.2`,
        fs:  `cpe:2.3:a:hp:omniback_ii:a.03.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.4.0:-`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.4.0:beta`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.4.0:beta6`,
        fs:  `cpe:2.3:h:ibm:system_x_idataplex_direct_water_cooled_dx360_m4_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.5.0:beta`,
        fs:  `cpe:2.3:a:sharp:eva_animator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.8`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.8.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.9`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.9.1`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.10`,
        fs:  `cpe:2.3:h:intel:qm77_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.10.1`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.11`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.11.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.11.2`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.11.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.12`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.12.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta54:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.11-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.1`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.2`,
        fs:  `cpe:2.3:a:lepton-cms:lepton:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.4`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.5`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.6`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.16.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.7`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.8`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.10`,
        fs:  `cpe:2.3:a:roxio:cineplayer:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:1.13.11`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:2.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:2.0.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:2.0.2`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2012:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:2.1`,
        fs:  `cpe:2.3:a:impi:impi_mobile_security:2.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:2.1.1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emberjs:ember.js:2.2`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.1.0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:alphastor:4.0`,
        fs:  `cpe:2.3:h:tp-link:tl-wrd841n_\(9.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:appsync:2.0`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:atmos:2.1.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3jea:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:atmos:2.1.4`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:autostart:5.5.0`,
        fs:  `cpe:2.3:a:quagga:quagga:0.96.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:4.0`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_server:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:4.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.466.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:5.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1304.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:5.0:sp1`,
        fs:  `cpe:2.3:a:avscripts:av_arcade:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:5.0:sp2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:5.0.0-407`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:5.0.4-26`,
        fs:  `cpe:2.3:a:solarwinds:engineers_edition:solarwinds_engineers_edition:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:6.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:6.0.1`,
        fs:  `cpe:2.3:a:stackideas:komento:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:6.0.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:6.0.3`,
        fs:  `cpe:2.3:a:ilch:cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:6.1:-:~~~vmware~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:6.1.100-333:-:~~~vmware~~`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar:6.1.100-402:-:~~~vmware~~`,
        fs:  `cpe:2.3:h:lexmark:c546:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar_plugin:4.0:-`,
        fs:  `cpe:2.3:a:opsview:opsview:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar_plugin:5.0:-`,
        fs:  `cpe:2.3:a:emc:networker:7.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar_plugin:6.0:-`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:1.0:ur1_po1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:avamar_plugin:6.1:-`,
        fs:  `cpe:2.3:a:otrs:faq:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:captiva_capture:7.0`,
        fs:  `cpe:2.3:a:oracle:mobile_application_server:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:captiva_capture:7.1`,
        fs:  `cpe:2.3:a:plone:plone:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:captiva_quickscan_pro:4.6:sp1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:cava:3.6.2`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:celerra_cifs_management:4.1.0.6`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:celerra_network_attached_storage:-`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:centera:3.1:sp2`,
        fs:  `cpe:2.3:a:blueteck:witze_addon:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:centera:4.2.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:centerstage:1.2:sp1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:centerstage:1.2:sp2`,
        fs:  `cpe:2.3:a:urs_wolfer:kwebkitpart:0.9.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:clariion_procedure_generator:4.4.2`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:cloud_tiering_appliance:-`,
        fs:  `cpe:2.3:a:apple:safari:3.1.1b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:cloud_tiering_appliance_software:9.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:cloud_tiering_appliance_software:10.0:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:cloud_tiering_appliance_software:10.0:sp1`,
        fs:  `cpe:2.3:a:openbsd:ftpd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:connectrix_manager:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:connectrix_manager:9.5.0.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:connectrix_manager:11.2.1:-:~-~converged_network_edition~~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:connectrix_manager:12.0.1:-:~-~converged_network_edition~~~`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:connectrix_manager:12.0.3:-:~-~converged_network_edition~~~`,
        fs:  `cpe:2.3:a:hp:smart_array_multipath_software:2.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:control_center:5.2:sp5`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.0:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:control_center:6.0`,
        fs:  `cpe:2.3:a:preplogic:exam_70-680:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:controlcenter:-`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:controlcenter:5.2.0`,
        fs:  `cpe:2.3:a:gnu:enscript:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:controlcenter:6.0.0`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:controlcenter_master_agent:6.0.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:data_domain:5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:data_domain:5.4`,
        fs:  `cpe:2.3:a:samba:samba:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:data_domain:5.5`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:data_domain:5.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:data_domain:5.7`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:data_domain:5.7.1.0`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:data_domain:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:data_domain_openstorage_plugin:2.2.2.0`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.7.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:data_domain_openstorage_plugin:2.3.1.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:digital_assets_manager:6.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:digital_assets_manager:6.5:sp5`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:digital_assets_manager:6.5:sp6`,
        fs:  `cpe:2.3:a:gnome:glib:2.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:dmx_1000:-`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.1:sp1:~-~documentum~~~`,
        fs:  `cpe:2.3:a:redhat:libreport:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.1:sp1:~-~enterprise~-~-~compuset_engine`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.1:sp1:~-~enterprise~-~-~publish_engine`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.2:-:~-~documentum~~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.2:-:~-~enterprise~-~-~compuset_engine`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d48.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.2:-:~-~enterprise~-~-~publish_engine`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.5:-:~-~documentum~~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.5:-:~-~enterprise~-~-~compuset_engine`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:document_sciences_xpression:4.5:-:~-~enterprise~-~-~publish_engine`,
        fs:  `cpe:2.3:a:autonomy:connector_framework:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_administrator:6.7`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.2\(3h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_administrator:6.7:sp1`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_administrator:6.7:sp2`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_administrator:7.0`,
        fs:  `cpe:2.3:a:intel:display_adapter_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_administrator:7.1`,
        fs:  `cpe:2.3:h:nvidia:quadro_m500m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_applicationxtender_desktop:5.4`,
        fs:  `cpe:2.3:a:google:chrome:16.0.887.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_capital_projects:1.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2009.925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_capital_projects:1.9`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.0`,
        fs:  `cpe:2.3:a:xnview:xnview:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.5:sp1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.5:sp2`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:12.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.5:sp3`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.6`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.6-26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.7:-`,
        fs:  `cpe:2.3:a:abbyy:finereader:7.0:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.7:sp1`,
        fs:  `cpe:2.3:a:heartlogic.jp:hl-sitemanager:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:6.7:sp2`,
        fs:  `cpe:2.3:a:jenkins:git:2.6.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:7.0`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_content_server:7.2`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_d2:3.1:-`,
        fs:  `cpe:2.3:a:informaciondelvaticano:noticias_del_vaticano:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_d2:3.1:sp1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_d2:4.0`,
        fs:  `cpe:2.3:a:samba:samba:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_d2:4.1`,
        fs:  `cpe:2.3:a:hp:storageworks_performance_advisor_xp_software:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_d2:4.2`,
        fs:  `cpe:2.3:a:payment_for_webform_project:payment_for_webform:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_d2:4.5:p14`,
        fs:  `cpe:2.3:a:perl:perl:5.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_d2:4.6:p2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_digital_asset_manager:6.5:sp3`,
        fs:  `cpe:2.3:a:adobe:connect:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_digital_asset_manager:6.5:sp4`,
        fs:  `cpe:2.3:o:ibm:aix:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_digital_asset_manager:6.5:sp5`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_digital_asset_manager:6.5:sp6`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_eroom:7.3.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_eroom:7.4.0`,
        fs:  `cpe:2.3:h:apple:imac:mb323xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_eroom:7.4.1`,
        fs:  `cpe:2.3:a:plone:plone:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_eroom:7.4.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_eroom:7.4.3`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_eroom:7.4.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_eroom:7.4.4:sp1`,
        fs:  `cpe:2.3:a:hp:device_discovery:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_foundation_services:6.5`,
        fs:  `cpe:2.3:a:yahoo:audio_conferencing_activex_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_foundation_services:6.6`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_foundation_services:6.7`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_foundation_services:6.7:sp1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_foundation_services:6.7:sp2`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_foundation_services:7.0`,
        fs:  `cpe:2.3:a:novell:suse_lifecycle_management_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_foundation_services:7.1`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_records_manager:6.7`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_records_manager:6.7:sp1`,
        fs:  `cpe:2.3:h:3com:tippingpoint_ips:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_records_manager:6.7:sp2`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_taskspace:6.7`,
        fs:  `cpe:2.3:a:spip:spip:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_taskspace:6.7:sp1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_taskspace:6.7:sp2`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_wdk:6.7`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_wdk:6.7:sp1`,
        fs:  `cpe:2.3:a:jease:jease:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_wdk:6.7:sp2`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1183.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_web_publisher:6.5:sp1`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.0:beta-4:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_web_publisher:6.5:sp2`,
        fs:  `cpe:2.3:a:polylang_plugin_project:polylang:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_web_publisher:6.5:sp3`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_web_publisher:6.5:sp4`,
        fs:  `cpe:2.3:a:spumko_project:hapi_server_framework:2.0.0:preview:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_web_publisher:6.5:sp5`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_web_publisher:6.5:sp6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.7:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_webtop:6.7`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_webtop:6.7:sp1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_webtop:6.7:sp2`,
        fs:  `cpe:2.3:a:webmin:usermin:1.290:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_xcelerated_management_system:1.1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_xcp:2.1`,
        fs:  `cpe:2.3:a:caldera:caldera:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_xcp:2.2`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_xplore:1.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_xplore:1.1`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_xplore:1.1:p01`,
        fs:  `cpe:2.3:a:siemens:wincc:7.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_xplore:1.1:p03`,
        fs:  `cpe:2.3:a:privawall:privawall_antivirus:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:documentum_xplore:1.2`,
        fs:  `cpe:2.3:a:dropbox:lepton:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:ds-32m_switch:-`,
        fs:  `cpe:2.3:a:nuuo:crystal:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:engineering_plant_facilities_management_solution_for_documentum:1.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:engineering_plant_facilities_management_solution_for_documentum:1.7:sp1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:-`,
        fs:  `cpe:2.3:h:cisco:router_2500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:6.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:6.0.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:6.0.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:6.0.3`,
        fs:  `cpe:2.3:a:digium:asterisk:13.0.0:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:6.0.4`,
        fs:  `cpe:2.3:o:hp:hp-ux_series_800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:6.0.5`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:15.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:6.0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:eroom:6.0.7`,
        fs:  `cpe:2.3:a:ibm:worklight:6.0.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:file_management_appliance:-`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:file_management_appliance_software:7.0`,
        fs:  `cpe:2.3:h:hp:0235a25s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:global_services:4.1.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1.3\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:iomega_automatic_backup:1.2.10.54`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.7.407:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:iomega_encryption:1.3.3`,
        fs:  `cpe:2.3:a:apple:cups:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:iomega_product_registration:7.24.0`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:isilon_insightiq:2.0.0`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:isilon_insightiq:2.0.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:isilon_insightiq:2.1.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:isilon_insightiq:2.5.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:isilon_insightiq:2.5.1`,
        fs:  `cpe:2.3:o:oracle:opus_10g_ethernet_switch_family:1.2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:isilon_insightiq:2.5.2`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.6.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:isilon_insightiq:3.0.0`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:isilon_insightiq:3.0.1`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:p11-0040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.0.2.12`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.0.0`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_alcatel_timetra:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.0.1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.952:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.0.2`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:2.0.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.0.3`,
        fs:  `cpe:2.3:a:microsoft:outlook_web_access:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.0.4`,
        fs:  `cpe:2.3:h:hp:scanjet_2400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.0.5`,
        fs:  `cpe:2.3:a:emc:vmware_server:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.1.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.1.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.1.7`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.1.1.10`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_direct_user_interface:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.2.0.0`,
        fs:  `cpe:2.3:h:3com:tippingpoint_ips_1200e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.2.0.2`,
        fs:  `cpe:2.3:a:wolfcms:wolf_cms:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.2.1.0`,
        fs:  `cpe:2.3:a:cisco:security_agent:5.1.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emc:isilon_onefs:7.2.1.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:it_operations_intelligence:9.0`,
        fs:  `cpe:2.3:a:barebones:yojimbo:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:-`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:6.0`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:6.1`,
        fs:  `cpe:2.3:a:juniper:junos_space:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.1.1`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.1.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.1.3`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.2`,
        fs:  `cpe:2.3:a:codehaus:redback:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.2.1`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.2_build172`,
        fs:  `cpe:2.3:a:apache:libcloud:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.3.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.21:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:legato_networker:7.13`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:my_documentum_for_desktop:6.7.2`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:my_documentum_for_microsoft_outlook:6.7:sp1`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:my_documentum_for_microsoft_outlook:6.7:sp2`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:my_documentum_for_microsoft_outlook:6.7.1`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:my_documentum_for_microsoft_outlook:6.7.3`,
        fs:  `cpe:2.3:o:trustix:secure_linux:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_agent:26.0.2.20`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_agent:26.5.0.95`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_agent:26.9.0.51`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_agent:26.31.2.62`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_agent:28.20.1.40`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_agent:29.0.6.1`,
        fs:  `cpe:2.3:a:progress:webspeed:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_agent:29.6.0.35`,
        fs:  `cpe:2.3:a:blogkamek:koleksi_hadis_nabi_saw:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_command_line_interface:26.0.2.24`,
        fs:  `cpe:2.3:a:ibm:websphere_cast_iron_solution:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_command_line_interface:26.5.0.95`,
        fs:  `cpe:2.3:a:bluecoat:content_analysis_system_software:1.1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_command_line_interface:26.9.0.51`,
        fs:  `cpe:2.3:a:apple:cups:1.1.10-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_command_line_interface:26.10.0.61`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_command_line_interface:28.0.4.25`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_command_line_interface:28.20.1.40`,
        fs:  `cpe:2.3:a:webmin:webmin:1.660:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_manager:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_manager:6.4`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_manager:6.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_manager:6.6`,
        fs:  `cpe:2.3:a:apache:derby:10.8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_off-array_management_server:29.6.0.64`,
        fs:  `cpe:2.3:h:cisco:catalyst_4200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_server_utility:6.20.2.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_server_utility:6.24.0.6.12`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_server_utility:6.24.0.7.0`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.20.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_server_utility:28.20.1.50`,
        fs:  `cpe:2.3:a:janetter:janetter:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_service_taskbar:24.50.0.81`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_service_taskbar:28.53.1.76`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:navisphere_service_taskbar:29.2.0.62`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:-`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:6.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:6.1`,
        fs:  `cpe:2.3:h:netgear:wgr614:v5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.2`,
        fs:  `cpe:2.3:a:cisco:unity_connection:10.5\(2.3009\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.176:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.3.2`,
        fs:  `cpe:2.3:a:mail_on_update_project:mail_on_update:5.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4:sp1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4:sp2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4:sp3`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4:sp4`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:6.00.2800.1106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4:sp5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4.5.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4.5.5`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.12:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4.5.6`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.6.3-025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.4.5.10`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.7.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5:sp1`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5:sp2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5:sp3`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.2.0`,
        fs:  `cpe:2.3:a:ca:etrust_secure_content_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.2.1`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.2.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.2.4`,
        fs:  `cpe:2.3:o:cisco:vpn_3015_concentrator:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.3`,
        fs:  `cpe:2.3:a:siemens:openscape_session_border_controller:1r4.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.3.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.7q8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.3.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.3.3`,
        fs:  `cpe:2.3:a:intel:mzconfig:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.3.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.3.5`,
        fs:  `cpe:2.3:a:apple:keynote:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.4`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.21:-:*:*:*:solaris:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.4.2`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.4.3`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.4.4`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.4.5`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.4.6`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.5.4.7`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6:sp1`,
        fs:  `cpe:2.3:o:vmware:esx:2.0:build_5257:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6:sp2`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.0.2`,
        fs:  `cpe:2.3:a:intel:network_connections:15.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.0.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.0.4`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.0.5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.0.6`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update2:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.0.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.0.8`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.0.9`,
        fs:  `cpe:2.3:a:apache:poi:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.1`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.1.1`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_agent_framework:3.3.1064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.1.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.1.3`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.1.4`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.1.5`,
        fs:  `cpe:2.3:a:synology:cloud_station:3.1-3320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.3`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.4`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.4.1`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.4.2`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2_sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.4.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.1.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.4.4`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.4.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.6\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.5`,
        fs:  `cpe:2.3:a:chilkat_software:chilkat_xml_activex_control:3.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.5.2`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.5.3`,
        fs:  `cpe:2.3:a:kristof_de_jaeger:bundle_copy:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.5.4`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.5.5`,
        fs:  `cpe:2.3:a:jetbrains:teamcity:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:7.6.5.6`,
        fs:  `cpe:2.3:a:goforandroid:go_twiwidget:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.0.1`,
        fs:  `cpe:2.3:o:advantech:eki-1322_series_firmware:1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.0.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.0.3`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.0.4`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.8.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.0.5`,
        fs:  `cpe:2.3:a:nokia:intellisync_mobile_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.0.6`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.1.3`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:locked:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.1.5`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.1.6`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.2.0`,
        fs:  `cpe:2.3:a:simgear:simgear:2.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.2.1`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.0.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.2.2`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.4.3`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.0.4.4`,
        fs:  `cpe:2.3:a:irfanview:flashpix_plugin:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.0.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.0.1`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.0.2`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit-32:12.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.0.3`,
        fs:  `cpe:2.3:a:packetfence:packetfence:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.0.4`,
        fs:  `cpe:2.3:o:hp:ignite-ux:c.7.1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.0.5`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.0`,
        fs:  `cpe:2.3:a:informationbuilders:webfocus:77.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.1`,
        fs:  `cpe:2.3:h:nokia:6210_handset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.2`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.3`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.5`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.8`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.1.9`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.2.0`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.2.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.2.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud_client:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.2.3`,
        fs:  `cpe:2.3:a:packagekit_project:packagekit:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.2.4`,
        fs:  `cpe:2.3:h:siemens:cfmw3025:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.2.5`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.2.6`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.7.2\(75\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.2.7`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.3.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.3.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1022.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.3.3`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.1.3.4`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.0.1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.0.2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.0.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.0.3`,
        fs:  `cpe:2.3:a:xchat:xchat:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.0.4`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.0.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.181.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.0.6`,
        fs:  `cpe:2.3:a:google:chrome:6.0.445.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.2`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.13:ga6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.3`,
        fs:  `cpe:2.3:a:winzip:winzip:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.4`,
        fs:  `cpe:2.3:a:mochiweb_project:mochiweb:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.5`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.6`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.7-p1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.7`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.1.8`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.0.4115.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.2.0`,
        fs:  `cpe:2.3:a:hp:update:4.0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:8.2.2.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker:9.0.0.0`,
        fs:  `cpe:2.3:a:aimluck:aipo-asp:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker_module_for_microsoft_applications:2.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker_module_for_microsoft_applications:2.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker_module_for_microsoft_applications:2.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker_module_for_microsoft_applications:2.2.1`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker_module_for_microsoft_applications:2.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:networker_module_for_microsoft_applications:2.4`,
        fs:  `cpe:2.3:a:roxio:easy_cd_\&amp;_dvd_creator:6.2.0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:-`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:3.0.5`,
        fs:  `cpe:2.3:a:php:php:5.6.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:3.0.6`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:4.3.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:4.5.0`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:5.1.0`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:5.1.1`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:5.2.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.236:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:5.3.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:5.4.2`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath:5.5.0`,
        fs:  `cpe:2.3:o:opensuse:opensuse:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:powerpath_virtual_appliance:1.2`,
        fs:  `cpe:2.3:a:microsoft:xml_core_services:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:quickscan:3.5.1.2829`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:records_client:6.7`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:records_client:6.7:sp1`,
        fs:  `cpe:2.3:a:nuance:pdf_converter:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:records_client:6.7:sp2`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replication_manager:5.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-03-03:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replication_manager:5.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replication_manager:5.2::client`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replication_manager:5.3`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.820:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replication_manager:5.4`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replication_manager:5.5`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replication_manager:5.5.1`,
        fs:  `cpe:2.3:a:cisco:tftp_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replication_manager:5.5.2`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replistor:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:replistor:6.1.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect:-`,
        fs:  `cpe:2.3:a:samba:samba:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect:6.5`,
        fs:  `cpe:2.3:a:gnu:xemacs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect:7.0`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect:7.5`,
        fs:  `cpe:2.3:a:redhat:openstack:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect:7.50.252`,
        fs:  `cpe:2.3:a:ca:etrust_security_suite:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect_client:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s_3.10.7s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect_client:5.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect_client:6.5`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect_client:7.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:retrospect_client:7.5`,
        fs:  `cpe:2.3:a:roxio:central_tools:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_access_manager:6.1:-`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_access_manager:6.1:sp1`,
        fs:  `cpe:2.3:a:symantec:product_authentication_service_client:4.3.34.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_access_manager:6.1:sp2`,
        fs:  `cpe:2.3:a:apple:cups:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_access_manager:6.1:sp3`,
        fs:  `cpe:2.3:a:emc:global_services:4.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_access_manager:6.1:sp4`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_collaboration_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_access_manager:6.2:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_access_manager:6.2:sp1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_adaptive_authentication_hosted:11.0`,
        fs:  `cpe:2.3:a:webmin:usermin:1.360:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.0`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.33.381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.2`,
        fs:  `cpe:2.3:a:apache:tomcat:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.4`,
        fs:  `cpe:2.3:a:adobe:linguistics_cs4:4.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.4:sp1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.5`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5b\)su5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.5:sp1`,
        fs:  `cpe:2.3:a:acquia:commons:6.x-2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_egrc:5.5.1`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_smartsuite:4.3`,
        fs:  `cpe:2.3:a:gnu:glibc:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_archer_smartsuite:4.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.5-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_authentication_agent:7.0.0`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_authentication_agent:7.0.1`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_authentication_agent:7.0.2`,
        fs:  `cpe:2.3:h:d-link:dcs-5025l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_authentication_agent:7.1`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_authentication_agent:7.1.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_authentication_manager:8.0`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_authentication_manager:8.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1282.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:3.2.0::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:isc:bind:9.8.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:3.2.1::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:3.2.2::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:3.2.3::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:3.2.4::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:o:sun:solaris:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:3.2.5::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:3.2.6::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:h:polycom:viavideo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:4.0.0::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-72-\/d:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:4.0.1::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:4.0.2::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:4.0.3::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:4.0.4::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe:4.0.5::~~micro_edition_suite~~~`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe-c_toolkits:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe-java_toolkits:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe_ssl-j:6.1.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(3a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_bsafe_toolkits:-`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.02:*:le:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_loss_prevention:9.6.1`,
        fs:  `cpe:2.3:a:apple:quicktime:7.70.80.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_loss_prevention:9.6.2`,
        fs:  `cpe:2.3:h:netgear:fvs318:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_loss_prevention:9.6.2.1`,
        fs:  `cpe:2.3:a:detlef_pilzecker:proc\:\:adaemon-run_perl:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_loss_prevention:9.6.2.2`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_loss_prevention:9.6.2.3`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_loss_prevention:9.6.2.4`,
        fs:  `cpe:2.3:a:opentext:enterprise_library_records_management:4.2.0.487:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_protection_manager:20130918`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:2.7.0`,
        fs:  `cpe:2.3:a:x:libxfont:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:3.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:3.1`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:3.2`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:3.2.1`,
        fs:  `cpe:2.3:a:web2py:web2py:1.91.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:3.2.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:3.2.3`,
        fs:  `cpe:2.3:a:gnu:glibc:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:3.2.4.1`,
        fs:  `cpe:2.3:a:dell:client_configuration_toolkit:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emc:rsa_data_protection_manager_appliance:3.5`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_protection_manager_software_server:2.7.0`,
        fs:  `cpe:2.3:a:ibm:leads:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_protection_manager_software_server:3.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_protection_manager_software_server:3.1`,
        fs:  `cpe:2.3:a:oracle:application_server_portal:9.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_protection_manager_software_server:3.2`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.1.20000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_data_protection_manager_software_server:3.2.1`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_identity_management_and_governance:6.5.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_identity_management_and_governance:6.5.1`,
        fs:  `cpe:2.3:a:openstack:swift:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_identity_management_and_governance:6.5.2`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_identity_management_and_governance:6.8.0`,
        fs:  `cpe:2.3:a:cisco:rv016_multi-wan_vpn_firmware:4.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_identity_management_and_governance:6.8.1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.763:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_identity_management_and_governance:6.9.0`,
        fs:  `cpe:2.3:a:vmware:capacityiq:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_identity_management_and_governance:6.9.1`,
        fs:  `cpe:2.3:a:siteminder_for_secure_proxy_server:12.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_netwitness:9.8.5.17`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_netwitness:9.8.5.19`,
        fs:  `cpe:2.3:a:schneider-electric:clearscada:2010:r3.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_netwitness_nextgen:9.8`,
        fs:  `cpe:2.3:h:rockwellautomation:rslinx_enterprise:cpr9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_security_analytics:10.0`,
        fs:  `cpe:2.3:a:ca:netviz_viewer:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_security_analytics:10.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_security_analytics:10.2`,
        fs:  `cpe:2.3:a:microsoft:access:2013:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_security_analytics:10.2.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_security_analytics:10.2.4`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.572:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_security_analytics:10.3`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_security_analytics:10.3.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_security_analytics:10.3.2`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_web_threat_detection:4.0`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_web_threat_detection:4.1`,
        fs:  `cpe:2.3:a:redaxo:redaxo:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_web_threat_detection:4.6.1.0`,
        fs:  `cpe:2.3:a:polycom:dma_system_software:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:rsa_web_threat_detection:5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:secure_remote_services:3.0::~~virtual~~~`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:secure_remote_services:3.02::~~virtual~~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.491.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:secure_remote_services:3.03::~~virtual~~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:smarts_network_configuration_manager:9.1`,
        fs:  `cpe:2.3:a:airdroid:airdroid:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:smarts_network_configuration_manager:9.2`,
        fs:  `cpe:2.3:a:lsoft:listserv:1.8e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:smarts_network_configuration_manager:9.3`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:solutions_enabler:-`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.6:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:solutions_enabler:6.5.883`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10\)ec1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:solutions_enabler_for_ecc:7.10.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:sourceone_email_management:7.1`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:storagescope_queries:1.0.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:symmetrix_8530:-`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option_server:08-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:task_space:6.7`,
        fs:  `cpe:2.3:a:elsop:linkscan:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:task_space:6.7:sp1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:task_space:6.7:sp2`,
        fs:  `cpe:2.3:a:php:pear:1.3b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:unisphere:1.0:-:~~~vmax~~`,
        fs:  `cpe:2.3:a:amazon:kindle:4.6.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:unisphere:1.1:-:~~~vmax~~`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:unisphere:1.5:-:~~~vmax~~`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:unisphere:1.6:-:~~~vmax~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:unisphere:8.1::~~~vmax~~`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:unisphere_central:3.5.0`,
        fs:  `cpe:2.3:a:google:earth_plug-in:6.1.0.5001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:unisphere_service_manager:1.1.25.10129`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vipr_srm:3.6.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vipr_srm:3.6.4`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vipr_srm:4.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vmware:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vmware:6.0.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.480:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vmware_player:-`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vmware_server:-`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.41:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vmware_server:1.0.4`,
        fs:  `cpe:2.3:a:google:chrome:10.0.631.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vmware_server:1.0.4_build_56528`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vplex_geosynchrony:4.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vplex_geosynchrony:5.0`,
        fs:  `cpe:2.3:a:adobe:extension_manager:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vplex_geosynchrony:5.1`,
        fs:  `cpe:2.3:a:webmin:usermin:0.970:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vplex_geosynchrony:5.2`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vplex_geosynchrony:5.2.1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.1a:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vplex_geosynchrony:5.3`,
        fs:  `cpe:2.3:h:samsung:galaxy_s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vplex_geosynchrony:5.4:sp1`,
        fs:  `cpe:2.3:a:snort:snort:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:vplex_geosynchrony:5.5`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:watch4net:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:watch4net:6.1`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:watch4net:6.2`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:watch4net:6.3`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:watch4net:6.5`,
        fs:  `cpe:2.3:a:oracle:mysql_documents:5.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:web_publishers:6.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:web_publishers:6.5:sp6`,
        fs:  `cpe:2.3:a:asial:monaca_debugger:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emc:web_publishers:6.5:sp7`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.6`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.7`,
        fs:  `cpe:2.3:a:apport_project:apport:2.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.8`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.9`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.11`,
        fs:  `cpe:2.3:h:lexmark:x644:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.12`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.13`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.14`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.15`,
        fs:  `cpe:2.3:a:symantec:netbackup_enterprise_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.16`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.17`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.18`,
        fs:  `cpe:2.3:a:moodle:moodle:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.19`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.20`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.tc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.21`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.22`,
        fs:  `cpe:2.3:a:aimluck:aipo-plus:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.23`,
        fs:  `cpe:2.3:a:vmware:tools:8.0.2.17586:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.24`,
        fs:  `cpe:2.3:a:horde:imp:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.25`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.26`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.27`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.28`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.29`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.11:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.30`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.31`,
        fs:  `cpe:2.3:a:logitech:video_enumerator:10.0.1439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.32`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.32.1`,
        fs:  `cpe:2.3:h:d-link:dap-1360:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.33`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.34`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.35`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.36`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.37`,
        fs:  `cpe:2.3:a:adobe:air:19.0.0.241:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.38`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.39`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(14\)e9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.40`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:tr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.41`,
        fs:  `cpe:2.3:a:altiris:realtime_system_manager:6.3.1066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.42`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.43`,
        fs:  `cpe:2.3:h:cisco:ios:12.2mc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.44`,
        fs:  `cpe:2.3:a:apache:axis2:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.45`,
        fs:  `cpe:2.3:a:mnt-tech:wp-facethumb:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.46`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emeric_vernat:javamelody:1.47`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:aperture_web_application_server:4.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:aperture_web_services_server:4.0`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:avocent_dsr1021:-`,
        fs:  `cpe:2.3:o:ibm:lotus_smartsuite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:avocent_dsr1031:-`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:avocent_mpu108edac:-`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:avocent_mpu4032:-`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r77.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav:9.3.1`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.4:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav:10.3.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav:11.3`,
        fs:  `cpe:2.3:a:apple:quicktime:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav:11.3.1`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav:12.3`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav_proessentials_scientific_graph:5.0.0.6`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:018:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav_workstation:9.3.1`,
        fs:  `cpe:2.3:o:microsoft:windows_me:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav_workstation:10.3.1`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav_workstation:11.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emerson:deltav_workstation:11.3.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:dl_8000_remote_terminal_unit:-`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:gxt4-2000rt120:-`,
        fs:  `cpe:2.3:a:mccabe:iq:8.0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:network_power_avocent_mergepoint_unity_2016:-`,
        fs:  `cpe:2.3:a:avast:internet_security:11.1.2261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:emerson:network_power_avocent_mergepoint_unity_2016_firmware:1.9.16473`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:roc_800_remote_terminal_unit:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1291.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:emerson:roc_800l_remote_terminal_unit:-`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emersonnetworkpower:aperture_web_application_server:4.0`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emersonnetworkpower:aperture_web_services_server:4.0`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.5.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:2.0.6`,
        fs:  `cpe:2.3:a:janetter:janetter:1.6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:2.1.0`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:2.1.2:d`,
        fs:  `cpe:2.3:a:nec:socks_5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.3.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.4.0`,
        fs:  `cpe:2.3:a:redhat:icedtea7:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.5.1`,
        fs:  `cpe:2.3:a:sap:netweaver:7.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.6.1`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.6.2`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.7`,
        fs:  `cpe:2.3:a:teamquest:alert:10.1_pf_20080815:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.7.1`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.8`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emery_berger:hoard:3.9`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emil_stjerneman:linkit:7.x-2.0`,
        fs:  `cpe:2.3:a:sagecrm:sagecrm:7.3:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emil_stjerneman:linkit:7.x-2.0:beta1`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emil_stjerneman:linkit:7.x-2.0:beta2`,
        fs:  `cpe:2.3:a:dell:kace_k1000_systems_management_appliance_software:5.4.76847:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emil_stjerneman:linkit:7.x-2.1`,
        fs:  `cpe:2.3:a:google:v8:3.24.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emil_stjerneman:linkit:7.x-2.2`,
        fs:  `cpe:2.3:a:google:chrome:12.0.737.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emil_stjerneman:linkit:7.x-2.3`,
        fs:  `cpe:2.3:a:synology:diskstation_manager:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emisoft:online_armor:4.0.0.35:-:premium`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.54:bbet54p:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emorym:android_pusher:-:-:~~~android~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emtec:zoc_terminal:6.33`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:common_san_management:5.0.66.5`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:common_san_management:30.1.32`,
        fs:  `cpe:2.3:o:yamaha:rt60w:5.01.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:common_san_management:31.1.9.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:common_san_management:31.23.26`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.10:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:common_san_management:32.0.1.34`,
        fs:  `cpe:2.3:a:oracle:marketing:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:common_san_management:32.1.1.35`,
        fs:  `cpe:2.3:a:apple:safari:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:common_san_management:32.1.1.36`,
        fs:  `cpe:2.3:h:polycom:viewstation_sp_sp384:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:elxocm:5.0.66.05-6`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:fibre_channel_hbanyware:2.1.15`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:fibre_channel_hbanyware:2.1.17`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:fibre_channel_hbanyware:2.1.35`,
        fs:  `cpe:2.3:a:wondercms:wondercms:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:fibre_channel_hbanyware:2.1.38`,
        fs:  `cpe:2.3:a:ca:etrust_siteminder_policy_server:12.0.105.635:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:fibre_channel_hbanyware:2.1.45`,
        fs:  `cpe:2.3:o:huawei:mate_8_firmware:nxt-cl10c00b197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:fibre_channel_hbanyware:3.0.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:fibre_channel_hbanyware:3.0.19`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:hbanyware:3.1.37`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.5.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:hbanyware:3.3.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:hbanyware:3.3a14`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r2:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:hbanyware:3.4a9`,
        fs:  `cpe:2.3:a:apple:cups:1.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:hbanyware:4.00a32`,
        fs:  `cpe:2.3:h:fortinet:fortianalyzer-200d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:hbanyware:4.01a36`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_patch_management_solution_for_windows:6.2.3644:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emulex:ocmanager:5.0.66.5`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emunching:harry%27s_pub:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.14f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emurasoft:emeditor_professional:10.0.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emurasoft:emftp:-::~~professional~~~`,
        fs:  `cpe:2.3:h:motorola:atrix_hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:emurasoft:emftp:-::~~standard~~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:en2grate:eta_mobile:1.6.6::~~~android~~`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enalean:tuleap:7.5.99.5`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enalean:tuleap:7.5.99.6`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:enalean:tuleap:7.6`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:0.8.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.2.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:0.8.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:0.8.3`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.3.7.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:0.8.4`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.0.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:0.9.1`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:0.9.2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:0.9.3`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.52:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.1`,
        fs:  `cpe:2.3:a:drupal:drupal:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.2:b1`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.4`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.6`,
        fs:  `cpe:2.3:a:gnu:bash:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.6:pl1`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.6:pl2`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.0.6:pl3`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:11.1.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.3`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.5`,
        fs:  `cpe:2.3:a:vmware:fusion_pro:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.6`,
        fs:  `cpe:2.3:h:supermicro:x9dbl-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.7`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.7:pl1`,
        fs:  `cpe:2.3:a:apple:itunes:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.7:pl2`,
        fs:  `cpe:2.3:a:solarwinds:orion_netflow_traffic_analyzer:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enanocms:enano_cms:1.1.8`,
        fs:  `cpe:2.3:a:keepass:keepass:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:encardirect:sk_encar:%407f050000::~~~android~~`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:11.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.0`,
        fs:  `cpe:2.3:a:emc:networker_module_for_microsoft_applications:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.1`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.2`,
        fs:  `cpe:2.3:a:php:php:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1688.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.4`,
        fs:  `cpe:2.3:o:apple:watchos:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.5`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.6`,
        fs:  `cpe:2.3:a:rim:blackberry_desktop_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.7`,
        fs:  `cpe:2.3:a:apache:struts:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.8`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.14s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.10`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.4.11`,
        fs:  `cpe:2.3:a:sefrengo:sefrengo:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.5.0`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.5.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.5.2`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:0.1:beta-3:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.5.3`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.5.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.5.5`,
        fs:  `cpe:2.3:o:rockwellautomation:softlogix_5800_controller_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.5.6`,
        fs:  `cpe:2.3:a:apache:subversion:0.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.6.0`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.6.2`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.6.3`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.6.4`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.6.5`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.7.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.7.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.7.2`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.8.0`,
        fs:  `cpe:2.3:a:tilman_hausherr:xenu_link_sleuth:1.2i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.8.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.8.2`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.9.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.11s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.9.1`,
        fs:  `cpe:2.3:h:yokogawa:exarqe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.10.0`,
        fs:  `cpe:2.3:a:cisco:secure_services_client:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.11.0`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.12.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.12.1`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.13.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p237_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.13.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.13.2`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.14.0`,
        fs:  `cpe:2.3:a:microsoft:office:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.14.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.14.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.14.3`,
        fs:  `cpe:2.3:a:google:v8:3.22.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.14.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.14.5`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.15.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.15.1`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:6.x-1.3:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.16.0`,
        fs:  `cpe:2.3:o:apple:airport_base_station_firmware:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endeavorsystems:openfisma:2.16.1`,
        fs:  `cpe:2.3:a:microsoft:directx:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endian:firewall:2.1.2`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endian:firewall:2.4`,
        fs:  `cpe:2.3:a:topazsystems:sigplus_pro_activex_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endonesia:endonesia:8.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endonesia:endonesia:8.1`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript_lite:8.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endonesia:endonesia:8.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endonesia:endonesia:8.3`,
        fs:  `cpe:2.3:a:hp:creativeprojects_package_basic1:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endonesia:endonesia:8.4`,
        fs:  `cpe:2.3:a:apple:itunes:5.0:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:endulujans:eyvah%21_bosandim_ozgurum:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.62:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:enea:ose:1.20`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:enea:ose:2.30`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(1a\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:enea:ose:3.50`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:energyscripts:simple_download:1.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp4:advanced_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eng:spagobi:4.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eng:spagobi:4.1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.4.143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:engardelinux:guardian_digital_webtool:-`,
        fs:  `cpe:2.3:a:cygnacom:visualspif:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:engardelinux:guardian_digital_webtool:1.2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:engardelinux:secure_community:-`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:engardelinux:secure_community:1.0.1`,
        fs:  `cpe:2.3:a:gnu:cpio:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:engardelinux:secure_community:2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:engardelinux:secure_linux:-`,
        fs:  `cpe:2.3:h:cisco:telepresence_server_mse_8710:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:engardelinux:secure_linux:1.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p203:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:engardelinux:secure_professional:-`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enghouseinteractive:ivr_pro:9.0.3`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:gold:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enhydra:director:4`,
        fs:  `cpe:2.3:h:juniper:secure_access_700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enigmail:enigmail:1.7`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enigmail:enigmail:1.7.2`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enl_newsletter_plugin_project:enl-newsletter:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:h:asus:dsl-n55u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enl_newsletter_plugin_project:enl-newsletter:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(22\)s5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enorth:webpublisher_cms:5.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:1h582-25:-`,
        fs:  `cpe:2.3:a:ibm:http_server_ssl_module_common:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:1h582-51:-`,
        fs:  `cpe:2.3:a:microsoft:ie:5.01:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:2e42-27r:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:2h252-25r:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6e233-49:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p198:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6g306-06:-`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_plant_applications:215.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6g306-6:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6h202-24:-`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6h252-17:-`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6h258-17:-`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6h302-48:-`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6h303-48:-`,
        fs:  `cpe:2.3:a:php:phpbookingcalendar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:6h352.25:-`,
        fs:  `cpe:2.3:a:redhat:rhel_developer_suite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:ang_3000_7050:-`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:aps_3000_7000:-`,
        fs:  `cpe:2.3:a:apache:james_server:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:dragon:-`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:matrix_n3:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:matrix_n7:-`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.060109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enterasys:netsight_console:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enterasys:netsight_console:2.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.5\(1\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enterasys:netsight_inventory_manager:-`,
        fs:  `cpe:2.3:a:perl:perl:5.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enterasys:netsight_inventory_manager:2.1`,
        fs:  `cpe:2.3:a:winzip:winzip_command_line_support_add-on:1.1:sr-1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:roamabout_ap2000:-`,
        fs:  `cpe:2.3:a:apple:safari:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:roamabout_ap2000:6.04.12`,
        fs:  `cpe:2.3:a:google:chrome:12.0.712.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:roamabout_ap3000:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:roamabout_ap3000:2.12`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:roamabout_ap3000:3.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.6-150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:smartswitch_ssr8000:-`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:ssr:-`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:vertical_horizon-2402s:2.05.00`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-03-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:vertical_horizon-2402s:2.05.08.01`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:vertical_horizon-2402s:2.05.09.07`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:5.2\(1\)sm1\(5.1\):-:*:*:*:microsoft_hyper-v:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:vh-2402s:-`,
        fs:  `cpe:2.3:a:citrix:presentation_server_administration_snap-in:4.6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:x-pedition:-`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.96:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:xp-2400:-`,
        fs:  `cpe:2.3:a:python:python:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:xsr-1805:-`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:xsr-1850:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:el:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:enterasys:xsr-3000:-`,
        fs:  `cpe:2.3:a:jusapp:jusapp\!:3.7.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:entertailion:able_remote:2.3.6::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_api_project:entity_api:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:docker:docker:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:h:cisco:call_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p121:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(23\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:beta4`,
        fs:  `cpe:2.3:a:joachim_ruhs:locator:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:beta5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:rc2`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:rc3`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:rc4`,
        fs:  `cpe:2.3:a:microsoft:html_help_workshop:4.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.0:rc5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.1:rc1`,
        fs:  `cpe:2.3:a:vmware:hyperic_hq:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entity_reference_project:entityreference:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entrouvert:lasso:1.9.9.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entrouvert:lasso:2.0.0-1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entrouvert:lasso:2.2.1-0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:entrouvert:lasso:2.3.5`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.91:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:entrouvert:lasso:2.3.6`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1035:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:entrypass:n5200_active_network_control_panel:-`,
        fs:  `cpe:2.3:a:gnu:emacs:20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:1.0.0:rev25273`,
        fs:  `cpe:2.3:a:haxx:curl:7.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:1.0.1:rev25421`,
        fs:  `cpe:2.3:a:gnome:glib:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:1.0.2:rev25487`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:2.0.0:rev27524`,
        fs:  `cpe:2.3:h:cisco:sn_5428_storage_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:2.0.1:rev27876`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.3:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:2.0.2:rev28693`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:2.0.3:rev28734`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.0.0:rev29469`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.0.1:rev29536`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.1.0:rev30003`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.1.1:rev30900`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_97:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.0:rev31030`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd306a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.1:rev33197`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.2:rev33971`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.3:rev34390`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.4:rev34757`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.5:rev34942`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.6:rev36235`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.7:rev36257`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.2.8:rev36369`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.3.0:rev36620`,
        fs:  `cpe:2.3:o:sun:sunos:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.3.1:rev38906`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.8:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.3.2:rev39009`,
        fs:  `cpe:2.3:a:netscout:ngenius_client:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.3.3:rev39177`,
        fs:  `cpe:2.3:a:wtmdesktop_project:wtmdesktop:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:envato:complete_gallery_manager_plugin:3.3.4:rev40279`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:envialosimple:email_marketing_y_newsletters:1.97:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:breezy:breezy:1.2.15:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:enyetech:coca-cola_fm_brasil:2.0.41709::~~~android~~`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enyetech:coca-cola_fm_guatemala:2.0.41725::~~~android~~`,
        fs:  `cpe:2.3:h:dell:precision_t5600_xl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enyetech:coca-cola_fm_honduras:2.0.41725::~~~android~~`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:enyetech:coca-cola_fm_peru:2.0.41716::~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eolsoft:flash_movie_player:1.5`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ephiphanyheathdata:cardio_server:3.3`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ephiphanyheathdata:cardio_server:4.0`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ephiphanyheathdata:cardio_server:4.1`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epignosis:efront:3.6.15.2::~~open_source~~~`,
        fs:  `cpe:2.3:a:frank_matano_project:frank_matano:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:epiqo:email:6.x-1.0`,
        fs:  `cpe:2.3:a:entity_api_project:entity_api:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:epiqo:email:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epiqo:email:6.x-1.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epiqo:email:6.x-1.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epiqo:email:6.x-1.3`,
        fs:  `cpe:2.3:o:juniper:junos:5.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epiqo:email:6.x-1.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epiqo:email:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:hp:gpbaseservice:100.0.187.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epractizelabs:subscription_manager:1.0`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.14:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:copy_utility:3.4.0.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:copy_utility:3.5.0.0`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:event_manager:2.1.0`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_command_center:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:event_manager:2.30.1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:event_manager:2.40.1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:photostarter:3.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p155:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:print_cd:1.60.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p226:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:print_cd:2.0.0`,
        fs:  `cpe:2.3:a:xymon:xymon:4.2:beta20060605:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:scan_pdf_extensions:1.0.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:epson:stylus_color_850_ink_jet_printer:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:twain:5.71.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:epson:usb_display:1.42.0`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:equifax:equifax_mobile:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:equis:metastock:8.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:equis:metastock:9.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:equis:metastock:9.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.538:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:equis:metastock:9.2`,
        fs:  `cpe:2.3:a:techsmith:camtasia_relay:6.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:equis:metastock:10.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:equis:metastock:10.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:equis:metastock:11.0`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erau:embry-riddle:1.4.04::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0`,
        fs:  `cpe:2.3:o:cisco:unified_intelligence_center:10.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:beta1`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:beta2`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:beta3`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:pre1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:pre2`,
        fs:  `cpe:2.3:a:schneider-electric:clearscada:2010:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:pre3`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:pre4`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:pre6`,
        fs:  `cpe:2.3:h:cisco:c210_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eric_m_ludlam:cedet:1.0:pre7`,
        fs:  `cpe:2.3:a:emc:navisphere_agent:26.31.2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ericpol:ewus_mobile:1.4.5::~~~android~~`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ericsson:drutt_mobile_service_delivery_platform:4.0`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ericsson:drutt_mobile_service_delivery_platform:5.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ericsson:drutt_mobile_service_delivery_platform:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.4.3`,
        fs:  `cpe:2.3:a:microsoft:expression_design:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.0`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.1`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(4k\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.3`,
        fs:  `cpe:2.3:a:dell:repository_manager:1.2.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.4`,
        fs:  `cpe:2.3:a:znc:znc:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.5`,
        fs:  `cpe:2.3:a:umn:mapserver:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.2sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.7`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:3.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_hjortsberg:ember:0.5.8`,
        fs:  `cpe:2.3:a:mcafee:dlp_agent:2.2.200.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erik_michaels-ober:multi_xml:0.5.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:vandyke:securecrt:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.0:alpha4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.1`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.2`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.7:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.4`,
        fs:  `cpe:2.3:a:atlassian:jira:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.5`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.6`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.808:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:6.x-1.x:dev`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd303a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.0`,
        fs:  `cpe:2.3:a:apc:powerchute_network_shutdown:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:webcreate:webforum:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.0:beta2`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.0:beta4`,
        fs:  `cpe:2.3:a:spice_project:spice:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:netease:youdao_dictionary:2.0.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.0:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.0:rc3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.2`,
        fs:  `cpe:2.3:a:altova:missionkit_2009:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4.3\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.5`,
        fs:  `cpe:2.3:a:hp:destination_component:110.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erikwebb:password_policy:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_xi:3.1:fp1.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.7.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.1`,
        fs:  `cpe:2.3:a:sun:sdk:1.1.8_007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.1.1`,
        fs:  `cpe:2.3:a:oracle:opensso:3.0-0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.1.2`,
        fs:  `cpe:2.3:o:pheonixcontact-software:proconos_eclr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:10.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.2`,
        fs:  `cpe:2.3:a:vips:vips:7.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.2.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.2.2`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.2.3`,
        fs:  `cpe:2.3:a:luracast:restler:0.10.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.3`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.4`,
        fs:  `cpe:2.3:a:ibm:optim_workload_replay:2.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xb15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.5.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.5.2`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:12.3:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.5.2.1`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.5.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.6`,
        fs:  `cpe:2.3:a:busybox:busybox:1.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.6.1`,
        fs:  `cpe:2.3:a:bestpractical:rtfm:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.6.2`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.95.j1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.6.3`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:1.6.4`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:5.5:u3b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:2.0`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:2.0.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:2.0.2`,
        fs:  `cpe:2.3:a:minitab:license_manager:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:2.0.2.1`,
        fs:  `cpe:2.3:a:intel:wimax_network_service:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:2.0.2.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p245:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:crypto:2.0.3`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r11b-5`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.12:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r12b-5`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r13b`,
        fs:  `cpe:2.3:a:siemens:openscape_session_border_controller:7r1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r13b02-1`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.5:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r13b03`,
        fs:  `cpe:2.3:a:digifi:motoring_classics:1.8.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r13b04`,
        fs:  `cpe:2.3:a:apple:itunes:7.5:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r14a`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r14b`,
        fs:  `cpe:2.3:a:intel:network_connections:14.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r14b01`,
        fs:  `cpe:2.3:a:emc:web_publishers:6.5:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r14b02`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.0.0:rev29469:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang:erlang%2fotp:r14b03`,
        fs:  `cpe:2.3:a:isc:bind:9.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang-solutions:mongooseim:1.2.1`,
        fs:  `cpe:2.3:a:cisco:meetingtime:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang-solutions:mongooseim:1.2.2`,
        fs:  `cpe:2.3:a:checkpoint:secureclient_ng:r54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang-solutions:mongooseim:1.3.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang-solutions:mongooseim:1.3.1:-`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:erlang-solutions:mongooseim:1.3.1:rev2`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:escucha_eldiario_project:escucha_eldiario:1.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:lotus_mobile_connect:6.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eset:personal_firewall_ndis_filter:1183_%2820140214%29`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eshtery.she7ata:eshtery_cms:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esoftpro:online_contact_manager:3.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esoftpro:online_guestbook_pro:5.1`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esoftpro:online_photo_pro:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis:-`,
        fs:  `cpe:2.3:a:makina-corpus:soappy:0.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis:9.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis:10.0.2.3200`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis:10.1`,
        fs:  `cpe:2.3:a:mbtcreations:detox_juicing_diet_recipes:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis:10.2`,
        fs:  `cpe:2.3:a:janetter:janetter:2.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis_3d_analyst:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis_arcsde:-`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis_for_server:10.1.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcgis_spatial_analyst:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcinfo_workstation:-`,
        fs:  `cpe:2.3:a:samba:samba:3.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcinfo_workstation:9.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcmap:9.0`,
        fs:  `cpe:2.3:a:matrox:dualhead2go:1.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcpad:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcpad:7.0.0.156`,
        fs:  `cpe:2.3:o:google:android:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcsde:-`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:9.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcsde:8.3`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcsde:9.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcsde:9.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:esri:arcview:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1286.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:essentialobjects:eo.web_controls_2011:9.0.22`,
        fs:  `cpe:2.3:a:rockwellautomation:factorytalk_services_platform:cpr9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estateapps:acorn_estate_agents:3.1::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:ngc:22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estrongs:es_file_explorer:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.198:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estrongs:es_file_explorer:1.6.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estrongs:es_file_explorer:1.6.1.1::~~~android~~`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:estrongs:es_file_explorer:3.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:developer_log_project:developer_log:2.11.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:estrongs:es_file_explorer:3.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estrongs:es_file_explorer:3.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:hp:jh196a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estrongs:es_file_explorer:3.1.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:10.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estsoft:alsee:6.20.0.1`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:8.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estsoft:alzip:8.0`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.032_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estsoft:alzip:8.12`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:102sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:estsoft:alzip:8.21`,
        fs:  `cpe:2.3:a:condor_project:condor:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:19990519`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20000421`,
        fs:  `cpe:2.3:a:adobe:robohelp:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20000426`,
        fs:  `cpe:2.3:a:emc:solutions_enabler:6.5.883:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20000427`,
        fs:  `cpe:2.3:a:novell:zenworks_server_management:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20000815`,
        fs:  `cpe:2.3:a:winzip:winzip:10.0_build_6667:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20000825`,
        fs:  `cpe:2.3:a:adobe:golive:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20010610`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20010812`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yg1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20010922`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20020710`,
        fs:  `cpe:2.3:a:altiris:monitor_agent_for_windows:6.0.1317:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20020730`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:8.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20020803`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20020804`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20020823`,
        fs:  `cpe:2.3:a:opentext:enterprise_library_service_module:1.1.0.272:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20020913`,
        fs:  `cpe:2.3:a:netcreators:irfaq:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20021106`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20030313`,
        fs:  `cpe:2.3:a:oracle:apex:2.2.0.00.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20030409`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20030626`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20031005`,
        fs:  `cpe:2.3:a:posh_project:posh:2.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20040218`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20040808`,
        fs:  `cpe:2.3:a:lunarline:cyber_intelligence_console:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20050410`,
        fs:  `cpe:2.3:a:plone:plone:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20060517`,
        fs:  `cpe:2.3:a:webmin:usermin:1.380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20060710`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20080303`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20090417`,
        fs:  `cpe:2.3:a:mcafee:antispyware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20090522`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2980:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20100509`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20100512`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20100617`,
        fs:  `cpe:2.3:a:exim:exim:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20100621`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20100920`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20111118`,
        fs:  `cpe:2.3:o:cisco:cg-os:cg4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20140102`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20140201`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eterna:bozohttpd:20140708`,
        fs:  `cpe:2.3:o:gehealthcare:centricity_dms_firmware:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:etghosting:etg_hosting:2::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(26\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ethereal:ethereal:0.9.13a`,
        fs:  `cpe:2.3:a:symantec:backup_exec:2010_r3:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:etoolkit:love_collage_-_photo_editor:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:etopuponline:etopuponline:3.4.9::~~~android~~`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:etoshop:c2c_forward_auction_creator:2.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:etoshop:classifieds_creator:2.0`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:340.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:etoshop:dynamic_biz_website_builder_quickweb:1.0`,
        fs:  `cpe:2.3:a:altiris:software_virtualization_solution:2.1.2095:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:etouch:samepage:4.4.0.0.239::~~enterprise~~~`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.6.3.1`,
        fs:  `cpe:2.3:a:pocketmags:american_waterfowler:\@7f0801aa:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.7.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:fnc9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.7.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.7.4`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.7.4.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.7.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.7.5.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.8.0`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ettercap_project:ettercap:0.8.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.2`,
        fs:  `cpe:2.3:a:oracle:mysql_examples_and_samples:5.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.3`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.4`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.5.1`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.5.2`,
        fs:  `cpe:2.3:a:adobe:creative_suite_4_web_premium:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.6`,
        fs:  `cpe:2.3:h:cisco:nexus_5548up_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.6.2`,
        fs:  `cpe:2.3:a:datawatch:monarch_pro:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:1.6.2:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:2.0`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:2.0:-:enterprise`,
        fs:  `cpe:2.3:a:hp:photosmart_disclabel_plugin:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:2.0.0`,
        fs:  `cpe:2.3:a:acronis:true_image_echo_server:9.7.8398:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:2.0.1`,
        fs:  `cpe:2.3:a:python:python:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:2.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:2.0.2`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:2.0.3`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.0.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.1.0`,
        fs:  `cpe:2.3:a:kmart:kmart:6.2.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.1.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.1.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.2.0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.6.156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.2.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.2.2`,
        fs:  `cpe:2.3:a:roxio:dvdmax_player:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.3.0`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.3.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.589:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.3.2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.4.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.4.1`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.4.2`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security:e80.50:-:vpn_blade:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:3.4.3`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:4.0.0`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:4.0.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:4.0.2`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:4.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:4.1.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:4.1.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eucalyptus:eucalyptus:4.2.0`,
        fs:  `cpe:2.3:a:siemens:starter:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:eucalyptus:eustore:emi_0400376721`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:eucalyptus:eustore:emi_1347115203`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.4.5.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:eucalyptus:eustore:emi_2425352071`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:eucalyptus:eustore:emi_3868652036`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:evan_dandrea:usb-creator:0.2.38`,
        fs:  `cpe:2.3:a:novell:libzypp:12.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:evan_dandrea:usb-creator:0.2.38.1`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:evan_dandrea:usb-creator:0.2.38.2`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.17f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:evan_dandrea:usb-creator:0.2.40`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.8:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:evan_dandrea:usb-creator:0.2.40ubuntu2`,
        fs:  `cpe:2.3:h:brocade:silkworm_200e_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:evan_dandrea:usb-creator:0.2.47`,
        fs:  `cpe:2.3:a:pip-installer:pip:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:evan_dandrea:usb-creator:0.2.47.1`,
        fs:  `cpe:2.3:a:carahsoft:jabber_xcp:5.4.0.6098:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:evanhoe:aimtsm:3.0.6`,
        fs:  `cpe:2.3:a:nicolas_cannasse:ocaml_xml-light_library:r234:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eventsentry:eventsentry:3.1.0`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.44:174:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:everest_poker_project:everest_poker:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:49.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/h:everfocus:ecor264-16x1:-`,
        fs:  `cpe:2.3:a:microsoft:pocket_ie:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:evernote:evernote:4.5.1.5432`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)mb3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eviware:loadui:1.0.1`,
        fs:  `cpe:2.3:a:sendmail:sendmail:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eviware:soapui:2.5.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eviware:soapui:3.0.1`,
        fs:  `cpe:2.3:a:gnome:evolution:2.32.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eviware:soapui:3.5`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k_secure:14.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eviware:soapui:3.5.1`,
        fs:  `cpe:2.3:o:microsoft:windows_95:-:osr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eviware:soapui:3.6`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eviware:soapui:3.6.1`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ewon:ewon_firmware:10.0s0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ewww_image_optimizer_plugin_project:ewww_image_optimizer_plugin:2.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2010-11-07a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ewww_image_optimizer_plugin_project:ewww_image_optimizer_plugin:2.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:8.10:-:*:*:*:windows_7:*:*`,
    },
     
    {
        uri: `cpe:/a:exabot:exabot:3.0`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.2`,
        fs:  `cpe:2.3:a:isc:bind:4.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.3`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.4`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.5`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.6`,
        fs:  `cpe:2.3:a:avaya:ip_office_customer_call_reporter:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.7`,
        fs:  `cpe:2.3:a:ca:directory:r12:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.11`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.12`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.13`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.35.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.14`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.15`,
        fs:  `cpe:2.3:h:hp:j9533a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.16`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.0.17`,
        fs:  `cpe:2.3:a:logitech:vid:1.70.1044:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.1.0`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.2.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.2.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.2.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.2.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.2.5`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.50.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.2.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.0`,
        fs:  `cpe:2.3:a:symantec:i-gear:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.1`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.27:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.3`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.4`,
        fs:  `cpe:2.3:a:zope:zope:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.5`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.06:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.6`,
        fs:  `cpe:2.3:h:buffalotech:whr-1166dhp_firmware:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.7`,
        fs:  `cpe:2.3:h:d-link:di-604\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.3.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.4.0`,
        fs:  `cpe:2.3:a:gnu:gdb:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.4.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.4.2`,
        fs:  `cpe:2.3:a:synology:video_station:1.6-0840:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8a\)ew:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.5.1`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.5.2`,
        fs:  `cpe:2.3:a:ticstyle:bultmonster_registret:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.5.3`,
        fs:  `cpe:2.3:a:tm_software:tempo:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.0`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.1`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.11:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.2`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.3`,
        fs:  `cpe:2.3:h:huawei:nip2100:v100r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.4`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r2.16_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.5`,
        fs:  `cpe:2.3:a:kadu:kadu:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.8`,
        fs:  `cpe:2.3:a:mygoodhotels:booking_discount:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.6.9`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(24\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.7.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.7.1`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.7.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.644:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.7.3`,
        fs:  `cpe:2.3:a:thinkshout:mandrill:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.7.4`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.7.5`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.7.6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.0`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.1`,
        fs:  `cpe:2.3:a:intuit:quickbooks:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.2`,
        fs:  `cpe:2.3:a:sun:java_system_calendar_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.3`,
        fs:  `cpe:2.3:a:oracle:ilearning:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.5`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.6`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.7`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.8`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exactcode:exactimage:0.8.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exchangerxml:exchanger_xml_editor:3.3.1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exfo:otdr_viewer:6.13.0.38`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:2.10`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:2.11`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:2.12`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:5.6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.00`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.01`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3205a:a.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.02`,
        fs:  `cpe:2.3:a:google:chrome:13.0.749.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.03`,
        fs:  `cpe:2.3:a:gnome:update-manager-core:0.156.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.10`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.11`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.12`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.13`,
        fs:  `cpe:2.3:a:hp:smart_web_printing:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.14`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.15`,
        fs:  `cpe:2.3:o:asus:rt-ac66u_firmware:3.0.0.4.270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.16`,
        fs:  `cpe:2.3:a:google:chrome:4.0.222.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.20`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.21`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.22`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.30`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.31`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-52p-si_ls-3600-52p-si-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.32`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.33`,
        fs:  `cpe:2.3:h:xerox:workcentre_265:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.34`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.35`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:3.36`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.00`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.01`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.02`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.03`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.04`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.05`,
        fs:  `cpe:2.3:a:clearfishing:pesca_de_carpa_lite:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.10`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.11`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.12`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.14`,
        fs:  `cpe:2.3:o:ibm:aix:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.20`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6ccb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.21`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.22`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.23`,
        fs:  `cpe:2.3:a:isc:dnsco_bind:9.9.3:s1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.24`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.30`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.31`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.32`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.33`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.34`,
        fs:  `cpe:2.3:a:docker:docker:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.40`,
        fs:  `cpe:2.3:a:web-dorado:web-dorado_spider_video_player:1.4.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.41`,
        fs:  `cpe:2.3:a:digium:asterisk:11.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.42`,
        fs:  `cpe:2.3:a:hp:web_registration:50.0.123.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.43`,
        fs:  `cpe:2.3:a:juniper:vpn:1.1.0.3489:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.44`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.8.0.577:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.50`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.51`,
        fs:  `cpe:2.3:a:docker:docker:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.52`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.53`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.54`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.60`,
        fs:  `cpe:2.3:a:oracle:e-business_intelligence:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.61`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.62`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17\)a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.63`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.64`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.65`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:6.7:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.66`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.67`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.12:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.68`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.69`,
        fs:  `cpe:2.3:a:jruby:jruby:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.70`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.71`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.72`,
        fs:  `cpe:2.3:a:adobe:media_encoder_cs4_importer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.73`,
        fs:  `cpe:2.3:a:apache:hadoop:0.20.205.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.74`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.75`,
        fs:  `cpe:2.3:a:c-icap_project:c-icap:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.76`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110608:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.77`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.80`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.80.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.82`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:exim:exim:4.82.1`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exiv2:exiv2:0.24`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exiv2:exiv2:0.26`,
        fs:  `cpe:2.3:a:silanis:approveit_desktop:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exoticpetnetwork:tortoise_forum:3.5.16::~~~android~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expeditersonline:expeditersonline.com_forum:3.7.13::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:0.97.0`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:0.98.0`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:0.99.0:beta1`,
        fs:  `cpe:2.3:a:altiris:software_virtualization_solution_documentation:2.1.1009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.0.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.0.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.17:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.0.2`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.0.3`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.0.4:p3`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:17.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.0.5:p1`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.0.6:p2`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.0.8:p2`,
        fs:  `cpe:2.3:a:oracle:database_server:11.1.0.7.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.1.0:alpha`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.1.4:p11`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.2.0:p5`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.2.1`,
        fs:  `cpe:2.3:o:juniper:junose:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.2.2:p2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p235_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.2.3:p14`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.0:p4`,
        fs:  `cpe:2.3:a:commerceguys:commerce_reorder:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.1:p4`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.2`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.2:p2`,
        fs:  `cpe:2.3:a:apache:hadoop:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.3`,
        fs:  `cpe:2.3:a:google:chrome:17.0.946.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.3:p1`,
        fs:  `cpe:2.3:a:openstack:diablo:2011.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.4`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.790.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.4:p1`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.5:p2`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.3:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.7`,
        fs:  `cpe:2.3:a:mobfox:madserve:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.3.8`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:r17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.4.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exponentcms:exponent_cms:2.4.0:p1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:express:express:2.5.3::~~~android~~`,
        fs:  `cpe:2.3:a:hitachi:ibm_xl_c\/c\&#43;\&#43;_v7_for_aix_\&amp;_hitachi_developer\&#39;s_kit_for_java:01-00:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressdigital:darkroom_professional_edition:8.91.1678`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:3.10.5`,
        fs:  `cpe:2.3:a:color:icclib:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.0.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.9:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.1.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.1.1`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.1t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.1.2`,
        fs:  `cpe:2.3:a:goforandroid:go_fbwidget:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.2.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.3.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.3.1`,
        fs:  `cpe:2.3:a:emc:replication_manager:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.3.2`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.4.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.4.1`,
        fs:  `cpe:2.3:a:mozilla:camino:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.4.2`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.4.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.4.4`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.03.537:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:expressjs:express:4.4.5`,
        fs:  `cpe:2.3:a:cognos:financial_statement_reporting:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:exsoul-browser:exsoul_web_browser:3.3.3::~~~android~~`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.0.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.0.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.0.3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(15\)bc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.1.0`,
        fs:  `cpe:2.3:a:plone:plone:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.1.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.8.1.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.1.2`,
        fs:  `cpe:2.3:a:emulex:fibre_channel_hbanyware:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.1.3`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cm6030_mfp:ce664a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.1.4`,
        fs:  `cpe:2.3:a:debian:apt:0.7.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.1.5`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.2.0`,
        fs:  `cpe:2.3:a:ibm:sterling_b2b_integrator:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.2.1`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.2.2`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extended_module_player_project:extended_module_player:4.2.3`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extendsim:extendsim:6_golden_master`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.7.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extendsim:extendsim:7.0.4`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_standalone_agent:4.3.0.292238:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extensoft:mfc_runtime_files:1.0.0`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extplorer:com_extplorer:2.0.0:rc2`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extplorer:com_extplorer:2.1.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.3:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extplorer:com_extplorer:2.1.0:rc4`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.12:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extplorer:com_extplorer:2.1.0:rc5`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter:4.2.1.327369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extplorer:extplorer:2.1.0:rc3`,
        fs:  `cpe:2.3:h:cisco:ids:4.1\(5b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extplorer:extplorer:2.1.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extplorer:extplorer:2.1.6`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:alpine:-`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:alpine:6.2.2_68`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:alpine:7.2.0`,
        fs:  `cpe:2.3:a:microsoft:windows_media_format_runtime:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:blackdiamond_10808:-`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:blackdiamond_8800:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:extremenetworks:exos:-`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:extremenetworks:extremeware_xos:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:extremenetworks:extremeware_xos:10.0`,
        fs:  `cpe:2.3:a:citrix:xenapp_commands:6.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:extremenetworks:extremeware_xos:11.0.2.3`,
        fs:  `cpe:2.3:a:emc:networker:7.5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:extremenetworks:extremeware_xos:11.1`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:extremenetworks:extremeware_xos:11.1.3.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:msm64:-`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:msm64:7.2.0`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:summit:-`,
        fs:  `cpe:2.3:a:wernerd:zrtpcpp:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:summit:6.2.2_68`,
        fs:  `cpe:2.3:a:binarymoon:timthumb:2.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:extremenetworks:summit:7.2.0`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.20.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:extron:extroncorlib:1.0.26`,
        fs:  `cpe:2.3:a:hp:hpztlbxfx:4.9.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.0.3.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.0.4.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.5.1.0`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.11-60.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.5.4.0`,
        fs:  `cpe:2.3:a:die-netzmacher:browser:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.5.5.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.5.26.0`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.5.27.0`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.6.0.0`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.6.9.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:2.6.12.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp2:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.1.2`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.1.9`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.2.2`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.3.0`,
        fs:  `cpe:2.3:a:salome-platform:salome:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.4.23`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp1:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.4.26`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.4.29`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.4.34`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:eye:eye-fi_helper:3.4.35`,
        fs:  `cpe:2.3:a:yahoo:music_jukebox:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:eyexam:eyexam:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:gzip:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.0`,
        fs:  `cpe:2.3:a:jease:jease:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.1`,
        fs:  `cpe:2.3:h:d-link:dcs-933l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.4`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.5`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.6`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.7`,
        fs:  `cpe:2.3:a:git-scm:git:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.8`,
        fs:  `cpe:2.3:a:php:php:5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.9`,
        fs:  `cpe:2.3:a:cybozu:cybozu_live:2.0.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.10`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.11`,
        fs:  `cpe:2.3:a:cisco:cius_software:9.2\(1\)sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:3.7.12`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:4.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:4.1.4`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.2.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:4.2`,
        fs:  `cpe:2.3:a:vector:ultra_mini_httpd:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:4.3`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:4.4`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:4.5`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ez:ez_publish:4.6`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ezbsystems:ultraiso:9.3.6.2750`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.24:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-prot:f-prot_antivirus:4.6.2.117`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.009.20071:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:anti-virus:-:-:~-~~mac_os_x~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:anti-virus:9.00::~~~citrix_servers~~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:anti-virus:9.00::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:apple:cups:1.1.19:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:anti-virus:9.00::~~~windows_server~~`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.0:cf03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:anti-virus:9.10::~~~exchange_server~~`,
        fs:  `cpe:2.3:h:xerox:phaser_6130n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:email_and_server_security:9.20`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:psb_workstation_security:-:-:~-~~mac_os_x~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:safe_anywhere:-:-:~-~~mac_os_x~~`,
        fs:  `cpe:2.3:o:cisco:virtualization_experience_client_6000_series_firmware:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:secure_messaging_secure_gateway:7.5.0`,
        fs:  `cpe:2.3:a:splunk:splunk:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:server_security:9.20`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.51:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f-secure:ssh_client:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:3_dns:-`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:arx:6.0.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:arx:6.1.0`,
        fs:  `cpe:2.3:a:aloaha:aloaha_pdf_suite_free:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:arx:6.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:arx:6.2.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.314:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:arx:6.3.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc124b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:arx:6.4.0`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.71:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:arx_data_manager:3.0.0`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-4.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:arx_data_manager:3.1.0`,
        fs:  `cpe:2.3:a:hp:keyview:10.24.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:-`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip:-`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:2.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp2:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.0`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.4`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.5`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.5.6`,
        fs:  `cpe:2.3:a:apache:apache_test:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.5.9`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.5.10`,
        fs:  `cpe:2.3:h:huawei:quidway_s7700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.5.11`,
        fs:  `cpe:2.3:a:autodesk:material_library_base_image_library_2011:2.0.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.5.12`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp4:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.6`,
        fs:  `cpe:2.3:h:hp:0235a38l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:4.6.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:9.0`,
        fs:  `cpe:2.3:a:dell:powervault_modular_disk_storage_manager:3.35.x6.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:9.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p199:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:9.0.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:9.0.3`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1y\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:9.0.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:9.0.5`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:9.1`,
        fs:  `cpe:2.3:a:apache:cloudstack:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip:9.4.3`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.42.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_1000:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_11050:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_1500:-`,
        fs:  `cpe:2.3:a:koha:koha:3.16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_1600:-`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_2400:-`,
        fs:  `cpe:2.3:a:adobe:community_help:3.4.980:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_3400:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_3410:-`,
        fs:  `cpe:2.3:a:christian_kindahl:tugzip:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_3600:-`,
        fs:  `cpe:2.3:o:f5:tmos:9.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_3900:-`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_4100:-`,
        fs:  `cpe:2.3:o:trustix:secure_linux:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_5100:-`,
        fs:  `cpe:2.3:o:bluecoat:sgos:5.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_5110:-`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_6400:-`,
        fs:  `cpe:2.3:a:microsoft:project:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_6800:-`,
        fs:  `cpe:2.3:a:ca:etrust_admin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_6900:-`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_8400:-`,
        fs:  `cpe:2.3:a:suse:webyast:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_8800:-`,
        fs:  `cpe:2.3:a:samba:samba:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_8900:-`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1047:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_8950:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:10.1.0`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd7.d4xxxt5f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_access_policy_manager:10.1.0::~~~~~standalone`,
        fs:  `cpe:2.3:h:hp:0235a20l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:10.2.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:10.2.1`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:10.2.2`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.6:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:10.2.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:10.2.4`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_access_policy_manager:10.2.4::~~~~~standalone`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.0.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_access_policy_manager:11.0.0::~~~~~standalone`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_sametime:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.1.0`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_access_policy_manager:11.1.0::~~~~~standalone`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.2.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_access_policy_manager:11.2.0::~~~~~standalone`,
        fs:  `cpe:2.3:a:healthways:well-being_connect_mobile:2.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.2.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_access_policy_manager:11.2.1::~~~~~standalone`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.3.0`,
        fs:  `cpe:2.3:a:flatnux:flatnux:2011-08-09-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_access_policy_manager:11.3.0::~~~~~standalone`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.4.0`,
        fs:  `cpe:2.3:a:keepass:keepass:0.96:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.4.1`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.5.0`,
        fs:  `cpe:2.3:a:ibm:secureway_firewall:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.5.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.5.2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.5.3`,
        fs:  `cpe:2.3:a:oracle:jre:8.0:update_121:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.5.4`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.3002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:11.6.0`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:12.0.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_access_policy_manager:12.1.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.2.1`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.1.4.6324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.4.0`,
        fs:  `cpe:2.3:a:microsoft:class_package_export_tool:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.4.1`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.5.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.5.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.5.2`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:9.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.5.3`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.5.4`,
        fs:  `cpe:2.3:a:adobe:acrobat:4.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:11.6.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:12.0.0`,
        fs:  `cpe:2.3:h:huawei:echo_life:hg8247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_advanced_firewall_manager:12.1.1`,
        fs:  `cpe:2.3:a:bea:aqualogic_service_bus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.1.0`,
        fs:  `cpe:2.3:h:cisco:5508_wireless_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.2.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.2.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.3.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.4.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.4.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.5.0`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.5.1`,
        fs:  `cpe:2.3:a:businessobjects:xcelsius:12.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.5.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p226:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.5.3`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.5.4`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:11.6.0`,
        fs:  `cpe:2.3:a:teradata:statistics_wizard:13.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:12.0.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1033:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:12.1.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_analytics:12.1.1`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:11.4.0`,
        fs:  `cpe:2.3:a:atlassian:jira:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:11.4.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.434.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:11.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(10\)bc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:11.5.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:11.5.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:11.5.3`,
        fs:  `cpe:2.3:a:mnt-tech:wp-facethumb:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:11.5.4`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:11.6.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.1.32:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:12.0.0`,
        fs:  `cpe:2.3:a:videowhisper:live_streaming_integration_plugin:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_acceleration_manager:12.1.1`,
        fs:  `cpe:2.3:a:kaylon:powermarks:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:10.1.0`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:10.2.0`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:10.2.1`,
        fs:  `cpe:2.3:a:openstack:swift:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:10.2.2`,
        fs:  `cpe:2.3:a:veritas:netbackup:4.5.0:mp2:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:10.2.3`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:10.2.4`,
        fs:  `cpe:2.3:a:instantphp:jobs_pro:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.0.0`,
        fs:  `cpe:2.3:a:alexis_wilke:protected_node:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.1.0`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_miis:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.2.0`,
        fs:  `cpe:2.3:a:canon:dv_network_software:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.2.1`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.3.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.4.0`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.4.1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.5.0`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.5.1`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.5.2`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sru:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.5.3`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.3.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.5.4`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.4.2:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:11.6.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5820x-28c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:12.0.0`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_application_security_manager:12.1.1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_configuration_utility:10.0.0`,
        fs:  `cpe:2.3:h:lexmark:t522_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_configuration_utility:10.2.4`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_configuration_utility:11.0.0`,
        fs:  `cpe:2.3:o:hp:ignite-ux:c.6.2.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_configuration_utility:11.2.1`,
        fs:  `cpe:2.3:h:kyocera:xw320kr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_domain_name_system:12.0.0`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_domain_name_system:12.1.0`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:9.0.0:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_domain_name_system:12.1.1`,
        fs:  `cpe:2.3:a:labsmedia:clickheat:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:10.1.0`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:10.2.0`,
        fs:  `cpe:2.3:a:hp:virtual_connect_enterprise_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:10.2.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:10.2.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:10.2.3`,
        fs:  `cpe:2.3:a:onesolutionapps:aaaa_discount_bail:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:10.2.4`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:11.0.0`,
        fs:  `cpe:2.3:a:solarwinds:network_configuration_manager:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:11.1.0`,
        fs:  `cpe:2.3:a:dell:controlvault_host_components_installer:1.7.450.290:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:11.2.0`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:11.2.1`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:11.3.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_edge_gateway:11.5.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_enterprise_manager:3.0.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.28:gamma:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_enterprise_manager:3.1.0`,
        fs:  `cpe:2.3:a:apple:quicktime:7.3.1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_enterprise_manager:3.1.1`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:10.1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.19:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:10.2.0`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:*:pl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:10.2.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:10.2.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0:tiv-ncreporter-if0002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:10.2.3`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:10.2.4`,
        fs:  `cpe:2.3:a:connectiva:linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.0.0`,
        fs:  `cpe:2.3:a:ubercart_currency_conversion_project:ubercart_currency_conversion:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.1.0`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.20.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.2.0`,
        fs:  `cpe:2.3:a:keepass:keepass:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.2.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.3.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.4.0`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.4.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.5.0`,
        fs:  `cpe:2.3:a:pingidentity:pingfederate:6.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.5.1`,
        fs:  `cpe:2.3:a:condor_project:condor:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.5.2`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.5.3`,
        fs:  `cpe:2.3:a:phoenixcpm:phoenix_project_manager:2.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.5.4`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.3.4:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_global_traffic_manager:11.6.0`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.4.0:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:10.1.0`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:10.2.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:10.2.1`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:10.2.2`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:10.2.3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:10.2.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.0.0`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.1.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.2.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.6:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.2.1`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.3.0`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.4.0`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.4.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.5.0`,
        fs:  `cpe:2.3:a:synology:video_station:1.2-0443:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.5.1`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.5.2`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.5.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.5.4`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:11.6.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:12.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_link_controller:12.1.1`,
        fs:  `cpe:2.3:a:dir2web:dir2web:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:10.0.0`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.8b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:10.0.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:rc.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:10.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:10.2.0`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:10.2.1`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta__dpr2325:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:10.2.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:10.2.3`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.6.0:sr1:ja:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:10.2.4`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.0.0`,
        fs:  `cpe:2.3:a:bluecoat:director:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.1.0`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.2.0`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.2.1`,
        fs:  `cpe:2.3:a:roxio:creator_bdav_plugin:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.3.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.4.0`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.4.1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.5.0`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.5.1`,
        fs:  `cpe:2.3:a:bareftp:bareftp:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.5.2`,
        fs:  `cpe:2.3:a:apache:ofbiz:12.04.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.5.3`,
        fs:  `cpe:2.3:a:busybox:busybox:1.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.5.4`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_xi_.net_server:11.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:11.6.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.879.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:12.0.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_local_traffic_manager:12.1.1`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_tx1300_47:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.3.0`,
        fs:  `cpe:2.3:a:roxio:media_manager:9.4.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.4.0`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.4.1`,
        fs:  `cpe:2.3:a:cts_projects\&amp;software:classad:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.5.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.5.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.5.2`,
        fs:  `cpe:2.3:h:d-link:dcs-930l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.5.3`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.5.4`,
        fs:  `cpe:2.3:a:mcafee:superscan:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:11.6.0`,
        fs:  `cpe:2.3:a:csounds:csound:5.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:12.0.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_policy_enforcement_manager:12.1.1`,
        fs:  `cpe:2.3:a:nq:vault-hide_sms_pics_\&amp;_videos:5.0.14.22:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:10.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:10.2.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:10.2.1`,
        fs:  `cpe:2.3:h:siemens:scalance_x-200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:10.2.2`,
        fs:  `cpe:2.3:a:ibm:sterling_file_gateway:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:10.2.3`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:10.2.4`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:11.0.0`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:11.1.0`,
        fs:  `cpe:2.3:a:magento:magento:1.9.2.2:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:11.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:11.2.1`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:11.3.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:11.4.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:big-ip_protocol_security_manager:11.4.1`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_protocol_security_module:11.2.0`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_protocol_security_module:11.2.1`,
        fs:  `cpe:2.3:a:apple:safari:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_protocol_security_module:11.3.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:04-01:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_protocol_security_module:11.4.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.18.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_protocol_security_module:11.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:10.1.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:10.2.0`,
        fs:  `cpe:2.3:a:apache:tomcat_jk_web_server_connector:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:10.2.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:10.2.2`,
        fs:  `cpe:2.3:a:intel:network_connections:13.0.44.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:10.2.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:10.2.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:11.0.0`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.7:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:11.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.4:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:11.2.0`,
        fs:  `cpe:2.3:a:isc:bind:8.2.2:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:11.2.1`,
        fs:  `cpe:2.3:h:polycom:viewstation_sp_384:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_wan_optimization_manager:11.3.0`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:10.1.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:10.2.0`,
        fs:  `cpe:2.3:a:ibm:aix_enetwork_firewall:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:10.2.1`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.5:rev34942:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:10.2.2`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:10.2.3`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:*:x64-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:10.2.4`,
        fs:  `cpe:2.3:a:die-netzmacher:browser:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:11.0.0`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:11.1.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:11.2.0`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:11.2.1`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_webaccelerator:11.3.0`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_websafe:11.5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_websafe:11.5.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1307.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_websafe:11.5.2`,
        fs:  `cpe:2.3:a:isc:bind:9.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_websafe:11.5.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-ip_websafe:11.5.4`,
        fs:  `cpe:2.3:a:opnet:model_library:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_adc:4.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_application_delivery_controller:4.5.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_centralized_management:4.6.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_cloud:4.0.0`,
        fs:  `cpe:2.3:a:n-i-agroinformatics:soy_cms:1.4.0:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_cloud:4.1.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_cloud:4.2.0`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_cloud:4.3.0`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_cloud:4.4.0`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.14:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_cloud:4.5.0`,
        fs:  `cpe:2.3:a:keepass:keepass:0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_cloud_and_orchestration:1.0.0`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_device:4.2.0`,
        fs:  `cpe:2.3:a:bioinformatics:ordersys:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_device:4.3.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_device:4.4.0`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.05.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_device:4.5.0`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_security:4.0.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.16-isaacs-manual:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_security:4.1.0`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_security:4.2.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_security:4.3.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_security:4.4.0`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_299_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:big-iq_security:4.5.0`,
        fs:  `cpe:2.3:a:sun:openoffice.org:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:edge_fx:-`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.5:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:enterprise_manager:2.1.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:enterprise_manager:2.2.0`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.6:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:enterprise_manager:2.3.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:enterprise_manager:3.0.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:enterprise_manager:3.1.1`,
        fs:  `cpe:2.3:a:apple:webkit:312.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:firepass:6.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:firepass:6.0.1`,
        fs:  `cpe:2.3:a:cisco:ids_device_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:firepass:6.0.2`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:firepass:6.0.3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:firepass:6.1.0`,
        fs:  `cpe:2.3:h:hp:laserjet_2410:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:firepass:7.0.0`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.0.596:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_1000:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1305.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_1000:5.5`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_1200:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.09.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.1`,
        fs:  `cpe:2.3:a:apache:poi:3.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.61:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.4`,
        fs:  `cpe:2.3:a:hp:xp_p9000_device_manager:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.6`,
        fs:  `cpe:2.3:a:baidu:spark_browser:26.5.9999.3511:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.7`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.8`,
        fs:  `cpe:2.3:a:citadel:ux:6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.4.9`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.5.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.5.1`,
        fs:  `cpe:2.3:a:sympa:sympa:0.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:5.5.2`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:6.0`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4100:6.0.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:firepass_4300:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.00:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:global-site:-`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator_instrumentation_service:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:icontrol_service_manager:-`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:1.6.0`,
        fs:  `cpe:2.3:a:irislink:i.r.i.s._ocr_engine:12.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:1.6.1`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:1.6.2`,
        fs:  `cpe:2.3:o:apple:watchos:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:1.6.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.304:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:1.6.4`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.2.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.2.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.2.2`,
        fs:  `cpe:2.3:a:juniper:junos_space:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.2.3`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.0.2.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.2.4`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.2.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.2.6`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.2.7`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.3.0`,
        fs:  `cpe:2.3:a:sagecrm:sagecrm:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.3.1`,
        fs:  `cpe:2.3:a:magzter:macau_business:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.3.2`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.3.3`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:6.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.4.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.4.1`,
        fs:  `cpe:2.3:a:atlassian:jira:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.4.2`,
        fs:  `cpe:2.3:h:supermicro:x9drff-itg\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:linerate:2.5.0`,
        fs:  `cpe:2.3:a:gnu:a2ps:4.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:-`,
        fs:  `cpe:2.3:a:gnu:glibc:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:2.0`,
        fs:  `cpe:2.3:a:islonline:isl_desktop_plugin:1.4.7:-:-:*:windows:isl_light:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.0`,
        fs:  `cpe:2.3:a:netapp:data_ontap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.2`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.5:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.3`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.4`,
        fs:  `cpe:2.3:a:checkpoint:management_server:r75.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.5`,
        fs:  `cpe:2.3:a:google:chrome:14.0.827.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.5.6`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.5.9`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.5.10`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.5.11`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.14.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.5.12`,
        fs:  `cpe:2.3:a:debian:mime-support:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.6`,
        fs:  `cpe:2.3:a:altiris:svs_task_server_plugin_language_pack:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:4.6.2`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.0`,
        fs:  `cpe:2.3:a:barracudanetworks:yosemite_server_backup:8.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.0.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch_1800-24g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.0.2`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.0.3`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.0.4`,
        fs:  `cpe:2.3:a:isc:bind:9.9.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.0.5`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.1`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.1.1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.8:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.1.2`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.1.3`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.2`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.2.2`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.2.4`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.2.5`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.3`,
        fs:  `cpe:2.3:o:vmware:esx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.3.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4`,
        fs:  `cpe:2.3:a:hp:newcopy_cda:70.0.231.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4.1`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4.2`,
        fs:  `cpe:2.3:a:vmware:virtual_infrastructure_client:2.0.2.62345:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4.4`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4.5`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4.6`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4.7`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.4.8`,
        fs:  `cpe:2.3:a:quest:spotlight_on_oracle:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.6.0`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_agent:10.0.13545:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:9.6.1`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:10.0.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.152.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:10.0.1`,
        fs:  `cpe:2.3:a:apache:struts:2.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:10.1.0`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:f5:tmos:10.2.0`,
        fs:  `cpe:2.3:a:cisco:diagnostic_anyconnect_reporting_tool:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:viprion_performance_blade_100:-`,
        fs:  `cpe:2.3:a:mcafee:saas_endpoint_protection:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:f5:viprion_performance_blade_200:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:vpn_client_for_windows:55.2.60918.1441`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:f5:vpn_client_for_windows:60.2007.1001.2146`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faailkhair:faailkhair:1::~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:gold:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fabasoft:fabasoft_cloud:3.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fabien_coelho:mod_macro:1.1.1`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fabien_coelho:mod_macro:1.1.2`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fabricio_zuardi:xspf_player_plugin:0.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:face_fun_photo_collage_maker_project:face_fun_photo_collage_maker_2:1.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:debian:debmake:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:al_jazeera:6::~~~android~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:arabic_troll_football:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:barcode_scanner:2.3.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:best_beginning:2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:bilingual_magic_ball:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:global_order_promising:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:bilingual_magic_ball_relajo:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:bite_it%21:1.1.8::~~~android~~`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:face_fun_photo_collage_maker_2:1.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.195.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:facebook_platform:1.0`,
        fs:  `cpe:2.3:a:caucho:resin:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:fire_equipments_screen_lock:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:hiphop_virtual_machine:2.4.1`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:hiphop_virtual_machine:3.0.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.11.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:hiphop_virtual_machine:3.2.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:hiphop_virtual_machine:3.4.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:hunting_trophy_whitetails:0.75.13441.88885::~~~android~~`,
        fs:  `cpe:2.3:a:altiris:deployment_web_console:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:instaroid_-_instagram_viewer:1.2.1::~~~android~~`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2034:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:kazakhstan_radio:2.5::~~~android~~`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:logosquest_-_beginnings:1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:macedonia_hacienda_hotel:1::~~~android~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:325.00:-:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:news_revolution_-_bahrain:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:lotus_expeditor:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:pakan_ken_tube:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.2:beta1:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:radio_de_la_cato:2::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:savage_nation_mobile_web:0.57.13354.63350::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:office:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:street_walker:0.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:giantrobot:zipcart:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:suriname_radio:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.11:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook:zhang_zhijun_taiwan_visit_2014-06-25:1::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook_album_fetcher_project:facebook_album_fetcher:7.x-1.x-dev::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook_like_box_project:facebook_like_box:2.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facebook_profits_on_steroids_project:facebook_profits_on_steroids:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:liquidthreads_project:liquidthreads:2.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facsys:facsys:1.0.0`,
        fs:  `cpe:2.3:a:isc:bind:9.2.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facsys:facsys_desktop_client:5.0.2.0`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:facsys:facsys_desktop_client:5.1.0.3`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:3.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:facsys:facsys_desktop_client:5.1.406.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:factbites:factbot:1.09`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.1.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:06-70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.1.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.1.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.3.0`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.3.1`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.4.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.4.1`,
        fs:  `cpe:2.3:a:microsoft:excel:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.5.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.221:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.5.1`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.11.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.5.2`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_web_standard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.5.3`,
        fs:  `cpe:2.3:a:ericpol:ewus_mobile:1.4.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.5.4`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.5.5`,
        fs:  `cpe:2.3:o:xen:xen:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.6.0`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.6.1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.8-177:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.0`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(2r\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.4`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.5`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.6`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.7`,
        fs:  `cpe:2.3:o:hp:tru64:5.1a_pk2_bl2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.8`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:5.2.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.7.9`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.0`,
        fs:  `cpe:2.3:a:samba:samba:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.2`,
        fs:  `cpe:2.3:a:mcafee:security_center:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.3`,
        fs:  `cpe:2.3:a:isc:bind:9.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.4`,
        fs:  `cpe:2.3:a:myfone:myfone_shopping:2.1.01.00.040:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.5`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.6`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.7`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.2.3.65026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.7.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.8`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.10`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.1.5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fail2ban:fail2ban:0.8.11`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faircom:c-treeace:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.6.7`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.6.8`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.6.10`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.6.11`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.6.13`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.6.15`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.7.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.7.2`,
        fs:  `cpe:2.3:h:cabletron:smartswitch_router_8000_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:3.7.3`,
        fs:  `cpe:2.3:a:usebb:usebb:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.0`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.0:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.4`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.9`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.10`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.34:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.13`,
        fs:  `cpe:2.3:a:microsoft:works_spreadsheet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.17`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.18`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.19`,
        fs:  `cpe:2.3:a:openstack:folsom:2012.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.19.1`,
        fs:  `cpe:2.3:o:juniper:junos:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.19.2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.19.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_1t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.19.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.19.7`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.19.8`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.1.19.9`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2004:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint:4.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:falconsc:wisepoint_authenticator:4.1.19.22`,
        fs:  `cpe:2.3:a:microsoft:windows_movie_maker:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fallacystudios:marijuana_handbook_lite_-_weed:3.2::~~~android~~`,
        fs:  `cpe:2.3:o:xen:xen:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fallacystudios:stoner%27s_handbook_l-_bud_guide:7.2::~~~android~~`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:famatech:advanced_port_scanner:-`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:10.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:famatech:advanced_port_scanner:1.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:familyconnect_project:familyconnect:1.5.0::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fancybox_project:fancybox:3.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.26.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fancyfon:famoc:3.16.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fanshawec:fol:3.0.729.1459::~~~android~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faq-frequenty_asked_questions_project:faq-frequently_asked_questions:1.2.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:farm_frenzy_gold_project:farm_frenzy_gold:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:bilingual_magic_ball_project:bilingual_magic_ball:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:faro:faro_ls:1.1.6.58`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:-:-:std`,
        fs:  `cpe:2.3:h:cisco:telepresence_ex60:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.30.020.1180:-:std`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.30.020.1181:-:std`,
        fs:  `cpe:2.3:a:dell:lasso:3.4.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.40.020.1238:-:std`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.40.020.1248:-:std`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.50.020.1288:-:std`,
        fs:  `cpe:2.3:a:google:chrome:10.0.638.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.50.020.1299:-:std`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.60.020.1347:-:std`,
        fs:  `cpe:2.3:a:schneider-electric:modbus_serial_driver:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.70.020.1372:-:std`,
        fs:  `cpe:2.3:a:invensys:wonderware_information_server:4.0:sp1:-:-:portal:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.70.020.1378:-:std`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.70.020.1425:-:std`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.70.020.1426:-:std`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.2.1:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:5.70.020.1453:-:std`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.128.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.00.020.1523:-:std`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.10.020.1616:-:std`,
        fs:  `cpe:2.3:a:php:php:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.20.020.1692:-:std`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.30.020.1818:-:std`,
        fs:  `cpe:2.3:a:sagecrm:sagecrm:7.3:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.30.020.1819:-:std`,
        fs:  `cpe:2.3:a:apple:safari:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.30.020.1829:-:std`,
        fs:  `cpe:2.3:a:horoscopesanddreams:horoscopes_and_dreams:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.30.020.1871:-:std`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.30.020.1875:-:std`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.30.020.1917:-:std`,
        fs:  `cpe:2.3:a:apache:wink:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.30.020.1926:-:std`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.30.020.1931:-:std`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.40.020.1968:-:std`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.41.020.1973:-:std`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.51.020.2725:-:std`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.0:a:core:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.52.020.2735:-:std`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.53.020.2763:-:std`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.60.020.2771:-:std`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.61.020.2822:-:std`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:6.62.020.3058:-:std`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.2:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:7.00.020.3172:-:std`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:7.10.020.3176:-:std`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:7.20.020.3398:-:std`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:7.21.020.3447:-:std`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.580:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:7.22.020.3453:-:std`,
        fs:  `cpe:2.3:a:canonical:accountsservice:0.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faronics:deep_freeze:7.30.020.3852:-:std`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:6.x-2.0`,
        fs:  `cpe:2.3:a:ibm:flex_system_manager:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:6.x-2.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.7:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:6.x-2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.40.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:6.x-2.3`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:6.x-2.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:6.x-2.5`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:7.x-2.0`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:7.x-2.1`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:7.x-2.2`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:7.x-2.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fast_permissions_administration_project:fast_permission_administration:7.x-2.x:dev`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fastappz:corvette_museum:1.399::~~~android~~`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.53:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fastcgi:fcgi:2.4.0`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fasterxml:jackson:2.7.3`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fastin_project:fastin:1::~~~android~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2:update30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faststone_soft:faststone_image_viewer:4.6`,
        fs:  `cpe:2.3:a:symantec:veritas_update:1.0.4691:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fasttoggle_project:fasttoggle:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fasttoggle_project:fasttoggle:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.9.6`,
        fs:  `cpe:2.3:a:openx:openx:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.9.7`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.9.8`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.9.9`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.9.10`,
        fs:  `cpe:2.3:a:visiwave:site_survey:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.10.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.11.0`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:2.3:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.11.1`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.11.2`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.12.0`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.12.1`,
        fs:  `cpe:2.3:a:moodle:moodle:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fatfreecrm:fat_free_crm:0.13.5`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faxtalk:faxtalk_communicator:4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:faz:faz.net:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:h:hp:jg812aae:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fbpromotions_project:fbpromotions:1.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fca:uconnect:15.26.1`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.3.02039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featured_comments_plugin_project:featured_comments:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.1`,
        fs:  `cpe:2.3:a:gameloft:ice_age_village:2.8.0:m:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.2`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.3`,
        fs:  `cpe:2.3:a:google:api_search:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.4`,
        fs:  `cpe:2.3:a:intel:network_connections:14.6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.5`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.3.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.6`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.3.5:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.7`,
        fs:  `cpe:2.3:o:juniper:junos:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.8`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.9`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.0`,
        fs:  `cpe:2.3:h:linksys:befvp41:1.39.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.2`,
        fs:  `cpe:2.3:a:python:python:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.3`,
        fs:  `cpe:2.3:a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.4`,
        fs:  `cpe:2.3:a:google:chrome:17.0.954.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.5`,
        fs:  `cpe:2.3:a:redhat:satellite:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.6`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_agent_framework:3.3.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.0`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.1`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc2203:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.2`,
        fs:  `cpe:2.3:a:goforandroid:go_qqweibowidget:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.4`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.6`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.36:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.7`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.8`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:7.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.2`,
        fs:  `cpe:2.3:a:canonical:libpam-modules:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.3`,
        fs:  `cpe:2.3:a:synck_graphica:mailform_pro_cgi:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.4`,
        fs:  `cpe:2.3:a:pgp:desktop_for_mac:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.5`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.6`,
        fs:  `cpe:2.3:a:google:chrome:5.0.366.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.7`,
        fs:  `cpe:2.3:a:tibco:activematrix_management_agent:1.1.0:*:*:*:*:websphere:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.6.0`,
        fs:  `cpe:2.3:a:nortel:net_direct_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.6.1`,
        fs:  `cpe:2.3:a:datawatch:monarch:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:featurific_for_wordpress_project:featurific-for-wordpress:1.6.2`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedex:fxrscadv:10.5`,
        fs:  `cpe:2.3:a:digia:qt:4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedex:ship_manager_server:10.5.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.425:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedex:ship_manager_server:10.63.24`,
        fs:  `cpe:2.3:a:gnu:automake:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedora:pacemaker_configuration_system:0.9.137`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.1`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.3`,
        fs:  `cpe:2.3:a:egroupware:egroupware:1.8.001.20110805:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.5`,
        fs:  `cpe:2.3:a:mcafee:saas_endpoint_protection:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.5:rc1`,
        fs:  `cpe:2.3:a:siemens:simatic_prosave:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.5:rc2`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.5:rc3`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.5:rc4`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6:a2`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6:a3`,
        fs:  `cpe:2.3:a:digia:qt:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6:a4`,
        fs:  `cpe:2.3:o:tp-link:tl-wrd841nd_\(10.0\)_firmware:150104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6:rc1`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6:rc2`,
        fs:  `cpe:2.3:h:d-link:dcs-932l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6:rc3`,
        fs:  `cpe:2.3:a:90meter:cac_smartcard_manager-90:1.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6:rc6`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6:rc7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.6.1`,
        fs:  `cpe:2.3:a:ca:api_gateway:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.7:alpha3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.7.5`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.8:alpha1`,
        fs:  `cpe:2.3:a:ibm:jazz_reporting_service:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.8:alpha2`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.8:alpha3`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.8:rc1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.8:rc2`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0084:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.8.1`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.8.2`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.8.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xk2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.9.9`,
        fs:  `cpe:2.3:a:sun:web-based_enterprise_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.10`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.0.0.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.10:alpha8`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2007:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.10:rc1`,
        fs:  `cpe:2.3:o:rockwellautomation:rslogix_emulate_5000_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.10.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.10.3`,
        fs:  `cpe:2.3:a:jenkins:git:3.4.0:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.10.4`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.10.11`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.5`,
        fs:  `cpe:2.3:a:netscape:communicator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.8`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.4:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.9`,
        fs:  `cpe:2.3:a:php:php:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.10`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.11`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.12`,
        fs:  `cpe:2.3:a:lotum:paint-for-friends:1.5.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.13`,
        fs:  `cpe:2.3:a:apache:activemq:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.14`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.15`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.17`,
        fs:  `cpe:2.3:a:pocketmags:pc_advisor:\@7f08017a:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.19`,
        fs:  `cpe:2.3:h:emerson:avocent_mpu4032:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.20`,
        fs:  `cpe:2.3:a:apache:solr:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.21`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.22`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.23`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.115:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.25`,
        fs:  `cpe:2.3:a:wpslideshow:image_news_slider:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.2.11.26`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.0.2`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.0.3`,
        fs:  `cpe:2.3:a:monotone:monotone:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.0.4`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.0.5`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.0.6`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.0.7`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:5.1.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.0.8`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.246:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.1`,
        fs:  `cpe:2.3:a:symantec:client_security:3.1.394:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.3`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.5`,
        fs:  `cpe:2.3:o:opensuse:suse_linux_enterprise_server:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.6`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.7`,
        fs:  `cpe:2.3:a:x.org:x11:r6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.8`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_3_firmware:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.9`,
        fs:  `cpe:2.3:a:teradata:named_pipes_access_module:13.10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.10`,
        fs:  `cpe:2.3:a:php:php:5.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.11`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.12`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.13`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.14`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.15`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.16`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.17`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.18`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.19`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.1.22`,
        fs:  `cpe:2.3:a:vmware:workstation:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.66:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.3`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.4`,
        fs:  `cpe:2.3:a:sap:sybase_unwired_platform_online_data_proxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.5`,
        fs:  `cpe:2.3:h:hp:j9574a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.7`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.8`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.9`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.10`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_hydravision_full:2009.0113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.11`,
        fs:  `cpe:2.3:a:microsoft:works:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.13`,
        fs:  `cpe:2.3:a:lttng:ust:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.16`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.19`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.22`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.23`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.24`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.2.26`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.3.0`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0:feature_pack_7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.3.2`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.3.3`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.3.5`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.3.8`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.3.10`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.4:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:389_directory_server:1.3.3.11`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:anaconda:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:-`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:7`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:8`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:9`,
        fs:  `cpe:2.3:h:hp:t5540:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:10`,
        fs:  `cpe:2.3:a:asperasoft:aspera_client:2.6.3.28253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:11`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:12`,
        fs:  `cpe:2.3:a:wearepropeople:glossify_internal_links_auto_seo:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:13`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:15`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:16`,
        fs:  `cpe:2.3:o:ibm:vios:2.1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:17`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:18`,
        fs:  `cpe:2.3:a:tenable:nessus:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:19`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.4:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:20`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:21`,
        fs:  `cpe:2.3:o:cisco:catos:2.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:22`,
        fs:  `cpe:2.3:o:cisco:telepresence_tc_software:7.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:23`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora:24`,
        fs:  `cpe:2.3:a:google:v8:3.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora_core:-`,
        fs:  `cpe:2.3:a:vmware:fusion_pro:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora_core:1`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora_core:2`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora_core:3`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora_core:4`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora_core:5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fedoraproject:fedora_core:6`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:unstable7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.2.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.1r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.3.0`,
        fs:  `cpe:2.3:h:supermicro:x8dtu-ln4f\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.3.2`,
        fs:  `cpe:2.3:a:dkorunic:pam_s\/key:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.3.3`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.612.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.4.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.4.1`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.5.0`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.6.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.6.1`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.0.2:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.7.0`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.7.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.63:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.99.0`,
        fs:  `cpe:2.3:a:yahoo:yui:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:0.99.1`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62j:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.0.0`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g54_firmware:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.0.1`,
        fs:  `cpe:2.3:a:divx:player:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.0.2`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.0.3`,
        fs:  `cpe:2.3:h:supermicro:x9qr7-tf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.0.4`,
        fs:  `cpe:2.3:a:tivoli_storage_productivity_center:5.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.0.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.2:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.0.6`,
        fs:  `cpe:2.3:a:netscape:messaging_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.0.99`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.1.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:4.0.5c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.1.1`,
        fs:  `cpe:2.3:a:symantec:encryption_management_server:3.3.2:mp11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.1.2`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.1.91`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.1.92`,
        fs:  `cpe:2.3:o:huawei:honor_6_firmware:h60-l01c00b850:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.2.1`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.43:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.2.2`,
        fs:  `cpe:2.3:a:heikki_hokkanen:viewgit:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.2.3`,
        fs:  `cpe:2.3:a:aegirproject:hostmaster:6.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.2.4`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.2.91`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.3.0`,
        fs:  `cpe:2.3:h:hp:apache-based_web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.3.1`,
        fs:  `cpe:2.3:a:mautic:mautic:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.4.0`,
        fs:  `cpe:2.3:o:d-link:dcs-2310l_firmware:1.08.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.4.1`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.0`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.18s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.3`,
        fs:  `cpe:2.3:a:cisco:vsc3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.4`,
        fs:  `cpe:2.3:a:winzip:winzip:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.5`,
        fs:  `cpe:2.3:a:google:chrome:7.0.514.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.6`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.7`,
        fs:  `cpe:2.3:a:oracle:outside_in_technology:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.8`,
        fs:  `cpe:2.3:a:corel:painter:2015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.9`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.10`,
        fs:  `cpe:2.3:a:util-linux_project:util-linux:2.29.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.11`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.12`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.13`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_netscaler:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.14`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.15`,
        fs:  `cpe:2.3:o:hp:mpe:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.16`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp2:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.5.17`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.3:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.6.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:9.0:bundle7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.6.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.6.2`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.6.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sg.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.6.4`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.7.0`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.878.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.0:beta1`,
        fs:  `cpe:2.3:a:htc:evo_3d_software:2.08.651.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.0:beta2`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.0:beta3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.2`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:352.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.4`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.5`,
        fs:  `cpe:2.3:h:schneider_electric:sage_1410:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.8.6`,
        fs:  `cpe:2.3:a:microsoft:project:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.9.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.9.1`,
        fs:  `cpe:2.3:a:saltstack:salt:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.9.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je024a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.9.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.3.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.9.4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.10.0`,
        fs:  `cpe:2.3:a:buffalotech:wzr2-g300n_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.10.1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:7.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.11.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.11.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.11.2`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.11.3`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.11.4`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.11.5`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ebu:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.11.6`,
        fs:  `cpe:2.3:a:apache:activemq:4.0:m4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.11.7`,
        fs:  `cpe:2.3:a:tntnet:cxxtools:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.12.0`,
        fs:  `cpe:2.3:a:ibm:network_appliance_data_ontap:7.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.12.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.12.2`,
        fs:  `cpe:2.3:a:csc:tsrserviceclient:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.12.3`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.12.4`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.12.5`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.825:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedoraproject:sssd:1.13.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fedup_project:fedup:0.9.0`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feed_element_mapper_project:feed_element_mapper:-::~~~drupal~~`,
        fs:  `cpe:2.3:h:hp:jh188a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feeds_project:feeds:7.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:feeds_project:feeds:7.x-2.0:alpha2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feeds_project:feeds:7.x-2.0:alpha3`,
        fs:  `cpe:2.3:a:kay_messerschmidt:com_eventcal:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feeds_project:feeds:7.x-2.0:alpha4`,
        fs:  `cpe:2.3:a:hp:hpztlbxfx:3.7.281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feeds_project:feeds:7.x-2.0:alpha5`,
        fs:  `cpe:2.3:a:atutor:atutor:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feeds_project:feeds:7.x-2.0:alpha6`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feeds_project:feeds:7.x-2.0:alpha7`,
        fs:  `cpe:2.3:a:cisco:telepresence_management_suite:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feeds_project:feeds:7.x-2.x`,
        fs:  `cpe:2.3:a:zope:zope:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.0.4`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.0.5`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.0.6`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.0.7`,
        fs:  `cpe:2.3:h:hp:h3c_routing_switch:s9512e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.0.8`,
        fs:  `cpe:2.3:a:ibm:websphere_real_time:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.1.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.1.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.1.5`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.1.6`,
        fs:  `cpe:2.3:a:hp:web_registration:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.1.7`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.1.9`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.40.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.2`,
        fs:  `cpe:2.3:a:x.org:x11:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.4`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11._host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.5`,
        fs:  `cpe:2.3:a:wokamoto:wp-cron_dashboard:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.6`,
        fs:  `cpe:2.3:a:winzip:winzip_command_line_support_add-on:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.8`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.9`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.10`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_01a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.11`,
        fs:  `cpe:2.3:a:redhat:rhncfg:5.10.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.2.12`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.1`,
        fs:  `cpe:2.3:o:vmware:esx:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.3`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.4`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.5`,
        fs:  `cpe:2.3:a:apache:struts:2.3.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.6`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.1:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.7`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.8`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:12:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.9`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.10`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.11`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.12`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.13`,
        fs:  `cpe:2.3:a:magiciso:magicdisc:2.7.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.14`,
        fs:  `cpe:2.3:a:ca:etrust_internet_security_suite:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.3.15`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.4`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.4.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.4.2`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.4.3`,
        fs:  `cpe:2.3:a:monotone:monotone:0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.4.4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.4.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.4.6`,
        fs:  `cpe:2.3:a:ipswitch:imail:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.4.7`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.3.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.1`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:8.10.1125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.4`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.6`,
        fs:  `cpe:2.3:a:appstronautme:cleveland_football_stream:2.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.7`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.8`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.9`,
        fs:  `cpe:2.3:a:mozilla:firefox:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.10`,
        fs:  `cpe:2.3:a:winpcap:winpcap:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.11`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.5.12`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2se.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.6`,
        fs:  `cpe:2.3:h:entrypass:n5200_active_network_control_panel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.6.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.6.2`,
        fs:  `cpe:2.3:a:jq_project:jq:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.6.3`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.7`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.7.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.7.2`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.7.3`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.7.4`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.7.5`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8.2`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8.4`,
        fs:  `cpe:2.3:a:neojoomla:com_neorecruit:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8.5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8.6`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8.7`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:1.8.8`,
        fs:  `cpe:2.3:a:hp:http_communication:6.10.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:2.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:2.0.1`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.5.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:2.0.2`,
        fs:  `cpe:2.3:a:apache:axis:1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:2.0.3`,
        fs:  `cpe:2.3:a:david_king:vino:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:2.0.4`,
        fs:  `cpe:2.3:a:qemu:qemu:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:2.0.5`,
        fs:  `cpe:2.3:a:tincan:phplist:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedweb:feedweb:2.0.6`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feedwordpress_project:feedwordpress:2014.0805::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.11`,
        fs:  `cpe:2.3:a:hp:oneview:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.13`,
        fs:  `cpe:2.3:o:apple:airport_base_station_firmware:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.14`,
        fs:  `cpe:2.3:a:adobe:pagemaker:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.15`,
        fs:  `cpe:2.3:a:ni:labview:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.16`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.17`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_portal_server:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.18`,
        fs:  `cpe:2.3:a:buffalotech:wzr2-g300n_firmware:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.19`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feep:libtar:1.2.20`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:feiron:feiron:1.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fellowes:mediaface:4.1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:david_king:vino:2.27.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.4::~~~typo3~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:55.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.5::~~~typo3~~`,
        fs:  `cpe:2.3:a:hp:product_assistant:140.0.213.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.6::~~~typo3~~`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.7::~~~typo3~~`,
        fs:  `cpe:2.3:a:cisco:webns:7.40.1.19s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:femanager_project:femanager:1.0.8::~~~typo3~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.6.2`,
        fs:  `cpe:2.3:a:atutor:achecker:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7`,
        fs:  `cpe:2.3:a:sixapart:movable_type:3.2:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7:beta`,
        fs:  `cpe:2.3:a:hp:unload_support:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7:beta2`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7:rc`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g05.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7:rc2`,
        fs:  `cpe:2.3:h:cisco:wireless_lan_controller:4.2.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7:rc3`,
        fs:  `cpe:2.3:h:hp:jd658a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7.1`,
        fs:  `cpe:2.3:a:microsoft:metadirectory_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7.2`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.13:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7.3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.8.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7.5`,
        fs:  `cpe:2.3:h:cisco:unity_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7.5:beta`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7.5:rc2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:1.7.5:rc3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.0.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.0.0:beta1`,
        fs:  `cpe:2.3:a:faircom:c-treeace:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.0.0:beta2`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.0.0:beta3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert6:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.0.0:beta4`,
        fs:  `cpe:2.3:a:emc:networker:8.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.0.0:rc`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.1.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.4:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.1.0:beta`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.1.0:rc`,
        fs:  `cpe:2.3:a:apple:itunes:4.1.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.1.0:rc2`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.0`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.0:beta`,
        fs:  `cpe:2.3:h:lexmark:cx725de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.0:rc`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.1`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.1:rc`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.2`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.3.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.3.1:beta`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.9:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.4`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.4:beta`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.2.4.1`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd653a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3:beta`,
        fs:  `cpe:2.3:a:trioniclabs:sentinel:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3:rc`,
        fs:  `cpe:2.3:h:apple:imac:mb200xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3:rc2`,
        fs:  `cpe:2.3:a:realnetworks:rhapsody:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.1`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.1:beta`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(6a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.1:rc`,
        fs:  `cpe:2.3:a:samba:samba:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.1.1`,
        fs:  `cpe:2.3:o:blackberry:qnx_neutrino_rtos:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.2`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.2:beta`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.2:rc`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p212:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.2:rc2`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fengoffice:feng_office:2.3.2.1`,
        fs:  `cpe:2.3:h:ibm:system_x_idataplex_dx360_m4_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.5.10`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.5.11`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.5.12`,
        fs:  `cpe:2.3:a:adobe:flash_player:8.0.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.5.14`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.424:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.7.2`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.8.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:3.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.8.1`,
        fs:  `cpe:2.3:a:perl:perl:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.8.2`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:2.8.3`,
        fs:  `cpe:2.3:a:intel:proset_wireless:13.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:3.9.1.4000:-:~~~windows~~`,
        fs:  `cpe:2.3:a:grape_project:grape:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir:4.0.0.4000:-:~~~windows~~`,
        fs:  `cpe:2.3:a:hp:mpio_full_featured_dsm_for_eva4x00\/6x00\/8x00_family_of_disk_arrays:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.0.0:alpha`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.0.0:alpha:black`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.06.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.0.0:beta_update1`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.0.0:beta_update1:black`,
        fs:  `cpe:2.3:a:winzip:winzip:16.0.9661:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.0.0:rc`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.0.0:rc:black`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_nortel_passport:3.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.1.0`,
        fs:  `cpe:2.3:a:mvd:surething_cd_labeler:5.2.693:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.1.0:-:black`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.2.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.2.0:-:black`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.3.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:31.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.3.0:-:black`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.4.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.4.0:-:black`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.5.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.5.0:-:black`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.00:-:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.5.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.5.1:-:black`,
        fs:  `cpe:2.3:h:cisco:vpn_3080_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.6.0`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.6.0:-:black`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(32\)sy8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.7.0`,
        fs:  `cpe:2.3:a:not_yet_commons_ssl_project:not_yet_commons_ssl:0.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.7.0:-:black`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.7.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:1.7.1:-:black`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.0`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option_server:08-00\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.0:-:black`,
        fs:  `cpe:2.3:a:creatingahaven:compassion_satisfaction:0.75.13440.35155:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.1`,
        fs:  `cpe:2.3:h:cisco:5500_adaptive_security_appliance:7.2:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.1:-:black`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100515:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.2:-:black`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.3`,
        fs:  `cpe:2.3:o:huawei:ar_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.3:-:black`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.8.0\(582\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.0.4:-:black`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.1.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.1.0:-:black`,
        fs:  `cpe:2.3:a:r-company:unzipper:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.2.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.2.0:-:black`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.2.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.7.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.2.1:-:black`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.5:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.2.2`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.2.2:-:black`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_link_for_doors:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.2.3`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-10-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.2.3:-:black`,
        fs:  `cpe:2.3:a:hp:openview_performance_agent:c.04.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.3.0`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.3.0:-:black`,
        fs:  `cpe:2.3:a:drupal:drupal:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.4.0`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.4.0:-:black`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:milestone6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.4.1`,
        fs:  `cpe:2.3:a:smarttweak:updatemydrivers:7.0.0.147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.4.1:-:black`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.5.0`,
        fs:  `cpe:2.3:a:x:x.org-xserver:1.7.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.5.0:-:black`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.5.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.5.1:-:black`,
        fs:  `cpe:2.3:a:apple:safari:3.0.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.6.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.6.0:-:black`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.7.0`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.7.0:-:black`,
        fs:  `cpe:2.3:a:microsoft:asp.net:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.8.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.8.0:-:black`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.9.0:-:black`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.9.1`,
        fs:  `cpe:2.3:a:debian:libmail-audit-perl:2.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.9.1:-:black`,
        fs:  `cpe:2.3:a:altiris:symantec_endpoint_protection_integration_component:6.0.1171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.10:-:~~~android~~`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.10:-:~-~black~android~~`,
        fs:  `cpe:2.3:a:buffalotech:wzr-ampg144nh_firmware:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.10.0`,
        fs:  `cpe:2.3:a:apache:roller:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fenrir-inc:sleipnir_mobile:2.10.0:-:black`,
        fs:  `cpe:2.3:a:omeka:omeka:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fermononrespiri:fermononrespiri_mobile:3.8.6::~~~android~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ferretcms_project:ferretcms:1.0.4:alpha`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:festo:cecx-x-c1_modular_master_controller:-`,
        fs:  `cpe:2.3:a:apache:commons_email:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:festo:cecx-x-m1_modular_controller:-`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.5.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.5.2`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.5.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.5.4`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.5.5`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.5.6`,
        fs:  `cpe:2.3:a:symantec:on_icommand:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.5.7`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.5.8`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.0`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.1.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.12:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.4`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.5`,
        fs:  `cpe:2.3:a:google:chrome:10.0.622.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.6`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(24b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.7`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.8`,
        fs:  `cpe:2.3:a:digia:qt:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.6.9`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.7.0`,
        fs:  `cpe:2.3:a:vips:vips:7.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.7.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.7.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p392:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.7.3`,
        fs:  `cpe:2.3:a:paulalexanderformayor:paul_alexander_campaign:4.5.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.7.4`,
        fs:  `cpe:2.3:o:freenas:freenas:0.69:-:amd64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.7.5`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.7.6`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:4.7.7`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.0`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.1`,
        fs:  `cpe:2.3:a:alliedtelesyn:at-tftp:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.2`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.3`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.4`,
        fs:  `cpe:2.3:a:apple:safari:2.0.3:417.9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.5`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_regis_graphics_server:14.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.6`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.7`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1683.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)xe2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.1.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.1.4`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.2.0`,
        fs:  `cpe:2.3:a:rsa:keon_registration_authority_web_interface:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.2.1`,
        fs:  `cpe:2.3:a:tribulant:tibulant_slideshow_gallery:1.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.2.3`,
        fs:  `cpe:2.3:a:mesa3d:mesa:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.2.4`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.08.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.2.7`,
        fs:  `cpe:2.3:a:marconi:forethought:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.2.8`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.3.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr3204lf-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.3.1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.3.3`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.3.8`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.4.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.655.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.4.3`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.4.4`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:2.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.4.5`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.5.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.5.2`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.5.3`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.5.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.5.6`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.6.0`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.7.0`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r71.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.7.2`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.7.4`,
        fs:  `cpe:2.3:a:digia:qt:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.1`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.7.4:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.2`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.3`,
        fs:  `cpe:2.3:a:gnome:glib:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.5`,
        fs:  `cpe:2.3:h:hp:0235a25r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.6`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.11`,
        fs:  `cpe:2.3:a:opentext:enterprise_library_archive_server:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.13`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.14`,
        fs:  `cpe:2.3:a:microsoft:office_web_components:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.8.17`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.9.0`,
        fs:  `cpe:2.3:a:oracle:applications_framework:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.9.4`,
        fs:  `cpe:2.3:h:softbank:windows_mobile_smartphone:x05ht:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.9.5`,
        fs:  `cpe:2.3:a:wpsymposium:wp_symposium:15.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.9.8`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.9.10`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.9.11`,
        fs:  `cpe:2.3:a:google:v8:3.22.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:5.9.13`,
        fs:  `cpe:2.3:a:david_king:vino:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.0.0`,
        fs:  `cpe:2.3:o:opensuse:leap:42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.1.0`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.1.3`,
        fs:  `cpe:2.3:a:ibm:rational_directory_administrator:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.0`,
        fs:  `cpe:2.3:a:altiris:notification_server_configurator:6.1.7631.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.1`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.2`,
        fs:  `cpe:2.3:a:apple:itunes:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.3`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.4`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:9.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.5`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.5.1`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.5.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.5.4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.6:pre4`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_firmware:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.6:pre8`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.6:pre9`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.9:rc10`,
        fs:  `cpe:2.3:a:sgi:mediamail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.9:rc3`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.9:rc4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.9:rc5`,
        fs:  `cpe:2.3:a:ibm:secureway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.9:rc7`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.9:rc8`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.2.9:rc9`,
        fs:  `cpe:2.3:a:sympa:sympa:3.2.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.30:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.1`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.2`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.3`,
        fs:  `cpe:2.3:a:hp:cuetour:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.5`,
        fs:  `cpe:2.3:a:teradata:bteq:13.10.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.6:rc1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.680.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.6:rc2`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.6:rc3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.6:rc4`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.6:rc5`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.7`,
        fs:  `cpe:2.3:a:google:chrome:17.0.921.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.8`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.9`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.9:rc2`,
        fs:  `cpe:2.3:a:skype:skype:3.6.0.248:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.10`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux_corporate_server:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.11`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.12`,
        fs:  `cpe:2.3:a:galen_charlton:marc-xml:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.13`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.14`,
        fs:  `cpe:2.3:h:moxa:iologic_e2214-t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.15`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.16`,
        fs:  `cpe:2.3:h:ibm:system_x3100_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.17`,
        fs:  `cpe:2.3:o:cisco:staros:18.0.0.59167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.18`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fetchmail:fetchmail:6.3.19`,
        fs:  `cpe:2.3:a:openstack:neutron:2012.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffdshow:ffdshow_tryouts:2010-01-28`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffftp:ffftp:1.98`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffftp:ffftp:1.98:a`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffftp:ffftp:1.98:b`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffftp:ffftp:1.98:c`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.3.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.3.2`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.3.3`,
        fs:  `cpe:2.3:h:ibm:surepos_500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.3.4`,
        fs:  `cpe:2.3:a:exim:exim:4.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.0`,
        fs:  `cpe:2.3:a:hp:image_zone:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.4`,
        fs:  `cpe:2.3:o:debian:debian_linux:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.5`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1072.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.6`,
        fs:  `cpe:2.3:a:google:v8:3.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.7`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.8`,
        fs:  `cpe:2.3:h:cisco:spa2102_phone_adapter_with_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.9:pre1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.4.9_pre1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.808.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.5`,
        fs:  `cpe:2.3:a:dhims:ahlta:3.6.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.5.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.7.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.5.2`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.8:rev36369:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.5.3`,
        fs:  `cpe:2.3:a:microsoft:html_help_workshop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.5.4`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.5.4.5`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.5.4.6`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.5.5`,
        fs:  `cpe:2.3:a:eeye:retina:5.11.12.2092:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.6`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.0.40:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.6.1`,
        fs:  `cpe:2.3:a:digia:qt:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.6.2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.7:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.6.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.2`,
        fs:  `cpe:2.3:a:adobe:connect:9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.3`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.0.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.4`,
        fs:  `cpe:2.3:a:google:chrome:14.0.793.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.5`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.3:_nil_:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.6`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.7`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.8`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.9`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.11`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.7.12`,
        fs:  `cpe:2.3:a:recommend_to_a_friend_project:recommend_to_a_friend:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.1`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.2`,
        fs:  `cpe:2.3:a:gajim:gajim:0.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.18:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.5.3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.5.4`,
        fs:  `cpe:2.3:a:levelfourdevelopment:wp-easycart:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.6`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.7`,
        fs:  `cpe:2.3:a:ibm:algo_one:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.8`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.19.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.10`,
        fs:  `cpe:2.3:a:oracle:ilearning:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.8.11`,
        fs:  `cpe:2.3:o:iodata:ts-wlcam_camera_firmware:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.9`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.9.1`,
        fs:  `cpe:2.3:a:wasen:mod_simplefileupload:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.10`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.10.3`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.10.4`,
        fs:  `cpe:2.3:h:google:nexus_9:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.10.15`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.7.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p2_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.11.1`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.11.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.11.3`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:0.11.4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1009:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p129:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.0.2`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc12:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.0.3`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.0.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_endpoint_manager:9.1.1117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1.1`,
        fs:  `cpe:2.3:a:microsoft:office:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1.2`,
        fs:  `cpe:2.3:a:ag-klettern-odenwald:ag_klettern_odenwald:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1.3`,
        fs:  `cpe:2.3:a:phpmemcachedadmin_project:phpmemcachedadmin:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1.4`,
        fs:  `cpe:2.3:a:hp:storeonce_4210_fc_backup_system:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1.6`,
        fs:  `cpe:2.3:h:intel:carrier_grade_server_tigpr2u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1.7`,
        fs:  `cpe:2.3:a:idevspot:nixieaffiliate:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.1.8`,
        fs:  `cpe:2.3:a:emc:unisphere:8.1:*:*:*:*:vmax:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.2`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:1.2.1`,
        fs:  `cpe:2.3:a:pervasive:data_integrator_engine:9.0.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.0`,
        fs:  `cpe:2.3:a:raphael_zschorsch:rzautocomplete:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.0.1`,
        fs:  `cpe:2.3:a:tibco:slingshot:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.0.2`,
        fs:  `cpe:2.3:a:microsoft:excel:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.0.3`,
        fs:  `cpe:2.3:a:microsoft:ie:5.0.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.0.4`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.0.5`,
        fs:  `cpe:2.3:a:kde:ark:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.0.6`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.0.7`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2002:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1.1`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1.2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1.3`,
        fs:  `cpe:2.3:a:josh_fradley:burden:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1.5`,
        fs:  `cpe:2.3:a:busybox:busybox:1.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1.6`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1.7`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_service:3.3.1048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.1.8`,
        fs:  `cpe:2.3:a:tamos:commtraffic:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2`,
        fs:  `cpe:2.3:a:yahoo:messenger:6.0.0.1921:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.0:alpha-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.2`,
        fs:  `cpe:2.3:a:microsoft:pocket_ie:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.3`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.4`,
        fs:  `cpe:2.3:a:webmin:webmin:1.610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.5`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.7`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.1.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.8`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.9`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.10`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.11`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.12`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.13`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.14`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.15`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.2.16`,
        fs:  `cpe:2.3:a:skype:skype:2.6.0.81:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.3`,
        fs:  `cpe:2.3:a:giantrobot:zipcart:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.3.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.3.2`,
        fs:  `cpe:2.3:a:plone:plone:4.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.3.3`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:rc1:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.3.4`,
        fs:  `cpe:2.3:a:mod_nss_project:mod_nss:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.3.5`,
        fs:  `cpe:2.3:a:apache:solr:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.3.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:9.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.0`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_233_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.3`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.4`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.20:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.5`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.6`,
        fs:  `cpe:2.3:h:huawei:s5700:v100r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.7`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.8`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.9`,
        fs:  `cpe:2.3:o:qnap:qts:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.10`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.11`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt_2011_language_pack:18.1.49.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.4.12`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.093:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.0`,
        fs:  `cpe:2.3:a:gnu:lsh:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.1`,
        fs:  `cpe:2.3:a:microsoft:office_web_apps_server:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.3`,
        fs:  `cpe:2.3:a:yahoo:messenger:0.99.17-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.4`,
        fs:  `cpe:2.3:h:cisco:sf500-48:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.5`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.7`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.5.9`,
        fs:  `cpe:2.3:a:google:v8:3.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.6`,
        fs:  `cpe:2.3:a:janrain:ruby-openid:2.3.0:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.6.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.6.1`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.6.2`,
        fs:  `cpe:2.3:a:openid:openid4java:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.6.3`,
        fs:  `cpe:2.3:a:avaya:call_management_system_supervisor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.6.4`,
        fs:  `cpe:2.3:a:deltek:winsight:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.6.5`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.6.6`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.7.0`,
        fs:  `cpe:2.3:a:huawei:campus_series_switch_software:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.7.1`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.11i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.7.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.7.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.286.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.7.4`,
        fs:  `cpe:2.3:a:nginx:nginx:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.375:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8:dev`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.0`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.1`,
        fs:  `cpe:2.3:a:cisco:secure_acs_for_windows_nt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.2`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-755:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.3`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.4`,
        fs:  `cpe:2.3:a:vmware:openpegasus_management_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.5`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.6`,
        fs:  `cpe:2.3:a:serviceacademyforums:service_academy_forums:3.6.12:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.7`,
        fs:  `cpe:2.3:a:emc:documentum_foundation_services:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.8`,
        fs:  `cpe:2.3:a:antiword_project:antiword:0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.9`,
        fs:  `cpe:2.3:o:siemens:spc4000_firmware:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:2.8.11`,
        fs:  `cpe:2.3:a:corel:coreldraw_content:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0.4`,
        fs:  `cpe:2.3:a:apple:quicktime:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0.5`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.1337:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0.6`,
        fs:  `cpe:2.3:a:ibm:lotus_expeditor:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0.7`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.0.8`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1.2`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1.3`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1.4`,
        fs:  `cpe:2.3:a:vmware:player:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1.5`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1.6`,
        fs:  `cpe:2.3:o:d-link:dap-3320_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1.7`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.1.8`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.2`,
        fs:  `cpe:2.3:h:samsung:series_5_chromebook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.2.1`,
        fs:  `cpe:2.3:a:quest:powergui:2.2.0.1358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.2.2`,
        fs:  `cpe:2.3:a:cisco:tacacs\&#43;:f4.0.3alpha:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.2.3`,
        fs:  `cpe:2.3:a:tibco:slingshot:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.2.4`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.2.5`,
        fs:  `cpe:2.3:a:mozilla:camino:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.5.33:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.3.1`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.5:beta1:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.3.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.6\(1.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ffmpeg:ffmpeg:3.3.3`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.0.1:mu_\#11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiatforum:fiat_forum:3.8.41::~~~android~~`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiberlink:maas360:-`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fibonacciorange:wedeal:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:kidasa:milestones_2010:12.0.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiddler2:fiddler2:2.3.4.5`,
        fs:  `cpe:2.3:a:gnu:ksymoops:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiddler2:fiddler2:2.3.5.2`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiddler2:fiddler2:2.3.6.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:field_display_label_project:field_display_label:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:field_group_project:field_group:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:field_group_project:field_group:7.x-1.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:field_group_project:field_group:7.x-1.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:content_manager_ondemand_for_multiplatforms:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:field_group_project:field_group:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.1:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:field_group_project:field_group:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:aol:aim:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:field_group_project:field_group:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:debian:dpkg:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:field_group_project:field_group:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.23:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fiksu:fiksu:-::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiksu:fiksu_library:-::~~~android~~`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.08`,
        fs:  `cpe:2.3:a:innominate:mguard_delta:hw-103050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.09`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.10`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.3:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.11`,
        fs:  `cpe:2.3:a:apache:httpclient:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.12`,
        fs:  `cpe:2.3:a:apple:xcode:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.13`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p193:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.14`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-1500d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.15`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.16`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.17`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.16:build110612:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.18`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:me:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.19`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_opmanager:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.20`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:file_project:file:5.21`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filefield_project:filefield:6.x-3.12::~~~drupal~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p418:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filehold:filehold_desktop_application:9.0`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker:14.0.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.365:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:4.0`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:6.0`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:7.0.2.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd331a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:8.0.1.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta37:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:8.0.2.0`,
        fs:  `cpe:2.3:h:ibm:system_x3620_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:8.0.3.0`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:8.5.0.0`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:8.5.1.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:8.5.2.0`,
        fs:  `cpe:2.3:a:web2py:web2py:1.98.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:9.0.0.0`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:9.0.1.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1w\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:9.0.2.0`,
        fs:  `cpe:2.3:a:hp:openview_operations:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:9.0.3.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:10.0.0.0`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:10.0.1.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:10.0.3.0`,
        fs:  `cpe:2.3:a:microsoft:antispyware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:11.0.0.0`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:sp1a:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:11.0.1.0`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:11.0.2.0`,
        fs:  `cpe:2.3:h:teracom:t2-b-gawv1.4u10y-bi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:11.0.3.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:11.0.4.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:12.0.0.0`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.59:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:12.0.1.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:12.0.2.0`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:12.0.3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro:12.0.4.0`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:8.0.1.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:8.0.2.0`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:8.0.3.0`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:8.5.0.0`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:8.5.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:8.5.2.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:9.0.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.8.0\(55\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:9.0.1.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:9.0.2.0`,
        fs:  `cpe:2.3:h:quantum:scalar_i500:5u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:9.0.3.0`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:10.0.0.0`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpx213:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:10.0.1.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:10.0.3.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.0.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:11.0.0.0`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:11.0.1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:11.0.2.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:11.0.3.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:11.0.4.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:12.0.0.0`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_controller_firmware:20.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:12.0.1.0`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:12.0.2.0`,
        fs:  `cpe:2.3:a:djangoproject:tastypie:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:12.0.3.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_pro_advanced:12.0.4.0`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_server:-`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_server:7.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_server:8.0`,
        fs:  `cpe:2.3:a:citadel:ux:5.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_server:10.0.1.64`,
        fs:  `cpe:2.3:h:apple:imac:ma710xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filemaker:filemaker_server:10.0.2.206`,
        fs:  `cpe:2.3:a:microsoft:word_viewer:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filenice:filenice:1.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_management_framework:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filenice:filenice:1.1.1`,
        fs:  `cpe:2.3:o:cisco:asyncos:9.7.0-125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fileopen:fileopen_client:3.0.67.914`,
        fs:  `cpe:2.3:a:webmin:usermin:1.460:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filesanywhere:filesanywhere:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p125:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:filesland:open_ports_scanner:2.4`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:finalbeta:mywebsearch:1.00`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:finalbeta:mywebsearch:1.01`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:finalbeta:mywebsearch:1.10`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:finalbeta:mywebsearch:1.20`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:finalbeta:mywebsearch:1.21`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:finalbeta:mywebsearch:1.22`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:finalbeta:mywebsearch:1.23`,
        fs:  `cpe:2.3:o:debian:debian_linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:finansbank:finansbank_cep_subesi:1.1.5::~~~android~~`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd2.m5xx0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:find_color_project:find_color:1.1.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)jk5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:findingscience:mod_auth_openid:0.1::~~~apache~~`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:findingscience:mod_auth_openid:0.2::~~~apache~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.27:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:findingscience:mod_auth_openid:0.2.1::~~~apache~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.91.2_p0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:findingscience:mod_auth_openid:0.3::~~~apache~~`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:findingscience:mod_auth_openid:0.4::~~~apache~~`,
        fs:  `cpe:2.3:a:gnu:zlib:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:findingscience:mod_auth_openid:0.5::~~~apache~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p97:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:findingscience:mod_auth_openid:0.6::~~~apache~~`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.633:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:findingscience:mod_auth_openid:0.7::~~~apache~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf430b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fingersoft:cartoon_camera:1.2.2::~~~android~~`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firaxis:sid_meiers_civilization_chronicles:-`,
        fs:  `cpe:2.3:a:ibm:lotus_forms_viewer:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firaxis:sid_meiers_civilization_iii:-`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firaxis:sid_meiers_civilization_iv:-`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firaxis:sid_meiers_civilization_iv_warlords:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fire_equipments_screen_lock_project:fire_equipments_screen_lock:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebird:firebird:2.1.6`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebird:firebird:2.5`,
        fs:  `cpe:2.3:a:apache:batik:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebird:firebird:2.5.1`,
        fs:  `cpe:2.3:a:apple:safari:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebird:firebird:2.5.2`,
        fs:  `cpe:2.3:a:trioniclabs:sentinel:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebird:firebird:2.5.3`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:-`,
        fs:  `cpe:2.3:a:microsoft:access:2010:sp1:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.27.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.0.2`,
        fs:  `cpe:2.3:a:redcloth:redcloth_library:4.2.9:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.0.3`,
        fs:  `cpe:2.3:a:novell:imanager:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.5`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.5.0.4306`,
        fs:  `cpe:2.3:o:arbiter:power_sentinel_1133a_firmware:11jun2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.5.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.5.2`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.5.2.4731`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.5.3.4870`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.5.4.4910`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:1.5.5`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.0.0.12748`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.9.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.0.1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.0.1.12855`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.0.2`,
        fs:  `cpe:2.3:a:microsoft:sysinternals:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.0.3`,
        fs:  `cpe:2.3:o:mandriva:linux:2009.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.1`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.1:beta`,
        fs:  `cpe:2.3:a:digium:asterisk:13.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.1:rc1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.1.3`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.8b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.1.4`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.1.5`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.17.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.1_beta`,
        fs:  `cpe:2.3:a:vmware:capacityiq:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.5.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.5.2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.5.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p53:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firebirdsql:firebird:2.5.5`,
        fs:  `cpe:2.3:a:perl:perl:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firedaemon:firedaemon_pro:3.0.2437`,
        fs:  `cpe:2.3:a:python:python:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fireflymediaserver:firefly_media_server:1.0.0.1359`,
        fs:  `cpe:2.3:a:ibm:ds_storage_manager_host_software:10.83.05.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firejail_project:firejail:-`,
        fs:  `cpe:2.3:a:snort:snort:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firejail_project:firejail:0.9.38.2`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_hosted:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:firejail_project:firejail:0.9.44.2`,
        fs:  `cpe:2.3:a:python:setuptools:0.7b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fisher-price:smart_toy_bear:-`,
        fs:  `cpe:2.3:a:sambar:sambar_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fishshell:fish:1.16.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fishshell:fish:2.0.0`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fishshell:fish:2.1.1`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0f_pk6_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fitnesse:fitnesse_wiki:20131110`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fitnesse:fitnesse_wiki:20140201`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiverrscript:fiverrscript:7.2`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:5.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:1.5.7`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0`,
        fs:  `cpe:2.3:a:oracle:agile_engineering_data_management:6.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.1.5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:beta1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.1.6`,
        fs:  `cpe:2.3:a:bestpractical:rt:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.1.7`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.01:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.1.8`,
        fs:  `cpe:2.3:a:ibm:security_directory_server:6.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.1.9`,
        fs:  `cpe:2.3:h:advantech:eki-1322:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.1.9.1`,
        fs:  `cpe:2.3:h:ibm:security_network_protection_xgs_3100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.2`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.2.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.7.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.6`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.6.1`,
        fs:  `cpe:2.3:a:debian:apt:0.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fiyo:fiyo_cms:2.0.7`,
        fs:  `cpe:2.3:a:panasonic:network_camera_view:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:intel:rapid_storage_technology:10.1.0.1008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:symantec:client_security:3.1.0.401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.0:alpha4:~~~drupal~~`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:intel:mwmi:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:red-gate:sql_dependency_tracker:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.5::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flag_module_project:flag:7.x-3.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:13.0.767.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flane:cisco_class_locator_fast_lane:-::~~~android~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flashy_project:flashy:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flat_manager_project:flat_manager:2.7.9::~~~typo3~~`,
        fs:  `cpe:2.3:o:engardelinux:secure_community:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flatnux:flatnux:2008-12-11`,
        fs:  `cpe:2.3:a:emc:networker:8.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flatnux:flatnux:2009-01-27`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flatnux:flatnux:2009-02-04`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flatnux:flatnux:2011-08-09-2`,
        fs:  `cpe:2.3:a:symantec:liveupdate:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flatpress:flatpress:0.804`,
        fs:  `cpe:2.3:h:rockwellautomation:ab_micrologix_controller:1500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flatpress:flatpress:1.0.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:3.0\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fleugel:myu-s:-`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fleugel:myu-s:2.09`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fleugel:php_weblog_system_mania:-:-:net`,
        fs:  `cpe:2.3:a:redhat:jboss_overlord_run_time_governance:1.0:*:*:*:*:jbossas:*:*`,
    },
     
    {
        uri: `cpe:/a:flex_project:flex:2.6.0`,
        fs:  `cpe:2.3:a:teradata:multiload:13.10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flexerasoftware:flexnet_publisher:11.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p423:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flexerasoftware:flexnet_publisher:11.13.1.0`,
        fs:  `cpe:2.3:a:vmware:player:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flexymind:president_clicker:1.0.4::~~~android~~`,
        fs:  `cpe:2.3:o:scientificlinux:scientificlinux:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fli4l:fli4l:3.10.0`,
        fs:  `cpe:2.3:a:expressjs:express:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fli4l:fli4l:4.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flickatrade:flick_a_trade:3.3::~~~android~~`,
        fs:  `cpe:2.3:a:intel:network_connections:13.5.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flightgear:flightgear:1.9.1`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flightgear:flightgear:2.0.0`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flightgear:flightgear:2.6.0`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_21.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flightgear:flightgear:2.6.0.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flightgear:flightgear:2017.2`,
        fs:  `cpe:2.3:a:tnef_project:tnef:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flock:flock:0.7.14`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flood-it_project:flood-it:4.2::~~~android~~`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_balmer:notepad2:4.2.25_`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_heidenreich:mp3tag:v2.46a`,
        fs:  `cpe:2.3:a:php:pear:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0`,
        fs:  `cpe:2.3:a:aol:internet_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:alpha1`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:alpha2`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:beta1`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:beta2`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:beta3`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:beta4`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:beta5`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:beta6`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:r1`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller_enterprise_module:1.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.0:r2`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.1`,
        fs:  `cpe:2.3:a:schneider-electric:software_update_utility:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.2`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.3`,
        fs:  `cpe:2.3:a:oracle:business_intelligence_publisher:12.2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.4`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.5`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:florian_weber:spaces:6.x-3.7`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowerfire:sawmill:6.5.1100`,
        fs:  `cpe:2.3:a:kellygerards:mr.sausage:1.301:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.0.0`,
        fs:  `cpe:2.3:a:qualys:qualyssuite:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.0.1`,
        fs:  `cpe:2.3:a:sqlite:sqlite:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.0.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.0.3`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(24\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.0.4`,
        fs:  `cpe:2.3:h:huawei:s6300:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.0.5`,
        fs:  `cpe:2.3:a:userfriendlymedia:joe\&#39;s_lawn_service:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.0.6`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.1.0`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:19.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)s5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.1.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p213:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.1.3`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.1.4`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.0.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.1.5`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_agent:5.3.0.167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.0`,
        fs:  `cpe:2.3:h:lexmark:t64x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.2`,
        fs:  `cpe:2.3:a:altova:diffdog_2011:-:sp1:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p460:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.21:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.5`,
        fs:  `cpe:2.3:a:microsoft:visual_c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.6`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.7`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.8`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.9`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.10`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(22\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.12`,
        fs:  `cpe:2.3:a:php:php:5.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.13`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.14`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.554:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.15`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.16`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.17`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sg_3.3.1sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_flash:3.2.18`,
        fs:  `cpe:2.3:a:topazsystems:sigplus_pro_activex_control:3.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_html5:5.4.1`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flowplayer:flowplayer_html5:5.4.3`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update5:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluik:office_jerk_free:1.7.13::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:sharutils:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluik:office_zombie:1.3.13::~~~android~~`,
        fs:  `cpe:2.3:h:sun:extended_system_control_facility_xcp_1040:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluke:linkware:6.0`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluke:linkware:6.2`,
        fs:  `cpe:2.3:a:ibm:service_delivery_manager:7.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluke:power_log:2.9`,
        fs:  `cpe:2.3:a:ibm:alphaworks_tftp_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flurry:flurry-analytics-android:3.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:f5:firepass:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flurry:flurry-analytics-android:3.3.2::~~~android~~`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flurry:flurry-analytics-android:3.3.4::~~~android~~`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flurry:flurry-analytics-android:3.4.0::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:industry_applications:8.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flurry:flurry-analytics-android:4.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.4.11`,
        fs:  `cpe:2.3:a:hp:ocr_software:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.5.0`,
        fs:  `cpe:2.3:a:samba:samba:3.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.5.1`,
        fs:  `cpe:2.3:a:smarty:smarty:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.5.2`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-00-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.5.3`,
        fs:  `cpe:2.3:a:vmware:workstation:12.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.5.4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.72.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.5.5`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.1.90.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.5.6`,
        fs:  `cpe:2.3:a:solarwinds:storage_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fluxbb:fluxbb:1.5.7`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.05.017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flyfishing-and-flytying:fly_fishing_%26_fly_tying:3.21.0::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_host_on-demand:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:flyingcart:flying_cart:-`,
        fs:  `cpe:2.3:a:horde:imp:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fmac:fmac_%3a_federation_culinaire:1::~~~android~~`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foconet:foconet:1::~~~android~~`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foecms:foecms:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fogproject:fog:0.27`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-700d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fogproject:fog:0.28`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fogproject:fog:0.29`,
        fs:  `cpe:2.3:a:schneider-electric:powersuite:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fogproject:fog:0.30`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fogproject:fog:0.31`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fogproject:fog:0.32`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foliovision:foliopress_wysiwyg:2.6.8`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foliovision:foliopress_wysiwyg:2.6.8.1`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foliovision:foliopress_wysiwyg:2.6.8.2`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foliovision:foliopress_wysiwyg:2.6.8.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foliovision:foliopress_wysiwyg:2.6.8.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foliovision:foliopress_wysiwyg:2.6.8.5`,
        fs:  `cpe:2.3:a:adobe:flash_cs4_sti:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fonality:fonality:12.6`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fonality:fonality:12.8`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(1\)ey2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fonality:fonality:14.1i`,
        fs:  `cpe:2.3:a:trendmicro:internet_security_2010:17.50.1647.0000:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fonality:hud_web:1.4.1::~~~fonality~~`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fonality:trixbox:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fonality:trixbox:2.0`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8za:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fonality:trixbox:2.2.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:font_project:font:7.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontconfig_project:fontconfig:2.12`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20110222`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20120731`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20140101`,
        fs:  `cpe:2.3:h:hp:jg407a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20140813`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20141013`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8zf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20141014`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.85.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20141126`,
        fs:  `cpe:2.3:a:oracle:javafx:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20141230`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20150228`,
        fs:  `cpe:2.3:a:ibm:data_studio_web_console:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20150330`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20150430`,
        fs:  `cpe:2.3:o:cisco:ios:15.5s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20150612`,
        fs:  `cpe:2.3:a:microsoft:ie:6.0.2800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20150824`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20160403`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20160404`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20160930`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20161001`,
        fs:  `cpe:2.3:a:ipswitch:moveit_mobile:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20161004`,
        fs:  `cpe:2.3:a:emc:networker:8.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20161005`,
        fs:  `cpe:2.3:a:isc:bind:9.8.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20161012`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20170730`,
        fs:  `cpe:2.3:h:axis:mpeg-2_video_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fontforge_project:fontforge:20170731`,
        fs:  `cpe:2.3:h:supermicro:h8dgt-hf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.5.0.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.5.1.1.20090922`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1b.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.5.1.2`,
        fs:  `cpe:2.3:a:freepbx:freepbx:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.5.1.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p201:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.5.1.5`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.21:-:*:*:*:windows_server_2008:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.5.1.6`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.5.1.7`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.6.1:b7`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.6.1:b8`,
        fs:  `cpe:2.3:a:aimluck:aipo-plus:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.6.4`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foobla:com_obsuggest:1.8`,
        fs:  `cpe:2.3:a:gnu:glibc:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foodplannerapp:food_planner:4.8.4.3-google::~~~android~~`,
        fs:  `cpe:2.3:a:ubuntu_developers:obby:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fookes:notetab_light:4.95`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.2`,
        fs:  `cpe:2.3:a:klever:pumpkin:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.3`,
        fs:  `cpe:2.3:h:huawei:eudemon1000:v200r006c02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.4`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.5`,
        fs:  `cpe:2.3:a:arclogics:cch_teammate_tools:9.1.0.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.5:a`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.6`,
        fs:  `cpe:2.3:a:pyplate:pyplate:0.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.7`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.7:a`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.7.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.80`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.90`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.91`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.91:a`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.91:b`,
        fs:  `cpe:2.3:a:samba:samba:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.91:c`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.92`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.0.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.92:a`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30198:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.92:b`,
        fs:  `cpe:2.3:o:opensuse_project:opensuse:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.92:c`,
        fs:  `cpe:2.3:a:wp_guestmap_project:wp_guestmap_project:1.8:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.92:d`,
        fs:  `cpe:2.3:a:google:chrome:5.0.341.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.92:e`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.93`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.93:a`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.93:b`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:0.93:c`,
        fs:  `cpe:2.3:a:oracle:jdeveloper:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:1.00`,
        fs:  `cpe:2.3:a:misterpark:hydrogen_water:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:1.00:a`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je048a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:1.01`,
        fs:  `cpe:2.3:a:corosync:corosync:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:2.00`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p204:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:2.01`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.01.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:2.02`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:3.0.0.4.334:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:2.03`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview_access_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.00`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.0.1`,
        fs:  `cpe:2.3:a:easymoblog:easymoblog:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.01`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.02`,
        fs:  `cpe:2.3:a:mandiant:highlighter:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.02:pl1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.5:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.02:pl2`,
        fs:  `cpe:2.3:a:x:libxv:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.02:pl3`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.02:pl4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.02:pl5`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foolabs:xpdf:3.02:pl6`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ford:ford_credit_account_manager:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forestarea:forest_area_fcu_mobile:1.0.29::~~~android~~`,
        fs:  `cpe:2.3:h:hp:j9821a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forfone:forfone%3a_free_calls_%26_messages:1.5.11::~~~android~~`,
        fs:  `cpe:2.3:a:blackberry:enterprise_server_express:5.0.4:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:9.5.3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.629.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:9.5.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:9.5.5`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:10.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:10.0.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:10.0.2`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:10.1.0::~~xpress~~~`,
        fs:  `cpe:2.3:a:redhat:resteasy:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:11.0.0`,
        fs:  `cpe:2.3:a:myapp:ibis_pau_centre:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:11.0.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forgerock:openam:11.0.2`,
        fs:  `cpe:2.3:a:grey\&#39;s_anatomy_fan_project:grey\&#39;s_anatomy_fan:3.7.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.0.1`,
        fs:  `cpe:2.3:a:fiksu:fiksu:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.0.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.1.0`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.2.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.3.0`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.3.1`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.4.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(2a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.4.1`,
        fs:  `cpe:2.3:a:webmin:usermin:1.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.5.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.5.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.0`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.1`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:6.0:r1c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.2`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:9.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.3`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2004:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.4`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.5`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.7`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.8`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.9`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_real_time_console_infrastructure:6.3.1004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.10`,
        fs:  `cpe:2.3:a:horde:imp:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.11`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.12`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:2.6.13`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2010.706.2128.36662:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.0.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.0`,
        fs:  `cpe:2.3:h:xerox:document_centre_470:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.2`,
        fs:  `cpe:2.3:a:mcafee:protectionpilot:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.3`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.4`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.7`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.1.9`,
        fs:  `cpe:2.3:a:apple:webkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.2.0`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.2.1`,
        fs:  `cpe:2.3:a:gurock:testrail:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.2.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.2.3`,
        fs:  `cpe:2.3:h:softbank:disney_mobile_android_smartphone:dm013sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.2.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.2.5`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.2.6`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fork-cms:fork_cms:3.8.5`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.967:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:formalms:formalms:1.2.1`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formnage:cutprice:1.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:google:apps_migration_for_microsoft_exchange:2.2.756.1127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.3`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.1:1009`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1004`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1005`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1012`,
        fs:  `cpe:2.3:a:plone:plone:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1021`,
        fs:  `cpe:2.3:a:gnu:automake:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1025`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1027`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1028`,
        fs:  `cpe:2.3:a:devsaran:corporate:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1032`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1033`,
        fs:  `cpe:2.3:a:kunena:kunena:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1037`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1038`,
        fs:  `cpe:2.3:a:ibm:smartcloud_analytics_log_analysis:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.4.3:1040`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1008`,
        fs:  `cpe:2.3:a:hp:universal_configuration_management_database:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1009`,
        fs:  `cpe:2.3:a:code-crafters:ability_mail_server:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1012`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1013`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.2.5:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1014`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1015`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1016`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.21:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1021`,
        fs:  `cpe:2.3:a:baseurl:yum:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1022`,
        fs:  `cpe:2.3:a:altiris:task_synchronization_agent:6.1.1034.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1023`,
        fs:  `cpe:2.3:a:daemontools:daemon_tools_toolbar:1.1.2.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1024`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1025`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1026`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1027`,
        fs:  `cpe:2.3:a:photocati_media:photocrati:-:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1028`,
        fs:  `cpe:2.3:h:ibm:xiv_storage_system:2810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1029`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1030`,
        fs:  `cpe:2.3:a:pantech:pc_card_software:2.0.a11.430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1031`,
        fs:  `cpe:2.3:a:vmware:player:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1033`,
        fs:  `cpe:2.3:o:juniper:junos:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1034`,
        fs:  `cpe:2.3:a:perl:perl:5.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1035`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1036`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p222:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1037`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1038`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1039`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.1.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1040`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs2:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1041`,
        fs:  `cpe:2.3:a:oracle:listener:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1042`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(9\)xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1043`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.3:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1044`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1045`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1046`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1047`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.0.240.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1049`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1051`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1052`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.0:1054`,
        fs:  `cpe:2.3:a:kde:koffice:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1001`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1002`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1003`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1004`,
        fs:  `cpe:2.3:a:pgp:e-ppliance_300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1005`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1006`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1007`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1010`,
        fs:  `cpe:2.3:o:ibm:aix:5.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1013`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1015`,
        fs:  `cpe:2.3:a:directfb:directfb:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1018`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1019`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1671.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1020`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1021`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1022`,
        fs:  `cpe:2.3:h:moxa:miineport_e3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1023`,
        fs:  `cpe:2.3:a:clamav:clamav:0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1024`,
        fs:  `cpe:2.3:a:samba:samba:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1025`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1026`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.52:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1028`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.99.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1029`,
        fs:  `cpe:2.3:o:xen:xen:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1030`,
        fs:  `cpe:2.3:a:cmsdevelopment:business_card_web_builder:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1031`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.1:1032`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5104he:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.2:1001`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.2:1002`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.2:1003`,
        fs:  `cpe:2.3:a:mozilla:firefox:32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.2:1004`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.2:1005`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.2:1006`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.2:1007`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:5.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.3:1002`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.3:1003`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp2:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.3:1004`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.3:1005`,
        fs:  `cpe:2.3:a:apple:cups:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1001`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1005`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1006`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1007`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1010`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-00-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1012`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.0:mr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1013`,
        fs:  `cpe:2.3:a:microsoft:outlook:2016:*:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1014`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1015`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1018`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1022`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1023`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1024`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1025`,
        fs:  `cpe:2.3:a:ibm:lotus_symphony:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1026`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1030`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1032`,
        fs:  `cpe:2.3:a:gnu:g\&#43;\&#43;:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1033`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.4:1034`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-03-03:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1003`,
        fs:  `cpe:2.3:a:icinga:icinga:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1004`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1005`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1006`,
        fs:  `cpe:2.3:h:tenda:n3_wireless_n150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1008`,
        fs:  `cpe:2.3:a:gnu:gdb:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1009`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1010`,
        fs:  `cpe:2.3:a:unitedplanet:intrexx:6.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1011`,
        fs:  `cpe:2.3:a:ibon:ibon:3.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1012`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1013`,
        fs:  `cpe:2.3:a:piwik:piwik:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1014`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1015`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1016`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.07.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.5:1017`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.6`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.6:1004`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1289.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.5.7:1013`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zj1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1006`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1007`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.0:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1008`,
        fs:  `cpe:2.3:a:cisco:unified_operations_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1009`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1011`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.094:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1012`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1013`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:-:*:tru54:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1016`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1017`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1018`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1025`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2007.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1028`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1029`,
        fs:  `cpe:2.3:a:buycoins:buy_coins:0.62.13364.24150:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer:formsplayer:1.6:1030`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.8:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:formsplayer.formsplayer:1.5:-`,
        fs:  `cpe:2.3:a:saltstack:salt:0.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forosocuellamos:forosocuellamos:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:perl:perl:5.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:forperfect:csupport:1.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:connect:14.2`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:connect:14.10`,
        fs:  `cpe:2.3:a:microsoft:digital_image_pro:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:connect:15.10`,
        fs:  `cpe:2.3:a:dell:secureworks:2.0.6:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:connect:16.7`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-1000e:-`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:1.03.07a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-1500d:-`,
        fs:  `cpe:2.3:a:lappgroup:lapp_group_catalogue:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-2000d:-`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-200d:-`,
        fs:  `cpe:2.3:h:lorextechnology:edge:lh310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-300e:-`,
        fs:  `cpe:2.3:a:pinnaclesys:studio:12.1.3.6605:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-4000d:-`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-400e:-`,
        fs:  `cpe:2.3:a:ca:ehealth_livehealth:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-600e:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortiadc-700d:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortiadc_firmware:3.2.0`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortiadc_firmware:3.2.1`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortiadc_firmware:4.1.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortianalyzer-1000d:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortianalyzer-2000b:-`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.16:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortianalyzer-200d:-`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortianalyzer-3000d:-`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortianalyzer-300d:-`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortianalyzer-4000b:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortianalyzer_firmware:5.0.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortianalyzer_firmware:5.0.1`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortianalyzer_firmware:5.0.4`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortianalyzer_firmware:5.0.5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortianalyzer_firmware:5.0.10`,
        fs:  `cpe:2.3:a:microsoft:site_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortianalyzer_firmware:5.2.0`,
        fs:  `cpe:2.3:a:openpkg:openpkg:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortianalyzer_firmware:5.2.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiauthenticator:3.0.0`,
        fs:  `cpe:2.3:a:polycom:rmx_system_software:7.5.0.j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:forticlient:-::~~~linux_kernel~~`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-400_cpu_414f-3_pn\/dp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:forticlient:4.0.2`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:forticlient:4.3.3.445`,
        fs:  `cpe:2.3:a:ibm:leads:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:forticlient:5.2.3.091::~~~android~~`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:forticlient:5.2.028::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:forticlient_lite:2.0`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:forticlient_lite:4.3.3.445`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:forticlient_ssl_vpn:4.0.2012`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-1000c:-`,
        fs:  `cpe:2.3:h:uplogix:local_manager_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-1000d:-`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:sp2:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-100d:-`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-110c:-`,
        fs:  `cpe:2.3:a:demosphere:agc:3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-1200d:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.0:rc.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-1240b:-`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:-:cloud:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-1500d:-`,
        fs:  `cpe:2.3:a:spip:spip:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-200b:-`,
        fs:  `cpe:2.3:a:otrs:faq:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-20c:-`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-3000d:-`,
        fs:  `cpe:2.3:a:avaya:network_reporting:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-300c:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:7.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-3040b:-`,
        fs:  `cpe:2.3:a:spip:spip:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-310b:-`,
        fs:  `cpe:2.3:a:neturf:ecommerce_shopping_cart:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-311b:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-3140b:-`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-3240c:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-3700d:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-3810a:-`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-3815d:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-3950b:-`,
        fs:  `cpe:2.3:o:hp:tru64:5.1_pk4_bl18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-40c:-`,
        fs:  `cpe:2.3:a:hp:pki_activex_control:1.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-5001a-sw:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-5001b:-`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-5020:-`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-5060:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-50b:-`,
        fs:  `cpe:2.3:a:microsoft:zero_administration_kit:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-5101c:-`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-5140b:-`,
        fs:  `cpe:2.3:a:cisco:unified_web_and_e-mail_interaction_manager:9.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-600c:-`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-60c:-`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-620b:-`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-800c:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-80c:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.24:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigate-voice-80c:-`,
        fs:  `cpe:2.3:a:ibm:jazz_reporting_service:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fortinet:fortigaterugged-100c:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1.\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:4.3.8`,
        fs:  `cpe:2.3:a:tecolote:acdbdotnet:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.1`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.2`,
        fs:  `cpe:2.3:a:gnu:screen:3.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.3`,
        fs:  `cpe:2.3:a:k7computing:total_security:14.2.0.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.6`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.7`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.8`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.9`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5501:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.0.10`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.1.1`,
        fs:  `cpe:2.3:h:grandstream:gxv3504:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.1.2`,
        fs:  `cpe:2.3:a:samba:samba:3.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.1.3`,
        fs:  `cpe:2.3:a:spip:spip:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.1.4`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.102.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.1.5`,
        fs:  `cpe:2.3:a:apple:xcode:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.1.6`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.1`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/e:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.3`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.4`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.5`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.6`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.7`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.8`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.2.9`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server:10.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3.1`,
        fs:  `cpe:2.3:a:keepass:keepass:0.94:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3.2`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3.3`,
        fs:  `cpe:2.3:a:csounds:csound:5.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3.4`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3.6`,
        fs:  `cpe:2.3:a:ca:unicenter_network_and_systems_management:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3.7`,
        fs:  `cpe:2.3:a:roxio:cineplayer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortimail:5.3.8`,
        fs:  `cpe:2.3:o:gehealthcare:centricity_dms_firmware:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.0.3`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.0.4`,
        fs:  `cpe:2.3:a:tigerlogic:d3_odbc_client:2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.0.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.0.6`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.0.7`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.0.8`,
        fs:  `cpe:2.3:a:teradata:workload_analyzer:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.0.9`,
        fs:  `cpe:2.3:a:web2py:web2py:1.76.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.0.10`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.7:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.2.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortimanager_firmware:5.2.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.86:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.0`,
        fs:  `cpe:2.3:a:vmware:workstation:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.12`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.92.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.13`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.14`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.1\(3\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.15`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.16`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.17`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:4.3.18`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.0`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.1`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.2`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.3`,
        fs:  `cpe:2.3:h:3com:tippingpoint_2400e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.4`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.5`,
        fs:  `cpe:2.3:a:php:directory_listing_script:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.7`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.9`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.m0.62842:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.0.12`,
        fs:  `cpe:2.3:a:clamav:clamav:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.1`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.1.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.2`,
        fs:  `cpe:2.3:h:huawei:quidway_s2350:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.3`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0195:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.4`,
        fs:  `cpe:2.3:h:supermicro:x8si6-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.5`,
        fs:  `cpe:2.3:a:ibm:http_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.6`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.7`,
        fs:  `cpe:2.3:h:linksys:wip_330_wireless-g_ip_phone:1.0.6_a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.8`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.2.9`,
        fs:  `cpe:2.3:h:cisco:content_router_4450:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.4`,
        fs:  `cpe:2.3:a:posh_project:posh:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.4.0`,
        fs:  `cpe:2.3:a:content_rating_extbase_project:content_rating_extbase:2.0.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:fortinet:fortios:5.4.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.492.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.0.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.0.3`,
        fs:  `cpe:2.3:a:debian:fsp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.0.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(2m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.1.0`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.1.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.297:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.1.2`,
        fs:  `cpe:2.3:a:apache:mod_python:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.1.3`,
        fs:  `cpe:2.3:a:netscape:communicator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.1.4`,
        fs:  `cpe:2.3:a:f-secure:anti-virus:-:-:-:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.2.0`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.2.1`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.2.2`,
        fs:  `cpe:2.3:a:collectiveaccess:pawtucket:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.2.3`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.2.4`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.3.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.3.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.3.2`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.3.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.8:update8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:fortiweb:5.3.4`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fortinet:single_sign_on:4.3`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foscam:h.264_hi3510%2f11%2f12_ip_camera:-`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:foscam:ip_camera_firmware:11.37.2.49`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.0.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.0.1`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.0.2`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.0.3`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.0.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.0.10`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.1.2`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.1.3`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.1.4`,
        fs:  `cpe:2.3:h:lanier:rpcs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.1.5`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.1.6`,
        fs:  `cpe:2.3:a:apache:ofbiz:11.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foswiki:foswiki:1.1.7`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fotoschilenas:akne_ernahrung:1::~~~android~~`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fotoschilenas:pregnancy_tips:1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fotoschilenas:recetas_de_tragos:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:samba:samba:3.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:bigiron_15000_router:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.11:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:bigiron_4000_router:-`,
        fs:  `cpe:2.3:a:adobe:pdf_settings:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:bigiron_4000_switch:-`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:bigiron_800_backbone:-`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:bigiron_800_router:-`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:bigiron_8000_router:-`,
        fs:  `cpe:2.3:a:mcafee:vulnerability_manager:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:bigiron_8000_switch:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:bigiron_mg8_switch:-`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:edgeiron_eif4802cf_switch:-`,
        fs:  `cpe:2.3:a:microsoft:outlook:xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:edgeiron_eif48g_switch:-`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fastiron_400_switch:-`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:6.0.417.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fastiron_4802_switch:-`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fastiron_800_switch:-`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.0.0-95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fastiron_ii_router:-`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fastiron_ii_switch:-`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fastiron_iii_switch:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fastiron_workgroup_switch:-`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fes_2402_switch:-`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fes_4802_switch:-`,
        fs:  `cpe:2.3:a:symantec:protection_engine:7.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:fes_9604_switch:-`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:foundrynet:ironpoint_200_wireless_access_point:-`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.2\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foundstone:foundstone_ssldigger:1.0`,
        fs:  `cpe:2.3:h:cisco:epc3010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourelle:venturi_client:3.1.4`,
        fs:  `cpe:2.3:a:3com:3c16115-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:5.x-1.0`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:5.x-1.0:rc`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:5.x-1.1`,
        fs:  `cpe:2.3:a:microsoft:xml_parser:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:5.x-1.x:dev`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:6.x-1.0`,
        fs:  `cpe:2.3:a:mvd:surething_cd_labeler:4.3.196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:6.x-1.1`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:6.x-1.2`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:6.x-1.3`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.65:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:6.x-1.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:6.x-1.4:beta1`,
        fs:  `cpe:2.3:a:iain:gypsy:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:monotone:monotone:0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:7.x-1.0`,
        fs:  `cpe:2.3:a:netkit-ftp:netkit_ftpd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:block_class:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:gnome:glib:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:ed_readmore:6.x-3.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp3:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:ed_readmore:6.x-3.1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fourkitchens:ed_readmore:6.x-3.x:dev`,
        fs:  `cpe:2.3:h:symantec:nexland_pro400_firewall_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fox-it:fox_datadiode:1.7.1`,
        fs:  `cpe:2.3:h:d-link:dir-826l_wireless_n600_cloud_router:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:enterprise_reader:7.0.6.1126`,
        fs:  `cpe:2.3:a:symantec:liveupdate:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:enterprise_reader:7.1.3.320`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_advanced_pdf_editor:3.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_advanced_pdf_editor:3.04`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_mobilepdf_-_pdf_reader:2.2.0.0616::~~~android~~`,
        fs:  `cpe:2.3:h:ibm:mcs-7815i-2.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_pdf_sdk_activex:2.3`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_pdf_sdk_activex:3.0`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_pdf_sdk_activex:4.0`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_pdf_sdk_activex:5.0.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.7:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_pdf_sdk_activex:5.0.1.820`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.92:e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_pdf_sdk_dll:3.1.1.2927`,
        fs:  `cpe:2.3:h:cisco:nexus_6004x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_pdf_sdk_dll:3.1.1.5005`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:2.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:2.3`,
        fs:  `cpe:2.3:a:google:chrome:16.0.911.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:3.0`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:3.1.2.1013`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:3.1.2.1030`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:3.2.0.0303`,
        fs:  `cpe:2.3:a:samba:samba:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:3.2.1.0401`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:4.0`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:4.0.0.0619`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:4.1`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:4.1.1.0805`,
        fs:  `cpe:2.3:a:hp:business_availability_center:8.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:4.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:4.3`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.x:dev:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:4.3.1.0218`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:5.0`,
        fs:  `cpe:2.3:a:keepass:keepass:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:5.0.2`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.0:build110427:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:5.1.0.1021`,
        fs:  `cpe:2.3:a:emc:engineering_plant_facilities_management_solution_for_documentum:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:5.1.3`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:5.1.4.0104`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:5.3.1.0606`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:6.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:7.0.6.1126`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:7.2.0.722`,
        fs:  `cpe:2.3:a:microsoft:office_web_components:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:foxit_reader:7.3.0.118::~~~windows~~`,
        fs:  `cpe:2.3:a:john_nunemaker:crack:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:phantompdf:7.0.6.1126`,
        fs:  `cpe:2.3:a:f5:big-ip_protocol_security_module:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:phantompdf:7.1.3.320`,
        fs:  `cpe:2.3:a:google:chrome:14.0.809.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:phantompdf:7.2.0.722`,
        fs:  `cpe:2.3:a:hp:lefthand_virtual_san_appliance_hydra_software:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:phantompdf:7.3.0.118::~~~windows~~`,
        fs:  `cpe:2.3:a:hp:quality_center:9.2_patch_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:reader:6.1`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:foxitsoftware:reader:7.3.0.118::~~~windows~~`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:4.72.2106.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fpinternet:texas_poker_unlimited_hold%27em:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fractalconcept:mod_lisp:2.35`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.10.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:francisco_cifuentes:vote_for_tt_news:1.0.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frandroid:forum_frandroid_beta:3.4.3::~~~android~~`,
        fs:  `cpe:2.3:h:hp:ce992a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frank_matano_project:frank_matano:1::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:franklinfueling:ts-550_evo:-`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:franklinfueling:ts-550_evo_firmware:2.0.0.6833`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:franklinfueling:ts-550_evo_firmware:2.3.1.7492`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1006.101.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:franklinfueling:ts-550_evo_firmware:2.4.0`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franklychat:frankly_chat:3.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.4.0`,
        fs:  `cpe:2.3:a:posh_project:posh:1.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.4.1`,
        fs:  `cpe:2.3:a:ibm:sametime:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.4.2`,
        fs:  `cpe:2.3:a:novell:edirectory:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.4.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.4.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.4.5`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc655a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.4.6`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.5.0`,
        fs:  `cpe:2.3:a:hp:loadrunner:12.50:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:franz_holzinger:static_methods:0.5.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:free_ebooks_project:free_ebooks:14.0::~~~android~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:free_pageplus_activation_project:free_pageplus_activation:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeaudiovideosoft:free_iso_create_wizard:3.6.1.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:aide:-`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:fetch:-`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:0.4_1`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.94.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:1.0`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.60.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:1.1`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:1.1.5`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:-:seccenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:1.1.5.1`,
        fs:  `cpe:2.3:a:roxio:cineplayer:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:1.2`,
        fs:  `cpe:2.3:a:samba:samba:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:1.5`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.0.1`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ece:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.0.5`,
        fs:  `cpe:2.3:a:opera:opera_browser:4.00:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.1.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.1.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.1.6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_vista:2010.211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.1.6.1`,
        fs:  `cpe:2.3:o:google:android:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.1.7`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.1.7.1`,
        fs:  `cpe:2.3:a:sun:java_system_content_delivery_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2.1`,
        fs:  `cpe:2.3:a:mono:mono:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2.2`,
        fs:  `cpe:2.3:a:openttd:openttd:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2.3`,
        fs:  `cpe:2.3:a:apache:activemq:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2.8.1201.1503:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2.5`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.00:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2.6`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2.7`,
        fs:  `cpe:2.3:a:logitech:quickcam:11.10.2030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:2.2.8`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:3.0`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:3.1`,
        fs:  `cpe:2.3:a:boombatower:subuser:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:3.2`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:ccc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:3.3`,
        fs:  `cpe:2.3:a:ibm:java:5.0.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:3.4`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:3.5`,
        fs:  `cpe:2.3:a:ibm:maximo_service_desk:7.1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:3.5.1`,
        fs:  `cpe:2.3:a:symantec:data_insight:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.417:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.1`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.1.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1675.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.799.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.4`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.6`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.6.2`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5033-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.7`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.8`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.9`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.3.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.10`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:4.11`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:5.0`,
        fs:  `cpe:2.3:o:cisco:ons_15600:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:5.2`,
        fs:  `cpe:2.3:a:microsoft:windows_messaging:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:5.2.1`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2003:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:5.3`,
        fs:  `cpe:2.3:a:wali:walisms_cn:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:5.4`,
        fs:  `cpe:2.3:a:real:realplayer:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:5.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:6.0`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:6.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:6.2`,
        fs:  `cpe:2.3:a:jenkins:git:2.6.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:6.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:6.4`,
        fs:  `cpe:2.3:a:curtis_galloway:exif:0.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:7.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5800-56c-pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:7.1`,
        fs:  `cpe:2.3:o:xen:xen:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:7.1:rc1`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:7.2`,
        fs:  `cpe:2.3:a:apache:subversion:0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:7.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.395:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:7.4`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:8.0`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:8.1`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:8.2`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:8.3`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:8.4`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:9.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:9.1`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:9.1:release-p4`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:9.1:release-p5`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:11.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:9.2:-`,
        fs:  `cpe:2.3:a:otrs:faq:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:9.2:prerelease`,
        fs:  `cpe:2.3:h:ibm:m80:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:9.2:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:9.2:rc2`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:10.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:10.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freebsd:freebsd:10.3`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:heimdal:-`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:heimdal:0.4e`,
        fs:  `cpe:2.3:a:digia:qt:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:ja-xklock:-`,
        fs:  `cpe:2.3:a:libgd:libgd:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:ja-xklock:2.7.1`,
        fs:  `cpe:2.3:a:sap:ccms_\/_database_monitor:-:*:*:*:*:oracle:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:libarchive:-`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:libarchive:2.2.3`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:slashem-tty:-`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freebsd:slashem-tty:0.0.6e.4f.8`,
        fs:  `cpe:2.3:a:google:chrome:6.0.435.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.72`,
        fs:  `cpe:2.3:a:altova:umodel_2012:-:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.73`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.982:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.74`,
        fs:  `cpe:2.3:a:compaq:insight_management_agent:4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.76`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.78`,
        fs:  `cpe:2.3:a:emc:navisphere_service_taskbar:24.50.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.80`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.82`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.84`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.86`,
        fs:  `cpe:2.3:a:magzter:autocar_india:3.03:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.88`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.90`,
        fs:  `cpe:2.3:a:openx:openx:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.92`,
        fs:  `cpe:2.3:o:sun:sunos:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.94`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.96`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.98`,
        fs:  `cpe:2.3:a:luracast:restler:0.3.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.100`,
        fs:  `cpe:2.3:a:ca:secure_content_manager:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.100.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:dbus-glib:0.100.2`,
        fs:  `cpe:2.3:a:aol:aim:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:libdbus:1.5.0`,
        fs:  `cpe:2.3:a:typo3:flow:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:libdbus:1.5.2`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:libdbus:1.5.4`,
        fs:  `cpe:2.3:a:tibco:spotfire_professional:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:libdbus:1.5.6`,
        fs:  `cpe:2.3:h:yokogawa:omegaland\/opc_server_interface_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:libdbus:1.5.8`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.46.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:libdbus:1.5.10`,
        fs:  `cpe:2.3:a:pimcore:pimcore:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:libdbus:1.5.12`,
        fs:  `cpe:2.3:a:rpm:rpm:4.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.1`,
        fs:  `cpe:2.3:a:justsystems:atok:2008:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.1.1`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.1.2`,
        fs:  `cpe:2.3:a:extplorer:extplorer:2.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.2.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(4b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.3.0`,
        fs:  `cpe:2.3:a:augeas:augeas:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.3.1`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.3.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.3.3`,
        fs:  `cpe:2.3:a:apache:commons_fileupload:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.4.0`,
        fs:  `cpe:2.3:a:adobe:creative_suite_4_production_premium:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.4.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.4.3`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.4.4`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.5.0`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.5.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.5.2`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.5.3`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.5.4`,
        fs:  `cpe:2.3:h:cisco:unified_computing_system_integrated_management_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.5.9`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.5.90`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.5.91`,
        fs:  `cpe:2.3:a:overdrive:overdrive_media_console:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.6.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.6.1`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.6.2`,
        fs:  `cpe:2.3:h:hp:ce991a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.6.3`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.6.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.7.0`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.7.1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.7.2`,
        fs:  `cpe:2.3:a:hp:bufferchm:130.0.331.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.7.3`,
        fs:  `cpe:2.3:a:zarafa:zarafa:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.8.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.8.1`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.27a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.8.2`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1\(3\)sr5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.8.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(4\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.8.4`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.8.5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.8.6`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.8.7`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:578:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.9.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.9.1`,
        fs:  `cpe:2.3:a:gnu:lsh:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.9.2`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.9.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.10.0`,
        fs:  `cpe:2.3:a:netiq:appmanager_management_server:7.0.41053.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.10.1`,
        fs:  `cpe:2.3:o:sgi:irix:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.10.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.10.3`,
        fs:  `cpe:2.3:o:xen:xen:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.10.4`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.10.5`,
        fs:  `cpe:2.3:a:surfcontrol:superscout_email_filter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.10.6`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.10.7`,
        fs:  `cpe:2.3:h:huawei:s2000:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.11.0`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.11.1`,
        fs:  `cpe:2.3:a:isc:bind:9.7.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.11.2`,
        fs:  `cpe:2.3:h:cisco:nexus_56128p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.11.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:2.5.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.12.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.0:rc1:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.12.1`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.12.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.12.3`,
        fs:  `cpe:2.3:a:isc:bind:9.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.12.4`,
        fs:  `cpe:2.3:a:iss:blackice_agent:2.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.13.0`,
        fs:  `cpe:2.3:a:dell:system_e-support_tool:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.13.1`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.13.2`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.0.1.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.13.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.13.4`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.14.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.14.1`,
        fs:  `cpe:2.3:a:ibm:db2:10.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.14.2`,
        fs:  `cpe:2.3:a:vim:vim:8.0.0377:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.14.3`,
        fs:  `cpe:2.3:a:apple:safari:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.14.4`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.14.5`,
        fs:  `cpe:2.3:h:cisco:xr_12406:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.15.0`,
        fs:  `cpe:2.3:h:cisco:secure_access_control_server_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.15.1`,
        fs:  `cpe:2.3:h:ibm:power_5:9110-51a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.15.2`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.15.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p260:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.16.0`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.16.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.16.2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.16.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.16.4`,
        fs:  `cpe:2.3:a:redhat:kvm:83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.16.5`,
        fs:  `cpe:2.3:a:verifone:vericentre_web_console:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.16.6`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.12:ga11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.16.7`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:1.26.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.17.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.17.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)tpc10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.17.2`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2013.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.17.3`,
        fs:  `cpe:2.3:a:tm_software:tempo:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.17.4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.18.0`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:16.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.18.1`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.18.2`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.18.3`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:a.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.18.4`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.19.0`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.19.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.19.2`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:01-02-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.19.3`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.19.4`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.20.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.20.1`,
        fs:  `cpe:2.3:a:herac:tuxguitar:1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.20.2`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.20.3`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.20.4`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.20.5`,
        fs:  `cpe:2.3:a:koha:koha:3.20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.21.0`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.21.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.21.2`,
        fs:  `cpe:2.3:a:apache:ambari:2.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.21.3`,
        fs:  `cpe:2.3:a:fujitsu:interstage_application_server:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.21.4`,
        fs:  `cpe:2.3:a:process-one:ejabberd:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.22.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.22.1`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:6.0:r1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.22.2`,
        fs:  `cpe:2.3:a:openpkg:openpkg:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.22.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(4l\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.22.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.22.5`,
        fs:  `cpe:2.3:a:apache:activemq:5.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.23.0`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.23.1`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:6.0.305.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.23.2`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:7.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.23.3`,
        fs:  `cpe:2.3:a:oracle:financial_consolidation_hub:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.23.4`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.24.0`,
        fs:  `cpe:2.3:h:rockwellautomation:rslinx_enterprise:cpr9:sr6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.24.1`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2-p4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.24.2`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.24.3`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.24.4`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.0\(4\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.24.5`,
        fs:  `cpe:2.3:a:microsoft:virtual_server:2005:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.25.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.25.1`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.25.2`,
        fs:  `cpe:2.3:h:cisco:pix_firewall_525:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.25.3`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r7_p2:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.26.0`,
        fs:  `cpe:2.3:o:sun:solaris:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.26.1`,
        fs:  `cpe:2.3:h:huawei:ne80e:v600r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.26.2`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.2:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.26.3`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.26.4`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.26.5`,
        fs:  `cpe:2.3:a:ibm:atlas_ediscovery_process_management:6.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.28.0`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.28.1`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.29.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.30.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.31.0`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.32.0`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.1.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.33.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5a\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.34.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.35.0`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.36.0`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.37.0`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.1.0:-:-:-:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.38.0`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:6.0:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.39.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.40.0`,
        fs:  `cpe:2.3:o:juniper:junos:16.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.41.0`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.42.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.384:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.43.0`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.44.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.1.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.45.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.3.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.46.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p227:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.47.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p349:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.48.0`,
        fs:  `cpe:2.3:a:altiris:patch_management_solution_documentation:6.2.1060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.49.0`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.50.0`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:6.0.305.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.51.0`,
        fs:  `cpe:2.3:a:ibm:lotus_mobile_connect:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.52.0`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:5.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.53.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:poppler:0.55.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:systemd:233`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.10:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.0.1`,
        fs:  `cpe:2.3:h:wangkongbao:cns-1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.0.4`,
        fs:  `cpe:2.3:a:mysql:mysql_connector\/odbc:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.0.5`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.0.3:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.90.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.91.0`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.92.0`,
        fs:  `cpe:2.3:o:huawei:s9306e_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.93.0`,
        fs:  `cpe:2.3:o:apple:os_x_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.94.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.899.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.95.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.96.0`,
        fs:  `cpe:2.3:a:apache:camel:2.0.0:m3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.97.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.1\(1.51\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.98.0`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:1.99.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.0.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.0.1`,
        fs:  `cpe:2.3:a:jan_bednarik:cooluri:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.0.90`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.03w-1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.0.91`,
        fs:  `cpe:2.3:a:commerceguys:commerce_reorder:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.0.92`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.1.0`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2src:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.1.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedesktop:udisks:2.1.3`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.5.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:braille:10.14.2289.0`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:17.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:braille:10.19.760.0`,
        fs:  `cpe:2.3:a:emc:networker:7.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:document_server:10.14.2289.0`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:document_server:10.16.3519.0`,
        fs:  `cpe:2.3:a:foolabs:xpdf:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:document_server:10.19.760.0`,
        fs:  `cpe:2.3:a:freedomscientific:fsreader:2.0.1012.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:ffdshow-fsi:10.16.0.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:fsreader:2.0.1012.0`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:jaws:8.0.2173.2`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:jaws:11.0.756.400`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:magic:11.0.603.2`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:synthesizer_eloquence:6.1.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:synthesizer_eloquence:6.1.4`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:3.1.2.1013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:talking_installer:8.0.2173.2`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:talking_installer:9.0.552.2`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:talking_installer:11.0.756.400`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:utilities:10.19.760.0`,
        fs:  `cpe:2.3:a:emc:connectrix_manager:11.2.1:-:-:*:converged_network_edition:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:video_intercept:10.14.2289.0`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:video_intercept:10.16.3519.0`,
        fs:  `cpe:2.3:a:xfree86:x11perf:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedomscientific:video_intercept:10.19.760.0`,
        fs:  `cpe:2.3:a:ca:network_and_systems_management:r11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedownloadmanager:free_download_manager:-`,
        fs:  `cpe:2.3:o:xen:xen:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedownloadmanager:free_download_manager:2.0`,
        fs:  `cpe:2.3:o:ibm:aix:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedownloadmanager:free_download_manager:3.0`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedownloadmanager:free_download_manager:3.8`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedownloadmanager:free_download_manager:3.9.3`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freedownloadmanager:freedownloadmanager:2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freefloat:freefloat_ftp_server:1.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3610-28p_ls-3610-28p-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeftpd:freeftpd:1.0.11`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeimage_project:freeimage:3.17.0`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:6.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.0.0`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.0.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.0.2`,
        fs:  `cpe:2.3:h:cisco:mobility_services_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.0.3`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ecb:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.0.4`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.0.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.1.0`,
        fs:  `cpe:2.3:a:jijitechnologies:active_directory_cleaner:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.1.1`,
        fs:  `cpe:2.3:o:cisco:catos:3.1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.1.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.1.3`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.1.4`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.2.0`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.2.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.2.3`,
        fs:  `cpe:2.3:a:adobe:connect:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.2.4`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.3.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_4506:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.3.1`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.3.2`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.3.3`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.4.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.4.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.4.3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.4.4`,
        fs:  `cpe:2.3:a:adobe:connect:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.5.1`,
        fs:  `cpe:2.3:a:citrix:xenapp_reports:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.5.2`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.5.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeipa:freeipa:4.6.1`,
        fs:  `cpe:2.3:a:todo_filter_project:todo_filter:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:v8:4.9.385:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:13.0.763.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:word_for_mac:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.12::~~~drupal~~`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelance-it-consultant:eu_cookie_compliance:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq_management:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.01`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.2`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/b:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.11`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.21`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.22`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.22:a`,
        fs:  `cpe:2.3:a:google:chrome:12.0.729.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.32`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.33`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.33.1`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.34`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:4.1.3g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.35`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.35.1`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.35.2`,
        fs:  `cpe:2.3:h:huawei:eudemon_usg5500:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.35.3`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelancerkit:freelancerkit:2.35.4`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelinking_for_case_tracker_project:freelinking_for_case_tracker:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:iliumsoft:ewallet:6.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freelinking_project:freelinking:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.0.2`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.0.3`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:645:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.1.0`,
        fs:  `cpe:2.3:a:abbyy:finereader_sprint:6.0.1395.4512:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.2.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.3.0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.3.1`,
        fs:  `cpe:2.3:a:cerulean_studios:trillian:3.1:*:*:*:basic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.4`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.5`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.6`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.6.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.6.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.6.7`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.7.1`,
        fs:  `cpe:2.3:h:huawei:ne5000e:v800r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.8.0`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.8.1`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_provisioning:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta12`,
        fs:  `cpe:2.3:a:hp:sitescope:11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta13`,
        fs:  `cpe:2.3:h:hp:jg516a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta14`,
        fs:  `cpe:2.3:o:freebsd:freebsd:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta15`,
        fs:  `cpe:2.3:a:apache:struts:2.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta16`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1676.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta17`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta18`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta19`,
        fs:  `cpe:2.3:a:cisco:meeting_server:1.9_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta20`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_bell_wifi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:beta9`,
        fs:  `cpe:2.3:h:everfocus:ecor264-16x1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:rc1`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:014:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:rc3`,
        fs:  `cpe:2.3:a:vandyke:securecrt:6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:rc4`,
        fs:  `cpe:2.3:h:cisco:content_switching_module_with_ssl:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:rc6`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:rc7`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:rc8`,
        fs:  `cpe:2.3:a:gnu:screen:3.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freemind:freemind:0.9.0:rc9`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freenac:freenac:2.2:rc3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freenac:freenac:3.0.0`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freenac:freenac:3.0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freenac:freenac:3.0.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.8:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freenas:freenas:-`,
        fs:  `cpe:2.3:a:ibm:rational_service_tester:8.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freenas:freenas:0.69:-:amd64`,
        fs:  `cpe:2.3:a:bernhard_wymann:torcs:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freenas:freenas:0.69:-:i386`,
        fs:  `cpe:2.3:a:compfight_project:compfight:1.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:freenas:freenas:0.69.1:-:amd64`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.0.2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freenas:freenas:0.69.1:-:i386`,
        fs:  `cpe:2.3:a:gnome:evolution:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freenas:freenas:0.686.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:freenas:freenas:0.686.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freepbx:freepbx:2.9`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.8:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)ea1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.2`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.3`,
        fs:  `cpe:2.3:a:teradata:puttools:1.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.4`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.5`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.6`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.7`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.7.1`,
        fs:  `cpe:2.3:h:supermicro:x8sie-ln4f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.8`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.8.1`,
        fs:  `cpe:2.3:h:extremenetworks:summit:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.9.0`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.9.1`,
        fs:  `cpe:2.3:a:altova:databasespy_2011:2.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.9.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:0.9.3`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.0.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.0.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.0.2`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.0.3`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:5.1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.0.4`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.0.5`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.0`,
        fs:  `cpe:2.3:h:tp-link:td-8816:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.1`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.2`,
        fs:  `cpe:2.3:h:enterasys:6h202-24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.3`,
        fs:  `cpe:2.3:a:apple:bonjour:1.0.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.5`,
        fs:  `cpe:2.3:a:emc:documentum_records_manager:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.7`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:1.1.8`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_laptops_desktops:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.0`,
        fs:  `cpe:2.3:h:cisco:asr_1002_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.0.1`,
        fs:  `cpe:2.3:a:informatica:mapping_template:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.0.2`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1034:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.0.3`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.0.4`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.0`,
        fs:  `cpe:2.3:a:debian:reprepro:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.1`,
        fs:  `cpe:2.3:o:redhat:linux:2.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.2`,
        fs:  `cpe:2.3:a:lttng:ust:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.3`,
        fs:  `cpe:2.3:a:phpnuke:submit_news_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.4`,
        fs:  `cpe:2.3:a:huawei:document_security_management:v100r002c03spc005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.8`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.9`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.10`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.11`,
        fs:  `cpe:2.3:a:openttd:openttd:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.1.12`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:2.2.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:3.0.2`,
        fs:  `cpe:2.3:a:microsoft:microsoft_tech_companion:1.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:3.0.3`,
        fs:  `cpe:2.3:h:hp:elitedesk_800_g2_dm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:3.0.4`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:3.0.5`,
        fs:  `cpe:2.3:a:tincan:phplist:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:3.0.6`,
        fs:  `cpe:2.3:a:hitachi:compute_systems_manager:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:3.0.7`,
        fs:  `cpe:2.3:a:htc:hero_software:1.56.651.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeradius:freeradius:3.0.8`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freerdp_project:freerdp:1.0.0`,
        fs:  `cpe:2.3:h:axis:2401_video_server:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freerdp_project:freerdp:1.0.1`,
        fs:  `cpe:2.3:h:lexmark:n4050e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freerdp_project:freerdp:1.0.2`,
        fs:  `cpe:2.3:a:pnmsoft:sequence_kinetics:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freereprintables:articlefr:3.0.4`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freereprintables:articlefr:3.0.6`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freesql:freesql:1.0.0`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.06.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freesshd:freesshd:1.2.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freesshd:freesshd:1.2.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freesshd:freesshd:1.2.6`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.010.20056:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freeswitch:freeswitch:1.2`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.3:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetibet:herbal_guide:1::~~~android~~`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.0:beta2:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:1.3.1`,
        fs:  `cpe:2.3:a:logitech:mvision:11.50.1169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0`,
        fs:  `cpe:2.3:a:ibm:sametime:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.1`,
        fs:  `cpe:2.3:a:getpixie:pixie:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.2`,
        fs:  `cpe:2.3:a:zope:zope:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.4`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.5`,
        fs:  `cpe:2.3:a:oracle:applications_framework:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.6`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.7`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.8`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.7_pre1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.0.9`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.3`,
        fs:  `cpe:2.3:a:ibm:vios:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.4`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.5`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.6`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.7`,
        fs:  `cpe:2.3:a:openbravo:openbravo_erp:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.8`,
        fs:  `cpe:2.3:a:digium:asterisk:11.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.8:rc1`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.8_rc1`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.9`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.1.10`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.2`,
        fs:  `cpe:2.3:a:businessobjects:report_application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.2.1`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.2`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.5.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.3`,
        fs:  `cpe:2.3:o:sharp:aquos_hn-pp150_firmware:1.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.6`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.7`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.8`,
        fs:  `cpe:2.3:a:haxx:curl:7.52.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.9`,
        fs:  `cpe:2.3:a:cpuid:cpu-z:1.53.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.10`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.10:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.11`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.3.12`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.2.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.0`,
        fs:  `cpe:2.3:a:amiscu:westmoreland_water_fcu:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.1`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.3`,
        fs:  `cpe:2.3:a:hp:power_manager_remote_agent:4.0_build_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.4`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.5`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.6`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.7`,
        fs:  `cpe:2.3:a:drupal:drupal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.8`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.632:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.9`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.10`,
        fs:  `cpe:2.3:a:isaca:cism:6.2.208:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.11`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2000:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.4.12`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.5`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.5.1`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.5.2`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.5.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg305a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype:2.7`,
        fs:  `cpe:2.3:a:microsoft:ie:4.71.1712.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.1`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.2`,
        fs:  `cpe:2.3:a:plone:plone:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.3`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.6:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.4`,
        fs:  `cpe:2.3:a:addsoft:storebot:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.6`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.7`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.24:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.8`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3g:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.10`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.11`,
        fs:  `cpe:2.3:h:huawei:s2300:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.4.12`,
        fs:  `cpe:2.3:a:sympa:sympa:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.5.0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.5.0.1`,
        fs:  `cpe:2.3:a:mollify:mollify:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.5.1`,
        fs:  `cpe:2.3:h:hp:j9448a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.5.2`,
        fs:  `cpe:2.3:a:websense:websense_web_filter:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.5.3`,
        fs:  `cpe:2.3:a:apache:httpclient:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.5.4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.5.5`,
        fs:  `cpe:2.3:a:vmware:virtual_infrastructure_remote_command_line_interface:.278:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.6.0`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xnb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.6.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.6.3`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.6.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.6.5`,
        fs:  `cpe:2.3:a:apple:cups:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(13a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.7.0`,
        fs:  `cpe:2.3:a:etouch:samepage:4.4.0.0.239:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freetype:freetype2:2.7.1`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.4`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.5-66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.5`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.5:beta1`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.5:beta2`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.5:rc1`,
        fs:  `cpe:2.3:a:jollygiant:qws3270_secure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.5:rc2`,
        fs:  `cpe:2.3:h:primera:signature_iv_color_cd_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freka:yr_verdata:6.x-1.5:rc3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:french_national_commission_on_informatics_and_liberty:cookieviz:-`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:french_national_commission_on_informatics_and_liberty:cookieviz:1.0`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freshdirect:freshdirect:2.7.1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freshplanet:songpop:1.21.2::~~~android~~`,
        fs:  `cpe:2.3:a:apple:mail:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:6.x-2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(14.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:6.x-2.0:alpha1`,
        fs:  `cpe:2.3:o:redhat:enterprise_virtualization_manager:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:6.x-2.0:rc1`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:6.x-2.0:rc2`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.21-70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:6.x-2.1:rc1`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:6.x-2.x:dev`,
        fs:  `cpe:2.3:o:corel:linux:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:gitlist:gitlist:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:7.x-1.0:beta1`,
        fs:  `cpe:2.3:o:cisco:firepower_extensible_operating_system:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:freso:languageicons:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:friendcasterapp:friendcaster:5.4.5::~~~android~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.0.0:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.1.0:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.2.0:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.016.20045:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.2.1:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.2.3:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.2.4:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:apache:mod_python:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.2.5:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.3.0:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:h:hp:8gb_simple_san_connection_kit:ak241b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.3.1:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.3.2:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:1.3.3:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:symantec:norton_ghost:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:friends_of_symfony_project:fosuserbundle:2.0.0:-:~-~-~symfony~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3:beta`,
        fs:  `cpe:2.3:a:phptroubleticket:php_trouble_ticket:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3:rc`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3:rc1`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3:rc2`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3:rc3`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.0:-`,
        fs:  `cpe:2.3:a:janetter:janetter:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.02.307:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.3`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.4`,
        fs:  `cpe:2.3:o:centos:centos:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.5`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.6`,
        fs:  `cpe:2.3:a:google:chrome:5.0.340.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.7`,
        fs:  `cpe:2.3:a:ibm:worklight:6.1.0.1:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.8`,
        fs:  `cpe:2.3:a:axosoft:ontime:2010_web:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.10`,
        fs:  `cpe:2.3:a:cisco:accesspath:vs-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.11`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.12`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.13`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.14`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.15`,
        fs:  `cpe:2.3:a:apache:derby:10.11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.16`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.17`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.3054:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.18`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.19`,
        fs:  `cpe:2.3:a:avast:internet_security:11.1.2260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.20`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontaccounting:frontaccounting:2.3.21`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontend_uploader_project:frontend_uploader:0.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tincan:phplist:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontend_user_upload_project:frontend_user_upload:0.5.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontrange:devicewall:5.0`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontrange:devicewall_dynamic_activity_monitor:5.0.0`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontrange:goldmine:-`,
        fs:  `cpe:2.3:a:linux-ha:heartbeat:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontrange:goldmine:5.70`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontrange:goldmine:6.00`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p231:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontrange:heat:-`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.4:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontrange:heat:6.01`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:frontrange:iheat:-`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:froxlor:froxlor:0.9.34.2`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:6.x-4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.0`,
        fs:  `cpe:2.3:a:digia:qt:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:pl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.2`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.0.3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2009.925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.5`,
        fs:  `cpe:2.3:a:spip:spip:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.6`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.7`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.8`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.9`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.6.10`,
        fs:  `cpe:2.3:o:huawei:s9303e_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.99.905:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.1`,
        fs:  `cpe:2.3:a:cisco:email_security_appliance:9.8.5-085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.2`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:8.0.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.5`,
        fs:  `cpe:2.3:a:file_project:file:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.6`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.1.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.7`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(2\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.8`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.9`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.10`,
        fs:  `cpe:2.3:o:vmware:esx:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.7.11`,
        fs:  `cpe:2.3:a:quagga:quagga:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.0`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.2`,
        fs:  `cpe:2.3:a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.3`,
        fs:  `cpe:2.3:a:vmware:workstation_player:12.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.4`,
        fs:  `cpe:2.3:a:inria:ocaml:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.5`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.6`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.7`,
        fs:  `cpe:2.3:a:apache:subversion:m2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fruux:sabredav:1.8.9`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fte:fte_text_editor:-`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftpfs:ftpfs:-`,
        fs:  `cpe:2.3:a:hospira:mednet:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftpfs:ftpfs:0.1.1`,
        fs:  `cpe:2.3:a:webedition:webedition_cms:6.3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftpgetter:ftpgetter:3.51.0.05`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.32:prebeta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.582`,
        fs:  `cpe:2.3:a:gnu:enscript:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.583`,
        fs:  `cpe:2.3:a:teatrofrancoparenti:teatro_franco_parenti:1.4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.584`,
        fs:  `cpe:2.3:a:okacloud:domain_name_search_\&amp;_web_host:0.64.13398.55733:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.585`,
        fs:  `cpe:2.3:a:alex_barth:data:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.586`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.587`,
        fs:  `cpe:2.3:a:lepide:recoveryfix_for_ost_to_pst:11.3:*:*:*:evaluation:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.588`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(1j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.589`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.2\(1\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.590`,
        fs:  `cpe:2.3:a:redhat:kie_workbench:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.591`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.592`,
        fs:  `cpe:2.3:a:apple:cups:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.593`,
        fs:  `cpe:2.3:h:cisco:unity_server:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.594`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.595`,
        fs:  `cpe:2.3:a:adobe:framemaker:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.596`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.177:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.597`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.598`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.599`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:9.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.600`,
        fs:  `cpe:2.3:a:nowsms:now_sms_\&amp;_mms_gateway:2013.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.601`,
        fs:  `cpe:2.3:a:apple:safari:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.602`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.603`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1668.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.604`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.605`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.606`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.607`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.608`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.651.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.609`,
        fs:  `cpe:2.3:h:avaya:sg200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.610`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.611`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.612`,
        fs:  `cpe:2.3:a:e107:e107:0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.613`,
        fs:  `cpe:2.3:a:hp:instant_share_devices:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.614`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.615`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.616`,
        fs:  `cpe:2.3:o:cisco:staros:17.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.617`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.618`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.619`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.620`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.621`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.622`,
        fs:  `cpe:2.3:a:collabnet:subversion:1.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.623`,
        fs:  `cpe:2.3:a:milesj:decoda:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.624`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.625`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.0-11:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.0.0.626`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:git1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.3`,
        fs:  `cpe:2.3:a:vivonet:albion_college:2.1.16:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.4`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.5`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.6`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.7`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.8`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.9`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.10`,
        fs:  `cpe:2.3:a:usebb:usebb:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.11`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.4\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.12`,
        fs:  `cpe:2.3:h:cisco:mobility_services_engine:8.0\(110.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.0.15`,
        fs:  `cpe:2.3:a:zohocorp:servicedesk_plus:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.1.16`,
        fs:  `cpe:2.3:a:gnu:iceweasel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.2.17`,
        fs:  `cpe:2.3:h:nortel:contivity:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.2.18`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.2.19`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftprush:ftprush:1.1.3`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a1\(7b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftpshell:ftpshell_server:2002`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ftpx:ftp_explorer:10.5.19.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fuelrewards:fuel_rewards_network:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:windows_nt_option_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fujitsu:arrows_kiss_f-03d:-`,
        fs:  `cpe:2.3:a:digium:asterisk:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fujitsu:arrows_me_f-11d:-`,
        fs:  `cpe:2.3:a:vmware:vrealize_orchestrator:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fujitsu:arrows_tab_lte_f-01d:-`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:cardminder:v3.2l10`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fujitsu:f-12c:-`,
        fs:  `cpe:2.3:a:hp:client_automation_application_manager_agent:7.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_application_server:9.0.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_application_server:9.1.0`,
        fs:  `cpe:2.3:o:yamaha:rta54i:4.04.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_application_server:9.2.0`,
        fs:  `cpe:2.3:a:triumfant:triumfant_agent:4.3.4065.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_application_server:9.3.1`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_application_server:10.0.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_4j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_studio:9.0.0`,
        fs:  `cpe:2.3:a:att:communication_manager:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_studio:9.1.0`,
        fs:  `cpe:2.3:a:macromedia:dreamweaver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_studio:9.2.0`,
        fs:  `cpe:2.3:a:gnu:zlib:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:interstage_studio:10.0.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fujitsu:regza_phone_t-01d:-`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:scansnap:5.0.20.1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:scansnap_manager:v4.2l14`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:scansnap_manager:v5.0l20`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.120.1316.e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:scansnap_organizer:3.2.13.1`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:scansnap_organizer:4.1.11.18`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:scansnap_organizer:v3.2l13`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:scansnap_organizer:v4.1l11`,
        fs:  `cpe:2.3:a:thegr:dl:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fujitsu:scansnap_s1500:-`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:fujitsu:scansnap_s510:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.1.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:serverview_operations_manager:5.00.09`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.7.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:fujitsu:serverview_operations_manager:6.30.05`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fungames-forfree:sniper_shooter_free_-_fun_game:2.8::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:funny_photo_color_editor_project:funny_photo_color_editor:0.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:funnymonkey:feature_set:7.x-1.0-beta1::~~~drupal~~`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fuse_project:fuse:2.9.2`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusebox:fusebox:4.0.0`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.611:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusebox:fusebox:4.0.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusebox:fusebox:4.1.0`,
        fs:  `cpe:2.3:a:emc:networker:7.6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusebox:fusebox:4.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusebox:fusebox:5.0.0`,
        fs:  `cpe:2.3:a:apache:openjpa:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusebox:fusebox:5.1.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusebox:fusebox:5.5.0`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusebox:fusebox:5.5.1`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusedpress:buddypress-extended-frienship-request:1.0`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusedpress:buddypress-extended-frienship-request:1.0.1`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.02:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusedpress:buddypress-extended-frienship-request:1.0.2`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:1573:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fuseiso_project:fuseiso:20070708`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:2.0:-:basic`,
        fs:  `cpe:2.3:a:boost:boost:1.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:2.0:-:coldfusion`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:2.0:-:enterprise`,
        fs:  `cpe:2.3:a:nortel:media_processing_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:2.0:-:standard`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.24.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:3.0:-:basic`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:3.0:-:coldfusion`,
        fs:  `cpe:2.3:a:finalbeta:mywebsearch:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:3.0:-:enterprise`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:3.0:-:standard`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:3.2`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g54_firmware:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:4.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:4.0:-:basic`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:x6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:4.0:-:coldfusion`,
        fs:  `cpe:2.3:a:apache:roller:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:4.0:-:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1017.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk:fusetalk:4.0:-:standard`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk.:fusetalk:2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusetalk.:fusetalk:3.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.0`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:t1lib:t1lib:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.0:beta3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.0:beta4`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jax1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.0:dev`,
        fs:  `cpe:2.3:a:emc:documentum_wdk:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2009.211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53_92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusiondrupalthemes:fusion:6.x-1.13`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusionforge:fusionforge:5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yb4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusionforge:fusionforge:5.1`,
        fs:  `cpe:2.3:a:cisco:unified_cdm_platform_software:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusionforge:fusionforge:5.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fusionforge:fusionforge:6.0:rc3`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:kmail_cgi:-`,
        fs:  `cpe:2.3:a:jease:jease:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.0::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.1::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:ibm:connections:2.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.2::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:morfy_cms_project:morfy_cms:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.3::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:cisco:ip_call_center_express_enhanced:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.4::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:debian:adequate:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.5::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.6::~~ecommerce~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.7::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.8::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:adobe:extension_manager:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.9::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.10::~~ecommerce~~~`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.11::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:mp_form_mail_cgi:2.0.12::~~ecommerce~~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:revocounter_cgi:-`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.10:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:futomi:search_cgi:-`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:futurenuke:platinum:7.6.b.5`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:fylet:fylet_secure_large_file_sender:2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:te4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:g4stechnology:mn-nic-4-enc:-`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gadgettrak:gadgettrak_mobile_security:1.6::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.0.2`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1516f-3_pn\/dp_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.0.3`,
        fs:  `cpe:2.3:a:sap:network_interface_router:39.3:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.0.4`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.0.6`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6\(3\)_b45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.0`,
        fs:  `cpe:2.3:h:netgear:ssl312:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(1\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.4`,
        fs:  `cpe:2.3:a:google:v8:3.22.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.5`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:6.0.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.6`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.7`,
        fs:  `cpe:2.3:a:hp:webproxy:a.02.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.1.8`,
        fs:  `cpe:2.3:o:netgear:r8000_firmware:1.0.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.2.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.2.1`,
        fs:  `cpe:2.3:a:david_king:vino:2.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.2.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.2.3`,
        fs:  `cpe:2.3:a:yahoo:yui:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajennings:this:1.2.3:a`,
        fs:  `cpe:2.3:a:amazon:kindle:4.4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.2`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.2.1`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.3`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.4`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-07-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.4.1`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.14:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.5.1`,
        fs:  `cpe:2.3:a:altn:mdaemon:12.5.4:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.6`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.6.1`,
        fs:  `cpe:2.3:a:tenable:nessus:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.7`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.7.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.8`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.8.1`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.8.2`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.9`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.9.1`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.10`,
        fs:  `cpe:2.3:a:vmware:vcenter_update_manager:4.1.0.6589:update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.10.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.11`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000_software:2.23.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.11.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.11.2`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.11.3`,
        fs:  `cpe:2.3:o:hp:palm_webos:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.11.4`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.12`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.12.1`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.12.2`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.12.3`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1\(2\)es55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.12.4`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.12.5`,
        fs:  `cpe:2.3:a:red-gate:sql_packager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.12.5:alpha1`,
        fs:  `cpe:2.3:a:viscomsoft:image_viewer_cp_gold_sdk:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.12.5:beta1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.13`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.13.1`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.13.2`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.13.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p371:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.13.4`,
        fs:  `cpe:2.3:a:gnu:emacs:24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.14`,
        fs:  `cpe:2.3:o:sun:solaris:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.14.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(2\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.14.2`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.14.3`,
        fs:  `cpe:2.3:a:isc:bind:9.8.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.14.4`,
        fs:  `cpe:2.3:o:cisco:wap4410n_firmware:2.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(3d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.15.1`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.15.2`,
        fs:  `cpe:2.3:a:microsoft:directx:8.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.15.3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.15.4`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.16.4`,
        fs:  `cpe:2.3:a:yahoo:toolbar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gajim:gajim:0.16.7`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galen_charlton:marc-xml:1.0`,
        fs:  `cpe:2.3:a:hp:proliant_ilo_monitor_service:3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galen_charlton:marc-xml:1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galeriashqip:galeriashqip:1.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:galilmc:rio-47100_plc:-`,
        fs:  `cpe:2.3:a:ibm:installation_manager:1.8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:4.0.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.2`,
        fs:  `cpe:2.3:a:sphider:sphider:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.4`,
        fs:  `cpe:2.3:a:hp:openview_cross_platform_component:2.61.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.5`,
        fs:  `cpe:2.3:a:sun:jre:5.0.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.6`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.7`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.8`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galleryproject:gallery:3.0.9`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.4.121.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:galsila:il_brillo_parlante:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:game-insight:my_railway:1.1.33::~~~android~~`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:game-lion:allies_in_war:1.3.2::~~~android~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:game_tabs_project:game_tabs:0.4.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.1:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gamegou:perfect_kick:1.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gameinfo:best_racing%2fmoto_games_ranking:2.2.7::~~~android~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp3:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gameloft:brothers_in_arms_2_free%2b:1.2.0:b:~~~android~~`,
        fs:  `cpe:2.3:a:oracle:virtualization:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gameloft:ice_age_village:2.8.0:m:~~~android~~`,
        fs:  `cpe:2.3:a:adobe:bridge_cs5:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gameloft:wonder_zoo_-_animal_rescue_%21:1.6.1::~~~android~~`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gameresort:stupid_zombies:1.12::~~~android~~`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.9.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xv4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.0`,
        fs:  `cpe:2.3:a:horde:groupware:5.0.1:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.0:beta1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.0:rc1`,
        fs:  `cpe:2.3:o:quantum:scalar_i500_firmware:i8.2.2_\(645g.gs004\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.451.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.0:rc3`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.16:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.1`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.2`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1065.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.4`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.5`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.6`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.10.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.0:beta1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.0:rc1`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.1`,
        fs:  `cpe:2.3:o:apple:mac_os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.2`,
        fs:  `cpe:2.3:h:citrix:application_gateway:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.3`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.4`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.5`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.6`,
        fs:  `cpe:2.3:a:hp:bpdsoftware:82.0.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.11.7`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.0`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:8.0.0:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.0:beta1`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.0:rc1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.16:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.0:rc2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.1`,
        fs:  `cpe:2.3:a:plone:plone:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.3`,
        fs:  `cpe:2.3:a:openstack:swift:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.4`,
        fs:  `cpe:2.3:a:adobe:premiere_pro_cs3:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.12.5`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.13.0`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.13.0:beta1`,
        fs:  `cpe:2.3:a:sun:solaris_pc_netlink:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.13.0:rc1`,
        fs:  `cpe:2.3:a:monotone:monotone:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.13.1`,
        fs:  `cpe:2.3:a:mediachance:multimon_taskbar:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.13.2`,
        fs:  `cpe:2.3:a:cisco:webns:7.40.1.17s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.14.0`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.14.0:beta1`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.14.0:beta2`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.14.0:rc1`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.14.0:rc2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.14.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.15.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.15.0:beta1`,
        fs:  `cpe:2.3:a:netscape:messaging_server:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.15.0:rc1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganeti_project:ganeti:2.15.1`,
        fs:  `cpe:2.3:a:redmine:redmine:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.1.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.1.1`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.0:build110508:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.1.2`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.1.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.1.5`,
        fs:  `cpe:2.3:a:gnu:readline:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.1.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.1.7`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.1.8`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp2:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:2.2.0`,
        fs:  `cpe:2.3:a:augeas:augeas:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.3.0`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.3.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.4.1`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.4.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.0`,
        fs:  `cpe:2.3:a:samba:samba:3.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.2`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.3`,
        fs:  `cpe:2.3:a:invensys:dasabcip:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.4`,
        fs:  `cpe:2.3:h:rockwellautomation:1768-enbt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.5`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.6`,
        fs:  `cpe:2.3:h:supermicro:x9dr3-ln4f\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.7`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.8`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.9`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ganglia:ganglia-web:3.5.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gannett:argus_leader_print_edition:6.7::~~~android~~`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gannett:daily_advertiser_print:6.7::~~~android~~`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gannett:lansing_state_journal_print:6.7::~~~android~~`,
        fs:  `cpe:2.3:a:altiris:topology_viewer:6.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gapless_player:simzip:1.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gapless_player:simzip:1.2`,
        fs:  `cpe:2.3:a:juniper:http_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garagesale_project:garagesale:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:itunes:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garethjmsaunders:psiwin:2.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.28:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garip_ve_ilginc_olaylar_project:garip_ve_ilginc_olaylar:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:sprint:smartview:1.12.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garmin:communicator_plugin:2.6.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k:4.2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce_suite:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k:4.2.1`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs728tps:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k:4.3.0`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k:4.3.1`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k:4.4.0`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k_secure:14.2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k_secure:14.2.1`,
        fs:  `cpe:2.3:a:redhat:network_satellite:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k_secure:14.3.0`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k_secure:14.3.1`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garrettcom:magnum_managed_networks_software-6k_secure:14.4.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:garyjohnson2012:gary_johnson_for_president_%2712:0.75.13439.53899::~~~android~~`,
        fs:  `cpe:2.3:a:sas:visual_analytics:6.4:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gb-plugins:gb_gallery_slideshow:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcefcu:gulf_coast_educators_fcu:1.0.27::~~~android~~`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:beekeeping_forum:3.9.15::~~~android~~`,
        fs:  `cpe:2.3:a:rockwellautomation:1763-l16bbb_series_a:15.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:bersa_forum:3.9.16::~~~android~~`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:biplane_forum:3.7.14::~~~android~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:georgia_packing:3.9.16::~~~android~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:goat_forum:3.9.15::~~~android~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:home_repair:3.7.9::~~~android~~`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:homesteading_today:3.7.14::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:security_agent:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:slingshot_forum:3.9.14::~~~android~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:steyr_forum:3.9.12::~~~android~~`,
        fs:  `cpe:2.3:a:qlogic:sansurfer_fc_hba_management_agent:1.0.1281.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gcspublishing:wine_making:3.7.15::~~~android~~`,
        fs:  `cpe:2.3:h:asus:rt-g32:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:bently_nevada_3500%2f22m_serial:-`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:bently_nevada_3500%2f22m_serial_firmware:-`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:bently_nevada_3500%2f22m_usb:-`,
        fs:  `cpe:2.3:a:tobias_bathge:wp-table_reloaded:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:bently_nevada_3500%2f22m_usb_firmware:-`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_batch_execution:5.6`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:a`,
        fs:  `cpe:2.3:a:exim:exim:4.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:b`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:c`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:d`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:e`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:f`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p117:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:g`,
        fs:  `cpe:2.3:a:lookout:lookout:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:h`,
        fs:  `cpe:2.3:a:perl:perl:5.12.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:i`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:j`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_dnp3_i%2fo_driver:7.20:k`,
        fs:  `cpe:2.3:a:colorbox_node:dennis_blake:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:1.0`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:2.0`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:2.0:beta`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:3.0`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-4.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:3.1`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:3.5`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:4.0`,
        fs:  `cpe:2.3:a:collectivecolors:taxonomy_view_integrator_module:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:4.4.1`,
        fs:  `cpe:2.3:a:webmin:webmin:1.850:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:4.5`,
        fs:  `cpe:2.3:a:libraw:libraw:0.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_historian:5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p47:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_hmi%252fscada_cimplicity:8.2:sim24`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_hmi%2fscada_cimplicity:4.01`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_hmi%2fscada_cimplicity:7.5`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_hmi%2fscada_cimplicity:8.0`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:5.5:u1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_hmi%2fscada_cimplicity:8.1`,
        fs:  `cpe:2.3:h:tp-link:tl-wr841n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_hmi%2fscada_cimplicity:8.2`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_hmi%2fscada_ifix:5.0`,
        fs:  `cpe:2.3:a:apache:tika:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_hmi%2fscada_ifix:5.1`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_plant_applications:4.2.2`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_plant_applications:4.2.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_plant_applications:4.3.1`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_plant_applications:4.4.1`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_plant_applications:5.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp8:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_plant_applications:215.8`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:intelligent_platforms_proficy_process_systems:-`,
        fs:  `cpe:2.3:a:inmatrix:zoom_player:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_process_systems_with_cimplicity:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:nb:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_process_systems_with_cimplicity:1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_pulse:1.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_real-time_information_portal:-`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_real-time_information_portal:2.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_real-time_information_portal:3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(21\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_real-time_information_portal:3.0:sp1`,
        fs:  `cpe:2.3:o:oracle:integrated_lights_out_manager_firmware:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_real-time_information_portal:3.5`,
        fs:  `cpe:2.3:a:hbgary:hbgary_agent:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_proficy_real-time_information_portal:3.5:sp1`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_si7_i%2fo_driver:7.20`,
        fs:  `cpe:2.3:o:xen:xen:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ge:intelligent_platforms_si7_i%2fo_driver:7.42`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:multilink_ml1200:-`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:multilink_ml1200_firmware:4.2.1`,
        fs:  `cpe:2.3:a:logitech:lws_facebook:13.20.1166.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:multilink_ml1600:-`,
        fs:  `cpe:2.3:a:spip:spip:3.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:multilink_ml1600_firmware:4.2.1`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_form_module:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:multilink_ml2400:-`,
        fs:  `cpe:2.3:h:zebra:zp_450:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:multilink_ml2400_firmware:4.2.1`,
        fs:  `cpe:2.3:a:emc:quickscan:3.5.1.2829:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:multilink_ml3000:-`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:multilink_ml3000_firmware:5.2.0`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:multilink_ml3100:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(2\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:multilink_ml3100_firmware:5.2.0`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4.0202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:multilink_ml800:-`,
        fs:  `cpe:2.3:h:hp:0235a31x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:multilink_ml800_firmware:4.2.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:multilink_ml810:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:multilink_ml810_firmware:5.2.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.10:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:snmp%2fweb_adapter_1024746:-`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:snmp%2fweb_adapter_1024747:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.1.0\(254\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:snmp%2fweb_adapter_1024748:-`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ge:snmp%2fweb_adapter_1024921:-`,
        fs:  `cpe:2.3:h:hp:storevirtual_4730fc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ge:snmp%2fweb_adapter_firmware:4.7`,
        fs:  `cpe:2.3:h:nvidia:geforce_gtx_950m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gebrauchtwagenreport:dekra_used_car_report:3.0.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_free_mail_server:-`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:-:beta3`,
        fs:  `cpe:2.3:a:citrix:presentation_server_presentation_server_reports:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.0.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.0.2`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.93:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.0.5`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_netscaler:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.0.6`,
        fs:  `cpe:2.3:h:hp:3com_switch:4210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.0.7`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.1.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.1.0:beta1`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.1.1`,
        fs:  `cpe:2.3:a:unitedhawknation:united_hawk_nation:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.2.0`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.3.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.2.0:beta`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.2.3`,
        fs:  `cpe:2.3:a:ibm:http_server:6.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.2.4`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.2.5`,
        fs:  `cpe:2.3:a:secondfiction:blitz_bingo:2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.2.5:b`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:1.2.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:2.0`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:2.0.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:2.0.4`,
        fs:  `cpe:2.3:a:webmin:usermin:0.910:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:2.0.5`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:3.0`,
        fs:  `cpe:2.3:a:interworx:web_control_panel:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:3.0:beta`,
        fs:  `cpe:2.3:a:yahoo:messenger:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:3.0.1`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:4.0`,
        fs:  `cpe:2.3:o:lenovo:thinkserver_rd550_firmware:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:4.0:beta`,
        fs:  `cpe:2.3:a:skype:skype:3.5.0.234:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:4.0.1`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:4.0.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:5.0`,
        fs:  `cpe:2.3:a:apple:webkit:419.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:5.0:beta`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:5.0.1`,
        fs:  `cpe:2.3:h:xerox:workcentre:5645:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:5.0.2`,
        fs:  `cpe:2.3:h:3com:webbngss3nbxnts:4.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:5.0.3`,
        fs:  `cpe:2.3:a:icofx:icofx:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:6.0.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:6.1`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:6.1:beta`,
        fs:  `cpe:2.3:a:apache:subversion:0.28.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:6.2`,
        fs:  `cpe:2.3:a:novell:netmail:3.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:6.2.2`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.0`,
        fs:  `cpe:2.3:a:apache:derby:10.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.0:beta`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.1`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.1.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.1.2`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.8:b1:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.1.3`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.1.4`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.2`,
        fs:  `cpe:2.3:h:juniper:infranet_controller_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.2:beta`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.2.1`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.3`,
        fs:  `cpe:2.3:h:dell:latitude_e6420_xfr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.3:beta`,
        fs:  `cpe:2.3:o:apple:mac_os:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.3.1`,
        fs:  `cpe:2.3:a:yokogawa:exaopc:3.71.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.3.2`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.3.3`,
        fs:  `cpe:2.3:a:gnu:rsync:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.4`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.4:beta`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.4.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.5:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(24\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecad:axigen_mail_server:7.5.0`,
        fs:  `cpe:2.3:a:altova:xmlspy_2011:3.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gecu:gulf_credit_union:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:solarwinds:orion_web_performance_monitor:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.3.5`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.4.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.3.6`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.3.7`,
        fs:  `cpe:2.3:a:oracle:application_server_10g:10.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.3.8`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2011:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.3.9`,
        fs:  `cpe:2.3:a:augeas:augeas:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.3.10`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.30.269:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.3.11`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.4.0`,
        fs:  `cpe:2.3:a:csilvers:gperftools:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.5.0`,
        fs:  `cpe:2.3:a:openkm:openkm:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.5.0::ja`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.5.1`,
        fs:  `cpe:2.3:a:thegr:dl:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.5.1::ja`,
        fs:  `cpe:2.3:a:symantec:enterprise_firewall:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.5.2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.5.2::ja`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.6.0::ja`,
        fs:  `cpe:2.3:a:rsa:authentication_agent_for_web:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.6.0:-:ja`,
        fs:  `cpe:2.3:h:cisco:3660_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.6.0:sr1:ja`,
        fs:  `cpe:2.3:a:openttd:openttd:0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.6.0:sr2:ja`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.7.1`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.8.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.7asg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.8.2:sr1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:1.35`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:2.0.0:rc1`,
        fs:  `cpe:2.3:a:sega:sonic_cd_lite:1.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:geeklog:geeklog:2.0.0:rc2`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gegl:gegl:0.2.0`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:gehealthcare:centricity_dms_firmware:4.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gehealthcare:centricity_dms_firmware:4.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gehealthcare:centricity_dms_firmware:4.2`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gehealthcare:discovery_530c_firmware:-`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gehealthcare:optima_ct520_firmware:-`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gehealthcare:optima_ct540_firmware:-`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gehealthcare:optima_ct680_firmware:-`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gehealthcare:optima_mr360_firmware:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.8.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gemaire:gemaire%27s_hvac_assist:5::~~~android~~`,
        fs:  `cpe:2.3:a:apache:camel:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gemalto:gemezdiag:1.0.0`,
        fs:  `cpe:2.3:o:samsung:samsung_mobile:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gemalto:gempc430:1.0.0`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gemalto:integrator:1.0.0`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.16.295:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gemalto:pc-ccid:2.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gemalto:smartdiag:2.0.67.0`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gemalto:smartdiag:2.3.0.0`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gencat:artacces:1::~~~android~~`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:generaldynamics:pc_updater:2.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:generaldynamics:pc_updater:2.80.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.30:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:generaldynamics:taclane:-`,
        fs:  `cpe:2.3:a:google:earth:6.1.0.4857:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:generaldynamics:taclane:3`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genertel:genertel:2.6.0::~~~android~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.0.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(1\)xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.5`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.6`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.7`,
        fs:  `cpe:2.3:a:oracle:database_server:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.8`,
        fs:  `cpe:2.3:h:linksys:befvp41:1.40.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.9`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.1.9:a`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.63:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.1`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.07.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.627.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.4`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.6`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)xi7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.8:beta`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.9`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.9:a`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.2.91`,
        fs:  `cpe:2.3:a:apache:tomcat:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.30`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie-register:1.31`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genetechsolutions:pie_register:2.0.13::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(3d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:genexia:drgos:1.14`,
        fs:  `cpe:2.3:a:hp:hppdustdevil:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geniuscloud:smart_browser:2.0::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genixcms:genixcms:0.0.8`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:genixcms:genixcms:1.0.2`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:app-crypt_pinentry:-`,
        fs:  `cpe:2.3:a:gnu:enscript:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:app-crypt_pinentry:0.7.2`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:app-crypt_pinentry:0.7.2:r1`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:file:4.20`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:glibc:-`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:glibc:2.5:r3`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:libsndfile:-`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:libsndfile:1.0.17`,
        fs:  `cpe:2.3:a:redhat:jboss_web_framework_kit:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:-`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:1.2`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1042:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:1.4`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:1.4:rc1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:1.4:rc2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:1.4:rc3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:2.1.30:r9`,
        fs:  `cpe:2.3:h:xerox:document_centre_545:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:2.2.28:r7`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:gentoo:linux:2.3.30:r2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:linux_eix:-`,
        fs:  `cpe:2.3:a:php:php:5.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:linux_eix:0.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:linux_webapp-config:-`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:media-libs_jpeg:-`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:media-libs_jpeg:6b:r2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:media-libs_jpeg:6b:r3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.703.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:media-libs_jpeg:6b:r4`,
        fs:  `cpe:2.3:a:gnu:automake:1.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:media-libs_jpeg:6b:r5`,
        fs:  `cpe:2.3:o:tp-link:tl-wr741nd_\(5.0\)_firmware:141217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:media-libs_jpeg:6b:r6`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:unknown:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:-`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.80`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.81`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_real-time_information_portal:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.82`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.83`,
        fs:  `cpe:2.3:a:vmware:horizon_view:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.84`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.589:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.85`,
        fs:  `cpe:2.3:a:vortexgroup:light_alloy:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.86`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)db2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.87`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mirrorselect:0.88`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mldonkey_ebuild:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.11:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:mldonkey_ebuild:2.9.0:r2`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.8:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:nullmailer:1.11`,
        fs:  `cpe:2.3:a:httpwatch:httpwatch_basic:7.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:nvclock:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.20:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:nvclock:0.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:nview:-`,
        fs:  `cpe:2.3:a:cisco:cisco_technical_support:3.7.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:nview:4.51`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:poppassd_pam:-`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1049:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:poppassd_pam:1.0`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:portage:-`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:portage:2.0.51.22:r3`,
        fs:  `cpe:2.3:a:ca:brightstor_portal:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:portage:2.1.1:r2`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:portage:2.1.3.10`,
        fs:  `cpe:2.3:a:openpkg:openpkg:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:portage:2.1.4.4`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:qt-unixodbc:-`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r6_rc1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:qt-unixodbc:3.3.3`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.2f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:rootkit_hunter:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:rootkit_hunter:1.2`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:rootkit_hunter:1.2.1`,
        fs:  `cpe:2.3:a:libmms_project:libmms:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:rootkit_hunter:1.2.2`,
        fs:  `cpe:2.3:a:apache:traffic_server:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:rootkit_hunter:1.2.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:security:-`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:10.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:syslinux:-`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.140`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.150`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.160`,
        fs:  `cpe:2.3:a:ibm:os2_ftp_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.170`,
        fs:  `cpe:2.3:a:haxx:curl:7.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.180`,
        fs:  `cpe:2.3:a:microsoft:visio:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.200`,
        fs:  `cpe:2.3:a:digium:asterisk:12.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.210`,
        fs:  `cpe:2.3:h:readynet_solutions:wrt300n-dd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.220`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.230`,
        fs:  `cpe:2.3:a:autodesk:design_review:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.240`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.260`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.270`,
        fs:  `cpe:2.3:a:winzip:winzip:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.280`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.290`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.2.1651:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.300`,
        fs:  `cpe:2.3:a:e107:e107:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.310`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.320`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.330`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.340`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.370`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.380`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.390`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.400`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.410`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.420`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.430`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.440`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.6.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.450`,
        fs:  `cpe:2.3:a:apport_project:apport:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.470`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.480`,
        fs:  `cpe:2.3:h:xerox:document_centre_490:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.500`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.510`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.520`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.530`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-6530c_firmware:t430sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.550`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.495:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.560`,
        fs:  `cpe:2.3:h:cisco:c250_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.570`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.580`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:webmin:1.590`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:xdg-utils:-`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:xdg-utils:1.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:xdg-utils:1.1.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:xnview:-`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.1.4386.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:xnview:1.70`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:xnview:1.90.3`,
        fs:  `cpe:2.3:o:sgi:irix:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:xnview:1.91`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gentoo:xnview:1.92`,
        fs:  `cpe:2.3:h:nortel:symposium_call_center_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geo_mashup_project:geo_mashup:1.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geo_redirector_plugin_project:geo_redirector:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.01:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geodesicsolutions:geocore_max:7.3.0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geodesicsolutions:geocore_max:7.3.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geodesicsolutions:geocore_max:7.3.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geodesicsolutions:geocore_max:7.3.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1668.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geodesicsolutions:geocore_max:7.3.4`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geodesicsolutions:geocore_max:7.3.5`,
        fs:  `cpe:2.3:a:digium:asterisk:10.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geodesicsolutions:geocore_max:7.3.6`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.1`,
        fs:  `cpe:2.3:a:f5:big-iq_security:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.2`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.4`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.5`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.6`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.7`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.8`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:16.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.9`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.10`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.1:developer_preview:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.11`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.12`,
        fs:  `cpe:2.3:a:google:v8:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geoff_davies:contact_forms:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geopainting:gpsmapedit:1.1.73.2`,
        fs:  `cpe:2.3:o:debian:debian_linux:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:george_karpouzas:yet_another_question_%26_answer_system:1.0:alpha1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(5b\)a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:george_wassouf_project:george_wassouf:1::~~~android~~`,
        fs:  `cpe:2.3:a:drupal:drupal:6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gephi:gephi:0.7`,
        fs:  `cpe:2.3:a:posh_project:posh:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:germanwings:germanwings:2.1.13::~~~android~~`,
        fs:  `cpe:2.3:a:e107:e107:0.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:geteversnap:eversnap_private_photo_album:1.0.23::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0.4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getgosoft:getgo_download_manager:4.4.5.502`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getgosoft:getgo_download_manager:4.8.2.1346`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getgosoft:getgo_download_manager:4.9.0.1982`,
        fs:  `cpe:2.3:a:citrix:access_gateway:4.5:hf1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gethook:hook:0.9.3::~~~android~~`,
        fs:  `cpe:2.3:a:wave:trusted_drive_manager:3.3.3.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.2`,
        fs:  `cpe:2.3:a:ibm:license_metric_tool:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.3`,
        fs:  `cpe:2.3:a:gfi:vipre_antivirus:4.0.3272:-:premium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.4:b1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.6`,
        fs:  `cpe:2.3:a:hp:network_node_manager:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.7`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getid3:getid3:1.9.8`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getjar:azkend_gold:1.2.6::~~~android~~`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getnycelightworks:get_nyce_lightworks:0.84.13506.98953::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.726.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getpixie:pixie:1.01`,
        fs:  `cpe:2.3:a:pdfforge:pdfcreator:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getpixie:pixie:1.01:a`,
        fs:  `cpe:2.3:a:posh_project:posh:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getpixie:pixie:1.02`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_portal_server:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getpixie:pixie:1.03`,
        fs:  `cpe:2.3:a:hp:openview_performance_agent:4.70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getpixie:pixie:1.04`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getscoop:kontan_kiosk:%407f07025e::~~~android~~`,
        fs:  `cpe:2.3:a:3ds:3dvia_composer:6.8.1.1652:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getsentry:raven-ruby:0.12.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getsetgames:mega_jump:%407f080002::~~~android~~`,
        fs:  `cpe:2.3:o:dlink:des-3810_firmware:r2.20.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.5`,
        fs:  `cpe:2.3:a:redhat:conga:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.6`,
        fs:  `cpe:2.3:a:hp:bidi_channel_components_installer:1.2.0.2:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.7`,
        fs:  `cpe:2.3:o:ubnt:airvision_firmware:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.8`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.10`,
        fs:  `cpe:2.3:a:mcafee:quickclean:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.11`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.12`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.6.13`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7`,
        fs:  `cpe:2.3:a:aladdin:ghostview:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7:beta2`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7:beta3`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.1`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:016:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.2`,
        fs:  `cpe:2.3:a:lxml:lxml:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.3`,
        fs:  `cpe:2.3:a:cuoftexas:credit_union_of_texas_mobile:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.4`,
        fs:  `cpe:2.3:a:google:v8:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5:beta1`,
        fs:  `cpe:2.3:a:tripwire:tripwire_enterprise_console:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(4\)f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5:rc1`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5:rc2`,
        fs:  `cpe:2.3:a:pluck-cms:pluck:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5:rc3`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.0.1:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5:rc4`,
        fs:  `cpe:2.3:a:rsa:authentication_client:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5.1`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5.1:beta`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5.2`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.02:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.5.3`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6`,
        fs:  `cpe:2.3:a:bitrock:bitrock_installbuilder_enterprise:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6:rc1`,
        fs:  `cpe:2.3:a:cisco:unified_presence_server:1.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6:rc2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6:rc3`,
        fs:  `cpe:2.3:a:horde:imp:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6:rc4`,
        fs:  `cpe:2.3:a:drupal:drupal:6.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6.1`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.00:-:*:*:*:hp-ux:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6.2`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.4.0.46.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6.3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6.4`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6.7`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.6.9`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.7`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.8`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.8.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.8.2`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.7.8.3`,
        fs:  `cpe:2.3:h:hp:cd646a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.2\(3\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8:beta1`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8:beta2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8:beta3`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8:rc1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8:rc2`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8:rc3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8:rc4`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.1`,
        fs:  `cpe:2.3:a:splunk:splunk:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.2`,
        fs:  `cpe:2.3:a:autodesk:revit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.5`,
        fs:  `cpe:2.3:a:vmware:workstation:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.6`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.6.1`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.7`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.00:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.7.1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.7.2`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.7.3`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.7.4`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.7.5`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:gold:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.7.6`,
        fs:  `cpe:2.3:a:gnu:groff:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.7.6.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.8`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:9.0.4.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.8.1`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.8.2`,
        fs:  `cpe:2.3:a:erlang:crypto:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.8.3`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_set:07-50-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.8.4`,
        fs:  `cpe:2.3:a:x:x_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getshopped:wp_e-commerce:3.8.8.5`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:getswish:swish_payments:2.0::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_servers_software:x7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getusedtoit:wp_slimstat:3.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:watchguard:server_center:11.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:getusedtoit:wp_slimstat:3.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:onenote:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gewara:gewara:5.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:drupal:drupal:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gfi:gfi_languard:9.6.2010.1113`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gfi:gfi_languard_reportpack:9.0.2009.709`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)seb4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gfi:gfi_reportcenter_framework:3.6.2009.630`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gfi:vipre_antivirus:4.0.3272:-:premium`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.16s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ggbu:twitter_no_background:0.85.13509.97828::~~~android~~`,
        fs:  `cpe:2.3:a:git-scm:git:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ghozylab:gallery_-_photo_albums_-_portfolio:1.3.47::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:giantrobot:zipcart:6.x-1.2`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:giantrobot:zipcart:6.x-1.3`,
        fs:  `cpe:2.3:a:ecmwf:magics\&#43;\&#43;:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:giantrobot:zipcart:6.x-1.4`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.1j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:giantrobot:zipcart:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:giflib_project:giflib:5.1.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gigablast:gigabot:2.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gigablast:gigabot:3.0`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-beta3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gigabyte:dldrv2_activex_control:1.4.206.11`,
        fs:  `cpe:2.3:a:ca:workload_automation_ae:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gigaccsecure:gigacc_office:2.3`,
        fs:  `cpe:2.3:a:hp:laserjet_p3010_series_user_guide:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gigpress:gigpress:2.3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.53`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.500`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.504`,
        fs:  `cpe:2.3:a:oracle:diagnostics:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.508`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p95:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.516`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.518`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.2:a:core:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.525`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.542`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.547`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.554`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.558`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1\)dc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.564`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.567`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.569`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.580`,
        fs:  `cpe:2.3:a:haxx:curl:7.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gilles_lamiral:imapsync:1.584`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:-`,
        fs:  `cpe:2.3:h:sierrawireless:raven_xt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.0`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.992:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.2.13`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.2.14`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.4.0`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:3.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.4.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.4.2`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass_pro:6.3.4:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.4.3`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.4.4`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.4.5`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.4.6`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.8.0.910:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.4.7`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.0`,
        fs:  `cpe:2.3:a:synology:photo_station:6.3-2944:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.1`,
        fs:  `cpe:2.3:a:tejonstore:secretos_de_belleza:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.3`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.4`,
        fs:  `cpe:2.3:a:niif:shibb_auth:7.x-4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.5`,
        fs:  `cpe:2.3:a:isc:inn:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.6`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.7`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.8`,
        fs:  `cpe:2.3:a:bea:weblogic_workshop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.9`,
        fs:  `cpe:2.3:a:ronan_dowling:node_hierarchy:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.10`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.11`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_firmware:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.12`,
        fs:  `cpe:2.3:a:gradkell:dbsign:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.6.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.29:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.8.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gimp:gimp:2.8.16`,
        fs:  `cpe:2.3:a:microsoft:word:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ginkgo-cms:ginkgocms:5.0`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:girlsgames123:kiss_kiss_office:1.0::~~~android~~`,
        fs:  `cpe:2.3:h:hp:j8715b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:0.01`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5604:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:0.02`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:0.03`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(9.4\)da:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:0.04`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p338:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.00`,
        fs:  `cpe:2.3:a:debian:dpkg:1.15.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.01`,
        fs:  `cpe:2.3:a:google:v8:3.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.02`,
        fs:  `cpe:2.3:a:novell:imanager:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.03`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.04`,
        fs:  `cpe:2.3:a:mysql:mysql_eventum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.05`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110614:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.5.40_01`,
        fs:  `cpe:2.3:a:hp:hppscanto:1.102.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.06`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.07`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:12.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.08`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.09`,
        fs:  `cpe:2.3:a:sun:jre:6.0.160:update16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.10`,
        fs:  `cpe:2.3:a:trihedral:vtscada:8.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.11`,
        fs:  `cpe:2.3:a:uplus:u\&#43;box_2.0:2.0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.12`,
        fs:  `cpe:2.3:a:rpm:rpm:4.4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.13`,
        fs:  `cpe:2.3:a:oracle:database_server:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.14`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.15`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.16`,
        fs:  `cpe:2.3:a:gitlist:gitlist:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.17`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.18`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.18_03`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.18_04`,
        fs:  `cpe:2.3:a:gamegou:perfect_kick:1.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.18_05`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.19`,
        fs:  `cpe:2.3:a:logitech:vid_hd:7.2_\(7230\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.20`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.21`,
        fs:  `cpe:2.3:a:simplerisk:simplerisk:20130916-001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.22`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.30`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.8.432:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.31`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.32`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.33`,
        fs:  `cpe:2.3:o:suse:suse_linux:6.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.34`,
        fs:  `cpe:2.3:a:google:chrome:5.0.344.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.35`,
        fs:  `cpe:2.3:a:qbnz:geshi:1.0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.36`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.41`,
        fs:  `cpe:2.3:a:isc:bind:9.7.4b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.42`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.43`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.44`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.45`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.46`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.47`,
        fs:  `cpe:2.3:h:intel:c206_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.48`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.49`,
        fs:  `cpe:2.3:a:adobe:fireworks_cs4:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.50`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.51`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.21:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.52`,
        fs:  `cpe:2.3:a:mybb:mybb:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53`,
        fs:  `cpe:2.3:a:buffalotech:wer-ag54_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53_90`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-451c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53_91`,
        fs:  `cpe:2.3:a:xfree86:x11perf:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53_92`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53_93`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53_94`,
        fs:  `cpe:2.3:a:citrix:xenapp_management:6.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53_95`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53_96`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.53_97`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.60`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.61`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.62`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x45:d15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.63`,
        fs:  `cpe:2.3:o:cisco:ios:3.7.0e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.64`,
        fs:  `cpe:2.3:h:hp:a2w78a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.65`,
        fs:  `cpe:2.3:a:git-scm:git:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.66`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.67`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.3:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.68`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.69`,
        fs:  `cpe:2.3:a:horde:gollem:1.0.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.70`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.71`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.72`,
        fs:  `cpe:2.3:o:huawei:s6300ei_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.73`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.74`,
        fs:  `cpe:2.3:a:ca:single_sign-on:r6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.75`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.76`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.77`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.5:-:-:*:enterprise:-:-:publish_engine`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.78`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.79`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.800`,
        fs:  `cpe:2.3:h:xerox:workcentre:232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.801`,
        fs:  `cpe:2.3:a:apache:mod_dontdothat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.802`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.15:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.803`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-00-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.804`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.805`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.19898:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.806`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.807`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.808`,
        fs:  `cpe:2.3:a:apache:httpclient:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.810`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.811`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.812`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.813`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p61:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.814`,
        fs:  `cpe:2.3:a:automatedqa:testexecute_demo:7.52.678.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.815`,
        fs:  `cpe:2.3:a:intra-mart:webplatform\/appframework:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.816`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.817`,
        fs:  `cpe:2.3:a:apple:cups:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.818`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.4.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.819`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.820`,
        fs:  `cpe:2.3:o:windriver:vxworks:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.821`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.822`,
        fs:  `cpe:2.3:a:ibm:db2_runtime_client:9.1.401.444:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.823`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.824`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.825`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.826`,
        fs:  `cpe:2.3:a:imop:long:1.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.827`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.828`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.829`,
        fs:  `cpe:2.3:a:login_security_project:login_security:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.830`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.831`,
        fs:  `cpe:2.3:a:redmine:redmine:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.832`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.833`,
        fs:  `cpe:2.3:a:symantec:web_security:3.01.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.834`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.835`,
        fs:  `cpe:2.3:a:samba:samba:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5.836`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b5`,
        fs:  `cpe:2.3:a:google:chrome:7.0.520.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b6`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-05-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b7`,
        fs:  `cpe:2.3:a:web-dorado:spider_facebook:1.0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b8`,
        fs:  `cpe:2.3:a:adobe:anchor_service_cs4:2.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b9`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b10`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b11`,
        fs:  `cpe:2.3:a:websense:enterprise:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b12`,
        fs:  `cpe:2.3:a:nextapp:echo:3.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gisle_aas:libwww-perl:5b13`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.300:update30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.6.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.6.1`,
        fs:  `cpe:2.3:a:debian:txt2man:1.5.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.6.2`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.6.3`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.6.4`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2005:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.6.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2009.211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.7.0`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.7.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.7.1`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.7.2`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_series_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.7.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.7.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.7.5`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:45.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.8.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.8.1`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.8.2`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.8.3`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.8.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.4sq:3.4.1sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.9.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.35:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.9.1`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.9.2`,
        fs:  `cpe:2.3:o:xen:xen:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.9.3`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.10.0`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.08.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.10.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.10.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.11.0`,
        fs:  `cpe:2.3:o:conectiva:linux:ecommerce:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.12.0`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.584:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.13.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.14.0`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.15.0`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.16.0`,
        fs:  `cpe:2.3:h:hp:presentation_barcode_scanner_qy439aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.17.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_2900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.18.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.19.0`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.20.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.21.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp2:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.2`,
        fs:  `cpe:2.3:a:ipswitch:imail:2006.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.3`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.4`,
        fs:  `cpe:2.3:a:samba:samba:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.5`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.51:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.7`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.901.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.7a`,
        fs:  `cpe:2.3:a:microsoft:server_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.7b`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1085.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.7c`,
        fs:  `cpe:2.3:a:louis_jimenez:custom_meta:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.7d`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p450:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.8`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.00.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.8a`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.8b`,
        fs:  `cpe:2.3:a:sendmail:sendmail:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.8c`,
        fs:  `cpe:2.3:a:aphpkb:aphpkb:0.95.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.8d`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.8e`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.8f`,
        fs:  `cpe:2.3:h:apple:imac:m9844xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.8g`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9a`,
        fs:  `cpe:2.3:a:qlogic:sansurfer_fc_hba_manager:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9b`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9c`,
        fs:  `cpe:2.3:h:fortinet:fortigate-60c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9d`,
        fs:  `cpe:2.3:a:allroundautomation:pl\/sql_developer:9.0.2.1621:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9e`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9f`,
        fs:  `cpe:2.3:a:google:chrome:11.0.673.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9g`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1023:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9h`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd7.d4xxv_firmware:1.24.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9i`,
        fs:  `cpe:2.3:a:apache:struts:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9j`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9k`,
        fs:  `cpe:2.3:a:atlassian:oauth:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9l`,
        fs:  `cpe:2.3:a:samba:samba:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9m`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:0.99.9n`,
        fs:  `cpe:2.3:a:php:php:5.5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.0`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.0a`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.0b`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.1`,
        fs:  `cpe:2.3:a:emulex:elxocm:5.0.66.05-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.2`,
        fs:  `cpe:2.3:h:hp:storageworks_san_switch:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.4`,
        fs:  `cpe:2.3:a:hp:hppfaxdrv:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.5`,
        fs:  `cpe:2.3:a:getpixie:pixie:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.6`,
        fs:  `cpe:2.3:a:google:chrome:11.0.668.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.7`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.8`,
        fs:  `cpe:2.3:a:unrealircd:unrealircd:3.2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.9`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.10`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.11`,
        fs:  `cpe:2.3:a:cisco:meetingplace_web_confrencing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.12`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.0.13`,
        fs:  `cpe:2.3:a:ibm:java:5.0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.1.0`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.1.1`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.9.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.1.2`,
        fs:  `cpe:2.3:a:perl:perl:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.1.3`,
        fs:  `cpe:2.3:a:hp:pml_driver_hpz12:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.1.4`,
        fs:  `cpe:2.3:a:honda:motolinc:1.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.1.5`,
        fs:  `cpe:2.3:a:digia:qt:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.1.6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta46:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.2.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.2.1`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.1.0:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.2.2`,
        fs:  `cpe:2.3:a:intel:proset_for_wired_connections:9.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.2.3`,
        fs:  `cpe:2.3:a:bandoo:windows_savevid_toolbar:2.5.0.103268:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.2.4`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.80.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.2.5`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.2.6`,
        fs:  `cpe:2.3:a:libpng:libpng:0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.3.0`,
        fs:  `cpe:2.3:a:flightgear:flightgear:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.3.0:rc1`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.3.0:rc2`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.3.0:rc3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.3.0:rc4`,
        fs:  `cpe:2.3:a:atmail:atmail:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.3.1`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.3.2`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.3.3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.0`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.0:rc1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.3:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.0:rc2`,
        fs:  `cpe:2.3:h:alcatel:speed_touch_home:khdsaa.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.1`,
        fs:  `cpe:2.3:a:ca:erwin_process_modeler:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.1.1`,
        fs:  `cpe:2.3:a:bentley:microstation:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2:rc1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2:rc2`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2:rc3`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:eba:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2:rc4`,
        fs:  `cpe:2.3:a:avast:pro_antivirus:11.1.2260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2.1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.13.2:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2.3`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.2.4`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.3`,
        fs:  `cpe:2.3:a:gnu:anubis:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.3:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.3:rc3`,
        fs:  `cpe:2.3:o:debian:debian_linux:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.3.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.3.2`,
        fs:  `cpe:2.3:a:altiris:carbon_copy_solution:6.2.1144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.3.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.3.4`,
        fs:  `cpe:2.3:h:cisco:telepresence_server_7010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.3.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.0:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.4`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.4.1`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.4.2`,
        fs:  `cpe:2.3:a:pgp:openpgp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.4.3`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.4.4`,
        fs:  `cpe:2.3:a:apache:ambari:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.4.4.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.4md:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:preview1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0:rc0`,
        fs:  `cpe:2.3:a:dell:ibm_tape_diagnostic_tool:1.2.0.6:*:*:*:dell_customer_release:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0:rc3`,
        fs:  `cpe:2.3:a:python:python:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0:rc4`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0.1`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0.2`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0.3`,
        fs:  `cpe:2.3:a:apache:cassandra:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0.5`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_server:12.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0.6`,
        fs:  `cpe:2.3:h:ibm:s28:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.0.7`,
        fs:  `cpe:2.3:a:sony:sonicstage_mastering_studio:1.4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1:rc1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1:rc2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1:rc3`,
        fs:  `cpe:2.3:a:apache:derby:10.8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1.1`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1.2`,
        fs:  `cpe:2.3:h:fisher-price:smart_toy_bear:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1.3`,
        fs:  `cpe:2.3:o:asus:rt-n10e_firmware:2.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1.4`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.1.6`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.2:rc0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.2.1`,
        fs:  `cpe:2.3:a:nih:libzip:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.2.2`,
        fs:  `cpe:2.3:a:anthony_tuininga:cx_oracle-10g:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.2.3`,
        fs:  `cpe:2.3:a:x:libxv:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.2.4`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.2.5`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3:rc0`,
        fs:  `cpe:2.3:a:ni:lookout:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3:rc4`,
        fs:  `cpe:2.3:a:posh_project:posh:1.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3:rc5`,
        fs:  `cpe:2.3:a:redmine:redmine:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3:rc6`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3:rc7`,
        fs:  `cpe:2.3:a:redmine:redmine:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3.1`,
        fs:  `cpe:2.3:o:edimax:br-6104k_router_firmware:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3.2`,
        fs:  `cpe:2.3:a:nttdata:terasoluna_server_framework_for_java_web:2.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3.4`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3.5`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3.6`,
        fs:  `cpe:2.3:a:ibm:rational_performance_tester:8.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3.7`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.3.8`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4:rc0`,
        fs:  `cpe:2.3:a:ibm:sterling_file_gateway:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4:rc5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4.1`,
        fs:  `cpe:2.3:a:appa-apps:top_roller_coasters_europe_2:\@7f050001:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4.2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.25:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4.5`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20110222:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4.6`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:6.14.11.9716:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.4.7`,
        fs:  `cpe:2.3:a:apple:quicktime:6.3.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.5`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.5:rc0`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:gold:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.5.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_6509-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.5.2`,
        fs:  `cpe:2.3:o:ge:bently_nevada_3500\/22m_usb_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.5.3`,
        fs:  `cpe:2.3:a:netfilter:ipset:6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.5.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.5.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.5.6`,
        fs:  `cpe:2.3:a:vmware:gsx_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6:rc0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6:rc1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_platform:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6:rc2`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6:rc3`,
        fs:  `cpe:2.3:a:redmine:redmine:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6.2`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6.3`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6.5`,
        fs:  `cpe:2.3:a:openstack:horizon:2014.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.5.6.6`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0`,
        fs:  `cpe:2.3:h:xerox:workcentre_3325:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0:rc0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0:rc1`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0:rc2`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0:rc3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0.1`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:943sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0.2`,
        fs:  `cpe:2.3:a:sabreairlinesolutions:crew_operations:2010.2.12.20008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0.3`,
        fs:  `cpe:2.3:a:sigmatel:c-major_audio:5.10.5210.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0.4`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.0.6`,
        fs:  `cpe:2.3:a:microsoft:excel:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.1`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.1:rc2`,
        fs:  `cpe:2.3:o:novell:netware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.1:rc3`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.1:rc4`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.1.1`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.1.2`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-2.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.1.3`,
        fs:  `cpe:2.3:a:nokia:affix:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.1.4`,
        fs:  `cpe:2.3:a:goforandroid:go_sms_pro:4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.2`,
        fs:  `cpe:2.3:a:koha:koha:3.14.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.2:rc0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.38:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.2:rc2`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf017:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.2.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_91:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.2.2`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.23pi_pa_host_agent_files:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.2.3`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:ccf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.2.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.2.5`,
        fs:  `cpe:2.3:a:sun:net_connect_software:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.3`,
        fs:  `cpe:2.3:a:openstack:horizon:2012.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.3:rc0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.3:rc3`,
        fs:  `cpe:2.3:a:sun:hotjava_browser:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.3:rc4`,
        fs:  `cpe:2.3:a:bird_feeder_project:bird_feeder:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.3.1`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.3.2`,
        fs:  `cpe:2.3:h:intel:q35_express_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.3.3`,
        fs:  `cpe:2.3:o:microsoft:windows_10:1709:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.3.4`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.0:beta:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.4`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.4:rc0`,
        fs:  `cpe:2.3:a:adobe:bridgetalk_plugin_cs3:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.4.1`,
        fs:  `cpe:2.3:a:codiad:codiad:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sef:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.4.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.2.2:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.4.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.4.5`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.1r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5:rc0`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.0\(2m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.1`,
        fs:  `cpe:2.3:a:schedmd:slurm:17.02.0:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.2`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.4`,
        fs:  `cpe:2.3:a:debian:apt:0.7.17:exp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.5`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.3:*:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.7`,
        fs:  `cpe:2.3:o:google:android:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.8`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.5.9`,
        fs:  `cpe:2.3:a:symantec:mail_security:5.0.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6:rc0`,
        fs:  `cpe:2.3:a:microsoft:excel:2013:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6:rc1`,
        fs:  `cpe:2.3:h:lexmark:c543:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6:rc2`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6:rc3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6:rc4`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6.1`,
        fs:  `cpe:2.3:a:nttdata:terasoluna_server_framework_for_java_web:2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6.2`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.6.6.3`,
        fs:  `cpe:2.3:a:abbyy:finereader:8.0:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0`,
        fs:  `cpe:2.3:a:libav:libav:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0:rc0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0:rc2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.1`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.2`,
        fs:  `cpe:2.3:a:vips:vips:7.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.3`,
        fs:  `cpe:2.3:a:sun:one_directory_server:4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.4`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)t6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.6`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.7`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.4t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.0.9`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6:\(2a\)su1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.1:rc0`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.1:rc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(3\)i2\(0.373\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.1:rc2`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:sp2_alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.1.1`,
        fs:  `cpe:2.3:h:hp:color_laserjet_2500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.1.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.1.3`,
        fs:  `cpe:2.3:a:mysql:mysql_tools:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.1.4`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:5.6.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2:rc0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(5b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2:rc2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2:rc3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2.1`,
        fs:  `cpe:2.3:a:bioinformatics:ordersys:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2.2`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2.4`,
        fs:  `cpe:2.3:a:openstack:neutron:2012.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.2.5`,
        fs:  `cpe:2.3:a:altiris:computer_management:6.2.3529:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.3`,
        fs:  `cpe:2.3:a:impresspages:impresspages_cms:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.3:rc0`,
        fs:  `cpe:2.3:h:hp:0235a0c4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.3:rc2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.3.1`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.3.2`,
        fs:  `cpe:2.3:a:kvirc:kvirc:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.3.3`,
        fs:  `cpe:2.3:a:x:libxrandr:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.3.4`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.3.5`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.4`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.4:rc0`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.4:rc3`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.4.1`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.4.2`,
        fs:  `cpe:2.3:h:siemens:ruggedcom_win7000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.4.3`,
        fs:  `cpe:2.3:a:symantec:data_center_security_server:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.4.4`,
        fs:  `cpe:2.3:a:lsoft:listserv:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.4.5`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5:rc0`,
        fs:  `cpe:2.3:a:citrix:secure_gateway:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5:rc1`,
        fs:  `cpe:2.3:a:abbyy:finereader:7.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5:rc2`,
        fs:  `cpe:2.3:a:apple:java_1.5:0:13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5:rc3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1060.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5.1`,
        fs:  `cpe:2.3:a:apache:camel:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5.2`,
        fs:  `cpe:2.3:o:cisco:edge_340_firmware:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5.3`,
        fs:  `cpe:2.3:o:hp:palm_webos:1.4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.5.4`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6`,
        fs:  `cpe:2.3:a:juniper:junos_space:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6:rc0`,
        fs:  `cpe:2.3:a:s9y:serendipity:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6:rc3`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6.2`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6.3`,
        fs:  `cpe:2.3:a:emc:vplex_geosynchrony:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6.5`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.6.6`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7:rc0`,
        fs:  `cpe:2.3:h:supermicro:x9sri-3f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7:rc3`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7.1`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7.2`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7.3`,
        fs:  `cpe:2.3:a:ibm:security_guardium_database_activity_monitor:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7.4`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7.5`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7.6`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.7.7`,
        fs:  `cpe:2.3:a:roxio:media_manager:9.4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8`,
        fs:  `cpe:2.3:a:hp:software_cross_platform_component:6.0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8:rc0`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8:rc2`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8:rc3`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8:rc4`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:7.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8.1`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8.2`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8.3`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8.4`,
        fs:  `cpe:2.3:h:hp:service_manager_server:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8.5`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.8.6`,
        fs:  `cpe:2.3:a:altiris:application_metering_agent:6.1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9:rc0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9.1`,
        fs:  `cpe:2.3:a:softwareag:webmethods:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9.2`,
        fs:  `cpe:2.3:a:libssh:libssh:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9.4`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9.5`,
        fs:  `cpe:2.3:a:novell:opensuse_swamp_workflow_administration_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9.6`,
        fs:  `cpe:2.3:a:vanilla_perl_project:strawberry_perl:5.12.768:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.9.7`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10:rc0`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2011:1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10:rc1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10:rc2`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10:rc3`,
        fs:  `cpe:2.3:a:procmail:procmail:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10:rc4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10.1`,
        fs:  `cpe:2.3:a:web2py:web2py:1.81.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg255a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10.3`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10.4`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.10.5`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11:rc0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11:rc3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11.1`,
        fs:  `cpe:2.3:a:breezy:breezy:1.2.8:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11.2`,
        fs:  `cpe:2.3:o:cisco:network_analysis_module_software:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11.4`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11.5`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11.6`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.11.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.10.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.12`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.9.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.12:rc0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)sy2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.12:rc3`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.12.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.12.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.12.3`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.7.12.4`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.6:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.0:rc0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.0:rc1`,
        fs:  `cpe:2.3:a:augeas:augeas:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:53.0.2785.143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.0:rc3`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.0:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.0.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.0.2`,
        fs:  `cpe:2.3:a:smarty:smarty:2.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.0.3`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.12:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1:rc0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1:rc3`,
        fs:  `cpe:2.3:o:huawei:s5300si_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1.1`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1.2`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1.3`,
        fs:  `cpe:2.3:a:omeka:omeka:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1.4`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1.5`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.1.6`,
        fs:  `cpe:2.3:a:shape:im\&#43;:6.6.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.2:rc0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.374:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.2:rc2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.2:rc3`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.2.1`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.2.2`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.5.1.754:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.2.3`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0574:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.3`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.3:rc0`,
        fs:  `cpe:2.3:a:php:php:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.3.1`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.3.2`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.0.0.863:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.3.3`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.3.4`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4:rc0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4:rc1`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4:rc2`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4:rc3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4:rc4`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.8.0.2257:unknown:online_windows_server_2003_x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4.2`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4.3`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4.4`,
        fs:  `cpe:2.3:a:samba:ppp:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.4.5`,
        fs:  `cpe:2.3:a:adobe:jrun:4.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5`,
        fs:  `cpe:2.3:o:google:android:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5:rc0`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:4.2\(4.17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5:rc2`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.15:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5:rc3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1662.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5.3`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5.4`,
        fs:  `cpe:2.3:a:nvidia:control_panel:266.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.8.5.6`,
        fs:  `cpe:2.3:o:mikrotik:routeros:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.0:rc0`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.0:rc1`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.0:rc3`,
        fs:  `cpe:2.3:a:saltstack:salt:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.1`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(27\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.3`,
        fs:  `cpe:2.3:a:cisco:personal_assistant:1.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.4`,
        fs:  `cpe:2.3:a:altova:xmlspy_2007:30.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:1.9.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.10:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.0:rc0`,
        fs:  `cpe:2.3:a:altiris:asset_management_solution_documentation:6.5.1049:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.0:rc1`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.0:rc2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.0:rc3`,
        fs:  `cpe:2.3:a:informatica:xconnect_for_business_objects:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.0:rc4`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.1`,
        fs:  `cpe:2.3:a:corporater:epm_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.2`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ea2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.4`,
        fs:  `cpe:2.3:a:apple:safari:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.0.5`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.1.0`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.1.0:rc0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.671.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.1.0:rc1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.1.0:rc2`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.1.1`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.1.2`,
        fs:  `cpe:2.3:a:winzip:winzip:15.0.9334:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.1.3`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.1.4`,
        fs:  `cpe:2.3:a:samba:samba:4.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.2.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.762.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.2.0:rc0`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.2.0:rc1`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.2.0:rc2`,
        fs:  `cpe:2.3:a:openstack:keystone:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.2.0:rc3`,
        fs:  `cpe:2.3:h:cisco:4100_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.2.1`,
        fs:  `cpe:2.3:a:schneems:wicked:0.0.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.2.2`,
        fs:  `cpe:2.3:a:drupal:drupal:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.2.3`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.0`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.0:rc0`,
        fs:  `cpe:2.3:a:apple:cups:1.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.0:rc1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.0:rc2`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30121:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.2`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.4`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.5`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.6`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.7`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.8`,
        fs:  `cpe:2.3:a:bea:liquid_data:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.9`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4012:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.3.10`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.0`,
        fs:  `cpe:2.3:h:supermicro:h8sml-i:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.0:rc0`,
        fs:  `cpe:2.3:h:3com:3c16450-us:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.0:rc1`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.0:rc2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.0:rc3`,
        fs:  `cpe:2.3:a:hitachi:global_link_manager:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.1`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.2`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.3`,
        fs:  `cpe:2.3:h:samsung:galaxy_s4_mini:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.4`,
        fs:  `cpe:2.3:a:redhat:linux:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2010.211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.6`,
        fs:  `cpe:2.3:a:ibm:daeja_viewone:4.1.5:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.7`,
        fs:  `cpe:2.3:a:rockwellautomation:rslogix_5000_design_and_configuration_software:21.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.8`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.405:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.9`,
        fs:  `cpe:2.3:a:hp:centralview_fraud_risk_management:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.10`,
        fs:  `cpe:2.3:a:tibco:spotfire_professional:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.11`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.4.12`,
        fs:  `cpe:2.3:h:cisco:asr_9001:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.0:rc0`,
        fs:  `cpe:2.3:o:zyxel:zynos_firmware:3.40\(axh.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.0:rc1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.0:rc2`,
        fs:  `cpe:2.3:a:parsagostar:parsaweb_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.0:rc3`,
        fs:  `cpe:2.3:o:cisco:rvs4000_firmware:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.1`,
        fs:  `cpe:2.3:h:ovislink:airlive_poe2600hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.2`,
        fs:  `cpe:2.3:a:zen-cart.jp:zen_cart:1.5.0:*:*:ja-jp:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.3`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.4`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.5`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.5.6`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.0`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.0:rc0`,
        fs:  `cpe:2.3:a:openttd:openttd:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.0:rc1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.0:rc2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf427a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.0:rc3`,
        fs:  `cpe:2.3:a:webmin:usermin:0.980:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.2`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.3`,
        fs:  `cpe:2.3:a:idera:uptime_infrastructure_monitor:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.4`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.5`,
        fs:  `cpe:2.3:a:oracle:web_listener:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.6`,
        fs:  `cpe:2.3:a:hp:webinspect:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.6.7`,
        fs:  `cpe:2.3:a:ipswitch:imail:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.0`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.2.v1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.0:rc0`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.0:rc1`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.2:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.0:rc2`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.0:rc3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.3`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.4`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.5`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.7.6`,
        fs:  `cpe:2.3:a:cisco:resource_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.0`,
        fs:  `cpe:2.3:a:siemens:wincc_tia_portal:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.0:rc0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.0:rc1`,
        fs:  `cpe:2.3:h:toshiba:e210c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.0:rc2`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:3.2.3:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.0:rc3`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.0:rc4`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.016.20039:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.3`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.4`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.0.0.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.5`,
        fs:  `cpe:2.3:a:nero:soundtrax:4.0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.8.6`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1049.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.0:rc0`,
        fs:  `cpe:2.3:o:hp:tru64:4.0f:pk8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.0:rc1`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_management_framework:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.2`,
        fs:  `cpe:2.3:a:ca:license_software:1.70.1.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.4`,
        fs:  `cpe:2.3:a:oracle:flexcube_direct_banking:12.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.9.5`,
        fs:  `cpe:2.3:a:jogoeusei:questoes_oab:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.0:rc0`,
        fs:  `cpe:2.3:a:dnb:dnb_trade:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.0:rc1`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.0:rc2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.1`,
        fs:  `cpe:2.3:a:plone:plone:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.2`,
        fs:  `cpe:2.3:o:novell:netware:6.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.3`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.4`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:10.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.10.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.0`,
        fs:  `cpe:2.3:a:adobe:flash_mx:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.0:rc0`,
        fs:  `cpe:2.3:a:sun:jre:6.0.200:update20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.0:rc1`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:sp1:x64-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.0:rc2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.0:rc3`,
        fs:  `cpe:2.3:h:hp:z240_tower_workstation_n51:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.1`,
        fs:  `cpe:2.3:o:cisco:catos:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.3`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.11.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.0`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.0:rc0`,
        fs:  `cpe:2.3:a:drupal:drupal:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.0:rc1`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.0:rc2`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.1`,
        fs:  `cpe:2.3:a:php:php:5.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.3`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_management_center_for_ids_sensors:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.4`,
        fs:  `cpe:2.3:a:linksys:wpc300n_wireless-n_notebook_adapter_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.12.5`,
        fs:  `cpe:2.3:a:piwik:piwik:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.0:rc0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.0:rc1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.0:rc2`,
        fs:  `cpe:2.3:a:skype:skype:3.1.0.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.1`,
        fs:  `cpe:2.3:a:schneems:wicked:0.4.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.3`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.4`,
        fs:  `cpe:2.3:a:advancedsearchbar:advanced_search_bar:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.5`,
        fs:  `cpe:2.3:a:debian:apt:0.8.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.13.6`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.14.0`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-15_a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.14.0:rc0`,
        fs:  `cpe:2.3:a:ibm:ds_storage_manager_host_software:10.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.14.0:rc1`,
        fs:  `cpe:2.3:h:hp:2550c_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.14.1`,
        fs:  `cpe:2.3:a:trillian:trillian:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.14.2`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.0.0:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.15.0`,
        fs:  `cpe:2.3:a:quest:intrust_agent:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.15.0:rc0`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git-scm:git:2.15.0:rc1`,
        fs:  `cpe:2.3:a:adobe:bridge_cc:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.0:rc0`,
        fs:  `cpe:2.3:a:hp:photosmart_disclabel_paperlabel:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.0:rc1`,
        fs:  `cpe:2.3:h:microsoft:xbox_360:4532:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.0:rc2`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.0:rc3`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.0.1`,
        fs:  `cpe:2.3:a:sabreairlinesolutions:crew_training:2010.2.12.20008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.0.2`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.1_build_19175:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1:rc0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1:rc1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1:rc2`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1:rc3`,
        fs:  `cpe:2.3:a:typo3:typo3:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1.1`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1.2`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1.3`,
        fs:  `cpe:2.3:a:splunk:splunk:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1.4`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1.5`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.1.6`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.2:rc0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.31:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.2:rc1`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.2:rc2`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.2:rc3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.2.1`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:*:x64-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.2.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg257a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.2.3`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.5-48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3:rc0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(15\)sl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3:rc1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.12:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3:rc2`,
        fs:  `cpe:2.3:a:freedownloadmanager:free_download_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3:rc3`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3.2`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3.3`,
        fs:  `cpe:2.3:a:openstack:swift:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.3.4`,
        fs:  `cpe:2.3:a:microsoft:small_business_srv:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4:rc0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4:rc1`,
        fs:  `cpe:2.3:h:netgear:rt314:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4:rc2`,
        fs:  `cpe:2.3:a:isc:bind:9.7.2:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4:rc3`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4:rc4`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4.1`,
        fs:  `cpe:2.3:a:vmware:workstation:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4.2`,
        fs:  `cpe:2.3:a:winzip:winzip:14.5.9095:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4.3`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:milestone5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.4.4`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5:rc0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5:rc1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5:rc2`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5:rc3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5.1`,
        fs:  `cpe:2.3:a:paul_lesniewsk:autocomplete:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5.2`,
        fs:  `cpe:2.3:h:xerox:document_centre_220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5.3`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.3:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5.4`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.19.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.8.5.5`,
        fs:  `cpe:2.3:a:libssh:libssh:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.0:rc0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.574:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.0:rc1`,
        fs:  `cpe:2.3:a:vmware:tools:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.0:rc2`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:3.1.324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.0:rc3`,
        fs:  `cpe:2.3:o:novell:unixware:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.1`,
        fs:  `cpe:2.3:o:hp:openvms:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.2`,
        fs:  `cpe:2.3:a:horde:imp:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.3`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.291:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_for_windows_project:git_for_windows:1.9.4`,
        fs:  `cpe:2.3:a:swishzone:swish_max3:3.0.2009.11.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:git_project:git:2.5.3`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:github:gaug.es:-`,
        fs:  `cpe:2.3:a:rpm:rpm:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:github:gaug.es:1.4`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.8.0`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.8.0::~~community~~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.8.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.1`,
        fs:  `cpe:2.3:a:nova921:nova_92.1_fm:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.1::~~community~~~`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.50.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.4`,
        fs:  `cpe:2.3:a:mcafee:application_control:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.4::~~community~~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.4::~~enterprise~~~`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.6`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.6::~~community~~~`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.06b53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:0.9.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.0`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.0::~~community~~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:atheme:atheme:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.1::~~community~~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.2`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.2::~~community~~~`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:h:hp:officejet_6100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.1.0`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.1.0::~~community~~~`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.0::~~community~~~`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:git-scm:git:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.1::~~community~~~`,
        fs:  `cpe:2.3:a:apport_project:apport:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.1.0.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.2`,
        fs:  `cpe:2.3:a:qemu:qemu:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.2::~~community~~~`,
        fs:  `cpe:2.3:a:gentoo:media-libs_jpeg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:1.2.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.0.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.0.0::~~community~~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ca:etrust_siteminder:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.1.0`,
        fs:  `cpe:2.3:h:zyxel:p-660h-t1:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.1.0::~~community~~~`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.2.0`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.2.0::~~community~~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.2.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.3.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.10:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.3.0::~~community~~~`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.12.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.3.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.3.1`,
        fs:  `cpe:2.3:a:apache:poi:3.8:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.3.1::~~community~~~`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.7.1.19610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.3.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.4.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.4.0::~~community~~~`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_avaya:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.4.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.5.0`,
        fs:  `cpe:2.3:a:heirloom:mailx:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.5.0::~~community~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.5.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.6.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.6.0::~~community~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.6.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:covetfashion:covet_fashion_-_shopping_game:2.14.40:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.7.0`,
        fs:  `cpe:2.3:a:hp:jc652a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.7.0::~~community~~~`,
        fs:  `cpe:2.3:a:kingsoft:office_2012:8.1.0.3238:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.7.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.8.0`,
        fs:  `cpe:2.3:a:janetter:janetter:1.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.8.0::~~community~~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.8.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_network_devices_documentation:6.0.1015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.8.1`,
        fs:  `cpe:2.3:a:ekiga:ekiga:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.8.1::~~community~~~`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.8.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.9.0`,
        fs:  `cpe:2.3:o:huawei:s6700_firmware:v200r001c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.9.0::~~community~~~`,
        fs:  `cpe:2.3:h:linksys:befsx41:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.9.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.5:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.9.1`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.9.1::~~community~~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1031:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:2.9.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.0::~~community~~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.6.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gnu:enscript:1.6.4_beta:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.1`,
        fs:  `cpe:2.3:a:cyberlink:power2go:7.0.0.0816:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.1::~~community~~~`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.2::~~community~~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd309a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:o:iij:seil\%2fneu_2fe_plus_firmware:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.3`,
        fs:  `cpe:2.3:a:blackberry:blackberry_link:1.2.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.3::~~community~~~`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.1.0::~~community~~~`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:3.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.0.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.0.0::~~community~~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.00:-:*:*:linux_kernel:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.1.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:fi:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.1.0::~~community~~~`,
        fs:  `cpe:2.3:a:realvnc:realvnc:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:php:php:5.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.2.0`,
        fs:  `cpe:2.3:a:docker:docker:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.2.0::~~community~~~`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:4.2.0::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)e17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.0.0`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.0.0::~~community~~~`,
        fs:  `cpe:2.3:a:hummingbird:dm:5.1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.0.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.0.1::~~community~~~`,
        fs:  `cpe:2.3:h:juniper:infranet_controller_6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc104a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.1.0`,
        fs:  `cpe:2.3:a:nmedia:member_conversation:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.1.0::~~community~~~`,
        fs:  `cpe:2.3:a:schneider-electric:sft2841:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.2.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.7.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.2.0::~~community~~~`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.2.0::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.3.0`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.3.0::~~community~~~`,
        fs:  `cpe:2.3:a:openstack:swift:1.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.3.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:microsoft:security_compliance_manager:1.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.0`,
        fs:  `cpe:2.3:a:novell:client:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.0::~~community~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.1`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.1::~~community~~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20110225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:filenet_content_manager:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.2::~~community~~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:5.4.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:vmware:fusion:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.0`,
        fs:  `cpe:2.3:a:pureedge:pureedge_viewer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.0.0`,
        fs:  `cpe:2.3:a:apache:subversion:0.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.0.0::~~community~~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp2:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.1.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.1.0::~~community~~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.0::~~community~~~`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.4.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.1::~~community~~~`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.2`,
        fs:  `cpe:2.3:a:tenable:nessus:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.2::~~community~~~`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.3`,
        fs:  `cpe:2.3:a:trillian:trillian:0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.3::~~community~~~`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.4`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2006-03-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.2.4::~~community~~~`,
        fs:  `cpe:2.3:a:rsa:ace_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.3.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.4.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p232_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.4.1`,
        fs:  `cpe:2.3:a:user_import_project:user_import:6.x-4.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.4.2`,
        fs:  `cpe:2.3:a:apache:axis:1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.4.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2scd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.5.0`,
        fs:  `cpe:2.3:a:expressjs:express:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.5.1`,
        fs:  `cpe:2.3:a:fluke:linkware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.0`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ca:siteminder:12.0:sp3:cr01:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gnu:readline:6.3:3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.6.5`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.7.0`,
        fs:  `cpe:2.3:a:canonical:telepathy-idle:0.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.7.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.7.2`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2011:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.7.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.8.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:6.9.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.2.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.2.1`,
        fs:  `cpe:2.3:a:libgd:libgd:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.2.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.2.3`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.2.4`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_internet_pass_thru:2.1.0.1:*:*:*:*:websphere_mq:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.2.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.0`,
        fs:  `cpe:2.3:a:sun:solstice_backup:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.1`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.2`,
        fs:  `cpe:2.3:a:david_king:vino:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.3`,
        fs:  `cpe:2.3:h:hp:jg207a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.4`,
        fs:  `cpe:2.3:a:debian:apt:0.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.5`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.6`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)dx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.8`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k_secure:14.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.3.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.1`,
        fs:  `cpe:2.3:a:lucent:vitalhelp:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.2`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.3`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.4`,
        fs:  `cpe:2.3:a:itography:itography_item_hunt:3.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.5`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.6`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.7`,
        fs:  `cpe:2.3:h:verizon:fios_actiontec_mi424wr-gen31_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.8`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.1.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.9`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.5.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.4.10`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.0`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.1`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:aternity:aternity:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.2`,
        fs:  `cpe:2.3:a:rhodecode:rhodecode_enterprise:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.2::~~enterprise~~~`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:2.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.3`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.3::~~enterprise~~~`,
        fs:  `cpe:2.3:o:freenas:freenas:0.69.1:-:amd64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.4`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.356.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.5`,
        fs:  `cpe:2.3:a:apache:axis2:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sgminer_project:sgminer:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.6`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.7`,
        fs:  `cpe:2.3:a:symantec:brightmail_antispam:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.7::~~enterprise~~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.8`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:intel:mpfwiz:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.9`,
        fs:  `cpe:2.3:a:spice_project:spice:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.9::~~enterprise~~~`,
        fs:  `cpe:2.3:h:cisco:wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.10`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.0.148.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.11`,
        fs:  `cpe:2.3:a:google:sketchup:7.0:maintenance_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.12`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.12::~~enterprise~~~`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.5.13::~~enterprise~~~`,
        fs:  `cpe:2.3:a:digium:asterisk:13.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.0`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_service:3.3.1066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.1`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.2`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle_common:2.0.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.3`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.3::~~enterprise~~~`,
        fs:  `cpe:2.3:h:ibm:system_x3630_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:lxml:lxml:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.5`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:10.0.617.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.6`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:15.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.7`,
        fs:  `cpe:2.3:a:monotone:monotone:0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.8`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.6.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:babydays:baby_days:1.5.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.0`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-600_firmware:t390sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.951.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.3::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1sec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:11:release-preview:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nextendweb:nextend_facebook_connect:1.5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:suse:linux_firewall_on_cd_admin_host:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.444:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.7.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1:*:alpha:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.3::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.3\(0\)zn\(0.83\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.4::~~enterprise~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ni:diadem:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.8.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.0::~~enterprise~~~`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:2008.0:x86_64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.1`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.1::~~enterprise~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:1.0\(1.110a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.3`,
        fs:  `cpe:2.3:a:daum:daum_maps_-_subway:3.9.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1682.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.4`,
        fs:  `cpe:2.3:a:sage:sage_timesheet:9.85.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p200:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.6`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:51.2:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.7`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_lan_management_solution:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.8`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00-06:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.9`,
        fs:  `cpe:2.3:a:hp:service_manager:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.10`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.3:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.11`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.9.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.0`,
        fs:  `cpe:2.3:a:twilio_project:twilio:7.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.1`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:microsoft:onenote:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.625.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:emc:documentum_d2:3.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.5`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d63:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:22.0.0.192:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.8`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:9.0_0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.9`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:aimluck:aipo:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.10`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_database_control:11.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.11`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.35.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.12`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.12::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.0\(1\)_sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.13`,
        fs:  `cpe:2.3:h:cisco:asa_aip_security_services_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.10.13::~~enterprise~~~`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.5:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.0::~~enterprise~~~`,
        fs:  `cpe:2.3:h:symantec:gateway_security_460r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.1`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:snort:snort:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.2`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.2.6:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.951:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.4`,
        fs:  `cpe:2.3:a:phpvibe:phpvibe:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2010.0211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.6`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.7`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.7::~~enterprise~~~`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.8`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.9`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5800-32c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:digitaljuice:juicer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.10`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.0.1:rev29536:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.10::~~enterprise~~~`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:20.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.11.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:digia:qt:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.0`,
        fs:  `cpe:2.3:a:digia:qt:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:server_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.1`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:g06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.2`,
        fs:  `cpe:2.3:a:sun:openoffice.org:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:innominate:mguard_smart:bd-101020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:f5:enterprise_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.4`,
        fs:  `cpe:2.3:a:prosody:prosody:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:redmine:redmine:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.5`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.6`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.7`,
        fs:  `cpe:2.3:h:oleumtech:sensor_wireless_i\/o_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.8`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.8::~~enterprise~~~`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro:265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:webform_prepopulate_block_project:webform_prepopulate_block:7.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.85:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.7:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.12.12::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.1`,
        fs:  `cpe:2.3:a:python:python:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.1::~~enterprise~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.3`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:tryton:trytond:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.35b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nuance:omnipage:17:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:hexagon:erdas_er_viewer:13.0.1.1298:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:magzter:hong_kong_tatler_society:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.10::~~enterprise~~~`,
        fs:  `cpe:2.3:o:huawei:s9306e_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.13.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.2.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.7:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.1`,
        fs:  `cpe:2.3:a:indianic:testimonial_plugin:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.2::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:-:pre5:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.4`,
        fs:  `cpe:2.3:h:ibm:mcs-7815-1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.5`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:red-gate:sql_packager:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.6`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.01:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.8::~~enterprise~~~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_hpc_node:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.9`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.14.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:micros_cwdirect:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.0`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_designer:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.1::~~enterprise~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.2`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.334:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.6`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:welcart:e-commerce:1.3.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.7`,
        fs:  `cpe:2.3:a:siemens:simatic_wincc_sm\@rtclient:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.15.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_exec:5.3.2190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.0`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:schneider-electric:unityloader:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.1`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:atlassian:jira:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.3`,
        fs:  `cpe:2.3:a:bluecoat:proxyclient:3.3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:3com:3c15100d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.4`,
        fs:  `cpe:2.3:h:dlink:des-3810-28:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:oracle_data_provider_for_.net_help:11.1.720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.5`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.6`,
        fs:  `cpe:2.3:a:gnu:less:471:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.8:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:apache:opennlp:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.16.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.14s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.7:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.1`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_rich_text_editor:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.2`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:compaq:insight_manager_lc:1.50a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.3`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:kwoksys:information_server:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p237:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:8.17.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4011:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.0_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.0\(3f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.0.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:capasystems:performance_guard:6.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:redhat:jboss_communications_platform:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.1.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:scott_reynen:node_embed:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.1.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.1.3::~~enterprise~~~`,
        fs:  `cpe:2.3:h:cisco:wireless_lan_controller:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.1.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.1.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.1.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.1.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:filefield_project:filefield:6.x-3.12:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.2.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.2.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.2.2::~~enterprise~~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:2.6.32.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.2.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.23:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.2.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.2.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.102.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.2.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:microsoft:access:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.2.7::~~enterprise~~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.3.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.3.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:wolfssl:wolfssl:3.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.3.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.3.3::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:6.0.2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.3.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:kana:knowledge_server:7.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.3.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.5:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.3.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.585.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab:9.3.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:activcard:activcard_gold_for_cac:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.0.4`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.1.0`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.2.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.3.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.4.0`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.5.0`,
        fs:  `cpe:2.3:a:vmware:gsx_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.6.0`,
        fs:  `cpe:2.3:o:d-link:dsr-150_firmware:1.08b29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.0`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.1`,
        fs:  `cpe:2.3:a:hp:business_availability_center:8.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.2`,
        fs:  `cpe:2.3:a:php:php:5.6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.3`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-s39:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.4`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.5`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.6`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.7`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.8`,
        fs:  `cpe:2.3:h:cisco:nexus_4001i:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.7.9`,
        fs:  `cpe:2.3:a:emc:cloud_tiering_appliance_software:10.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.8.0`,
        fs:  `cpe:2.3:a:oracle:jdk:8.0:update_73:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.8.1`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.21:-:*:*:*:windows_server_2003:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.8.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.8.3`,
        fs:  `cpe:2.3:h:zte:zxhn_h108l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.8.4`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.8.5`,
        fs:  `cpe:2.3:a:justsystems:oreplug:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.9.0`,
        fs:  `cpe:2.3:a:websunlimited:j-bots_plus_2004:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.9.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.9.2`,
        fs:  `cpe:2.3:h:linksys:wrt54gc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.9.3`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.003:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlab:gitlab-shell:1.9.4`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlist:gitlist:-`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.0.5-h2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlist:gitlist:0.1`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlist:gitlist:0.2`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlist:gitlist:0.3`,
        fs:  `cpe:2.3:a:skyarc:authoreffective:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlist:gitlist:0.4.0`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitlist:gitlist:0.5.0`,
        fs:  `cpe:2.3:a:gnu:coreutils:5.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.0.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.0.6`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.01.446:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.0.7`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns9200rx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.0.8`,
        fs:  `cpe:2.3:a:f5:linerate:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.0.9`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.1.1`,
        fs:  `cpe:2.3:a:compaq:acms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.0`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.1`,
        fs:  `cpe:2.3:a:matrixssl:matrixssl:3.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.2`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.3`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.4`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.5`,
        fs:  `cpe:2.3:a:apple:safari:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.6`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass_pro:6.3.8:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.7`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.1.1008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.8`,
        fs:  `cpe:2.3:a:mcafee:securify_securvantage_studio:v5.2_\(build_v5.2_385\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.9`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gitphp_project:gitphp:0.2.9.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gittigidiyor:gittigidiyor:1.4.1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:givenu:givenu_give:1.5.3::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:elicensing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gizra:og_vocab:6.x-1.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gizra:og_vocab:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gizra:og_vocab:6.x-1.1`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gizra:og_vocab:6.x-1.2`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gizra:og_vocab:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:plone:plone:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:global_beauty_research_project:global_beauty_research:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:hp:centralized_management_console_software:7.0.01:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:globalscape:c%2b%2b_release_runtime:9.0.30729.4148`,
        fs:  `cpe:2.3:a:python:python:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:globalscape:eft_server:6.2.31.2`,
        fs:  `cpe:2.3:a:novell:service_desk:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:globeranger:dla_central_reporting_client:1.1.0.0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:globeranger:dod_passive_rfid_solution_base:1.6.0`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:globeranger:dod_passive_rfid_solution_event_notification:1.2.1`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:globeranger:edcl_central_reporting_server:1.0.0.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:globeranger:imotion_edgeware_platform:5.5.0.188`,
        fs:  `cpe:2.3:a:symantec:antivirus:10.1.9100.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:globiz_solutions:snowfox_content_management_system:1.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.5`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.5:rc1`,
        fs:  `cpe:2.3:a:diabetic_diet_guide_project:diabetic_diet_guide:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.5:rc2`,
        fs:  `cpe:2.3:a:adobe:flash_player:22.0.0.211:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.6:rc1`,
        fs:  `cpe:2.3:a:pixman:pixman:0.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.6:rc2`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.6:rc3`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.20`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.21`,
        fs:  `cpe:2.3:h:nvidia:quadro_m4000m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.30`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.31`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.40`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.41`,
        fs:  `cpe:2.3:h:ibm:system_x3400_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.42`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.51`,
        fs:  `cpe:2.3:h:linksys:befsr41:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.51a`,
        fs:  `cpe:2.3:a:hp:veritas_recordnow:4.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.65`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.65:rc1`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.65:rc2`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_71:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.68`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.68:rc1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.68:rc2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.68:rc3`,
        fs:  `cpe:2.3:a:ibm:navio_nc_browser:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.68.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.68.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.68.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.70`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.11:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.70:rc1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.70:rc2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.178:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.70:rc3`,
        fs:  `cpe:2.3:h:cisco:catalyst_7600_ws-x6380-nam:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.70.1`,
        fs:  `cpe:2.3:a:softbank:wisprclient:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.70.2`,
        fs:  `cpe:2.3:o:huawei:s2350ei_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.7\(0\):sp1\(1\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.1:rc1`,
        fs:  `cpe:2.3:a:cisco:webex_productivity_tools:2.40.5001.10012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.1:rc2`,
        fs:  `cpe:2.3:a:roxio:cd_creator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.1:rc3`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.2`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.24:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.4`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.5`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.71.6`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.01.457:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.72`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:009z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.72:rc1`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.72:rc2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.72:rc3`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.72.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.72.2`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.72.3`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.72.4`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.2.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.78`,
        fs:  `cpe:2.3:a:vitamin_plugin_project:vitamin:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.78.1`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.78.2`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.78.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.78.4`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5:b5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.78.5`,
        fs:  `cpe:2.3:a:digium:asterisk:14.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.0.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80.1`,
        fs:  `cpe:2.3:a:intel:proset_wireless:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80.2`,
        fs:  `cpe:2.3:a:logitech:videocall\&#43;comlink:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80.3`,
        fs:  `cpe:2.3:h:lucent:ascend_routers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80.4`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80.6`,
        fs:  `cpe:2.3:a:opscode:chef:0.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80.7`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.80.61`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.1`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.2`,
        fs:  `cpe:2.3:a:adobe:photoshop:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.3`,
        fs:  `cpe:2.3:a:hp:remote_diagnostics_enabling_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.4`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:941sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.5`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.6`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.7`,
        fs:  `cpe:2.3:a:jruby:jruby:1.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.8`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.9`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.31`,
        fs:  `cpe:2.3:h:buffalotech:as-100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.83.91`,
        fs:  `cpe:2.3:a:antoine_beaupre:hostmaster:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.84`,
        fs:  `cpe:2.3:a:citrix:receiver_pna:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.84.1`,
        fs:  `cpe:2.3:a:kryo:iodine:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.84.6`,
        fs:  `cpe:2.3:a:acronis:true_image_echo_enterprise_server:9.7.8398:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.84.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)bx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glpi-project:glpi:0.85`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.1`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.3`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.4`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.5`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.6`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.9.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.9.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.10`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.11`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0.12`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.0b1`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.1:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.1.1`,
        fs:  `cpe:2.3:a:sunstormgames:donut_maker:1.27:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5`,
        fs:  `cpe:2.3:a:php:php:5.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5:beta_pr1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5:beta_pr2`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.2`,
        fs:  `cpe:2.3:a:flightgear:flightgear:2.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.3`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf231a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.4`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.5`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.6`,
        fs:  `cpe:2.3:a:cisco:telepresence_management_suite:14.3\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.7`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.8`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.9`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.10`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.11`,
        fs:  `cpe:2.3:a:wasen:mod_simplefileupload:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.12`,
        fs:  `cpe:2.3:a:libarchive:libarchive:3.1.2:*:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.13`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.14`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.15`,
        fs:  `cpe:2.3:o:cisco:catos:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.18`,
        fs:  `cpe:2.3:a:webyog:sqlyog:2.51:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.19`,
        fs:  `cpe:2.3:a:netiq:privileged_user_manager:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.20`,
        fs:  `cpe:2.3:a:novell:zenworks_desktop_management:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:glub:secure_ftp:2.5.21`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1011:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gluster:glusterfs:3.3.0`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gluster:glusterfs:3.5`,
        fs:  `cpe:2.3:a:ca:etrust_audit_datatools:1.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gmarket:gmarket:5.1.3::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:atlas_ediscovery_process_management:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gmt-editions:rando_noeux:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.1`,
        fs:  `cpe:2.3:a:google:chrome:2.0.169.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.2`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.3`,
        fs:  `cpe:2.3:a:webmin:usermin:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.5`,
        fs:  `cpe:2.3:h:avaya:sg5:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.6`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.7`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.1.8`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zya:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.3`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.00:-:*:*:unix:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.6`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.91`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.91.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.3.92`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:0.4.1`,
        fs:  `cpe:2.3:a:hp:jg798a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.0`,
        fs:  `cpe:2.3:a:novell:groupwise:2014:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.2`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.3`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.4`,
        fs:  `cpe:2.3:a:web-dorado:photo_gallery:1.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.5`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.90`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.91`,
        fs:  `cpe:2.3:a:plone:plone:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.92`,
        fs:  `cpe:2.3:a:apache:tomcat:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:1.91.93`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.0.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.40:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.0.1`,
        fs:  `cpe:2.3:a:prosody:prosody:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.0.2`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.1.3`,
        fs:  `cpe:2.3:a:bgenergy:bgenergy:1.153.0034:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.1.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.1.5`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.1.90`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.1.91`,
        fs:  `cpe:2.3:a:hp:sanworks:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.1.92`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.2.0`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.0.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.2.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.2.2`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.3.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.3.2`,
        fs:  `cpe:2.3:a:microsoft:psloglist:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.3.3`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.3.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.3.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.3.90`,
        fs:  `cpe:2.3:a:createdineden:buy_yorkshire_conference:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.3.91`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.3.92`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.4.0`,
        fs:  `cpe:2.3:a:sgminer_project:sgminer:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.5.1`,
        fs:  `cpe:2.3:o:windriver:platform_sa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.5.2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.5.3`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.5.4`,
        fs:  `cpe:2.3:a:iss:blackice_agent:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.5.5`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.5.90`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.5.91`,
        fs:  `cpe:2.3:h:xerox:workcentre_7556:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.5.92`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.6.0`,
        fs:  `cpe:2.3:a:microsoft:windows_live_messenger:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.6.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:at-spi2-atk:2.7.1`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:byzanz:-`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:epiphany:1.2.10`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:epiphany:1.6.5`,
        fs:  `cpe:2.3:a:sybase:sql_anywhere:11.1.2506:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:epiphany:2.18`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.0.8`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.2`,
        fs:  `cpe:2.3:o:huawei:s5300li_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.2.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.2.2`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.2.3`,
        fs:  `cpe:2.3:a:wasen:mod_simplefileupload:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.2.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.4`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.4.3`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.4.4`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.4.5`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.4.6`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.1.0-103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.5`,
        fs:  `cpe:2.3:o:yahama:rta52i:4.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:1.11`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.0`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:9.1.507.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.0.1`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.0.2`,
        fs:  `cpe:2.3:a:symantec:im_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.1`,
        fs:  `cpe:2.3:a:david_king:vino:2.28.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.2.1`,
        fs:  `cpe:2.3:a:emc:avamar_plugin:4.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.3.1`,
        fs:  `cpe:2.3:a:otrs:otrs:1.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.3.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.3.3`,
        fs:  `cpe:2.3:a:php:pear:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.3.4`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_workstation_extension:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.3.5`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.3.6`,
        fs:  `cpe:2.3:a:intervideo:home_theater:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.3.6.1`,
        fs:  `cpe:2.3:a:linux-atm:linux-atm:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.3.7`,
        fs:  `cpe:2.3:a:ibm:integration_bus:10.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.4`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.4.2.1`,
        fs:  `cpe:2.3:a:dotcms:dotcms:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.534:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.8.1`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.10.3`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.12`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:6.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.12.3`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:6.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.22.1`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r12b-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.22.3`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.24`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.24.5`,
        fs:  `cpe:2.3:a:galen_charlton:marc-xml:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.26.1`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.26.3`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.28.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.30.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:2.32.3`,
        fs:  `cpe:2.3:a:al_3azmi:ce4arab_market:0.12.13093.40460:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:evolution:3.0.3`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.0:e0101l01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.16.5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.17.1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.17.2`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.0.0.1040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.17.3`,
        fs:  `cpe:2.3:a:apache:juddi:0.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.17.90`,
        fs:  `cpe:2.3:o:apple:mac_os:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.17.91`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.17.92`,
        fs:  `cpe:2.3:o:buffalotech:whr-1166dhp_firmware:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.18.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.18.1`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.18.2`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.19.1`,
        fs:  `cpe:2.3:a:individualsoftware:professor_teaches_outlook:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.19.2`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.19.3`,
        fs:  `cpe:2.3:a:webmin:usermin:1.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.19.4`,
        fs:  `cpe:2.3:h:axis:230_mpeg2_video_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.19.90`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.19.91`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.19.92`,
        fs:  `cpe:2.3:h:dell:kace_k1000_systems_management_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.20.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.21.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.20.1`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.20.2`,
        fs:  `cpe:2.3:a:sybase:easerver_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:eye_of_gnome:3.20.3`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gcab:0.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gdk-pixbuf:2.22.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gdk-pixbuf:2.23.3`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gdk-pixbuf:2.23.5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gdk-pixbuf:2.24.0`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_ee:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gdk-pixbuf:2.26.1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.14:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.1.12`,
        fs:  `cpe:2.3:o:d-link:dsr-250n_firmware:1.05b53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.1.12-1`,
        fs:  `cpe:2.3:h:nvidia:quadro_m600m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.1.15`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.0`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.1`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.3`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.4`,
        fs:  `cpe:2.3:h:hp:jg353a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.5`,
        fs:  `cpe:2.3:o:cray:unicos_lc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.6`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.7`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.8`,
        fs:  `cpe:2.3:a:ericsson:drutt_mobile_service_delivery_platform:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.9`,
        fs:  `cpe:2.3:a:apache:opennlp:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.2.10`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.3.9`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.3.10`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:08-00-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.3.11`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.3.12`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.3.13`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.3.14`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:1.3.15`,
        fs:  `cpe:2.3:a:redhat:storage:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0.0`,
        fs:  `cpe:2.3:h:siemens:scalance_x-200irt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0.1`,
        fs:  `cpe:2.3:a:google:v8:3.24.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0.3`,
        fs:  `cpe:2.3:a:facsys:facsys_desktop_client:5.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0.4`,
        fs:  `cpe:2.3:a:microsoft:ie:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.111.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0.6`,
        fs:  `cpe:2.3:a:citrix:cloudplatform:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.0.7`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.1.0`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.1.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.50.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.1.2`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.1.3`,
        fs:  `cpe:2.3:a:bigware:bigware_shop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.1.4`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.1.5`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_user_tracking_utility:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.2.0`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.1.1.329:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.2.1`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.2.2`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.2.3`,
        fs:  `cpe:2.3:a:pass4sure:questions_and_answers_for_cisco_640-816:3.0:*:*:*:demo:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.3.0`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.888:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.3.1`,
        fs:  `cpe:2.3:a:hp:sitescope_integrations:11.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.3.2`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.3.3`,
        fs:  `cpe:2.3:h:ibm:s07:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.3.4`,
        fs:  `cpe:2.3:h:ge:snmp\/web_adapter_1024921:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.3.5`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.3.6`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.0`,
        fs:  `cpe:2.3:a:dell:wireless_wlan_card_driver:4.100.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.1`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p326:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.3`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.5`,
        fs:  `cpe:2.3:a:hp:storageworks_xp_host_agent_installer:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zd4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.7`,
        fs:  `cpe:2.3:a:sun:java_system_access_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.4.8`,
        fs:  `cpe:2.3:a:php:php:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.5.0`,
        fs:  `cpe:2.3:a:cisco:unified_operations_manager:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.5.1`,
        fs:  `cpe:2.3:a:oracle:listener:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.5.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.626:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.5.3`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.5.4`,
        fs:  `cpe:2.3:a:tools4ever:user_management_resource_administrator:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.5.5`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:538:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.5.6`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.5.7`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.6.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.6.1`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.67:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.6.2`,
        fs:  `cpe:2.3:a:redhat:lha:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.6.3`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.5.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.6.4`,
        fs:  `cpe:2.3:a:sun:java_embedding_plugin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.6.5`,
        fs:  `cpe:2.3:a:autodesk:land_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.6.6`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.7.0`,
        fs:  `cpe:2.3:a:apple:itunes:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.7.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.7.2`,
        fs:  `cpe:2.3:a:gnu:glibc:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.7.3`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.7.4`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.7.5`,
        fs:  `cpe:2.3:a:apache:hadoop:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.7.6`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.7.7`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.8.0`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.8.1`,
        fs:  `cpe:2.3:a:oracle:developer_tools_for_visual_studio_help:11.1.620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.8.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.8.3`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ebw:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.8.4`,
        fs:  `cpe:2.3:h:redhat:network_satelite_server:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.8.5`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.8.6`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.9.0`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.9.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:8:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.9.2`,
        fs:  `cpe:2.3:a:apache:solr:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.9.3`,
        fs:  `cpe:2.3:a:roxio:creator_data:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.9.4`,
        fs:  `cpe:2.3:a:web2py:web2py:1.96.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.9.5`,
        fs:  `cpe:2.3:a:umn:mapserver:4.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.9.6`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.10.0`,
        fs:  `cpe:2.3:a:wysigot:wysigot:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.10.1`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.10.2`,
        fs:  `cpe:2.3:a:symantec:network_access_control:11.0.7000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.10.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.11.0`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.11.1`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.11.2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.11.3`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.11.4`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.0`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.1`,
        fs:  `cpe:2.3:a:adobe:bridge:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.2`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.3`,
        fs:  `cpe:2.3:a:apache:hadoop:0.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.6`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.7`,
        fs:  `cpe:2.3:a:stillbreathing:bannerman:0.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.8`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.9`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.10`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.11`,
        fs:  `cpe:2.3:a:apple:safari:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.12`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.12.13`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.13.0`,
        fs:  `cpe:2.3:a:tobias_bathge:wp-table_reloaded:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.13.1`,
        fs:  `cpe:2.3:a:gnu:mailman:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.13.2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.13.3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.396.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.13.4`,
        fs:  `cpe:2.3:a:sun:grid_engine:6.0:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.13.5`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.13.6`,
        fs:  `cpe:2.3:a:koha:koha:3.16.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.13.7`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.14.0`,
        fs:  `cpe:2.3:a:csounds:csound:5.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.14.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.14.2`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.14.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.14.4`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.14.5`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.14.6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.15.0`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.15.1`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.15.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.15.3`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.15.4`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.16-64.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.15.5`,
        fs:  `cpe:2.3:a:leon_weber:pyxtrlock:0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.15.6`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.16.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.16.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.16.2`,
        fs:  `cpe:2.3:a:roxio:central_core:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.16.3`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder_g2:6.1.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.16.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.16.5`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.16.6`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.17.0`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l1_controller_firmware:21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.17.1`,
        fs:  `cpe:2.3:a:microsoft:pinyin_ime:2010:*:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.17.2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.17.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.343:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.17.4`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.17.5`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.79:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.17.6`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.17.7`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:06-70-\/g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.18.0`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.18.1`,
        fs:  `cpe:2.3:a:dell:sonicwall_analyzer:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.18.2`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.18.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.18.4`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.1`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.387:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.3`,
        fs:  `cpe:2.3:a:netapp:data_ontap:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.4`,
        fs:  `cpe:2.3:a:phplist:phplist:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.5`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.6`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.8`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.9`,
        fs:  `cpe:2.3:a:mcafee:siteadvisor:3.3.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.19.10`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.20.0`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.20.1`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.20.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.20.3`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.20.4`,
        fs:  `cpe:2.3:a:yokogawa:fast\/tools:r9.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.20.5`,
        fs:  `cpe:2.3:a:blogengine:e2:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.21.0`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.21.1`,
        fs:  `cpe:2.3:o:debian:debian_linux:3.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.21.2`,
        fs:  `cpe:2.3:a:microsoft:windows_2000_terminal_services:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.21.3`,
        fs:  `cpe:2.3:a:ca:license_software:1.63.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.21.4`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.21.5`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.21.6`,
        fs:  `cpe:2.3:a:debian:adequate:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.22.0`,
        fs:  `cpe:2.3:a:apple:safari:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.22.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.22.2`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.22.3`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.22.4`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.22.5`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.23.0`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.23.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.23.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.23.3`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.23.4`,
        fs:  `cpe:2.3:a:news_project:news:3.4.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.23.5`,
        fs:  `cpe:2.3:h:hp:0235a32g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.23.6`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.24.0`,
        fs:  `cpe:2.3:a:opcsystems:opcsystems.net:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.24.1`,
        fs:  `cpe:2.3:a:websense:websense_email_security:6.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.24.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(22\)md:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.0`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.1`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.2`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.3`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.5`,
        fs:  `cpe:2.3:a:revive-adserver:revive_adserver:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.6`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.1.35:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.7`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:15.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ea2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.9`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.10`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.11`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.12`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.13`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.14`,
        fs:  `cpe:2.3:a:ncr:bootdiskmon:2.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.15`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.16`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.25.17`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.26.0`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.26.1`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.0`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.1`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.3`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.6_build_97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.4`,
        fs:  `cpe:2.3:a:livetecs:timeline:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.5`,
        fs:  `cpe:2.3:a:wampserver:wampserver:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.90`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.91`,
        fs:  `cpe:2.3:a:home_improvement_project:home_improvement:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.92`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.27.93`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.0`,
        fs:  `cpe:2.3:a:adobe:dreamweaver:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.1`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.tc4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.3`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.4`,
        fs:  `cpe:2.3:a:python:python:2.7.1150:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.5`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_anti-spyware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.6`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.7`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.28.8`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.2`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.4`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5a\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.6`,
        fs:  `cpe:2.3:a:gnu:groff:1.11a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.8`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.10`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.3:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.12`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.14`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.16`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.18`,
        fs:  `cpe:2.3:a:ross_burton:libsocialweb:0.25.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.90`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.29.92`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.30.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.30.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.30.2`,
        fs:  `cpe:2.3:a:microsoft:xml_core_services:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.31.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.31.2`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.31.4`,
        fs:  `cpe:2.3:h:xerox:workcentre:255:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.31.6`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.31.8`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:glib:2.44.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnombe_online_accounts:3.4.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome:-::linux`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-keyring:3.0.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-keyring:3.2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-keyring:3.4.0`,
        fs:  `cpe:2.3:a:ati:skins:0108.2146.2565.38893:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-keyring:3.4.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-keyring:3.6.0`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.8m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.0.0`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.0.0.1`,
        fs:  `cpe:2.3:h:huawei:e585:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.0.0.2`,
        fs:  `cpe:2.3:a:intel:2915abg_proset_wireless:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.0.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.0.2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.1.3`,
        fs:  `cpe:2.3:a:apache:org.apache.sling.servlets.post:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.1.4`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r2.15_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.1.90`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.1.90.1`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.1.91`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.1.91.1`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.1.92`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.72:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.2.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.2.1`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.2.2`,
        fs:  `cpe:2.3:a:pgp:keyserver:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.2.2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.3.2`,
        fs:  `cpe:2.3:h:hp:jf240a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.3.5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.3.90`,
        fs:  `cpe:2.3:a:intel:proset_for_wired_connections:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.3.91`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.3.92`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.4.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.3:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.4.1`,
        fs:  `cpe:2.3:a:altiris:barcode_solution_documentation:6.6.1031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.4.2`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.5.2`,
        fs:  `cpe:2.3:a:autodesk:autocad_architecture_2012:6.7.49.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.5.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.16:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.5.4`,
        fs:  `cpe:2.3:a:agilebits:knox:2.0.5:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.5.90`,
        fs:  `cpe:2.3:a:adobe:flash_player:19.0.0.226:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.5.91`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.5.92`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.6.0`,
        fs:  `cpe:2.3:a:docker:docker:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.6.1`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_500-37:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.6.3`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.6.3.1`,
        fs:  `cpe:2.3:a:samba:samba:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.2`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.2.1`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.3`,
        fs:  `cpe:2.3:a:apache:hadoop:0.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.3.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.4`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.4.1`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.5`,
        fs:  `cpe:2.3:a:autodesk:revit:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.91`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp2:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.7.92`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.4542:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.8.0`,
        fs:  `cpe:2.3:a:dleviet:datalife_engine:9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.8.0.1`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction_collaboration:4.5.1.328258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.8.1`,
        fs:  `cpe:2.3:a:apple:cups:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.8.2`,
        fs:  `cpe:2.3:a:insanevisions:adaptcms:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.8.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.8.4`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.9.1`,
        fs:  `cpe:2.3:a:emc:networker:7.4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.9.2`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.9.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.9.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.9.5`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5605:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.9.90`,
        fs:  `cpe:2.3:a:citrix:xendesktop:5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.9.91`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.9.92`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:9.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.10.0`,
        fs:  `cpe:2.3:a:david_king:vino:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.10.0.1`,
        fs:  `cpe:2.3:a:artifex:mujs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.10.1`,
        fs:  `cpe:2.3:a:mautic:mautic:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.10.2`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.10.2.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.10.3`,
        fs:  `cpe:2.3:a:mover_project:mover:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.10.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.11.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:4.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.11.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.11.3`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.11.5`,
        fs:  `cpe:2.3:o:conectiva:linux:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.11.90`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.11.91`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.11.92`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.12.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.12.1`,
        fs:  `cpe:2.3:a:qemu:qemu:0.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-shell:3.14.0`,
        fs:  `cpe:2.3:a:mobilityware:spider_solitaire:3.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:-`,
        fs:  `cpe:2.3:a:libpng:libpng:0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:0.28.0`,
        fs:  `cpe:2.3:a:corel:painter_ix:9.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:0.28.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.0`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.1.1`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.1.2`,
        fs:  `cpe:2.3:a:netscape:navigator:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.1.3`,
        fs:  `cpe:2.3:a:iss:blackice_agent_server:3.6eca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.1.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.2`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.2.1`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.26.3.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:108.2146.2565.38893:*:*:ar:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome-terminal:2.28.1`,
        fs:  `cpe:2.3:a:atheme:atheme:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:-`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:12.0.1:-:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:0.7`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.14.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:1.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.47:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.0`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.3`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.1:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.4`,
        fs:  `cpe:2.3:a:logitech:lws_videoeffects:13.25.1005.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.4.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)s7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.4.1.1`,
        fs:  `cpe:2.3:a:microsoft:windows_live_messenger:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.4.1.2`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cm1312nfi_multifunction_printer:cc431a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.4.1.3`,
        fs:  `cpe:2.3:o:siemens:cvmw3025-ir_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.4.1.4`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.1\(.02043\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.4.1.5`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.4.1.6`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:preview2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.5`,
        fs:  `cpe:2.3:a:apache:solr:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.6`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.8`,
        fs:  `cpe:2.3:a:oracle:mysql_connector_j:5.1.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.13`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14`,
        fs:  `cpe:2.3:a:apache:struts:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.1`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.19.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.5`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.6`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.7`,
        fs:  `cpe:2.3:a:git-scm:git:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.8`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v100r006c00spc800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.9`,
        fs:  `cpe:2.3:a:ibm:content_collector:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.10`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.76:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.11`,
        fs:  `cpe:2.3:a:google:v8:3.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.14.12`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.15`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.1.0.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.16`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.16.1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.16.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.17`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.18`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.18.1`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.18.2`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.18.3`,
        fs:  `cpe:2.3:a:meinberg:ntp_time_server_monitor:0.9g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.19`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.17:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.19.1`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:fp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.19.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.19.3`,
        fs:  `cpe:2.3:h:cisco:unified_ip_conference_station_7935:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.19.4`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.0`,
        fs:  `cpe:2.3:a:hp:fax:82.0.188.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.4`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.5`,
        fs:  `cpe:2.3:o:huawei:unified_security_gateway_firmware:v300r001c10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.6`,
        fs:  `cpe:2.3:h:hp:designjet_500ps:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.7`,
        fs:  `cpe:2.3:a:gns3:gns3:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.8`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.9`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.20.10`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:944sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21.2`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21.4`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21.5`,
        fs:  `cpe:2.3:a:twilio_project:twilio:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21.6`,
        fs:  `cpe:2.3:a:icewarp:webmail:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21.7`,
        fs:  `cpe:2.3:a:altiris:client_service:5.6.181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21.8`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.4.4:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.21.9`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.22.0`,
        fs:  `cpe:2.3:a:mollify:mollify:1.6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.23`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.23.2`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.23.90`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.23.92`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.24`,
        fs:  `cpe:2.3:a:gnu:radius:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.24.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.24.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.944.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.25`,
        fs:  `cpe:2.3:a:google:chrome:4.0.299.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.25.1`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.6.0:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.25.2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.4p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.25.92`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.26.0`,
        fs:  `cpe:2.3:a:google:chrome:46.0.2490.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.26.1`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.27.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p1_beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.27.4`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.27.90`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.28.0`,
        fs:  `cpe:2.3:a:juniper:junos_space:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.28.1`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.28.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.29.0`,
        fs:  `cpe:2.3:a:oracle:mysql:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.29.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.29.4`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.05.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.29.5`,
        fs:  `cpe:2.3:a:barracuda:yosemite_server_backup:8.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.29.6`,
        fs:  `cpe:2.3:a:debian:reportbug:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.29.92`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1024:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.30.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_4700:q7492a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.30.1`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.30.2`,
        fs:  `cpe:2.3:a:werner_baumann:davfs2:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.30.3`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.30.4`,
        fs:  `cpe:2.3:a:redhat:spacewalk:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.30.5`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.30.6`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.30.7`,
        fs:  `cpe:2.3:a:brocade:san_health_diagnostics_capture:3.2.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.31.0`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.07.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.31.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.31.2`,
        fs:  `cpe:2.3:a:oracle:database_server:9.0.2.4:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.31.90`,
        fs:  `cpe:2.3:a:samba:samba:3.0.20:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.31.92`,
        fs:  `cpe:2.3:a:ca:brightstor_storage_resource_manager:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.32.0`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.32.1`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:ccb:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.32.2`,
        fs:  `cpe:2.3:a:phpfox:phpfox:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.91.0`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.91.4`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:4.2\(1\)_sv1\(4b\):-:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.91.6`,
        fs:  `cpe:2.3:a:redhat:cygwin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.91.90`,
        fs:  `cpe:2.3:a:ibm:homepageprint:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.91.91`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.91.92`,
        fs:  `cpe:2.3:a:novell:edirectory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.91.93`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:2.91.94`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.0.0`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.0.2`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.0.3`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.20:build110707:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.0.4`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.1.2`,
        fs:  `cpe:2.3:h:cisco:telepresence_mcu_4520:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.1.90`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.1.91`,
        fs:  `cpe:2.3:o:cisco:headend_system_release:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.1.92`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update6:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.2.0`,
        fs:  `cpe:2.3:a:gnu:gdb:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.2.1`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.2.1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.3.92`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.3.92.1`,
        fs:  `cpe:2.3:o:oracle:linux:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.4.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:8.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.4.0.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.4.1`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.3\(2i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.4`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.4.1`,
        fs:  `cpe:2.3:a:atutor:atutor:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.4.2`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.5`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.90`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.417:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.91`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.92`,
        fs:  `cpe:2.3:a:heat-trakr_project:heat-trackr:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.5.92.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.5.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.6.0`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.03b23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_display_manager:3.6.1`,
        fs:  `cpe:2.3:o:ibm:aix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.4.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.6.0`,
        fs:  `cpe:2.3:a:perl:perl:2.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.6.1`,
        fs:  `cpe:2.3:o:advantech:eki-1322_series_firmware:2015-10-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.6.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.7.1`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.24.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.7.2`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.7.3`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.7.4`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnome_online_accounts:3.7.90`,
        fs:  `cpe:2.3:a:castor_project:castor:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.0`,
        fs:  `cpe:2.3:a:bluecoat:reporter:9.2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.1`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.2`,
        fs:  `cpe:2.3:h:hp:0235a398:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.3`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.4`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.5`,
        fs:  `cpe:2.3:a:php:php:5.5.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.6`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.7`,
        fs:  `cpe:2.3:a:barebones:textwrangler:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.8`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_configuration_manager:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:gnumeric:1.12.9`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.0.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.1\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.0.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.0.2`,
        fs:  `cpe:2.3:a:gnu:anubis:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sg.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.1.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.1.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.1.3`,
        fs:  `cpe:2.3:a:vmware:workstation:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.1.4`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.1.5`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ebg:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:1.1.6`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.0.0`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.0.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.1.0`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.1.1`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:1.5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.1.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.7.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.1.4`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.1.5`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.2.0`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3b.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.2.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.2.2`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.2.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.24:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.2.4`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.2.5`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.3.0`,
        fs:  `cpe:2.3:h:cisco:ace_application_controle_engine_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.3.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.4.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.5.0`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.6.0`,
        fs:  `cpe:2.3:a:wpcommenttwit_project:wpcommenttwit:0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.6.1`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5800-56c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.6.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.6.3`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.6.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.6.5`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.7.0`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.7:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.7.1`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.9.434:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.7.2`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.8.0`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.8.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.9.5`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.11.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(27\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.11.1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.12.0`,
        fs:  `cpe:2.3:a:videos_tube_project:videos_tube:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.12.1`,
        fs:  `cpe:2.3:a:mozilla:camino:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.12.2`,
        fs:  `cpe:2.3:a:wave:embassy_security_center:1.1.8.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.12.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.12.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.12.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2009.113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.12.6`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.12.7`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.094:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.1`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_management_console:11.0.17318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.3`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.4`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(12a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.5`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.90`,
        fs:  `cpe:2.3:a:microsoft:visual_c\&#43;\&#43;:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.91`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.92`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.13.93`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.14.0`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.14.1`,
        fs:  `cpe:2.3:a:yokogawa:fast\/tools:r9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.14.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5100:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.14.3`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.14.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p299:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.15.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.15.90`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.16.0`,
        fs:  `cpe:2.3:a:nasioc:nasioc:3.8.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.16.1`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.18.0`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2014:-:*:*:tetsu:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.18.1`,
        fs:  `cpe:2.3:a:hex-rays:ida:6.6:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.18.2`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.20.0`,
        fs:  `cpe:2.3:h:fortinet:fortianalyzer-3000d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.22.0`,
        fs:  `cpe:2.3:a:rakus:maildealer:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.22.1`,
        fs:  `cpe:2.3:h:axis:2130_ptz_network_camera:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.22.2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.22.3`,
        fs:  `cpe:2.3:a:gnu:gdb:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.26.0`,
        fs:  `cpe:2.3:a:skype:skype:1.2.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.26.1`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.26.2`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.26.3`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.31.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.32.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.32.1`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.34.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.41.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.34.1`,
        fs:  `cpe:2.3:a:google:v8:3.13.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.34.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.21.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.35.0`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.35.1`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.35.2`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.27:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.36.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.36.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.36.2`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.36.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.37.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.39.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.40.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.40.6`,
        fs:  `cpe:2.3:a:jease:jease:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:librsvg:2.40.11`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:libsocialweb:0.25.1`,
        fs:  `cpe:2.3:a:ibm:security_directory_server:6.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:libsocialweb:0.25.5`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:libsocialweb:0.25.10`,
        fs:  `cpe:2.3:a:websense:websense_email_security:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:libsocialweb:0.25.13`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:libsocialweb:0.25.19`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(8\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:screensaver:3.4.0`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:screensaver:3.4.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.291:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:screensaver:3.4.3`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:screensaver:3.5.3`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:tomboy:1.0.1`,
        fs:  `cpe:2.3:a:symantec:wise_package_studio:7.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:tomboy:1.2.2`,
        fs:  `cpe:2.3:a:cisco:unity_connection:11.5\(0.199\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:tomboy:1.4.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.392:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:tomboy:1.5.1`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:-:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:tomboy:1.5.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:update-manager-core:0.150.5.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:update-manager-core:0.152.25.10`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.1.7.770:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:update-manager-core:0.156.14.3`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnome:update-manager-core:0.156.14.4`,
        fs:  `cpe:2.3:a:autodesk:dwg_trueview:18.1.49.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gns3:gns3:0.7.1`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gns3:gns3:0.7.4`,
        fs:  `cpe:2.3:a:symantec:data_center_security_server:6.0:mp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gns3:gns3:1.2.3`,
        fs:  `cpe:2.3:a:tibco:activematrix_policy_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:a2ps:-`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:a2ps:4.10.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p279:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:a2ps:4.10.4`,
        fs:  `cpe:2.3:a:hp:photosmart_express:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:a2ps:4.12`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:a2ps:4.13`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:a2ps:4.13b`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:a2ps:4.14`,
        fs:  `cpe:2.3:a:apache:openjpa:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:anubis:-`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:anubis:3.6.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:anubis:3.6.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:anubis:3.6.2`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:anubis:3.9.92`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:anubis:3.9.93`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh8b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:aspell:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:aspell:0.50-3`,
        fs:  `cpe:2.3:a:avaya:vsu_10000:3.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:aspell:0.50.5`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:aspell_dictionary:0.50-2:::en`,
        fs:  `cpe:2.3:o:cisco:ios_xe:15.4\(3\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.0`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.6_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.2`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.3`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.4:p1`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.4:p2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.277:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.4:p3`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:-:*:solaris:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.4:p4`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2007:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.4:p5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.3.2.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.4:p6`,
        fs:  `cpe:2.3:a:sun:java_web_console:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.5`,
        fs:  `cpe:2.3:a:gegl:gegl:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.6`,
        fs:  `cpe:2.3:a:polycom:s4gw_system_software:5.7.2.0.g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.6.1`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.251:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.6.2`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.6.3`,
        fs:  `cpe:2.3:a:apache:synapse:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7`,
        fs:  `cpe:2.3:o:apple:iphone_os:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.2`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.3`,
        fs:  `cpe:2.3:a:imsidesign:turbocad_deluxe:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.4`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.6`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.7`,
        fs:  `cpe:2.3:a:vips:vips:7.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.8`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.7.9`,
        fs:  `cpe:2.3:a:froxlor:froxlor:0.9.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.8`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.8.1`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.8.2`,
        fs:  `cpe:2.3:h:seil:bpv_4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.8.3`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.8.4`,
        fs:  `cpe:2.3:a:sun:java_system_access_manager:6.3:2005q4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.8.5`,
        fs:  `cpe:2.3:h:cisco:router_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.9`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.9.1`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.9.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.9.3`,
        fs:  `cpe:2.3:a:debian:mime-support:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.9.4`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.9.5`,
        fs:  `cpe:2.3:h:schneider-electric:tburjr900:01002eh0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.9.6`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.10`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.10.1`,
        fs:  `cpe:2.3:a:novell:identity_manager:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.10.2`,
        fs:  `cpe:2.3:a:ulead:photoimpact:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.10.3`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.11.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.11.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p173:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.11.3`,
        fs:  `cpe:2.3:a:justsystems:just_school:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.11.4`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.00.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.11.5`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.11.6`,
        fs:  `cpe:2.3:a:piwik:piwik:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.12`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5612:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.12.1`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:9.0.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:automake:1.12.2`,
        fs:  `cpe:2.3:a:roxio:cineplayer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:1.14.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:1.14.1`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:1.14.2`,
        fs:  `cpe:2.3:a:isc:inn:1.4sec2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:1.14.3`,
        fs:  `cpe:2.3:a:kryo:iodine:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:1.14.4`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_real-time_information_portal:3.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:1.14.5`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:1.14.6`,
        fs:  `cpe:2.3:a:google:chrome:13.0.775.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:1.14.7`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.0`,
        fs:  `cpe:2.3:o:d-link:dir-619l_firmware:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.01`,
        fs:  `cpe:2.3:a:video-lead-form:uk-cookie:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.01.1`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:8.6\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.02`,
        fs:  `cpe:2.3:h:sun:fire_x2200_m2:2.19:_nil_:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.02.1`,
        fs:  `cpe:2.3:a:dmca:dmca_watermarker:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.03`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.04`,
        fs:  `cpe:2.3:a:datawatch:monarch:10.5:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.05`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.05:a`,
        fs:  `cpe:2.3:a:lxml:lxml:3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:2.05:b`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.74:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:3.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:3.0.16`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.7.0.1530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:3.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:3.2`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:3.2.48`,
        fs:  `cpe:2.3:a:isc:bind:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:4.0`,
        fs:  `cpe:2.3:a:dhtmlx:dhtmlxspreadsheet:2.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:4.0:rc1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:4.1`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:4.2`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:4.3`,
        fs:  `cpe:2.3:h:buffalotech:wmr-300_firmware:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:bash:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)sy2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:binutils:-`,
        fs:  `cpe:2.3:a:mygamedaytix:game_day_tix:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:binutils:2.22`,
        fs:  `cpe:2.3:h:cisco:content_services_switch_11501:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:binutils:2.25`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:binutils:2.28`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:binutils:2.29`,
        fs:  `cpe:2.3:a:oracle:micros_arspos:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:binutils:2.29.1`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:-`,
        fs:  `cpe:2.3:a:google:chrome:12.0.745.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:1.5`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:1.5.3-4`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:1.6.5`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.0`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.4.6:*:*:*:*:*:*:permissive`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.1`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs3:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.2`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.3`,
        fs:  `cpe:2.3:a:triumfant:triumfant_agent:4.3.3165:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.4`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.5`,
        fs:  `cpe:2.3:a:devsaran:corporate:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.6`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.7`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.0.8`,
        fs:  `cpe:2.3:a:emc:retrospect:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.1.8`,
        fs:  `cpe:2.3:a:redhat:network_satellite:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.1.9`,
        fs:  `cpe:2.3:a:gnu:gnumail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cfengine:2.1.16`,
        fs:  `cpe:2.3:a:ibm:lotus_expeditor:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:chess:-`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110730:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:chess:5.02`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:-`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:5.2.1`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:5.91`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:5.92`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.654:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:5.93`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:5.94`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:5.95`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:5.96`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.6:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:5.97`,
        fs:  `cpe:2.3:o:yahama:rt56v:4.07.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.2`,
        fs:  `cpe:2.3:a:huawei:espace_7950:v200r002c00spc101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.3`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.4`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.5`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.6`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.7`,
        fs:  `cpe:2.3:h:seagate:wireless_mobile_storage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.8`,
        fs:  `cpe:2.3:a:levelfourdevelopment:wp-easycart:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20.4\)sp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.10`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.11`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:6.12`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:7.1`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:7.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:7.3`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:7.4`,
        fs:  `cpe:2.3:a:clamav:clamav:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:7.5`,
        fs:  `cpe:2.3:a:plone:plone:5.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:7.6`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:coreutils:8.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(10e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:-`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:1.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:1.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:1.2`,
        fs:  `cpe:2.3:a:symantec:wise_package_studio:7.3.385:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:1.3`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:11.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:2.4-2`,
        fs:  `cpe:2.3:a:emc:documentum_d2:3.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:2.5`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:2.5.90`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cpio:2.6`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.1`,
        fs:  `cpe:2.3:a:adobe:linguistics_cs4:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.62.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.5`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.6`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.7`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.9`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8b\)e16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.11`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.7.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.12`,
        fs:  `cpe:2.3:a:apache:ofbiz:13.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:cvs:1.12.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:data_display_debugger:-`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:data_display_debugger:3.3.1`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:ed:-`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.66:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:ed:0.2`,
        fs:  `cpe:2.3:h:f5:big-ip_8800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_supply_chain_management_purchasing:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:20.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.1.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:20.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:20.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:20.3`,
        fs:  `cpe:2.3:a:pgp:desktop_for_windows:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:20.4`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.3.0.3670:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:20.5`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:20.6`,
        fs:  `cpe:2.3:a:microsoft:lync_server:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:20.7`,
        fs:  `cpe:2.3:a:sysax:multi_server:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:21`,
        fs:  `cpe:2.3:a:apache:openoffice.org:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:21.1`,
        fs:  `cpe:2.3:a:plone:plone:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:21.2`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:21.2.1`,
        fs:  `cpe:2.3:a:apache:solr:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:21.3`,
        fs:  `cpe:2.3:h:axis:2460_network_dvr:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:21.3.1`,
        fs:  `cpe:2.3:a:adobe:camera_raw:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:21.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:22.1`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports:10.0.0.53327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:22.2`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:22.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:23.1`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:23.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:23.3`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_protocol_support_for_vrrp:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:23.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:24.1`,
        fs:  `cpe:2.3:a:novell:data_synchronizer:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:24.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p103:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:24.3`,
        fs:  `cpe:2.3:h:cisco:cius:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:emacs:24.4`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:-`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.3.0`,
        fs:  `cpe:2.3:a:perl:perl:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.4`,
        fs:  `cpe:2.3:a:gnu:libidn:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.4.0`,
        fs:  `cpe:2.3:a:nortel:mobile_voice_client_2050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.5`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.22.11:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.5.0`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.6`,
        fs:  `cpe:2.3:a:conky:conky:1.7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.6.0`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.6.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.6.2`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.6.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.6.4`,
        fs:  `cpe:2.3:a:collectiveaccess:providence:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.6.4:beta`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.0:preview2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:enscript:1.6.4_beta`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:fileutils:-`,
        fs:  `cpe:2.3:a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:fileutils:4.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:fileutils:4.0.36`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:fileutils:4.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:fileutils:4.1.6`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:sp2:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:fileutils:4.1.7`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.3:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:findutils:-`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(7\)aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:findutils:4.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp3525:cc469a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:findutils:4.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:findutils:4.2.28`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.00.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:findutils:4.2.29`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:findutils:4.2.30`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:finger_service:-`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:fingerd:-`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.24.621:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:fingerd:1.37`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:flash_player:-`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:flash_player:0.7.2`,
        fs:  `cpe:2.3:a:roxio:creator:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:flim:-`,
        fs:  `cpe:2.3:a:dhtmlx:dhtmlxspreadsheet:1.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:flim:1.14.2`,
        fs:  `cpe:2.3:a:macromedia:jrun:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:g%2b%2b:-`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:g%2b%2b:3.3.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gcc:-`,
        fs:  `cpe:2.3:a:opendaylight:opendaylight:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gcc:3.3.3`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gcc:4.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:4.18`,
        fs:  `cpe:2.3:a:juniper:junos_pulse_access_control_service:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:5.0`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:5.0.92`,
        fs:  `cpe:2.3:a:websense:triton_web_filter:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:5.0.93`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:5.1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:5.1.1`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:5.2`,
        fs:  `cpe:2.3:a:flightgear:flightgear:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:5.2.1`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:5.3`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.0`,
        fs:  `cpe:2.3:a:keepass:keepass:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.1`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.1.1`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.2`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1500.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.2.1`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.4`,
        fs:  `cpe:2.3:a:redhat:freeipa:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.5`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.6`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.7`,
        fs:  `cpe:2.3:a:kingsoft:personal_firewall_9:2009.05.07.70:-:plus:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.7.1`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:6.8`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.0.1`,
        fs:  `cpe:2.3:a:avast:internet_security:11.1.2245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.2`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a4:2.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p400:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.3.1`,
        fs:  `cpe:2.3:a:microsoft:access_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.4`,
        fs:  `cpe:2.3:a:hp:version_control_agent:6.1.0.842:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.4.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:8.3\(0\)cv\(0.345\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.5.1`,
        fs:  `cpe:2.3:a:sprint:airave_software:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.11`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.11.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)ja1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.12`,
        fs:  `cpe:2.3:a:openstack:swift:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:7.12.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:8.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.9:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gdb:8.0.1`,
        fs:  `cpe:2.3:a:borland:starteam_sdk_runtime_for_.net:10.0.58.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gettext:-`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gettext:0.14.1`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gimp:-`,
        fs:  `cpe:2.3:a:rocketsoftware:rocket_servergraph:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gimp:2.6.8`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gimp:2.6.11`,
        fs:  `cpe:2.3:a:adobe:robohelp:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:-`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.2\(2e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.0.1`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6eca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.0.2`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.0.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.0.4`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.0.5`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5104h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.0.6`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ecf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.1.1`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.1.1.6`,
        fs:  `cpe:2.3:a:hp:intelligent_provisioning:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.1.2`,
        fs:  `cpe:2.3:o:microsoft:windows_me:-:scd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.1.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.1.9`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.2.1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.006:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.2.2`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.2.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.4:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.2.4`,
        fs:  `cpe:2.3:h:hp:0235a298:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.2.5`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.3`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.3.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-03-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.3.2`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.3.3`,
        fs:  `cpe:2.3:a:gnome:glib:2.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.3.4`,
        fs:  `cpe:2.3:a:mediawiki:rssreader:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.3.5`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.3.6`,
        fs:  `cpe:2.3:a:apache:mod_dav_svn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.3.10`,
        fs:  `cpe:2.3:a:acronis:components_for_remote_installation:11.0.17318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.4`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.5`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.5_build_719:*:exchange:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.5.1`,
        fs:  `cpe:2.3:a:gnu:groff:1.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.6`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.6.1`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.7`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.8`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.9`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.10`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.10.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.11`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.11.1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.11.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.39.389:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.11.3`,
        fs:  `cpe:2.3:o:sgi:irix:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.12`,
        fs:  `cpe:2.3:a:hp:storageworks_windows_host_agent_files:2.22.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.12.1`,
        fs:  `cpe:2.3:a:microsoft:office_communications_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.12.2`,
        fs:  `cpe:2.3:a:avaya:message_networking:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.13`,
        fs:  `cpe:2.3:o:sun:solaris:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.14`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.1_build_9.0.1.1000:mr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.14.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.15`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.16`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:06-70-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.17`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.33.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.19`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.20`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.21`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.22`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.23`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.17:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:glibc:2.25`,
        fs:  `cpe:2.3:h:supermicro:x9dr7-ln4f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnash:0.8.5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnash:0.8.7`,
        fs:  `cpe:2.3:h:cisco:ios:12.2jk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnash:0.8.8`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnash:0.8.9`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.42.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnash:0.8.9:rc4`,
        fs:  `cpe:2.3:a:analytictech:netdraw:2.00.0097:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnats:-`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnats:3.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnats:3.113`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnats:3.113.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnats:4.0`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnats:4.1.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.7:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:-`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.0.3`,
        fs:  `cpe:2.3:a:apache:mod_python:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.0.4`,
        fs:  `cpe:2.3:a:redhat:spacewalk-java:2.1.147-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.0.5`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.6.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.0.6`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20101201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.0.7`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.0.8`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.0.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.0.10`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.2.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.3:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnubiff:1.4.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.11.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnumail:-`,
        fs:  `cpe:2.3:h:hp:psc_750:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnumail:1.1.2`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnumeric:-`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnumeric:0.27`,
        fs:  `cpe:2.3:a:phillip_lougher:squashfs:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:-`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.0`,
        fs:  `cpe:2.3:a:sony:first4internet_xcp_content_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.2`,
        fs:  `cpe:2.3:a:koha:koha:3.14.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.3`,
        fs:  `cpe:2.3:h:hp:officejet_pro_8500:cb025a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.4`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_monitoring_center_for_security:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.5`,
        fs:  `cpe:2.3:h:symantec:firewall_vpn_appliance_200r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.5b`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_7970g:8.0\(4\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.6`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.8`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:16.0.0.2:*:*:*:liberty:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.9.1`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.9.2`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.9.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.9.4`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.9.5`,
        fs:  `cpe:2.3:a:bluecoat:proxysgos:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.9.6`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnump3d:2.9.7`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:-`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.16`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.17`,
        fs:  `cpe:2.3:a:emc:rsa_authentication_agent:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.18`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.19`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.20`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.21`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.22`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.23`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.24`,
        fs:  `cpe:2.3:a:isc:bind:9.9.7:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.0.25`,
        fs:  `cpe:2.3:o:siemens:scalance_x-200_series_firmware:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.13`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.4.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.14`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.15`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.16`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.17`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1\(3\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.18`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.19`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.04.0300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.20`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.21`,
        fs:  `cpe:2.3:a:ti:pci_7510_cardbus_controller_with_smartcard_and_software:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.22`,
        fs:  `cpe:2.3:a:symantec:critical_system_protection:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.1.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_43:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.1`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.2`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp4:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.3`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.4`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.5`,
        fs:  `cpe:2.3:a:python:python:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.6`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:12.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.7`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.8`,
        fs:  `cpe:2.3:a:banner_effect_header_project:banner_effect_header:1.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.8.1a1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.10`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.2.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ey2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.3.0`,
        fs:  `cpe:2.3:o:cisco:cisco_ons_15454_system_software:9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.3.1`,
        fs:  `cpe:2.3:o:asus:rt-g32_firmware:2.0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.3.2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.47:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.3.3`,
        fs:  `cpe:2.3:a:facebook_album_fetcher_project:facebook_album_fetcher:7.x-1.x-dev:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.3.4`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:4.6\(2\):sr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.3.5`,
        fs:  `cpe:2.3:a:microsoft:ie:5.50.3825.1300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.4.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.4.1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.21:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.4.2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.0.3:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.4.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.4.4`,
        fs:  `cpe:2.3:a:redhat:dogtag_certificate_system:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.4.5`,
        fs:  `cpe:2.3:h:foundrynet:fastiron_ii_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.5.0`,
        fs:  `cpe:2.3:a:apple:iwork:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.5.1`,
        fs:  `cpe:2.3:a:rsa:ace_server:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.5.2`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.5.3`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.1362:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.5.4`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.5.5`,
        fs:  `cpe:2.3:a:sun:jre:6.0.290:update29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.6.0`,
        fs:  `cpe:2.3:a:barebones:textwrangler:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.6.1`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.1.4393:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.6.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.6.3`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.1`,
        fs:  `cpe:2.3:a:spip:spip:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.3`,
        fs:  `cpe:2.3:a:gnu:fingerd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.4`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.6`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.7`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.8`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.9`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.10`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.11`,
        fs:  `cpe:2.3:a:emc:documentum_taskspace:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.12`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.13`,
        fs:  `cpe:2.3:a:siemens:automation_license_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.14`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_rim_documentation:6.1.1010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.15`,
        fs:  `cpe:2.3:a:age_verification_project:age_verification:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.17`,
        fs:  `cpe:2.3:a:f5:linerate:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.18`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.1.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:1.7.19`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.0.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.0.1`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd3.mxx60_firmware:1.24.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.0.2`,
        fs:  `cpe:2.3:a:avonesoft:mp3_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.0.3`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.0.4`,
        fs:  `cpe:2.3:a:gcspublishing:steyr_forum:3.9.12:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.0`,
        fs:  `cpe:2.3:h:yokogawa:b\/m9000_vp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1gc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.03:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.3`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.4`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a1:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.5`,
        fs:  `cpe:2.3:a:apple:itunes:11.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.6`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:8.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.7`,
        fs:  `cpe:2.3:a:shopware:shopware:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.1.8`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.2.0`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.2.1`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.2.2`,
        fs:  `cpe:2.3:a:fiatforum:fiat_forum:3.8.41:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.2.3`,
        fs:  `cpe:2.3:o:huawei:e3236_firmware:e3236s-2tcpu-22.146.29.00.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.2.4`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce_suite:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.2.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.18:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.0`,
        fs:  `cpe:2.3:a:adobe:freehand:11.0.0.439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.1`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.5`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.7`,
        fs:  `cpe:2.3:a:openstack:compute:2013.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.8`,
        fs:  `cpe:2.3:a:magzter:intelligent_sme:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.10`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.3.11`,
        fs:  `cpe:2.3:a:apache:camel:2.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.4.0`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.4.1`,
        fs:  `cpe:2.3:a:macromedia:shockwave_flash_plugin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.4.2`,
        fs:  `cpe:2.3:a:hp:serviceguard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.4.3`,
        fs:  `cpe:2.3:a:oracle:jre:8.0:update_73:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.5.0`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.6:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.6.0`,
        fs:  `cpe:2.3:h:edimax:6114wg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.6.1`,
        fs:  `cpe:2.3:a:cisco:webns:7.30_\(00.08\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.6.2`,
        fs:  `cpe:2.3:a:brocade:ezswitchsetup:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.6.3`,
        fs:  `cpe:2.3:a:geodesicsolutions:geocore_max:7.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.6.4`,
        fs:  `cpe:2.3:h:ibm:websphere_datapower_xc10_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.6.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.6.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.7.0`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.7.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.7.2`,
        fs:  `cpe:2.3:a:facsys:facsys_desktop_client:5.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.7.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.7.4`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.7.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.7.6`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.8.0`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.8.1`,
        fs:  `cpe:2.3:a:ca:anti-virus:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.8.2`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.8.3`,
        fs:  `cpe:2.3:a:linear_case_project:linear_case:6.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.8.4`,
        fs:  `cpe:2.3:a:ibm:db2:9.8:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.8.5`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.8.6`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.10.0`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.10.1`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:589:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.10.2`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.10.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.10.4`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.10.5`,
        fs:  `cpe:2.3:a:microsoft:windows_2003:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.0`,
        fs:  `cpe:2.3:a:trendmicro:tmeext.sys:2.0.0.1014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.1`,
        fs:  `cpe:2.3:a:agilebits:knox:1.5.2:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.3`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.4`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.5`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.6`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.6.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.7`,
        fs:  `cpe:2.3:a:apache:http_server:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.8`,
        fs:  `cpe:2.3:a:gnome:evolution:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.9`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.4:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.10`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.12`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.13`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.14`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.15`,
        fs:  `cpe:2.3:h:supermicro:x9drx\&#43;-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.16`,
        fs:  `cpe:2.3:a:python:python:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.17`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.5.866.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.18`,
        fs:  `cpe:2.3:a:corel:iconhandler:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.19`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.20`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.21`,
        fs:  `cpe:2.3:a:apple:xcode:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.22`,
        fs:  `cpe:2.3:a:citrix:web_interface:5.3.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:2.12.23`,
        fs:  `cpe:2.3:a:bestapp:best_greatness_quotes:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.0`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.8.815:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.1`,
        fs:  `cpe:2.3:a:apple:bonjour:3.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.463:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.3`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.4`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.02b25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.5`,
        fs:  `cpe:2.3:a:samba:samba:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.6`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.7`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.8`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.9`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.10`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.11`,
        fs:  `cpe:2.3:a:atlassian:jira:3.8:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.12`,
        fs:  `cpe:2.3:a:mozilla:bonsai:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.13`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.14`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p70:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.635:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.16`,
        fs:  `cpe:2.3:a:cisco:cius_software:9.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.17`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.18`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.19`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.20`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.21`,
        fs:  `cpe:2.3:a:pmail:pegasus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.22`,
        fs:  `cpe:2.3:a:hp:update:5.2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.23`,
        fs:  `cpe:2.3:a:debian:fuse:2.9.3-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.24`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.25`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.26`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.27`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.0.28`,
        fs:  `cpe:2.3:a:bea:weblogic_server:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.0`,
        fs:  `cpe:2.3:a:isc:bind:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert7:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.2`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.4`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.5`,
        fs:  `cpe:2.3:a:microsoft:works:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.7`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r346.22:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.8`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:b8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.9`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.10`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.11`,
        fs:  `cpe:2.3:a:apache:hadoop:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.12`,
        fs:  `cpe:2.3:a:plone:plone:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.14`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.15`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-8t-si_ls-s3100-8t-si-ac-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.16`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.17`,
        fs:  `cpe:2.3:h:franklinfueling:ts-550_evo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.18`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.4:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.19`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.20`,
        fs:  `cpe:2.3:a:yahoo:messenger:11.0.0.2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.21`,
        fs:  `cpe:2.3:a:cisco:secure_acs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.22`,
        fs:  `cpe:2.3:a:oracle:warehouse_builder:10.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.23`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.24`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.1.25`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer_with_flow_analytics_module:9.0.0:-:pay:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.0`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.1`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.428.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.6`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.7`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.8`,
        fs:  `cpe:2.3:a:zend:zendto:4.10-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.8.1`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.9`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.19:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.10`,
        fs:  `cpe:2.3:h:tp-link:tl-wdr3500_\(1.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.11`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.12`,
        fs:  `cpe:2.3:a:cisco:pix_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.12.1`,
        fs:  `cpe:2.3:a:oracle:application_object_library:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.13`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.14`,
        fs:  `cpe:2.3:a:compaq:insight_management_agent:4.37e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.2.15`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.0:-`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.0:pre0`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.3`,
        fs:  `cpe:2.3:a:datawatch:monarch_pro:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.4`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.10`,
        fs:  `cpe:2.3:h:cisco:sg300-10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.11`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.12`,
        fs:  `cpe:2.3:h:hp:0235a238:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.13`,
        fs:  `cpe:2.3:a:oracle:database_server:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.14`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.014:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.15`,
        fs:  `cpe:2.3:a:mybb:mybb:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.16`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.3.25`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.4.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.4.1`,
        fs:  `cpe:2.3:h:hp:color_laserjet_9500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.4.2`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.4.3`,
        fs:  `cpe:2.3:a:python:python:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.4.14`,
        fs:  `cpe:2.3:a:qemu:qemu:0.14.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.0`,
        fs:  `cpe:2.3:h:avaya:s8300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.2`,
        fs:  `cpe:2.3:o:google:android:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.3`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.4`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.5`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.6`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.7`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gnutls:3.5.9`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.1.3-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gpgme:-`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gpgme:1.1.3`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gpgme:1.1.4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gpgme:1.5.0`,
        fs:  `cpe:2.3:a:henner_zeller:henplus:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.2`,
        fs:  `cpe:2.3:a:dell:openmanage:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.4`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.4.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.4.2`,
        fs:  `cpe:2.3:a:symantec:liveupdate:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.5`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-6:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.5.1`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.5.1:a`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.5.3`,
        fs:  `cpe:2.3:h:supermicro:x8dtu-ln4f\&#43;-lr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.5.3::~~gnuwin32~~~`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1301.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.5.4`,
        fs:  `cpe:2.3:a:hp:ibrix:6.1.243:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.6`,
        fs:  `cpe:2.3:a:redhat:interchange:4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.6.1`,
        fs:  `cpe:2.3:a:oracle:complex_maintenance_repair_and_overhaul:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.6.2`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.8.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.6.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.7`,
        fs:  `cpe:2.3:a:osticket:osticket:1.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.8`,
        fs:  `cpe:2.3:a:freemind:freemind:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.9`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.435:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.11`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.12`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.13`,
        fs:  `cpe:2.3:a:nero:neroxml:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.14`,
        fs:  `cpe:2.3:a:red-gate:sql_dependency_tracker:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.19`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.20`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grep:2.21`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:-`,
        fs:  `cpe:2.3:a:sgi:workshop_debugger_and_performance_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.10`,
        fs:  `cpe:2.3:a:f5:big-iq_cloud_and_orchestration:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.11`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.11a`,
        fs:  `cpe:2.3:a:ca:arcserve_backup_agent_for_open_files_for_windows:12.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.14`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.15`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.16`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.16.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.18.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:groff:1.19`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grub:-`,
        fs:  `cpe:2.3:a:gnu:fileutils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grub2:1.98`,
        fs:  `cpe:2.3:o:cisco:ios_xe_16.1:16.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grub2:1.99`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grub2:2.00`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grub2:2.01`,
        fs:  `cpe:2.3:o:google:chrome_os:0.9.134.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:grub2:2.02`,
        fs:  `cpe:2.3:a:drupal:drupal:6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gv:-`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gv:3.5.8`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gv:3.6.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.b04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gv:3.6.1`,
        fs:  `cpe:2.3:a:synck_graphica:mailform_pro_cgi:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gv:3.6.2`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.2.4`,
        fs:  `cpe:2.3:a:kmonos:xacrett:49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.2.4a`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.3.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.4`,
        fs:  `cpe:2.3:a:php:php:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.5`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.6`,
        fs:  `cpe:2.3:a:hp:process_resource_manager:c.01.08.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.7`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:gzip:1.8`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.03.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:icecat:2.0.0.1`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:icecat:2.0.0.4`,
        fs:  `cpe:2.3:a:x3cms:x3_cms:0.4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:icecat:2.0.0.5`,
        fs:  `cpe:2.3:a:sun:java_web_console:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:iceweasel:-`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:iceweasel:2.0.0.3`,
        fs:  `cpe:2.3:h:hp:lcd_pole_display_f7a93aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:inet:-`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:inetutils:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:517:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:inetutils:1.4.2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:ksymoops:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:ksymoops:2.4.5`,
        fs:  `cpe:2.3:h:huawei:6300ei:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:ksymoops:2.4.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:ksymoops:2.4.9`,
        fs:  `cpe:2.3:o:cisco:content_router_4430:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:less:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:less:358`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:less:381`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:less:382`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:less:471`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libc:-`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libc:5.0.9`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libc:5.2.18`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libc:5.3.12`,
        fs:  `cpe:2.3:h:apple:airport_express_base_station_firmware:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libcdio:-`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:*:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libcdio:0.79`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libidn:1.30`,
        fs:  `cpe:2.3:a:citadel:webcit:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libidn:1.32`,
        fs:  `cpe:2.3:a:x:libxi:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.16`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.17`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.18`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.19`,
        fs:  `cpe:2.3:a:busybox:busybox:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.20`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.21`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.22`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.23`,
        fs:  `cpe:2.3:a:itu:ap7capture:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.24`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.25`,
        fs:  `cpe:2.3:a:tincan:phplist:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.26`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.27`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.28`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.17.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.29`,
        fs:  `cpe:2.3:a:ibm:maximo_for_energy_optimization:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.30`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.31`,
        fs:  `cpe:2.3:a:schneider_electric:wonderware_intouch_2014:7.1:sp3:*:*:machine:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libmicrohttpd:0.9.32`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.16a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.1.0`,
        fs:  `cpe:2.3:a:autodesk:design_review_2010:10.0.0.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.1.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.1.2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.5.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.2`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.3`,
        fs:  `cpe:2.3:a:actualtests:comptia_220-702_in_exam_engine_format:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.4`,
        fs:  `cpe:2.3:a:emc:documentum_xplore:1.1:p01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.5`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.20:-:*:*:*:solaris:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.6`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.0.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.7`,
        fs:  `cpe:2.3:o:cisco:cisco_ons_15454_system_software:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.8`,
        fs:  `cpe:2.3:a:otrs:faq:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.9`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.10`,
        fs:  `cpe:2.3:a:oracle:jre:1.4.2_40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.11`,
        fs:  `cpe:2.3:a:packetfence:packetfence:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.12`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.13`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.14`,
        fs:  `cpe:2.3:a:zend:zendto:4.07-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.15`,
        fs:  `cpe:2.3:a:symantec:vrtsccg:5.0.443:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.16`,
        fs:  `cpe:2.3:a:smackcoders:wp_ultimate_email_marketer_plugin:1.1.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.17`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.2.18`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.0`,
        fs:  `cpe:2.3:a:oracle:interaction_blending:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.1`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:7.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.3`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.4:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.5`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.811:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.6`,
        fs:  `cpe:2.3:o:raritan:px:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.7`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.8`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.9`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.12.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:0.3.10`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.0`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.12.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.1`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.3`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.4`,
        fs:  `cpe:2.3:a:git-scm:git:0.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.5`,
        fs:  `cpe:2.3:a:skout:boyahoy_-_gay_chat:4.3.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.6`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.7`,
        fs:  `cpe:2.3:o:ibm:aix:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:1.8`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.1`,
        fs:  `cpe:2.3:a:bite_it\!_project:bite_it\!:1.1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.2`,
        fs:  `cpe:2.3:h:acer:ac700_chromebook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.3`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(19\)gs0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.4`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.5`,
        fs:  `cpe:2.3:a:dell:lasso:3.3.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.6`,
        fs:  `cpe:2.3:a:ibm:flex_system_manager:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.7`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.8`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp1518:cc378a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.9`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.10`,
        fs:  `cpe:2.3:h:3com:tippingpoint_200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.11`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:2.12`,
        fs:  `cpe:2.3:h:iij:seil_x1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:3.0`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:3.1`,
        fs:  `cpe:2.3:o:cisco:ip_phone_7800_series_firmware:10.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:3.2`,
        fs:  `cpe:2.3:a:inria:ocaml:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:3.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.480.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:3.4`,
        fs:  `cpe:2.3:a:hitachi:it_operations_analyzer:02-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:3.5`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:3.6`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.03:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:4.3`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:4.4`,
        fs:  `cpe:2.3:a:ark-web:a-form:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:4.7`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:4.8`,
        fs:  `cpe:2.3:a:compaq:compaqhttpserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:4.9`,
        fs:  `cpe:2.3:a:ayatana_project:unity:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:4.10`,
        fs:  `cpe:2.3:a:google:v8:3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtasn1:4.12`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:-`,
        fs:  `cpe:2.3:a:moodle:moodle:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.0`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1\(.1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_everyplace_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.2`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.12.140.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.3`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.3.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.3.3`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.3.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd302a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.3.5`,
        fs:  `cpe:2.3:a:adastra:trace_mode_data_center:6.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.4`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.4.1`,
        fs:  `cpe:2.3:a:sun:enterprise_storage_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.4.2`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.4.3`,
        fs:  `cpe:2.3:a:netease:netease_weibohd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool:1.5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool-ltdl:-`,
        fs:  `cpe:2.3:h:cisco:2125_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:libtool-ltdl:1.5.22-2.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je026a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:lsh:-`,
        fs:  `cpe:2.3:o:cisco:mgx_8250:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:lsh:1.4`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:lsh:1.4.1`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:lsh:1.4.2`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:9.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:lsh:2.0.1`,
        fs:  `cpe:2.3:o:oracle:opensolaris:snv_134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:-`,
        fs:  `cpe:2.3:a:apache:subversion:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:1.0`,
        fs:  `cpe:2.3:a:rpm:rpm:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:1.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1b\)da1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0:beta3`,
        fs:  `cpe:2.3:a:isc:bind:9.8.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0:beta4`,
        fs:  `cpe:2.3:h:hp:jg783a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0:beta5`,
        fs:  `cpe:2.3:a:ddsn:cm3_acora_content_management_system:6.0.2\/1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.3`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.4`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:11.0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.5`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.6`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.7`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.8`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.9`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.10`,
        fs:  `cpe:2.3:a:razorcms:razorcms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.12`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.13`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.0.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1:alpha`,
        fs:  `cpe:2.3:a:hp:storageworks_red_hat_enterprise_linux_3.0_host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1:beta`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.179:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1:stable`,
        fs:  `cpe:2.3:h:d-link:dap-3320:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.1`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.1:beta1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.2:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.2`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.1.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.4`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.3.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.5`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2_sp1:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.5.8`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.6`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.7`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.8`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.9`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.10`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.10:rc1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp2:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.10b1`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.10b3`,
        fs:  `cpe:2.3:a:vmware:view:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.10b4`,
        fs:  `cpe:2.3:h:cisco:asr_9922:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.11`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.11:rc1`,
        fs:  `cpe:2.3:a:bea:tuxedo:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.11:rc2`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.12`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.12:rc1`,
        fs:  `cpe:2.3:a:avast:endpoint_protection:8.0.1606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.12:rc2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.13`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.13:rc1`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.14`,
        fs:  `cpe:2.3:a:facebook:hiphop_virtual_machine:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.14:rc1`,
        fs:  `cpe:2.3:a:adobe:photoshop:11.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.14-1`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.15`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.15:rc1`,
        fs:  `cpe:2.3:a:oracle:human_capital_management_configuration_workbench:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.16`,
        fs:  `cpe:2.3:a:redmine:redmine:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.16:rc1`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.16:rc2`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.16:rc3`,
        fs:  `cpe:2.3:a:tinc-vpn:tinc:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.17`,
        fs:  `cpe:2.3:a:piwik:piwik:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.18`,
        fs:  `cpe:2.3:a:php:php:5.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.18:rc1`,
        fs:  `cpe:2.3:a:dadabik:dadabik:2.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.18:rc2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.18:rc3`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.30.0039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.18-1`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.19`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.0:pr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.19:rc1`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.4b.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.19:rc2`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.19:rc3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.20`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.21`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.21:rc2`,
        fs:  `cpe:2.3:a:symantec:pgp_universal_server:3.2.1:mp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.22`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(2\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1.23`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailman:2.1b1`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:0.9.2:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailutils:-`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.0:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailutils:0.5`,
        fs:  `cpe:2.3:a:redhat:undertow:1.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:mailutils:0.6`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:make:-`,
        fs:  `cpe:2.3:a:allegrosoft:rompager:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:make:3.77.44`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:patch:2.7.1`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:sp4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:phpbook:-`,
        fs:  `cpe:2.3:a:kth:wavesurfer:1.8.8:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:-`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:6.8:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.0`,
        fs:  `cpe:2.3:a:microsoft:open_xml_file_format_converter:-:*:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.2:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.0.2`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.7.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.0.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.0.4`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.0.5`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_sametime:8.5.1.20100709-1631:*:*:*:advanced_embedded:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.0.6`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.30.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.0.7`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.2`,
        fs:  `cpe:2.3:a:isc:bind:8.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.2.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8zh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.2.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.2.3`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.2.4`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.2.5`,
        fs:  `cpe:2.3:a:hitachi:job_management_partner_1\/it_desktop_management-manager:09-50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.2.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.2.7`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.3.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.3.4`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.4`,
        fs:  `cpe:2.3:a:cdotech:cdo_dal_components:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.4.1`,
        fs:  `cpe:2.3:a:vmware:fusion:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.4.2`,
        fs:  `cpe:2.3:a:websense:triton_web_security_gateway:7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.4.2.1`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.4.2.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.4.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.4.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.4.5`,
        fs:  `cpe:2.3:a:mini_group:tv_guide:5.4.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.9.10`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.4:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.9.15`,
        fs:  `cpe:2.3:a:cisco:prime_service_catalog:11.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:1.9.20`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:2.0`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.5:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:2.0.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:7.1`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:7.2`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:privacy_guard:8.0`,
        fs:  `cpe:2.3:a:python:python:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:queue:-`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:queue:1.12.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:queue:1.12.8`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.8.3\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:queue:1.12.9`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:queue:1.20.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:queue:1.20.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:queue:1.20.2`,
        fs:  `cpe:2.3:a:dave_thomas:rdoc:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:-`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:0.92.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:0.93`,
        fs:  `cpe:2.3:h:intel:active_management_technology:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:0.94`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:0.95`,
        fs:  `cpe:2.3:a:ffdshow:ffdshow_tryouts:2010-01-28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:0.96`,
        fs:  `cpe:2.3:a:rsa:securid_software_token_converter:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:1.1`,
        fs:  `cpe:2.3:a:sun:java_system_directory_proxy_server:5.2:2005q1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:1.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:radius:1.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:2.1`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x47:d35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:2.2`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:4.0`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:12.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:4.1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:4.2`,
        fs:  `cpe:2.3:a:logitech:imagestudio:7.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:4.2:a`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:4.3`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:5.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:5.1`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:5.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:6.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.105.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:6.1`,
        fs:  `cpe:2.3:o:novell:suse_linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:6.2`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb133xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:6.3`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:6.3:3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:readline:7.0`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc026xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:realtime_linux_security_module:-`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:realtime_linux_security_module:0.8.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:rsync:-`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:rsync:2.5.7`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:rush:1.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:-`,
        fs:  `cpe:2.3:a:john_geo:freelancer_calendar:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:3.9.4`,
        fs:  `cpe:2.3:a:emc:documentum_xcelerated_management_system:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:3.9.8`,
        fs:  `cpe:2.3:a:agilebits:knox:1.5.3:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:3.9.9`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.08.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:3.9.10`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:3.9.11`,
        fs:  `cpe:2.3:a:redmine:redmine:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:3.9.13`,
        fs:  `cpe:2.3:a:buffalotech:wer-am54g54_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:3.9.15`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:4.0.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:4.0.2`,
        fs:  `cpe:2.3:a:shrew:vpn_client:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:screen:4.0.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:sharutils:-`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:sharutils:4.2`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-alpha1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:sharutils:4.2.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:-`,
        fs:  `cpe:2.3:a:stage_file_proxy_project:stage_file_proxy:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13`,
        fs:  `cpe:2.3:a:oracle:quality:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13.11`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13.14`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13.17`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13.18`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1680.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13.19`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp7:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.13.25`,
        fs:  `cpe:2.3:a:busybox:busybox:0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.14`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.14.1`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.14.90`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.15`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.15.1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.16.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.15.90`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.15.91`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.50.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tar:1.16`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:texinfo:-`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:texinfo:4.8`,
        fs:  `cpe:2.3:a:perl:perl:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tramp:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg316a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:tramp:2.1.10`,
        fs:  `cpe:2.3:a:isc:bind:9.9.9:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:userv:-`,
        fs:  `cpe:2.3:h:arubanetworks:instant_access_point:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:userv:1.0.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:-`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.5.3`,
        fs:  `cpe:2.3:a:xfree86:xfree86:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.6`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:10.00.00.3990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.7`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.7.1`,
        fs:  `cpe:2.3:a:logitech:webcam_software:12.0.1280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.8`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:8.5.6-106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.8.1`,
        fs:  `cpe:2.3:h:intel:ia64:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.8.2`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.9`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.9.1`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.10`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.10.1`,
        fs:  `cpe:2.3:h:huawei:s3300hi:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.10.2`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.11.4-1::~~gnuwin32~~~`,
        fs:  `cpe:2.3:a:avaya:secure_access_link_gateway:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.17`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:wget:1.19.1`,
        fs:  `cpe:2.3:a:mcafee:cloud_single_sign_on:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:xemacs:-`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:xemacs:21.4`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r12.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zebra:-`,
        fs:  `cpe:2.3:h:cisco:epc3925:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zebra:0.91`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:2.5.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zebra:0.91a`,
        fs:  `cpe:2.3:a:ez:ez_publish:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zebra:0.92a`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing:10.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zebra:0.93a`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zebra:0.93b`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:-`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0`,
        fs:  `cpe:2.3:a:microsoft:producer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.1`,
        fs:  `cpe:2.3:a:emc:iomega_encryption:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.2`,
        fs:  `cpe:2.3:o:sun:sunos:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.3`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp1:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.5`,
        fs:  `cpe:2.3:a:leon_weber:pyxtrlock:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.7`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.8`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.0.9`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.1`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.1.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.52:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.1.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.0:beta0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.1.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.1.4`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.2.0`,
        fs:  `cpe:2.3:a:redhat:rhel_cluster:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.2.1`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.2.2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.36:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.2.8`,
        fs:  `cpe:2.3:h:barraguard:barracuda_link_balancer:330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.2.9`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.2.10`,
        fs:  `cpe:2.3:a:payment_for_webform_project:payment_for_webform:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnu:zlib:1.2.11`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.0.3`,
        fs:  `cpe:2.3:a:ca:brightstor_san_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.0.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.0.5`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.0.6`,
        fs:  `cpe:2.3:h:cisco:sg300-10sfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.0.7`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.0.8`,
        fs:  `cpe:2.3:a:php:php:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.0.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.0`,
        fs:  `cpe:2.3:a:simplehrm:simplehrm:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.2`,
        fs:  `cpe:2.3:a:schneider-electric:somachine:3.0:*:*:*:xs:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.3`,
        fs:  `cpe:2.3:a:cisco:connected_grid_network_management_system:3.0\(0.54\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.4`,
        fs:  `cpe:2.3:a:xnview:xnview:1.91.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.5`,
        fs:  `cpe:2.3:h:linksys:befsx41:1.42.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.6`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.7`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(13a\)bc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.2.9`,
        fs:  `cpe:2.3:a:blogstand_banner_plugin_project:blogstand-smart-banner:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.3.0`,
        fs:  `cpe:2.3:a:keepass:keepass:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.3.1`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.3.2`,
        fs:  `cpe:2.3:a:siteminder_federation:12.1:-:standalone:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.3.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.3.4`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:2.3.5`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:3.0`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:3.0:beta`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnugk:gnu_gatekeeper:3.1:beta`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.0.0:-`,
        fs:  `cpe:2.3:a:webgateinc:winrds:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.2.15`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.2.16`,
        fs:  `cpe:2.3:h:d-link:dcs-5010l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.2.17`,
        fs:  `cpe:2.3:a:xnview:xnview:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.2.18`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.2.19`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.3.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.3.1`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.3.2`,
        fs:  `cpe:2.3:a:hp:network_automation:10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.3.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.3.4`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp4:express_advanced_services:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.3.5`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.4.0`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.4.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u6\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.4.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.4.4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.399:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.4.5`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.0`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jpc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.3`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.4`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.5`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:60.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.6`,
        fs:  `cpe:2.3:a:google:chrome:6.0.397.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.7`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.8`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:10.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.10`,
        fs:  `cpe:2.3:a:actividentity:actividentity_device_installer:2.00.00012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:0.9.11`,
        fs:  `cpe:2.3:a:emc:networker:7.6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.0`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.1`,
        fs:  `cpe:2.3:a:andrew_levine:multiblock:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.2`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.3`,
        fs:  `cpe:2.3:a:haxx:curl:7.53.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.4:-:win32`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.5`,
        fs:  `cpe:2.3:a:hp:jetadmin:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.5:-:win32`,
        fs:  `cpe:2.3:a:janetter:janetter:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.6`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.0.7`,
        fs:  `cpe:2.3:a:google:chrome:10.0.651.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.1`,
        fs:  `cpe:2.3:a:hp:select_identity:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.1:windows`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.2`,
        fs:  `cpe:2.3:a:google:chrome:16.0.880.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.3`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1288.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.4`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s7506e-v:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.5`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.6`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.2.7`,
        fs:  `cpe:2.3:a:intel:graphics_driver:15.36.30.4385:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.0`,
        fs:  `cpe:2.3:a:gnu:rsync:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch_1800-8g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.4`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.6`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.90`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.91`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.92`,
        fs:  `cpe:2.3:o:huawei:ar_firmware:v200r005c10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.3.93`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.3`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.8`,
        fs:  `cpe:2.3:a:vmware:server:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.10`,
        fs:  `cpe:2.3:a:gnu:glibc:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.11`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.12`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2116h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.13`,
        fs:  `cpe:2.3:a:usaa:mobile_banking:7.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.14`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.10:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.15`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.16`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.4.17`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.9.16`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.9.17`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.1.1:rev30900:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.9.19`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)xf1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.9.20`,
        fs:  `cpe:2.3:a:graveydesign:gravey_design:0.58.13357.54919:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:1.9.92`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.5.502.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.24.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.4`,
        fs:  `cpe:2.3:h:cabletron:micro_mmac:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.6`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.5.1681:unknown:online_windows_server_2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.7`,
        fs:  `cpe:2.3:a:oracle:sysfw:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.8`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.10`,
        fs:  `cpe:2.3:a:microsoft:visual_basic_software_development_kit:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.11`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.12`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.13`,
        fs:  `cpe:2.3:a:oracle:hyperion_production_reporting_server:11.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.14`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.15`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:10.1.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.16`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.17`,
        fs:  `cpe:2.3:a:adobe:framemaker:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.18`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.19`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.20`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.21`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.22`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.23`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.0.1.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.0.24`,
        fs:  `cpe:2.3:a:icinga:icinga:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gnupg:2.1.0:beta1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller:4.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gpgee:1.2.0`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:gpgee:1.2.1`,
        fs:  `cpe:2.3:a:web2py:web2py:1.85.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.4.0`,
        fs:  `cpe:2.3:a:oracle:customer_interaction_history:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.4.3`,
        fs:  `cpe:2.3:a:x:x_server:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.4.4`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.4.5`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.4.6`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.5.0`,
        fs:  `cpe:2.3:a:apache:subversion:m1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.5.1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.5.2`,
        fs:  `cpe:2.3:a:ibm:db2:10.5:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.5.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.6.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.6.1`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.15f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.6.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.6.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.6.4`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.6.5`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.7.0`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.7.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gnupg:libgcrypt:1.7.2`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gnustep:base:1.24.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:go-nitty-gritty:right_to_the_nitty_gritty:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:go-text:text_me%21_free_texting_%26_call:2.5.5::~~~android~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goahead:goahead_webserver:2.0`,
        fs:  `cpe:2.3:a:drupal:drupal:7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goahead:goahead_webserver:2.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goahead:goahead_webserver:2.1.1`,
        fs:  `cpe:2.3:a:spice_project:spice:0.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goahead:goahead_webserver:2.1.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goahead:goahead_webserver:2.1.3`,
        fs:  `cpe:2.3:a:sun:java_web_start:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goahead:goahead_webserver:2.1.4`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goahead:goahead_webserver:2.1.8`,
        fs:  `cpe:2.3:a:citrix:xenapp_web_plugin:11.0.0.5357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goahead:goahead_webserver:2.5`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goautodial:goadmin_ce:3.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goautodial:goadmin_ce:3.3`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:godwin%27s_law_project:godwin%27s_law:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_bookmark_widget:1.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(0\)n1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_email_widget:1.3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r6_rc2:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_email_widget:1.8`,
        fs:  `cpe:2.3:a:horde:groupware:1.0.1:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_email_widget:1.81`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.21.1:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_fbwidget:1.9`,
        fs:  `cpe:2.3:a:ibm:u2_universe:10.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_fbwidget:2.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.362.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_message_widget:1.9`,
        fs:  `cpe:2.3:a:marked_project:marked:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_message_widget:2.1`,
        fs:  `cpe:2.3:a:sun:openoffice.org:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_message_widget:2.3`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_note_widget:1.5`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_note_widget:1.9`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.64.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_qqweibowidget:1.2`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_sms_pro:3.72`,
        fs:  `cpe:2.3:o:cisco:catos:2.4\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_sms_pro:4.10`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_sms_pro:4.35`,
        fs:  `cpe:2.3:h:generaldynamics:taclane:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_twiwidget:1.7`,
        fs:  `cpe:2.3:a:microsoft:visio_2007:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_twiwidget:2.1`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.03b12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goforandroid:go_weibowidget:2.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gogago:gogago_youtube_video_converter:1.1.6`,
        fs:  `cpe:2.3:a:blaine_lang:filedepot:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gojbm:coe_message_processor:4.6.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:golang:go:1.6`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gollos:gollos:2.8`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gollum_project:gollum:4.0`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:golosinassimpson:golosinas_simpson1:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:apple:watchos:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomiso:miso:2.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.0.6`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.4.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.0.9`,
        fs:  `cpe:2.3:a:google:chrome:5.0.380.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.0.11`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je046a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.0.12`,
        fs:  `cpe:2.3:a:iomega:hotburn:2.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.1`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.2`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.3`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.6`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.8`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.817:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.9.3753`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.9.3754`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.14.4525`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.15.4610`,
        fs:  `cpe:2.3:a:tumbleweed:validation_authority:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.16.4631`,
        fs:  `cpe:2.3:a:ibm:maximo_anywhere:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.17.4710`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.18.4762`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.21.4846`,
        fs:  `cpe:2.3:a:ingy:spoon:0.24:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.25.5015`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p86:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.27.5031`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.28.5039`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.33.5071`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.37.5085`,
        fs:  `cpe:2.3:a:php:php:5.4.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.39.5101`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.40.5106`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.292:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.43.5119`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.47.5133`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.49.5139`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.48.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.1.50.5145`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.2.53.5169`,
        fs:  `cpe:2.3:o:centos:centos:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gomlab:gom_player:2.2.56.5158`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goo:dj_brad_h:0.9::~~~android~~`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:3.6ecf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goo:health_assistance_service:2.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.02.0090:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:1.9.8`,
        fs:  `cpe:2.3:a:adobe:flash:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:1.9.9`,
        fs:  `cpe:2.3:a:digium:asterisk:13.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:1.9.10`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jab:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.0.0`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:0.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.0.1`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.0.2`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.0.3.1464`,
        fs:  `cpe:2.3:a:dameware:remote_support:9.0.1.247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.1.2.1510`,
        fs:  `cpe:2.3:o:xen:xen:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.1.3.1513`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.1.4.1518`,
        fs:  `cpe:2.3:a:corosync:corosync:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.1.5.1551`,
        fs:  `cpe:2.3:a:ubuntu_developers:language-selector:0.79.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.2.0.1575`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.2.1.1591`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.2.2`,
        fs:  `cpe:2.3:a:compaq:version_control_agent:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.2.3`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_for_enterprise:2.2.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30174:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_messaging_server:_6.3.1.24`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:good:good_mobile_control_server:_1.3.1.122`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:1.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:jijitechnologies:active_directory_cleaner:3.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.2:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:webhive:timeline:4.2.5:p9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.3:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.4:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5600:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.5:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.5.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg312a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.6:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:oracle:payroll:12.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.7:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.7.4:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:e107:e107:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.8:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.8.2:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:cartpauj:shortcode-redirect:1.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.8.4:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:2.8.5:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.0.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.0.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.0.2:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.0.3:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.1.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:mozilla:mozilla_suite:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.1.2:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.2.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.2.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:h:tropos:4310_mobile_mesh_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.2.3:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:sap:hybris:5.1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.3.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.3.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.4.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/a:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.4.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.5.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.5.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.6.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:h:netgear:fvs318:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.6.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.7.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.7.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.8.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.04.313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.8.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.9.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:apache:ambari:2.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.9.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.10.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-00-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.10.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.10.2:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:estateapps:acorn_estate_agents:3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.10.3:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.11.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.11.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:cognos:series_7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.12.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.12.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.14.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.13.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.13.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.14.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:microsoft:windows-nt:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.14.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.14.2:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.15.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.15.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodiware:goodreader:3.16:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:justsystems:atok_subscription_service:-:windows:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goodwinproject:goodwin:1.15::~~~android~~`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:admob:-`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:1.0`,
        fs:  `cpe:2.3:h:f5:firepass_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:1.1`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:1.5`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:1.6`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.0.1`,
        fs:  `cpe:2.3:h:polycom:hdx_7002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.1`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.2`,
        fs:  `cpe:2.3:a:chamberme:so._co._business_partnership:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.2:rev1`,
        fs:  `cpe:2.3:a:codepeople:com_multicalendar:4.0.2:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.2.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.5.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.2.2`,
        fs:  `cpe:2.3:a:ibm:informix:7.25_.uc3_se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.2.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3:rev1`,
        fs:  `cpe:2.3:a:almanah_project:almanah:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3.1`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:9.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3.2`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3.4`,
        fs:  `cpe:2.3:a:combodo:itop:1.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3.5`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3.6`,
        fs:  `cpe:2.3:h:hp:jf228a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:2.3.7`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.1\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:3.0`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.22:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:3.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:3.2`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:3.2.1`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:3.2.2`,
        fs:  `cpe:2.3:o:bluecoat:sgos:5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:3.2.4`,
        fs:  `cpe:2.3:h:nvidia:geforce_gtx_1080:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:3.2.6`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.16:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.0.1`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.0.2`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.0.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.0.4`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.1`,
        fs:  `cpe:2.3:h:sun:storedge_6130_arrays:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.1.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:2.1.1063:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30172:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.2.1`,
        fs:  `cpe:2.3:a:adobe:onlocation_cs4:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.2.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.3`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)sg1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.4`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.4.1`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.4.2`,
        fs:  `cpe:2.3:h:supermicro:x9drl-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.4.3`,
        fs:  `cpe:2.3:a:hp:release_control:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:4.4.4`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/ru2_firmware:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:5.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.411.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:5.0.1`,
        fs:  `cpe:2.3:a:juniper:junos_pulse_secure_access_service:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:5.0.2`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:5.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:5.1.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.1.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:5.1.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:6.0`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:6.0.1`,
        fs:  `cpe:2.3:a:alfresco:alfresco:4.1.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:7.0`,
        fs:  `cpe:2.3:o:juniper:ive_os:7.2r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:7.1.0`,
        fs:  `cpe:2.3:a:php:php:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:7.1.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:7.1.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:android:8.0`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:2.0`,
        fs:  `cpe:2.3:a:apache:hadoop:0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:3.0`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:4.0`,
        fs:  `cpe:2.3:a:indigorose:setup_factory:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:5.0`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:6.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:7.0`,
        fs:  `cpe:2.3:a:microsoft:visio:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:8.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:9.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:10.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:11.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:12.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-05-\/p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:13.0`,
        fs:  `cpe:2.3:a:opsview:opsview:4.0:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:14.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_hydravision_full:2009.0211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:15.0`,
        fs:  `cpe:2.3:a:informatica:powercenter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:16.0`,
        fs:  `cpe:2.3:a:teamquest:manager:10.1_pf_20081001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:17.0`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:18.0`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_api:19.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_browser:4.2.1:-:~-~-~android~~:-`,
        fs:  `cpe:2.3:a:powie:pgb:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_debug_bridge:-`,
        fs:  `cpe:2.3:a:pegasus_airlines_project:pegasus_airlines:0.84.13503.96707:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_sdk_platform_tools:18.0.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:android_sdk_tools:0.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(8.3\)sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:api_search:-`,
        fs:  `cpe:2.3:a:att:communication_manager:6.12.0046.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:api_search:1.3.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:apps_migration_for_microsoft_exchange:2.2.756.1127`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:authenticator:0.86`,
        fs:  `cpe:2.3:a:citrix:xendesktop:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:authenticator:0.87`,
        fs:  `cpe:2.3:a:sharethis:sharethis:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:authenticator:0.91`,
        fs:  `cpe:2.3:a:pomm-project:pomm:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:bionic:-::~~~android~~`,
        fs:  `cpe:2.3:a:netease:netease_pmail:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:checkout-php:1.2`,
        fs:  `cpe:2.3:a:google:android_api:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:checkout-php:1.2:beta`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:checkout-php:1.2.1:beta`,
        fs:  `cpe:2.3:a:vips:vips:7.11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:checkout-php:1.2.5`,
        fs:  `cpe:2.3:a:cisco:unity_connection:11.5\(0.98\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:checkout-php:1.2.5a`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:checkout-php:1.3.0`,
        fs:  `cpe:2.3:a:ibm:db2:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:checkout-php:1.3.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:checkout-php:1.3.2`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.1.38.1`,
        fs:  `cpe:2.3:h:cisco:vpn_3060_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.1.38.2`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.1.38.4`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.1.40.1`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.1.42.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.1.42.3`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.2.149.27`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4501_series_software:4.2\(1.46\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.2.149.29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.2.149.30`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je019a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.2.152.1`,
        fs:  `cpe:2.3:h:cisco:unified_computing_system_6248up_fabric_interconnect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.2.153.1`,
        fs:  `cpe:2.3:a:php:php:5.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.3.154.0`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.3.154.3`,
        fs:  `cpe:2.3:a:google:chrome:9.0.578.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.4.154.18`,
        fs:  `cpe:2.3:a:docker:docker:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.4.154.22`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2011.1025.2152.37348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.4.154.31`,
        fs:  `cpe:2.3:o:cisco:staros:15.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:0.4.154.33`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.36`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.39`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.42`,
        fs:  `cpe:2.3:o:huawei:s9303e_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.43`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.46`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.48`,
        fs:  `cpe:2.3:a:microsoft:directx:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.52`,
        fs:  `cpe:2.3:a:newsoftinc:presto\!_pagemanager:7.16.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.53`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.59`,
        fs:  `cpe:2.3:o:juniper:junos:16.1:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.64`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:1.0.154.65`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1a_pk3_bl3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.156.1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.157.0`,
        fs:  `cpe:2.3:a:ibm:websphere_cast_iron_solution:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.157.2`,
        fs:  `cpe:2.3:h:ceragon:fiberair_ip-10e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.158.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.159.0`,
        fs:  `cpe:2.3:a:citrix:xenmobile_device_manager:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.169.0`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.169.1`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.170.0`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172`,
        fs:  `cpe:2.3:a:boost:boost:1.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.2`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.8`,
        fs:  `cpe:2.3:a:linkit_project:linkit:7.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.27`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.28`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.30`,
        fs:  `cpe:2.3:h:netgear:rp114:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.31`,
        fs:  `cpe:2.3:a:rsa:envision:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.33`,
        fs:  `cpe:2.3:a:sgminer_project:sgminer:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.37`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:2.0.172.38`,
        fs:  `cpe:2.3:a:pass4sure:questions_and_answers_for_ec-council_2-50:3.0:*:*:*:demo:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.182.2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.190.2`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.145:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.193.2:beta`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.21`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.24`,
        fs:  `cpe:2.3:a:exim:exim:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.25`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.27`,
        fs:  `cpe:2.3:a:linux-sottises:news-tnk:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.32`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.33`,
        fs:  `cpe:2.3:a:checkpoint:ng-ai:r54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.36`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.37`,
        fs:  `cpe:2.3:a:apple:quicktime:6.1.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:3.0.195.38`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.212.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.212.1`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.75.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.221.8`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.222.0`,
        fs:  `cpe:2.3:h:supermicro:x9drl-3f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.222.1`,
        fs:  `cpe:2.3:a:plone:plone:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.222.5`,
        fs:  `cpe:2.3:a:gnu:ed:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.222.12`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:gold:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.223.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.223.1`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.223.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.223.4`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.223.5`,
        fs:  `cpe:2.3:o:sun:sunos:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.223.7`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.223.8`,
        fs:  `cpe:2.3:a:openfabrics:ibacm:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.223.9`,
        fs:  `cpe:2.3:a:adobe:flash_player:26.0.0.137:*:*:*:*:internet_explorer_11:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.224.0`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.229.1`,
        fs:  `cpe:2.3:a:atlassian:oauth:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.235.0`,
        fs:  `cpe:2.3:a:hp:select_identity:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.236.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.237.0`,
        fs:  `cpe:2.3:a:datadynamics:activereports:2.5.0.1314:_nil_:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.237.1`,
        fs:  `cpe:2.3:a:git-scm:git:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.239.0`,
        fs:  `cpe:2.3:a:hp:customer_participation_program:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.240.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.241.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.242.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.243.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.244.0`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.245.0`,
        fs:  `cpe:2.3:a:netgear:readynas_surveillance:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.245.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.246.0`,
        fs:  `cpe:2.3:a:microsoft:windows_2000_terminal_services:-:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.247.0`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.248.0`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.0`,
        fs:  `cpe:2.3:a:gummi_project:gummi:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.1`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.2`,
        fs:  `cpe:2.3:a:aol:aolserver:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.3`,
        fs:  `cpe:2.3:a:autodesk:autocad_electrical:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.4`,
        fs:  `cpe:2.3:a:hp:fortify_software_security_center:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.5`,
        fs:  `cpe:2.3:o:siemens:ozw772_firmware:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.6`,
        fs:  `cpe:2.3:a:bea:weblogic_workshop:8.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.7`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.8`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.9`,
        fs:  `cpe:2.3:a:cisco:ucs_director:4.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.10`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.11`,
        fs:  `cpe:2.3:a:cisco:finesse:9.1\(1\)_es1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.12`,
        fs:  `cpe:2.3:a:apple:cups:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.14`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.16`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.17`,
        fs:  `cpe:2.3:a:combodo:itop:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.18`,
        fs:  `cpe:2.3:a:hp:photosmart_essential:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.19`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.20`,
        fs:  `cpe:2.3:o:trustix:secure_linux:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.21`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.16:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.22`,
        fs:  `cpe:2.3:a:spice_project:spice:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.23`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.24`,
        fs:  `cpe:2.3:h:canon:network_camera_server_vb101:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.25`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.26`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p107:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.27`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.28`,
        fs:  `cpe:2.3:a:red-gate:sql_refactor:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.29`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.30`,
        fs:  `cpe:2.3:a:totalseminars:a\&#43;_2009_701_and_702_voucher_demo:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.31`,
        fs:  `cpe:2.3:a:gnu:radius:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.32`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p72:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.33`,
        fs:  `cpe:2.3:h:axis:2400_video_server:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.34`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.35`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.36`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.37`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.38`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:2.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.39`,
        fs:  `cpe:2.3:o:hp:1000_series_firmware:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.40`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:10.6.0.42:*:*:*:freeware:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.41`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.42`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.43`,
        fs:  `cpe:2.3:a:josh_fradley:burden:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.44`,
        fs:  `cpe:2.3:a:ibm:web_content_manager:8.0.0.0:cf003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.45`,
        fs:  `cpe:2.3:h:sierrawireless:raven_x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.46`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.47`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.48`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.49`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.50`,
        fs:  `cpe:2.3:a:mono:mono:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.51`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2005-09-19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.52`,
        fs:  `cpe:2.3:a:gnome:glib:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.53`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.54`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.55`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg348a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.56`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.57`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.58`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.59`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.60`,
        fs:  `cpe:2.3:a:novell:netware_client:4.91:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.61`,
        fs:  `cpe:2.3:a:osisoft:pi_interface:3.1.2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.62`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.63`,
        fs:  `cpe:2.3:o:google:android:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.64`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.65`,
        fs:  `cpe:2.3:a:projectforge:projectforge:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.66`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.67`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2008.225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.68`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.9:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.69`,
        fs:  `cpe:2.3:a:adobe:adobe_air:14.0.0.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.70`,
        fs:  `cpe:2.3:a:oracle:database_server:11.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.71`,
        fs:  `cpe:2.3:a:spip:spip:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.72`,
        fs:  `cpe:2.3:a:appthemes:classipress:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.73`,
        fs:  `cpe:2.3:a:apple:safari:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.74`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.75`,
        fs:  `cpe:2.3:a:oracle:interaction_blending:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.76`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1131:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.77`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0\(2c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.78`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.78:beta`,
        fs:  `cpe:2.3:a:perl:perl:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.79`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.80`,
        fs:  `cpe:2.3:o:apple:airport_base_station_firmware:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.81`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.82`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.249.89`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.250.0`,
        fs:  `cpe:2.3:a:ibm:qradar_risk_manager:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.250.2`,
        fs:  `cpe:2.3:a:qemu:qemu:0.14.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.251.0`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.8.2-webinterface:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.252.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.254.0`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.255.0`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.256.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.257.0`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.258.0`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:0.93.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.259.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.260.0`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.261.0`,
        fs:  `cpe:2.3:o:google:android:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.262.0`,
        fs:  `cpe:2.3:a:cisco:webns:7.50.2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.263.0`,
        fs:  `cpe:2.3:a:altiris:power_control_task:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.264.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.265.0`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.266.0`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.267.0`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.268.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.269.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.271.0`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.272.0`,
        fs:  `cpe:2.3:a:jan_bednarik:cooluri:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.275.0`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.10c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.275.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.276.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.277.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.278.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.286.0`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4.2:*:validation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.287.0`,
        fs:  `cpe:2.3:a:apache:axis2:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.288.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.7.6:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.288.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.289.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:te4.1.1-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.290.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.292.0`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.294.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.295.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1662.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.296.0`,
        fs:  `cpe:2.3:h:siemens:scalance_w746-1pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.299.0`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.300.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.301.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.302.0`,
        fs:  `cpe:2.3:a:microsoft:excel:2000:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.302.1`,
        fs:  `cpe:2.3:a:utorrent:utorrent_remote:1.0.20110929:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.302.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5s\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.302.3`,
        fs:  `cpe:2.3:a:microsoft:asp.net_core:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.303.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.304.0`,
        fs:  `cpe:2.3:a:oracle:clinical:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.0.305.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1:beta`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1001`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1004`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1006`,
        fs:  `cpe:2.3:a:sixapart:movabletype:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1007`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1008`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1009`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1010`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p479:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1011`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.01.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1012`,
        fs:  `cpe:2.3:a:trend_micro:trend_micro_common_cgi:2.0.0.1227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1013`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_secureclient:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1014`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1015`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1016`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1017`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-4.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1018`,
        fs:  `cpe:2.3:a:oracle:developer_tools_for_visual_studio_help:11.1.720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1019`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(2\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1020`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1021`,
        fs:  `cpe:2.3:a:rack_project:rack:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1022`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1023`,
        fs:  `cpe:2.3:a:logitech:videocall\&#43;vibec:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1024`,
        fs:  `cpe:2.3:a:google:chrome:5.0.317.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1025`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1026`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1027`,
        fs:  `cpe:2.3:a:happyworm:jplayer:0.2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1028`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp1:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1029`,
        fs:  `cpe:2.3:a:iscripts:easybiller:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1030`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1031`,
        fs:  `cpe:2.3:a:mutiny:mutiny:5.0-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1032`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.1:cf3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1033`,
        fs:  `cpe:2.3:a:microsoft:frontpage_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1034`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1035`,
        fs:  `cpe:2.3:a:microsoft:terminal_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1036`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1037`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1038`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1039`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1040`,
        fs:  `cpe:2.3:a:cisco:vsc3000:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1041`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1042`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1043`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1044`,
        fs:  `cpe:2.3:h:hp:apache-based_web_server:2.0.43.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1045`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.3.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1046`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1047`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1048`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1049`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:-:pre1:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1050`,
        fs:  `cpe:2.3:a:adobe:illustrator:16.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1051`,
        fs:  `cpe:2.3:a:riken:xoonips:3.46:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1052`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1053`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1054`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1055`,
        fs:  `cpe:2.3:h:ovislink:airlive_poe100hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1056`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1057`,
        fs:  `cpe:2.3:a:roxio:express_labeler:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1058`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1059`,
        fs:  `cpe:2.3:a:xnview:xnview:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1060`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1061`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1062`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1063`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:4.1.249.1064`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.306.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.306.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.1`,
        fs:  `cpe:2.3:h:softbank:disney_mobile_android_smartphone:dm011sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.3`,
        fs:  `cpe:2.3:a:x.org:libxv:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.5`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.95.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.6`,
        fs:  `cpe:2.3:a:ipswitch:imail_premium:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.7`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.8`,
        fs:  `cpe:2.3:a:digium:asterisk:14.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.9`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.10`,
        fs:  `cpe:2.3:o:cisco:catos:7.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.307.11`,
        fs:  `cpe:2.3:a:siemens:simatic_pcs7:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.308.0`,
        fs:  `cpe:2.3:a:apple:webkit:85.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.309.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.313.0`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.314.0`,
        fs:  `cpe:2.3:a:isc:bind:9.11.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.314.1`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.315.0`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.316.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.317.0`,
        fs:  `cpe:2.3:a:hp:veritas_recordnow:3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.317.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.317.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1652.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.318.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.319.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:8.0.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.320.0`,
        fs:  `cpe:2.3:o:cisco:ons_15216_optical_add_drop_multiplexer:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.321.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:0.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.322.0`,
        fs:  `cpe:2.3:a:emurasoft:emeditor_professional:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.322.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.322.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.323.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.324.0`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.325.0`,
        fs:  `cpe:2.3:a:kk-osk:advance-flow_forms:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.326.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.327.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.328.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cm6040_mfp:q3939a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.329.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.330.0`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.332.0`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.333.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.50:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.334.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.335.0`,
        fs:  `cpe:2.3:a:network-weathermap:.network_weathermap:0.97:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.335.1`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.335.2`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.335.3`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.335.4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.336.0`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.337.0`,
        fs:  `cpe:2.3:a:google:v8:3.17.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.338.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.339.0`,
        fs:  `cpe:2.3:a:aprelium:abyss_web_server_x1:2.4.0.3:-:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.340.0`,
        fs:  `cpe:2.3:a:blackberry:enterprise_server_express:5.0.4:*:*:*:*:lotus_domino:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.341.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.1`,
        fs:  `cpe:2.3:a:tionetworks:gulf_power_mobile_bill_pay:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)ec1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.4`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.5`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.6`,
        fs:  `cpe:2.3:h:lexmark:x73x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.8`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.342.9`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.343.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.344.0`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.345.0`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.346.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.443.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.347.0`,
        fs:  `cpe:2.3:a:adobe:dispatcher:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.348.0`,
        fs:  `cpe:2.3:a:microsoft:access:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.349.0`,
        fs:  `cpe:2.3:a:winscp:winscp:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.350.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.350.1`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.351.0`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5037-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.353.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.354.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.354.1`,
        fs:  `cpe:2.3:a:ibm:spectrum_protect_for_virtual_environments:7.1:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.355.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.356.0`,
        fs:  `cpe:2.3:a:python-requests:requests:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.356.1`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-s24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.356.2`,
        fs:  `cpe:2.3:a:synology:download_station:3.8.2-3455:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.357.0`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-07-21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.358.0`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:1.2.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.359.0`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.360.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.360.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.360.4`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.360.5`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.361.0`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.362.0`,
        fs:  `cpe:2.3:a:ssh:secure_shell_for_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.363.0`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.364.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.365.0`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.366.0`,
        fs:  `cpe:2.3:a:cisco:anyconnect_vpn_client_start_before_login_components:2.4.1012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.366.1`,
        fs:  `cpe:2.3:a:ciphertrust:ironmail:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.366.2`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.0.115.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.366.3`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.366.4`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.367.0`,
        fs:  `cpe:2.3:a:debian:elvis_tiny:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.368.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.369.0`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.8:beta:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.369.1`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.369.2`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.370.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.371.0`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.372.0`,
        fs:  `cpe:2.3:a:iss:realsecure_network:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.373.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:14.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.374.0`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.0`,
        fs:  `cpe:2.3:a:ibm:intelligent_operations_center:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.1`,
        fs:  `cpe:2.3:a:python:python:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.2`,
        fs:  `cpe:2.3:o:xen:xen:4.4.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.4`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.42a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.5`,
        fs:  `cpe:2.3:a:nokia:affix:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.6`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.8`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.9`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_client:06-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.10`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.264:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.11`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.12`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.13`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.14`,
        fs:  `cpe:2.3:a:love_horoscope_guide_project:love_horoscope_guide:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.15`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.40.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.16`,
        fs:  `cpe:2.3:a:cisco:ucs_director:4.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.17`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.95.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.18`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.19`,
        fs:  `cpe:2.3:a:isc:bind:9.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.20`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_91:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.21`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.22`,
        fs:  `cpe:2.3:h:mediabridge:medialink_mwn-wapr300n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.23`,
        fs:  `cpe:2.3:h:hp:j9851a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.25`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.04b58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.26`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.27`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.9:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.28`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.29`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.117.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.30`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.31`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.32`,
        fs:  `cpe:2.3:a:atme:atme:1.0.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.33`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.34`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.35`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.4:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.36`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.37`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.38`,
        fs:  `cpe:2.3:a:yahoo:tumblr:3.4.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.39`,
        fs:  `cpe:2.3:h:hp:jf431c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.40`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.40a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.41`,
        fs:  `cpe:2.3:a:openstack:swift:1.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.42`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.43`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.44`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.45`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.46`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.47`,
        fs:  `cpe:2.3:a:google:chrome:10.0.608.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.48`,
        fs:  `cpe:2.3:a:netmarble:mpang.gp:4.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.49`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.50`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.51`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.52`,
        fs:  `cpe:2.3:a:synology:video_station:1.5-0753:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.53`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.54`,
        fs:  `cpe:2.3:a:cisco:webns:7.20.2.206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.55`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.56`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.57`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.58`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.59`,
        fs:  `cpe:2.3:a:horde:imp:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.60`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.61`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.62`,
        fs:  `cpe:2.3:a:lightscribe:lightscribe:1.4.142.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.63`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3040-ac-ovs-as-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.64`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.65`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.3:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.66`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.68.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.67`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.68`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.69`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.70`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.71`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.471:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.72`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.73`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.74`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.75`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.76`,
        fs:  `cpe:2.3:a:symantec:endpoint_encryption:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.77`,
        fs:  `cpe:2.3:a:apache:log4j:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.78`,
        fs:  `cpe:2.3:a:dell:sonicwall_global_management_system:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.79`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.80`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.81`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.82`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.83`,
        fs:  `cpe:2.3:a:redmine:redmine:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.84`,
        fs:  `cpe:2.3:a:vmware:gsx_server:3.0_build_7592:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.85`,
        fs:  `cpe:2.3:h:iodata:ts-wlcam\/v_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.86`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.87`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:3.2.1.0401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.88`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p407:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.89`,
        fs:  `cpe:2.3:a:erlang:crypto:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.90`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.91`,
        fs:  `cpe:2.3:a:ibm:websphere_dashboard_framework:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.92`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.93`,
        fs:  `cpe:2.3:a:piwik:piwik:0.6.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.94`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.460:mr6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.95`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.96`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.97`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.98`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.440:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.99`,
        fs:  `cpe:2.3:a:trustport:webfilter:6.0.0.3033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.125`,
        fs:  `cpe:2.3:a:zippyyum:subway_ordering_for_california:3.7.1:-:-:*:-:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.126`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.375.127`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.376.0`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.378.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.379.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_operations:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.380.0`,
        fs:  `cpe:2.3:a:apache:solr:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.381.0`,
        fs:  `cpe:2.3:a:apple:quicktime:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.382.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.382.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.0:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.383.0`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.384.0`,
        fs:  `cpe:2.3:h:fujitsu:scansnap_s1500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.385.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.386.0`,
        fs:  `cpe:2.3:a:isc:bind:9.10.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.387.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.3:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.390.0`,
        fs:  `cpe:2.3:o:ibm:global_console_manager_16_firmware:1.18.0.22011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.391.0`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.392.0`,
        fs:  `cpe:2.3:a:horde:gollem:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.393.0`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.394.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.1xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.395.0`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_technology_for_sysml:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:5.0.396.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.397.0`,
        fs:  `cpe:2.3:a:cobblerd:cobbler:2.4.0:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.398.0`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.399.0`,
        fs:  `cpe:2.3:a:oracle:applications:10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.400.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.468:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.401.0`,
        fs:  `cpe:2.3:a:symantec:netbackup_enterprise_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.401.1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.403.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.404.0`,
        fs:  `cpe:2.3:a:idleman:leed:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.404.1`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2005:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.404.2`,
        fs:  `cpe:2.3:a:google:v8:3.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.405.0`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.406.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:1.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.407.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.0`,
        fs:  `cpe:2.3:h:ibm:system_x3630_m4_hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.1`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:fp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.3`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.4`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:8.0.0:03:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.6`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p1_rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.8`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.9`,
        fs:  `cpe:2.3:o:d-link:dsl-2730b_firmware:ge_1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.408.10`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.409.0`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.410.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.411.0`,
        fs:  `cpe:2.3:a:oracle:hyperion_financial_management:11.1.2.1.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.412.0`,
        fs:  `cpe:2.3:a:serena:changeman_version_manager:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.413.0`,
        fs:  `cpe:2.3:a:php-nuke:sections_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.414.0`,
        fs:  `cpe:2.3:a:tag1consulting:support_timer:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.415.0`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.415.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:git5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.416.0`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.416.1`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.417.0`,
        fs:  `cpe:2.3:a:gnu:gdb:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.0`,
        fs:  `cpe:2.3:a:intel:network_connections:15.7.176.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.1`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.3.1:mu_\#2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.2`,
        fs:  `cpe:2.3:a:redhat:network_satellite:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.3`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.4`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.8:cert1_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.6`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1012:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.7`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.8`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.418.9`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050306:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.419.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.421.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.422.0`,
        fs:  `cpe:2.3:a:bestpractical:rtfm:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.423.0`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_monitor_solution:6.0.1064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.424.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.425.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.426.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.427.0`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.428.0`,
        fs:  `cpe:2.3:a:openbsd:ftpd:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.430.0`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.431.0`,
        fs:  `cpe:2.3:a:veritas:backup_exec:16.1142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.432.0`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.433.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.434.0`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.435.0`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.436.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30352:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.437.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.437.1`,
        fs:  `cpe:2.3:a:google:chrome:16.0.900.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.437.2`,
        fs:  `cpe:2.3:a:reviewboard:djblets:0.7.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.437.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.438.0`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.440.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.441.0`,
        fs:  `cpe:2.3:a:ibm:bigfix_remote_control:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.443.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.444.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.445.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.445.1`,
        fs:  `cpe:2.3:a:hp:panostandalone:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.446.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.447.0`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.447.1`,
        fs:  `cpe:2.3:h:sfr:sfr_box_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.447.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.449.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.450.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1o\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.450.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.450.2`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.450.3`,
        fs:  `cpe:2.3:a:oracle:industry_applications:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.450.4`,
        fs:  `cpe:2.3:a:codehaus:xfire:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.451.0`,
        fs:  `cpe:2.3:a:greenend:putty:0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.452.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.452.1`,
        fs:  `cpe:2.3:o:d-link:dsr-150n_firmware:1.05b64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.453.0`,
        fs:  `cpe:2.3:o:sun:solaris:4.1.3:u1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.453.1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.454.0`,
        fs:  `cpe:2.3:o:ibm:aix:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.455.0`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2007-07-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.456.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.cors:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.457.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.458.0`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce_suite_service_provider:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.458.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.458.2`,
        fs:  `cpe:2.3:a:winscp:winscp:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.459.0`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.43:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.460.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.461.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.462.0`,
        fs:  `cpe:2.3:h:ubnt:aircam_dome:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.464.1`,
        fs:  `cpe:2.3:a:sap:netweaver:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.465.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.465.2`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.0.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.466.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.466.1`,
        fs:  `cpe:2.3:a:opalvoip:portable_tool_library:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.466.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je009a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.466.3`,
        fs:  `cpe:2.3:a:percona:percona_server:5.7.13-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.466.4`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.466.5`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.466.6`,
        fs:  `cpe:2.3:o:schneider-electric:tburjr900_firmware:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.467.0`,
        fs:  `cpe:2.3:h:extremenetworks:msm64:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.469.0`,
        fs:  `cpe:2.3:a:netease:netease_cloudalbum:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.470.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.471.0`,
        fs:  `cpe:2.3:a:cobblerd:cobbler:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.0`,
        fs:  `cpe:2.3:a:hp:status:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.2`,
        fs:  `cpe:2.3:a:devsaran:company:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.3`,
        fs:  `cpe:2.3:a:biscom:faxcom_suite_for_windows_client:9.4.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.4`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.5`,
        fs:  `cpe:2.3:a:paypal:instant_payment_notification:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.6`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/f:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.7`,
        fs:  `cpe:2.3:a:synology:video_station:1.2-0451:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.9`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.10`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.11`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.12`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.13`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.14`,
        fs:  `cpe:2.3:a:crazybrowser:crazybrowser:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.15`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.16`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.17`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.18`,
        fs:  `cpe:2.3:a:intel:processor_graphics:8.15.10.2418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.19`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.20`,
        fs:  `cpe:2.3:a:combodo:itop:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.21`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:r55w:hfa2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.22`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.23`,
        fs:  `cpe:2.3:a:stardock:fences:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.24`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.25`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.26`,
        fs:  `cpe:2.3:a:apple:itunes:4.9.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.27`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.28`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.186.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.29`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.30`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.31`,
        fs:  `cpe:2.3:a:ultrapop:i-httpd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.32`,
        fs:  `cpe:2.3:a:adobe:connect:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.33`,
        fs:  `cpe:2.3:a:sap:supplier_relationship_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.34`,
        fs:  `cpe:2.3:a:microsoft:iis:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.35`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.36`,
        fs:  `cpe:2.3:a:adobe:flash_player:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.37`,
        fs:  `cpe:2.3:a:kajona:kajona:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.38`,
        fs:  `cpe:2.3:a:apple:apple_tv:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.39`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.40`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.41`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.42`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.43`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.44`,
        fs:  `cpe:2.3:a:squareup:okhttp3:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.45`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.46`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.47`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.48`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.49`,
        fs:  `cpe:2.3:a:buffalotech:whr-amg54_firmware:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.50`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.51`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.1.5:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.52`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.53`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.54`,
        fs:  `cpe:2.3:a:david_king:vino:2.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.55`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.56`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.57`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.45:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.58`,
        fs:  `cpe:2.3:a:webmin:webmin:1.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.59`,
        fs:  `cpe:2.3:a:compaq:insight_manager_xe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.60`,
        fs:  `cpe:2.3:a:openstack:telemetry_\(ceilometer\):2013.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.61`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.62`,
        fs:  `cpe:2.3:a:bioinformatics:ordersys:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.472.63`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.473.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.474.0`,
        fs:  `cpe:2.3:a:zenprise:zenprise_device_manager:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.475.0`,
        fs:  `cpe:2.3:a:serena:teamtrack:6.6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.476.0`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.477.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.478.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.479.0`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.480.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.481.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.482.0`,
        fs:  `cpe:2.3:a:veritas:backup_exec_remote_agent:9.0.4454:sp1:windows_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.483.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.484.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(22\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.485.0`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.07.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.486.0`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.487.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.488.0`,
        fs:  `cpe:2.3:a:apps4u\@android:sd_card_manager:20140224:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.489.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.490.0`,
        fs:  `cpe:2.3:o:canyon-tech:cn-wf514_router_firmware:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.490.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.491.0`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r14b03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.492.0`,
        fs:  `cpe:2.3:a:nttdata:terasoluna_server_framework_for_java_web:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.493.0`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.494.0`,
        fs:  `cpe:2.3:a:symantec:mail_security_for_smtp:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.495.0`,
        fs:  `cpe:2.3:a:ibm:content_collector:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.495.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.17:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:6.0.496.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.497.0`,
        fs:  `cpe:2.3:h:cisco:2000_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.498.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.499.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.499.1`,
        fs:  `cpe:2.3:a:siemens:simatic_step_7:13.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.500.0`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.47:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.500.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.503.0`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd923a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.503.1`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.504.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.505.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.506.0`,
        fs:  `cpe:2.3:a:google:v8:5.1.281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.507.0`,
        fs:  `cpe:2.3:a:adobe:indesign_cs4_common_base_files:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.507.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:4.00:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.507.2`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.507.3`,
        fs:  `cpe:2.3:a:novell:libzypp:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.509.0`,
        fs:  `cpe:2.3:a:netscape:communicator:4.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.510.0`,
        fs:  `cpe:2.3:h:buffalotech:whr-am54g54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.511.1`,
        fs:  `cpe:2.3:a:dadabik:dadabik:3.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.511.2`,
        fs:  `cpe:2.3:a:oscommerce:online_merchant:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.511.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.512.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.12:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.513.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.514.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.7.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.514.1`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.515.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.516.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00-09:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.458.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.5`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.6`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.7`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.8`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.9`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.10`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.11`,
        fs:  `cpe:2.3:a:netartmedia:real_estate_portal:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.12`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.13`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.14`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.17`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd376a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.18`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.50:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.19`,
        fs:  `cpe:2.3:a:altiris:application_management_solution_documentation:6.1.4085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.20`,
        fs:  `cpe:2.3:a:webyog:sqlyog:2.5:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.21`,
        fs:  `cpe:2.3:h:cabletron:6h302-48:5.05.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.22`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.23`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.24`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.25`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.26`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2011.728.1723.29300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.27`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.28`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.29`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.30`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.31`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.32`,
        fs:  `cpe:2.3:h:lexmark:xc8155dte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.33`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.34`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.35`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.36`,
        fs:  `cpe:2.3:a:rack_project:rack:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.37`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.38`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20141014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.39`,
        fs:  `cpe:2.3:a:cnectd:cnectd:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.40`,
        fs:  `cpe:2.3:a:redhat:cloudforms:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.41`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.42`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.43`,
        fs:  `cpe:2.3:a:swipe_checkout_for_eshop_project:swipe_checkout_for_eshop:3.7.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.517.44`,
        fs:  `cpe:2.3:o:cisco:rv110w_wireless-n_vpn_firewall_firmware:1.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.518.0`,
        fs:  `cpe:2.3:a:hp:intelligent_provisioning:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.519.0`,
        fs:  `cpe:2.3:a:imagecms:imagecms:4.0.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.520.0`,
        fs:  `cpe:2.3:a:naver:nhn_japan_naver_line:3.3.7:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.521.0`,
        fs:  `cpe:2.3:a:sun:java_system_directory_proxy_server:5.2:2003q4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.522.0`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.524.0`,
        fs:  `cpe:2.3:a:nuance:pdf_reader:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.525.0`,
        fs:  `cpe:2.3:a:perl:perl:5.12.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.526.0`,
        fs:  `cpe:2.3:a:kryo:iodine:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.528.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.529.0`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.529.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1301.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.529.2`,
        fs:  `cpe:2.3:h:hp:jf239a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.530.0`,
        fs:  `cpe:2.3:a:keepass:keepass:0.95:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.531.0`,
        fs:  `cpe:2.3:a:marc_vertes:txt2man:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.531.1`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.531.2`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.13.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.535.1`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.535.2`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2_cvs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.536.0`,
        fs:  `cpe:2.3:a:mono:mono:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.536.1`,
        fs:  `cpe:2.3:a:altnet:altnet_download_manager:4.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.536.2`,
        fs:  `cpe:2.3:h:marconi:asx-1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.536.3`,
        fs:  `cpe:2.3:h:huawei:atn:v200r001c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.536.4`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.537.0`,
        fs:  `cpe:2.3:a:hp:openmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.538.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:pre.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.539.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.540.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.541.0`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.542.0`,
        fs:  `cpe:2.3:a:airdroid:airdroid:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.544.0`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.3:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.547.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.547.1`,
        fs:  `cpe:2.3:a:esri:arcmap:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:7.0.548.0`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.549.0`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.550.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.318.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.551.0`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.551.1`,
        fs:  `cpe:2.3:a:supmua:sup:0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.0`,
        fs:  `cpe:2.3:a:dracut_project:dracut:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.1`,
        fs:  `cpe:2.3:h:apple:imac:mc508xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.2`,
        fs:  `cpe:2.3:a:amd:catalyst_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xne:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.6`,
        fs:  `cpe:2.3:a:schneider-electric:modbus_serial_driver:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.7`,
        fs:  `cpe:2.3:a:sun:libattach:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.8`,
        fs:  `cpe:2.3:a:google:chrome:54.0.2840.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.9`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.10`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.11`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.36:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.12`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.13`,
        fs:  `cpe:2.3:a:osticket:osticket:1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.14`,
        fs:  `cpe:2.3:a:rom_walton:boinc:6.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.15`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.16`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.17`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.18`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.19`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.20`,
        fs:  `cpe:2.3:a:e107:e107:0.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.21`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.23`,
        fs:  `cpe:2.3:a:microsoft:word:98:sr1:mac_os:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.24`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.25`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.13570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.26`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.27`,
        fs:  `cpe:2.3:a:instantasp:instantforum:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.28`,
        fs:  `cpe:2.3:o:hp:mpe_ix:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.29`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1\(.1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.35`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.40`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.41`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.42`,
        fs:  `cpe:2.3:a:hp:select_access:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.43`,
        fs:  `cpe:2.3:h:h3c:sr88_firewall_processing_module:0231a88l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.44`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.45`,
        fs:  `cpe:2.3:a:vinay_sajip:python-gnupg:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.47`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.48`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.49`,
        fs:  `cpe:2.3:a:ca:etrust_access_control:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.50`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.51`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.52`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.100`,
        fs:  `cpe:2.3:a:solarwinds:information_service:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.101`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.102`,
        fs:  `cpe:2.3:a:curtis_galloway:libexif:0.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.103`,
        fs:  `cpe:2.3:a:bea:jrockit_jdk:r28.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.104`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.46:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.105`,
        fs:  `cpe:2.3:a:php:pear:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.200`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ebk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.201`,
        fs:  `cpe:2.3:a:xnview:xnview:1.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.202`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.203`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.204`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.205`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.206`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.207`,
        fs:  `cpe:2.3:a:trendmicro:common_cgi:2.0.0.1227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.208`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.209`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.210`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.211`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.212`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.213`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:7.1:mr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.214`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.1\(3\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.215`,
        fs:  `cpe:2.3:o:netgear:prosafe_firmware:5.4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.216`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.217`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.218`,
        fs:  `cpe:2.3:o:raritan:px:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.219`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.220`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.221`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.222`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.223`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.224`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.225`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.226`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.4.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.227`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.20.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.228`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.229`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.230`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.231`,
        fs:  `cpe:2.3:a:koha:koha:3.14.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.232`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.233`,
        fs:  `cpe:2.3:a:adobe:flash_player:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.234`,
        fs:  `cpe:2.3:a:apple:itunes:4.2.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.235`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.237`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.300`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.301`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.302`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.303`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.304`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.305`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.306`,
        fs:  `cpe:2.3:h:schneider-electric:tburjr900:06002eh0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.307`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp3:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.308`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.309`,
        fs:  `cpe:2.3:a:mclewin:wishlist:7.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.310`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)ew5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.311`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.312`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.313`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-8p-ei_ls-5100-8p-ei-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.315`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.316`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.317`,
        fs:  `cpe:2.3:h:xerox:workcentre:238:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.318`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.319`,
        fs:  `cpe:2.3:a:atlassian:jira:3.1.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.320`,
        fs:  `cpe:2.3:a:git-scm:git:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.321`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:6.4.1:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.322`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.323`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.324`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.325`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.5.4912.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.326`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.327`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.328`,
        fs:  `cpe:2.3:a:openafs:openafs:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.329`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.330`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.331`,
        fs:  `cpe:2.3:a:php:php:5.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.332`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.333`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:sp2_alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.334`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.335`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.336`,
        fs:  `cpe:2.3:a:adobe:type_support:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.337`,
        fs:  `cpe:2.3:a:microsoft:powerpoint_viewer:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.338`,
        fs:  `cpe:2.3:a:ibm:sametime:8.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.339`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.340`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.341`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.342`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.343`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1_pk4_bl18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.552.344`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.32.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.553.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.411:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.554.0`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.555.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.556.0`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.2.2.835:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.557.0`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.41.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.558.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.296:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.559.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.560.0`,
        fs:  `cpe:2.3:a:hp:storeonce_virtual_storage_appliance:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:8.0.561.0`,
        fs:  `cpe:2.3:a:isc:bind:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.562.0`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.563.0`,
        fs:  `cpe:2.3:a:alfresco:alfresco:4.2.f:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.564.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.565.0`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.566.0`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.567.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.568.0`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.569.0`,
        fs:  `cpe:2.3:a:foliovision:foliopress_wysiwyg:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.570.0`,
        fs:  `cpe:2.3:a:apache:ofbiz:11.04.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.570.1`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.571.0`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.572.0`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.572.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.653.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.573.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.574.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.575.0`,
        fs:  `cpe:2.3:a:openbsd:openbsd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.576.0`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:19.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.577.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.578.0`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.579.0`,
        fs:  `cpe:2.3:a:emc:networker:7.6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.580.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.581.0`,
        fs:  `cpe:2.3:a:apache:struts:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.582.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/e:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.583.0`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.584.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.585.0`,
        fs:  `cpe:2.3:a:pacificmags:better_homes_and_gardens_aus:\@7f0801b2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.586.0`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.587.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.587.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.588.0`,
        fs:  `cpe:2.3:a:paul_lesniewsk:autocomplete:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.589.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.590.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.3.90a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.591.0`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.592.0`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.593.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.594.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.595.0`,
        fs:  `cpe:2.3:a:vmware:workstation:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.596.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.0`,
        fs:  `cpe:2.3:a:rsa:securid_web_agent:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.1`,
        fs:  `cpe:2.3:a:ca:unicenter_application_performance_monitor:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.2`,
        fs:  `cpe:2.3:o:cisco:catos:5.4\(1\)deferred:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.4`,
        fs:  `cpe:2.3:h:cisco:ons_15302_multiservice_customer_access_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.5`,
        fs:  `cpe:2.3:h:d-link:dcs-942l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.7`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.2.1.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.8`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.9`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.10`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.11`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.12`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.14`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.15`,
        fs:  `cpe:2.3:a:buffalotech:wer-am54g54_firmware:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.16`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.02b25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.17`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.18`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.19`,
        fs:  `cpe:2.3:a:adobe:pdf_creation_add-on:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.20`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.21`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.22`,
        fs:  `cpe:2.3:a:drupal:drupal:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.23`,
        fs:  `cpe:2.3:a:google:v8:3.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.24`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.25`,
        fs:  `cpe:2.3:a:ubuntu_developers:language-selector:0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.26`,
        fs:  `cpe:2.3:a:intelliants:elitius:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.27`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.28`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.99.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.29`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.30`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.100.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.31`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.32`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.33`,
        fs:  `cpe:2.3:a:php:php:5.5.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.34`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.35`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.36`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.37`,
        fs:  `cpe:2.3:a:canonical:libpam-modules:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.38`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.39`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.40`,
        fs:  `cpe:2.3:a:rwcinc:free_realty:3.1-0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.41`,
        fs:  `cpe:2.3:h:enterasys:vertical_horizon-2402s:2.05.09.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.42`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.44`,
        fs:  `cpe:2.3:a:h2o_human_harmony_organization_project:h2o_human_harmony_organization:1.6.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.45`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.46`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.47`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.54`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(23.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.55`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.56`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1659.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.57`,
        fs:  `cpe:2.3:a:arbornetworks:peakflow_sp:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.58`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.59`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.60`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.62`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.63`,
        fs:  `cpe:2.3:a:netfilter:ipset:6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.64`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.65`,
        fs:  `cpe:2.3:a:cisco:unity_connection:11.0_0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.66`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.67`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.68`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.69`,
        fs:  `cpe:2.3:a:bea:aqualogic_enterprise_security:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.70`,
        fs:  `cpe:2.3:h:apple:imac:m9248xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.71`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.72`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.73`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:6.2.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.74`,
        fs:  `cpe:2.3:a:apple:java_1.6:0:07:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.75`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.8.817:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.76`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ebt:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.77`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.78`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.79`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.80`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.81`,
        fs:  `cpe:2.3:a:ibm:license_metric_tool:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.82`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.83`,
        fs:  `cpe:2.3:a:hp:openview_omniback_ii:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.84`,
        fs:  `cpe:2.3:a:cisco:icdn:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.85`,
        fs:  `cpe:2.3:a:php:php:7.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.86`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.88`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.2:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.90`,
        fs:  `cpe:2.3:a:inclind:custom_pub:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.92`,
        fs:  `cpe:2.3:a:organizer_project:organizer:0.4b:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.94`,
        fs:  `cpe:2.3:h:huawei:s8500:r1631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.96`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.19.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.97`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.2.3730.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.98`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.99`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.100`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.03.4151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.101`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:4.0.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.102`,
        fs:  `cpe:2.3:a:magzter:just_bureaucracy:3.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.106`,
        fs:  `cpe:2.3:a:topazsystems:sigplus_pro_activex_control:3.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.597.107`,
        fs:  `cpe:2.3:a:apache:struts:2.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.598.0`,
        fs:  `cpe:2.3:a:schneider_electric:indusoft_web_studio:7.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.599.0`,
        fs:  `cpe:2.3:a:qemu:qemu:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:9.0.600.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.22.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.601.0`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.602.0`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.603.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.30.367:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.603.2`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.603.3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.604.0`,
        fs:  `cpe:2.3:a:janetter:janetter:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.605.0`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.606.0`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-2.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.607.0`,
        fs:  `cpe:2.3:a:emc:documentum_web_publisher:6.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.608.0`,
        fs:  `cpe:2.3:a:suse:kiwi:4.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.609.0`,
        fs:  `cpe:2.3:a:mozilla:camino:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.610.0`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.611.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.611.1`,
        fs:  `cpe:2.3:a:apache:poi:3.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.612.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.3:1004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.612.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.612.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.612.3`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.613.0`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.614.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.615.0`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.616.0`,
        fs:  `cpe:2.3:o:cisco:dx_series_ip_phones_firmware:9.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.617.0`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.618.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:gold:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.619.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.325.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.620.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)xc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.621.0`,
        fs:  `cpe:2.3:a:adobe:stock_photos_cs2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.622.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.622.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.623.0`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.624.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.625.0`,
        fs:  `cpe:2.3:a:x3cms:x3_cms:0.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.626.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.627.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.628.0`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.629.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.630.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.631.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.632.0`,
        fs:  `cpe:2.3:a:skype:skype:3.5.0.107:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.633.0`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:7.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.634.0`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.634.1`,
        fs:  `cpe:2.3:a:sightlinesystems:expert_advisor\/vision:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.635.0`,
        fs:  `cpe:2.3:a:kana:iq:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.636.0`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.638.0`,
        fs:  `cpe:2.3:a:vmware:workstation:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.638.1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.639.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.640.0`,
        fs:  `cpe:2.3:a:roxio:cineplayer:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.642.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(4m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.642.1`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.642.2`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.643.0`,
        fs:  `cpe:2.3:a:apple:applescript:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.644.0`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.645.0`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.646.0`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.647.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.0`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.5.1:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.1`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.2`,
        fs:  `cpe:2.3:a:hp:openview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.3`,
        fs:  `cpe:2.3:h:novatech:orion5r_dnp_slave:1.23.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.4`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.5`,
        fs:  `cpe:2.3:a:mostgear:easy_lan_folder_share:3.2.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.6`,
        fs:  `cpe:2.3:h:nortel:cvx_1800_multi-service_access_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.7`,
        fs:  `cpe:2.3:a:teradata:gsctools:9.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.8`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.8b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.9`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2.6:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.10`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.11`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.12`,
        fs:  `cpe:2.3:a:apple:quicktime:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.13`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.18`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.23`,
        fs:  `cpe:2.3:o:openvas:greenbone_security_assistant:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.26`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.28`,
        fs:  `cpe:2.3:a:qemu:qemu:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.32`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.35`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.38`,
        fs:  `cpe:2.3:a:apache:axis:1.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.42`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.45`,
        fs:  `cpe:2.3:a:altiris:diagnostics:6.1.7325.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.49`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.54`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.56`,
        fs:  `cpe:2.3:a:cisco:finesse:10.0\(1\)_su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.59`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.62`,
        fs:  `cpe:2.3:o:d-link:dsr-250_firmware:1.05b20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.66`,
        fs:  `cpe:2.3:a:goforandroid:go_email_widget:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.68`,
        fs:  `cpe:2.3:a:python-requests:requests:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.70`,
        fs:  `cpe:2.3:a:redhat:freeipa:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.72`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.76`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.79`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd007a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.82`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp3:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.84`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.87`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.90`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:0.99.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.101`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.103`,
        fs:  `cpe:2.3:a:hp:imc_branch_intelligent_management_system_software_module:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.105`,
        fs:  `cpe:2.3:a:mysql:mysql:3.22.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.107`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.114`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.116`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.118`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.119`,
        fs:  `cpe:2.3:a:k-litecodec:k-lite_codec:10.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.120`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.121`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.1-8:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.122`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.123`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.124`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.125`,
        fs:  `cpe:2.3:a:piwik:piwik:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.126`,
        fs:  `cpe:2.3:a:debian:apt:0.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.127`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.128`,
        fs:  `cpe:2.3:a:oracle:sysfw:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.129`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.130`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp1:adv_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.131`,
        fs:  `cpe:2.3:a:ca:unicenter_network_and_systems_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.132`,
        fs:  `cpe:2.3:a:hogs_fly_crazy_project:hogs_fly_crazy:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.133`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.134`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.135`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.151`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.201`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3a.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.203`,
        fs:  `cpe:2.3:h:cisco:sf302-08:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.204`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.648.205`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.649.0`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:15.00.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.650.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.0:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:10.0.651.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.652.0`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.0.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.653.0`,
        fs:  `cpe:2.3:a:oneorzero:action_and_information_management_system:2.8.0:build231211:trial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.654.0`,
        fs:  `cpe:2.3:a:apple:itunes:12.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.655.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.344:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.656.0`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.657.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.658.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.658.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.659.0`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-2.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.660.0`,
        fs:  `cpe:2.3:a:cutesite:cutesite_cms:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.661.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.662.0`,
        fs:  `cpe:2.3:a:microsoft:system.text.encodings.web:4.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.663.0`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.664.1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.665.0`,
        fs:  `cpe:2.3:a:samba:samba:3.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.666.0`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:3.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.667.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.667.2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.667.3`,
        fs:  `cpe:2.3:h:cisco:1941_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.667.4`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.668.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.669.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.509.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.670.0`,
        fs:  `cpe:2.3:a:binarymoon:timthumb:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.671.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.672.0`,
        fs:  `cpe:2.3:a:mol:mol_bringapont:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.672.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.0\(46\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.672.2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.673.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.674.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg304a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.675.0`,
        fs:  `cpe:2.3:a:debian:apt:0.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.676.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.677.0`,
        fs:  `cpe:2.3:a:perl:perl:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.678.0`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.679.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.680.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.681.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.682.0`,
        fs:  `cpe:2.3:a:paul_perkins:tail_for_win32:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.683.0`,
        fs:  `cpe:2.3:a:ibm:qradar_vulnerability_manager:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.684.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_vx_clinical_assistant:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.685.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.686.0`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:540:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.686.1`,
        fs:  `cpe:2.3:a:google:v8:3.24.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.686.2`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.686.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)ew:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.687.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.687.1`,
        fs:  `cpe:2.3:a:plone:plone:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.688.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.689.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.690.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.25:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.690.1`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.691.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.692.0`,
        fs:  `cpe:2.3:a:levelfourdevelopment:wp-easycart:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.693.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.694.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.18:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.695.0`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.0`,
        fs:  `cpe:2.3:a:belkin:wireless_usb_utility:6.3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.2`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.3`,
        fs:  `cpe:2.3:a:apache:tomcat:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.4`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.7`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.1.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.8`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.9`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.10`,
        fs:  `cpe:2.3:a:hp:mercury_quality_center:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.11`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.20:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.12`,
        fs:  `cpe:2.3:a:roxio:vd64inst:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.13`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.14`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_mse_series_software:4.3\(1.68\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.15`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.16`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.17`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.18`,
        fs:  `cpe:2.3:a:opnet:model_library:16.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.19`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.20`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.21`,
        fs:  `cpe:2.3:a:otrs:faq:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.22`,
        fs:  `cpe:2.3:a:drupal:drupal:7.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.23`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.24`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.25`,
        fs:  `cpe:2.3:a:google:v8:3.23.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.26`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.27`,
        fs:  `cpe:2.3:a:netscape:navigator:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.28`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.29`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.30`,
        fs:  `cpe:2.3:a:wildpackets:omnipeek:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.31`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.32`,
        fs:  `cpe:2.3:a:apple:cups:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.33`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.34`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.35`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p205:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.36`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.37`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.38`,
        fs:  `cpe:2.3:a:john_nunemaker:crack:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.39`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.40`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.41`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.42`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.43`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.44`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.45`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.46`,
        fs:  `cpe:2.3:a:evan_dandrea:usb-creator:0.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.47`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.48`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.49`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.50`,
        fs:  `cpe:2.3:a:siemens:spcanywhere:1.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.51`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2008.717.2343.40629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.52`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.53`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.54`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.4.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.55`,
        fs:  `cpe:2.3:a:corosync:corosync:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.56`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.57`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc118xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.58`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.59`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.60`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.61`,
        fs:  `cpe:2.3:h:siemens:simatic_s7_1200_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.62`,
        fs:  `cpe:2.3:a:corosync:corosync:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.63`,
        fs:  `cpe:2.3:a:pcre:pcre:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.64`,
        fs:  `cpe:2.3:a:apache:hadoop:0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.65`,
        fs:  `cpe:2.3:a:apc:powerchute:9.0.1.606:*:*:*:business:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.66`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.65:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.67`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.68`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.69`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.70`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-01-\/l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.71`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.72`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.696.77`,
        fs:  `cpe:2.3:a:emc:documentum_foundation_services:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.697.0`,
        fs:  `cpe:2.3:a:mach5:mach5_analyzer:mach5_analyzer_4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.698.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s12518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:11.0.699.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.700.0`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.701.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.702.0`,
        fs:  `cpe:2.3:a:mcafee:antispyware:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.702.1`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.470:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.702.2`,
        fs:  `cpe:2.3:a:cyrus:imap:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.703.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.704.0`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.705.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.706.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.707.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.708.0`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.709.0`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.710.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.711.0`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_plant_applications:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.712.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.713.0`,
        fs:  `cpe:2.3:a:apache:libcloud:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.714.0`,
        fs:  `cpe:2.3:o:maygion:ip_camera_firmware:05.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.715.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.716.0`,
        fs:  `cpe:2.3:a:orientdb:orientdb:2.0.14:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.717.0`,
        fs:  `cpe:2.3:h:hp:2300dn_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.718.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.719.0`,
        fs:  `cpe:2.3:a:lazyer:doodle_drop:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.719.1`,
        fs:  `cpe:2.3:a:microsoft:urlscan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.720.0`,
        fs:  `cpe:2.3:h:lexmark:c4150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.721.0`,
        fs:  `cpe:2.3:a:x:libxvmc:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.721.1`,
        fs:  `cpe:2.3:a:cryptopp:crypto\&#43;\&#43;:5.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.722.0`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.723.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.723.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.724.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ya:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.725.0`,
        fs:  `cpe:2.3:a:emc:networker:7.6:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.726.0`,
        fs:  `cpe:2.3:a:jig:movatwitouch_paid:1.793:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.727.0`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.728.0`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.729.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.05.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.730.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.16:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.731.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.732.0`,
        fs:  `cpe:2.3:h:xerox:copycentre_c65:1.001.02.073:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.733.0`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.734.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15.2:beta:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.735.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.736.0`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution_assurance:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.737.0`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.738.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.739.0`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.740.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.741.0`,
        fs:  `cpe:2.3:a:spip:spip:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.0`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.2`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.1:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.3`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.4`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.2.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.5`,
        fs:  `cpe:2.3:a:xnview:xnview:1.93.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.8`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.9`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.10`,
        fs:  `cpe:2.3:a:perl:perl:5.23.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.11`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.12`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.5_build_1100_mp1:mr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.13`,
        fs:  `cpe:2.3:a:roxio:creator_data:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.14`,
        fs:  `cpe:2.3:h:axis:250s_video_server:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.15`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.16`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.17`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:gold:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.18`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd317a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.19`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.20`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.21`,
        fs:  `cpe:2.3:h:hp:jg403a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.22`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.30`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.41`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.4.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.42`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.013:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.43`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.44`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.45`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.46`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.47`,
        fs:  `cpe:2.3:a:megalab:the_uploader:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.48`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.49`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.50`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.51`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.52`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.53`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.54`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.55`,
        fs:  `cpe:2.3:a:oracle:opmn_daemon:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.56`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.57`,
        fs:  `cpe:2.3:a:sharethis:sharethis:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.58`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d43.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.59`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.60`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.61`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.63`,
        fs:  `cpe:2.3:a:google:chrome:5.0.328.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.64`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.65`,
        fs:  `cpe:2.3:a:ibm:java:5.0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.66`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.67`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.68`,
        fs:  `cpe:2.3:a:wikidforum:wikidforum:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.69`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.70`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0.2359:unknown:online_windows_server_2003_x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.71`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.72`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.73`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.74`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.36.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.75`,
        fs:  `cpe:2.3:a:rhq-project:rhq:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.77`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:173:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.82`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.10:ga3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.91`,
        fs:  `cpe:2.3:o:sun:sunos:5.11:-:*:*:*:*:amd64:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.92`,
        fs:  `cpe:2.3:a:just-great-software:editpad:v.5.4.6:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.93`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.94`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.100`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:255:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.105`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.111`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.112`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:13.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.113`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.114`,
        fs:  `cpe:2.3:a:docker:docker:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.115`,
        fs:  `cpe:2.3:a:adobe:framemaker:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.120`,
        fs:  `cpe:2.3:a:symantec:network_access_control:11.0.7100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.121`,
        fs:  `cpe:2.3:a:digium:asterisk:12.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.122`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_6961:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.123`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1031.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.742.124`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20\)w5\(22b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.743.0`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.744.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.745.0`,
        fs:  `cpe:2.3:a:winscp:winscp:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.746.0`,
        fs:  `cpe:2.3:a:att:communication_manager:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:12.0.747.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.748.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.749.0`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:02-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.750.0`,
        fs:  `cpe:2.3:h:hp:integrated_lights-out:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.751.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.752.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.753.0`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d80:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.754.0`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:2.05\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.755.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.756.0`,
        fs:  `cpe:2.3:a:hp:openview_configuration_management:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.757.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.758.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.759.0`,
        fs:  `cpe:2.3:a:apple:cups:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.760.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.761.0`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.761.1`,
        fs:  `cpe:2.3:h:cabletron:micro_mmac:1.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.762.0`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.762.1`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.763.0`,
        fs:  `cpe:2.3:a:perl:perl:5.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.764.0`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.765.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.766.0`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.767.0`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.767.1`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.768.0`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.769.0`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.770.0`,
        fs:  `cpe:2.3:a:adobe:community_help:3.0.0.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.771.0`,
        fs:  `cpe:2.3:a:apache:cloudstack:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.772.0`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.773.0`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.774.0`,
        fs:  `cpe:2.3:a:withhive:tiny_farm:2.02.00:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.775.0`,
        fs:  `cpe:2.3:a:hp:ibrix:6.1.196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.775.1`,
        fs:  `cpe:2.3:a:sap:enterprise_central_component:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.775.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.20:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.775.4`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.776.0`,
        fs:  `cpe:2.3:a:meta_tags_quick_project:meta_tags_quick:7.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.776.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.374:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.777.0`,
        fs:  `cpe:2.3:a:avscripts:av_arcade:2.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.777.1`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.777.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.777.3`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.777.4`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.777.5`,
        fs:  `cpe:2.3:o:hp:laserjet_pro_m1213nf_mfp_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.777.6`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.778.0`,
        fs:  `cpe:2.3:a:zemanta:search_everything:8.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.779.0`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:2.50.2726:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.780.0`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.3.4:rev40279:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.781.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.192:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.0`,
        fs:  `cpe:2.3:a:grape_project:grape:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.6`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.7`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.10`,
        fs:  `cpe:2.3:a:novell:zenworks_asset_management:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.11`,
        fs:  `cpe:2.3:a:apple:itunes:4.8.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.12`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp5225:ce711a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.13`,
        fs:  `cpe:2.3:h:hp:jd432a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.14`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:hu:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.15`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.16`,
        fs:  `cpe:2.3:o:cisco:mds_9000_san-os:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.17`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.18`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.19`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.20`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.21`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.23`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.24`,
        fs:  `cpe:2.3:a:indus-systems:idrawings_setup:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.25`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.26`,
        fs:  `cpe:2.3:a:vmware:vcenter_operations:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.27`,
        fs:  `cpe:2.3:o:honeywell:excel_web_xl_1000c100u_104_i\/o_uukl:2.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.28`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.29`,
        fs:  `cpe:2.3:a:redhat:openshift_origin:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.30`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.31`,
        fs:  `cpe:2.3:a:cminds:enhanced-tooltipglossary:3.2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.32`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.33`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.34`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.35`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.36`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7\)da3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.37`,
        fs:  `cpe:2.3:a:google:chrome:16.0.911.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.38`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.39`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.40`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.41`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.3.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.42`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.43`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.44`,
        fs:  `cpe:2.3:a:clip-bucket:clipbucket:2.7:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.45`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.46`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.47`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.48`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.49`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.50`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.51`,
        fs:  `cpe:2.3:a:aol:internet_software:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.52`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.53`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.55`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:60.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.56`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.81`,
        fs:  `cpe:2.3:a:apache:subversion:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.82`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.83`,
        fs:  `cpe:2.3:a:serv-u:serv-u:5.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.84`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.85`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.86`,
        fs:  `cpe:2.3:a:hp:toolbox:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.87`,
        fs:  `cpe:2.3:h:enterasys:x-pedition:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.88`,
        fs:  `cpe:2.3:a:intelitycorp:four_seasons_beverly_hills:\@7f050007:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.89`,
        fs:  `cpe:2.3:a:google:talk_plugin:2.5.8.4958:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.90`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.91`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.92`,
        fs:  `cpe:2.3:o:bluecoat:avos:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.93`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.94`,
        fs:  `cpe:2.3:a:roxio:creator:10.1:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.95`,
        fs:  `cpe:2.3:a:macromedia:dreamweaver:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.96`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.97`,
        fs:  `cpe:2.3:a:pip-installer:pip:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.98`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.99`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.100`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.101`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.102`,
        fs:  `cpe:2.3:h:schneider-electric:bmxnor0200h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.103`,
        fs:  `cpe:2.3:a:x:libx11:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.104`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2007:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.105`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.106`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.107`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.108`,
        fs:  `cpe:2.3:h:cisco:nexus_93108tc-ex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.109`,
        fs:  `cpe:2.3:h:hospira:lifecare_pcainfusion_pump:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.112`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.210`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.211`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.212`,
        fs:  `cpe:2.3:a:mandrakesoft:mandrake_lam-runtime:7.0.6.2mdk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.213`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.57:rc01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.214`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.215`,
        fs:  `cpe:2.3:o:xen:xen:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.216`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.217`,
        fs:  `cpe:2.3:a:typo3:neos:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.218`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.0:rc2a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.219`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.1.528992:*:*:*:linux:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.220`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.237`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:13.0.782.238`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.783.0`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.784.0`,
        fs:  `cpe:2.3:a:endonesia:endonesia:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.785.0`,
        fs:  `cpe:2.3:a:websvn:websvn:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.786.0`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.2.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.787.0`,
        fs:  `cpe:2.3:a:gnu:ksymoops:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.788.0`,
        fs:  `cpe:2.3:a:vmware:player:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.789.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.790.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.791.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1284.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.792.0`,
        fs:  `cpe:2.3:a:microsoft:outlook.com:7.8.2.10.47.7365:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.793.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.tc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.794.0`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.30.020.1871:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.795.0`,
        fs:  `cpe:2.3:a:fusetalk.:fusetalk:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.796.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.797.0`,
        fs:  `cpe:2.3:a:ontariosystems:artiva_workstation:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.798.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.799.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.800.0`,
        fs:  `cpe:2.3:h:hp:jd661a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.801.0`,
        fs:  `cpe:2.3:a:mautic:mautic:1.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.802.0`,
        fs:  `cpe:2.3:a:barracuda:web_filter:8.0.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.803.0`,
        fs:  `cpe:2.3:a:php:php:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.804.0`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.805.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.0.2.12610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.806.0`,
        fs:  `cpe:2.3:a:candlepinproject:candlepin:0.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.807.0`,
        fs:  `cpe:2.3:a:ibm:rational_appscan_source:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.808.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.809.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.810.0`,
        fs:  `cpe:2.3:a:otrs:faq:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.811.0`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7961g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.812.0`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.813.0`,
        fs:  `cpe:2.3:a:apple:webkit:413:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.814.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.815.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.816.0`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.3663.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.818.0`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.819.0`,
        fs:  `cpe:2.3:a:eaton:proview:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.820.0`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.821.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.822.0`,
        fs:  `cpe:2.3:h:hp:0235a20n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.823.0`,
        fs:  `cpe:2.3:a:php:php:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.824.0`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.825.0`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.826.0`,
        fs:  `cpe:2.3:a:spip:spip:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.827.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.827.10`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.827.12`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.829.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.830.0`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.831.0`,
        fs:  `cpe:2.3:a:altiris:deployment_agent:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.832.0`,
        fs:  `cpe:2.3:a:phorum:phorum:3.3.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.833.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.834.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_24:*:solaris:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.1`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.2`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.8`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.9`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3xo.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.13`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.12:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.14`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(2a\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.15`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.16`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.18`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.8_pre2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.20`,
        fs:  `cpe:2.3:o:cisco:sn_5428_storage_router:2-3.3.1-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.21`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.22`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.23`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.1.5\(104\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.24`,
        fs:  `cpe:2.3:a:cisco:unity_connection:11.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.25`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.26`,
        fs:  `cpe:2.3:h:3com:3c16950-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.27`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.28`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.29`,
        fs:  `cpe:2.3:a:cisco:trust_agent:2.1.103.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.30`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.31`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.32`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.33`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.34`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:2013.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.35`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.86`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.87`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.88`,
        fs:  `cpe:2.3:a:symantec:encryption_desktop:10.3.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.89`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:5.3.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.90`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.13:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.91`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.92`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ye:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.93`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.94`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.11.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.95`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.96`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.97`,
        fs:  `cpe:2.3:a:hp:loadrunner:11.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.98`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7.5e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.99`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.100`,
        fs:  `cpe:2.3:a:nortel:symposium_web_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.101`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.102`,
        fs:  `cpe:2.3:a:apple:cups:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.103`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.104`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.105`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.106`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.107`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.108`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.109`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.03:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.110`,
        fs:  `cpe:2.3:a:apache:poi:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.111`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.112`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.113`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.114`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.115`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.116`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.117`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.118`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gw_3241:2.1\(1.56\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.119`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.120`,
        fs:  `cpe:2.3:a:pondol-carousel_project:pondol-carousel:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.121`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.32.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.122`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.123`,
        fs:  `cpe:2.3:o:novell:opensuse:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.124`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.125`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.126`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.127`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:cbz:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.128`,
        fs:  `cpe:2.3:a:foxitsoftware:enterprise_reader:7.0.6.1126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.149`,
        fs:  `cpe:2.3:a:oracle:database_server:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.150`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.151`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.152`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.6:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.153`,
        fs:  `cpe:2.3:a:hp:deskjet_single_function_software_req:90.0.200.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.154`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:0.0.4:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.155`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.156`,
        fs:  `cpe:2.3:a:emc:networker:7.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.157`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.158`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p343:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.159`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.160`,
        fs:  `cpe:2.3:h:sharp:aquos_hn-pp150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.161`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.162`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.163`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.184`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.186`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.187`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.202`,
        fs:  `cpe:2.3:a:frontrange:heat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.203`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.835.204`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.836.0`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.837.0`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.0:alpha:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.838.0`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:14.0.839.0`,
        fs:  `cpe:2.3:a:adobe:creative_suite_5_design_standard:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.859.0`,
        fs:  `cpe:2.3:a:symantec:veritas_gridnode_agent:5.0.286:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.860.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.861.0`,
        fs:  `cpe:2.3:o:buffalotech:airstation_extreme_n600_firmware:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.862.0`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.862.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.863.0`,
        fs:  `cpe:2.3:a:xangati:xangati_xnr:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.864.0`,
        fs:  `cpe:2.3:a:microsoft:outlook_rt:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.865.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.866.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.867.0`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.868.0`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.868.1`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0567:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.869.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.870.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.871.0`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-182_with_network_printer_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.871.1`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.872.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.873.0`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.1`,
        fs:  `cpe:2.3:a:cisco:resource_manager_essentials:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.3`,
        fs:  `cpe:2.3:a:cairographics:cairo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.4`,
        fs:  `cpe:2.3:o:huawei:5310ei_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.5`,
        fs:  `cpe:2.3:o:huawei:honor_6_firmware:h60-l03c01b850:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.6`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.7`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.8`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.9`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.10`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.11`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.12`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.13`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:4.6.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.14`,
        fs:  `cpe:2.3:a:avaya:argent_office:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.15`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.16`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.17`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.18`,
        fs:  `cpe:2.3:a:elxis:elxis_cms:2006.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.19`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.20`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)sy3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.21`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.22`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.23`,
        fs:  `cpe:2.3:a:keepass:keepass:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.24`,
        fs:  `cpe:2.3:a:adobe:dreamweaver_mx:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.44`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:5.0.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.45`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.46`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:6.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.47`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.48`,
        fs:  `cpe:2.3:a:hp:storageworks_united_linux_1.0_\/_sles8_host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.49`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.101`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp7:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.102`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.36.386:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.103`,
        fs:  `cpe:2.3:o:sun:sunos:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.104`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.106`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.116`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.117`,
        fs:  `cpe:2.3:a:cisco:resource_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.119`,
        fs:  `cpe:2.3:a:google:chrome:13.0.777.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.120`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:15.0.874.121`,
        fs:  `cpe:2.3:h:d-link:dir-905l:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.877.0`,
        fs:  `cpe:2.3:a:tumbleweed:server_validator_suite:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.878.0`,
        fs:  `cpe:2.3:o:moxa:miineport_e2_1242_firmware:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.879.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:7.0.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.880.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s12508:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.881.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.882.0`,
        fs:  `cpe:2.3:h:iss:proventia_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.883.0`,
        fs:  `cpe:2.3:h:rockwellautomation:1768_compactlogix_l4x_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.884.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.885.0`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.886.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.365:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.886.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.887.0`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:sp4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.888.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.889.0`,
        fs:  `cpe:2.3:h:symantec:gateway_security_360:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.889.2`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.889.3`,
        fs:  `cpe:2.3:a:april\&#39;s_super_functions_pack_project:april\&#39;s_super_functions_pack:1.4.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.890.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.11.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.890.1`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.891.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.891.1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.892.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.893.0`,
        fs:  `cpe:2.3:a:ixiacom:ixloadlite:3.30.66.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.893.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.688.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.894.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.895.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.896.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.897.0`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.898.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.899.0`,
        fs:  `cpe:2.3:a:brocade:vyatta_vrouter_software:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.900.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.901.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.902.0`,
        fs:  `cpe:2.3:a:sun:java_system_identity_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.903.0`,
        fs:  `cpe:2.3:a:rack_project:rack:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.904.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.905.0`,
        fs:  `cpe:2.3:a:cisco:network_recording_player:2.3.1109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.906.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.5:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.906.1`,
        fs:  `cpe:2.3:a:dell:controlvault_host_components_installer:2.1.2.187:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.907.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.18.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.908.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.909.0`,
        fs:  `cpe:2.3:a:wdc:software_upgrader:1.4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.910.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.911.0`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.911.1`,
        fs:  `cpe:2.3:a:wp-dbmanager_project:wp-dbmanager:2.71:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.911.2`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.0`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-06:-:standard:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.1`,
        fs:  `cpe:2.3:a:menalto:gallery:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.2`,
        fs:  `cpe:2.3:a:lxml:lxml:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.3`,
        fs:  `cpe:2.3:a:ibm:rational_directory_server:5.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.4`,
        fs:  `cpe:2.3:a:adobe:media_encoder_cs4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.6`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.7`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.22:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.8`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.9`,
        fs:  `cpe:2.3:a:sap:hybris:5.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.11`,
        fs:  `cpe:2.3:a:tincan:phplist:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.12`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.13`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.2.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.14`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.15`,
        fs:  `cpe:2.3:a:gnu:automake:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.19`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.20`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.21`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-452:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.22`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.23`,
        fs:  `cpe:2.3:a:citrix:receiver_dv:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.24`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.25`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.26`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.27`,
        fs:  `cpe:2.3:a:itriagehealth:itriage_health:5.29:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.28`,
        fs:  `cpe:2.3:a:hummingbird:exceed:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.29`,
        fs:  `cpe:2.3:a:acrosoftware:cutepdf:3.4.1.3:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.30`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(1i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.31`,
        fs:  `cpe:2.3:a:apple:itunes:4.1.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.32`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.33`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.34`,
        fs:  `cpe:2.3:a:ca:systems_performance_liteagent:11.2.9273:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.35`,
        fs:  `cpe:2.3:a:debian:adequate:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.36`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.37`,
        fs:  `cpe:2.3:a:dell:all_day_battery_life_configuration:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.38`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.39`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.40`,
        fs:  `cpe:2.3:a:juniper:networks_mobility_system_software:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.41`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.42`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:7.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.43`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.62`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.63`,
        fs:  `cpe:2.3:a:symantec:velociraptor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.66`,
        fs:  `cpe:2.3:a:paymentsplus:payments_plus:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.74`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.75`,
        fs:  `cpe:2.3:a:indusoft:web_studio:7.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.76`,
        fs:  `cpe:2.3:a:agilebits:1password:-:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:16.0.912.77`,
        fs:  `cpe:2.3:a:haxx:curl:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.921.3`,
        fs:  `cpe:2.3:a:synology:cloud_station:2.0-2402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.922.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.923.0`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.923.1`,
        fs:  `cpe:2.3:a:dell:online_diagnostics:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.924.0`,
        fs:  `cpe:2.3:h:huawei:s2300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.925.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.22.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.926.0`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.927.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.928.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.928.1`,
        fs:  `cpe:2.3:o:xen:xen:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.928.2`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20150824:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.928.3`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.929.0`,
        fs:  `cpe:2.3:a:janetter:janetter:1.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.930.0`,
        fs:  `cpe:2.3:a:symantec:reporting_agents:1.0.224.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.931.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.932.0`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:12.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.933.0`,
        fs:  `cpe:2.3:a:divx:player:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.933.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2011.524.2258.39378:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.934.0`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.2\(2c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.935.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc612a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.935.1`,
        fs:  `cpe:2.3:a:jenkins:git:0.5.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.936.0`,
        fs:  `cpe:2.3:h:hp:s1000-e_vpn_firewall_appliance:jd272a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.936.1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.937.0`,
        fs:  `cpe:2.3:a:nuance:omnipage:2.0.0:*:*:*:se:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.938.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.939.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.939.1`,
        fs:  `cpe:2.3:a:x:libxext:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.940.0`,
        fs:  `cpe:2.3:a:cartpauj:shortcode-redirect:1.0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.941.0`,
        fs:  `cpe:2.3:a:softbank:wi-fi_application:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.942.0`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.943.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.0.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.944.0`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.945.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.946.0`,
        fs:  `cpe:2.3:a:microsoft:pocket_internet_explorer:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.947.0`,
        fs:  `cpe:2.3:a:symantec:intruder_alert_workstation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.948.0`,
        fs:  `cpe:2.3:o:f5:tmos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.949.0`,
        fs:  `cpe:2.3:o:d-link:dir-645_firmware:1.04:b11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.950.0`,
        fs:  `cpe:2.3:a:nullsoft:winamp:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.951.0`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.952.0`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.953.0`,
        fs:  `cpe:2.3:a:ibm:security_directory_server:6.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.954.0`,
        fs:  `cpe:2.3:a:cabextract:cabextract:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.954.1`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:4.0.0:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.954.2`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.954.3`,
        fs:  `cpe:2.3:a:horde:imp:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.955.0`,
        fs:  `cpe:2.3:a:apache:camel:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.956.0`,
        fs:  `cpe:2.3:a:smarty:smarty:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.957.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.6.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.958.0`,
        fs:  `cpe:2.3:a:forgerock:openam:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.958.1`,
        fs:  `cpe:2.3:a:openbsd:openssh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.959.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.960.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.961.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.962.0`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.0`,
        fs:  `cpe:2.3:o:apple:os_x_server:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.1`,
        fs:  `cpe:2.3:o:dell:sonicwall_netextender_firmware:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.2`,
        fs:  `cpe:2.3:a:harmonizers_planet_project:harmonizers_planet:2.3.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.3`,
        fs:  `cpe:2.3:o:xen:xen:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.4`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.5`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_redhat_enterprise_linux_and_suse_linux_enterprise_server:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.6`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.8`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.9`,
        fs:  `cpe:2.3:o:cisco:ios:15.3m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.10`,
        fs:  `cpe:2.3:a:debian:netstd:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.11`,
        fs:  `cpe:2.3:a:justsystems:atok:2006:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.12`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.13`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.14`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.15`,
        fs:  `cpe:2.3:a:x.org:libxv:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.16`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.17`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.18`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.19`,
        fs:  `cpe:2.3:a:qemu:qemu:1.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.20`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.21`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.22`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.23`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.24`,
        fs:  `cpe:2.3:h:cisco:nexus_9516:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.25`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.26`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.27`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.28`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.29`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.4:fp-25_sp-02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.30`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.31`,
        fs:  `cpe:2.3:a:gnome:glib:2.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.32`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.33`,
        fs:  `cpe:2.3:a:php:php:5.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.34`,
        fs:  `cpe:2.3:a:hp:web_registration:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.35`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.36`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_3_firmware:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.37`,
        fs:  `cpe:2.3:a:apple:webkit:522.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.38`,
        fs:  `cpe:2.3:a:ibm:interact:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.39`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.40`,
        fs:  `cpe:2.3:a:skype:skype:3.5.0.178:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.41`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.42`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.43`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.44`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.45`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.46`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.47`,
        fs:  `cpe:2.3:a:google:v8:3.17.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.48`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.49`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.50`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.51`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.52`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(5\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.53`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.54`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.55`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.56`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.57`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.59`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.60`,
        fs:  `cpe:2.3:a:allaire:homesite:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.61`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.62`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.63`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.64`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.440:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.65`,
        fs:  `cpe:2.3:a:sun:solaris_answerbook2:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.66`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.67`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.69`,
        fs:  `cpe:2.3:a:digium:asterisk:11.19.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.70`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.74`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.75`,
        fs:  `cpe:2.3:a:intel:crosswalk:19.49.514.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.76`,
        fs:  `cpe:2.3:a:hp:cuetour:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.77`,
        fs:  `cpe:2.3:a:david_king:vino:2.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.78`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.79`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.80`,
        fs:  `cpe:2.3:a:libexpat:expat:1.95.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.81`,
        fs:  `cpe:2.3:a:oracle:warehouse_builder:11.2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.82`,
        fs:  `cpe:2.3:a:oracle:customer_intelligence:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.83`,
        fs:  `cpe:2.3:a:digium:asterisk:11.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:17.0.963.84`,
        fs:  `cpe:2.3:a:groupon:groupon_merchants:1.5.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1000.0`,
        fs:  `cpe:2.3:a:microsoft:sql_server:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1001.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1001.1`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1002.0`,
        fs:  `cpe:2.3:a:power-tab:power_tab_editor:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1003.0`,
        fs:  `cpe:2.3:a:microsoft:foundation_class_library:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1003.1`,
        fs:  `cpe:2.3:a:schneider-electric:floating_license_manager:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1004.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1005.0`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.3.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1006.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1007.0`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1008.0`,
        fs:  `cpe:2.3:a:oracle:virtualization:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1009.0`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1010.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1010.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1010.2`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1011.1`,
        fs:  `cpe:2.3:h:netgear:fvs318:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1012.0`,
        fs:  `cpe:2.3:a:emc:rsa_archer_smartsuite:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1012.1`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.9.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1012.2`,
        fs:  `cpe:2.3:a:sun:openoffice.org:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1013.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1014.0`,
        fs:  `cpe:2.3:o:siemens:scalance_x-200_series_firmware:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1015.0`,
        fs:  `cpe:2.3:a:apple:itunes:10.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1016.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1017.0`,
        fs:  `cpe:2.3:a:kiosklogix:designerpro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1017.1`,
        fs:  `cpe:2.3:h:juniper:netscreen-5400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1017.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1017.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1018.0`,
        fs:  `cpe:2.3:a:vips:vips:7.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1019.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1019.1`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1020.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1021.0`,
        fs:  `cpe:2.3:a:scriptsfeed:dating_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1022.0`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1023.0`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1024.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.0`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.2`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.3`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.4`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs728txs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.5`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:6.0:u1b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.6`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.7`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.8`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.9`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.2.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.10`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.29`,
        fs:  `cpe:2.3:h:axis:2460_network_dvr:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.30`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.31`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.32`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.33`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.35`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.36`,
        fs:  `cpe:2.3:o:f5:tmos:9.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.37`,
        fs:  `cpe:2.3:o:hp:tru64:5.1a_pk4_bl21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.38`,
        fs:  `cpe:2.3:a:samba:ppp:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.39`,
        fs:  `cpe:2.3:a:ibm:flashcopy_manager:3.1:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.40`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.41`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.42`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.43`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.3.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.44`,
        fs:  `cpe:2.3:a:altiris:dell_client_configuration_utility:3.1.1230.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.45`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.46`,
        fs:  `cpe:2.3:a:ubercart_webform_checkout_pane_project:ubercart_webform_checkout_pane:7.x-3.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.47`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.48`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.100.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.49`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.50`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.51`,
        fs:  `cpe:2.3:a:hp:enterprise:50.0.165.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.52`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.54`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.55`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.56`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:2.5.2.c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.57`,
        fs:  `cpe:2.3:a:dlink:des-3800_firmware:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.58`,
        fs:  `cpe:2.3:a:libssh:libssh:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.60`,
        fs:  `cpe:2.3:a:oracle:http_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.73`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.74`,
        fs:  `cpe:2.3:a:digium:asterisk:13.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.95`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.96`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.97`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.98`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.99`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.100`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg092a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.102`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.107`,
        fs:  `cpe:2.3:a:amazon:merchant_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.108`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.109`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.110`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.111`,
        fs:  `cpe:2.3:a:symantec:norton_power_eraser:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.112`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.8.800.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.113`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.114`,
        fs:  `cpe:2.3:a:symantec:encryption_desktop:10.3.2:mp1:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.116`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.117`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.118`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.120`,
        fs:  `cpe:2.3:a:apache:synapse:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.129`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.130`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.131`,
        fs:  `cpe:2.3:a:mcafee:saas_endpoint_protection:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.132`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:2.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.133`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.134`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.25.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.135`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.136`,
        fs:  `cpe:2.3:a:jason_moore:amadou:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.137`,
        fs:  `cpe:2.3:a:epiqo:email:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.139`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.391:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.140`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.142`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.145`,
        fs:  `cpe:2.3:a:jease:jease:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.146`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.147`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.148`,
        fs:  `cpe:2.3:h:avaya:converged_communications_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.149`,
        fs:  `cpe:2.3:a:sap:hybris:5.6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.150`,
        fs:  `cpe:2.3:a:wali:walisms_cn:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.151`,
        fs:  `cpe:2.3:a:fastin_project:fastin:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:18.0.1025.166`,
        fs:  `cpe:2.3:a:gnu:grub2:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1028.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1029.0`,
        fs:  `cpe:2.3:a:mcafee:firewall_enterprise_control_center:5.0.0.3686:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1030.0`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1031.0`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1032.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg302a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1033.0`,
        fs:  `cpe:2.3:a:hummingbird:exceed_powersuite:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1034.0`,
        fs:  `cpe:2.3:a:phusion:passenger:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1035.0`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1036.0`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r5_b1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1036.2`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1036.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1036.4`,
        fs:  `cpe:2.3:h:cisco:aironet_1260:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1036.6`,
        fs:  `cpe:2.3:o:cisco:dpc3939_wireless_residential_voice_gateway_firmware:121109acmcst_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1036.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1037.0`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1038.0`,
        fs:  `cpe:2.3:a:mediawiki:rssreader:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1039.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1040.0`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:5.2.0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1041.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1042.0`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1043.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.7.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1044.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1045.0`,
        fs:  `cpe:2.3:a:apple:pages:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1046.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1047.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1048.0`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:6.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1049.0`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1049.1`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1049.2`,
        fs:  `cpe:2.3:a:hp:imc_branch_intelligent_management_system_software_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1049.3`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1050.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1051.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1052.0`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1053.0`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1054.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1055.0`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1055.1`,
        fs:  `cpe:2.3:a:commvault:file_system_idataagent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1055.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1055.3`,
        fs:  `cpe:2.3:a:sun:jre:6.0.190:update19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1056.0`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.0.10.636:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1056.1`,
        fs:  `cpe:2.3:a:x:libxcb:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1057.0`,
        fs:  `cpe:2.3:a:merethis:centreon:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1057.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1057.3`,
        fs:  `cpe:2.3:a:candycaneapps:fling_gold:1.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1058.0`,
        fs:  `cpe:2.3:h:cisco:anomaly_guard_module:5.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1058.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1059.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1060.0`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1060.1`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1061.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1061.1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1062.0`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(26a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1062.1`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1063.0`,
        fs:  `cpe:2.3:h:3com:3cp4144:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1063.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1064.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1044:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1065.0`,
        fs:  `cpe:2.3:a:yahoo:yui:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1066.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1067.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1068.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1068.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1069.0`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1070.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1071.0`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120527:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1072.0`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1073.0`,
        fs:  `cpe:2.3:a:sir:gnuboard:4.33.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1074.0`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1075.0`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1076.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1076.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1077.0`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x51:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1077.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1077.2`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1077.3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1078.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1079.0`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1080.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1081.0`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.0.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1081.2`,
        fs:  `cpe:2.3:a:plone:plone:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1082.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1082.1`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.5.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1083.0`,
        fs:  `cpe:2.3:a:bizagi:business_process_management_suite:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.0`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.2`,
        fs:  `cpe:2.3:a:apache:wss4j:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.3`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.4`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.5`,
        fs:  `cpe:2.3:a:mobiscope:mobiscope_local:1.05:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.6`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.7`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.8`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.0:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.9`,
        fs:  `cpe:2.3:a:postfix:postfix:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.10`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.11`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.12`,
        fs:  `cpe:2.3:a:caldera:caldera:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.13`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.14`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.15`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.9.221665.2197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.16`,
        fs:  `cpe:2.3:a:clamav:clamav:0.87.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.17`,
        fs:  `cpe:2.3:h:bluecoat:proxysg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.18`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.19`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.20`,
        fs:  `cpe:2.3:a:hitachi:it_operations_analyzer:02-53-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.22`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.23`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.24`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.25`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.26`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-5520c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.27`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.28`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.29`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.30`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.31`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.32`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.33`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.35`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.36`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.37`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.38`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.39`,
        fs:  `cpe:2.3:a:git-scm:git:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.40`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.41`,
        fs:  `cpe:2.3:a:jruby:jruby:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.42`,
        fs:  `cpe:2.3:a:ca:license_software:1.57.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.43`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.44`,
        fs:  `cpe:2.3:a:investintech:slimpdf_reader:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.45`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.46`,
        fs:  `cpe:2.3:a:bblog_project:bblog:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.47`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.48`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.50`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.387:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.51`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1084.52`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:19.0.1085.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.176:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.0`,
        fs:  `cpe:2.3:a:heikki_hokkanen:viewgit:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.1`,
        fs:  `cpe:2.3:a:microsoft:visio_viewer:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.3`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.4`,
        fs:  `cpe:2.3:a:libav:libav:0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.5`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.6`,
        fs:  `cpe:2.3:a:teamviewer:teamviewer:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.7`,
        fs:  `cpe:2.3:h:hp:jc125a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.8`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:3.3\(5\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.9`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.10`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.11`,
        fs:  `cpe:2.3:a:apple:quicktime:7.2.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.12`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.13`,
        fs:  `cpe:2.3:a:dakshaa:neeku_naaku_dash_dash:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.14`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:08-00-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.15`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.16`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.17`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jab1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.18`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.19`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.20`,
        fs:  `cpe:2.3:a:hp:reporter:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.21`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(1a\)n2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.22`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.23`,
        fs:  `cpe:2.3:a:codedesign:artime_japanese_input:1.1.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.24`,
        fs:  `cpe:2.3:h:intel:server_platform_srsh4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.25`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120406:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.26`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.27`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.28`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.29`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.30`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.31`,
        fs:  `cpe:2.3:a:jogamp:joal:2.0:rc11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.32`,
        fs:  `cpe:2.3:a:teradata:fastexport:12.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.33`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.34`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.7.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.35`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.36`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.37`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.38`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050413:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.39`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.40`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.9:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.41`,
        fs:  `cpe:2.3:a:sap:hybris:5.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.42`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.43`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1010:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.45`,
        fs:  `cpe:2.3:a:microsoft:iis:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.46`,
        fs:  `cpe:2.3:h:cisco:as5400hpx_universal_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.47`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(3.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.54`,
        fs:  `cpe:2.3:a:att:communication_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.55`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.56`,
        fs:  `cpe:2.3:h:cisco:aironet_ap350:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:20.0.1132.57`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.0`,
        fs:  `cpe:2.3:a:isc:bind:9.9.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.1`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.2`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:5.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.2`,
        fs:  `cpe:2.3:h:rockwellautomation:1756-eweb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.31`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.31`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.32`,
        fs:  `cpe:2.3:h:servision:hvg400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.32`,
        fs:  `cpe:2.3:a:openstack:swift:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.33`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.33`,
        fs:  `cpe:2.3:a:sas:base_sas:9.3:ts1m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.34`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.34`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.35`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.35`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.36`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.64:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.36`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.37`,
        fs:  `cpe:2.3:a:digium:asterisk:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.37`,
        fs:  `cpe:2.3:a:google:chrome:41.0.2272.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.38`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.38`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:nb:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.39`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.39`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.41`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.41`,
        fs:  `cpe:2.3:a:ibm:integration_bus:10.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.46`,
        fs:  `cpe:2.3:a:op5:monitor:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.46`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:2.1.1112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.47`,
        fs:  `cpe:2.3:a:ibm:tivoli_integration_composer:7.2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.47`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.48`,
        fs:  `cpe:2.3:a:samba-tng:samba-tng:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.48`,
        fs:  `cpe:2.3:o:huawei:s7703_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.49`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.49`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.50`,
        fs:  `cpe:2.3:h:hp:cz258a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.50`,
        fs:  `cpe:2.3:a:vandyke:securecrt:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.51`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.51`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.52`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.52`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.53`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.07:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.53`,
        fs:  `cpe:2.3:a:redhat:network_satellite_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.54`,
        fs:  `cpe:2.3:h:hp:j9824a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.54`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:2.1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.55`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.55`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0558:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.56`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.56`,
        fs:  `cpe:2.3:o:datumsystems:snip:-:*:*:*:*:*:psm-500:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome:21.0.1180.57`,
        fs:  `cpe:2.3:a:macromedia:shockwave:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.57`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:4.0.5:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.59`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.60`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.30:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.61`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.62`,
        fs:  `cpe:2.3:a:cisco:prime_service_catalog:10.0\(r2\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.63`,
        fs:  `cpe:2.3:h:intel:server_platform_sr870bh2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.64`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.68`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.69`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.70`,
        fs:  `cpe:2.3:h:h3c:s9500e_secblade_vpn_firewall_module:0231a0av:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.71`,
        fs:  `cpe:2.3:a:squareup:okhttp3:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.72`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.73`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.74`,
        fs:  `cpe:2.3:h:d-link:dcs-7010l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.75`,
        fs:  `cpe:2.3:a:x:libxfont:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.76`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.77`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.78`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.79`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.80`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.81`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:5.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.82`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110906:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.83`,
        fs:  `cpe:2.3:a:apple:boot_camp:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.84`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_firmware:ss4.4.4624.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.85`,
        fs:  `cpe:2.3:o:siemens:ccpw3025_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.86`,
        fs:  `cpe:2.3:a:forgerock:openam:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.87`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.88`,
        fs:  `cpe:2.3:h:moxa:iologic_e2262-t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:21.0.1180.89`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.1`,
        fs:  `cpe:2.3:a:powerdns:authoritative:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.3`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.4`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.6`,
        fs:  `cpe:2.3:a:webmin:usermin:1.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.7`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:01-01-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.8`,
        fs:  `cpe:2.3:a:pivotal_software:redis:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.9`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.10`,
        fs:  `cpe:2.3:a:sympa:sympa:0.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.11`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.12`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.54:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.14`,
        fs:  `cpe:2.3:a:otrs:otrs:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.16`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.17`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.18`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.20`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.22`,
        fs:  `cpe:2.3:h:dell:precision_m4300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.23`,
        fs:  `cpe:2.3:a:webmin:usermin:1.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.24`,
        fs:  `cpe:2.3:a:openttd:openttd:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.25`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.52:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.26`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.27`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1657.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.28`,
        fs:  `cpe:2.3:a:sap:businessobjects_xi:r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.29`,
        fs:  `cpe:2.3:a:htc:evo_3d_software:1.13.651.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.31`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.32`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.33`,
        fs:  `cpe:2.3:a:oracle:mysql_connector_net:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.35`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.11.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.36`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p157:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.37`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.39`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.48`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.49`,
        fs:  `cpe:2.3:a:drupal:drupal:6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.50`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.51`,
        fs:  `cpe:2.3:h:hp:8gb_simple_san_connection_kit:ak241a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.52`,
        fs:  `cpe:2.3:a:dell:upek_touchchip_fingerprint_reader:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.53`,
        fs:  `cpe:2.3:o:buffalotech:airstation_extreme_n600_firmware:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.54`,
        fs:  `cpe:2.3:a:gnu:groff:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.55`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.56`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.57`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.58`,
        fs:  `cpe:2.3:a:drupal:drupal:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.59`,
        fs:  `cpe:2.3:a:ibm:java:6.0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.60`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.62`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.63`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.64`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.65`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.67`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.76`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.78`,
        fs:  `cpe:2.3:a:oracle:corporate_time_outlook_connector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.79`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.89`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.5.2:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.91`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.92`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.94`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.95`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:22.0.1229.96`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.1`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.2`,
        fs:  `cpe:2.3:a:winscp:winscp:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.3`,
        fs:  `cpe:2.3:a:nonghyup:smart:3.0.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.4`,
        fs:  `cpe:2.3:a:enorth:webpublisher_cms:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.5`,
        fs:  `cpe:2.3:a:ca:etrust_audit_policy_manager:1.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.6`,
        fs:  `cpe:2.3:o:schneider-electric:modicon_m251_firmware:4.0.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.7`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.8`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.9`,
        fs:  `cpe:2.3:a:debian:apt:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.10`,
        fs:  `cpe:2.3:a:avaya:ip_office_customer_call_reporter:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.11`,
        fs:  `cpe:2.3:a:misli:misli.com_app:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.12`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.13`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.14`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.15`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.16`,
        fs:  `cpe:2.3:h:panasonic:workio_dp-3560:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.17`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.18`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.19`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.20`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.21`,
        fs:  `cpe:2.3:a:digium:asterisk:a:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.22`,
        fs:  `cpe:2.3:a:gnu:glibc:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.23`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.24`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.26`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.30`,
        fs:  `cpe:2.3:a:schneider-electric:ofs_test_client_tlxcdluofs33:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.31`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.32`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.33`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1025:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.35`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.36`,
        fs:  `cpe:2.3:a:yokogawa:exaopc:3.72.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.37`,
        fs:  `cpe:2.3:a:air_war_hero_project:air_war_hero:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.38`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.39`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.40`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.1.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.41`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.44`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.45`,
        fs:  `cpe:2.3:a:isc:bind:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.46`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.49`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.50`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.51`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.52`,
        fs:  `cpe:2.3:a:teradata:visual_explain:13.10.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.53`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.54`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5:cu2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.55`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta7.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.56`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.57`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.58`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.523:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.59`,
        fs:  `cpe:2.3:a:emc:rsa_access_manager:6.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.60`,
        fs:  `cpe:2.3:a:gnome:glib:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.61`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.62`,
        fs:  `cpe:2.3:a:augeas:augeas:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.64`,
        fs:  `cpe:2.3:h:buffalotech:wsr-600dhp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.83`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.84`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.85`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.86`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.87`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.88`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.89`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.13:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.94`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.95`,
        fs:  `cpe:2.3:a:honeywell:enterprise_buildings_integrator:r400.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.96`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p430:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:23.0.1271.97`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.0.2:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1272.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.358.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1272.1`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.2:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1273.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.5-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1274.0`,
        fs:  `cpe:2.3:a:knowledgeview:knowledgeview_editorial_and_management_application:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1275.0`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1276.0`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1276.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1277.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1278.0`,
        fs:  `cpe:2.3:a:cisco:unified_operations_manager:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1279.0`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_cisco_pix_firewall_and_checkpoint_firewall:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1280.0`,
        fs:  `cpe:2.3:a:horde:groupware:5.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1281.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1281.1`,
        fs:  `cpe:2.3:a:oracle:retail_service_backbone:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1281.2`,
        fs:  `cpe:2.3:a:posh_project:posh:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1281.3`,
        fs:  `cpe:2.3:a:oracle:database:12.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1282.0`,
        fs:  `cpe:2.3:a:sap:netweaver:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1283.0`,
        fs:  `cpe:2.3:h:hp:jg210a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1284.0`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1284.1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1284.2`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1285.0`,
        fs:  `cpe:2.3:a:apple:itunes:4.6:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1285.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1285.2`,
        fs:  `cpe:2.3:a:webmin:usermin:0.940:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1286.0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1286.1`,
        fs:  `cpe:2.3:a:cisco:anyconnect_vpn_client:2.4.1012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1287.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1287.1`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1288.0`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.11:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1288.1`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1289.0`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1289.1`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1290.0`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1290.1`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1290.2`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1291.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1291.1`,
        fs:  `cpe:2.3:h:wago:wago_i\/o_system_758_industrial_pc_device:758-876:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1292.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1292.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1293.0`,
        fs:  `cpe:2.3:a:webmin:usermin:1.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1294.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1295.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.19:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1296.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1296.1`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1297.0`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1298.0`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1298.1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1299.0`,
        fs:  `cpe:2.3:a:emc:networker:8.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1300.0`,
        fs:  `cpe:2.3:a:atutor:atutor:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1301.0`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1301.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1301.2`,
        fs:  `cpe:2.3:a:lxml:lxml:3.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1302.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1303.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1304.0`,
        fs:  `cpe:2.3:a:sun:one_application_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1304.1`,
        fs:  `cpe:2.3:a:estrongs:es_file_explorer:1.6.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1305.0`,
        fs:  `cpe:2.3:a:ntop:ntop:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1305.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1305.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1305.3`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1305.4`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(2r\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1306.0`,
        fs:  `cpe:2.3:a:sendmail:message_store_sams:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1306.1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1307.0`,
        fs:  `cpe:2.3:a:debian:reprepro:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1307.1`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1308.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.761.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1309.0`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1310.0`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1311.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1311.1`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.0`,
        fs:  `cpe:2.3:a:cisco:webns:7.10_\(05.07\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.1`,
        fs:  `cpe:2.3:a:conky:conky:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.3`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.48.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.4`,
        fs:  `cpe:2.3:a:php:php:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.5`,
        fs:  `cpe:2.3:h:lg:optimus_g_e973:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.6`,
        fs:  `cpe:2.3:h:cisco:catalyst_ws-c2924-xl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.1dc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.8`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.577:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.9`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.10`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(12b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.12`,
        fs:  `cpe:2.3:a:logilab:logilab-common:0.58.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.13`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.14`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.15`,
        fs:  `cpe:2.3:a:isc:bind:9.9.9:s1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.16`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.17`,
        fs:  `cpe:2.3:a:rockwellautomation:rslogix_5000_design_and_configuration_software:21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.18`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.4.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.20`,
        fs:  `cpe:2.3:a:tincan:phplist:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.21`,
        fs:  `cpe:2.3:h:netgear:me102:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.22`,
        fs:  `cpe:2.3:a:movesti:acontact:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.23`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.24`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.25`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.26`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.27`,
        fs:  `cpe:2.3:a:netscape:smartdownload:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.28`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.2.0.0\(200\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.29`,
        fs:  `cpe:2.3:h:cisco:idsm-2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.30`,
        fs:  `cpe:2.3:o:fortinet:fortianalyzer_firmware:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.31`,
        fs:  `cpe:2.3:o:extremenetworks:extremeware_xos:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.32`,
        fs:  `cpe:2.3:a:microsoft:office:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.33`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144n_firmware:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.34`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.35`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.36`,
        fs:  `cpe:2.3:a:ca:license_software:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.37`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.38`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.39`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.40`,
        fs:  `cpe:2.3:a:islonline:isl_desktop_plugin:1.4.3:-:-:*:windows:isl_light:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.41`,
        fs:  `cpe:2.3:a:adobe:flash_player:22.0.0.192:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.42`,
        fs:  `cpe:2.3:a:opnet:it_guru:16.0.0.10215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.43`,
        fs:  `cpe:2.3:a:activestate:activeperl_pdk:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.44`,
        fs:  `cpe:2.3:h:panasonic:network_camera_recorder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.45`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.46`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:6.40.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.47`,
        fs:  `cpe:2.3:a:debian:adequate:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.48`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.49`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.50`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.51`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.52`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.53`,
        fs:  `cpe:2.3:o:cisco:mds_9000_nx-os:4.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.54`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.55`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.56`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:24.0.1312.57`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.2`,
        fs:  `cpe:2.3:a:ibm:license_metric_tool:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.5`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.00:-:*:*:linux_kernel:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.7`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.8`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.9`,
        fs:  `cpe:2.3:a:hp:openmail:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.11`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.12`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.13`,
        fs:  `cpe:2.3:a:google:chrome:54.0.2840.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.14`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.15`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.16`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.17`,
        fs:  `cpe:2.3:h:meinberg:ims-lantime_m500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.18`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.19`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.20`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.21`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.22`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.23`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.24`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.25`,
        fs:  `cpe:2.3:a:plone:plone:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.26`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.27`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.1:-:liberty_profile:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.28`,
        fs:  `cpe:2.3:a:esri:arcsde:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.29`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.30`,
        fs:  `cpe:2.3:h:hp:designjet_1055:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.31`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.32`,
        fs:  `cpe:2.3:a:esri:arcsde:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.33`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.34`,
        fs:  `cpe:2.3:a:suse:suse_linux_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.35`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view_appliance_iso:6.4.42-2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.36`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp9:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.37`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.38`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.39`,
        fs:  `cpe:2.3:a:microsoft:isa_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.40`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.41`,
        fs:  `cpe:2.3:h:linksys:wrt54g:3.03.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.42`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.43`,
        fs:  `cpe:2.3:o:google:android:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.44`,
        fs:  `cpe:2.3:a:pcre:pcre:8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.45`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.46`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.47`,
        fs:  `cpe:2.3:a:phpscriptlerim:php_scriptlerim_who\&#39;s_who:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.48`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.49`,
        fs:  `cpe:2.3:a:pantech:pc_usb_modem_software:3.2.4074.1103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.50`,
        fs:  `cpe:2.3:a:pineapp:mail-secure:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.51`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.52`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.53`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xi2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.54`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.55`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.56`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.57`,
        fs:  `cpe:2.3:a:mysql:mysql:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.58`,
        fs:  `cpe:2.3:a:pmail:mercury_mail_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.61`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.62`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.63`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)snh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.65`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.66`,
        fs:  `cpe:2.3:a:shopware:shopware:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.67`,
        fs:  `cpe:2.3:h:cisco:2106_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.68`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.70`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.72`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.73`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.74`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a1:7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.75`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.5:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.76`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp2:advanced_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.77`,
        fs:  `cpe:2.3:a:byfes:ileri_gazetesi_-_yozgat:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.78`,
        fs:  `cpe:2.3:a:symantec:veritas_operations_manager:3.0.358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.79`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.80`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.81`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.82`,
        fs:  `cpe:2.3:a:apple:safari:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.84`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.85`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.86`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.87`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.88`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.0.4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.89`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.90`,
        fs:  `cpe:2.3:o:juniper:junos:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.91`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-01-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.92`,
        fs:  `cpe:2.3:a:ibm:sterling_file_gateway:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.93`,
        fs:  `cpe:2.3:a:corel:painter_ipm:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.95`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.98`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.99`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_8945:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.108`,
        fs:  `cpe:2.3:h:hp:9000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.110`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7971g:8.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.112`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.0.2:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.113`,
        fs:  `cpe:2.3:h:cabletron:6h252-17:4.08.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.114`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.115`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.116`,
        fs:  `cpe:2.3:a:apple:itunes:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.117`,
        fs:  `cpe:2.3:a:lightdm_project:lightdm:1.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.118`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.119`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r331.112:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.120`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.121`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.122`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.123`,
        fs:  `cpe:2.3:a:ca:etrust_integrated_threat_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.124`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.125`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:25.0.1364.126`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_supply_chain_management_purchasing:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.1`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.2`,
        fs:  `cpe:2.3:a:gnu:wget:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.3`,
        fs:  `cpe:2.3:h:lexmark:t652:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:50.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.5`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.13.4693:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.6`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.7`,
        fs:  `cpe:2.3:a:samba:samba:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.8`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.9`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.10`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.11`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xv3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.14`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert:1.0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.15`,
        fs:  `cpe:2.3:h:polycom:viewstation_mp:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.16`,
        fs:  `cpe:2.3:a:nagios:nagios:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.17`,
        fs:  `cpe:2.3:a:google:v8:3.24.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.18`,
        fs:  `cpe:2.3:a:microsoft:visio:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.19`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.20`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.21`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0.2112:online_windows_server_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.22`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.23`,
        fs:  `cpe:2.3:a:hp:icewall_file_manager:3.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.24`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.25`,
        fs:  `cpe:2.3:h:tek:phaser_network_printer_740:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.26`,
        fs:  `cpe:2.3:a:citrix:xenapp:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.27`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.1.1557:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.28`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.29`,
        fs:  `cpe:2.3:o:google:android:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.30`,
        fs:  `cpe:2.3:a:roxio:creator:2011:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.31`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.32`,
        fs:  `cpe:2.3:a:hub_project:hub:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.33`,
        fs:  `cpe:2.3:a:drupal:drupal:6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.34`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:6.x-3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.35`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53_93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.36`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.37`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.38`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.39`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.10:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.40`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.41`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:26.0.1410.42`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1444.0`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:2.0.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p474:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.1`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.3`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.4`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.5`,
        fs:  `cpe:2.3:a:blackberry:blackberry_world:5.1.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.6`,
        fs:  `cpe:2.3:a:hp:insight_control_performance_management:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.7`,
        fs:  `cpe:2.3:a:checkpoint:secureclient_ng:r56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p348:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.10`,
        fs:  `cpe:2.3:a:google:chrome:4.0.300.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.11`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.12`,
        fs:  `cpe:2.3:o:cisco:rv215w_wireless-n_vpn_router_firmware:1.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.13`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.15`,
        fs:  `cpe:2.3:h:sitecom:wlm-2501:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.34`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.35`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.7:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.36`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:8.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.37`,
        fs:  `cpe:2.3:a:inline:ihtml:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.38`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.39`,
        fs:  `cpe:2.3:a:hp:fortify_software_security_center:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.40`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.41`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.42`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.6:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.43`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.44`,
        fs:  `cpe:2.3:h:juniper:srx210:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.45`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.46`,
        fs:  `cpe:2.3:a:hp:ldap-ux_integration:b.02.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.47`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.49`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.50`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.51`,
        fs:  `cpe:2.3:a:xnview:xnview:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.52`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.54`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17d\)sxb10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.55`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.56`,
        fs:  `cpe:2.3:a:hp:software_core_simplified_chinese_localization:6.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.57`,
        fs:  `cpe:2.3:h:juniper:srx220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.58`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.59`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.60`,
        fs:  `cpe:2.3:a:microsoft:media_player:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.61`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.62`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.63`,
        fs:  `cpe:2.3:a:cisco:security_agent:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.64`,
        fs:  `cpe:2.3:a:adobe:air_sdk:20.0.0.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.65`,
        fs:  `cpe:2.3:a:gnu:glibc:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.66`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.429:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.67`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.68`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.69`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.70`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.71`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.72`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.73`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.74`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.75`,
        fs:  `cpe:2.3:a:agilebits:knox:2.0.3:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.76`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.77`,
        fs:  `cpe:2.3:a:avantstar:quick_view_plus:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.78`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.79`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.80`,
        fs:  `cpe:2.3:a:justsystems:hanako_police:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.81`,
        fs:  `cpe:2.3:a:roaraudio:roaraudio:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.82`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.83`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.84`,
        fs:  `cpe:2.3:a:alphabetic_sitemap_project:alphabetic_sitemap:0.0.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.85`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.86`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.87`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.88`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.89`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.90`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0002_3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.91`,
        fs:  `cpe:2.3:h:zyxel:p-660h-t1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.93`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.94`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-00-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.102`,
        fs:  `cpe:2.3:o:juniper:junos:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.103`,
        fs:  `cpe:2.3:a:zhtiantian:kuailecaidengmi:1.7.12.15:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.104`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.105`,
        fs:  `cpe:2.3:h:netscout:ngenius_probes:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.106`,
        fs:  `cpe:2.3:a:adobe:flash_player:20.0.0.306:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.107`,
        fs:  `cpe:2.3:a:freebsd:heimdal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.108`,
        fs:  `cpe:2.3:a:netscape:navigator:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.109`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.110`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.111`,
        fs:  `cpe:2.3:h:hp:jf241a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.112`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.113`,
        fs:  `cpe:2.3:a:symantec:pgp_universal_server:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.114`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.115`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:27.0.1453.116`,
        fs:  `cpe:2.3:a:xnview:xnview:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sxh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.4`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.5`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.6`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:sp1:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.8`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.9`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:j:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.10`,
        fs:  `cpe:2.3:a:xnview:xnview:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.11`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.12`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.13`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.14`,
        fs:  `cpe:2.3:a:gnu:bash:1.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.15`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.16`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.17`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_1100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.18`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.19`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.20`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.24:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.21`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.22`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:9.6.0-000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.23`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.24`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.25`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.26`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.27`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.123:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.28`,
        fs:  `cpe:2.3:o:xen:xen:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.29`,
        fs:  `cpe:2.3:a:augeas:augeas:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.31`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.32`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.33`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.31:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.34`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_51:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.35`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.36`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.37`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.38`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.39`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.1:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.40`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.41`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.42`,
        fs:  `cpe:2.3:o:juniper:screenos:6.2.0r15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.43`,
        fs:  `cpe:2.3:a:vmware:tools:8.3.7.3827:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.44`,
        fs:  `cpe:2.3:h:netgear:d6400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.45`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.46`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.47`,
        fs:  `cpe:2.3:h:xerox:workcentre_40_color:01.00.060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.48`,
        fs:  `cpe:2.3:a:qlogic:sansurfer:1.0.0.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.49`,
        fs:  `cpe:2.3:h:juniper:fips_secure_access_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.50`,
        fs:  `cpe:2.3:a:php-nuke:downloadsplus_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.51`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.52`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.53`,
        fs:  `cpe:2.3:a:apache:hadoop:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.54`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4:*:*:*:*:symbian_os:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.56`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.58`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.59`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.60`,
        fs:  `cpe:2.3:a:nonghyup:smart_card:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.61`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.62`,
        fs:  `cpe:2.3:a:busybox:busybox:1.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.63`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.64`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.66`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.6.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.68`,
        fs:  `cpe:2.3:a:typo3:flow:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.70`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.71`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.72`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.89`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.91`,
        fs:  `cpe:2.3:a:openstack:swift:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.93`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.94`,
        fs:  `cpe:2.3:a:linux-nis:rpc.yppasswdd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:28.0.1500.95`,
        fs:  `cpe:2.3:a:ubuntu_developers:language-selector:0.79.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.334.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.3`,
        fs:  `cpe:2.3:a:cisco:1000v_virtual_ethernet_module_\(vem\):4.0\(4\):sv1\(2\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.4`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.5`,
        fs:  `cpe:2.3:a:intel:management_engine_components:6.0.0.1179:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.7`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.8`,
        fs:  `cpe:2.3:a:firejail_project:firejail:0.9.44.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.9`,
        fs:  `cpe:2.3:h:zyxel:p-660hw_t3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.10`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.11`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.12`,
        fs:  `cpe:2.3:a:gajim:gajim:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.13`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.475:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.14`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.15`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_9.0_firmware:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.16`,
        fs:  `cpe:2.3:a:adobe:flash_player:23.0.0.207:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.17`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.18`,
        fs:  `cpe:2.3:a:springshare:libcal:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.19`,
        fs:  `cpe:2.3:a:suse:suse_linux_enterprise_software_development_kit:11.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.20`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.21`,
        fs:  `cpe:2.3:a:perlmonks:module\:\:signature:0.73:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.22`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.23`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.27`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g01.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.28`,
        fs:  `cpe:2.3:h:hp:jg837a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.29`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.30`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.31`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.32`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.33`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer_with_flow_analytics_module:9.0.1:-:pay:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.34`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:r2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.35`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.36`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.37`,
        fs:  `cpe:2.3:a:php:php:5.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.38`,
        fs:  `cpe:2.3:a:hp:continuous_delivery_automation:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.39`,
        fs:  `cpe:2.3:a:phpspot:php_bbs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.40`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update6:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.41`,
        fs:  `cpe:2.3:a:microsoft:office_web_apps:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.42`,
        fs:  `cpe:2.3:a:linecorp:line:4.3.1:*:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.45`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.46`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.47`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.48`,
        fs:  `cpe:2.3:a:samba:samba:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.49`,
        fs:  `cpe:2.3:a:microsoft:msn_setup_bulletin_board_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.50`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.51`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.52`,
        fs:  `cpe:2.3:a:debian:apt:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.53`,
        fs:  `cpe:2.3:a:apple:quicktime:7.3.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.54`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.55`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:qa2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.56`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:29.0.1547.57`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.0`,
        fs:  `cpe:2.3:a:unisys:enterprise_output_manager:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.2`,
        fs:  `cpe:2.3:a:malware_finder_plugin_project:malware_finder:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(25e\)jao5m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.5`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.6`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.7`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.8`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.9`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.10`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.11`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.4.0.2540:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.12`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.13`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.14`,
        fs:  `cpe:2.3:a:lsi:symplicity_es_storage_manager:10.70.x3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.15`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.16`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.06:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.17`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.18`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.19`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.20`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.21`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.1.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.22`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.23`,
        fs:  `cpe:2.3:a:acme:thttpd:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.24`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-00-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.25`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.26`,
        fs:  `cpe:2.3:a:redwood:explorer:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.27`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.28`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1670.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.29`,
        fs:  `cpe:2.3:a:sharetronix:sharetronix:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.30`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:08-00-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.31`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.32`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.33`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.34`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.35`,
        fs:  `cpe:2.3:o:enea:ose:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.36`,
        fs:  `cpe:2.3:a:mawashimono:nikki:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.37`,
        fs:  `cpe:2.3:a:mollify:mollify:0.9.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.38`,
        fs:  `cpe:2.3:h:ibm:flex_system_manager_node_8734:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.39`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.40`,
        fs:  `cpe:2.3:a:cdnvote_project:cdnvote:0.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.41`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.42`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle:7.5.3.1281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.43`,
        fs:  `cpe:2.3:a:nvidia:display_driver:307.00:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.44`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.47`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.60:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.48`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.49`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.490:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.50`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-00-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.51`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.52`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.53`,
        fs:  `cpe:2.3:a:emc:smarts_network_configuration_manager:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.56`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.57`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.58`,
        fs:  `cpe:2.3:o:redhat:linux:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.59`,
        fs:  `cpe:2.3:h:rockwellautomation:softlogix_5800_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.60`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)t11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.61`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.505:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.64`,
        fs:  `cpe:2.3:a:google:chrome:6.0.437.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.65`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.66`,
        fs:  `cpe:2.3:a:redmine:redmine:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.67`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.11:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.68`,
        fs:  `cpe:2.3:a:nvidia:nview:135.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.69`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.79`,
        fs:  `cpe:2.3:o:huawei:s9303_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.80`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.3.7:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.81`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:1.02.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.82`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.84`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.85`,
        fs:  `cpe:2.3:a:ibm:filenet_content_manager:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.86`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.87`,
        fs:  `cpe:2.3:a:jenkins:git:0.9.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.88`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.90`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.100`,
        fs:  `cpe:2.3:a:web2py:web2py:1.96.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:30.0.1599.101`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.2`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.3`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.17:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.5`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.6`,
        fs:  `cpe:2.3:a:microsoft:ie:6.0.2600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.7`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.8`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.9`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.10`,
        fs:  `cpe:2.3:h:honeywell:midas_black:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.11`,
        fs:  `cpe:2.3:a:google:chrome:5.0.339.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.12`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.13`,
        fs:  `cpe:2.3:a:gnu:zebra:0.93b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.14`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.15`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.16`,
        fs:  `cpe:2.3:a:at32:reverse_proxy:1.060.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.17`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.18`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.19`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.20`,
        fs:  `cpe:2.3:a:python:python:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.22`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.23`,
        fs:  `cpe:2.3:h:hp:jg362b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.25`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.26`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.27`,
        fs:  `cpe:2.3:o:suse:suse_linux:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.28`,
        fs:  `cpe:2.3:a:hp:quicktransfer:140.0.98.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.29`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.30`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.31`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.32`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.69.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.33`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-02-\/f:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.34`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.35`,
        fs:  `cpe:2.3:a:busybox:busybox:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.36`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.1:ea8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.37`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.38`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.39`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.41`,
        fs:  `cpe:2.3:o:huawei:s9312e_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.42`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.43`,
        fs:  `cpe:2.3:h:fortinet:fortigate-20c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.44`,
        fs:  `cpe:2.3:a:ca:mlink:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.45`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.46`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf553a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.47`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p372:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.48`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.49`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:tenc4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.50`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.51`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf019:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.52`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.53`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.54`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.55`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.57`,
        fs:  `cpe:2.3:h:iij:seil\/turbo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.58`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.59`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.60`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:941sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.61`,
        fs:  `cpe:2.3:a:python:python:2.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.62`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd333a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:31.0.1650.63`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1651.2`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1652.0`,
        fs:  `cpe:2.3:a:apache:libcloud:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1652.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.00:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1653.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1653.1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1653.2`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1654.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1654.2`,
        fs:  `cpe:2.3:h:cisco:cache_engine_505:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1654.3`,
        fs:  `cpe:2.3:a:perl:perl:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1655.0`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1655.1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1656.0`,
        fs:  `cpe:2.3:h:f5:big-ip_8900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1656.1`,
        fs:  `cpe:2.3:a:smarttech:smart_board_software:9.5.49.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1656.2`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1657.0`,
        fs:  `cpe:2.3:o:asus:rt-n10e_firmware:2.0.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1657.2`,
        fs:  `cpe:2.3:h:juniper:router_m16:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1658.0`,
        fs:  `cpe:2.3:a:invitation_project:invitation:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1658.1`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.4.3850.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1658.2`,
        fs:  `cpe:2.3:a:teradata:sql_assistant:12.0:*:*:*:web:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1659.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1659.1`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1659.2`,
        fs:  `cpe:2.3:a:cardscan:cardscan:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1659.3`,
        fs:  `cpe:2.3:a:arcsight:arcsight_smartconnector:5.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1660.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1660.1`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1660.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1661.0`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1661.1`,
        fs:  `cpe:2.3:a:mysql:mysql:3.22.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1662.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1662.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1662.2`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1663.0`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1663.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1663.2`,
        fs:  `cpe:2.3:a:dell:touchpad:7.2.101.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1663.3`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1664.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1664.1`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_solaris:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1664.2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1664.3`,
        fs:  `cpe:2.3:a:idt:idt_audio:1.0.6274.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1665.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_idm_launcher:1.5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1666.0`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1666.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1667.0`,
        fs:  `cpe:2.3:o:ibm:linux_on_zseries:-:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1667.1`,
        fs:  `cpe:2.3:a:spip:spip:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1668.0`,
        fs:  `cpe:2.3:a:altiris:connector_solution_data_integration_component_extensions:6.0.1318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1668.1`,
        fs:  `cpe:2.3:o:samsung:samsung_mobile:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1668.2`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1668.3`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1668.4`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1668.5`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:9.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1668.6`,
        fs:  `cpe:2.3:h:cabletron:6h252-17:5.05.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1669.0`,
        fs:  `cpe:2.3:o:cisco:nx-os_1000v_switch:4.0\(4\)sv1\(3a\):*:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1669.1`,
        fs:  `cpe:2.3:h:oracle:sun_blade_x6270_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1669.2`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1669.3`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1670.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1670.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p362:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1670.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.248:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1670.3`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24:rc1.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1670.4`,
        fs:  `cpe:2.3:a:hp:restful_interface_tool:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1670.5`,
        fs:  `cpe:2.3:a:menalto:gallery:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1671.0`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1671.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.156.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1671.3`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1671.4`,
        fs:  `cpe:2.3:a:microweber:microweber:0.830:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1671.7`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1671.8`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1672.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1672.2`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1673.0`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1673.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1673.3`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1673.4`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1674.0`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1674.1`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120526:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1674.2`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1675.0`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1675.1`,
        fs:  `cpe:2.3:a:andsocialrew:amkamal_science_portfolio:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1675.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1675.3`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1676.0`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1676.1`,
        fs:  `cpe:2.3:a:apache:hbase:0.92.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1676.2`,
        fs:  `cpe:2.3:a:agilebits:knox:1.6.2:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1677.0`,
        fs:  `cpe:2.3:a:tightvnc:tightvnc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1677.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1678.0`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1678.1`,
        fs:  `cpe:2.3:a:csilvers:gperftools:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1678.2`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1679.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1679.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1680.0`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1680.1`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:10.1.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1681.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1681.2`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1681.3`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.92:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1682.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)xv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1682.3`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:4.6\(2\):sr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1682.4`,
        fs:  `cpe:2.3:a:nortel:meridian_option_51c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1682.5`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1683.0`,
        fs:  `cpe:2.3:a:citrix:password_manager_plugin:4.6.264.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1683.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1683.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1684.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1684.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1684.2`,
        fs:  `cpe:2.3:o:d-link:dir-816l_firmware:2.05.b02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1684.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1685.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1685.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1685.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1685.3`,
        fs:  `cpe:2.3:a:hp:6400_help:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1686.0`,
        fs:  `cpe:2.3:a:ca:unicenter_serviceplus_service_desk:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1686.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1687.0`,
        fs:  `cpe:2.3:a:wec_map_project:wec_map:3.0.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1687.2`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1688.0`,
        fs:  `cpe:2.3:a:hp:openview_client_configuraton_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1688.1`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1689.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.23.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1689.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1689.2`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.4.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1689.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1690.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1690.2`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.0`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.2`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.3`,
        fs:  `cpe:2.3:o:yahama:rta52i:4.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.4`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.6`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.7`,
        fs:  `cpe:2.3:h:hp:j9310a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.8`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.9`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.361:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.10`,
        fs:  `cpe:2.3:h:apple:iphone:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.11`,
        fs:  `cpe:2.3:a:google:chrome:7.0.518.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.12`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.13`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.14`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.15`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.16`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.17`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.18`,
        fs:  `cpe:2.3:a:debian:mime-support:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.19`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.21`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.22`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p473:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.23`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.24`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0_b2pl23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.26`,
        fs:  `cpe:2.3:a:vastal:phpvid:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.27`,
        fs:  `cpe:2.3:a:sap:crystal_enterprise_xi:3.1:fp_3.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.28`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.29`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.30`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.31`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.32`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.33`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.34`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.35`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.38`,
        fs:  `cpe:2.3:a:pgpdump_project:pgpdump:0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.39`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.41`,
        fs:  `cpe:2.3:a:roxio:easy_cd_creator_basic:5.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.50`,
        fs:  `cpe:2.3:a:apache:subversion:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.51`,
        fs:  `cpe:2.3:a:sap:sapcryptolib:5.555.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.52`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.53`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:x64-datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.54`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.55`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.56`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.88:-:*:*:linux_kernel:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.57`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.58`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.59`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.62`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.63`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.64`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.65`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.66`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.67`,
        fs:  `cpe:2.3:a:websupergoo:abcpdf_.net:8.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.68`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.22:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.69`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.70`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:9.3.e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.71`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.72`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.74`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.2.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.75`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)ey1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.76`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.77`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.94`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp13:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.95`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.96`,
        fs:  `cpe:2.3:a:adobe:creative_suite_4_design_premium:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.97`,
        fs:  `cpe:2.3:a:oracle:customer_relationship_management_technical_foundation:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.98`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.1:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.99`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.100`,
        fs:  `cpe:2.3:a:kyoceramita:product_library:2.0.713:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.101`,
        fs:  `cpe:2.3:a:oracle:reports:9i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.102`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:32.0.1700.103`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.3.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.1`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.03b23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.2`,
        fs:  `cpe:2.3:a:keepass:keepass:0.93:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.3`,
        fs:  `cpe:2.3:a:cisco:server_provisioner:6.4.0:patch_5-1301292331:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.4`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.5`,
        fs:  `cpe:2.3:a:apple:safari:3.0.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.6`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.1:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.7`,
        fs:  `cpe:2.3:a:git-scm:git:1.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.8`,
        fs:  `cpe:2.3:a:samba:samba:3.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.9`,
        fs:  `cpe:2.3:a:redmine:redmine:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.10`,
        fs:  `cpe:2.3:a:yahoo:messenger:2.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.11`,
        fs:  `cpe:2.3:a:symantec:norton_security:13.0.1:*:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.12`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.13`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.7.720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.14`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.15`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0081:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.16`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.18`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.19`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.20`,
        fs:  `cpe:2.3:a:debian:mime-support:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.21`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.22`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.23`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.24`,
        fs:  `cpe:2.3:a:cgit_project:cgit:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.25`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.26`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.16.3:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.27`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.28`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.53:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.29`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.0:alpha4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.30`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.31`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.34`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.35`,
        fs:  `cpe:2.3:a:e107:e107:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.36`,
        fs:  `cpe:2.3:a:typoheads:formhandler:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.37`,
        fs:  `cpe:2.3:a:sony:digital_voice_editor:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.38`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.39`,
        fs:  `cpe:2.3:a:tincan:phplist:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.40`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.41`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.42`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.43`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.12.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.44`,
        fs:  `cpe:2.3:a:tribulant:tibulant_slideshow_gallery:1.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.45`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.46`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.47`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.48`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p130:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.49`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.08b77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.50`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.22:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.51`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.52`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.53`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.34:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.54`,
        fs:  `cpe:2.3:a:perl:perl:5.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.55`,
        fs:  `cpe:2.3:a:gnu:coreutils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.56`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.08:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.57`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:rc14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.58`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.59`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.60`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.61`,
        fs:  `cpe:2.3:a:emc:networker:8.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.62`,
        fs:  `cpe:2.3:a:avaya:network_routing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.63`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.64`,
        fs:  `cpe:2.3:a:citrix:xenserver:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.65`,
        fs:  `cpe:2.3:a:google:chrome:10.0.639.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.66`,
        fs:  `cpe:2.3:a:novell:iprint:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.67`,
        fs:  `cpe:2.3:o:cisco:ios:10.3\(3.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.68`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.3.2\(1393\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.69`,
        fs:  `cpe:2.3:a:cisco:webex_social:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.70`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.0.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.71`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.3:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.73`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.74`,
        fs:  `cpe:2.3:h:cabletron:smartswitch_router_8000_firmware:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.75`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.76`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.77`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.79`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.80`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.81`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.82`,
        fs:  `cpe:2.3:h:juniper:mag2600_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.83`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.85`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.88`,
        fs:  `cpe:2.3:a:osticket:osticket:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.89`,
        fs:  `cpe:2.3:a:social_stats_project:social_stats:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.90`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.91`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.3.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.92`,
        fs:  `cpe:2.3:h:hp:j8715a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.93`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_user:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.104`,
        fs:  `cpe:2.3:a:google:chrome:6.0.490.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.106`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.107`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.108`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.109`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.110`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.111`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5204l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.112`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.0:alpha-3:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.113`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.115`,
        fs:  `cpe:2.3:a:ca:unicenter_service_metric_analysis:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.116`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.117`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.124`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.125`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.126`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.132`,
        fs:  `cpe:2.3:a:meta_tags_quick_project:meta_tags_quick:7.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.133`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxf8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.135`,
        fs:  `cpe:2.3:a:bannersky:bsk_pdf_manager:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.136`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.144`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.146`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.149`,
        fs:  `cpe:2.3:a:livetecs:timeline:6.2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.151`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:6.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.152`,
        fs:  `cpe:2.3:a:mike_peachey:authen\:\:externalauth:0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.153`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.154`,
        fs:  `cpe:2.3:a:trioniclabs:sentinel:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.166`,
        fs:  `cpe:2.3:h:xerox:workcentre_232:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.167`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:33.0.1750.168`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.14:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.1`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.2`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.4`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.5`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.6`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.7`,
        fs:  `cpe:2.3:a:adobe:camera_raw:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.8`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-02-\/f:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.9`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.10`,
        fs:  `cpe:2.3:a:abbyy:finereader:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.12`,
        fs:  `cpe:2.3:a:juniper:junos_space_virtual_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.14`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.14:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxd4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.23`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.24`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.25`,
        fs:  `cpe:2.3:a:ocportal:ocportal:5.0.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.36`,
        fs:  `cpe:2.3:h:meinberg:lantime_m400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.37`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.38`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.39`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:331.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.41`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.42`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.1.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.43`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.44`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.45`,
        fs:  `cpe:2.3:a:techsmith:snagit:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.46`,
        fs:  `cpe:2.3:a:gnu:mailman:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.47`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.52.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.48`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)ja1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.49`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.50`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/impact:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.51`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.52`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:08-00:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.53`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.54`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.55`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.56`,
        fs:  `cpe:2.3:h:cisco:wireless_lan_controller:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.57`,
        fs:  `cpe:2.3:a:clamav:clamav:0.93.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.58`,
        fs:  `cpe:2.3:o:apple:os_x_server:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.59`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13.4\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.60`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.61`,
        fs:  `cpe:2.3:a:apache:log4net:1.2.9_beta:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.62`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.63`,
        fs:  `cpe:2.3:a:gnu:wget:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.64`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.65`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.66`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.67`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.68`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.69`,
        fs:  `cpe:2.3:a:redhat:directory_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.71`,
        fs:  `cpe:2.3:a:oracle:commerce_platform:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.72`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.73`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.74`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.75`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.278:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.76`,
        fs:  `cpe:2.3:a:maxthon:maxthon_browser:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.77`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.78`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.79`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.80`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_tray_monitor:10.0.11639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.81`,
        fs:  `cpe:2.3:a:adobe:flex_builder:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.82`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.83`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-00:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.85`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.86`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.87`,
        fs:  `cpe:2.3:a:clamav:clamav:0.95:src1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.91`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.92`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.94`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.97`,
        fs:  `cpe:2.3:h:supermicro:x8sie-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.98`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:p9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.99`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.100`,
        fs:  `cpe:2.3:a:oracle:sun_middleware_products:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.101`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.102`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.103`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.104`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.109`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.111`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.112`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.702:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.113`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.114`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)xr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.115`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.116`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.118`,
        fs:  `cpe:2.3:h:d-link:dcs-5000l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.120`,
        fs:  `cpe:2.3:a:oracle:hyperion:11.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.130`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.131`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.132`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.133`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.134`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.135`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.136`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:34.0.1847.137`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.0`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:3.0:sp2a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.2`,
        fs:  `cpe:2.3:a:netscape:communicator:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.4`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.5`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.6`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.4:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.8`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.9`,
        fs:  `cpe:2.3:a:websitepanel:websitepanel:1.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.10`,
        fs:  `cpe:2.3:a:nmh:nmh:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p176:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.13`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.14`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.15`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.17`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.18`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.19`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.20`,
        fs:  `cpe:2.3:a:byond:byond:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.21`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.22`,
        fs:  `cpe:2.3:a:in-portal:in-portal:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.23`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.6300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.27`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.31`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.06.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.32`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.33`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.34`,
        fs:  `cpe:2.3:h:enterasys:vertical_horizon-2402s:2.05.08.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.35`,
        fs:  `cpe:2.3:a:adobe:type_support_cs4:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.36`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.95:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.37`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.38`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.39`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.40`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.41`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.42`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.43`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.44`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.45`,
        fs:  `cpe:2.3:a:symantec:gateway_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.46`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.47`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.48`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.49`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97-final:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.51`,
        fs:  `cpe:2.3:a:google:v8:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.52`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.54`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.56`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.57`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(3b\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.59`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.61`,
        fs:  `cpe:2.3:a:google:chrome:16.0.909.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.68`,
        fs:  `cpe:2.3:h:hp:laserjet_4000n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.69`,
        fs:  `cpe:2.3:a:wesley_destailleur:todoo_forum:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.71`,
        fs:  `cpe:2.3:a:emc:isilon_insightiq:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.72`,
        fs:  `cpe:2.3:a:atutor:atutor:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.74`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.77`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(24a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.80`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.82`,
        fs:  `cpe:2.3:a:pragmasys:fortress_ssh_client_suite:5.0.9.1370:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.84`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.4.1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.85`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.86`,
        fs:  `cpe:2.3:a:instantasp:instantforum:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.88`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(18\)s5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.90`,
        fs:  `cpe:2.3:a:sgi:fam:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.92`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:8.5.3-055:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.93`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.95`,
        fs:  `cpe:2.3:a:yahoo:toolbar:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.96`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.98`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.99`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.101`,
        fs:  `cpe:2.3:h:xerox:colorqube_8570:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.103`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.104`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.105`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.106`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.4:a_beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.107`,
        fs:  `cpe:2.3:a:cisco:evolved_programmable_network_manager:1.2.500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.108`,
        fs:  `cpe:2.3:a:corel:wordperfect:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.109`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.110`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.111`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.499:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.112`,
        fs:  `cpe:2.3:a:hp:sitescope_integrations:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:35.0.1916.113`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.4.0.46.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.1`,
        fs:  `cpe:2.3:a:uanw:united_advantage_nw_federal_cr:1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.2`,
        fs:  `cpe:2.3:h:htc:merge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.3`,
        fs:  `cpe:2.3:a:hp:openview_e\/a_agent:8.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.5`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.6`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.7`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.41:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.8`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.9`,
        fs:  `cpe:2.3:a:supportezzy_ticket_system_project:supportezzy_ticket_system:1.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.10`,
        fs:  `cpe:2.3:a:nirsoft:smartsniff:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.11`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:7.21.020.3447:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.12`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.13`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.14`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.15`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.16`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.3.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.17`,
        fs:  `cpe:2.3:a:apache:struts:2.3.24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.18`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.19`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.20`,
        fs:  `cpe:2.3:a:emc:records_client:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.21`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.6:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.22`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.23`,
        fs:  `cpe:2.3:h:zyxel:p-660h-67:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.24`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.00.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.25`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(13\)wt6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.26`,
        fs:  `cpe:2.3:a:microsoft:windows_media_services:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.27`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.28`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.29`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.10:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.30`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.8:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.31`,
        fs:  `cpe:2.3:a:apple:itunes:12.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.32`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.33`,
        fs:  `cpe:2.3:o:opensuse:opensuse:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.34`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.35`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.36`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.37`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.39`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.120.1316.e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.43`,
        fs:  `cpe:2.3:a:redhat:analog_real-time_synthesizer:2.2-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.44`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.45`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.46`,
        fs:  `cpe:2.3:a:altiris:deployment_server_extension_for_ibm_director:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.47`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.48`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.49`,
        fs:  `cpe:2.3:o:breakingpointsystems:breakingpoint_storm_appliance_ctm:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.50`,
        fs:  `cpe:2.3:a:ati:control_panel:6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.51`,
        fs:  `cpe:2.3:a:schneems:wicked:0.1.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.52`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.53`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.54`,
        fs:  `cpe:2.3:o:iij:eil\%2fx2_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.55`,
        fs:  `cpe:2.3:h:hp:nonstop_himalaya:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.56`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.57`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.58`,
        fs:  `cpe:2.3:a:oracle:http_server:10.1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.59`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.60`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.61`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.62`,
        fs:  `cpe:2.3:a:python:python:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.63`,
        fs:  `cpe:2.3:a:sun:java_web_start:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.64`,
        fs:  `cpe:2.3:a:reviewboard:djblets:0.7.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.65`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53_93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.66`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.67`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.68`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(4.11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.69`,
        fs:  `cpe:2.3:a:ibm:workload_deployer:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.70`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.71`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.72`,
        fs:  `cpe:2.3:a:emc:rsa_data_protection_manager_software_server:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.73`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.74`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.75`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.76`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.77`,
        fs:  `cpe:2.3:a:google:chrome:14.0.797.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.78`,
        fs:  `cpe:2.3:a:attachmate:infoconnect_enterprise_edition:7.50.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.80`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.81`,
        fs:  `cpe:2.3:a:web-dorado:web-dorado_spider_video_player:1.4.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.89`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.90`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.91`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.626:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.92`,
        fs:  `cpe:2.3:a:f5:enterprise_manager:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.93`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.94`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.95`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.96`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.97`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:37.0.2062.99`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:38.0.2125.101::~~~android~~`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-ampg_firmware:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:39.0.2171.63`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:40.0.2214.85`,
        fs:  `cpe:2.3:h:hp:0235a20j:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:40.0.2214.89::~~~android~~`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ebx:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:40.0.2214.93`,
        fs:  `cpe:2.3:a:hp:arcsight_logger:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:40.0.2214.115`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:41.0.2272.74`,
        fs:  `cpe:2.3:a:apache:camel:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:41.0.2272.102`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:42.0.2311.60`,
        fs:  `cpe:2.3:a:advantech:adamview:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:42.0.2311.87`,
        fs:  `cpe:2.3:a:apache:poi:2.0:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:42.0.2311.107::~~~android~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:42.0.2311.152`,
        fs:  `cpe:2.3:a:alvaro_herrera:pl\/php:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:43.0.2357.81`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1302.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:43.0.2357.134`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:45.0.2454.93`,
        fs:  `cpe:2.3:a:oracle:database_server:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:45.0.2454.101`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:3.0.0.4.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:46.0.2490.80`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:46.0.2490.86`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:47.0.2526.73`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.4.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:47.0.2526.80`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_client:4.1.1.6534:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:47.0.2526.106`,
        fs:  `cpe:2.3:a:tvbengali:tv_bengali_open_directory:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:47.0.2526.111`,
        fs:  `cpe:2.3:a:cisco:webns:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:48.0.2564.103`,
        fs:  `cpe:2.3:a:pedro_cambra:commerce_extra_panes:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:48.0.2564.109`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:48.0.2564.116`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:49.0.2623.75`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:49.0.2623.95`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:49.0.2623.112`,
        fs:  `cpe:2.3:a:entertailion:able_remote:2.3.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:50.0.2661.87`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:50.0.2661.91`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:50.0.2661.102`,
        fs:  `cpe:2.3:a:fastappz:corvette_museum:1.399:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:51.0.2704.63`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:51.0.2704.84`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:51.0.2704.106`,
        fs:  `cpe:2.3:a:symantec:vrtsaa:5.0.433:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:52.0.2743.82`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:52.0.2743.116`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:53.0.2785.101`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:53.0.2785.143`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:54.0.2840.68::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:54.0.2840.71`,
        fs:  `cpe:2.3:a:google:chrome:4.0.276.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:54.0.2840.87`,
        fs:  `cpe:2.3:a:ca:siteminder:12.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:54.0.2840.99`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.3.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:55.0.2883.87`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome:59.0.3071.115`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.13:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome_frame:15.0.874.121`,
        fs:  `cpe:2.3:o:sun:solaris:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:chrome_frame:16.0.912.63`,
        fs:  `cpe:2.3:a:libav:libav:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:0.9.110.6`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:0.9.126.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:0.9.128.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:0.9:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:0.9.130.14:beta`,
        fs:  `cpe:2.3:a:ibm:iss_proventia_desktop:8.0.675.1790:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:0.9.131.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:0.9.134.14`,
        fs:  `cpe:2.3:h:samsung:shr-5162:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:0.10.140.0`,
        fs:  `cpe:2.3:a:blaine_lang:maestro:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:8.0.552.342`,
        fs:  `cpe:2.3:a:xnview:xnview:1.94.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:8.0.552.343`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:8.0.552.344`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.9:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.2.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.1`,
        fs:  `cpe:2.3:h:iodata:ts-wptcam_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.2`,
        fs:  `cpe:2.3:h:cisco:cgr_1120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.3`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.6`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:1.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.7`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.8`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.9`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.10`,
        fs:  `cpe:2.3:a:redhat:libtirpc:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.11`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.12`,
        fs:  `cpe:2.3:o:huawei:mate_8_firmware:nxt-dl10c00b197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.13`,
        fs:  `cpe:2.3:a:siemens:simatic_step_7:5.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.14`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:522:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.23:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.16`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.121.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.17`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.18`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.19`,
        fs:  `cpe:2.3:a:gnu:wget:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.20`,
        fs:  `cpe:2.3:a:busybox:busybox:1.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:20.0.1132.21`,
        fs:  `cpe:2.3:a:magzter:global_movie_magazine:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.0`,
        fs:  `cpe:2.3:h:hp:lio_10_100_print_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.1`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.5-1:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.3`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.4`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.5`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.6`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.7`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.8`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:503:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.10`,
        fs:  `cpe:2.3:a:apache:tomcat_jk_web_server_connector:1.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.11`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.13`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.14`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.15`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.17`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.18`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.31`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.32`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(3d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.33`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(6a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.34`,
        fs:  `cpe:2.3:a:riken:xoonips:3.45:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.35`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.36`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(24\)sv1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.37`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:27.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.38`,
        fs:  `cpe:2.3:a:oracle:balanced_scorecard:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.39`,
        fs:  `cpe:2.3:h:hp:jg869a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.41`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.46`,
        fs:  `cpe:2.3:a:acquia:mollom:6.x-2.12:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.47`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.48`,
        fs:  `cpe:2.3:a:apple:webkit:419.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.49`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.50`,
        fs:  `cpe:2.3:a:openstack:neutron:2014.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.51`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.52`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.53`,
        fs:  `cpe:2.3:a:geteversnap:eversnap_private_photo_album:1.0.23:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.54`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.55`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1511c-1_pn_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.56`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.57`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.79`,
        fs:  `cpe:2.3:a:apache:hadoop:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1180.81`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:21.0.1183.0`,
        fs:  `cpe:2.3:a:sun:solaris_answerbook2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.0`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.1`,
        fs:  `cpe:2.3:h:juniper:netscreen-idp_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.2`,
        fs:  `cpe:2.3:o:fedoraproject:fedora_core:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.3`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.5`,
        fs:  `cpe:2.3:a:david_king:vino:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.7`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.1.1:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.8`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.10`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.11`,
        fs:  `cpe:2.3:a:redmine:redmine:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.12`,
        fs:  `cpe:2.3:a:inline_entity_form_project:inline_entity_form:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.13`,
        fs:  `cpe:2.3:a:cisco:webns:7.1_0.1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.14`,
        fs:  `cpe:2.3:a:asg:asg-report.web:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.15`,
        fs:  `cpe:2.3:h:netgear:d6220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.16`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:95:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.17`,
        fs:  `cpe:2.3:a:adgjm:galapagos_browser:-:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.18`,
        fs:  `cpe:2.3:a:adobe:camera_raw:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.19`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.20`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.21`,
        fs:  `cpe:2.3:a:zend:zendservice_windowsazure:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.22`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.23`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.24`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.25`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.26`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.27`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.28`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.29`,
        fs:  `cpe:2.3:a:web2py:web2py:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.30`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r9:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.31`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.32`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.33`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.34`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.8c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.35`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.36`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:alpha1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.37`,
        fs:  `cpe:2.3:a:heiko_sudar:slideshare:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.38`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.39`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.817:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.40`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.41`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.42`,
        fs:  `cpe:2.3:a:exim:exim:4.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.43`,
        fs:  `cpe:2.3:a:vmware:player:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.44`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.45`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.46`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.47`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.44:-:*:*:esx:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.48`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator:3.3.782:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.49`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.50`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.51`,
        fs:  `cpe:2.3:a:barracuda:yosemite_server_backup:8.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.52`,
        fs:  `cpe:2.3:a:happyworm:jplayer:0.2.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.53`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.54`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.70:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.55`,
        fs:  `cpe:2.3:a:hexagon:erdas_apollo_ecwp:13.00.0001:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.56`,
        fs:  `cpe:2.3:a:sharethis:sharethis:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.57`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention_server:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.58`,
        fs:  `cpe:2.3:o:centos:centos:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.61`,
        fs:  `cpe:2.3:h:hp:2d_value_wireless_scanner_k3l28aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.62`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.3.1:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.63`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ew:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.65`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.66`,
        fs:  `cpe:2.3:a:hp:software_cross_platform_component:6.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.67`,
        fs:  `cpe:2.3:a:sun:ipmitool:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.68`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.70`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.1.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.72`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.73`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0.0.18997:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.74`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.75`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.0.7539:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.76`,
        fs:  `cpe:2.3:h:supermicro:x9drw-3tf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.77`,
        fs:  `cpe:2.3:a:ca:messaging:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.78`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.79`,
        fs:  `cpe:2.3:a:microsoft:outlook.com:7.8.2.12.49.7564:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.80`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.81`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.82`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server_supplementary:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.84`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.85`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p128:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.86`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.87`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_database_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.88`,
        fs:  `cpe:2.3:a:sun:n1_system_manager:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.89`,
        fs:  `cpe:2.3:a:haxx:curl:7.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.90`,
        fs:  `cpe:2.3:a:rastreadordecelulares:rastreador_de_celulares:5.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.91`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.92`,
        fs:  `cpe:2.3:a:oracle:reports:6i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.93`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.95`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.8:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.98`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.99`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.108`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.110`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.112`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.113`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.114`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.115`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.116`,
        fs:  `cpe:2.3:a:winzip:self-extractor:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.117`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.118`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.119`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.120`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.121`,
        fs:  `cpe:2.3:a:findingscience:mod_auth_openid:0.6:*:*:*:*:apache:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.122`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.123`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.124`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.18:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.125`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.831:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.126`,
        fs:  `cpe:2.3:a:sympa:sympa:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.152`,
        fs:  `cpe:2.3:o:cisco:vpn_3060_concentrator:4.7\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.154`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.7.22161:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.155`,
        fs:  `cpe:2.3:a:perl:perl:2.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.156`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.159`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.9.0.1030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.160`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.161`,
        fs:  `cpe:2.3:a:relsoftware:web_link_validator:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.168`,
        fs:  `cpe:2.3:h:cisco:rv325_dual_gigabit_wan_wf_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.169`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.170`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.171`,
        fs:  `cpe:2.3:a:google:chrome:11.0.690.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.172`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:25.0.1364.173`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.16.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.4`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.6`,
        fs:  `cpe:2.3:a:microsoft:project:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.7`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.8`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:fnc9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.9`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.9.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.11`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.12`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0552:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.14`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.15`,
        fs:  `cpe:2.3:a:apple:safari:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.16`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p433:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.17`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:9.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.18`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6ece:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.19`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.20`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.21`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.22`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.23`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.24`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:12.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.25`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.26`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.804:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.27`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.28`,
        fs:  `cpe:2.3:a:altiris:component_for_active_directory_documentation:6.1.1019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.29`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.30`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.31`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(3\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.32`,
        fs:  `cpe:2.3:a:perl:perl:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.33`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.34`,
        fs:  `cpe:2.3:a:craig_barratt:backuppc:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.35`,
        fs:  `cpe:2.3:a:autodesk:dwf_viewer:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.36`,
        fs:  `cpe:2.3:a:ibm:websphere_plugin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.37`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.38`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.39`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.40`,
        fs:  `cpe:2.3:a:debian:apt:0.7.17:exp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.41`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.42`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.43`,
        fs:  `cpe:2.3:a:monotone:monotone:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.44`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.45`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.46`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.47`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.5:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.48`,
        fs:  `cpe:2.3:a:ibm:content_collector:3.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.49`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.50`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.51`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.52`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.54`,
        fs:  `cpe:2.3:a:microsoft:outlook:2002:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.55`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:google:chrome_os:26.0.1410.56`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:1.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:cityhash:-`,
        fs:  `cpe:2.3:a:gb-plugins:gb_gallery_slideshow:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:cityhash:1.1.0`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:google:cr-48_chromebook:-`,
        fs:  `cpe:2.3:a:altiris:task_management_pack_language_pack:6.0.1504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:custom_search_engine:-`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:desktop:-`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:drive:-`,
        fs:  `cpe:2.3:a:sap:crystal_enterprise_xi:3.1:fp_3.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:drive:1.0.77::~~~android~~`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:drive:1.0.2891.6813::~~~windows~~`,
        fs:  `cpe:2.3:a:google:chrome:10.0.601.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:-`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:4.0.2091:beta`,
        fs:  `cpe:2.3:o:brocade:fabric_os:5.0.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:4.2.198.2451`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:4.2.205.5730`,
        fs:  `cpe:2.3:a:sympa:sympa:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:4.3.7204.836`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:4.3.7284.3916`,
        fs:  `cpe:2.3:a:sophos:unified_threat_management_software:9.351:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:5.0.11733.9347`,
        fs:  `cpe:2.3:a:oracle:flexcube_direct_banking:12.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:5.1.3533.1731`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:5.1.3535.3218`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p224:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:5.1.7894.7252`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.384:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:5.2.0.5932`,
        fs:  `cpe:2.3:a:expressjs:express:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:5.2.1.1547`,
        fs:  `cpe:2.3:a:rpm:rpm:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:5.2.1.1588`,
        fs:  `cpe:2.3:a:facebook:hiphop_virtual_machine:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:6.0.1.2032`,
        fs:  `cpe:2.3:a:levelfourdevelopment:wp-easycart:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:6.0.2.2074`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:6.0.3.2197`,
        fs:  `cpe:2.3:o:cisco:catos:4.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:6.1.0.4857`,
        fs:  `cpe:2.3:a:microsoft:baseline_security_analyzer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth:6.1.0.5001`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth_plug-in:5.2.0.5932`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth_plug-in:6.0.2.2016`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth_plug-in:6.0.3.2197`,
        fs:  `cpe:2.3:a:avaya:vsu_2000:3.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth_plug-in:6.1.0.4738`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth_plug-in:6.1.0.4857`,
        fs:  `cpe:2.3:a:schneider-electric:powerlogic_scada:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:earth_plug-in:6.1.0.5001`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:email:4.2.2.0200::~~~android~~`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:frame:-`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:gears:0.4.17.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:google:glass:xe5`,
        fs:  `cpe:2.3:a:adrian_chadd:rtg2:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:google:glass:xe6`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:7.7.0-608:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:google_chart_server:1.0`,
        fs:  `cpe:2.3:a:sap:mmc_snapin:7.20.30038:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:googlebot:2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2irb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:googlebot-image:1.0`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:kubernetes:-`,
        fs:  `cpe:2.3:a:google:chrome:12.0.710.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:google:mini_search_appliance:-`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:google:mini_search_appliance:3.4.14`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.9:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/h:google:mini_search_appliance:4.4.102.m.36`,
        fs:  `cpe:2.3:a:ca:brightstor_process_automation_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.1.1-171`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.8.1-215`,
        fs:  `cpe:2.3:a:microsoft:frontpage:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.8.1-250`,
        fs:  `cpe:2.3:h:buffalotech:wex-300_firmware:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.11.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.14.6`,
        fs:  `cpe:2.3:a:digium:asterisk:11.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.15.3`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.0.8:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.16.3`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(8\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.16.9`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.17.3`,
        fs:  `cpe:2.3:a:k7computing:k7firewall_packet_driver:14.0.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.17.6`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.9.18.6`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.10.19.1`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.10.19.3`,
        fs:  `cpe:2.3:a:inspiration:text_to_speech_xp:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.10.19.5`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.1.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.10.21.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.10.22.4`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.10.22.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:mod_pagespeed:0.10.22.7`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:google:nexus_9:-`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:picasa:-`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:picasa:3.6`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1681.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:picasa:3.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:picasa:3.9.0`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:picasa:3.9.140`,
        fs:  `cpe:2.3:a:google:v8:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:google:search_appliance:-`,
        fs:  `cpe:2.3:a:cisco:prime_service_catalog:10.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:search_appliance_software:6.12`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:search_appliance_software:6.14`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:search_appliance_software:7.0.14`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:search_appliance_software:7.0.14.g.216`,
        fs:  `cpe:2.3:a:altiris:network_inventory:6.0.1198:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:search_appliance_software:7.2.0`,
        fs:  `cpe:2.3:a:symantec:vrtsaa:5.0.286:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:search_appliance_software:7.2.0.g.114`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:6.0:maintenance_6`,
        fs:  `cpe:2.3:a:solarwinds:tftp_server:9.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:7.0:maintenance_1`,
        fs:  `cpe:2.3:a:opsview:opsview:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:7.1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:7.1:maintenance_1`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:7.1:maintenance_2`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:8.0`,
        fs:  `cpe:2.3:a:cubicfactory:cubic_cms:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:8.0:maintenance_1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:8.0:maintenance_2`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:8.0:maintenance_3`,
        fs:  `cpe:2.3:h:ceragon:fiberair_ip-10c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:sketchup:8.0:maintenance_4`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk:-`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk:1.0.0.64`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk:1.0.0.66`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk:1.0.0.67`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk:1.0.0.68`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00-\/i:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk:1.0.0.70`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk:1.0.0.72`,
        fs:  `cpe:2.3:a:rpm:rpm:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk:1.0.0.75`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:1.0.2.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:1.2.0.0`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:1.5.1.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:1.9.2.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:2.0.7.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.94:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:2.1.6.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:2.1.8.0`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0053:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:2.2.2.0`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:2.3.2.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:talk_plugin:2.5.8.4958`,
        fs:  `cpe:2.3:a:red-gate:sql_backup:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:-`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.41`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:5.0.0-h1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.42`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.43`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.44`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.0.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.45`,
        fs:  `cpe:2.3:a:measureup:certification_preparation:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.47`,
        fs:  `cpe:2.3:a:citrix:access_management_console_diagnostics:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.48`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.49`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.53`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.54`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.55`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.56`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.57`,
        fs:  `cpe:2.3:a:dell:wyse_device_manager:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.58`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.59`,
        fs:  `cpe:2.3:a:ca:host-based_intrusion_prevention_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:1.1.60`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:2.0.114.1`,
        fs:  `cpe:2.3:o:opensuse_project:opensuse:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:4`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar:5:beta`,
        fs:  `cpe:2.3:h:huawei:ne5000e:v300r007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar_for_firefox:7.1.20101113b1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)st1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar_for_internet_explorer:1.0.0`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar_for_internet_explorer:4.0.0.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.6.5\(4097\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar_for_internet_explorer:6.6.1015.36`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar_for_internet_explorer:7.0.1710.2246`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar_for_internet_explorer:7.1.2003.1856`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar_for_internet_explorer:7.2.2308.2056`,
        fs:  `cpe:2.3:a:python:python:3.3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:toolbar_for_internet_explorer:7.2.2318.1946`,
        fs:  `cpe:2.3:a:netapp:netcache:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:update_helper:1.2.183.29`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:update_helper:1.3.21.53`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:update_helper:1.3.21.57`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:update_helper:1.3.21.69`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:update_helper:1.3.21.79`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:update_helper:1.3.21.81`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_form_module:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:updater:2.4.1536.6592`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:updater:2.4.2432.1652`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.13:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:urchin:-`,
        fs:  `cpe:2.3:a:redprairie:redprairie_client:2010.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:urchin:5`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:1.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.1`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.2`,
        fs:  `cpe:2.3:a:fiberlink:maas360:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.605:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.4`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.6`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.2rc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.7`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.8`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.4.9`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.1`,
        fs:  `cpe:2.3:a:nigel_horne:mod_spambot:0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.2`,
        fs:  `cpe:2.3:a:isc:bind:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.3`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.4`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.5`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.6`,
        fs:  `cpe:2.3:a:roxio:dvdmax_player:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.7`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.8`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp3:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:2.5.9`,
        fs:  `cpe:2.3:a:kencast:fazzt_enterprise_server:8.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.0`,
        fs:  `cpe:2.3:o:sun:sunos:5.11:-:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.283.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.3`,
        fs:  `cpe:2.3:h:rockwellautomation:1769_compactlogix_l23x_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.4`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.5`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.6`,
        fs:  `cpe:2.3:h:xyplex:maxserver_1620_terminal_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.8`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.10`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5600-50c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.11`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.0.12`,
        fs:  `cpe:2.3:a:rocklobster:contact_form_7:3.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.0`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.1`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.2`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_pdf_sdk_dll:3.1.1.5005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.3`,
        fs:  `cpe:2.3:h:cisco:dpc3925:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.5`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:103sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.6`,
        fs:  `cpe:2.3:a:google:chrome:13.0.767.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.7`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.1.8`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.0`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator:3.3.929:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.2`,
        fs:  `cpe:2.3:a:rpm:rpm:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.6`,
        fs:  `cpe:2.3:a:apache:mod_perl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.10.8`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.0`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.1`,
        fs:  `cpe:2.3:a:yokogawa:fast\/tools:r9.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.2`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.3`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.4`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.5`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.6`,
        fs:  `cpe:2.3:a:microsoft:sql_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.7`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.8`,
        fs:  `cpe:2.3:h:hp:4650_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.9`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.5:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.11.10`,
        fs:  `cpe:2.3:a:isc:bind:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.0`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.554.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.2`,
        fs:  `cpe:2.3:o:vmware:esx:1.5.2:patch2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.3`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.04.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.6`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.0:rc2:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.7`,
        fs:  `cpe:2.3:a:netbsd:umapfs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.8`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.9`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.10`,
        fs:  `cpe:2.3:a:hanabank:hanabank:4.06:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.11`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.12`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.13`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.14`,
        fs:  `cpe:2.3:h:logitech:cordless_freedom:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.15`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.16`,
        fs:  `cpe:2.3:a:redgraphic:sapid_cms:1.2.3:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.17`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.18`,
        fs:  `cpe:2.3:a:altiris:package_rule_management_language_pack:6.1.4085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.12.19`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.0`,
        fs:  `cpe:2.3:a:citrix:broadcast_server:6.0:*:cisco:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.1`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.3`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.4`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.5`,
        fs:  `cpe:2.3:h:siemens:simatic_s7_cpu_1214c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.6`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.7`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.13.7.5`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.14.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.1.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.14.1`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.14.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.14.3`,
        fs:  `cpe:2.3:a:voucherry:vouch\!:2.1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.14.4`,
        fs:  `cpe:2.3:a:f5:big-ip_configuration_utility:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.14.5`,
        fs:  `cpe:2.3:a:scilab:scilab:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.0`,
        fs:  `cpe:2.3:a:novell:netmail:3.10e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(8\)db2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.2`,
        fs:  `cpe:2.3:a:libav:libav:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.4`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.5`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.7`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.8`,
        fs:  `cpe:2.3:a:altiris:monitor_solution:6.0.1341:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.9`,
        fs:  `cpe:2.3:a:qbnz:geshi:1.0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.10`,
        fs:  `cpe:2.3:a:oracle:agile_product_lifecycle_management:9.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.11`,
        fs:  `cpe:2.3:a:elinks:elinks:0.12:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.17.12`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.1`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.2`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.4`,
        fs:  `cpe:2.3:a:qemu:qemu:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.5`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.6`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.0.10.648:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.7`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.8`,
        fs:  `cpe:2.3:a:symantec:mail-gear:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.9`,
        fs:  `cpe:2.3:a:mysql:mysql:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.10`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.11`,
        fs:  `cpe:2.3:a:acra:acra_library:-:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.12`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.13`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.14`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.383:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.15`,
        fs:  `cpe:2.3:a:ibm:acprunner:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.16`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.17`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.11-1.8:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.18`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.19`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.20`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.21`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.22`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.23`,
        fs:  `cpe:2.3:o:bluecoat:avos:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.24`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.22.24.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_platform:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.1`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.2`,
        fs:  `cpe:2.3:a:mozilla:gecko:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.3`,
        fs:  `cpe:2.3:a:opera:opera_mini:7.5.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.4`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.5`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.06.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.7`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.8`,
        fs:  `cpe:2.3:h:netgear:r6900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.9`,
        fs:  `cpe:2.3:a:php:php:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.10`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.11`,
        fs:  `cpe:2.3:a:winzip:winzip:12.1.8497:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.12`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.13`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.14`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.15`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.16`,
        fs:  `cpe:2.3:a:openvpn:openvpn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.17`,
        fs:  `cpe:2.3:a:intellegere:thanodi_-_setswana_translator:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.23.18`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.0`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.1`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.1.4er1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.4`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.07.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.5`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.6`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.7`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.8`,
        fs:  `cpe:2.3:a:mcafee:virusscan:10.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.9`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.10`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.11`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.0-14:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.12`,
        fs:  `cpe:2.3:a:php:php:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.13`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.14`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.15`,
        fs:  `cpe:2.3:a:cisco:unified_icm_hosted:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.16`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.17`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.18`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.19`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:3.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.20`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.02:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.21`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.22`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.23`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.24`,
        fs:  `cpe:2.3:h:cisco:cache_engine_505:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.25`,
        fs:  `cpe:2.3:h:foundrynet:bigiron_mg8_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.26`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.0.1-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.27`,
        fs:  `cpe:2.3:a:ibm:api_management:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.28`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.29`,
        fs:  `cpe:2.3:a:cisco:mediasense:9.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.30`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.31`,
        fs:  `cpe:2.3:a:sympa:sympa:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.32`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.33`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.34`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.433:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.35`,
        fs:  `cpe:2.3:o:apple:os_x_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.36`,
        fs:  `cpe:2.3:o:cisco:catos:6.2\(0.111\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.37`,
        fs:  `cpe:2.3:a:kaylon:powermarks:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.38`,
        fs:  `cpe:2.3:a:boost:boost:1.56.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.39`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.24.40`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.1:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.25.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.25.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.25.2`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.25.3`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.25.4`,
        fs:  `cpe:2.3:a:indus-systems:idrawings_work_flow:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:3.30.33.14`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.6:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:4.2.77.7`,
        fs:  `cpe:2.3:a:altiris:helpdesk_proxy:6.0.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:4.6.85.23`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:4.7.80`,
        fs:  `cpe:2.3:h:canyon-tech:cn-wf512:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:4.9.385`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:5.0.71`,
        fs:  `cpe:2.3:a:mcafee:asset_baseline_monitor_agent:mcafee_inc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:5.1.281`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_direct_user_interface:1.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:v8:5.2.360`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:web_server:2.1`,
        fs:  `cpe:2.3:a:google:v8:3.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:web_toolkit:-`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google:web_toolkit:1.4.60`,
        fs:  `cpe:2.3:a:ssh:tectia_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:ad-minister_project:ad-minister:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:6.x-1.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp4:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:6.x-1.2`,
        fs:  `cpe:2.3:a:apport_project:apport:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:7.x-1.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:19.0.0.245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:7.x-1.0:dev`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:7.x-1.1`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:7.x-1.2`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_authenticator_login_project:ga_login:7.x-1.3`,
        fs:  `cpe:2.3:a:surfcontrol:web_filter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_calendar_events_project:google_calendar_events:2.0.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_doc_embedder:google_doc_embedder:2.5.18::~~~wordpress~~`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd7.d4xxd_svga_mb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_doc_embedder_project:google_doc_embedder:2.5.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wildpackets:ip_subnet_calculator:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:6.x-1.0`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:6.x-1.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:2.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:6.x-1.2`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:6.x-1.3`,
        fs:  `cpe:2.3:a:moodle:moodle:3.3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:6.x-1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120702:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.0`,
        fs:  `cpe:2.3:a:jython_project:jython:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.1`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.05.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.1:rc1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.3`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.17a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.4:beta1`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.5`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.6`,
        fs:  `cpe:2.3:a:hp:service_virtualization:3.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.7`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.1:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.8`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.9`,
        fs:  `cpe:2.3:a:gajim:gajim:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.10`,
        fs:  `cpe:2.3:a:ibm:informix_client_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_site_search_project:google_site_search_module:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:google_sitemap_project:google_sitemap:0.4.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goomeo:sopexa_pavillon_france:3.6.5::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.0.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.0.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.0.2`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.0.3`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.0.4`,
        fs:  `cpe:2.3:a:flat_manager_project:flat_manager:2.7.9:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.1.0`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.1.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_products:8.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.1.2`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-00-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.1.3`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.1.4`,
        fs:  `cpe:2.3:o:hp:tru64:5.1_pk6_bl20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.1.5`,
        fs:  `cpe:2.3:h:pacom:rtu_gms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.2.0`,
        fs:  `cpe:2.3:a:defa-online-image-protector_project:defa-online-image-protector:3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.2.1`,
        fs:  `cpe:2.3:a:collabnet:subversion_client:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.2.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.2.3`,
        fs:  `cpe:2.3:a:coffee-inn:coffee_inn:2.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.2.4`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.2.5`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.3.0`,
        fs:  `cpe:2.3:a:irdeto:flexsms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.3.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.3.2`,
        fs:  `cpe:2.3:a:webform_invitation_project:webform_invitation:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.3.3`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.3.4`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.3.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails:2.3.6`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.05.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.0.0`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.0.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.1.0`,
        fs:  `cpe:2.3:o:cisco:cisco_ons_15454_system_software:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.1.1`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.1.2`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.1.4`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.1.5`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.1.6`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.820:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.2.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.2.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.2.2`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.2.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.2.4`,
        fs:  `cpe:2.3:a:adobe:common_file_installer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gopivotal:grails-resources:1.2.5`,
        fs:  `cpe:2.3:a:emc:networker:7.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gotobestofprice:thai_food:1::~~~android~~`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gots:civa:1.0.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:govhk:government_bookstore:1.01::~~~android~~`,
        fs:  `cpe:2.3:a:apple:cups:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gowkster:fabulas_infantiles:3.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:goywp:webpress:13.00.06`,
        fs:  `cpe:2.3:a:exim:exim:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gparted:gparted:14.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.5`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.5:rc2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.313.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.5:rc3`,
        fs:  `cpe:2.3:a:debian:php5-common:5.3.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.5:rc4`,
        fs:  `cpe:2.3:h:huawei:s5300hi:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6:rc1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.2.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6:rc2`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6:rc3`,
        fs:  `cpe:2.3:a:abtei-neuburg:stift_neuburg:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6:rc4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6:rc5`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6.1`,
        fs:  `cpe:2.3:h:hp:nonstop_himalaya_s7800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6.2`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:1.6.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1656.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:2.0.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:2.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:2.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:2.3`,
        fs:  `cpe:2.3:a:isc:bind:9.7.6:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:2.3.1`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:2.3.2`,
        fs:  `cpe:2.3:a:bullguard:bdagent.sys:1.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:2.3.3`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:2.4`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_human_capital_management_human_resources:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.0`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.0.1`,
        fs:  `cpe:2.3:o:brickom:100ap_device_firmware:3.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.0.2`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry:241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.0.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.0.5`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.5`,
        fs:  `cpe:2.3:a:lester_chan:wp-downloadmanager:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.5.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p476:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpeasy:gpeasy_cms:3.5.2`,
        fs:  `cpe:2.3:a:thycotic:secret_server:8.8.000001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpg4win:gpg4win:-`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.2`,
        fs:  `cpe:2.3:h:hp:aaa_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.3`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p239_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.5`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.6`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.7`,
        fs:  `cpe:2.3:a:apple:itunes:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.8`,
        fs:  `cpe:2.3:a:twiki:twiki:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.9`,
        fs:  `cpe:2.3:a:mcafee:asap_virusscan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gpsd_project:gpsd:3.10`,
        fs:  `cpe:2.3:h:huawei:ar_18-1x:r0130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grabapp:eponyms:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gradkell:dbsign:2.3`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gradkell:dbsign_administration_tools:3.0`,
        fs:  `cpe:2.3:a:apache:struts:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gradkell:dbsign_for_html_applications:3.0.0.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gradkell:dbsign_web_signer:2.3`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:9.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gradkell:dbsign_web_signer:3.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.2.3`,
        fs:  `cpe:2.3:o:cisco:voip_phone_cp-7960:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.3.9`,
        fs:  `cpe:2.3:a:opsview:opsview:3.6:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.6`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.7`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.11`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.16`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.27`,
        fs:  `cpe:2.3:a:veritas:backup_exec_remote_agent:10.0.5484:sp4:windows_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.34`,
        fs:  `cpe:2.3:a:justsystems:shuriken_pro:4:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.37`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.38`,
        fs:  `cpe:2.3:o:cisco:ip_phone_8800_series_firmware:10.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.39`,
        fs:  `cpe:2.3:a:oracle:virtualization:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.42`,
        fs:  `cpe:2.3:a:rsa:bsafe_ssl-j_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.43`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1297.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:grandstream:gxv_device_firmware:1.0.4.44`,
        fs:  `cpe:2.3:a:subrion:cms:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3500:-`,
        fs:  `cpe:2.3:a:busybox:busybox:1.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3501:-`,
        fs:  `cpe:2.3:a:sympa:sympa:0.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3504:-`,
        fs:  `cpe:2.3:a:devarai:word_search_free:4.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3601:-`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.70.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3601hd%2fll:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.185.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3611hd%2fll:-`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3615w%2fp:-`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3615wp_hd:-`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3651fhd:-`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:grandstream:gxv3662hd:-`,
        fs:  `cpe:2.3:a:twiki:twiki:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:granita:cloud_browser:2.2.1::~~~android~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graniteds:granite_data_services:3.1.1-snapshot`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2008.717.2343.40629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.1.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.14:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.1.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(4a\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.1.2`,
        fs:  `cpe:2.3:a:scilab:scilab:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.1.3`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.1.4`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.1.5`,
        fs:  `cpe:2.3:a:microsoft:office:2013:-:-:*:-:-:x64:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.2.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.24.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.2.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.2.3`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.2.4`,
        fs:  `cpe:2.3:o:cisco:catos:2.4\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.2.5`,
        fs:  `cpe:2.3:a:google:chrome:2.0.159.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.2.6`,
        fs:  `cpe:2.3:a:all_around_cyprus_project:all_around_cyprus:2.11:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.3.0`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.3.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.3.2`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.4.0`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grape_project:grape:0.4.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:0.5.125.0:beta1`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:0.5.142.0:beta2`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.30.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.63.0`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.128.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.02:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.175.0:beta`,
        fs:  `cpe:2.3:h:oracle:sun_blade_x6270:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.195.0:beta`,
        fs:  `cpe:2.3:a:microsoft:proxy_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.236.0:beta`,
        fs:  `cpe:2.3:a:oracle:webcenter_content:12.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.261.0:rc`,
        fs:  `cpe:2.3:o:suse:suse_linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.342.0:rc`,
        fs:  `cpe:2.3:o:d-link:dcs-5020l_firmware:1.13.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.419.0`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.0.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.441.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.0.546.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.5.711.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.5.750.0`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.5.807.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.5.866.0`,
        fs:  `cpe:2.3:a:meinberg:network_time_protocol:4.2.4p8\@lennon-o-lpv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.5.905.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.5.1052.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.6.1818.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.6.1818.8`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.07:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.6.1871.8`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.6.1871.24`,
        fs:  `cpe:2.3:a:freedesktop:poppler:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.6.1871.45`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3a\)e8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.6.1871.61`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grapecity:data_dynamics_reports:1.6.2084.14`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:-`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.441:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.0`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-3.0:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.0.1`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.0.2`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.07.0290:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.0.3`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.0.4`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.0.5`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.0.6`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20150330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.22:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.2`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-4:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.3`,
        fs:  `cpe:2.3:a:dell:truemobile_1300_wlan_mini-pci_card_util_trayapplet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.4`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:hu:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.6`,
        fs:  `cpe:2.3:a:google:chrome:4.0.242.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.7`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.8`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.9`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.10`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.11`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.12`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.4:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.13`,
        fs:  `cpe:2.3:a:vmware:player:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.1.14`,
        fs:  `cpe:2.3:a:microsoft:active_directory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2`,
        fs:  `cpe:2.3:h:nortel:wlan_access_point_2221:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2.1`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.9:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2.3`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2.4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2.5`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2.6`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2.7`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.05.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.2.18`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_mse_series_software:4.1\(1.59\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.3`,
        fs:  `cpe:2.3:a:hp:care_pack_products:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.4`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.5`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.8`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.4:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.9`,
        fs:  `cpe:2.3:a:ca:unicenter_performance_management_for_openvms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.10`,
        fs:  `cpe:2.3:a:nobexrc:abc_lounge_webradio:3.3.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.11`,
        fs:  `cpe:2.3:h:cisco:hosting_solution_engine:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.12`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.13`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.14`,
        fs:  `cpe:2.3:a:tibco:spotfire_deployment_kit:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.15`,
        fs:  `cpe:2.3:a:tenable:nessus:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.16`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.16:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.17`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.18`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.23`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.17-66.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.24`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.25`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix_5570_controller_firmware:20.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicsmagick:graphicsmagick:1.3.26`,
        fs:  `cpe:2.3:a:hp:scanjet_8200_firmware:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphicstylus:north_american_ismaili_games:5.26.2::~~~android~~`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphisoft:archicad:13.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphisoft:archicad:14.0`,
        fs:  `cpe:2.3:a:cisco:resource_manager_essentials:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.2`,
        fs:  `cpe:2.3:a:actividentity:corestreet_desktop_validation_client:3.1.4.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.3`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.4.1:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.5`,
        fs:  `cpe:2.3:a:moderndecoration:interior_design:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.6`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.7`,
        fs:  `cpe:2.3:a:jenkins-ci:exclusion:0.7:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.8`,
        fs:  `cpe:2.3:a:osticket:osticket:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.9`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.10`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graphite_project:graphite:0.9.11`,
        fs:  `cpe:2.3:a:pushpinsapp:pushpins_grocery_coupons:1.56:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:graphon:go-global_ux:2.1.2`,
        fs:  `cpe:2.3:a:masquito2013:masquito_blogger:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:graphviz:graphviz:2.34.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.04.311:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grasshopper:grasshopper_beta:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.152.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grassroots_dicom_project:grassroots_dicom:2.6.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grassroots_dicom_project:grassroots_dicom:2.6.1`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gratta_%26_vinci%3f_project:gratta_%26_vinci%3f:0.21.13167.93474::~~~android~~`,
        fs:  `cpe:2.3:a:perl:perl:0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:graveydesign:gravey_design:0.58.13357.54919::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:word:98:sr2:mac_os:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:1.6.0`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:1.7.0`,
        fs:  `cpe:2.3:o:f5:tmos:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.336:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.6`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.7`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:15.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.8`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:11.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.9`,
        fs:  `cpe:2.3:a:php:php:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.10`,
        fs:  `cpe:2.3:a:logitech:setpoint:4.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.11`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.12`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:3.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.13`,
        fs:  `cpe:2.3:a:boopsie:anaheim_library_2go\!:4.5.110:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.14`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.15`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:17.009.20058:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.16`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.17`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.18`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.19`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.20`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:28.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.21`,
        fs:  `cpe:2.3:a:macromedia:flash_player:8.0.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.22`,
        fs:  `cpe:2.3:a:apache:tomcat:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:greenbone:greenbone_os:3.1.23`,
        fs:  `cpe:2.3:a:freedesktop:libdbus:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:0.8.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je029a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:0.8.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.82.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0:beta1`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0:beta2`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0:beta3`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0:beta4`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0:beta5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0:beta6`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0:beta7`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1671.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.0:rc1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.1`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:11:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.2`,
        fs:  `cpe:2.3:a:x:libxtst:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:1.0.3`,
        fs:  `cpe:2.3:a:microsoft:iis:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:2.0:beta1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.004:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:2.0:rc1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:2.0:rc3`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:2.0:rc4`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:2.0:rc5`,
        fs:  `cpe:2.3:a:water_wish:shop_love:1.05:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:2.0.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:2.0.1`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:2.0.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:beta1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:beta2`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:beta3`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:ccb:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:beta4`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:beta5`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:beta6`,
        fs:  `cpe:2.3:a:cisco:tac_plus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:beta7`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:beta8`,
        fs:  `cpe:2.3:a:autodesk:autocad:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0:rc1`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0.0`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.3:rev34390:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0.1`,
        fs:  `cpe:2.3:a:sympa:sympa:0.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0.2`,
        fs:  `cpe:2.3:h:hp:cc523a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:3.0.3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0:beta1`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0:beta2`,
        fs:  `cpe:2.3:o:yahama:rtx1200:10.01.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0:beta3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0:beta4`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0:beta5`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0:rc1`,
        fs:  `cpe:2.3:a:rsa:ace_server:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0.0`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0.1`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:4.0.3`,
        fs:  `cpe:2.3:a:vmware:infrastructure_update:2.5.0.64227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta1`,
        fs:  `cpe:2.3:a:webmin:usermin:1.410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta10`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta11`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.441.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta12`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta13`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p179:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta2`,
        fs:  `cpe:2.3:a:emc:rsa_data_loss_prevention:9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta3`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.66.27:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta4`,
        fs:  `cpe:2.3:a:atlassian:sourcetree:2.5c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta5`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta6`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta7`,
        fs:  `cpe:2.3:a:umn:mapserver:4.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta8`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0:beta9`,
        fs:  `cpe:2.3:a:iss:realsecure_network_sensor:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.1`,
        fs:  `cpe:2.3:a:serf_project:serf:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.2`,
        fs:  `cpe:2.3:a:perl:perl:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.3`,
        fs:  `cpe:2.3:a:cisco:webns:8.10.2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.4`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.5`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.24:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.568:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.7`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:5.0.8`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0:beta1`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:15.1t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0:beta3`,
        fs:  `cpe:2.3:h:hp:j9473a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0:beta4`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0:beta5`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.3en:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0:beta6`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.11.197:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(25e\)jam1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0.9`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0.10`,
        fs:  `cpe:2.3:a:tony_freixas:ubercart_product_keys:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0.11`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.0.12`,
        fs:  `cpe:2.3:a:meta_tags_quick_project:meta_tags_quick:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.1:beta1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.1:beta2`,
        fs:  `cpe:2.3:h:hp:500ps_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.1:beta3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_server:04-00-\/a:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:6.1:beta4`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:7.0.0`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2009:13.0.835.64:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:7.0.1`,
        fs:  `cpe:2.3:a:apache:log4j:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenbone:greenbone_security_assistant:7.0.2`,
        fs:  `cpe:2.3:o:f5:tmos:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenecosystem:ges_agri_connect:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:ektron:ektron_content_management_system:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:greenend:putty:0.63`,
        fs:  `cpe:2.3:a:hummingbird:exceed_on_demand_client:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grey%27s_anatomy_fan_project:grey%27s_anatomy_fan:3.7.2::~~~android~~`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.5.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.7.15`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.1`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(2\)sn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.4`,
        fs:  `cpe:2.3:a:ibm:java:5.0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.5`,
        fs:  `cpe:2.3:a:apple:apple_tv:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.6`,
        fs:  `cpe:2.3:a:veritas:backup_exec_remote_agent:9.1.4691:sp3:windows_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.7`,
        fs:  `cpe:2.3:a:apple:webkit:312.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.8`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.9`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:4.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.10`,
        fs:  `cpe:2.3:a:oracle:retail_applications:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.8.11`,
        fs:  `cpe:2.3:a:rpm:rpm:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.9.1`,
        fs:  `cpe:2.3:a:hp:sitescope_core:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.9.2`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.9.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.9.4`,
        fs:  `cpe:2.3:a:buffalotech:whr-amg54_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.9.5`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:1.9.6`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l16er-bb1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.0:ea1`,
        fs:  `cpe:2.3:a:symantec:reporting_agents:1.0.234.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.0:ea2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.0:ea3`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.0:ea4`,
        fs:  `cpe:2.3:a:mollify:mollify:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.0:ea5`,
        fs:  `cpe:2.3:a:ibm:java:5.0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:5.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.1:ea1`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.1:ea4`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.3.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.1:ea7`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.1:ea8`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.1:ea9`,
        fs:  `cpe:2.3:a:amazon_aws_project:amazon_aws:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.2:ea2`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.2:ea3`,
        fs:  `cpe:2.3:a:techsmith:snagit:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea10`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea11`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.11.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea12`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea13`,
        fs:  `cpe:2.3:a:python:python:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea14`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.22:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea15`,
        fs:  `cpe:2.3:a:gnome:glib:2.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea16`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea8`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.3:ea9`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.0.4:ea1`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.1`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.3:p1`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.3:p2`,
        fs:  `cpe:2.3:a:hp:virtualvault:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.3:p3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.3:p4`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.3:p5`,
        fs:  `cpe:2.3:o:juniper:screenos:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.4`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gridgain:gridgain:8.1.4:p1`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_user:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grillingwithrich:grilling_with_rich:1::~~~android~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.13:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gromada:multimedia_conversion_library:5.4.0`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grouperahal:karim_rahal_essoulami:1::~~~android~~`,
        fs:  `cpe:2.3:a:php:php:5.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groupon:groupon_merchants:-:-:~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.0:alpha-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:groupon:groupon_merchants:1.5.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.0:alpha4:~~~drupal~~`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:a.01.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.1:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert3:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:groups_communities_and_co_project:gcc:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:iconics:genesis32:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:grpc:grpc:1.1.2`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gsitecrawler:gsitecrawler:v1.23`,
        fs:  `cpe:2.3:a:ibm:infosphere_replication_server:10.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gslideshow_project:gslideshow:0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:06-70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.0`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.1`,
        fs:  `cpe:2.3:a:yahoo:messenger:7.0.0.437:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.2`,
        fs:  `cpe:2.3:o:yamaha:rt60w:5.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.5`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.5.5.577:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.7`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.8`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.9`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.10`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.11`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.17:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.12`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.13`,
        fs:  `cpe:2.3:a:symantec:veritas_commandcentral:5.2.2203.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.14`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.15`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.16`,
        fs:  `cpe:2.3:a:google:chrome:12.0.735.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.17`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:4.2\(1\)sv1\(5.1a\):-:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.18`,
        fs:  `cpe:2.3:a:mutiny:mutiny:5.0-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.19`,
        fs:  `cpe:2.3:a:opcsystems:opcsystems.net:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.20`,
        fs:  `cpe:2.3:o:suse:suse_united_linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.21`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.22`,
        fs:  `cpe:2.3:a:oracle:business_intelligence:11.1.1.9.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.23`,
        fs:  `cpe:2.3:a:xaos:space_cinema:2.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.24`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.25`,
        fs:  `cpe:2.3:a:novell:groupwise:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.26`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.27`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.28`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.29`,
        fs:  `cpe:2.3:a:kasper_skarhoj:accessible_is_browse_results:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.30`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.25:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.31`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.0.2_cf2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.32`,
        fs:  `cpe:2.3:a:citrix:ica_web_client:9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.33`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2010.211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.34`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.35`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gstreamer_project:gstreamer:0.10.36`,
        fs:  `cpe:2.3:a:pedestal:securityexpressions:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gsview:gsview:4.3`,
        fs:  `cpe:2.3:h:antlabs:inngate_ig_3.00_e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gsview:gsview:4.9`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gtk:gtk%2b:3.9.6`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gtk:gtk%2b:3.10.9`,
        fs:  `cpe:2.3:a:horde:imp:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gtopala:siw:1.68.626`,
        fs:  `cpe:2.3:a:microsoft:office:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.1`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.2`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.3`,
        fs:  `cpe:2.3:a:apple:remote_desktop:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.4`,
        fs:  `cpe:2.3:a:emc:documentum_webtop:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.5`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.4:bundle15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.6`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.3.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.7`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.99.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.7.1`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.7.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.7.3`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.7.4`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.7.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.7.6`,
        fs:  `cpe:2.3:a:matroska:libebml:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.8`,
        fs:  `cpe:2.3:a:apache:camel:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.9`,
        fs:  `cpe:2.3:a:timely:all-in-one_event_calendar:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guillaume_gauvrit:pyshop:0.9.1`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1\(3\)sr3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guitar-pro:guitar_pro:6.1.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:guitartuna:guitar_tuner_free_-_guitartuna:2.4.5::~~~android~~`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gummi_project:gummi:0.6.5`,
        fs:  `cpe:2.3:a:roxio:data_module:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gummybearstudios:ftp_drive_%2b_http_server:1.0.4`,
        fs:  `cpe:2.3:a:hp:openview_performance_agent:4.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gunbroker:gunbroker.com:1.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gunhillwireless:verizon:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gurock:testrail:3.1.1.3130`,
        fs:  `cpe:2.3:h:sagem:f\@st_2604:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gurock:testrail:3.1.3`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gwmicro:window-eyes:7.0`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gwmicro:window-eyes:7.5.2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gwos:groundwork_monitor:6.7.0:-:enterprise`,
        fs:  `cpe:2.3:h:cisco:spa_302d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:gwt_mobile_phonegap_showcase_project:gwt_mobile_phonegap_showcase:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h-dvisa:harley-davidson_visa:1.18::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h-fj:mt-phpincgi:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h2o_human_harmony_organization_project:h2o_human_harmony_organization:1.6.5::~~~android~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h2o_project:h2o:1.6.1`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h2o_project:h2o:1.7.0:beta2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h2o_project:h2o:1.7.2`,
        fs:  `cpe:2.3:a:netscreen:network_and_security_manager:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h2o_project:h2o:2.0.0:beta4`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h2o_project:h2o:2.0.3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h2o_project:h2o:2.1.0:beta2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc125b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:h3c:f1000-e_vpn_firewall:0235a26g`,
        fs:  `cpe:2.3:a:redhat:sysreport:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:h3c:s5820_secblade_vpn_firewall_module:0231a94j`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:h3c:s7500e_secblade_vpn_firewall_module:0231a832`,
        fs:  `cpe:2.3:h:supermicro:x7spe-hf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:h3c:s9500e_secblade_vpn_firewall_module:0231a0av`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h3c:secbladefw:5.20`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h3c:secpath1000fe:5.20`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution_assurance:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:h3c:sr66_gigabit_firewall_module:0231a88a`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:h3c:sr88_firewall_processing_module:0231a88l`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:h5ai_project:h5ai:0.24.1`,
        fs:  `cpe:2.3:a:hp:solution_center:100.0.175.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:halanew:sunnat_e_rasool:2::~~~android~~`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:halgame:dk_online_beta:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.3:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ham3d:ham3d_shop_engine:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hanabank:hanabank:4.06::~~~android~~`,
        fs:  `cpe:2.3:h:huawei:eudemon200:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hancom:hancom_office_2010_se:8.5.5`,
        fs:  `cpe:2.3:h:lexmark:25xxn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hancom:hancom_office_2014:9.1.0.2176`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_alshoff:minalic:2.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-1.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.0`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_server:6.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.1`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.2`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.4`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:6.06:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.5`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:2.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.6`,
        fs:  `cpe:2.3:a:microsoft:visual_c\#:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.7`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.8`,
        fs:  `cpe:2.3:h:buffalotech:whr-300hp2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.8:beta1`,
        fs:  `cpe:2.3:a:ibm:forms_viewer:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-3.0`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-3.0:beta1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)yt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-3.0:beta2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.386:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:7.x-3.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.1.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:7.x-3.0:beta1`,
        fs:  `cpe:2.3:a:fabasoft:fabasoft_cloud:3.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:7.x-3.0:beta2`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hans_nilsson:video_filter:7.x-3.x:dev`,
        fs:  `cpe:2.3:a:ibm:java:6.0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hansotools:hanso_player:2.1.0`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.4:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hansotools:hanso_player:2.5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haowanlab:qincard:2::~~~android~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hapijs:crumb:2.2.0::~~~node.js~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happycloud:happy:2::~~~android~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happylabs:hotel_story%3a_resort_simulation:1.7.9b::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:0.2.1:beta`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_access_control_list_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:0.2.2:beta`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:eby:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:0.2.3:beta`,
        fs:  `cpe:2.3:a:silanis:approveit_lotus_fix:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:0.2.4:beta`,
        fs:  `cpe:2.3:h:intel:mobile_intel_pm45_express_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:0.2.5:beta`,
        fs:  `cpe:2.3:a:pandasecurity:panda_gold_protection:7.01.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:1.0.0`,
        fs:  `cpe:2.3:a:acronis:true_image_echo_workstation:9.7.8206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:1.1.0`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:1.1.1`,
        fs:  `cpe:2.3:a:intercom:web_kyukincho:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:1.2.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.0`,
        fs:  `cpe:2.3:a:netscape:proxy_server:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.1`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.2`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(23\)s5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.4`,
        fs:  `cpe:2.3:a:automon:alisha_marie:1.4.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.5`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.6`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.7`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.8`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.9`,
        fs:  `cpe:2.3:a:sympa:sympa:2.7b.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.10`,
        fs:  `cpe:2.3:a:hp:creativeprojects_atenashokunin1config:45.4.131.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.11`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.12`,
        fs:  `cpe:2.3:a:k7computing:anti-virus_plus:14.2.0.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.14`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.15`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.16`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.17`,
        fs:  `cpe:2.3:a:microsoft:access:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.18`,
        fs:  `cpe:2.3:a:hp:my_print_mileage:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.19`,
        fs:  `cpe:2.3:a:mod_nss_project:mod_nss:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.20`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.21`,
        fs:  `cpe:2.3:a:webmin:usermin:0.990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.22`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.23`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.24`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.25`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:4.0:*:*:*:*:*:rsg2488:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.26`,
        fs:  `cpe:2.3:a:adobe:illustrator:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.27`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.28`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.29`,
        fs:  `cpe:2.3:a:analogx:proxy:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.30`,
        fs:  `cpe:2.3:a:gnu:ed:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.31`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.32`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.33`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.34`,
        fs:  `cpe:2.3:a:suse:suse_linux_openexchange_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.35`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.0.36`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.1.0`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.1.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.1.2`,
        fs:  `cpe:2.3:a:embedthis:goahead:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.1.3`,
        fs:  `cpe:2.3:h:supermicro:x9sbaa-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.1.4`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.1.5`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.894:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.1.6`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.638:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.1`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.2`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.2.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.3`,
        fs:  `cpe:2.3:a:google:chrome:14.0.802.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.4`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.5`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.6.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.6`,
        fs:  `cpe:2.3:a:oracle:communications_service_broker:6.0:*:*:*:engineered_system:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.7`,
        fs:  `cpe:2.3:o:ibm:xiv_storage_system_gen3_firmware:11.1.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.8`,
        fs:  `cpe:2.3:a:samba:samba:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.9`,
        fs:  `cpe:2.3:a:perl:perl:5.12.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.10`,
        fs:  `cpe:2.3:a:pixman:pixman:0.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.11`,
        fs:  `cpe:2.3:a:nero:vision:6.0.6.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.12`,
        fs:  `cpe:2.3:a:redhat:rhel_application_stack:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.13`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.14`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.15`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.17`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.1.3.6323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.18`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.19`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.20`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.21`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.22`,
        fs:  `cpe:2.3:a:att:labs\&#39;_natural_voices_desktop_redist:1.4.0916:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.23`,
        fs:  `cpe:2.3:o:honeywell:midas_firmware:1.13b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.24`,
        fs:  `cpe:2.3:a:netscape:navigator:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.2.25`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.0`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma092xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.2`,
        fs:  `cpe:2.3:o:f5:tmos:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.4`,
        fs:  `cpe:2.3:h:cisco:asr_1002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.5`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.7.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.6`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.8`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.9`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.10`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.3.11`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:happyworm:jplayer:2.4.0`,
        fs:  `cpe:2.3:o:novell:suse_linux:10:*:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.54:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.0`,
        fs:  `cpe:2.3:a:novell:groupwise_messenger:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.1`,
        fs:  `cpe:2.3:a:appthemes:classipress:3.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.2`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.3`,
        fs:  `cpe:2.3:h:d-link:dir-600l:b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.4`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.5`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.6`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.7`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.8`,
        fs:  `cpe:2.3:a:perl:perl:0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.9`,
        fs:  `cpe:2.3:h:3com:3c250100a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.10`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.11`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.13`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.14`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.15`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.16`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.17`,
        fs:  `cpe:2.3:a:hp:storageworks_command_view_xp:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.18`,
        fs:  `cpe:2.3:a:rockwellautomation:factorytalk_services_platform:cpr9:sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.19`,
        fs:  `cpe:2.3:a:microsoft:subsystem_for_unix-based_applications:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.20`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.11:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.21`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.22`,
        fs:  `cpe:2.3:h:hp:storageworks_p2000_g3_sas_msa_dual_controller_lff_array_system:aw593a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.23`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.4.24`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.24:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev0`,
        fs:  `cpe:2.3:a:kmart:kmart:\@7f0c00ef:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev1`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev10`,
        fs:  `cpe:2.3:h:hp:digital_sender_9100c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev11`,
        fs:  `cpe:2.3:o:cisco:catos:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev12`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev13`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev14`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev15`,
        fs:  `cpe:2.3:h:cisco:spa_514g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev16`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev17`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev18`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev19`,
        fs:  `cpe:2.3:a:nttdocomo:overseas_usage:2.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev2`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev4`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.335.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev6`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev7`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:10.01.1740:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev8`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haproxy:haproxy:1.5:dev9`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp1:datacenter_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:-:beta_2006.09.07`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:-:beta_2006.09.09`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ez2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.1`,
        fs:  `cpe:2.3:a:microsoft:hotmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.2`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.4`,
        fs:  `cpe:2.3:a:spip:spip:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.5`,
        fs:  `cpe:2.3:a:apache:solr:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.6`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.6.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.6.2`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.6.3`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.7`,
        fs:  `cpe:2.3:a:process-one:ejabberd:3.0.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.8`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.9`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.9.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.10`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:b6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.11`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpx130:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.12`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.13`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.14`,
        fs:  `cpe:2.3:a:spip:spip:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.15`,
        fs:  `cpe:2.3:a:rarlab:winrar:4.1.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.16`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.17`,
        fs:  `cpe:2.3:a:ibm:cognos_business_intelligence:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.18`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.19`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:3.0\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.20`,
        fs:  `cpe:2.3:a:apple:cups:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.21`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.22`,
        fs:  `cpe:2.3:a:just-great-software:powergrep:demo_3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.23`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.24`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.25`,
        fs:  `cpe:2.3:o:ibm:os_400:v4r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.26`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.0\(1\)su1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.27`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.28`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.29`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.30`,
        fs:  `cpe:2.3:a:hp:sitescope_user_interface:11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.31`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hardened-php:suhosin:0.9.33`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haremthief:harem_thief_dating:1.2.1::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil\%2fx86_firmware:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:harfbuzz_project:harfbuzz:1.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:harfbuzz_project:harfbuzz:1.0.5`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:harman:amx_firmware:1.2.322`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.25.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:harman:amx_firmware:1.3.100`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:harmonizers_planet_project:harmonizers_planet:2.3.4::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:harris:intraplex_intralink-ip:-`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:harris:stat_guardian_vms:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:harris:stat_guardian_vms:6.4.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:harris:stat_scanner:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:harris:stat_scanner:5.4`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:251:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:harvestyourdata:droid_survey_offline_forms:2.5.2::~~~android~~`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hasb_e_haal_project:hasb_e_haal:1.0.9::~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p314:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.1.1`,
        fs:  `cpe:2.3:a:symantec:on-demand_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.1.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.5`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.6`,
        fs:  `cpe:2.3:a:microsoft:excel_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.8`,
        fs:  `cpe:2.3:a:emc:rsa_archer_smartsuite:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.9`,
        fs:  `cpe:2.3:a:filesland:open_ports_scanner:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.9.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.9.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0sp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.9.5`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.4369-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.9.8`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:0.9.9`,
        fs:  `cpe:2.3:a:intra-mart:webplatform\/appframework:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.1.2`,
        fs:  `cpe:2.3:a:dell:client_configuration_toolkit:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.2`,
        fs:  `cpe:2.3:h:huawei:ma5200g:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.3.1`,
        fs:  `cpe:2.3:a:posh_project:posh:2.2:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.4`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.5`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.6`,
        fs:  `cpe:2.3:a:givenu:givenu_give:1.5.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.6.1`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.6.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.6.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.6.4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.7`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.7.1`,
        fs:  `cpe:2.3:o:cisco:rvs4000_firmware:1.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.7.2`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.7.3`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.7.4`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.8`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.8.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.8.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:1.9`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.783.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.0.1`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.0.2`,
        fs:  `cpe:2.3:a:advanced_forum_signatures_project:advanced_forum_signatures:2.0.4:*:*:*:*:mybb:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.0.3`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.1`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.1.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.1.2`,
        fs:  `cpe:2.3:a:softerra:ldap_administrator:3.3.1.1461:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.1.3`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_express:11.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.0_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.2.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.2.2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.2.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.3`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.3:rc1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.3:rc2`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.3:rc3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.5.0`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.5.1`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.5.2`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.5.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.5.4`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:7.02.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.6.0`,
        fs:  `cpe:2.3:a:idera:uptime_infrastructure_monitor:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.7.0`,
        fs:  `cpe:2.3:a:roxio:express_labeler:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.7.1`,
        fs:  `cpe:2.3:h:huawei:s12712:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.7.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.8.0`,
        fs:  `cpe:2.3:a:oracle:configurator:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.9.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.9.1`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:2.9.2`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:3.0.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:3.1.0`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:p04-0018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haudenschilt:family_connections_cms:3.1.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hawk_project:hawk:3.1.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.260.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hawk_project:hawk:4.1.0`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.5\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.1:beta`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.21:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.2`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.3.1`,
        fs:  `cpe:2.3:h:fortinet:fortigate-5060:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.4`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.5`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.5.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:6.5.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.1`,
        fs:  `cpe:2.3:h:xerox:workcentre_m45:4.84.16.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.1.1`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.2`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.2.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.3`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.8:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.4`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp1:tablet_pc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.4.2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.5.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.5.2`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.6`,
        fs:  `cpe:2.3:a:gnu:glibc:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.6.1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.7`,
        fs:  `cpe:2.3:a:macromedia:flash_player:9.0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.7.1`,
        fs:  `cpe:2.3:a:apache:poi:3.0.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.7.2`,
        fs:  `cpe:2.3:a:agnitum:outpost_security_suite:7.0.3330.505.1221:beta:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.7.3`,
        fs:  `cpe:2.3:h:astaro:security_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.8`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.8.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9`,
        fs:  `cpe:2.3:h:polycom:recording_and_streaming_server_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9.1`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.10:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9.2`,
        fs:  `cpe:2.3:a:joachim_ruhs:locator:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9.3`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.0.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9.4`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9.5`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.3:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9.6`,
        fs:  `cpe:2.3:a:sun:java_system_directory_proxy_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9.7`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.9.8`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.48:betas:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.269:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10.4`,
        fs:  `cpe:2.3:a:pinnaclesys:studio:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10.5`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10.6`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10.7`,
        fs:  `cpe:2.3:a:axway:email_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.10.8`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.11.0`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1.4:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.11.1`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc11:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.11.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.12.0`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.12.1`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.12.2`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.12.3`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.7:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.13.0`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.13.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.13.2`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.14.0`,
        fs:  `cpe:2.3:a:apple:itunes:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.14.1`,
        fs:  `cpe:2.3:o:d-link:dsr-250n_firmware:1.08b31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.15.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.15.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.15.2`,
        fs:  `cpe:2.3:a:gnu:zlib:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.15.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.15.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.15.5`,
        fs:  `cpe:2.3:h:cisco:catalyst_6500_ws-x6380-nam:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.16.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.16.1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.16.7:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.16.2`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.2.11:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.16.3`,
        fs:  `cpe:2.3:a:ibm:powerkvm:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.16.4`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.17.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.17.1`,
        fs:  `cpe:2.3:a:pimcore:pimcore:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.18.0`,
        fs:  `cpe:2.3:h:grandstream:gxv3615wp_hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.18.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.18.2`,
        fs:  `cpe:2.3:a:iss:realsecure_server_sensor:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.19.0`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.19.1`,
        fs:  `cpe:2.3:a:vmware:fusion:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.19.2`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.19.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.19.4`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.13:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.19.5`,
        fs:  `cpe:2.3:a:pcre:pcre:8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.19.6`,
        fs:  `cpe:2.3:a:jan_bednarik:cooluri:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.19.7`,
        fs:  `cpe:2.3:a:bandoo:savevid_plug-in:2.0.0.107556:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.20.0`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:365.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.20.1`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.21.0`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.21.1`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.21.2`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.1.4380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.21.3`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.21.4`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_vpn_security_management_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.21.5`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.21.6`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.21.7`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.22.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.23.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.23.1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.13.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.24.0`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.25.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.26.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)ys:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.27.0`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.28.0`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.28.1`,
        fs:  `cpe:2.3:o:cisco:mds_9000_nx-os:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.29.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.30.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.31.0`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.5.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.32.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.33.0`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.34.0`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.35.0`,
        fs:  `cpe:2.3:a:ansys:ls-dyna:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.36.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.38.0`,
        fs:  `cpe:2.3:a:php:errordocs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.39.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.40.0`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.41.0`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.42.0`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.42.1`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.43.0`,
        fs:  `cpe:2.3:a:apple:safari:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.44.0`,
        fs:  `cpe:2.3:a:google:sketchup:8.0:maintenance_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.45.0`,
        fs:  `cpe:2.3:o:cisco:broadband_operating_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.46.0`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1102.101.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.47.0`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.47.1`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.48.0`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.8:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.49.0`,
        fs:  `cpe:2.3:a:vandyke:securefx:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.49.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.50.0`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.82\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.50.1`,
        fs:  `cpe:2.3:a:rpm:rpm:4.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.50.2`,
        fs:  `cpe:2.3:a:wdc:fat32_formatter:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.50.3`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.51.0`,
        fs:  `cpe:2.3:a:hp:device_discovery:140.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.52.0`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.52.1`,
        fs:  `cpe:2.3:a:opscode:chef:0.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.53.0`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.53.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.91.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:curl:7.54.1`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.0`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.1`,
        fs:  `cpe:2.3:a:microsoft:xml_parser:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.1:beta`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.2`,
        fs:  `cpe:2.3:h:linksys:wap11:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.3`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.3.1`,
        fs:  `cpe:2.3:o:juniper:junos_m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.4`,
        fs:  `cpe:2.3:a:vmware:vsphere_update_manager_client:5.0.0.8039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.5`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.5.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:6.5.2`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.1.1`,
        fs:  `cpe:2.3:a:visionsolutions:double-take:4.3.0.0.1170.s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.2`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.2.1`,
        fs:  `cpe:2.3:a:phorum:phorum:5.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.4`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.4.1`,
        fs:  `cpe:2.3:a:feeds_project:feeds:7.x-2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.4.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.5`,
        fs:  `cpe:2.3:a:lester_chan:wp-downloadmanager:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.5.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.5.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.6`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.6.1`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.7`,
        fs:  `cpe:2.3:a:microsoft:windows_movie_maker:2.1.4026.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.7.1`,
        fs:  `cpe:2.3:a:cloudwords:cloudwords_for_multilingual:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.7.2`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.370:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.7.3`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.8`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.8.1`,
        fs:  `cpe:2.3:a:exiv2:exiv2:0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_provisioning:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9.2`,
        fs:  `cpe:2.3:a:novell:suse_audit_log_keeper:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9.3`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9.4`,
        fs:  `cpe:2.3:a:canonical:php5:5.3.5-1ubuntu7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9.5`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.4_build_44386:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9.6`,
        fs:  `cpe:2.3:a:rockwellautomation:integrated_architecture_builder:9.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9.7`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.9.8`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:7.x-1.3:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10.2`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:7.0:*:hp_ux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10.3`,
        fs:  `cpe:2.3:a:isc:bind:8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10.4`,
        fs:  `cpe:2.3:a:ipswitch:imail:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10.5`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10.6`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10.7`,
        fs:  `cpe:2.3:a:citrix:web_interface:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.10.8`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.11.0`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.11.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.11.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.12.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.12.1`,
        fs:  `cpe:2.3:a:displaylink:displaylink_graphics:6.0.33809.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.12.2`,
        fs:  `cpe:2.3:h:hp:laserjet_p2055:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.12.3`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.13.0`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.13.1`,
        fs:  `cpe:2.3:a:vmware:workstation:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.13.2`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.14.0`,
        fs:  `cpe:2.3:a:phplist_integration_project:phplist_integration:6.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.14.1`,
        fs:  `cpe:2.3:a:gnome:screensaver:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.15.0`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.7:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.15.1`,
        fs:  `cpe:2.3:a:microsoft:psgetsid:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.15.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120701:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.15.3`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.15.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.3:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.15.5`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.16.0`,
        fs:  `cpe:2.3:a:spice_project:spice:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.16.1`,
        fs:  `cpe:2.3:a:ca:etrust_audit_policy_manager:1.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.16.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_4d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.16.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.16.4`,
        fs:  `cpe:2.3:a:hp:document_viewer:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.17.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.17.1`,
        fs:  `cpe:2.3:a:buffalotech:wzr2-g300n_firmware:1.50:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.18.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.18.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_performance_manager:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.18.2`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.19.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.19.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.19.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.19.3`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.19.4`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.19.5`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf817a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.19.6`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.3103.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.19.7`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.20.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.20.1`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3610-28f_ls-3610-28f-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.21.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.21.1`,
        fs:  `cpe:2.3:a:ucdok:tomato:0.0.5:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.21.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.21.3`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.21.4`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.21.5`,
        fs:  `cpe:2.3:a:oxwall:oxwall:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.21.6`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.21.7`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.6_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.22.0`,
        fs:  `cpe:2.3:a:nginx:nginx:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.23.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.23.1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.992_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.24.0`,
        fs:  `cpe:2.3:a:microsoft:ie:7.00.6000.16441:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.25.0`,
        fs:  `cpe:2.3:a:ipswitch:imail:8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.26.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.27.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_common_reporting:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.28.0`,
        fs:  `cpe:2.3:a:oracle:jd_edwards_products:8.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.28.1`,
        fs:  `cpe:2.3:a:encardirect:sk_encar:\@7f050000:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.29.0`,
        fs:  `cpe:2.3:a:vips:vips:7.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.30.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.31.0`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.9:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.32.0`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.33.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.34.0`,
        fs:  `cpe:2.3:o:huawei:s5310hi_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.35.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.36.0`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:0.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.37.0`,
        fs:  `cpe:2.3:o:huawei:ips_module_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.37.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-02:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.38.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.0.1679:online_windows_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.39`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6a:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.40.0`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.41.0`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.42.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.42.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.43.0`,
        fs:  `cpe:2.3:o:redhat:directory_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.44.0`,
        fs:  `cpe:2.3:a:horde:gollem:1.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.45.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.46.0`,
        fs:  `cpe:2.3:h:cisco:multiservice_platform_2650xm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.47.0`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.47.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.48.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.49.0`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.49.1`,
        fs:  `cpe:2.3:a:dukapress_project:dukapress:2.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.50.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.50.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.50.2`,
        fs:  `cpe:2.3:a:zencast:zencast:1.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.50.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.51.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.52.0`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:7.0.2:mr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.52.1`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.53.0`,
        fs:  `cpe:2.3:a:jetbrains:omea_reader:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.53.1`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.0.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.54.0`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.54.1`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.55.0`,
        fs:  `cpe:2.3:a:gnu:cfengine:1.5.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:haxx:libcurl:7.55.1`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hbgary:hbgary_agent:1.5.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hccgmbh:mycare2x:-`,
        fs:  `cpe:2.3:a:apache:openoffice.org:3.4:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hdcar:exercitii_pentru_abdomen:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hdw-tube_project:hdw-tube:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:web2py:web2py:1.86.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hdwplayer:hdw-player-video-player-video-gallery:2.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.01:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:headlightinc:getright:6.1`,
        fs:  `cpe:2.3:a:fedex:ship_manager_server:10.63.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:headlines_news_india_project:headlines_news_india:0.21.13219.95110::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:health:how_to_boil_eggs:251333::~~~android~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:healthadvocate:health_advocate_smarthelp:3.6::~~~android~~`,
        fs:  `cpe:2.3:a:apache:activemq:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:healthways:well-being_connect_mobile:2.9::~~~android~~`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heartlogic.jp:hl-sitemanager:0.50`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1674.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heartlogic.jp:hl-sitemanager:0.70`,
        fs:  `cpe:2.3:a:hp:6300_help:70.0.231.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heartlogic.jp:hl-sitemanager:0.71`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:b5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heartlogic.jp:hl-sitemanager:1.00`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heat-trakr_project:heat-trackr:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heaventools:pe_explorer:1.99.6`,
        fs:  `cpe:2.3:a:pineapp:mail-secure_5099sk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heikki_hokkanen:viewgit:0.0.1`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:9.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heikki_hokkanen:viewgit:0.0.2`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heikki_hokkanen:viewgit:0.0.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heikki_hokkanen:viewgit:0.0.4`,
        fs:  `cpe:2.3:o:oracle:opus_10g_ethernet_switch_family:2.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heikki_hokkanen:viewgit:0.0.5`,
        fs:  `cpe:2.3:a:hummingbird:hostexplorer:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heikki_hokkanen:viewgit:0.0.6`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heiko_sudar:slideshare:0.1.0`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2-p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0j`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:4.0:unknown:unknown:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0k`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0l`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0m`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0n`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0o`,
        fs:  `cpe:2.3:a:boost:boost:1.57.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0p`,
        fs:  `cpe:2.3:a:logilab:logilab-common:0.59.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0q`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0r`,
        fs:  `cpe:2.3:a:skype:skype:1.3.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0s`,
        fs:  `cpe:2.3:a:documentcloud:karteek-docsplit:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0t`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.0u`,
        fs:  `cpe:2.3:h:netgear:d3600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1a`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1b`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1c`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1d`,
        fs:  `cpe:2.3:a:augeas:augeas:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1e`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.8p12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1f`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1g`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1h`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1i`,
        fs:  `cpe:2.3:a:macromedia:flash_player:7.0.61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1j`,
        fs:  `cpe:2.3:a:ronan_dowling:node_hierarchy:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1k`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1l`,
        fs:  `cpe:2.3:a:bundler:bundler:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.1m`,
        fs:  `cpe:2.3:a:milesj:decoda:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2a`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2b`,
        fs:  `cpe:2.3:a:google:chrome:11.0.667.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2c`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2d`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_500-32:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2e`,
        fs:  `cpe:2.3:a:ati:catalyst_registration:3.00.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2f`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.415:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2g`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2h`,
        fs:  `cpe:2.3:a:altimatech:netzoom:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2i`,
        fs:  `cpe:2.3:a:intel:mlogview:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2j`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.13:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2k`,
        fs:  `cpe:2.3:a:woocommerce:woocommerce:2.6.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2l`,
        fs:  `cpe:2.3:a:apache:struts:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2m`,
        fs:  `cpe:2.3:a:cws:sahab-alkher.com:2.4.9.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2n`,
        fs:  `cpe:2.3:a:apache:subversion:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2o`,
        fs:  `cpe:2.3:a:conky:conky:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2p`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2q`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2r`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2s`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.2t`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:5.1:r1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.3a`,
        fs:  `cpe:2.3:a:microsoft:windows_event_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.3b`,
        fs:  `cpe:2.3:a:nagios:nagios:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.3c`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.3d`,
        fs:  `cpe:2.3:a:status:statusnet:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.3e`,
        fs:  `cpe:2.3:a:cisco:as5800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.3f`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.4.d`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.4.e`,
        fs:  `cpe:2.3:h:cisco:unified_sip_phone_3951:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.4.f`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)xc4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.4a`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.4b`,
        fs:  `cpe:2.3:a:agi:stk:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.4c`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.5`,
        fs:  `cpe:2.3:a:adways:party_track_sdk:1.6.5:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.5.2`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.5.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.6`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.6.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.6.2`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.6.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.6.4`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.6.5`,
        fs:  `cpe:2.3:a:microsoft:windows_98_plus_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.6.6`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.7.1`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.7.2`,
        fs:  `cpe:2.3:h:turck:bl67_programmable_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.8`,
        fs:  `cpe:2.3:a:digium:asterisk:13.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.8.1`,
        fs:  `cpe:2.3:a:horde:groupware:1.0.5:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:0.9:rc1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:sv:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.0.0`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.0.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_common_reporting:3.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.1.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_virtualization_manager:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.2.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.2.1`,
        fs:  `cpe:2.3:a:lightwitch:metronome:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0`,
        fs:  `cpe:2.3:a:hp:openview_report:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre1`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_m1212nf_mfp:ce841a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre10`,
        fs:  `cpe:2.3:a:kent-web:clip_board:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre11`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre2`,
        fs:  `cpe:2.3:a:ibm:egatherer:2.42.243:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre3`,
        fs:  `cpe:2.3:o:google:android:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre4`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre5`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre6`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.4:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre7`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre8`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r16.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:pre9`,
        fs:  `cpe:2.3:a:janetter:janetter:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.0:rc1`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.1`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.1:rc1`,
        fs:  `cpe:2.3:a:cgi:hotscan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.2`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.2:rc1`,
        fs:  `cpe:2.3:a:kde:kde-workspace:4.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.2:rc2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.2:rc3`,
        fs:  `cpe:2.3:a:emc:documentum_records_manager:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.2:rc4`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.3`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.3.3:rc1`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.4.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.4.1:rc1`,
        fs:  `cpe:2.3:a:microsoft:outlook:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.4.1:rc2`,
        fs:  `cpe:2.3:a:ireadercity:100_books:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.5.0`,
        fs:  `cpe:2.3:a:gnu:automake:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.5.0:pre1`,
        fs:  `cpe:2.3:h:ibm:iss_proventia_network_ips:gx5008:1.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.5.0:pre2`,
        fs:  `cpe:2.3:a:hp:scan:11.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.5.0:rc1`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.5.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.1:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.5.2`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.5.3`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:8.5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.6.0:rc1`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.18.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:1.6.0:rc2`,
        fs:  `cpe:2.3:a:oracle:jdeveloper:10.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.0.1`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.0.2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.50:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(14\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.1.0`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.1.0:rc1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.2.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.3.0`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2000_datacenter:6.2.904:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.4.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heimdal_project:heimdal:7.5.0`,
        fs:  `cpe:2.3:o:gentoo:linux:1.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.50`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.009.20069:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.51`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd431a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.52`,
        fs:  `cpe:2.3:h:cisco:asr_1001:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.53`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.54`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.9:bundle3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.55`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.56`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.57`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.58`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.59`,
        fs:  `cpe:2.3:a:nortel:media_communication_server_5200:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.60`,
        fs:  `cpe:2.3:a:apache:cxf:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.61`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.62`,
        fs:  `cpe:2.3:a:logitech:videocall\&#43;webcamxmp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.63`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.64`,
        fs:  `cpe:2.3:a:dlink:dwl-3200ap_firmware:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.65`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.66`,
        fs:  `cpe:2.3:a:okb.co.jp:smartphone_passbook:1.00:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.67`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.68`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.69`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.70`,
        fs:  `cpe:2.3:a:x:libxt:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.71`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.72`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_mauelshagen:lvm2:2.02.73`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heinz_richter:mod_auth_mda:2.0`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_server:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heirloom:mailx:12.5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heliconsoft:isapi_rewrite_lite:2.15.78`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.9:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:heliconsoft:isapi_rewrite_lite:3.1.85`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:helios:textpad:4.7.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:helios:textpad:5.0.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:helios:textpad:5.2.0`,
        fs:  `cpe:2.3:a:pcre:pcre:8.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:helios:textpad:5.3.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.942.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:helios:textpad:5.4.0`,
        fs:  `cpe:2.3:h:3com:3c17401:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:helios:textpad:5.4.2`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_portal_server:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henk:git_extensions:2.17`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.15s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henner_zeller:henplus:0.3.2`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henner_zeller:henplus:0.3.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus\/opentp1_web_web_front-endset:02-70-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henner_zeller:henplus:0.9`,
        fs:  `cpe:2.3:a:microsoft:content_management_server:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henner_zeller:henplus:0.9.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.17:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henner_zeller:henplus:0.9.4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.95:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henner_zeller:henplus:0.9.5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henner_zeller:henplus:0.9.7`,
        fs:  `cpe:2.3:a:compaq:easy_access_keyboard_software:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henner_zeller:henplus:0.9.8`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_platform_emulator:3.0\(2c\)a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.3`,
        fs:  `cpe:2.3:a:pinssible:phonegram_-_instagram_download:1.9.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.4`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.0:beta-3:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.6`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5611:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.7`,
        fs:  `cpe:2.3:a:ibm:powerkvm:2.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.825.2145.37182:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.9`,
        fs:  `cpe:2.3:h:hp:jg785a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.10`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass_guest:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.11`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.5.13`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.6`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.6.1`,
        fs:  `cpe:2.3:a:adobe:experience_manager:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.6.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.7.0`,
        fs:  `cpe:2.3:a:cisco:server_provisioner:6.4.0:patch_2-1112122225:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.8.0`,
        fs:  `cpe:2.3:a:phillip_lougher:squashfs:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.8.1`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.8.2`,
        fs:  `cpe:2.3:a:trendmicro:hijackthis:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.0`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.15:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.1`,
        fs:  `cpe:2.3:a:ibm:websphere_caching_proxy_server:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.2`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.4`,
        fs:  `cpe:2.3:a:hp:cards_calendar_ordergift_domoreplugout:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.6`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.6.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:05-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.7`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-451c_firmware:t410sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.7.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.8`,
        fs:  `cpe:2.3:a:plone:plone:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.9`,
        fs:  `cpe:2.3:a:emc:avamar:6.1.100-333:-:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:henri_wahl:nagstamon:0.9.10`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.1:pre`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.2`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.3`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.4.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.3.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.4`,
        fs:  `cpe:2.3:o:redhat:certificate_server:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.4.1`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.6`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.7`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.8`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.9`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:0.9.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:1.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.23:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:1.0:rc1`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:1.0:rc2`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.2.1.6506:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:1.0:rc3`,
        fs:  `cpe:2.3:a:google:sketchup:8.0:maintenance_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:1.0:rc4`,
        fs:  `cpe:2.3:a:nero:neronet:1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:1.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herac:tuxguitar:1.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herbs_%26_flowers_dictionary_project:herbs_%26_flowers_dictionary:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20100920:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hermanmiller:cad_pack_for_north_america:5.0.0`,
        fs:  `cpe:2.3:a:dell:powervault_ml6000_firmware:590g.gs00100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hero-maps-pro_project:hero-maps-pro:2.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herpin_time_radio_project:herpin_time_radio:2::~~~android~~`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.0.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p184:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:david_king:vino:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:mibizapps:absolute_lending_solutions:1.0073.b0073:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.7::~~~ruby~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.8::~~~ruby~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.9::~~~ruby~~`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0.0:p195:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.10::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.11::~~~ruby~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.2:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.12::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.13::~~~ruby~~`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1284.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.1.14::~~~ruby~~`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:1.5\(.1.131\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:flyfishing-and-flytying:fly_fishing_\&amp;_fly_tying:3.21.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:pass4sure:questions_and_answers_for_cisco_640-816:5.0.13021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:cherrypy:cherrypy:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.7::~~~ruby~~`,
        fs:  `cpe:2.3:a:jig:movatwitouch:1.793:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.8::~~~ruby~~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.11.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.9::~~~ruby~~`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.2.10::~~~ruby~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.19a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.1::~~~ruby~~`,
        fs:  `cpe:2.3:o:juniper:junos:12.1r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.3:*:smart:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:apache:sentry:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.7::~~~ruby~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.8::~~~ruby~~`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.9::~~~ruby~~`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.3.10::~~~ruby~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p192:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:posh_project:posh:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.1::~~~ruby~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.2::~~~ruby~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:3.0\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:9.1:bundle4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:1529:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.7::~~~ruby~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.8::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.9::~~~ruby~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.10::~~~ruby~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.11::~~~ruby~~`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.13:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.12::~~~ruby~~`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.13::~~~ruby~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.14::~~~ruby~~`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1517f-3_pn\/dp_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:herry:sfpagent:0.4.15::~~~ruby~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hesk:hesk:2.4.0`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.60.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hex-rays:ida:6.6::~~pro~~~`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_apollo_ecwp:13.00.0000:-:~~~chrome~~`,
        fs:  `cpe:2.3:a:bigfix:discovery_platform:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_apollo_ecwp:13.00.0000:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:drupal:drupal:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_apollo_ecwp:13.00.0000:-:~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_apollo_ecwp:13.00.0001:-:~~~chrome~~`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.5\(2\)_sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_apollo_ecwp:13.00.0001:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_apollo_ecwp:13.00.0001:-:~~~internet_explorer~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.237.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_er_viewer:11.04`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_er_viewer:13.00.0001`,
        fs:  `cpe:2.3:a:justin_ellison:node_gallery:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_er_viewer:13.0.1.1298`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.04:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexagon:erdas_er_viewer:13.0.1.1301`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hexchat_project:hexchat:2.11.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hi-tech_software:c_compiler_for_the_pic10%2f12%2f16_mcus:9.81`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.977:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.00`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.01`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.01:a`,
        fs:  `cpe:2.3:a:apache:axis2:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.02`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.03`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.04`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.10`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.11`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.12`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.13`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.7000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.20`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.21`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc2300:a6898a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.22`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.30`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.31`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.22:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.32`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p185:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.33`,
        fs:  `cpe:2.3:a:ca:output_management_web_viewer:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.34`,
        fs:  `cpe:2.3:a:hp:scan:9.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.35`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.40`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.41`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.42`,
        fs:  `cpe:2.3:h:intel:entry_server_platform_sr1325tp1-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.50`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hidemaru:editor:8.51`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hideyuki_chikada:perltreebbs:2.30`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hideyuki_chikada:perltreebbs:2.31`,
        fs:  `cpe:2.3:a:apache:wicket:6.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:frame:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:videowhisper:live_streaming_integration_plugin:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.8::~~~drupal~~`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hierarchial_select_project:hierarchical_select:6.x-3.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:highlighterstudio:vineyard_all_in:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.6:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hijabmodern:hijab_modern:1.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)mx1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hillside_project:hillside:1.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(18\)sl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiniarata:casebook_plugin:0.9.3::~~~basercms~~`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hioa:student_id:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiox:hiox_guest_book:5.0`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.0.0`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.0.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.0.2`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.1.0`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.2.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.3.0`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.3.1`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_foundation:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.3.2`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.10.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:3.12`,
        fs:  `cpe:2.3:h:fox-it:fox_datadiode:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hippostudio:hippo_studio:1::~~~android~~`,
        fs:  `cpe:2.3:a:emc:vipr_srm:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:06-00`,
        fs:  `cpe:2.3:a:aprelium:abyss_web_server_x1:2.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:06-01`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:06-01%2fa`,
        fs:  `cpe:2.3:a:pinnaclesys:rapid:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:07-00`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:07-01`,
        fs:  `cpe:2.3:a:ca:etrust_security_command_center:8:sp1:cr1:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:07-01%2fa`,
        fs:  `cpe:2.3:a:ubi:rayman_legends:1.3.140380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:08-00`,
        fs:  `cpe:2.3:a:fabricio_zuardi:xspf_player_plugin:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:08-00%2fa`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_iris_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option:08-00%2fb`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option_server:07-00`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option_server:07-01`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option_server:07-01%2fa`,
        fs:  `cpe:2.3:a:ctdb_project:ctdb:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option_server:07-01%2fb`,
        fs:  `cpe:2.3:a:symantec:mail_security:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option_server:08-00`,
        fs:  `cpe:2.3:a:simple_popup_project:simple_popup:-:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option_server:08-00%2fa`,
        fs:  `cpe:2.3:a:evanhoe:aimtsm:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol_gui_option_server:08-00%2fb`,
        fs:  `cpe:2.3:a:huawei:espace_7910:v200r002c00spc101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:01-00`,
        fs:  `cpe:2.3:o:dell:equallogic_ps4000_firmware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:01-01`,
        fs:  `cpe:2.3:o:ibm:aix:5l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:01-01-%2fd`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:01-02`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:01-02-%2ff`,
        fs:  `cpe:2.3:a:ibm:web_content_manager:7.0.0.1:cf004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:01-03`,
        fs:  `cpe:2.3:a:google:chrome:0.1.38.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:01-03-%2ff`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:02-00`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.05:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:02-00-%2fd`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_client_suite:02-01`,
        fs:  `cpe:2.3:a:roy_baxter:better_revisions:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:01-00`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:01-01`,
        fs:  `cpe:2.3:a:debian:dpkg:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:01-01-%2fd`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:01-02`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:01-02-%2ff`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:01-03`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.3:-:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:01-03-%2ff`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:02-00`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:02-00-%2fd`,
        fs:  `cpe:2.3:a:haxx:curl:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:02-01`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:7.5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_developer:02-01-%2fc`,
        fs:  `cpe:2.3:h:hp:jf234a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:01-00`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_foundry:2.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:01-01`,
        fs:  `cpe:2.3:a:opnet:development_kit_module_documentation:16.0.0.10106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:01-01-%2fd`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf240a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:01-02`,
        fs:  `cpe:2.3:a:apple:itunes:11.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:01-02-%2ff`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:3.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:01-03`,
        fs:  `cpe:2.3:a:symantec:veritas_commandcentral:5.2.20000.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:01-03-%2ff`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:02-00`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:02-00-%2fd`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)mr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cobol2002_net_server_suite:02-01`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:compute_systems_manager:7.6.1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:2.0\(0.147\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:compute_systems_manager:8.0.0`,
        fs:  `cpe:2.3:a:oracle:sysfw:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:compute_systems_manager:8.1.0`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:compute_systems_manager:8.1.1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus%2fopentp1_web_web_front-endset:01-00`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.1:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus%2fopentp1_web_web_front-endset:01-00-%2fb`,
        fs:  `cpe:2.3:a:iojs:io.js:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus%2fopentp1_web_web_front-endset:01-01`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus%2fopentp1_web_web_front-endset:01-01-%2fc`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns500rx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus%2fopentp1_web_web_front-endset:02-00`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ye:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus%2fopentp1_web_web_front-endset:02-00-%2fa`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus%2fopentp1_web_web_front-endset:02-50`,
        fs:  `cpe:2.3:a:sympa:sympa:3.0b.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus%2fopentp1_web_web_front-endset:02-50-%2fa`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1yi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-00`,
        fs:  `cpe:2.3:o:sun:solaris:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-00-%2fi`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:8.1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-00-%2fs`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70-\/f:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-01`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p286:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-01-%2fl`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.5.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-02`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-02-%2fe`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-05`,
        fs:  `cpe:2.3:a:smarttech:smart_install_manager:1.0.58.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-05-%2fi`,
        fs:  `cpe:2.3:a:hp:marketresearch:82.0.174.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-05-%2fo`,
        fs:  `cpe:2.3:a:php:php:5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:05-05-%2fp`,
        fs:  `cpe:2.3:a:mahara:mahara:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:6`,
        fs:  `cpe:2.3:a:openstack:folsom:2012.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:6:-:enterprise`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00:-:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00:-:standard`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00-%2fa:-:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00-%2fa:-:standard`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00-%2fb:-:enterprise`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-352_firmware:t364sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00-%2fb:-:standard`,
        fs:  `cpe:2.3:h:lexmark:t632:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00-%2fe:-:enterprise`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00-%2fe:-:standard`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00-%2fi:-:enterprise`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.21.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-00-%2fi:-:standard`,
        fs:  `cpe:2.3:o:xen:xen:4.1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-02:-:enterprise`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:4.1.0.12319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-02:-:standard`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_agent_sql:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-02-%2fd:-:enterprise`,
        fs:  `cpe:2.3:a:gns3:gns3:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-02-%2fd:-:standard`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-02-%2ff:-:enterprise`,
        fs:  `cpe:2.3:h:dell:precision_t5600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-02-%2ff:-:standard`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-02-%2fg:-:enterprise`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-02-%2fg:-:standard`,
        fs:  `cpe:2.3:a:libraw:libraw:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50:-:enterprise`,
        fs:  `cpe:2.3:a:busybox:busybox:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50:-:standard`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.62:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2fb:-:enterprise`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2fb:-:standard`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2fc:-:enterprise`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2fc:-:standard`,
        fs:  `cpe:2.3:o:cisco:ios:12.3bw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2fe:-:enterprise`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2fe:-:standard`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2ff:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:ios:15.0m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2ff:-:standard`,
        fs:  `cpe:2.3:a:emc:isilon_insightiq:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2fi:-:enterprise`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-50-%2fi:-:standard`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-51:-:enterprise`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-51:-:standard`,
        fs:  `cpe:2.3:a:htc:shift_4g_software:2.76.651.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-51-%2fb:-:enterprise`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-51-%2fb:-:standard`,
        fs:  `cpe:2.3:a:forestarea:forest_area_fcu_mobile:1.0.29:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-51-%2fe:-:enterprise`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-51-%2fe:-:standard`,
        fs:  `cpe:2.3:a:adobe:device_central_cs3:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-51-%2fk:-:enterprise`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_application_server:06-51-%2fk:-:standard`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_client:5.0.201:rp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_client:06-00`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p179:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_client:06-00-%2fi`,
        fs:  `cpe:2.3:a:checkpoint:provider-1:4.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_client:06-02`,
        fs:  `cpe:2.3:a:microsoft:visual_basic_software_development_kit:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_client:06-02-%2fg`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_client:06-50`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_client:06-50-%2ff`,
        fs:  `cpe:2.3:a:osinet:classified_ads:6.x-3.1:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_client:06-51`,
        fs:  `cpe:2.3:a:mollify:mollify:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_client:06-51-%2fk`,
        fs:  `cpe:2.3:a:curtis_galloway:exif:0.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:5`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:05-00`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:05-00-%2fi`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:05-01`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:05-01-%2fl`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:05-05`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2009:-:government:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:05-05-%2fp`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:6:-:light`,
        fs:  `cpe:2.3:a:hp:icewall_java_agent_library:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:6:-:pro`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:6:-:standard`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-00:-:light`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-00:-:pro`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-00:-:standard`,
        fs:  `cpe:2.3:a:mysql:mysql_connector\/odbc:3.51.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-00-%2fi:-:light`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5s\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-00-%2fi:-:pro`,
        fs:  `cpe:2.3:o:vmware:esxi:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-00-%2fi:-:standard`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-02:-:light`,
        fs:  `cpe:2.3:a:oracle:integration_services_server:11.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-02:-:pro`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-02:-:standard`,
        fs:  `cpe:2.3:a:vmware:workstation:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-02-%2fg:-:light`,
        fs:  `cpe:2.3:h:lorextechnology:edge3:lh340:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-02-%2fg:-:pro`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-02-%2fg:-:standard`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-50:-:light`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-50:-:pro`,
        fs:  `cpe:2.3:a:altiris:svs_task:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-50:-:standard`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-50-%2ff:-:light`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-50-%2ff:-:pro`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.91.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-50-%2ff:-:standard`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-51:-:light`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-51:-:pro`,
        fs:  `cpe:2.3:a:vmware:server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-51:-:standard`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-51-%2fk:-:light`,
        fs:  `cpe:2.3:o:yahama:rt56v:4.07.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-51-%2fk:-:pro`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_developer:06-51-%2fk:-:standard`,
        fs:  `cpe:2.3:a:gnu:wget:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_server:04-00:-:standard`,
        fs:  `cpe:2.3:h:axis:2401_video_server:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_server:04-00:-:web`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_server:04-00-%2fa:-:standard`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_server:04-00-%2fa:-:web`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.13065:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_server:04-01:-:standard`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_server:04-01:-:web`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_server:04-01-%2fa:-:standard`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_server:04-01-%2fa:-:web`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:04-00:-:standard`,
        fs:  `cpe:2.3:o:juniper:screenos:6.2.0r16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:04-00:-:web`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:04-00-%2fa:-:standard`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:04-00-%2fa:-:web`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:04-01:-:standard`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:04-01:-:web`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.16:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:04-01-%2fa:-:standard`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.10:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:04-01-%2fa:-:web`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:05-00`,
        fs:  `cpe:2.3:a:php:php:5.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:05-00-%2fi`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p54:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:05-01`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:05-01-%2fl`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:05-05`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexus_studio:05-05-%2fp`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:cosminexux_client:6`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:developer%27s_kit_for_java:-`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:device_manager:8.1.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:06-70`,
        fs:  `cpe:2.3:a:gizra:og_vocab:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:06-70-%2ff`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:-:seccenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-00`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-00-%2fc`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:14.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-00-10`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-10`,
        fs:  `cpe:2.3:a:ca:unicenter_autosys_jm:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-10-%2fa`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.6.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-11`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-11-%2fc`,
        fs:  `cpe:2.3:a:pimpstore:esercizi_per_le_donne:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-20`,
        fs:  `cpe:2.3:o:suse:suse_linux:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_client_set:07-20-%2fb`,
        fs:  `cpe:2.3:a:autodesk:design_review_2008:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_set:07-50`,
        fs:  `cpe:2.3:a:harris:stat_guardian_vms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_set:07-50-%2fd`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_set:07-50-09`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.8:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_set:07-60`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-developer_set:07-60-%2fi`,
        fs:  `cpe:2.3:a:lemon-s_php:gazou_bbs_plus:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:06-70`,
        fs:  `cpe:2.3:a:digia:qt:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:06-70-%2fc`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:06-70-%2ff`,
        fs:  `cpe:2.3:a:ibm:api_management:4.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:06-70-%2fg`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-00`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-00-%2fb`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-00-%2fc`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-00-09`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:009sh:y:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-00-10`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-10`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-10-%2fa`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-11`,
        fs:  `cpe:2.3:a:google:v8:3.23.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-11-%2fc`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.56:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-20`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_library_set:07-20-%2fb`,
        fs:  `cpe:2.3:a:apache:axis:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_set:07-50`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_set:07-50-%2fd`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-professional_set:07-50-09`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.91.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:06-70`,
        fs:  `cpe:2.3:a:miniclip:rail_rush:1.9.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:06-70-%2fc`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router_firmware:1.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:06-70-%2ff`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:06-70-%2fg`,
        fs:  `cpe:2.3:a:adobe:robohelp_server:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-00`,
        fs:  `cpe:2.3:a:keepass:keepass:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-00-%2fb`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-00-%2fc`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1653.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-00-09`,
        fs:  `cpe:2.3:a:nagios:plugins:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-00-10`,
        fs:  `cpe:2.3:h:cisco:ons_15327:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-10`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-10-%2fa`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_server:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-11`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-11-%2fc`,
        fs:  `cpe:2.3:a:web2py:web2py:1.78.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-20`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow-standard_set:07-20-%2fb`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_portal_server:2001:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow_set:07-50`,
        fs:  `cpe:2.3:a:hp:praesidium_webproxy:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow_set:07-50-%2fd`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.36:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow_set:07-50-09`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow_set:07-60`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:electronic_form_workflow_set:07-60-%2fi`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:global_link_manager:8.1.1`,
        fs:  `cpe:2.3:a:inria:ocaml:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-20:-:server`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-20-%2fd:-:server`,
        fs:  `cpe:2.3:h:lexmark:t650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-20-%2fe:-:server`,
        fs:  `cpe:2.3:a:fortinet:single_sign_on:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-30:-:server`,
        fs:  `cpe:2.3:a:ibm:db2:11.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-30-%2ff:-:server`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-30-%2fg:-:server`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-35:-:server`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-35-%2ff:-:server`,
        fs:  `cpe:2.3:a:emc:networker:7.4.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:groupmax_collaboration:07-35-%2fg:-:server`,
        fs:  `cpe:2.3:a:adobe:digital_editions:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ibm_xl_c%2fc%2b%2b_v7_for_aix_%26_hitachi_developer%27s_kit_for_java:01-00:-:enterprise`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ibm_xl_c%2fc%2b%2b_v7_for_aix_%26_hitachi_developer%27s_kit_for_java:02-05-%2fq:-:enterprise`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ibm_xl_c%2fc%2b%2b_v8_for_aix_%26_hitachi_developer%27s_kit_for_java:01-00:-:enterprise`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ibm_xl_c%2fc%2b%2b_v8_for_aix_%26_hitachi_developer%27s_kit_for_java:02-05-%2fq:-:enterprise`,
        fs:  `cpe:2.3:a:allegrosoft:rompager:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_analyzer:02-01`,
        fs:  `cpe:2.3:o:google:chrome_os:0.9.128.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_analyzer:02-51`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.12.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_analyzer:02-51-01`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_analyzer:02-53`,
        fs:  `cpe:2.3:a:apache:couchdb:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_analyzer:02-53-01`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_analyzer:02-53-02`,
        fs:  `cpe:2.3:a:php:pear:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:02-50`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:02-50-01`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:02-50-06`,
        fs:  `cpe:2.3:a:emc:networker:7.4:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:02-50-07`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:03-00`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:03-00-04`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.556:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:03-00-07`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5a\)b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:03-00-08`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:03-00-12`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:6.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:04-00`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:it_operations_director:04-00-01`,
        fs:  `cpe:2.3:o:ibm:aix:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:job_management_partner_1%2fit_desktop_management-manager:09-50`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:job_management_partner_1%2fit_desktop_management-manager:09-50-03`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:job_management_partner_1%2fit_desktop_management-manager:10-01`,
        fs:  `cpe:2.3:a:lxml:lxml:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fit_desktop_management-manager:09-51`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fit_desktop_management-manager:09-51-05`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fit_desktop_management-manager:10-00`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fit_desktop_management-manager:10-00-02`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fit_desktop_management-manager:10-01`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fit_desktop_management-manager:10-01-02`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fperformance_management-manager_web_option:07-00::~~~solaris~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fperformance_management-manager_web_option:07-00::~~~windows~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fperformance_management-manager_web_option:07-54::~~~solaris~~`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.10:*:le:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fperformance_management-manager_web_option:07-54::~~~windows~~`,
        fs:  `cpe:2.3:a:rsa:authentication_agent_for_web:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:07-52:-:enterprise:ja`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:07-52:-:standard:ja`,
        fs:  `cpe:2.3:a:ca:etrust_audit_aries:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:07-56:-:enterprise:ja`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:07-56:-:standard:ja`,
        fs:  `cpe:2.3:h:enterasys:6e233-49:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:07-56-%2fg%28%2a2%29:-:enterprise:ja`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:07-56-%2fg%28%2a2%29:-:standard:ja`,
        fs:  `cpe:2.3:a:gnu:tar:1.13.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-00:-:enterprise:ja`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-00:-:standard:ja`,
        fs:  `cpe:2.3:a:ca:messaging:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-06:-:enterprise:en`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-06:-:standard:en`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-07:-:enterprise:en`,
        fs:  `cpe:2.3:a:phpyabs:phpyabs:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-07:-:standard:en`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-50-%2fb:-:enterprise:ja`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-50-%2fb:-:standard:ja`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-51:-:enterprise:en`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-51:-:standard:en`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-55:-:enterprise:ja`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:jp1%2fserverconductor%2fdeploymentmanager:08-55:-:standard:ja`,
        fs:  `cpe:2.3:a:citrix:access_gateway_plug-in:10.0:69.4:*:*:enterprise:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-00`,
        fs:  `cpe:2.3:a:transifex:transifex:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-05`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-05-%2fa`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-05-%2fb`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.17.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-05-%2fc`,
        fs:  `cpe:2.3:h:huawei:s5300:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-05-%2fd`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-07`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-07-%2fa`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:01-07-%2fb`,
        fs:  `cpe:2.3:a:google:chrome:7.0.513.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-00`,
        fs:  `cpe:2.3:a:videocharge:watermark_master:2.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-00-%2fb`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-00-%2fc`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.8.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-00-%2fd`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-05`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.3:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-05-%2fa`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-05-%2fb`,
        fs:  `cpe:2.3:a:dell:idrac6_modular:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-05-%2fc`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-05-%2fd`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:processing_kit_for_xml:02-05-%2fe`,
        fs:  `cpe:2.3:a:siemens:simatic_step_7:5.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:replication_manager:8.1.1`,
        fs:  `cpe:2.3:a:zoner:zoner_antivirus_free:1.7.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:serverconductor%2fdeploymentmanager:01-00:-:-:ja`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.5:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:serverconductor%2fdeploymentmanager:01-01:-:-:ja`,
        fs:  `cpe:2.3:h:intel:c216_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:serverconductor%2fdeploymentmanager:06-00:-:-:ja`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:serverconductor%2fdeploymentmanager:06-00-%2fa:-:-:ja`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tiered_storage_manager:8.1.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:6.0.0::~~~solaris~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:6.0.0::~~~windows~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:7.1.0::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:python:python:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:7.6.1::~~~solaris~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:7.6.1:05:~~~solaris~~`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:8.0.0::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:8.0.0::~~~windows~~`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:8.0.0:03:~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:tuning_manager:8.0.0:03:~~~windows~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus%2fopentp1_web_web_front-endset:02-70`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router_firmware:1.1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus%2fopentp1_web_web_front-endset:02-70-%2fa`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0_build_8.01.9374:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus%2fopentp1_web_web_front-endset:02-70-%2fb`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70:-:enterprise`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70:-:standard`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fa:-:enterprise`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fa:-:standard`,
        fs:  `cpe:2.3:h:intel:pentuim:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fe:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fe:-:standard`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2ff:-:enterprise`,
        fs:  `cpe:2.3:a:apache:subversion:0.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2ff:-:standard`,
        fs:  `cpe:2.3:a:zooeffect:zooeffect:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fg:-:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.1:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fg:-:standard`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.0:pre.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fh:-:enterprise`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fl:-:enterprise`,
        fs:  `cpe:2.3:a:gentoo:xdg-utils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fl:-:standard`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fn:-:enterprise`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fn:-:standard`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fo:-:enterprise`,
        fs:  `cpe:2.3:a:microsoft:project:98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70-%2fo:-:standard`,
        fs:  `cpe:2.3:a:silanis:approveit_desktop:6.50.25.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70f:-:enterprise`,
        fs:  `cpe:2.3:a:oracle:secure_backup:10.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-70f:-:standard`,
        fs:  `cpe:2.3:a:cisco:jabber:9.7\(5\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-71:-:enterprise`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-71:-:standard`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-71-%2ff:-:enterprise`,
        fs:  `cpe:2.3:h:rockwellautomation:controllogix_5580:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-71-%2ff:-:standard`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-71-%2fg:-:enterprise`,
        fs:  `cpe:2.3:a:vmware:server:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-71-%2fg:-:standard`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_mib_support_for_huawei_switch:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-71-%2fh:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-71-%2fh:-:standard`,
        fs:  `cpe:2.3:a:otrs:faq:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-72:-:enterprise`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-72:-:standard`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0.1984:unknown:online_windows_server_2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-72-%2fd:-:enterprise`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-72-%2fd:-:standard`,
        fs:  `cpe:2.3:a:x:libxcb:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-72-%2fe:-:enterprise`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:06-72-%2fe:-:standard`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:6.7:-:enterprise`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:6.7:-:standard`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:7:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:7:-:standard`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00:-:enterprise`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00:-:standard`,
        fs:  `cpe:2.3:a:adobe:premiere_pro_cs3:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00-05:-:enterprise`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62y:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00-05:-:standard`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(3.210\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00-06:-:enterprise`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00-06:-:standard`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20101023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00-09:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00-09:-:standard`,
        fs:  `cpe:2.3:a:netgear:netgear_ga311_smart_wizard_utility:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00-10:-:enterprise`,
        fs:  `cpe:2.3:a:opsview:opsview:4.1:-:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-00-10:-:standard`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-03-02:-:enterprise`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-03-02:-:standard`,
        fs:  `cpe:2.3:a:radius_extension_project:radius:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-03-03:-:enterprise`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-03-03:-:standard`,
        fs:  `cpe:2.3:h:buffalotech:whr-g54s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-10:-:enterprise`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-10:-:standard`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-50-09:-:enterprise`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-50-09:-:standard`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-60:-:enterprise`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:07-60:-:standard`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.3:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:8:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.5\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:8:-:standard`,
        fs:  `cpe:2.3:a:ibm:java:5.0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:08-00:-:enterprise`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:08-00:-:standard`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:08-00-01:-:enterprise`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:08-00-01:-:standard`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.5:i5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:08-00-02:-:enterprise`,
        fs:  `cpe:2.3:a:sap:netweaver_abap:7.02:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_application_server:08-00-02:-:standard`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:06-70`,
        fs:  `cpe:2.3:a:webedition:webedition_cms:6.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:06-70-%2ff`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:06-70-%2fg`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:06-71`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:06-71-%2ff`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:06-71-%2fg`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-00`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-00-05`,
        fs:  `cpe:2.3:a:zencast:zencast:1.04.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-00-06`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-00-09`,
        fs:  `cpe:2.3:h:huawei:svn5000:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-00-10`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-03-02`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-03-03`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:4.2\(4.18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-50-09`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:07-60`,
        fs:  `cpe:2.3:a:microsoft:office:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:08-00`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:08-00-01`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_client:08-00-02`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-20:-:server`,
        fs:  `cpe:2.3:a:perl:perl:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-20-%2fd:-:server`,
        fs:  `cpe:2.3:a:netscout:ngenius_probes:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-20-%2fe-:server`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-30:-:server`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.2:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-30-%2ff:-:server`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-30-%2fg-:server`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-35:-:server`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.13:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-35-%2ff:-:server`,
        fs:  `cpe:2.3:a:simgear:simgear:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_collaboration:06-35-%2fg-:server`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:6:-:pro`,
        fs:  `cpe:2.3:o:bluecoat:sgos:5.2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:6:-:standard`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70:-:light`,
        fs:  `cpe:2.3:a:nullsoft:winamp:0.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70:-:pro`,
        fs:  `cpe:2.3:a:apache:axis:-:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70:-:standard`,
        fs:  `cpe:2.3:h:huawei:s5720ei:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70-%2ff:-:light`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70-%2ff:-:pro`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70-%2ff:-:standard`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70-%2fg:-:light`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70-%2fg:-:pro`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-70-%2fg:-:standard`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71:-:light`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71:-:pro`,
        fs:  `cpe:2.3:a:microsoft:ie_for_macintosh:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71:-:standard`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.186:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71-%2ff:-:light`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71-%2ff:-:pro`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71-%2ff:-:standard`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71-%2fg:-:light`,
        fs:  `cpe:2.3:a:horde:groupware:1.0.2:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71-%2fg:-:pro`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:06-71-%2fg:-:standard`,
        fs:  `cpe:2.3:a:pass4sure:pass4sure_for_comptia_sy0-201:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:6.7:-:light`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:6.7:-:pro`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:6.7:-:standard`,
        fs:  `cpe:2.3:a:lumonet_php_include_project:lumonet_php_include:1.2.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:7:-:light`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:7:-:pro`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:7:-:standard`,
        fs:  `cpe:2.3:a:microsoft:webtv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00:-:pro`,
        fs:  `cpe:2.3:h:hp:cd644a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00:-:standard`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00-05:-:pro`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00-05:-:standard`,
        fs:  `cpe:2.3:a:gnu:libcdio:0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00-06:-:pro`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00-06:-:standard`,
        fs:  `cpe:2.3:h:huawei:quidway_s2750:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00-09:-:pro`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00-09:-:standard`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00-10:-:pro`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cbr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-00-10:-:standard`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-03-02:-:pro`,
        fs:  `cpe:2.3:a:symantec:i-gear:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-03-02:-:standard`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-03-03:-:pro`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.9.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-03-03:-:standard`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-50-09:-:pro`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.9.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-50-09:-:standard`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-60:-:pro`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:07-60:-:standard`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:8:-:light`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:8:-:pro`,
        fs:  `cpe:2.3:h:ge:snmp\/web_adapter_1024748:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:8:-:standard`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:08-00:-:pro`,
        fs:  `cpe:2.3:a:mawashimono:nikki:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:08-00:-:standard`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:08-00-01:-:pro`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)t9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:08-00-01:-:standard`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:08-00-02:-:pro`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_developer:08-00-02:-:standard`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.102.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:6.7`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:7`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-00`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-00-05`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-00-06`,
        fs:  `cpe:2.3:a:microsoft:lync_room_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-00-09`,
        fs:  `cpe:2.3:a:f5:linerate:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-00-10`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-03-02`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-03-03`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:06-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-50-09`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:07-60`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.11:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_operator:8`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:6.7`,
        fs:  `cpe:2.3:a:david_king:vino:2.25.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:7`,
        fs:  `cpe:2.3:a:python:pillow:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-00`,
        fs:  `cpe:2.3:a:hp:keyview:10.23.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-00-05`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:epk:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-00-06`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-00-09`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-00-10`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-03-02`,
        fs:  `cpe:2.3:h:intel:active_management_technology:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-03-03`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-50-09`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:07-60`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:8`,
        fs:  `cpe:2.3:a:f-secure:psb_workstation_security:-:-:-:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:08-00`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:i7_quad_sinit_20.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:08-00-01`,
        fs:  `cpe:2.3:a:rim:blackberry_desktop_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_architect:08-00-02`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:6.7`,
        fs:  `cpe:2.3:a:citrix:access_client_for_metaframe:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:7`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-00`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-00-05`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp1:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-00-06`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p182:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-00-09`,
        fs:  `cpe:2.3:h:tenda:a5s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-00-10`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.82.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-03-02`,
        fs:  `cpe:2.3:a:ca:license_software:1.56.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-03-03`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-10`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-50-09`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:07-60`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:8`,
        fs:  `cpe:2.3:a:hippostudio:hippo_studio:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:08-00`,
        fs:  `cpe:2.3:h:fortinet:fortigate-5020:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:08-00-01`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.54:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitachi:ucosminexus_service_platform:08-00-02`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hitronsoft:nasim_guest_book:1.2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hk_exif_tags_project:hk_exif_tags:1.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.3.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hkbn:hkbn_my_account:%407f070015::~~~android~~`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hl7:c-cda:1.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.289:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hobbylobby:hobby_lobby_stores:2.1.9::~~~android~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hogs_fly_crazy_project:hogs_fly_crazy:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:holding_pattern_project:holding_pattern:0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:huawei:campus_series_switch_software:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:home_improvement_project:home_improvement:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.0.7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:home_made_air_freshener_project:home_made_air_freshener:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:home_shopping_apps:buy_a_gift:13529.90084::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.52.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:homeadvisor:homeadvisor_mobile:3.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.5.2\(423\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:homepage_decorator:perltreebbs:2.30`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:homepage_decorator_perlmailer_project:homepage_decorator_perlmailer:3.10`,
        fs:  `cpe:2.3:a:npds:revolution:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:homepage_decorator_perlmailer_project:homepage_decorator_perlmailer:3.11`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.38:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:homerelectric:hea_mobile:1.153.0034::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:database:11.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:honda:motolinc:1.6.1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:honda:motolinc:1.6.2::~~~android~~`,
        fs:  `cpe:2.3:a:node_invite_project:node_invite:6.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:honeywell:comfortpoint_open_manager_station:r100`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:honeywell:enterprise_buildings_integrator:r310`,
        fs:  `cpe:2.3:a:microsoft:class_package_export_tool:5.0.2752:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:honeywell:enterprise_buildings_integrator:r400.2`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.24:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:honeywell:enterprise_buildings_integrator:r410.1`,
        fs:  `cpe:2.3:a:dell:openmanage_active_directory_snap-in_utility:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:honeywell:enterprise_buildings_integrator:r410.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.8.0\(1026\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:excel_web_xl_1000c100_104_i%2fo:2.04.00`,
        fs:  `cpe:2.3:a:ibm:db2:9.8:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:excel_web_xl_1000c1000_600_i%2fo:2.04.00`,
        fs:  `cpe:2.3:a:schneider-electric:clearscada:2010:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:excel_web_xl_1000c1000_600_i%2fo_uukl:2.04.00`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:excel_web_xl_1000c100u_104_i%2fo_uukl:2.04.00`,
        fs:  `cpe:2.3:a:isc:bind:9.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:excel_web_xl_1000c50_52_i%2fo:2.04.00`,
        fs:  `cpe:2.3:a:avsmedia:video_editor:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:excel_web_xl_1000c500_300_i%2fo:2.04.00`,
        fs:  `cpe:2.3:a:phpipam:phpipam:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:excel_web_xl_1000c500_300_i%2fo_uukl:2.04.00`,
        fs:  `cpe:2.3:h:hp:laserjet_m3035_mfp:cc519a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:excel_web_xl_1000c50u_52_i%2fo_uukl:2.04.00`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:honeywell:falcon_xlweb_linux_controller:2.04.01`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:honeywell:falcon_xlweb_xlwebexe:2.02.11`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.1.1:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:honeywell:midas:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:honeywell:midas_black:-`,
        fs:  `cpe:2.3:a:emc:avamar:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:midas_black_firmware:2.13b1`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:honeywell:midas_firmware:1.13b1`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:honeywell:symmetre:r310`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:honeywell:symmetre:r400.2`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.10.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:honeywell:symmetre:r410.1`,
        fs:  `cpe:2.3:a:ronan_dowling:node_hierarchy:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.0`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.0:alpha`,
        fs:  `cpe:2.3:h:xerox:document_centre_230:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.0:rc1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:08-00-01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.0:rc2`,
        fs:  `cpe:2.3:a:not_yet_commons_ssl_project:not_yet_commons_ssl:0.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.0:rc3`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1:rc1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.6:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1:rc2`,
        fs:  `cpe:2.3:a:irislink:readiris:8.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1.2`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1.3`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:9.2\(1\):su1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1.4`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1.5`,
        fs:  `cpe:2.3:a:cisco:meeting_server:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:dynamic_imp:1.1.6`,
        fs:  `cpe:2.3:a:softconcept-inc:sysflowagent:1.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0:alpha`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0:beta`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0:rc1`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0:rc2`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:945sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0.1`,
        fs:  `cpe:2.3:a:brian_altenhofel:slidebox:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0.1:rc1`,
        fs:  `cpe:2.3:a:candlepinproject:candlepin:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0.2`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0.2:rc1`,
        fs:  `cpe:2.3:a:apple:apple_tv:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0.3`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.0.4`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.6p5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.1:rc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.1.1`,
        fs:  `cpe:2.3:a:apache:couchdb:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:gollem:1.1.2`,
        fs:  `cpe:2.3:a:plone:plone:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0::webmail`,
        fs:  `cpe:2.3:a:gmt-editions:rando_noeux:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0:rc1:webmail`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0:rc2:webmail`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.0.471780:*:*:*:linux:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0.1::webmail`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0.2::webmail`,
        fs:  `cpe:2.3:a:sybase:easerver:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0.3::webmail`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0.4::webmail`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0.5::webmail`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1\)e5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0.6::webmail`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0.7::webmail`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.0.8::webmail`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1::webmail`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1:rc1:webmail`,
        fs:  `cpe:2.3:a:git-scm:git:0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1:rc2:webmail`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1:rc3:webmail`,
        fs:  `cpe:2.3:a:conky:conky:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1:rc4:webmail`,
        fs:  `cpe:2.3:a:ark-web:a-form:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1.1::webmail`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1.2::webmail`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1.3::webmail`,
        fs:  `cpe:2.3:a:apple:webkit:124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1.4::webmail`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1.5::webmail`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.1.6::webmail`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd392a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2::webmail`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2:rc1:webmail`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.16.3:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.1::webmail`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p242_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.2::webmail`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.3::webmail`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.3:rc1:webmail`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.4::webmail`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.5::webmail`,
        fs:  `cpe:2.3:a:quest:knowledge_portal:2.5.1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.6::webmail`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:3.0:build121022:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.7::webmail`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.8::webmail`,
        fs:  `cpe:2.3:a:hawk_project:hawk:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:1.2.9::webmail`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.7.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.0.0::~~webmail~~~`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.0.0:rc1:~~webmail~~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.0.1::~~webmail~~~`,
        fs:  `cpe:2.3:a:webmin:usermin:1.330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.0.2::~~webmail~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.0.3::~~webmail~~~`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.0.4::~~webmail~~~`,
        fs:  `cpe:2.3:h:barraguard:barracuda_link_balancer:430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.0.5::~~webmail~~~`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:06-70-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.1.0::~~webmail~~~`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.1.0:rc1:~~webmail~~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.1.1::~~webmail~~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.1.2::~~webmail~~~`,
        fs:  `cpe:2.3:a:ca:network_and_systems_management:r3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.1.3::~~webmail~~~`,
        fs:  `cpe:2.3:a:apple:ical:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.1.4::~~webmail~~~`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.1.5::~~webmail~~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.2.15`,
        fs:  `cpe:2.3:a:intel:msso:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:groupware:5.2.15::~~webmail~~~`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc9:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:1.0.3`,
        fs:  `cpe:2.3:a:microsoft:office:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:1.1.1`,
        fs:  `cpe:2.3:a:b-e-soft:artweaver:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:1.3.0`,
        fs:  `cpe:2.3:a:alibaba:alibaba:4.1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:1.3.1`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:20051021:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:1.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:1.3.3`,
        fs:  `cpe:2.3:h:intel:q67_express_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:1.3.4`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:1.3.5`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5580_firmware:v28.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.0`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.0:rc1`,
        fs:  `cpe:2.3:o:freebsd:freebsd:1.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.0:rc3`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.0:rc4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.1`,
        fs:  `cpe:2.3:a:ca:single_sign-on:r12.0j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2`,
        fs:  `cpe:2.3:a:serena:license_manager:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.1`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.3`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.4`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.6`,
        fs:  `cpe:2.3:a:broadcom:management_programs:10.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.6:rc1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.7`,
        fs:  `cpe:2.3:a:logitech:lws_youtube_plugin:13.0.1777.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.8`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.11.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:2.2.9`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.1.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0`,
        fs:  `cpe:2.3:h:3com:superstack_3_switch_4924:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0:alpha`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.6:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0:beta`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0:rc1`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.1r1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0:rc2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0:rc3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.1`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.2`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.3:rc1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.4`,
        fs:  `cpe:2.3:a:horde:groupware:5.1.5:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.4:rc1`,
        fs:  `cpe:2.3:a:codiad:codiad:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.4:rc2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.5`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.5:rc1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.5:rc2`,
        fs:  `cpe:2.3:a:adobe:flash_player:8.0.42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2010.706.2128.36662:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.6:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.7`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.8`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.9`,
        fs:  `cpe:2.3:a:autodesk:inventor_fusion:1.0.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.10`,
        fs:  `cpe:2.3:a:apc:powerchute:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.11`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.0.12`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1:rc1`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1:rc2`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller:7.3\(103.8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1:rc3`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.3`,
        fs:  `cpe:2.3:a:open-xchange:ox_guard:2.0.0:rev6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.4`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.4:rc1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30201:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p152:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.7`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.8`,
        fs:  `cpe:2.3:a:symantec:norton_bootable_removal_tool:2016.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.1.9`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2`,
        fs:  `cpe:2.3:a:ibm:db2:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2:alpha`,
        fs:  `cpe:2.3:o:sun:solaris:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2:rc1`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2:rc2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2:rc3`,
        fs:  `cpe:2.3:a:apache:cxf:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2:rc4`,
        fs:  `cpe:2.3:a:skydreams:prof._usman_ali_awheela:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2.2`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2.3`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2.4`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.2.5`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3`,
        fs:  `cpe:2.3:h:lexmark:xc4150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3:rc1`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.1`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.612.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.4`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7971g-ge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.4:rc1`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.7`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.8`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.9`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:3.3.10`,
        fs:  `cpe:2.3:a:gnu:grub2:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.0.0`,
        fs:  `cpe:2.3:o:ibm:os_400:v4r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.0.1`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_batch_execution:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.0.2`,
        fs:  `cpe:2.3:h:cisco:aironet_1830e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.0.4`,
        fs:  `cpe:2.3:a:apple:iphoto:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.1.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.1.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.04:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.1.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.1.3`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_lights_out:2_1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_application_framework:5.1.4`,
        fs:  `cpe:2.3:a:telelogic:telelogic_license_server:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_groupware:5.2.11`,
        fs:  `cpe:2.3:a:samba:samba:3.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_groupware:5.2.11::~~webmail~~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.0`,
        fs:  `cpe:2.3:h:cisco:business_edition_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.0:alpha1`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.711.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.0:beta2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.1`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.2`,
        fs:  `cpe:2.3:a:jruby:jruby:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.3`,
        fs:  `cpe:2.3:o:d-link:dcs-5010l_firmware:1.13.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.4`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.5`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.6`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.7`,
        fs:  `cpe:2.3:a:samba:samba:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.8`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.0.9`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.1.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.2.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.3.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1669.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.3.1`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.3.2`,
        fs:  `cpe:2.3:h:schneider-electric:bmxnoc0401:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.3.3`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.36.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.3.4`,
        fs:  `cpe:2.3:h:ge:multilink_ml3100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.3.5`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.3.6`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.4.0`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:4.2\(1\)sv1\(5.1\):-:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:horde_image_api:2.4.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.0`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2`,
        fs:  `cpe:2.3:o:extremenetworks:extremeware_xos:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2.1`,
        fs:  `cpe:2.3:a:hp:vertica:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2.2`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.14.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2.3`,
        fs:  `cpe:2.3:a:omeka:omeka:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2.4`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2.5`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2.6`,
        fs:  `cpe:2.3:a:digium:asterisk:11.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2.7`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.2.8`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.2.01022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:2.3`,
        fs:  `cpe:2.3:a:justsystems:shuriken:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.1`,
        fs:  `cpe:2.3:a:novell:small_business_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.1.2`,
        fs:  `cpe:2.3:o:vmware:esx:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4jmb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.6:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2.5`,
        fs:  `cpe:2.3:a:redhat:openshift:2.0.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2.6`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:195.22:-:*:*:linux_kernel:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2.7`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:3.2.7:rc1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.2:cf2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.0.1`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.0.3`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.0.4`,
        fs:  `cpe:2.3:a:xnview:xnview:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.1.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.4jma:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.1.5`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.1.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.2`,
        fs:  `cpe:2.3:a:hp:icewall_file_manager:3.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.2.1`,
        fs:  `cpe:2.3:a:radware:fireproof:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.2.2`,
        fs:  `cpe:2.3:a:yourls:yourls:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.1`,
        fs:  `cpe:2.3:a:eviware:loadui:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.2`,
        fs:  `cpe:2.3:a:apple:safari:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.5`,
        fs:  `cpe:2.3:h:omron:ns5_hmi_terminal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.6`,
        fs:  `cpe:2.3:o:siemens:ccmw1025_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.7`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.8`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.5:sr_3.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:4.3.9`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)xy5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0:alpha1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0:beta1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0:rc1`,
        fs:  `cpe:2.3:a:checkpoint:connectra_ngx:r60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0:rc2`,
        fs:  `cpe:2.3:h:hp:jg496a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0.1`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:0.1.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0.2`,
        fs:  `cpe:2.3:a:apache:solr:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0.3`,
        fs:  `cpe:2.3:a:apache:wicket:6.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:imp:5.0.4-git`,
        fs:  `cpe:2.3:a:bzrtp_project:bzrtp:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.0:alpha1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.2\(2\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.0:beta1`,
        fs:  `cpe:2.3:a:samba:samba:3.0.20:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.0:beta2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.0:beta3`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.0:beta4`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.4:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.0:rc1`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.1`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.2`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.3`,
        fs:  `cpe:2.3:a:cisco:unity_connection:11.0\(0.98000.225\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.4`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc372xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.0.6`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.0`,
        fs:  `cpe:2.3:a:infotecs:vipnet_safedisk:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.0:beta1`,
        fs:  `cpe:2.3:o:yahama:rt60w:5.01.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.0:beta2`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.1`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.0_build_13124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.2`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.3`,
        fs:  `cpe:2.3:a:adastra:trace_mode_data_center:6.07.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.4`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.5`,
        fs:  `cpe:2.3:a:otrs:faq:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.6`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:246:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.7`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:internet_mail_program:6.1.8`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.3:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0:alpha1`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0:beta1`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0:rc1`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:2.3.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0:rc2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5b\)su1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.1`,
        fs:  `cpe:2.3:a:f5:big-ip_protocol_security_module:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.2`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.3`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.4`,
        fs:  `cpe:2.3:a:mod_nss_project:mod_nss:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.5`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.6`,
        fs:  `cpe:2.3:h:linksys:befsr11:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.7`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p272:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.9`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.10`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.11`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.12`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.13`,
        fs:  `cpe:2.3:a:php:php:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.14`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.15`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.05.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.16`,
        fs:  `cpe:2.3:a:ibm:tivoli_common_reporting:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.17`,
        fs:  `cpe:2.3:a:rsa:authentication_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horde:kronolith_h4:3.0.18`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.2:a`,
        fs:  `cpe:2.3:a:andrew_levine:multiblock:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.3`,
        fs:  `cpe:2.3:o:fli4l:fli4l:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.5.1`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.5.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:4.0`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_cms:5.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:4.1`,
        fs:  `cpe:2.3:a:netiq:appmanager_control_center:7.0.40428.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hornbill:supportworks_itsm:1.0.0`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hornbill:supportworks_itsm:3.4.14`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:horoscopesanddreams:horoscopes_and_dreams:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:krisonav:krisonav:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hospira:lifecare_pca3:-`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:p09-0035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hospira:lifecare_pca5:-`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hospira:lifecare_pcainfusion_firmware:5.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hospira:lifecare_pcainfusion_pump:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.07.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hospira:lifecare_pcainfusion_pump_firmware:412`,
        fs:  `cpe:2.3:h:hp:j9091a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hospira:mednet:5.8`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:02-08-2013`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:04-11-2013`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.7.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp2:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.7.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.7.4`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.7.6`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.7.8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.388:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.8.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.2:1005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.8.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.8.4`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.8.6`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.8.8`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.9.0`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.9.2`,
        fs:  `cpe:2.3:a:f5:big-ip_protocol_security_module:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.9.6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:4.9.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2009.211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:06-11-2013`,
        fs:  `cpe:2.3:a:webmin:usermin:1.450:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:06-12-2013`,
        fs:  `cpe:2.3:a:vandyke:securecrt_and_securefx:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:08-11-2013`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:13-12-2013`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:14-12-2013`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:15-11-2013`,
        fs:  `cpe:2.3:o:cisco:vpn_3060_concentrator:4.7.1.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:18-10-2013`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:19-11-2013`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_opstor:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:20-12-2013`,
        fs:  `cpe:2.3:a:microsoft:visio_multilingual_user_interface_pack:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:22-11-2013`,
        fs:  `cpe:2.3:a:altiris:deployment_server_extension_for_ibm_director:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:25-10-2013`,
        fs:  `cpe:2.3:a:ctdb_project:ctdb:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hostbillapp:hostbill:29-11-2013`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hot:hotbox_router:-`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hot:hotbox_router_firmware:2.1.11`,
        fs:  `cpe:2.3:o:opensuse:opensuse:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.6.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-71-\/h:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.6.4`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.7.0`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.7.1`,
        fs:  `cpe:2.3:h:hp:12500_vpn_firewall_module:jc635a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.7.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_1i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.7.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.7.5`,
        fs:  `cpe:2.3:a:cisco:finesse:10.5\(1\)_es3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.7.7`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.14.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.8.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.8.2`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.8.4`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotbar:hbtools:4.8.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p240:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotel-room:hotel_room:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotlingo:hotlingo:2.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotlingo:hotlingo:2.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotlingo:hotlingo:2.2`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hotlingo:hotlingo:2.3`,
        fs:  `cpe:2.3:a:qemu:qemu:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:houcine_el_jasmi_project:houcine_el_jasmi:1::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0231a0kl:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0231a791:-`,
        fs:  `cpe:2.3:a:apache:struts:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0231a84q:-`,
        fs:  `cpe:2.3:a:ibm:db2:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0a7:-`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0a8:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0bx:-`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0c0:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0c2:-`,
        fs:  `cpe:2.3:a:tbb:taiwan_business_bank:2.04:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0c4:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0e6:-`,
        fs:  `cpe:2.3:a:yahoo:ui_library:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0e7:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0g6:-`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0g7:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0ge:-`,
        fs:  `cpe:2.3:a:cyberoperations:pro-defense:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a0gf:-`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.17.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a19l:-`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a20j:-`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a20k:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a20l:-`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a20n:-`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.7.0.2090:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a20p:-`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a20s:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a20v:-`,
        fs:  `cpe:2.3:a:orchardproject:orchard:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a237:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0da:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a238:-`,
        fs:  `cpe:2.3:a:dest-unreach:socat:2.0.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a239:-`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a25r:-`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.4.2:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a25s:-`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a267:-`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a268:-`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a269:-`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a296:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a297:-`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a298:-`,
        fs:  `cpe:2.3:a:krisonav:krisonav:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a299:-`,
        fs:  `cpe:2.3:a:x2engine:x2crm:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a29l:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a31n:-`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a31p:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a31q:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.4\(0.181\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a31r:-`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a31v:-`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a31w:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a31x:-`,
        fs:  `cpe:2.3:o:cisco:modular_encoding_platform_d9036_software:02.01.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a320:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.5.1\(2082\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a321:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a322:-`,
        fs:  `cpe:2.3:o:dell:sonicwall_netextender_firmware:7.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a323:-`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:6.0.182.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a324:-`,
        fs:  `cpe:2.3:a:lstc:ls-dyna:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a326:-`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a327:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a328:-`,
        fs:  `cpe:2.3:a:nero:controlcenter:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a32b:-`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a32e:-`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a32g:-`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_for_plsql:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a38k:-`,
        fs:  `cpe:2.3:a:sap:netweaver_enterprise_portal:7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a38l:-`,
        fs:  `cpe:2.3:a:php:php:7.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a38m:-`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a38n:-`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a38p:-`,
        fs:  `cpe:2.3:a:mw6tech:datamatrix_activex_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a38q:-`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.1.1.323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a38r:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(3\)n2\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a38v:-`,
        fs:  `cpe:2.3:a:progea:movicon:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a390:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a391:-`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:1.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a392:-`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a393:-`,
        fs:  `cpe:2.3:a:siemens:wincc:6.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a394:-`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a395:-`,
        fs:  `cpe:2.3:a:inline_entity_form_project:inline_entity_form:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a396:-`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.66.26:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a397:-`,
        fs:  `cpe:2.3:a:winzip:self-extractor:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a398:-`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:0235a39h:-`,
        fs:  `cpe:2.3:o:novell:netware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:1000_series_firmware:1.1`,
        fs:  `cpe:2.3:a:samba:samba:3.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:1000_series_firmware:1.01`,
        fs:  `cpe:2.3:a:vmware:converter:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:1000_series_firmware:1.04`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:10500%2f7500_advanced_vpn_firewall_module:jd249a`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:1055_network_printer:-`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:12500_vpn_firewall_module:jc635a`,
        fs:  `cpe:2.3:a:apple:safari:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:1500_network_printer:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je110a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2200_network_printer:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2200dtn_network_printer:-`,
        fs:  `cpe:2.3:a:skype:skype:1.3.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2260_network_printer:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2300dn_network_printer:-`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2500c_network_printer:-`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2500c_pro_printer:-`,
        fs:  `cpe:2.3:a:fallacystudios:marijuana_handbook_lite_-_weed:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2550c_network_printer:-`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2600c_network_printer:-`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.5:i5p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2620-24-poe%2b_switch:-`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:2d_value_wireless_scanner_k3l28aa:-`,
        fs:  `cpe:2.3:a:apache:roller:0.9.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_baseline_plus_switch:2900`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_baseline_plus_switch:2900g`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_baseline_plus_switch:2900g-28hpwr`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p31:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_baseline_plus_switch:2900g-28pwr`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:3com_officeconnect_gigabit_vpn_firewall_software:1.0.8`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:3com_officeconnect_gigabit_vpn_firewall_software:1.0.12`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:3012`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:3013`,
        fs:  `cpe:2.3:a:candlepinproject:candlepin:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:3016`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.15:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:3018`,
        fs:  `cpe:2.3:a:opnet:it_guru:15.0.0.8652:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:3036`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:3040`,
        fs:  `cpe:2.3:a:djangoproject:django:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:3041`,
        fs:  `cpe:2.3:a:avonesoft:ipod_video_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5009`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5012`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5231`,
        fs:  `cpe:2.3:o:freebsd:freebsd:9.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5232`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5640`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5642`,
        fs:  `cpe:2.3:a:apache:sling_auth_core_component:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5642_taa`,
        fs:  `cpe:2.3:a:hp:virtualvault:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5680`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:5682`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:6040`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:6080`,
        fs:  `cpe:2.3:a:lepton-cms:lepton:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:jg005a`,
        fs:  `cpe:2.3:a:ask:ask_toolbar:1.6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_router:ss4_5500g-ei`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4200g`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4200g-ntg`,
        fs:  `cpe:2.3:a:openstack:horizon:2013.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4200g_pwr`,
        fs:  `cpe:2.3:a:schneider-electric:vijeo_citect:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4210`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4210-24g`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-5:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4210-48g`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4210_pwr`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4210_pwr_9p_taa`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4500`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4500_pwr`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.6.122.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4510g`,
        fs:  `cpe:2.3:h:supermicro:x9drt-ibff:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4510g_pwr`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:4800g`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.78.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:5500g-ei_sfp`,
        fs:  `cpe:2.3:a:acme:thttpd:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:e4210-24g-poe`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:e4510-24g`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:ss4_5500-ei`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:ss4_5500-ei-pwr`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:ss4_5500-si`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:ss4_5500g-ei`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.14.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:ss4_5500g-ei-pwr`,
        fs:  `cpe:2.3:a:tvdr:vdr:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch:ss4_switch_5500g-ei`,
        fs:  `cpe:2.3:a:commpower:dc_config:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch_taa_compliant:5500g-ei`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:1.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch_taa_compliant:5500g-ei-pwr`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_switch_taa_compliant:5500g-ei-sfp`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3com_taa_switch:5500-ei`,
        fs:  `cpe:2.3:a:cipherdyne:fwknop:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:3crevf100-73:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:4_network_printer:-`,
        fs:  `cpe:2.3:a:pinnaclesys:instant_dvd_recorder:1.60.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:4000_network_printer:-`,
        fs:  `cpe:2.3:a:openssl:openssl:1.1.0f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:4050_network_printer:-`,
        fs:  `cpe:2.3:a:altnet:altnet_download_manager:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:4200ln_network_printer:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:4600_network_printer:-`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:4650_network_printer:-`,
        fs:  `cpe:2.3:o:d-link:dcs-5025l_firmware:1.02.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:4m_plus_network_printer:-`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:5_network_printer:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:5000_network_printer:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:500ps_network_printer:-`,
        fs:  `cpe:2.3:a:google:chrome:14.0.815.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:5100_network_printer:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2010.825.2146.37182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:5500_network_printer:-`,
        fs:  `cpe:2.3:o:edimax:6114wg_router_firmware:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:5550_color_network_printer:-`,
        fs:  `cpe:2.3:a:cisco:webns:8.10.1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:5600_help:50.0.206.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:5820_vpn_firewall_module:jd255a`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.60a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:5850_network_printer:-`,
        fs:  `cpe:2.3:a:redatoms:redatoms_three:2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:5m_network_printer:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:6000e609_basicweb:140.0.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_directory_administrator:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:6000e609_help_basicweb:1.0.0`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:6300_help:70.0.231.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2s\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:6300_help:71.0.215.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:6400_help:1.0.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:6500_e709_edocs:1.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:6600_firewall_processing_rtr_module:jd250a`,
        fs:  `cpe:2.3:a:3ivx:mpeg-4:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:700_series_firmware:1.05`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1020:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:700_series_firmware:1.08`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0.7.3312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:700_series_firmware:2.05`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:700_series_firmware:2.07`,
        fs:  `cpe:2.3:a:webroot:internet_security_essentials:6.1.0.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:700_series_firmware:2.09`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:750_network_printer:-`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.8.2144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:7500_7600_7700_help:1.0.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.06:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:7500_7600_7700_help1:1.0.0`,
        fs:  `cpe:2.3:h:siemens:scalance_x202-2p_irt:-:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:755_network_printer:-`,
        fs:  `cpe:2.3:a:gnu:icecat:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8%2f20q_fibre_channel_switch_16_port:ak242a`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8%2f20q_fibre_channel_switch_16_port:ak242b`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:4.7-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8%2f20q_fibre_channel_switch_8_port:aq233a`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8%2f20q_fibre_channel_switch_8_port:aq233b`,
        fs:  `cpe:2.3:a:php:php:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:800_series_firmware:2.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:800_series_firmware:2.09`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8100c_digital_sender:-`,
        fs:  `cpe:2.3:h:supermicro:x8dtu-6tf\&#43;-lr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8500_network_printer:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:8500a909_edocs:1.0.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8550_network_printer:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8800_firewall_processing_module:jd251a`,
        fs:  `cpe:2.3:a:adobe:add_or_remove_creative_suite_3_web_premium:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8gb_simple_san_connection_kit:ak241a`,
        fs:  `cpe:2.3:a:microsoft:lync:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:8gb_simple_san_connection_kit:ak241b`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_hpc_node:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:9000:-`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:9100c_digital_sender:-`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.9:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:9200c_digital_sender:-`,
        fs:  `cpe:2.3:a:optipng_project:optipng:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:9500_vpn_firewall_module:jd245a`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:a2w75a:-`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:a2w76a:-`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:a2w77a:-`,
        fs:  `cpe:2.3:a:vmware:server:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:a2w78a:-`,
        fs:  `cpe:2.3:a:cisco:finesse:9.0\(2\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:a2w79a:-`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:aaa_server:-`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:9.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ad_install:1.0.0`,
        fs:  `cpe:2.3:h:cisco:cache_engine_550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advanced_server_9000:-`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advanced_server_9000:b.04.05`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advanced_server_9000:b.04.06`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp4:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advanced_server_9000:b.04.07`,
        fs:  `cpe:2.3:a:samba:samba:3.0.26a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advanced_server_9000:b.04.08`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:2.1:*:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advanced_server_9000:b.04.09`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:12.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3200a:-`,
        fs:  `cpe:2.3:o:iij:seil\%2fb1_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3200a:a.03.07`,
        fs:  `cpe:2.3:a:artifex:mupdf:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3201a:-`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3201a:a.03.07`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.183:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3202a:-`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.0.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3202a:a.03.07`,
        fs:  `cpe:2.3:a:ca:arcserve_client_agent:_nil_:_nil_:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3203a:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(16\)bx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3203a:a.03.07`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router:1.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3204a:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3204a:a.03.07`,
        fs:  `cpe:2.3:a:mscsoftware:msc_nastran:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3205a:-`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.5-89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3205a:a.03.07`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3210a:-`,
        fs:  `cpe:2.3:o:brickom:100ap_device_firmware:3.0.6.16c1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:advancestack_10base-t_switching_hub_j3210a:a.03.07`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:af601a:-`,
        fs:  `cpe:2.3:a:kingsoft:writer_2010:2724:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:all-in-one:-`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.1:sp1:sdk:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm-platform_loader:11.0.4504.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm-platform_loader:11.0.4804.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm-platform_loader:11.0.5154.0`,
        fs:  `cpe:2.3:a:python:python:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm-platform_loader:11.0.5373.0`,
        fs:  `cpe:2.3:h:sun:fire_x4250_server:sw_1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm-platform_loader:11.0.5844.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm_synchronizer:1.10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm_synchronizer:1.20`,
        fs:  `cpe:2.3:a:google:chrome:5.0.349.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm_synchronizer:1.30`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm_synchronizer:1.40`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:alm_synchronizer:1.41`,
        fs:  `cpe:2.3:a:automon:marcus_butler_unofficial:1.4.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:alphaserver_sc:-`,
        fs:  `cpe:2.3:a:apache:couchdb:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:apache-based_web_server:-`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:apache-based_web_server:1.3.27.00`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:apache-based_web_server:1.3.27.01`,
        fs:  `cpe:2.3:a:roxio:recordnow_copy:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:apache-based_web_server:2.0.43.00`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.5:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:apache-based_web_server:2.0.43.04`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:apollo_domain_os:-`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:apollo_domain_os:sr10.2`,
        fs:  `cpe:2.3:o:juniper:junos:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:apollo_domain_os:sr10.3`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_24.39:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:app_studio:140.0.95.0`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_information_optimizer:6.2`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_information_optimizer:6.3`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_information_optimizer:6.4`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_information_optimizer:7.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_lifecycle_management:-`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_lifecycle_management:11.00`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp4:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_lifecycle_management:11.50`,
        fs:  `cpe:2.3:a:asus:video_security_online:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_lifecycle_management:11.51`,
        fs:  `cpe:2.3:o:cisco:ios:12.4jx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_server:-`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:application_server:8.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:arcsight_command_center:6.8.0.1896.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:arcsight_connector_appliance:6.4.0.6881.3`,
        fs:  `cpe:2.3:a:schneider-electric:unity_pro:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:arcsight_connector_appliance:c1400`,
        fs:  `cpe:2.3:a:icinga:icinga:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:arcsight_connector_appliance:c3400`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:arcsight_connector_appliance:c5400`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:arcsight_connector_appliance_firmware:6.0.0.60023.2`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:arcsight_connector_appliance_firmware:6.2.0.6244.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:arcsight_connector_appliance_firmware:6.3`,
        fs:  `cpe:2.3:a:apache:axis:-:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:arcsight_connector_appliance_firmware:6.4`,
        fs:  `cpe:2.3:o:ibm:vios:2.1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:arcsight_enterprise_security_manager:5.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:arcsight_logger:5.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:arcsight_logger:5.3`,
        fs:  `cpe:2.3:a:ali_visual_project:ali_visual:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:arcsight_logger:6.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus\/opentp1_web_web_front-endset:01-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:arcsight_logger:6.0.0.7307.1`,
        fs:  `cpe:2.3:a:twiki:twiki:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:arcsight_logger:6.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:arcsight_logger_appliance:l7400-san`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:arcsight_logger_appliance_firmware:5.2.0.6288.0`,
        fs:  `cpe:2.3:a:divx:player:6.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:7.80.6.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.5:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:7.85.18.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:6.7:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.0.14.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.10.1.0`,
        fs:  `cpe:2.3:a:apple:mac_os_nsl_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.25.5.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.28.13.0`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.30.5.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.40.4.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.50.5.0`,
        fs:  `cpe:2.3:o:huawei:s9300e_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.60.7.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.48.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.70.9.0`,
        fs:  `cpe:2.3:a:analogx:proxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:8.75.12.0`,
        fs:  `cpe:2.3:a:f5:big-ip_websafe:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_configuration_utility:9.40`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_for_oracle_administration:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_diagnostic_utility:7.80.6.0`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_diagnostic_utility:7.85.16.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_diagnostic_utility:8.0.14.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_diagnostic_utility:8.10.3.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_diagnostic_utility:8.25.5.0`,
        fs:  `cpe:2.3:a:jffnms:just_for_fun_network_management_system:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_diagnostic_utility:8.26.1.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:array_diagnostics_utility:9.40`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.12:ga7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:aserver:-`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:asset_manager:9.40`,
        fs:  `cpe:2.3:o:asus:rt-n65u_firmware:3.0.0.3.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:asset_manager:9.41`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5b\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:asset_manager:9.50`,
        fs:  `cpe:2.3:a:netscape:communicator:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:asset_manager_cloudsystem_chargeback:9.40`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:autonomy_ultraseek:5.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.00:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:autonomy_ultraseek:6.0`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:b3g85a:-`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:b5l04a:-`,
        fs:  `cpe:2.3:a:plone:plone:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:b5l05a:-`,
        fs:  `cpe:2.3:a:open-realty:open-realty:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:b5l07a:-`,
        fs:  `cpe:2.3:a:isc:bind:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bastille:-`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bastille:b.02.00.05`,
        fs:  `cpe:2.3:a:divx:codec:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bidi_channel_components_installer:1.1.0.2`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bidi_channel_components_installer:1.2.0.2::~~~~x64~`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2009:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpd_dswizards:1.0.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpd_hpsu:1.0.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpd_scan:2.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpd_scan:3.0.0`,
        fs:  `cpe:2.3:a:sun:secure_global_desktop:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpd_scan_carrier:3.0.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpd_scan_ent:3.0.0`,
        fs:  `cpe:2.3:a:php:php:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpdfax:70.0.184.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpdsoftware:50.0.165.0`,
        fs:  `cpe:2.3:a:bluecoat:winproxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpdsoftware:70.0.283.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpdsoftware:82.0.173.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpdsoftware:140.0.0.0`,
        fs:  `cpe:2.3:a:digia:qt:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bpdsoftware_ini:1.0.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:45.4.157.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:53.0.13.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:53.0.24.0`,
        fs:  `cpe:2.3:a:yahoo:yahoo\!_browser:1.4.4:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:60.0.155.0`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:70.0.170.0`,
        fs:  `cpe:2.3:a:polycom:pathnavigator:7.0.3.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:82.0.173.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:90.0.146.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:100.0.170.0`,
        fs:  `cpe:2.3:a:plone:plone:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:110.0.180.0`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:120.0.194.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:130.0.331.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:140.0.212.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:bufferchm:140.0.213.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p157:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:7.0`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:7.55`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:8.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.31.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:8.01`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:8.02`,
        fs:  `cpe:2.3:a:hp:autonomy_ultraseek:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:8.03`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:8.04`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:8.05`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:8.06`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:8.07`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_availability_center:9.01`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_process_monitor:8.4.316`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_process_monitor:9.3:patch_1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:business_process_monitor:9.3.170`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:button_manager:1.6.0.0`,
        fs:  `cpe:2.3:a:jenkins:git:0.7.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:c2s11a:-`,
        fs:  `cpe:2.3:a:rubyonrails:jquery-rails:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:c2s12a:-`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:c4100_help:70.0.231.0`,
        fs:  `cpe:2.3:a:splunk:splunk:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:c4380_help:100.0.206.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:c6100_help:70.0.231.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:c7100_help:70.0.231.0`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ca251a:-`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.11.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cards_calendar_ordergift_domoreplugout:1.0.0`,
        fs:  `cpe:2.3:a:open-emr:openemr:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:care_pack_core:1.0.0.0`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8zc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:care_pack_core:10.0.0.1`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.128.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:care_pack_products:1.0.0.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:care_pack_products:1.0.0.1`,
        fs:  `cpe:2.3:a:security_questions_project:security_questions:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:care_pack_products:2.0.0.1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc2300:-`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc2300:a6898a`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.01:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc2300:a6899a`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc3300:-`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc3300:a6900a`,
        fs:  `cpe:2.3:o:sgi:irix:5.3:*:xfs:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc3300:a6901a`,
        fs:  `cpe:2.3:a:apple:itunes:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc3310:-`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.15:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc3310:a9862a`,
        fs:  `cpe:2.3:a:adobe:winsoft_linguistics_plugin:1.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/h:hp:carrier_grade_server_cc3310:a9863a`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.34.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cc522a:-`,
        fs:  `cpe:2.3:a:altova:altova_installer_for_apache_fop_for_jdk_1.4:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cc523a:-`,
        fs:  `cpe:2.3:a:gnu:glibc:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cc524a:-`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cd644a:-`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cd645a:-`,
        fs:  `cpe:2.3:a:roxio:cineplayer:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cd646a:-`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.03:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ce989a:-`,
        fs:  `cpe:2.3:a:thomas_eibner:mod_rpaf:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ce990a:-`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ce991a:-`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ce992a:-`,
        fs:  `cpe:2.3:a:ibm:notes_traveler:9.0.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ce993a:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ce994a:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ce995a:-`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ce996a:-`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralized_management_console_software:7.0.01:sp1`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralized_management_console_software:8.0`,
        fs:  `cpe:2.3:a:sysflow:sysflowagent:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralized_management_console_software:8.1`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralized_management_console_software:8.5`,
        fs:  `cpe:2.3:a:mcafee:application_control:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralized_management_console_software:9.0`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.107:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_credit_risk_control:2.1`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_credit_risk_control:2.2`,
        fs:  `cpe:2.3:a:yahoo:messenger:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_credit_risk_control:2.3`,
        fs:  `cpe:2.3:a:omeka:omeka:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_dealer_performance_audit:2.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_dealer_performance_audit:2.1`,
        fs:  `cpe:2.3:a:collectiveaccess:pawtucket:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_fraud_risk_management:11.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_fraud_risk_management:11.2`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.03b27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_fraud_risk_management:11.3`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_revenue_leakage_control:4.1`,
        fs:  `cpe:2.3:a:sun:forte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_revenue_leakage_control:4.2`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-200d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_revenue_leakage_control:4.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_roaming_fraud_control:2.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_roaming_fraud_control:2.2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-50c-ei_ls-5100-50c-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_roaming_fraud_control:2.3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_subscription_fraud_prevention:2.0`,
        fs:  `cpe:2.3:a:google:drive:1.0.77:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:centralview_subscription_fraud_prevention:2.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf066a:-`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.00.020.1523:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf067a:-`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf068a:-`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.31.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf069a:-`,
        fs:  `cpe:2.3:a:instantasp:instantforum:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf081a:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf082a:-`,
        fs:  `cpe:2.3:a:google:v8:3.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf083a:-`,
        fs:  `cpe:2.3:a:ubercart_views_project:uc_views:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf116a:-`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf117a:-`,
        fs:  `cpe:2.3:o:f5:tmos:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf118a:-`,
        fs:  `cpe:2.3:h:cisco:aironet_3600e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf235a:-`,
        fs:  `cpe:2.3:a:apache:camel:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf236a:-`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:01-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf238a:-`,
        fs:  `cpe:2.3:o:sun:solaris:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cf367a:-`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:chaivm:-`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.4p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:a.01.05`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:a.01.06`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:a.01.07`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:a.01.08`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:a.01.08.01`,
        fs:  `cpe:2.3:a:microsoft:access:2013:*:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:a.01.09`,
        fs:  `cpe:2.3:a:vips:vips:7.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:a.01.09.01`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cifs-9000_server:a.01.09.02`,
        fs:  `cpe:2.3:a:autodesk:vred:2014:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:1.0.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.49:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:2.1.0`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:2.1.2`,
        fs:  `cpe:2.3:a:cisco:desktop_supervisor:6.1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:2.1.4`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:2.1.5`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:2.1.6`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5216l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:2.2.4::~~~~x64~`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:3.1.1`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_pdf_sdk_activex:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:3.2.1::~~~~x64~`,
        fs:  `cpe:2.3:a:quagga:quagga:0.98.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:4.1.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:4.2.1::~~~~x64~`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:6.1.1`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.547:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:6.1.2`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(2\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:6.2.2::~~~~x64~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:7.1.4`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.1.0:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:7.1.5`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:7.1.7`,
        fs:  `cpe:2.3:a:hp:web_registration:53.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:7.2.4::~~~~x64~`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:7.2.5::~~~~x64~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.02:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:8.1.1`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:8.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:8.2.1::~~~~x64~`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:8.2.2::~~~~x64~`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cio_components_installer:8.2.4::~~~~x64~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:client_automation_administrator:7.80`,
        fs:  `cpe:2.3:a:smarttech:smart_classroom_suite_teacher:1.0.1059.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:client_automation_application_manager_agent:7.80`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:client_automation_core:7.80.0`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:client_automation_satellite:7.80.0`,
        fs:  `cpe:2.3:a:sybase:central:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:-`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1n\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:a.01.03`,
        fs:  `cpe:2.3:a:todo_filter_project:todo_filter:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:b.01.04`,
        fs:  `cpe:2.3:a:pocketmags:front:\@7f08017a:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:b.02.01.02`,
        fs:  `cpe:2.3:a:plxtech:remotecomms_external_disk_access:1.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:b.02.02.00`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:b.02.02.02`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.04:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:b.03.00.00`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:b.03.00.01`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cluster_object_manager:b.03.01.02`,
        fs:  `cpe:2.3:a:style_it_project:style_it:1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cm8050_color_mfp:-`,
        fs:  `cpe:2.3:a:facebook:logosquest_-_beginnings:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cm8060_color_mfp:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_inkjet_cp1160:-`,
        fs:  `cpe:2.3:a:ibm:advanced_settings_utility:3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_inkjet_cp1700:-`,
        fs:  `cpe:2.3:o:d-link:dcs-5222l__firmware:2.12.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_1500:-`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_2500:-`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:color_laserjet_2500_toolbox:-`,
        fs:  `cpe:2.3:a:pansi:pansi_sms:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_2500l:-`,
        fs:  `cpe:2.3:a:novell:filr:1.2:security_update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_2500lse:-`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_2500n:-`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.3.2:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_2500tn:-`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_2550:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_3000:q7534a`,
        fs:  `cpe:2.3:a:gnome:evolution:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_3800:q5981a`,
        fs:  `cpe:2.3:a:docker:docker:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_4550:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2\(0.747\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_4600:-`,
        fs:  `cpe:2.3:a:adobe:coldfusion:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:color_laserjet_4600_toolbox:-`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_4650:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1651.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_4700:-`,
        fs:  `cpe:2.3:h:apc:1500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_4700:q7492a`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:color_laserjet_4700_driver:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_4730_mfp:-`,
        fs:  `cpe:2.3:a:sos_recette_project:sos_recette:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_4730_mfp:cb480a`,
        fs:  `cpe:2.3:a:ca:unicenter_service_desk_knowledge_tools:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_5550:-`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_5550:q3714a`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_8500:-`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0009:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_8550:-`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_9500:-`,
        fs:  `cpe:2.3:a:horde:imp:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_9500_mfp:-`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_9500_mfp:c8549a`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.60.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cm1312nfi_multifunction_printer:cc431a`,
        fs:  `cpe:2.3:o:cisco:ios_xr:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cm2320n_multifunction_printer:cc434a`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cm6030_mfp:ce664a`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cm6040_mfp:q3939a`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.1.2401:online_windows_server_2003_x64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:color_laserjet_cp1210_series_toolbox:1.0.21`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp1515:cc377a`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp1518:cc378a`,
        fs:  `cpe:2.3:a:process-one:exmpp:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp2025_printer:cb494a`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.200:update20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp3505:cb442a`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp3525:cc469a`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.14:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp4005:cb503a`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.3:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:color_laserjet_cp4520-cp4020_series_screen_fonts:2.0.0.0`,
        fs:  `cpe:2.3:a:novell:access_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:color_laserjet_cp4520-cp4020_series_user_guide:1.0.0.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.4:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp5225:ce710a`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp5225:ce711a`,
        fs:  `cpe:2.3:a:alberto_pittoni:alguest:1.1:c-patched:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp5225:ce712a`,
        fs:  `cpe:2.3:a:moodle:moodle:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_cp6015:q3932a`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_enterprise_cp4025:cc490a`,
        fs:  `cpe:2.3:a:php:php:5.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_enterprise_cp4525:cc493a`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_m575dn:-`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_m575f:-`,
        fs:  `cpe:2.3:a:spip:spip:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_m775dn:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_m775f:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.4yb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_m775z:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:268:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:color_laserjet_m775z%2b:-`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:compaqhttpserver:-`,
        fs:  `cpe:2.3:a:avaya:vsu_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:compaqhttpserver:9.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:continuous_delivery_automation:1.3.0`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:copy:45.4.157.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:copy:90.0.146.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:copy:100.0.170.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cp1160_network_printer:-`,
        fs:  `cpe:2.3:a:nancy_wichmann:announcements:6.x-1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cp1700_network_printer:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects:45.4.157.0`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_atenashokunin1config:45.4.131.0`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_atenashokunin1config:53.0.13.0`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.5.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_calendartemplates1:53.0.13.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_calendartemplates1:70.0.170.0`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.2.0.6504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_dwshrek2albums1:45.4.157.0`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_dwshrek2cards1:45.4.157.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_onlineprojectsconfig:70.0.170.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_package_basic1:53.0.13.0`,
        fs:  `cpe:2.3:a:libav:libav:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_package_basic1:70.0.170.0`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_package_variety1:53.0.13.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_package_variety2:53.0.13.0`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_package_variety3:53.0.13.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.48:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_panorama1config:53.0.13.0`,
        fs:  `cpe:2.3:h:hp:storevirtual_4330:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_panorama1config:70.0.170.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_plsbusinessflyers:45.4.157.0`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_posterprintconfig:70.0.170.0`,
        fs:  `cpe:2.3:a:gnu:radius:0.92.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:creativeprojects_templates:45.4.157.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.13.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cuetour:45.4.157.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cuetour:53.0.13.0`,
        fs:  `cpe:2.3:a:justsystems:atok:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:cuetour:70.0.170.0`,
        fs:  `cpe:2.3:a:hp:centralview_subscription_fraud_prevention:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:customer_participation_program:7.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:customer_participation_program:8.0`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:customer_participation_program:9.0`,
        fs:  `cpe:2.3:a:ibm:forms_viewer:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:customer_participation_program:10.0`,
        fs:  `cpe:2.3:a:opsview:opsview:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:customer_participation_program:12.0`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:customer_participation_program:14.0`,
        fs:  `cpe:2.3:a:compaq:intelligent_cluster_administrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cz244a:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cz245a:-`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cz249a:-`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cz250a:-`,
        fs:  `cpe:2.3:a:intel:network_connections:15.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cz255a:-`,
        fs:  `cpe:2.3:a:sympa:sympa:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cz256a:-`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cz257a:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:cz258a:-`,
        fs:  `cpe:2.3:a:gnome:gnome:-:*:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:d3l08a:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)t6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:d3l09a:-`,
        fs:  `cpe:2.3:a:openfabrics:ibacm:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:d3l10a:-`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-3510c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:d4100_help:70.0.260.0`,
        fs:  `cpe:2.3:a:scripteen:free_image_hosting_script:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:d7p70a:-`,
        fs:  `cpe:2.3:a:x.org:libx11:1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:d7p71a:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector:6.10`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector:6.11`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector:7.03`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector:8.14`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector:9.05`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector_express:5.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.0:preflight1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector_express:6.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector_media_operations:5.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector_media_operations:5.1`,
        fs:  `cpe:2.3:a:redhat:rhevm-reports:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector_media_operations:5.5`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector_media_operations:6.10`,
        fs:  `cpe:2.3:a:apache:mod_python:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:data_protector_media_operations:6.11`,
        fs:  `cpe:2.3:a:redhat:wu_ftpd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:database_and_middleware_automation:10.0`,
        fs:  `cpe:2.3:a:psychostats:psychostats:3.2.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:database_and_middleware_automation:10.01`,
        fs:  `cpe:2.3:a:redhat:conga:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:database_and_middleware_automation:10.10`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:database_and_middleware_automation:10.20`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:database_and_middleware_automation:10.20.100`,
        fs:  `cpe:2.3:a:powerarchiver:powerarchiver:14.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:dc7900:-`,
        fs:  `cpe:2.3:a:netgear:prosafe_network_management_software_300:1.5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:decnet_osi:-`,
        fs:  `cpe:2.3:a:linux-atm:linux-atm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:designjet_1055:-`,
        fs:  `cpe:2.3:a:noodlecake:super_stickman_golf:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:designjet_500ps:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_omegamon_xe_for_messaging:601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:designjet_5500:-`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:designjet_755:-`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:deskjet_1220c:-`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:deskjet_3420_color_inkjet:-`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:deskjet_3820_color_inkjet:-`,
        fs:  `cpe:2.3:h:avaya:csu_5000:3.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:deskjet_5850:-`,
        fs:  `cpe:2.3:a:autodesk:civil_design:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:deskjet_694c:-`,
        fs:  `cpe:2.3:o:iij:seil\%2fneu_2fe_plus_firmware:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:deskjet_single_function_software:90.0.200.0`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:deskjet_single_function_software_req:90.0.200.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc1:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:hp:deskjet_taplugin:60.0.196.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:desms:-`,
        fs:  `cpe:2.3:a:php:pear:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destination_component:90.0.91.86`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destination_component:100.0.0.0`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destination_component:110.0.0.0`,
        fs:  `cpe:2.3:a:cisco:jabber:9.6\(0\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destinations:45.4.157.0`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destinations:53.0.13.0`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destinations:53.0.24.0`,
        fs:  `cpe:2.3:h:ibm:bladecenter:hs23e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destinations:60.0.155.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destinations:70.0.170.0`,
        fs:  `cpe:2.3:a:t1lib:t1lib:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destinations:82.0.173.0`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destinations:130.0.0.0`,
        fs:  `cpe:2.3:a:core-apps:eage_amsterdam_2014:6.1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:destinations:140.0.77.0`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:device_discovery:90.0.146.0`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:device_discovery:90.0.205.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:device_discovery:100.0.190.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(4\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:device_discovery:110.0.180.0`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_database_control:11.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:device_discovery:120.0.194.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:device_discovery:140.0.212.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.304:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:device_discovery:140.0.213.0`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:8.00`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:8.01`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:8.02`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:8.03`,
        fs:  `cpe:2.3:a:gnu:less:382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:8.04`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:8.05`,
        fs:  `cpe:2.3:a:citrix:secure_gateway_for_metaframe_secure_ticket_authority:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:8.06`,
        fs:  `cpe:2.3:a:90meter:cac_smartcard_manager-90:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:8.07`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:9.00`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6ccg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:9.01`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:9.02`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l2_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:9.10`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:9.12`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je166a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:9.20`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:diagnostics_server:9.21`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:digital_sender_8100c:-`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:digital_sender_9100c:-`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:digital_sender_9200c:-`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:digital_sender_9250c:cb472a`,
        fs:  `cpe:2.3:a:ontariosystems:artiva_rm:3.1:mr7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:digital_sending_software:4.10.5`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:digital_sending_software:4.91.21`,
        fs:  `cpe:2.3:a:pfsense:pfsense:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:director:45.4.157.0`,
        fs:  `cpe:2.3:a:c-3.co.jp:webcalenderc3:0.32:s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:directories_support_for_proliant_management_processors:3.10`,
        fs:  `cpe:2.3:a:tadaa\!_project:tadaa\!:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:directories_support_for_proliant_management_processors:3.20`,
        fs:  `cpe:2.3:a:digium:asterisk:13.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:directories_support_for_proliant_management_processors:3.30`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_manager:1.0`,
        fs:  `cpe:2.3:o:huawei:s9712_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_manager:2.0`,
        fs:  `cpe:2.3:a:apple:itunes:12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_manager:100.0.201.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_manager:120.0.0.0`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_viewer:5.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.6:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_viewer:7.0`,
        fs:  `cpe:2.3:a:oracle:jdeveloper:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_viewer:45.4.157.0`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_viewer:53.0.13.0`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:-:*:tru64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:document_viewer:70.0.170.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:dtmail:-`,
        fs:  `cpe:2.3:h:3com:3c16950-us:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:dynrootdisk:-`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:dynrootdisk:a.1.0.16.417`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p2_rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:dynrootdisk:a.1.0.18.245`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:dynrootdisk:a.1.1.0.344`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.4:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:dynrootdisk:a.2.0.0.592`,
        fs:  `cpe:2.3:a:vmware:tools:3.1.2.20911:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:e%2fa_agent_japanese_localization:8.60.7`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:e%2fa_agent_korean_localization:8.60.7`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:e%2fa_agent_simplified_chinese_localization:8.60.7`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:e%2fa_agent_spanish_localization:8.60.7`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:easy_tools:3.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitebook_725_g3:-`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitebook_745_g3:-`,
        fs:  `cpe:2.3:o:cisco:catos:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitebook_755_g3:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitebook_820_g3:-`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:313.30:-:*:*:sunos:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitebook_840_g3:-`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitebook_850_g3:-`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitebook_folio_1012_x2_g2:-`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2000_server:6.3.403:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitebook_folio_1040_g3:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p67:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitedesk_705_g2_dm:-`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitedesk_705_g2_mt_sff:-`,
        fs:  `cpe:2.3:h:nortel:vpn_router_2700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitedesk_800_g2_dm:-`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitedesk_800_g2_twr:-`,
        fs:  `cpe:2.3:a:electric_cloud:electriccommander:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:elitedesk_800_sff:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.09.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:eliteone_705_g2_23in_aio_t%2fnt:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p1_rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:eliteone_800_g2_23in_t%2fnt:-`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110627:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:employee_expense_management_system:3.5`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update1:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:enterprise:47.0.1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:enterprise:50.0.165.0`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:enterprise:50.0.227.0`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:enterprise_maps:1.00`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:enterprise_npi:70.0.200.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je089a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:eprint_and_share:1.1.0`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:esupportdiagnostics:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:esupportdiagnostics:1.0.11.0`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.3enp2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:eva_3000:-`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:eva_3000_array_control_software:-`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:eva_5000:-`,
        fs:  `cpe:2.3:a:macromedia:flash_player:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:event_monitoring_service:a.04.20.11.04`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.1.0:mr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:event_monitoring_service:a.04.20.11.04:1`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:event_monitoring_service:a.04.20.11.05`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:event_monitoring_service:a.04.20.23.06`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.18:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:event_monitoring_service:a.04.20.31.07`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:executive_scorecard:9.40`,
        fs:  `cpe:2.3:h:lexmark:x85x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:executive_scorecard:9.41`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:extended_capabilities:6.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax:47.0.1.0`,
        fs:  `cpe:2.3:a:python:python:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax:50.0.206.0`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_opstor:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax:82.0.188.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax:100.0.187.0`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax:100.0.272.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax:120.0.194.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.6.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax:140.0.212.0`,
        fs:  `cpe:2.3:a:ca:license_software:1.90.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax:140.0.213.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax_cda:70.0.231.0`,
        fs:  `cpe:2.3:a:dell:powervault_modular_disk_storage_manager:3.35.x6.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fax_cda:71.0.215.0`,
        fs:  `cpe:2.3:a:posh_project:posh:2.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fortify_software_security_center:3.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fortify_software_security_center:3.3`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fortify_software_security_center:3.4`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:fortify_software_security_center:3.5`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.50826.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ftp_print_server:-`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ftp_print_server:2.4`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ftp_print_server:2.4.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.10:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:futuresmart_firmware:3.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:gpbaseservice:100.0.187.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:graphical_pos_pole_display_qz704aa:-`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.11:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-28c-ei`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-28c-ei-dc`,
        fs:  `cpe:2.3:a:knowledgetree:knowledgetree:3.5.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-28c-pwr-ei`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-28c-pwr-si`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-28c-si`,
        fs:  `cpe:2.3:a:xnview:xnview:1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-28f-ei`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2.1:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-52c-ei`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-52c-pwr-ei`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-52c-pwr-si`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5500-52c-si`,
        fs:  `cpe:2.3:a:atutor:atutor:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5600-26c`,
        fs:  `cpe:2.3:a:ibm:operational_decision_manager:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5600-26c-pwr`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5600-26f`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5600-50c`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s5600-50c-pwr`,
        fs:  `cpe:2.3:h:siemens:s55:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s7502e`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s7503e`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s7503e-s`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s7506e`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s7506e-v`,
        fs:  `cpe:2.3:a:debian:adequate:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_ethernet_switch:s7510e`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_high_performance_main_processing_unit:msr_50_3ge`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_processing_module:msr_50_g2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_processor_module:msr_50`,
        fs:  `cpe:2.3:a:debian:reportbug:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-10`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:20.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-11`,
        fs:  `cpe:2.3:a:freedesktop:libdbus:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-12`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-12_t1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-13`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-13_w`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-15`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-15_a`,
        fs:  `cpe:2.3:o:schneider_electric:struxureware_building_operations_automation_server_as_firmware:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-15_a_w`,
        fs:  `cpe:2.3:a:telerik:asp.net_ajax_radeditor_control:2014.1.403.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-15_iw`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0:alpha_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-20`,
        fs:  `cpe:2.3:a:adobe:pdf_library_sdk:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-21`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_20-40`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.22-25.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_30-10`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_30-20`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:108.2146.2565.38893:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_30-20_poe`,
        fs:  `cpe:2.3:o:checkpoint:gaia_os:r76.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_30-20_rtvz33020as`,
        fs:  `cpe:2.3:a:gajim:gajim:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_30-40`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_30-40_poe`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_30-60`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:5.5.0.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_30-60_poe`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_50-40`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1669.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_50-60`,
        fs:  `cpe:2.3:o:cisco:unified_wireless_ip_phone_7920_firmware:2.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_900`,
        fs:  `cpe:2.3:a:x:libxrandr:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_920`,
        fs:  `cpe:2.3:a:logitech:backweb:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_3010`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_3016`,
        fs:  `cpe:2.3:a:serf_project:serf:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr_3016_poe`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:msr5040-dc-ovs-h3c`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sxd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2011-ac-ovs-h3`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2012-ac-ovs-h3`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2012-ac-ovs-s-h3`,
        fs:  `cpe:2.3:a:cybozu:mailwise:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2012-ac-ovs-w-h3`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2012-t-ac-ovs-h3`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2013-ac-ovs-h3`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_standalone:4.0.0.146302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2013-ac-ovs-w-h3`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2015-ac-ovs-a-h3`,
        fs:  `cpe:2.3:a:hp:openview_emanate_snmp_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2015-ac-ovs-aw-h3`,
        fs:  `cpe:2.3:a:isc:dhcp:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2015-ac-ovs-i-h3`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp2:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2015-ac-ovs-iw-h3`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2020-ac-ovs-h3c`,
        fs:  `cpe:2.3:a:cisco:secure_services_client:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2040-ac-ovs-h3`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr2040-ac-ovs-h3c`,
        fs:  `cpe:2.3:a:gnu:coreutils:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3011-ac-ovs-h3`,
        fs:  `cpe:2.3:a:lyften:com_lyftenbloggie:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3016-ac-ovs-h3`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3016-ac-poe-ovs-h3`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3020-ac-poe-ovs-h3`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1019.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3020-dc-ovs-h3`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3040-ac-ovs-as-h3`,
        fs:  `cpe:2.3:a:digium:asterisk:14.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3040-ac-ovs-h`,
        fs:  `cpe:2.3:a:mahara:mahara:16.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3040-ac-poe-ovs-h3`,
        fs:  `cpe:2.3:a:php:php:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3060-ac-ovs-h3`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3060-ac-poe-ovs-h3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr3060-dc-ovs-h3`,
        fs:  `cpe:2.3:a:lightdm_project:lightdm:1.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:rt-msr5060-ac-ovs-h3`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:sr_20-12_w`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:sr8802`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:sr8805`,
        fs:  `cpe:2.3:o:cisco:ios:10.3\(4.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:sr8808`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.21:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_router:sr8812`,
        fs:  `cpe:2.3:a:gnome:epiphany:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_routing_switch:s9505e`,
        fs:  `cpe:2.3:o:f5:tmos:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_routing_switch:s9508e-v`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110919:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_routing_switch:s9512e`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_routing_switch:s12508`,
        fs:  `cpe:2.3:a:gnu:coreutils:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_routing_switch:s12518`,
        fs:  `cpe:2.3:a:atlassian:jira:2.4.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-8c-si_ls-s3100-8c-si-ac-ovs`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-8c-si_ls-s3100-8c-si-dc-ovs`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa_bosh:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-8t-si_ls-s3100-8t-si-ac-ovs`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:5.5.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-16c-si_ls-s3100-16c-si-ac-ovs`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)xm2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-16c-si_ls-s3100-16c-si-dc-ovs`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-16t-si_ls-s3100-16t-si-ac-ovs`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-26c-si_ls-s3100-26c-si-ac-ovs`,
        fs:  `cpe:2.3:a:theonegames:gunship_battle\:helicopter_3d:1.1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-26c-si_ls-s3100-26c-si-dc-ovs`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-26t-si_ls-s3100-26t-si-ac-ovs`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3100-52p_ls-3100-52p-ovs-h3`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-28f-ei_ls-3600-28f-ei-ovs`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-28p-ei_ls-3600-28p-ei-ovs`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-28p-pwr-ei_ls-3600-28p-pwr-ei-ovs`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.05:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-28p-pwr-si_ls-3600-28p-pwr-si-ovs`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.9.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-28p-si_ls-3600-28p-si-ovs`,
        fs:  `cpe:2.3:a:samba:samba:3.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-28tp-si_ls-3600-28tp-si-ovs`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-52p-ei_ls-3600-52p-ei-ovs`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-52p-pwr-ei_ls-3600-52p-pwr-ei-ovs`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-52p-pwr-si_ls-3600-52p-pwr-si-ovs`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:1.2.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3600-52p-si_ls-3600-52p-si-ovs`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3610-28f_ls-3610-28f-ovs`,
        fs:  `cpe:2.3:a:tincan:phplist:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3610-28p_ls-3610-28p-ovs`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3610-28tp_ls-3610-28tp-ovs`,
        fs:  `cpe:2.3:a:php:php:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s3610-52p_ls-3610-52p-ovs`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-8p-ei_ls-5100-8p-ei-ovs-h3`,
        fs:  `cpe:2.3:a:heartlogic.jp:hl-sitemanager:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-8p-pwr-ei_ls-5100-8p-pwr-ei-ovs`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.22:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-8p-si_ls-5100-8p-si-ovs-h3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-16p-ei_ls-5100-16p-ei-ovs-h3`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-16p-pwr-ei_ls-5100-16p-pwr-ei-ovs`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-16p-si_ls-5100-16p-si-ovs-h3`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:-:syslog:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-24p-ei_ls-5100-24p-ei-ovs`,
        fs:  `cpe:2.3:a:vmware:movie_decoder:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-24p-si_ls-5100-24p-si-ovs-h3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-26c-ei_ls-5100-26c-ei-ovs`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-26c-pwr-ei_ls-5100-26c-pwr-ei-ovs`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-48p-ei_ls-5100-48p-ei-ovs`,
        fs:  `cpe:2.3:a:apache:wicket:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-48p-si_ls-5100-48p-si-ovs-h3`,
        fs:  `cpe:2.3:a:pageplanetsoftware:mgi_server:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-50c-ei_ls-5100-50c-ei-ovs`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5100-50c-pwr-ei_ls-5100-50c-pwr-ei-ovs`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.4:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-20p-si`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-24p-ei`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:8.0\(2\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-28c-ei`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-28c-pwr-ei`,
        fs:  `cpe:2.3:a:hp:proliant_remote_monitor_service:5.11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-28p-hpwr-si`,
        fs:  `cpe:2.3:a:emc:eroom:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-28p-pwr-si`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-28p-si`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-48p-ei`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-52c-ei`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-52c-pwr-ei`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5120-52p-si`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5800-32c`,
        fs:  `cpe:2.3:a:mcafee:cloud_analysis_and_deconstructive_services:1.0.0.4d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5800-32c-pwr`,
        fs:  `cpe:2.3:a:digium:asterisk:13.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5800-32f`,
        fs:  `cpe:2.3:a:redhat:network_satellite:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5800-56c`,
        fs:  `cpe:2.3:a:ca:workload_automation_ae:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5800-56c-pwr`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5800-60c-pwr`,
        fs:  `cpe:2.3:a:eng:spagobi:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5820x-28c`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd241a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s5820x-28s`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s7502e`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s7503e`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s7503e-s`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s7506e`,
        fs:  `cpe:2.3:a:f5:linerate:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s7506e-v`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s9505e`,
        fs:  `cpe:2.3:a:apache:maven:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s9508e-v`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:27.25.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s12508`,
        fs:  `cpe:2.3:a:boost:boost:1.55.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:h3c_switch:s12518`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:headless_server_registry_update:1.0.0.0`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0003_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:help_and_support_center:-`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:help_and_support_center:4.4_b`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2011.728.1723.29300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hotspot_laserjet_pro_m1218nfs_mfp_firmware:20130703`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:-`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0515:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:7.00`,
        fs:  `cpe:2.3:a:ipswitch:imail:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:7.02`,
        fs:  `cpe:2.3:a:apache:struts:2.3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:7.04`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:7.06`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:7.08`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.00`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.01`,
        fs:  `cpe:2.3:a:gnu:glibc:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.02`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.04`,
        fs:  `cpe:2.3:a:autoit:autoit:3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.05`,
        fs:  `cpe:2.3:a:iss:realsecure_event_collector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.06`,
        fs:  `cpe:2.3:a:gnu:grep:2.5.3:*:*:*:gnuwin32:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.07`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.08`,
        fs:  `cpe:2.3:h:hp:retail_integrated_2x20_display_g6u79aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:8.09`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.1.4:p11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.00`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.01`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.03`,
        fs:  `cpe:2.3:a:rpm:rpm:4.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.04`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.05`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.06`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.07`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.08`,
        fs:  `cpe:2.3:a:redhat:jboss_bpm_suite:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.09`,
        fs:  `cpe:2.3:a:spice_project:spice:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:9.10`,
        fs:  `cpe:2.3:a:sap:emr_unwired:-:-:--:*:-:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10`,
        fs:  `cpe:2.3:a:mathew_winstone:mobile_tools:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.00`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.01`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.02`,
        fs:  `cpe:2.3:a:tm_software:tempo:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.03`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.08`,
        fs:  `cpe:2.3:a:apache:commons_fileupload:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.09`,
        fs:  `cpe:2.3:a:hp:software_process_control:6.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.10`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.16`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.20`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.24`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.26`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.12.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.30`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:10.34`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.00`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.2`,
        fs:  `cpe:2.3:a:call-cc:http-client:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.04`,
        fs:  `cpe:2.3:a:tweetscribe_project:tweetscribe:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:hu:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.10`,
        fs:  `cpe:2.3:a:docker:docker:0.12.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.11`,
        fs:  `cpe:2.3:a:busybox:busybox:1.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.11i`,
        fs:  `cpe:2.3:a:wcs4web:easywebrealestate:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.20`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.22`,
        fs:  `cpe:2.3:a:lumension:patchlink_update_server:6.2.0.181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.23`,
        fs:  `cpe:2.3:h:nvidia:quadro_m5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:11.31`,
        fs:  `cpe:2.3:a:wdc:smartware:1.2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:b.11.11`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:b.11.23`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux:b.11.31`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hp-ux_containers:a.03.00`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.62:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hp-ux_containers:a.03.00.002`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hp-ux_containers:a.03.01`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p73:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hp-ux_containers:a.03.01.001`,
        fs:  `cpe:2.3:a:hummingbird:bi_query_user:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hp-ux_ipfilter:a.11.31.18.21`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux_series_700:-`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.1:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux_series_700:10.20`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux_series_800:-`,
        fs:  `cpe:2.3:h:linksys:befw11s4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp-ux_series_800:10.20`,
        fs:  `cpe:2.3:a:gimp:gimp:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hp-ux_whitelisting:a.01.02`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6ebz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hp-ux_whitelisting:a.01.02.02`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp_h-series_fibre_channel_switch_firmware:8.0`,
        fs:  `cpe:2.3:a:playscape:bouncy_bill_seasons:1.3.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:hp_h-series_fibre_channel_switch_firmware:8.0.14.08.00`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:hp_laserjet_pro_m1214nfh_mfp:ce842a`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpf_productcontext:60.0.196.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hph_productcontext:70.0.260.0`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hph_readme:70.0.260.0`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_basic_runtime_for_visual_studio_2008:10.5.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:hp:hph_software:70.0.260.0`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hph_software_req:70.0.260.0`,
        fs:  `cpe:2.3:a:cisco:jabber_guest:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppdustdevil:2.0.4`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppfaxdrv:2.0.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppfaxutility:0.105.94`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppfaxutility:2.101.2`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppfonts:0.1.54`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.1.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppfonts:0.106.40`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc226xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppfonts:1.1.56`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:7.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppfonts:1.1.61`,
        fs:  `cpe:2.3:a:luracast:restler:0.3.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppfonts:2.0.4`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppiofiles:0.1.10`,
        fs:  `cpe:2.3:a:gnu:userv:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppiofiles:1.1.24`,
        fs:  `cpe:2.3:a:debian:shadow:4.0.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppiofiles:1.2.27`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppiofiles:2.0.4`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppiofiles:2.0.30`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppmsredist:1.0.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x55:d35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppscanto:0.105.89`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p209:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppscanto:1.0.119`,
        fs:  `cpe:2.3:h:nokia:ip440_firewall_vpn_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppscanto:1.102.3`,
        fs:  `cpe:2.3:a:busybox:busybox:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppscanto:2.0.4`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppscanto:2.102.2`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppscanto:2.102.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppsendfax:0.105.81`,
        fs:  `cpe:2.3:h:hp:proliant_dl180_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppsendfax:1.102.3`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.0:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppsendfax:2.0.4`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpptoocool:0.105.58`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:940n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpptoocool:2.0.4`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpptoolboxfx:1.2.83`,
        fs:  `cpe:2.3:a:dressup:dress_up\!_girl_party:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hppwebregmm:0.1.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpsockd:-`,
        fs:  `cpe:2.3:h:huawei:s7706:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpssupply:2.1.1.0`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpssupply:2.1.3.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.8:cert1_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpssupply:2.2.0.0`,
        fs:  `cpe:2.3:a:cisco:email_security_appliance:9.7.1-hp2-207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpssupply:100.0.170.0`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpssupply:100.0.172.0`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpssupply:120.0.194.0`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc7:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpssupply:140.0.211.0`,
        fs:  `cpe:2.3:a:ibm:sbma_smi_provider:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpssupply:140.0.212.0`,
        fs:  `cpe:2.3:h:hp:jg354a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpztlbxfx:0.206.197`,
        fs:  `cpe:2.3:a:xceedium:xsuite:2.4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpztlbxfx:1.2.139`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2012:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpztlbxfx:2.2.170`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.5-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpztlbxfx:3.7.281`,
        fs:  `cpe:2.3:a:context_project:context:7.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpztlbxfx:4.9.140`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_security_suite:6.5.722.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpztlbxfx:4.17.154`,
        fs:  `cpe:2.3:a:microsoft:pspasswd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:hpztlbxfx:5.13.185`,
        fs:  `cpe:2.3:a:red-gate:sql_dependency_tracker:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:http_communication:6.10.50`,
        fs:  `cpe:2.3:a:rack_project:rack:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:http_communication:6.10.70`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:http_communication:6.20.50`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:http_server:-`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:http_server:5.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:http_server:5.92`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:http_server:5.93`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:http_server:5.94`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:hybrid_pos_printer_with_micr_us_fk184aa:-`,
        fs:  `cpe:2.3:h:d-link:dcs-2332l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ibrix:6.1.196`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ibrix:6.1.210`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ibrix:6.1.228`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ibrix:6.1.243`,
        fs:  `cpe:2.3:h:supermicro:h8dct-ibqf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ibrix:6.1.247`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.04.019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ibrix:6.1.249`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ibrix:6.1.251`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.2:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ibrix_x9300:aw539d`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ibrix_x9300:aw540d`,
        fs:  `cpe:2.3:a:busybox:busybox:0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ibrix_x9320:qp330b`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ibrix_x9320:qp331b`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ibrix_x9730:qz730a`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:ibrix_x9730:qz731a`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icc_profiles:2.0.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icc_profiles:2.0.0::~~~~x64~`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r009c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_federation_agent:3.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_federation_agent:8.0`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_file_manager:3.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_file_manager:3.0:sp1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.531:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_file_manager:3.0:sp2`,
        fs:  `cpe:2.3:a:juniper:setup_client_activex_control:1.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_file_manager:3.0:sp3`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_file_manager:3.0:sp4`,
        fs:  `cpe:2.3:a:samba:samba:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_java_agent_library:8.0`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.0.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_java_agent_library:8.0::2007`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_java_agent_library:10.0`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_mcrp:2.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_mcrp:3.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_smart_device_option:10.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso:10.0::~~dfw~~~`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.1.7.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:8.0`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:8.0::enterprise`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:8.0:r2:~~enterprise~~~`,
        fs:  `cpe:2.3:a:dotnetblogengine:blogengine.net:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:8.0:r2:~~standard~~~`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:8.0:r3:~~enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:global_order_promising:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:8.0:r3:~~standard~~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:8.0.1::~~standard~~~`,
        fs:  `cpe:2.3:a:webrtc_project:webrtc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:10.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:10.0::~~enterprise~windows~~`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:10.0::~~standard~~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent:10.0::~~standard~windows~~`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:5.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent_option:8.0`,
        fs:  `cpe:2.3:a:drupal:drupal:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent_option:8.0::~~2007~~~`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent_option:10.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_agent_option:10.0:r1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:icewall_sso_saml2_option:8.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:identity_driven_manager:4.0`,
        fs:  `cpe:2.3:a:microsoft:office:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:ignite-ux:-`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.7.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:-`,
        fs:  `cpe:2.3:a:dssearchagent_project:dssearchagent:1.0:beta10:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:a.3.5`,
        fs:  `cpe:2.3:h:cisco:hosting_solution_engine:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:a.3.6`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:a.3.7`,
        fs:  `cpe:2.3:a:boost:boost:1.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.3.5`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.3.6`,
        fs:  `cpe:2.3:a:avaya:interaction_center_voice_quick_start:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.3.7`,
        fs:  `cpe:2.3:a:simon_tatham:putty:2010-06-01:r8967:*:*:development_snapshot:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.3.8`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.4.0`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.4.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0sz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.4.3`,
        fs:  `cpe:2.3:a:gnu:grub:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.4.4`,
        fs:  `cpe:2.3:a:tincan:phplist:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.5.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.5.1`,
        fs:  `cpe:2.3:a:apache:camel:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.5.2`,
        fs:  `cpe:2.3:h:belden:hirschmann_l2e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.5.3`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:b.5.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:ignite-ux:c.6.2.241`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.2.241`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_lights_out:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.3`,
        fs:  `cpe:2.3:a:mobileeventguide:uber_b2b:1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.4`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.5`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.6`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.7`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.4:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.8`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.9.141`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.9.150`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.6.10`,
        fs:  `cpe:2.3:a:pygments:pygments:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.0`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.19.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:ignite-ux:c.7.0.212`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.0.212`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:ignite-ux:c.7.1.92`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.1.92`,
        fs:  `cpe:2.3:a:shiftdelete:sdn_forum:3.6.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:ignite-ux:c.7.2.93`,
        fs:  `cpe:2.3:h:avaya:s8700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.2.93`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.16a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:ignite-ux:c.7.3.144`,
        fs:  `cpe:2.3:h:supermicro:x9dr3-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.3.144`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.3.148`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.4.155`,
        fs:  `cpe:2.3:h:nec:univerge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.4.157`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-6520c_firmware:t430sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.5`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.6.98`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.6.100`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.40:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.7.93`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.7.98`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0595:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.8`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.0-30:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.9.254`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.9.260`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.9.261`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.10.472`,
        fs:  `cpe:2.3:h:sitecom:wl-174:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.10.474`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.11.439`,
        fs:  `cpe:2.3:a:janetter:janetter:2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ignite-ux:c.7.11.444`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)s5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:image_zone:4.5`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2610-24-pwr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:image_zone:4.7`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:image_zone:5.3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:image_zone_express:1.5.1.29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:imaging_barcode_scanner_bw868aa:-`,
        fs:  `cpe:2.3:a:jetbrains:intellij_idea:10.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:5.3`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:6.0`,
        fs:  `cpe:2.3:a:infoblox:netmri:6.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:7.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:8.0`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:9.0`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:g06.32.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:10.0`,
        fs:  `cpe:2.3:a:samba:samba:1.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:11.6`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:12.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:13.0`,
        fs:  `cpe:2.3:a:david_king:vino:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imaging_device_functions:14.0`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imc_branch_intelligent_management_system_software_module:-`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5600-26f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imc_branch_intelligent_management_system_software_module:5.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.0sid:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imc_branch_intelligent_management_system_software_module:5.1`,
        fs:  `cpe:2.3:a:qsxgroup:outlook_express_backup_wizard:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imc_branch_intelligent_management_system_software_module:5.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imc_branch_intelligent_management_system_software_module:7.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imc_branch_intelligent_management_system_software_module:7.0:e0201p02`,
        fs:  `cpe:2.3:o:cisco:ios:12.2se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:imc_service_operation_management_software_module:-`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:info_center:-`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:inkjet_2250_tn:-`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.6.0.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:inode_management_center_pc:5.0`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:inode_management_center_pc:5.0:e0101`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:inode_management_center_pc:5.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:inode_management_center_pc:5.1:e0304`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.8.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_contol:7.5`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_control_performance_management:5.0`,
        fs:  `cpe:2.3:a:vmware:tools:8.4.6.16648:*:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_control_performance_management:5.2`,
        fs:  `cpe:2.3:a:hp:status:140.0.256.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_control_performance_management:5.2.2`,
        fs:  `cpe:2.3:a:exim:exim:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_control_performance_management:6.0`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_for_plsql:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_control_performance_management:6.1`,
        fs:  `cpe:2.3:h:netgear:rt311:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_control_performance_management:6.2`,
        fs:  `cpe:2.3:a:google:v8:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_control_performance_management:6.3`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_control_server_deployment:-`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.0.0_a:offline`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.0.0_a:unknown:offline`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.2.1_a:offline`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.2.1_a:unknown:offline`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.0-15:online_linux`,
        fs:  `cpe:2.3:a:oracle:database_assistant:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.0-15:unknown:online_linux`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.0.878:online_windows_2000`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.0.878:online_windows_2003`,
        fs:  `cpe:2.3:a:humor_ironias_y_realidades_project:humor_ironias_y_realidades:0.63.13371.13576:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.0.878:unknown:online_windows_2000`,
        fs:  `cpe:2.3:a:tm_software:tempo:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.1-1:online_linux`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.1-1:unknown:online_linux`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.1.887:offline`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.3.1.887:unknown:offline`,
        fs:  `cpe:2.3:a:metacase:metaedit:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.4.1_a:offline`,
        fs:  `cpe:2.3:a:minitab:minitab:15.1.30:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.4.1_a:unknown:offline`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.5.0_a:offline`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:6.5.0_a:unknown:offline`,
        fs:  `cpe:2.3:a:cisco:unified_videoconferencing_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.0-30:online_linux`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.0-30:unknown:online_linux`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.1:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.0.1198:online_windows_2000`,
        fs:  `cpe:2.3:a:llvm:clang:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.0.1198:online_windows_2003`,
        fs:  `cpe:2.3:a:mathijs_koenraadt:search_api_sorts:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.0.1198:unknown:online_windows_2000`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.1-8:online_linux`,
        fs:  `cpe:2.3:o:ibm:flashsystem_v9000_firmware:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.1-8:unknown:online_linux`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.1.1219:online_windows_2000`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.1.1219:online_windows_server_2003`,
        fs:  `cpe:2.3:a:hitronsoft:nasim_guest_book:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.1.1219:unknown:online_windows_2000`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.1.1219:unknown:online_windows_server_2003`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.5:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.2_a:offline`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.0.2_a:unknown:offline`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.3.0:offline`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.3.0:unknown:offline`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.0-11:online_linux`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.8:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.0-11:unknown:online_linux`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.0.1570:online_windows_2000`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.05.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.0.1570:online_windows_2003_x64`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.0.1570:online_windows_server_2003`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.0.1570:unknown:online_windows_2000`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:7.0.172.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.0.1570:unknown:online_windows_server_2003`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.1:offline`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0.2359:unknown:online_windows_server_2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.4.1:unknown:offline`,
        fs:  `cpe:2.3:a:rsa:ace_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.0-14:online_linux`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.0-14:unknown:online_linux`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6:\(2a\)su3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.0.1679:online_windows_2000`,
        fs:  `cpe:2.3:a:samba:samba:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.0.1679:online_windows_2003`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.0.1679:online_windows_2003_x64`,
        fs:  `cpe:2.3:a:omeka:omeka:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.0.1679:unknown:online_windows_2000`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.2:offline`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.2:unknown:offline`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.4:offline`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.4:unknown:offline`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.5-1:online_linux`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.5-1:unknown:online_linux`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.47:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.5.1681:online_windows_2000`,
        fs:  `cpe:2.3:h:cisco:unified_sip_phone_3911:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.5.1681:online_windows_2003_x64`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.00.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.5.1681:online_windows_server_2003`,
        fs:  `cpe:2.3:a:sebastien_sauvage:webgobbler:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.5.1681:unknown:online_windows_2000`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.5.5.1681:unknown:online_windows_server_2003`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0:offline`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0:unknown:offline`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0-23:online_linux`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0-23:unknown:online_linux`,
        fs:  `cpe:2.3:a:apple:itunes:4.6.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0.1984:online_windows_2000`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0.1984:online_windows_2003_x64`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0.1984:online_windows_server_2003`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0.1984:unknown:online_windows_2000`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.0.1984:unknown:online_windows_server_2003`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.1:offline`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(8\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.1:unknown:offline`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.2_rev_a:offline`,
        fs:  `cpe:2.3:a:iojs:io.js:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.6.2_rev_a:unknown:offline`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0:offline`,
        fs:  `cpe:2.3:h:hp:jf817a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0:unknown:offline`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0-142:online_linux`,
        fs:  `cpe:2.3:a:hp:scan:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0-142:unknown:online_linux`,
        fs:  `cpe:2.3:a:gnome:glib:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0.2112:online_windows_server_2003`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.14.4525:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0.2112:online_windows_server_2003_x64`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0.2112:unknown:online_windows_server_2003`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0.2112:unknown:online_windows_server_2003_x64`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0_rev_b:offline`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.0_rev_b:unknown:offline`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.101_2097:offline`,
        fs:  `cpe:2.3:a:infoblox:netmri:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.7.101_2097:unknown:offline`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.8.0-159:unknown:online_linux`,
        fs:  `cpe:2.3:o:netgear:prosafe_firmware:5.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.8.0.2257:online_windows_server_2003`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:09.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.8.0.2257:online_windows_server_2003_x64`,
        fs:  `cpe:2.3:a:hp:database_and_middleware_automation:10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.8.0.2257:unknown:online_windows_server_2003`,
        fs:  `cpe:2.3:a:cisco:finesse:10.6\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.8.0.2257:unknown:online_windows_server_2003_x64`,
        fs:  `cpe:2.3:a:oracle:oracle_data_provider_for_.net_help:10.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0`,
        fs:  `cpe:2.3:h:cisco:ips_4270-20:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0:offline`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0:unknown:offline`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p309:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0-105:unknown:online_linux`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0.2359:online_windows_server_2003`,
        fs:  `cpe:2.3:a:progress:openedge:9.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0.2359:online_windows_server_2003_x64`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp3:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0.2359:unknown:online_windows_server_2003`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0.2359:unknown:online_windows_server_2003_x64`,
        fs:  `cpe:2.3:h:huawei:quidway_s5700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0_rev_a:offline`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.0_rev_a:unknown:offline`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.1-15:unknown:online_linux`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.2.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.1.2401:online_windows_server_2003`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.1.2401:online_windows_server_2003_x64`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.1.2401:unknown:online_windows_server_2003`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:7.9.1.2401:unknown:online_windows_server_2003_x64`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics:9.4.0.4710`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:7.4.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:7.6.0`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:7.7.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:7.8.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.1.1`,
        fs:  `cpe:2.3:a:cmu:flite:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.1.5`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.1:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.2.0`,
        fs:  `cpe:2.3:a:google:v8:3.23.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.2.5`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.3.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.45.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.4.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.6.0`,
        fs:  `cpe:2.3:a:nancy_wichmann:taxonomy_list:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_diagnostics_online_edition_for_windows:8.7.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management:7.4`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:7.70.0.0`,
        fs:  `cpe:2.3:a:iij:seil\/x2_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:7.80.0.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:7.90.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.0.0.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.11.0.0`,
        fs:  `cpe:2.3:o:huawei:s9703_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.15.0.0`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.2:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.20.0.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.26.0.0`,
        fs:  `cpe:2.3:a:cisco:webns:7.50.3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.30.0.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.40.0.0`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.50.0.0`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.60.0.0`,
        fs:  `cpe:2.3:a:redhat:openshift:1.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agent:8.70.0.0`,
        fs:  `cpe:2.3:a:samba:samba:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:6.30.0.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:6.31.0.0:b`,
        fs:  `cpe:2.3:o:debian:debian_linux:6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:6.40.0.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.0.0.0`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.10.0.0`,
        fs:  `cpe:2.3:a:vmware:movie_decoder:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.20.0.0`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.30.0.0`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.40.0.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.40.1.0`,
        fs:  `cpe:2.3:a:emc:documentum_foundation_services:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.41.0.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.50.0.0`,
        fs:  `cpe:2.3:o:cisco:rv110w_firmware:1.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.51.0.0`,
        fs:  `cpe:2.3:a:f5:linerate:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.60.0.0`,
        fs:  `cpe:2.3:a:posh_project:posh:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.70.0.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.80.0.0`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.90.0.0`,
        fs:  `cpe:2.3:h:sun:cobalt_raq_xtr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.91.0.0`,
        fs:  `cpe:2.3:a:emc:centerstage:1.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:7.95.0.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.0.0.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.231:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.1.0.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)xl3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.10.0.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.11.0.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.15.0.0`,
        fs:  `cpe:2.3:a:libndp:libndp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.20.0.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.22.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1.0-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.26.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2xo:3.2.0xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.30.0.0`,
        fs:  `cpe:2.3:a:heikki_hokkanen:viewgit:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.40.0.0`,
        fs:  `cpe:2.3:a:emc:networker:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.50.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sre2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.60.0.0`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.70.0.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:8.70.0.0:b`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_agents:9.0.0.0`,
        fs:  `cpe:2.3:h:polycom:viewstation_v.35:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_suite:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers:2.2.1.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.13.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers:2.3.0.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers:2.4.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers:2.5.0.0`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers:2.6.0.0`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers:2.7.0.0`,
        fs:  `cpe:2.3:a:ca:anti-virus_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers:2.8.0.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.2.1.0`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.2.1.0::~~~~x64~`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.3.0.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.3.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.4.0.0`,
        fs:  `cpe:2.3:a:qianqin:qtranslate:2.5.34:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.4.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:apple:ichat_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.5.0.0`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.5.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:cnectd:cnectd:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.6.0.0`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.6.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:apache:http_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.7.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.7.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.8.0.0`,
        fs:  `cpe:2.3:a:ibm:websphere_ilog_rule_team_server:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_management_wbem_providers_for_windows_server_2003%2f2008:2.8.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:mumble:mumble:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:insight_manager:-`,
        fs:  `cpe:2.3:h:cisco:telepresence_mcu_4510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:install_network_printer_wizard:8.1.3`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:installmicgenerichook:1.0.0`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:instant_printing_utility:3.5.1`,
        fs:  `cpe:2.3:o:juniper:junos:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:instant_share:45.4.157.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30280:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:instant_share_devices:53.0.13.0`,
        fs:  `cpe:2.3:a:gentoo:poppassd_pam:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:instant_share_devices:70.0.170.0`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.5.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:instant_share_devices_mfc:70.0.170.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:instant_support:-`,
        fs:  `cpe:2.3:a:adobe:livecycle_data_services:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:instant_toptools:-`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:instant_toptools:5.04`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.598:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights-out:-`,
        fs:  `cpe:2.3:o:ibm:aix:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights-out:4.0`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:1.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:1.10`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.14.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:1.20`,
        fs:  `cpe:2.3:a:digium:asterisk:10.3.0:rc2:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:1.30`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:1.70`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:1.75`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:1.77`,
        fs:  `cpe:2.3:a:intel:client_system_setup_utility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:2.12`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:2.15`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:2.20`,
        fs:  `cpe:2.3:a:perlmonks:module\:\:signature:0.70:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:2.22`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:2.23`,
        fs:  `cpe:2.3:a:yahoo:yui:3.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_2_firmware:2.25`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_3_firmware:1.00`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_3_firmware:1.05`,
        fs:  `cpe:2.3:a:sgi:propack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_3_firmware:1.20`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_3_firmware:1.26`,
        fs:  `cpe:2.3:a:websvn:websvn:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_3_firmware:1.28`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_3_firmware:1.50`,
        fs:  `cpe:2.3:a:ardour:ardour:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_3_firmware:1.55`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_3_firmware:1.80`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_4_firmware:1.11`,
        fs:  `cpe:2.3:h:softbank:windows_mobile_smartphone:x04ht:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_4_firmware:1.13`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_4_firmware:1.20`,
        fs:  `cpe:2.3:a:dev4press:gd_star_rating:19.22:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_4_firmware:2.01`,
        fs:  `cpe:2.3:a:ibm:security_directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_4_firmware:2.03`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(3c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_chassis_management_firmware:1.29`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.18:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.6a`,
        fs:  `cpe:2.3:a:interworx:web_control_panel:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.10`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.15`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.15a`,
        fs:  `cpe:2.3:a:isc:bind:9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.16a`,
        fs:  `cpe:2.3:a:novell:client:4.91:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.20a`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.26a`,
        fs:  `cpe:2.3:o:suse:suse_linux:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.27a`,
        fs:  `cpe:2.3:a:innominate:mguard_pci:bd-111010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.40a`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:2.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.41a`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.42a`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:6.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.50`,
        fs:  `cpe:2.3:a:digium:asterisk:13.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.50a`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.51a`,
        fs:  `cpe:2.3:a:sap:businessobjects:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.80`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.82`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.91`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_server:6.1.20000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:integrated_lights-out_firmware:1.93`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:integrated_lights_out:-`,
        fs:  `cpe:2.3:h:siemens:sinamics_g110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.6a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.10`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.15`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.15a`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.16a`,
        fs:  `cpe:2.3:a:apple:safari:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.20a`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.26a`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.32:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.27a`,
        fs:  `cpe:2.3:a:microsoft:outlook_2013_rt:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.40a`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.41a`,
        fs:  `cpe:2.3:a:samba:samba:4.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.42a`,
        fs:  `cpe:2.3:a:hp:solution_center:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.50`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.50a`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.0\(.00051\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:integrated_lights_out:1.51a`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.0:e0101`,
        fs:  `cpe:2.3:a:ibm:lotus_expeditor:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.0:e0101h03`,
        fs:  `cpe:2.3:a:sendcard:sendcard:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.0:e0101h04`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.0:e0101l01`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_xi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.0:e0101l02`,
        fs:  `cpe:2.3:a:alkacon:opencms:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.1`,
        fs:  `cpe:2.3:a:ibm:java:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.1:e0101p01`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:5.2`,
        fs:  `cpe:2.3:a:arubanetworks:airwave:7.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:7.0`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_management_center:7.0:e02020p03`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2104c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_provisioning:1.40`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_provisioning:1.50`,
        fs:  `cpe:2.3:a:samba:samba:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:intelligent_provisioning:1.60`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:interconnect_component:3.50.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ipfilter:-`,
        fs:  `cpe:2.3:a:sun:workshop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j7x28a:-`,
        fs:  `cpe:2.3:h:hp:0235a0ge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8692a:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(30\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8693a:-`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:unstable3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8697a:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8698a:-`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8699a:-`,
        fs:  `cpe:2.3:a:apple:safari:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8700a:-`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8715a:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.482:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8715b:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j8992a:-`,
        fs:  `cpe:2.3:h:intel:x58_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9091a:-`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.9.615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9263a:-`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9264a:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9265a:-`,
        fs:  `cpe:2.3:a:datadynamics:activebar:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9310a:-`,
        fs:  `cpe:2.3:a:google:chrome:9.0.570.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9311a:-`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9447a:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9448a:-`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9451a:-`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9452a:-`,
        fs:  `cpe:2.3:a:netartmedia:iboutique.mall:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9470a:-`,
        fs:  `cpe:2.3:a:microsoft:visual_interdev:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9471a:-`,
        fs:  `cpe:2.3:a:exim:exim:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9472a:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9473a:-`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9475a:-`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9532a:-`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9533a:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)sy1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9539a:-`,
        fs:  `cpe:2.3:a:digium:asterisk:11.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9540a:-`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9573a:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9574a:-`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9575a:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9576a:-`,
        fs:  `cpe:2.3:a:agrinsoft:argin_all_dvd_ripper:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9584a:-`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:b5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9585a:-`,
        fs:  `cpe:2.3:o:cisco:ons_15327:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9586a:-`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9587a:-`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.48.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9588a:-`,
        fs:  `cpe:2.3:a:southrivertech:webdrive:9.14.2353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9638a:-`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9639a:-`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9640a:-`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.0:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9641a:-`,
        fs:  `cpe:2.3:a:prestashop:ebay_module:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9642a:-`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9643a:-`,
        fs:  `cpe:2.3:h:cisco:catalyst_6500_ws-svc-nam-1:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9821a:-`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9822a:-`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9823a:-`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9824a:-`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9825a:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9826a:-`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9850a:-`,
        fs:  `cpe:2.3:a:microsoft:jscript:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9851a:-`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9866a:-`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:j9868a:-`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_desktop:11:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:java_jre-jdk:-`,
        fs:  `cpe:2.3:h:cisco:nexus_3064:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc072b:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jc085a:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_mse_series_software:4.2\(1.50\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc086a:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc124a:-`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:5.1.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc124b:-`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:r12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc125a:-`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc125b:-`,
        fs:  `cpe:2.3:a:broadcom:management_programs:10.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc474a:-`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc474b:-`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc611a:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc612a:-`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc613a:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jc652a:-`,
        fs:  `cpe:2.3:h:tp-link:tl-wr740n_\(5.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc653a:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc654a:-`,
        fs:  `cpe:2.3:a:commvault:resource_pack:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc655a:-`,
        fs:  `cpe:2.3:a:isc:bind:9.8.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc748a:-`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jc808a:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd429a:-`,
        fs:  `cpe:2.3:a:codiad:codiad:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd429b:-`,
        fs:  `cpe:2.3:a:fusebox:fusebox:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd431a:-`,
        fs:  `cpe:2.3:o:apple:os_x_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd432a:-`,
        fs:  `cpe:2.3:a:sowsoft:effective_file_search:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd433a:-`,
        fs:  `cpe:2.3:o:cisco:ios:11.2f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd653a:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.9:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd654a:-`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd655a:-`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd656a:-`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd657a:-`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd658a:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd659a:-`,
        fs:  `cpe:2.3:a:ibm:data_server_client:9.5.700.579:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd660a:-`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd661a:-`,
        fs:  `cpe:2.3:h:intel:server_board_sds2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd662a:-`,
        fs:  `cpe:2.3:a:samba:samba:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd663a:-`,
        fs:  `cpe:2.3:a:jonathan_leung:show_in_browser:0.0.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd663b:-`,
        fs:  `cpe:2.3:h:hp:jd674a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd664a:-`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd665a:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.9.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd666a:-`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd667a:-`,
        fs:  `cpe:2.3:a:drupal:drupal:6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd668a:-`,
        fs:  `cpe:2.3:a:gnu:emacs:20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd669a:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd670a:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd671a:-`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd672a:-`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.03b43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd673a:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd674a:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd675a:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jd676a:-`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.11:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:-`,
        fs:  `cpe:2.3:a:actividentity:corestreet_server_validation_extension_for_microsoft_domain_controller:3.1.4.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:4.0`,
        fs:  `cpe:2.3:o:cisco:ons_15327:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:4.1.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:5.1`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:5.5`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.5075:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:5.5.177`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:5.6`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.7.0.1948:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:6.0`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:6.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:6.2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jetadmin:rev._d.01.09`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_250m:-`,
        fs:  `cpe:2.3:h:avaya:cajun_p550r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_300x:-`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp8:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_310x:-`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_380x:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)bc1f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_600n_eio:-`,
        fs:  `cpe:2.3:a:tumbleweed:desktop_validator:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_610n:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_615n:-`,
        fs:  `cpe:2.3:a:condor_project:condor:7.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_615n_eio:-`,
        fs:  `cpe:2.3:a:gajim:gajim:0.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_635n:-`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_680n:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_680n_eio:-`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jetdirect_680n_eio_802.11b:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf228a:-`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf229a:-`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20170731:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf230a:-`,
        fs:  `cpe:2.3:a:digium:asterisk:11.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf231a:-`,
        fs:  `cpe:2.3:a:php:php:5.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf232a:-`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf233a:-`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf234a:-`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.13m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf235a:-`,
        fs:  `cpe:2.3:a:sentel:aesop:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf236a:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf237a:-`,
        fs:  `cpe:2.3:a:intel:proset_wireless:13.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf238a:-`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.306:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf239a:-`,
        fs:  `cpe:2.3:h:hp:jetdirect_635n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf240a:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf241a:-`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf283a:-`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf284a:-`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_exec:5.5.2310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf285a:-`,
        fs:  `cpe:2.3:a:apple:apple_application_support:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf287a:-`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf430a:-`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf430b:-`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf430c:-`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf431a:-`,
        fs:  `cpe:2.3:a:pass4sure:pass4sure_for_comptia_n10-004:3.10:*:*:*:demo:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf431b:-`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf431c:-`,
        fs:  `cpe:2.3:h:sony:snc_dh140:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf640a:-`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf800a:-`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf801a:-`,
        fs:  `cpe:2.3:a:polldaddy_polls_\&amp;_ratings_plugin_project:polldaddy_polls_\&amp;_ratings:2.0.25:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf802a:-`,
        fs:  `cpe:2.3:a:atutor:acollab:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf803a:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf804a:-`,
        fs:  `cpe:2.3:a:chilkat_software:chilkat_crypt_activex_control:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf806a:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1294.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf807a:-`,
        fs:  `cpe:2.3:a:microsoft:site_server:3.0:unknown:commerce:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf808a:-`,
        fs:  `cpe:2.3:a:att:communication_manager:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf809a:-`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.1.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf812a:-`,
        fs:  `cpe:2.3:a:agilebits:1password:-:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf813a:-`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf814a:-`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf815a:-`,
        fs:  `cpe:2.3:a:xnview:xnview:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf816a:-`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.04a-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jf817a:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jfs:-`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jfs:3.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg182a:-`,
        fs:  `cpe:2.3:a:nextapp:echo:3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg183a:-`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4.2\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg184a:-`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.0:update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg207a:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg208a:-`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg209a:-`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg210a:-`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg296a:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5\)e2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg353a:-`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:20.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg354a:-`,
        fs:  `cpe:2.3:h:hp:cc524a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg361a:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg361b:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg362a:-`,
        fs:  `cpe:2.3:a:redhat:ddskk-xemacs:11.6.0-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg362b:-`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg363a:-`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg363b:-`,
        fs:  `cpe:2.3:a:wdc:smartware:1.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg364a:-`,
        fs:  `cpe:2.3:a:redhat:cygwin:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg402a:-`,
        fs:  `cpe:2.3:a:gnu:coreutils:5.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg403a:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg404a:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg405a:-`,
        fs:  `cpe:2.3:a:apple:imageio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg406a:-`,
        fs:  `cpe:2.3:o:huawei:5700hi_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg407a:-`,
        fs:  `cpe:2.3:a:adobe:extension_manager:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg408a:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg409a:-`,
        fs:  `cpe:2.3:a:apple:remote_desktop:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg410a:-`,
        fs:  `cpe:2.3:a:paymentsplus:payments_plus:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg411a:-`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:5.5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg412a:-`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg496a:-`,
        fs:  `cpe:2.3:a:hijabmodern:hijab_modern:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg497a:-`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg512a:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg513a:-`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg514a:-`,
        fs:  `cpe:2.3:a:web2py:web2py:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg515a:-`,
        fs:  `cpe:2.3:a:citrix:web_interface:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg516a:-`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg517a:-`,
        fs:  `cpe:2.3:a:apache:httpclient:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg518a:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg519a:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg520a:-`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg531a:-`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0.0:p0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg555a:-`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg596a:-`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.2:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg597a:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg665a:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg704a:-`,
        fs:  `cpe:2.3:a:hp:openview_http_communication:6.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg732a:-`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg734a:-`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg735a:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)ja1n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg776a:-`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg777a:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:17.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg779a:-`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:2.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg782a:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg783a:-`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.2.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg784a:-`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg785a:-`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jg786a:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jg787a:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg788a:-`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jg789a:-`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_nortel_bay:3.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jg798a:-`,
        fs:  `cpe:2.3:a:vmware:workstation:12.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg802a:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:jg803a:7.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jg810a:-`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:08-00-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg811aae:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.459:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg812aae:-`,
        fs:  `cpe:2.3:o:ibm:os_400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:jg813aae:7.0`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg820a:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.3:2.3.1t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg821a:-`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg822a:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg823a:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg834a:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:jg835a:7.0`,
        fs:  `cpe:2.3:a:ca:application_configuration_manager_agent:12.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg836a:-`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg837a:-`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1021:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg861a:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg866a:-`,
        fs:  `cpe:2.3:o:sauter:moduweb_vision:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg869a:-`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.20.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jg875a:-`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jh060a:-`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:1561:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jh075a%29:-`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jh179a:-`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jh188a:-`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.1.7:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jh192a:-`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.20:-:*:*:*:windows_server_2008:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:jh196a:-`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:jh198a:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.2.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:keyview:10.23.0.0`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.19.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:keyview:10.24.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:l7000_basic:140.0.0.0`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2200:-`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_manager:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2200dtn:-`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2300dn:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2410:-`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2420:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2430:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2500:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2500c:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2600c:-`,
        fs:  `cpe:2.3:h:polycom:viewstation_dcp:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_2600n:-`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_3000:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_3700:-`,
        fs:  `cpe:2.3:a:emberjs:ember.js:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4:-`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4000:-`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4000n:-`,
        fs:  `cpe:2.3:h:symantec:gateway_security_460:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4050:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:update1:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4100_mfp:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4100mfp:-`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4200:-`,
        fs:  `cpe:2.3:h:softbank:nec_3g_handset:001n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4200dnt_network_printer:-`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.0:b:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4200ln:-`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4240:q7785a`,
        fs:  `cpe:2.3:a:transifex:transifex:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4250:q5400a`,
        fs:  `cpe:2.3:a:mollify:mollify:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4300:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:8.0.39.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4345_mfp:-`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4345_mfp:q3942a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4350:q5407a`,
        fs:  `cpe:2.3:a:google:v8:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4350dtn:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4650dn:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_4m_plus:-`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5:-`,
        fs:  `cpe:2.3:a:christopher_mitchell:smart_breadcrumb:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5000:-`,
        fs:  `cpe:2.3:a:google:chrome:0.2.153.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5000:r.25.15`,
        fs:  `cpe:2.3:a:allaire:homesite:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5000:r.25.47`,
        fs:  `cpe:2.3:a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5100:-`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5100:v.29.12`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5100dtn:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5200l:q7543a`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5200n:q7543a`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_5m:-`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_developer_suite:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_8150dn:-`,
        fs:  `cpe:2.3:a:microsoft:office_multilingual_user_interface_pack:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9000:-`,
        fs:  `cpe:2.3:a:sun:jre:6.0.210:update21:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9000_mfp:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9000mfp:-`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9040:q7697a`,
        fs:  `cpe:2.3:a:vips:vips:7.11.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9040_mfp:-`,
        fs:  `cpe:2.3:a:manugistics:scpo_runtime:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9040_mfp:q3721a`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.00:-:*:*:sunos:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9040_mpf:-`,
        fs:  `cpe:2.3:a:piriform:recuva:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9040mfp:-`,
        fs:  `cpe:2.3:h:seil:x2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9050:-`,
        fs:  `cpe:2.3:a:apache:wicket:6.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9050:q7697a`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9050_mfp:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9050_mfp:q3721a`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9050_mpf:-`,
        fs:  `cpe:2.3:a:phpfox:phpfox:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9050mfp:-`,
        fs:  `cpe:2.3:o:lexmark:printer_firmware:cb.02.048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9055:-`,
        fs:  `cpe:2.3:a:blubrry:powerpress_podcasting:6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9065:-`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9500:-`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:q35_sinit_18.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9500_mpf:-`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_9500mfp:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_cm3530_multifuction_printer:cc519a`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_cm3530_multifuction_printer:cc520a`,
        fs:  `cpe:2.3:a:google:chrome:5.0.376.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_enterprise_color_flow_m575c:-`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.12.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_enterprise_p3015:ce526a`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_flow_m525c:-`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:laserjet_fonts:2.0.0`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m1522n_multifunction_printer:cc372a`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m2727_multifunction_printer:cb532a`,
        fs:  `cpe:2.3:a:realvnc:realvnc:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m2727_multifunction_printer:cb533a`,
        fs:  `cpe:2.3:a:hp:web_registration:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m3027_mfp:-`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m3027_mfp:cb416a`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m3035_mfp:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.269:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m3035_mfp:cb414a`,
        fs:  `cpe:2.3:a:hp:centralized_management_console_software:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m3035_mfp:cc519a`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:04-01-\/a:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m4345_mfp:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m4345_mfp:cb425a`,
        fs:  `cpe:2.3:a:gnome:glib:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m4555:-`,
        fs:  `cpe:2.3:a:newsignature:addressfield_tokens:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m4555f:-`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m4555fskm:-`,
        fs:  `cpe:2.3:a:lunascape:ilunascape_android:1.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m4555h:-`,
        fs:  `cpe:2.3:a:gentoo:media-libs_jpeg:6b:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m5025_mfp:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m5025_mfp:q7840a`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m5035_mfp:-`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.2.0090:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m5035_mfp:q7829a`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m525dn:-`,
        fs:  `cpe:2.3:a:kde:koffice:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m525f:-`,
        fs:  `cpe:2.3:a:ibm:advanced_settings_utility:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m725dn:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m725f:-`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m725z:-`,
        fs:  `cpe:2.3:a:gnu:tar:1.15.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m725z%2b:-`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m9040_mpf:cc394a`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_m9050_mpf:cc395a`,
        fs:  `cpe:2.3:a:ibm:java:6.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_p2055:-`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_p2055d:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_p2055dn:-`,
        fs:  `cpe:2.3:o:cisco:staros:12.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_p2055x:-`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_p3005:q7812a`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)e13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:laserjet_p3010_series_screen_fonts:2.0.0.0`,
        fs:  `cpe:2.3:a:livezilla:livezilla:4.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:laserjet_p3010_series_user_guide:1.0.0.0`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_p4014:cb507a`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_p4015:cb509a`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.7.1r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_p4515:cb514a`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_100_color_mfp_m175:ce866a`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_300_color_mfp_printer_m375:ce903a`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ebm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_300_color_printer_m351:ce955a`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_400_color_mfp_m475:ce863a`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_400_color_mfp_m475:ce864a`,
        fs:  `cpe:2.3:a:google:chrome:9.0.572.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_400_color_printer_m451:ce956a`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_400_color_printer_m451:ce957a`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_xgs_firmware:5.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_400_color_printer_m451:ce958a`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.0:-:core:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_cm1415fnw_color_multifunction_printer:ce862a`,
        fs:  `cpe:2.3:a:atmail:atmail:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_cp1025nw:ce914a`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_cp1025nw:ce918a`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:laserjet_pro_cp1025nw_firmware:20130703`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_cp1525nw_color_printer:ce875a`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_m1212nf_mfp:ce841a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:laserjet_pro_m1212nf_mfp_firmware:20130703`,
        fs:  `cpe:2.3:a:libdwarf_project:libdwarf:2016-10-21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_m1213nf_mfp:ce845a`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:laserjet_pro_m1213nf_mfp_firmware:20130703`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.0:cf001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:laserjet_pro_m1214nfh_mfp_firmware:20130703`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.12p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_m1216nfh_mfp:ce843a`,
        fs:  `cpe:2.3:a:x.org:libxv:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:laserjet_pro_m1216nfh_multifunction_printer_firmware:20130703`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_m1217nfw_mfp:ce844a`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:laserjet_pro_m1217nfw_multifunction_printer_firmware:20130703`,
        fs:  `cpe:2.3:o:xen:xen:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_m1536dnf_multifunction_printer:ce538a`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:rc.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_p1102:ce657a`,
        fs:  `cpe:2.3:a:qemu:qemu:1.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_p1102:ce658a`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:laserjet_pro_p1102w_firmware:20130703`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.3:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:laserjet_pro_p1606dn:ce749a`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:laserjet_pro_p1606dn_firmware:20130703`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:laserjet_professional_m1210_mfp_series_toolbox:1.0.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:laserjet_toolbox:1.0.0.2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:laserjet_toolbox:1.0.58`,
        fs:  `cpe:2.3:a:scadatec:modbustagserver:4.1.1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:laserjet_toolbox:2.0.0`,
        fs:  `cpe:2.3:a:google:chrome:50.0.2661.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:lcd_pole_display_f7a93aa:-`,
        fs:  `cpe:2.3:a:dell:openmanage:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ldap-ux_integration:-`,
        fs:  `cpe:2.3:a:phorum:phorum:3.1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ldap-ux_integration:b.02.00`,
        fs:  `cpe:2.3:a:cogentdatahub:opc_datahub:6.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ldap-ux_integration:b.03.00`,
        fs:  `cpe:2.3:o:redhat:certificate_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lefthand_p4000_virtual_san_appliance:-`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lefthand_virtual_san_appliance_hydra:-`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update31:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lefthand_virtual_san_appliance_hydra_software:9.0`,
        fs:  `cpe:2.3:a:vmware:esx_server:1.5.2:patch3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lefthand_virtual_san_appliance_hydra_software:10.0`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5137-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:1.5.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p146:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:1.5.1.1`,
        fs:  `cpe:2.3:a:crunchify:foursquare-checkins:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:1.7.1.0`,
        fs:  `cpe:2.3:a:conky:conky:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:1.8.0.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd371a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:2.0.4.1`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:2.1.0.1`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:2.1.2.1`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:2.2.0.5`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:3.0.0.0`,
        fs:  `cpe:2.3:a:ibm:smartcloud_analytics_log_analysis:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:3.1.0.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.1.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:3.1.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.2se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility:3.2.0.0`,
        fs:  `cpe:2.3:h:polycom:viewstation_h.323:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_online_configuration_utility_for_windows_server_2003:2.0.4.1::~~~~x64~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lights-out_passthrough_service:1.2.26.0`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:linear_barcode_scanner_qy405aa:-`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:1.0`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:2.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:2.7.10`,
        fs:  `cpe:2.3:a:codiad:codiad:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.9.2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.466.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.9.4`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.9.4b`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:1.2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.9.6`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.9.8`,
        fs:  `cpe:2.3:a:hp:oracle_for_openview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.9.10`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.9.12`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.10.2`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.10.5`,
        fs:  `cpe:2.3:a:tenable:web_ui:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.10.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p189:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.10.9`,
        fs:  `cpe:2.3:a:sphider:sphider:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.11.1`,
        fs:  `cpe:2.3:a:apache:struts:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.11.3`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.11.3a`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.11.5`,
        fs:  `cpe:2.3:a:prosody:prosody:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.11.7`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.11.10`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.12.2`,
        fs:  `cpe:2.3:h:cisco:bpx_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.12.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.12.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.12.9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.12.10`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.12.10:a`,
        fs:  `cpe:2.3:h:rockwellautomation:controllogix_5570_redundant_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.12.11`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.1`,
        fs:  `cpe:2.3:a:microsoft:skype_for_business_server:2015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.3`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.4:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.5`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.6`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.7`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.8`,
        fs:  `cpe:2.3:a:google:chrome:12.0.713.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.9`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.2:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.10`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.11:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.13.11`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:linux_imaging_and_printing_project:3.14.1`,
        fs:  `cpe:2.3:a:sun:jre:1.1.8:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:lio_10_100_print_server:-`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.16.4631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:load_generator:11.0.0.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:-`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:9.0.0`,
        fs:  `cpe:2.3:a:libav:libav:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:9.50.0`,
        fs:  `cpe:2.3:a:atlassian:jira:2.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:9.51`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:9.52`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:11.0.0.0`,
        fs:  `cpe:2.3:a:horde:imp:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:11.50`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:11.51`,
        fs:  `cpe:2.3:a:david_king:vino:2.11.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:11.52`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:11.52:p3`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:12.00:p1`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:12.01:p3`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:12.02:p2`,
        fs:  `cpe:2.3:a:perl:perl:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:12.50:p1`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner:12.50:p3`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:loadrunner_results_translator:1.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:lp6940_help:60.0.196.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:managed_printing_admin:2.5.9`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1014:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:70.0.170.0`,
        fs:  `cpe:2.3:a:ibm:connections:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:82.0.174.0`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:90.0.142.0`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:90.0.146.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:100.0.170.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:120.0.226.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.51:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:130.0.374.0`,
        fs:  `cpe:2.3:a:md-systems:simplenews:7.x-1.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:140.0.212.0`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:marketresearch:140.0.214.0`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0007_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:matrix_operating_environment:7.4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:memories_disc:1.0.4.805`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_loadrunner_agent:-`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_loadrunner_agent:8.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_loadrunner_agent:8.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_monitor_over_firewall:-`,
        fs:  `cpe:2.3:a:scripthead:webmail_plus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_monitor_over_firewall:8.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.12:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_performance_center_agent:-`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_performance_center_agent:8.0`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1014.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_performance_center_agent:8.1`,
        fs:  `cpe:2.3:a:symantec:system_center:10.1.8000.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_quality_center:-`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:rc13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_quality_center:8.2`,
        fs:  `cpe:2.3:a:novell:imanager:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_quality_center:8.2:sp1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.223.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_quality_center:9.0`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_quality_center:9.0_build_9.1.0.4352`,
        fs:  `cpe:2.3:a:mcafee:firewall_enterprise_admin_console:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_sitescope:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_sitescope:8.1.2.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_sitescope:8.2`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mercury_testdirector_for_quality_center:-`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:misc:1.0.0`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:mp9_g2_retail_system:-`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.8:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe:6.5`,
        fs:  `cpe:2.3:o:dell:bios:a20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe_ix:-`,
        fs:  `cpe:2.3:h:huawei:eudemon500:v200r006c02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe_ix:4.5`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe_ix:5.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.8.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe_ix:5.5`,
        fs:  `cpe:2.3:a:apc:powerchute:1.5.0:-:personal:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe_ix:6.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe_ix:6.5`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:08-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:mpe_ix:7.0`,
        fs:  `cpe:2.3:a:facebook:savage_nation_mobile_web:0.57.13354.63350:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:mpio_full_featured_dsm_for_eva4x00%2f6x00%2f8x00_family_of_disk_arrays:4.0.0`,
        fs:  `cpe:2.3:a:adobe:soundbooth_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:msvcsetup:1.0.0`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:mt42_mobile_thin_client:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:my_print_mileage:1.0.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:netdevicemanager:100.0.170.0`,
        fs:  `cpe:2.3:a:yokogawa:exaopc:3.71.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network:120.0.194.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network:140.0.215.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:7.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.359:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:7.6`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:9.0`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.4.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:9.10`,
        fs:  `cpe:2.3:a:nvidia:install_application:2.265.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:9.22`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:9.22.01`,
        fs:  `cpe:2.3:h:cisco:ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:9.22.02`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:10.00`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_automation:10.00.01`,
        fs:  `cpe:2.3:a:horde:gollem:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager:7.5`,
        fs:  `cpe:2.3:a:citrix:secure_gateway:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager:8.10`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-207_with_network_printer_kit_firmware:t282cn0j421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager:8.11`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager:8.12`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager:8.13`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.20:*:le:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:8.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:8.10`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.02b11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:8.11`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:8.12`,
        fs:  `cpe:2.3:a:roxio:cineplayer:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:8.13`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:9.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:9.01`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:9.02`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:9.03`,
        fs:  `cpe:2.3:a:netiq:appmanager_agent:7.0.25142.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:9.10`,
        fs:  `cpe:2.3:a:apache:libcloud:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_node_manager_i:9.20`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:network_printer:-`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:network_switch_software:15.18.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_virtualization:8.6`,
        fs:  `cpe:2.3:a:hummingbird:collaboration:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_virtualization:8.61`,
        fs:  `cpe:2.3:a:alstom:e-terracontrol:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:network_virtualization:11.52`,
        fs:  `cpe:2.3:a:winzip:winzip:8.1.4331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:newcopy:50.0.206.0`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:newcopy_cda:70.0.231.0`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp1:enterprise_x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:newcopy_cda:71.0.215.0`,
        fs:  `cpe:2.3:a:prosody:prosody:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:nonstop_himalaya:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:nonstop_himalaya_s74:-`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:nonstop_himalaya_s76:-`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:nonstop_himalaya_s78:-`,
        fs:  `cpe:2.3:a:ibm:java:6.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:nonstop_himalaya_s7800:-`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:g06.14`,
        fs:  `cpe:2.3:a:batavi:batavi:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:g06.32.01`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:5.5:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.03`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:6.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.04`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.05`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.349:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.05.01`,
        fs:  `cpe:2.3:a:anti-plagiarism_project:anti-plagiarism:3.60:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.05.02`,
        fs:  `cpe:2.3:a:hummingbird:exceed_powersuite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.24.01`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.25`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.25.01`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.26`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.26.01`,
        fs:  `cpe:2.3:a:huawei:espace_desktop:v100r001c03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.27`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.27.01`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:h06.28`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.03`,
        fs:  `cpe:2.3:a:rpm:rpm:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.13.01`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.14`,
        fs:  `cpe:2.3:a:isc:bind:9.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.14.03`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.15`,
        fs:  `cpe:2.3:a:mozilla:firefox:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.15.02`,
        fs:  `cpe:2.3:a:splunk:splunk:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.16`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.16.02`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.17`,
        fs:  `cpe:2.3:h:lexmark:xc6152de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_netbatch:j06.17.01`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d40.00`,
        fs:  `cpe:2.3:a:directwebremoting:direct_web_remoting:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d41.00`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(7a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d42.00`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_34:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d42.01`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d43.00`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d43.01`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d43.02`,
        fs:  `cpe:2.3:a:rsa:bsafe_ssl-j_sdk:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d44.00`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.9:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d44.01`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d44.02`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d45.00`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d45.01`,
        fs:  `cpe:2.3:a:plone:plone:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d46.00`,
        fs:  `cpe:2.3:h:asus:rt-n56u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d47.00`,
        fs:  `cpe:2.3:a:ti:cardbus:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d48.00`,
        fs:  `cpe:2.3:a:symantec:product_authentication_service:4.3.42.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d48.01`,
        fs:  `cpe:2.3:a:lttng:ust:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d48.02`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:d48.03`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g01.00`,
        fs:  `cpe:2.3:a:php-nuke:platinum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g02.00`,
        fs:  `cpe:2.3:a:ibm:initiate_master_data_service:9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g03.00`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g04.00`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.9:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g05.00`,
        fs:  `cpe:2.3:a:ahtty:ahtty:1.97.16:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g05.01`,
        fs:  `cpe:2.3:a:conky:conky:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.00`,
        fs:  `cpe:2.3:a:horde:imp:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.01`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.03`,
        fs:  `cpe:2.3:a:gnu:gdb:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.04`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.05`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.06`,
        fs:  `cpe:2.3:a:samba:samba:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.07`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.0.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.08`,
        fs:  `cpe:2.3:a:roxio:cineplayer:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.09`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.10`,
        fs:  `cpe:2.3:h:ibm:netezza:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.11`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.12`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.13`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.14`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.15`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.16`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.17`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.18`,
        fs:  `cpe:2.3:a:gnu:wget:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.19`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_seeview_server_gateway:g06.20`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:nonstop_server:-`,
        fs:  `cpe:2.3:a:gnome:glib:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:nonstop_server:g06.29`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.29.00`,
        fs:  `cpe:2.3:a:roxio:easy_media_creator:7.0.430.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.29.01`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.29.02`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.29.03`,
        fs:  `cpe:2.3:a:sourcegear:vault_client:4.1.4.18402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.30.00`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.30.01`,
        fs:  `cpe:2.3:a:plone:plone:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.30.02`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.31.00`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.31.01`,
        fs:  `cpe:2.3:a:sun:java_plug-in:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.32.00`,
        fs:  `cpe:2.3:o:freebsd:freebsd:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:g06.32.01`,
        fs:  `cpe:2.3:a:hp:database_and_middleware_automation:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.08.00`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.09.00`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.10.00`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.14:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.10.01`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.11.00`,
        fs:  `cpe:2.3:a:google:googlebot:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.11.01`,
        fs:  `cpe:2.3:a:isc:bind:9.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.11.02`,
        fs:  `cpe:2.3:a:opnet:it_guru_documentation:16.0.0.10106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.11.03`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.12.00`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.3\(0\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.13.00`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.14.00`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.15.00`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.15.01`,
        fs:  `cpe:2.3:a:pokecreator:pokecreator_lite:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.15.02`,
        fs:  `cpe:2.3:o:cisco:spa_500_series_ip_phone_firmware:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.16.00`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.16.01`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.16.02`,
        fs:  `cpe:2.3:a:sap:netweaver:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.17.00`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.17.01`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.17.02`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.17.03`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server_supplementary:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.18.00`,
        fs:  `cpe:2.3:a:adobe:creative_cloud:3.7.0.272:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.18.01`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.18.02`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.19.00`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:milestone1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.19.01`,
        fs:  `cpe:2.3:a:mautic:mautic:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.19.02`,
        fs:  `cpe:2.3:a:mozilla:nss:3.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.19.03`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.20.00`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.20.01`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.20.02`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.20.03`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.21.00`,
        fs:  `cpe:2.3:o:cisco:spa_500_series_ip_phone_firmware:7.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.21.01`,
        fs:  `cpe:2.3:a:emc:documentum_d2:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:h06.21.02`,
        fs:  `cpe:2.3:a:netscape:communicator:4.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.03`,
        fs:  `cpe:2.3:a:intel:cli_auto-configuration_utility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.04.00`,
        fs:  `cpe:2.3:a:polycom:rss_system_software:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.04.01`,
        fs:  `cpe:2.3:a:wordboxapps:afghan_radio:2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.04.02`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.05.00`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.05.01`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_user_tracking_utility:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.05.02`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.06.00`,
        fs:  `cpe:2.3:a:google:toolbar_for_internet_explorer:6.6.1015.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.06.01`,
        fs:  `cpe:2.3:h:enterasys:roamabout_ap3000:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.06.02`,
        fs:  `cpe:2.3:a:smarttech:smart_meeting_pro:2.2.140.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.06.03`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.5:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.07.00`,
        fs:  `cpe:2.3:o:huawei:s7706_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.07.01`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.07.02`,
        fs:  `cpe:2.3:a:x:libxtst:1.0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.08.00`,
        fs:  `cpe:2.3:a:david_king:vino:2.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.08.01`,
        fs:  `cpe:2.3:a:samba:samba:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.08.02`,
        fs:  `cpe:2.3:a:plone:plone:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.08.03`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.08.04`,
        fs:  `cpe:2.3:a:citrix:access_gateway_plug-in:9.1:*:*:*:enterprise:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.09.00`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.09.01`,
        fs:  `cpe:2.3:a:libav:libav:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.09.02`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0:tiv-ncreporter-if0001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.09.03`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.09.04`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.10.00`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.10.01`,
        fs:  `cpe:2.3:a:gnome:evolution:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:nonstop_server_software:j06.10.02`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software:8.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software:9.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software_by_i.r.i.s:7.0`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software_by_i.r.i.s:10.0`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.6.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software_by_i.r.i.s:11.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software_by_i.r.i.s:12.0`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software_by_i.r.i.s:13.0`,
        fs:  `cpe:2.3:a:emc:captiva_quickscan_pro:4.6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software_by_i.r.i.s:14.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ocr_software_by_i.r.i.s.:12.3.4.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_4100:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_5100:-`,
        fs:  `cpe:2.3:a:redhat:thermostat:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_5500:-`,
        fs:  `cpe:2.3:a:winzip:winzip:14.0.8688:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_5610:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.687.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_6100:-`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_6300:-`,
        fs:  `cpe:2.3:a:woocommerce_sagepay_direct_payment_gateway_project:woocommerce_sagepay_direct_payment_gateway:0.1.6.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_7100:-`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_7300:-`,
        fs:  `cpe:2.3:a:winzip:winzip:11.2:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_9100:-`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_d:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_g:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_k:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_pro_8500:cb022a`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_pro_8500:cb023a`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_pro_8500:cb025a`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.21:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_pro_8500:cb793a`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:50.1.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_pro_8500:cb794a`,
        fs:  `cpe:2.3:a:ibm:dashdb_local:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_pro_8500:cb862a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p87:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_pro_8500:cb874a`,
        fs:  `cpe:2.3:a:f5:big-ip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:officejet_pro_8500:cn539a`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(2\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:officejet_pro_8500_firmware:-`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:officejet_pro_8500_firmware:dlm1fn1344ar`,
        fs:  `cpe:2.3:h:juniper:infranet_controller_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ole_point_of_sale_driver:1.13.001`,
        fs:  `cpe:2.3:o:vmware:esx:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:omniback_ii:-`,
        fs:  `cpe:2.3:a:wavea:toraware_takojyou:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:omniback_ii:a.03.50`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:1.00`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.x-dev:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:1.01`,
        fs:  `cpe:2.3:a:spip:spip:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:1.10`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.07.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:1.11`,
        fs:  `cpe:2.3:a:knowledgetree:knowledgetree:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:1.12`,
        fs:  `cpe:2.3:a:ibm:vios:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:1.20`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:1.30`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.01`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.02:a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.04`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.92:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.10`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.11`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.12`,
        fs:  `cpe:2.3:a:dell:touchpad:7.2.101.230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.13`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.20`,
        fs:  `cpe:2.3:o:ibm:aix:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.21`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.25`,
        fs:  `cpe:2.3:a:newsoftinc:presto\!_pagemanager:7.16.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.31`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.32`,
        fs:  `cpe:2.3:a:estsoft:alzip:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.41`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.50`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.51`,
        fs:  `cpe:2.3:a:tony_million:tuniac:090517c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.52`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.5:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:2.60`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.00`,
        fs:  `cpe:2.3:a:adobe:was_cs3:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.10`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-51:-:enterprise:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.11`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.20:a`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.21`,
        fs:  `cpe:2.3:a:ca:systems_performance_for_infrastructure_managers:12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.30`,
        fs:  `cpe:2.3:h:f5:firepass_4100:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.31`,
        fs:  `cpe:2.3:a:ibm:emptoris_program_management:10.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.32`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.50`,
        fs:  `cpe:2.3:a:sun:solstice_x.25:9.2:unknown:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:onboard_administrator:3.55`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:oneview:1.0`,
        fs:  `cpe:2.3:a:lepton-cms:lepton:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:oneview:1.01`,
        fs:  `cpe:2.3:o:sgi:irix:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openmail:-`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openmail:4.1`,
        fs:  `cpe:2.3:o:vmware:esxi:4.1:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openmail:5.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openmail:5.10`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.17:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openssh_services:3.7.1p1-1`,
        fs:  `cpe:2.3:a:csounds:csound:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview:-`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1066.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_agent_extension_for_configuration_and_discovery:2.1.144`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)yy3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_agent_extension_for_configuration_and_discovery:2.20.5`,
        fs:  `cpe:2.3:a:cisco:cloudcenter_orchestrator:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_autopass:5.50.52`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.3:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_certificate_management_client:1.0.180`,
        fs:  `cpe:2.3:a:ibm:security_guardium:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_client_configuraton_manager:-`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_client_configuraton_manager:2.0`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_configuration:1.10.30`,
        fs:  `cpe:2.3:h:fujitsu:scansnap_s510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_configuration_management:-`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_configuration_management:4.0`,
        fs:  `cpe:2.3:a:hp:hpssupply:140.0.211.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_configuration_management:4.1`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_configuration_management:4.2`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_configuration_management:4.2i`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_cross_platform_component:2.61.100`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_cross_platform_component:2.61.110`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_cross_platform_component:3.10.40`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_cross_platform_component:3.10.65`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6\(3\)_b39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_cross_platform_component_java:3.10.65`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_deployment:2.10.90`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:8:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_e%2fa_agent:8.16.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_emanate_snmp_agent:-`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_emanate_snmp_agent:14.2`,
        fs:  `cpe:2.3:a:irfanview:irfanview_plugins:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_event_correlation_services:-`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_event_correlation_services:3.2`,
        fs:  `cpe:2.3:a:ibm:db2:10.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_event_correlation_services:3.3`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_400_color_printer_m451:ce956a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_http_communication:6.0.52`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd1.m0xx0_firmware:1.24.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_http_communication:6.0.60`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_mib_api_loader_and_mibs:1.30.10`,
        fs:  `cpe:2.3:a:fonality:trixbox:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:4.11`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:5.0.1`,
        fs:  `cpe:2.3:a:devsaran:clean_theme:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:5.01`,
        fs:  `cpe:2.3:a:python:rply:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:6.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:6.1`,
        fs:  `cpe:2.3:a:oracle:industry_applications:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:6.2`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:6.4`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:6.10`,
        fs:  `cpe:2.3:a:microsoft:directx:9.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:6.20`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:6.31`,
        fs:  `cpe:2.3:a:netscape:certificate_server:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:6.41`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.0.1`,
        fs:  `cpe:2.3:o:iodata:ts-wlc2_camera_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.01`,
        fs:  `cpe:2.3:a:redhat:uberfire:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.50`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.51`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.51:-:hp-ux`,
        fs:  `cpe:2.3:a:hp:instant_support:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.51:-:linux`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.51:-:solaris`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.12.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.51:-:windows`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.53`,
        fs:  `cpe:2.3:a:kingsoft:spreadsheets_2012:8.1.0.3030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.53:-:hp-ux`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0045:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.53:-:linux`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.53:-:solaris`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(15\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_network_node_manager:7.53:-:windows`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_icons_for_avaya:1.2.0`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_icons_for_huawei:1.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_icons_for_juniper:1.0.0`,
        fs:  `cpe:2.3:a:netbsd:ftpd:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_3com:2.60.0`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:3.6ecd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_alcatel:2.50.0`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:rc11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_alcatel_timetra:1.0.0`,
        fs:  `cpe:2.3:a:util-linux_project:util-linux:2.24.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_avaya:1.1.0`,
        fs:  `cpe:2.3:a:attachmate:reflection_standard_suite:15.3.436_:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_cdp:2.62.0`,
        fs:  `cpe:2.3:h:linksys:befsru31:1.42.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_centillion:1.50.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_cisco:3.4.0`,
        fs:  `cpe:2.3:h:hp:3com_switch:ss4_5500g-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_edp:2.51.0`,
        fs:  `cpe:2.3:a:docker:docker:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_endp:1.0.0`,
        fs:  `cpe:2.3:o:f5:tmos:9.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_enterasys:1.2.0`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_extreme:2.51.0`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_fdp:1.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_foundry:2.51.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_hp_procurve:3.2.0`,
        fs:  `cpe:2.3:a:pantech:pc_card_software:2.2.6200.701:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_huawei_switch:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.769.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_lldp:1.0.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_marconi_atm:2.10.0`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_marconi_lan:2.0.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_nortel_bay:3.11.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_nortel_passport:3.21.0`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_device_support_for_riverstone:1.0.0`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_mib_support_for_huawei_switch:1.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.25.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_advanced_edition_protocol_support_for_vrrp:1.1.0`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.7.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_nnm_lcore_dependencies:7.53.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_omniback_ii:-`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_omniback_ii:2.55`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_omniback_ii:3.0`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_omniback_ii:3.1`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_operations:-`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr1604hf-s-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_operations:a.07.50`,
        fs:  `cpe:2.3:a:opentext:enterprise_library_security_clearance:4.2.0.466:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_access:10.0.123`,
        fs:  `cpe:2.3:a:cisco:unity_connection_8.6:base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_access:10.0.131`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server_supplementary:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_access:10.0.241`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_access:10.50.40`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_access:10.50.90`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_agent:4.50.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1050.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_agent:4.60.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_agent:4.70.0`,
        fs:  `cpe:2.3:a:apache:solr:4.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_agent:5.0.0`,
        fs:  `cpe:2.3:a:f5:linerate:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_agent:c.04.60`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_light:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_agent:c.04.61`,
        fs:  `cpe:2.3:a:webform_invitation_project:webform_invitation:7.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_core:10.0.123`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_core:10.0.131`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control_option:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_core:10.0.241`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_core:10.50.40`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_extended_capability_technology:4.50.0`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_extended_capability_technology:4.59.1`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_extended_capability_technology:4.70.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_performance_extended_capability_technology:5.0.0`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_perl:5.6.13`,
        fs:  `cpe:2.3:a:cisco:telepresence_ip_vcr_1.0_converter:1.0\(1.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_process_control:1.50.241`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_process_control:1.50.250`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_radia_management_portal:-`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_radia_management_portal:1.0`,
        fs:  `cpe:2.3:a:qbnz:geshi:1.0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_radia_management_portal:2.0`,
        fs:  `cpe:2.3:h:huawei:ne20:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_report:-:3.70`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_report:3.70`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_reporter:3.70`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_security_core:2.20.90`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.7.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_security_core:2.20.100`,
        fs:  `cpe:2.3:a:lxml:lxml:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_select_access:-`,
        fs:  `cpe:2.3:a:php:php:5.6.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_select_access:5.0`,
        fs:  `cpe:2.3:o:microsoft:windows:server_2008:unknown:x32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_select_access:5.1`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_select_access:5.2`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_select_access:6.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_snmp_runtime:1.30.10`,
        fs:  `cpe:2.3:a:iomega:hotburn:1.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_storage_data_protector:-`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_storage_data_protector:5.1`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_storage_data_protector:5.5`,
        fs:  `cpe:2.3:a:google:chrome:4.0.223.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_storage_data_protector:5.50`,
        fs:  `cpe:2.3:h:apc:700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openview_storage_management_appliance:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:openvms:-`,
        fs:  `cpe:2.3:h:festo:cecx-x-m1_modular_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openvms:7.3`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:openvms:7.3`,
        fs:  `cpe:2.3:a:winzip:winzip:9.0.6028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:openvms:7.3-2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openvms:7.3_2`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(2\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:openvms:8.2-1`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20000427:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:openvms:8.3`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:openvms:8.3-1h1::integrity_servers`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openvms_secure_web_server:-`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openvms_secure_web_server:1.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openvms_secure_web_server:1.1.1`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:openvms_secure_web_server:1.2`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:7.36`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.51`,
        fs:  `cpe:2.3:a:huawei:espace_7950:v200r002c00spc700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.51.102`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.52`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.53`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:4.0.141842.828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.60`,
        fs:  `cpe:2.3:a:nginx:nginx:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.60.005`,
        fs:  `cpe:2.3:a:rvappstudios:best_phone_security:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.60.006`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.60.007`,
        fs:  `cpe:2.3:a:ibm:jre:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.60.7`,
        fs:  `cpe:2.3:a:redhat:rsync:2.5.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.60.008`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:8.60.501`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:15.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:11.0`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:11.03.012`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:11.13`,
        fs:  `cpe:2.3:a:microsoft:jscript:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:11.14`,
        fs:  `cpe:2.3:a:rpm:rpm:4.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_agent:11.15`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_integration_adapter_policy_activation:9.0.111`,
        fs:  `cpe:2.3:a:brother:mfl-pro_suite:1.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager:8.1`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager:8.10`,
        fs:  `cpe:2.3:a:sgi:mipspro_compilers:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager:8.16`,
        fs:  `cpe:2.3:h:cisco:unified_border_element:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager:9.0`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager:9.21::~~~linux~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:108.2146.2565.38893:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager:9.21::~~~solaris~~`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager:9.21::~~~unix~~`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.1.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:9.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p132:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:9.2`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:9.12`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:9.13`,
        fs:  `cpe:2.3:a:hp:storageworks_secure_path:4.0c:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:9.22`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r005c02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:9.23`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:9.24`,
        fs:  `cpe:2.3:a:adobe:adobe_air:14.0.0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:9.25`,
        fs:  `cpe:2.3:a:isc:bind:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:10.00`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_manager_i:10.01`,
        fs:  `cpe:2.3:a:apache:poi:2.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:7.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-35-\/g-:server:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:7.2`,
        fs:  `cpe:2.3:h:cisco:861_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:7.5`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:14.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:9.0`,
        fs:  `cpe:2.3:h:xerox:workcentre_m55:4.97.20.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:9.02`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:9.03`,
        fs:  `cpe:2.3:a:ibm:db2:9.8:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:9.04`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:9.05`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.4.3-ac3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:operations_orchestration:10.0`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:oracle_for_openview:-`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:9.5.0:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:oracle_for_openview:8.1.7`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:oracle_for_openview:9.1.01`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:oracle_for_openview:9.2`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:pa-risc:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:pa-risc:-:-:x64`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:pa-risc:-:-:x86`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_agent_core:11.0.17318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:pa-risc:_nil_:_nil_:32bit`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:pa-risc:_nil_:_nil_:64bit`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:palm_webos:1.4.1`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:palm_webos:1.4.5`,
        fs:  `cpe:2.3:a:macromedia:flash_player:8.0.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:palm_webos:1.4.5.1`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r10_b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:palm_webos:2.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.0:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:panostandalone:45.4.157.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:panostandalone:53.0.13.0`,
        fs:  `cpe:2.3:a:emc:networker:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:panostandalone:70.0.170.0`,
        fs:  `cpe:2.3:a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:panostandalone:90.0.146.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:panostandalone:100.0.170.0`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:panostandalone:110.0.180.0`,
        fs:  `cpe:2.3:a:qualys:qualyssuite:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_access:10.50.190`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:3.0a3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_access:10.50.225`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_agent:4.70`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(52\)se1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_center:11.52:p3`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_center:12.00:p1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_center:12.01:p3`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_center:12.20:p2`,
        fs:  `cpe:2.3:a:cognos:series_7:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_center:12.50:p1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1006:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_core:10.50.90`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_core:10.50.190`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_core:10.50.225`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.303.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.1.1`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.1.2`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.2`,
        fs:  `cpe:2.3:a:symantec:deployment_solution:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.30`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.31`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.40`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.41`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.0:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.41.001`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_insight:5.41.002`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:performance_validation_sdk:1.0.0`,
        fs:  `cpe:2.3:a:commpower:dc_directory_admin:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_and_imaging_gallery:-`,
        fs:  `cpe:2.3:h:3com:netbuilder_2_bridge_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_and_imaging_gallery:1.1`,
        fs:  `cpe:2.3:a:debian:adequate:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_and_imaging_software:2.0.0`,
        fs:  `cpe:2.3:a:fotoschilenas:pregnancy_tips:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_and_imaging_software:2.2.0`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.44:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_and_imaging_software:2.3.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_creations:1.0.0.2024`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_gallery:45.4.157.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1053:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_gallery:53.0.13.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photo_gallery:70.0.170.0`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_disclabel_paperlabel:2.2.0`,
        fs:  `cpe:2.3:a:digium:asterisk:b:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_disclabel_paperlabel:2.4.0`,
        fs:  `cpe:2.3:a:apache:struts:2.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_disclabel_plugin:2.2.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_disclabel_plugin:2.4.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_disclabel_printondisc:2.2.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_disclabel_printondisc:2.4.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essential:1.8.0.26`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essential:1.9.1.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.7.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essential:1.12.0.46`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essential:2.1`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essential:2.4.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.1.0c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essential:2.5`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essential:3.5`,
        fs:  `cpe:2.3:a:gnu:lsh:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essentials:2.1`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_essentials:2.5`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_express:70.0.170.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_premier_software:6.5`,
        fs:  `cpe:2.3:a:collabnet:subversion:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:photosmart_printer_series:8.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:pki_activex_control:1.1.0.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.06.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:pki_activex_control:1.2.0.1`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:pml_driver_hpz12:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:portable_file_system:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:pos_pole_display_fk225aa:-`,
        fs:  `cpe:2.3:a:samba:samba:4.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:power_manager_remote_agent:-`,
        fs:  `cpe:2.3:a:oracle:communications_unified:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:power_manager_remote_agent:4.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.8-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:power_manager_remote_agent:4.0_build_10`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:praesidium_webproxy:-`,
        fs:  `cpe:2.3:a:lxml:lxml:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:praesidium_webproxy:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:precisionscan_pro:3.0.2.0`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:precisionscan_pro:3.1.3.0`,
        fs:  `cpe:2.3:a:samba:samba:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:presentation_barcode_scanner_qy439aa:-`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:print_screen_utility:5.40.10.0`,
        fs:  `cpe:2.3:a:persian_car_cms_project:persian_car_cms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:printer_access_tool:1.0.0.3`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:printer_utility:1.6.6.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proactive_services:1.6.0.37`,
        fs:  `cpe:2.3:a:gnome:glib:2.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:process_resource_manager:-`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:process_resource_manager:c.01.07`,
        fs:  `cpe:2.3:a:ibm:java:6.0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:process_resource_manager:c.01.08.02`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:process_resource_manager:c.01.08.2`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.53.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:process_resource_manager:c.02.01.01`,
        fs:  `cpe:2.3:a:redhat:linux_powertools:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:procurve_manager:3.20`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:procurve_manager:3.20::~~~plus~~`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:procurve_manager:4.0`,
        fs:  `cpe:2.3:a:oracle:e-business_suite_11i:11.5.10:cu2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:procurve_manager:4.0::~~~plus~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jc147a`,
        fs:  `cpe:2.3:a:otrs:otrs:0.5:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jc147b`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.51.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jc148a`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jc148b`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jc149a`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jc149b`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.0:beta0001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jc150a`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jc150b`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd429b`,
        fs:  `cpe:2.3:a:haxx:curl:7.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd431a`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd432a`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd433a`,
        fs:  `cpe:2.3:a:janetter:janetter:2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd653a`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd655a`,
        fs:  `cpe:2.3:a:drupal:drupal:6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd656a`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd662a`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd663a`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd663b`,
        fs:  `cpe:2.3:a:google:chrome:16.0.906.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd664a`,
        fs:  `cpe:2.3:a:mesa3d:mesa:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd916a`,
        fs:  `cpe:2.3:a:samba:samba:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd917a`,
        fs:  `cpe:2.3:a:citrix:xendesktop:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd918a`,
        fs:  `cpe:2.3:h:d-link:dap-2360:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd921a`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd922a`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd923a`,
        fs:  `cpe:2.3:a:djangoproject:django:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd935a`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd943a`,
        fs:  `cpe:2.3:a:powerdns:authoritative_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd944a`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0404hd-l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd945a`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd946a`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd967a`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jd972a`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf182a`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf183a`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1\(3\)sr4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf184a`,
        fs:  `cpe:2.3:a:paperton:dive_the_world:1.53:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf228a`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf229a`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf230a`,
        fs:  `cpe:2.3:a:ibm:hacmp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf231a`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf233a`,
        fs:  `cpe:2.3:h:hp:0235a38k:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf234a`,
        fs:  `cpe:2.3:a:straightrunning:xming:6.9.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf235a`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf236a`,
        fs:  `cpe:2.3:a:qemu:qemu:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf237a`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf238a`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf239a`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf240a`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf241a`,
        fs:  `cpe:2.3:a:google:chrome:10.0.625.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf283a`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(16\)aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf284a`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf285a`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf287a`,
        fs:  `cpe:2.3:a:cisco:prime_optical:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf640a`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf800a`,
        fs:  `cpe:2.3:a:ibm:operational_decision_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf801a`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf802a`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf803a`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf804a`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf806a`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf807a`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf808a`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf809a`,
        fs:  `cpe:2.3:a:symantec:ghost_console_and_standard_tools:115.0.2113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf812a`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:10.0_xc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf813a`,
        fs:  `cpe:2.3:o:brother:mfc-j4410dw_firmware:k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf814a`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf815a`,
        fs:  `cpe:2.3:o:cisco:catos:4.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf816a`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.407:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_router:jf817a`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:658247-b21`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.2:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:658250-b21`,
        fs:  `cpe:2.3:a:adt-taxis:adt_taxis:6.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc085a`,
        fs:  `cpe:2.3:a:ad-minister_project:ad-minister:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc086a`,
        fs:  `cpe:2.3:a:emc:networker:7.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc099a`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc100a`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc101a`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc102a`,
        fs:  `cpe:2.3:a:hp:openview_autopass:5.50.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc103a`,
        fs:  `cpe:2.3:a:ca:brightstor_san_manager:1.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc104a`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc105a`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc106a`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc124a`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc124b`,
        fs:  `cpe:2.3:a:tenable:nessus:6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc125a`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc125b`,
        fs:  `cpe:2.3:o:sun:solaris:2.6:hw5:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc474a`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc474b`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc611a`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc612a`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.14:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc613a`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.99.904:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc652a`,
        fs:  `cpe:2.3:a:cogentdatahub:opc_datahub:6.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc653a`,
        fs:  `cpe:2.3:a:mozilla:firefox:19.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc654a`,
        fs:  `cpe:2.3:h:hp:color_laserjet_2500tn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc655a`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc691a`,
        fs:  `cpe:2.3:a:chillingo:flying_fox:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc694a`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jc748a`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd007a`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0.320:update32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd008a`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd009a`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.567:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd010a`,
        fs:  `cpe:2.3:a:gnu:aspell:0.50-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd011a`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd238a`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:8.0.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd238b`,
        fs:  `cpe:2.3:a:redhat:lv:4.49.4-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd239a`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd239b`,
        fs:  `cpe:2.3:a:xchat:xchat:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd240a`,
        fs:  `cpe:2.3:a:perl:perl:0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd240b`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.325:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd241a`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd241b`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd242a`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:-:pulse:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd242b`,
        fs:  `cpe:2.3:h:d-link:dsr-250:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd243a`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd243b`,
        fs:  `cpe:2.3:a:adobe:flash_player:8.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd302a`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.5:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd303a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.24:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd304a`,
        fs:  `cpe:2.3:a:gnu:gdb:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd305a`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.0:dev1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd306a`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd307a`,
        fs:  `cpe:2.3:a:alkacon:opencms:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd308a`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.011:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd309a`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_client:7.2.1163_service_pack_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd310a`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd313b`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1669.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd317a`,
        fs:  `cpe:2.3:a:jpmorganchase:chase_mobile:2.7:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd318b`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.271:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd319b`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.7:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd320b`,
        fs:  `cpe:2.3:a:apache:libcloud:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd325a`,
        fs:  `cpe:2.3:a:web2py:web2py:1.90.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd326a`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd327a`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd328a`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd329a`,
        fs:  `cpe:2.3:a:google:update_helper:1.3.21.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd330a`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd331a`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd332a`,
        fs:  `cpe:2.3:a:apache:wink:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd333a`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.389:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd334a`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd335a`,
        fs:  `cpe:2.3:a:kony:enterprise_mobile_management:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd336a`,
        fs:  `cpe:2.3:a:webyog:sqlyog:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd337a`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd338a`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd344a`,
        fs:  `cpe:2.3:a:ca:unicenter_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd345a`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd346a`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd347a`,
        fs:  `cpe:2.3:a:novell:netmail:3.5.2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd348a`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd349a`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd350a`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd351a`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.05.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd352a`,
        fs:  `cpe:2.3:o:huawei:s9712_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd353a`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd354a`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd355a`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd356a`,
        fs:  `cpe:2.3:a:teradata:dssp:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd357a`,
        fs:  `cpe:2.3:a:microsoft:visual_c\&#43;\&#43;:2005:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd369a`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:12.04:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd370a`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd371a`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.1.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd372a`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd373a`,
        fs:  `cpe:2.3:a:vmware:player:3.1.0.12623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd374a`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd375a`,
        fs:  `cpe:2.3:a:ibm:connections:2.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd376a`,
        fs:  `cpe:2.3:h:supermicro:x9sce-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd377a`,
        fs:  `cpe:2.3:a:tecolote:aceit:7.2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd378a`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd379a`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd391a`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:2.1:*:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd392a`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd393a`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.0.0.7797:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd394a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p221:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jd395a`,
        fs:  `cpe:2.3:a:winscp:winscp:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je005a`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je006a`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je007a`,
        fs:  `cpe:2.3:a:microsoft:office:2010:sp1:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je008a`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je009a`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je015a`,
        fs:  `cpe:2.3:a:module-signature_project:module-signature:0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je016a`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:2.7.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je017a`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je018a`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je019a`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je020a`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)mra4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je021a`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je022a`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je023a`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4501_series_software:4.2\(1.43\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je024a`,
        fs:  `cpe:2.3:a:cisco:webex_meeting_center_for_firefox_or_chrome:8.23.2504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je025a`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2.9.211.2224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je026a`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.0.2p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je027a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je028a`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je029a`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.40.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je030a`,
        fs:  `cpe:2.3:a:isc:bind:4.9.5:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je031a`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.112.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je032a`,
        fs:  `cpe:2.3:a:sosreport_project:sosreport:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je033a`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je045a`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je046a`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je047a`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je048a`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je066a`,
        fs:  `cpe:2.3:o:cisco:catos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je067a`,
        fs:  `cpe:2.3:a:splunk:universal_forwarder:4.2.3.105575:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je068a`,
        fs:  `cpe:2.3:a:hitachi:serverconductor\/deploymentmanager:01-00:-:-:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je069a`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:2.9.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je070a`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je071a`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je072a`,
        fs:  `cpe:2.3:a:adastra:trace_mode_data_center:6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je073a`,
        fs:  `cpe:2.3:a:isc:bind:9.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je074a`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je088a`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.1:sp1:-:*:documentum:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je089a`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je090a`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.2\(0\)n1\(0.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je091a`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je092a`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.02:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je093a`,
        fs:  `cpe:2.3:a:emc:powerpath:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je094a`,
        fs:  `cpe:2.3:a:corel:coreldraw:x5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je095a`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je096a`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je097a`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je099a`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je100a`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je101a`,
        fs:  `cpe:2.3:a:vkr_soft:government_best_jobs:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je102a`,
        fs:  `cpe:2.3:a:horde:imp:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je104a`,
        fs:  `cpe:2.3:a:macromedia:flash_player:6.0.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je105a`,
        fs:  `cpe:2.3:h:cisco:virtualization_experience_client_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je106a`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:15.020.20042:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je107a`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1496.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je108a`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je109a`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je110a`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.100.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je164a`,
        fs:  `cpe:2.3:o:bluecoat:cacheos:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je165a`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:8.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je166a`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je167a`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je168a`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:je169a`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf427a`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf428a`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp2:tablet_pc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf430a`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf430b`,
        fs:  `cpe:2.3:a:php:cvs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf430c`,
        fs:  `cpe:2.3:h:sophos:unified_threat_management:625:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf431a`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf431b`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf431c`,
        fs:  `cpe:2.3:a:web2py:web2py:1.83.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf551a`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.2:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf552a`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf553a`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:6.x-1.17:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf844a`,
        fs:  `cpe:2.3:a:phppgadmin_project:phppgadmin:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf845a`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf846a`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jf847a`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg091a`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg092a`,
        fs:  `cpe:2.3:a:oracle:oracle_berkeley_db:11.2.5.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg219a`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg221a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg222a`,
        fs:  `cpe:2.3:a:core-apps:bowl_expo_2014:6.1.1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg223a`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg225a`,
        fs:  `cpe:2.3:a:erlang:crypto:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg236a`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg237a`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg238a`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg239a`,
        fs:  `cpe:2.3:a:gnu:groff:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg240a`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg241a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg242a`,
        fs:  `cpe:2.3:a:tibco:activematrix_policy_agent:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg243a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg245a`,
        fs:  `cpe:2.3:a:microsoft:excel:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg246a`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:8.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg247a`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg248a`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg249a`,
        fs:  `cpe:2.3:a:booksellerscanada:free_canadian_author_previews:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg250a`,
        fs:  `cpe:2.3:a:google:v8:3.24.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg251a`,
        fs:  `cpe:2.3:a:blaine_lang:filedepot:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg252a`,
        fs:  `cpe:2.3:a:symantec:network_access_control:11.0.6000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg253a`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg254a`,
        fs:  `cpe:2.3:a:apple:cups:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg255a`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg256a`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.3315.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg257a`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:12.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg258a`,
        fs:  `cpe:2.3:a:ibm:serverguide:9.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg259a`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg299a`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg300a`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnitouch_8400_instant_communications_suite:6.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg301a`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg302a`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg303a`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg304a`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg305a`,
        fs:  `cpe:2.3:a:apple:webkit:125.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg306a`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(12\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg307a`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg311a`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)t9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg312a`,
        fs:  `cpe:2.3:o:huawei:s9312_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg315a`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg316a`,
        fs:  `cpe:2.3:h:d-link:dsr-150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg348a`,
        fs:  `cpe:2.3:a:vmware:view:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg349a`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)ird1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg350a`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.5.2:-:-:ja-jp:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch:jg374a`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.15:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_1600m:-`,
        fs:  `cpe:2.3:a:oracle:customer_intelligence:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_1700-24:-`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_1700-8:-`,
        fs:  `cpe:2.3:a:google:v8:3.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_1800-24g:-`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_1800-8g:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2400m:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2424m:-`,
        fs:  `cpe:2.3:a:ibm:gina:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2610:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2610-24:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2610-24-pwr:-`,
        fs:  `cpe:2.3:a:vmware:fusion:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2610-24%2f12pwr:-`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2610-48:-`,
        fs:  `cpe:2.3:h:fortinet:fortigate-3240c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2610-48-pwr:-`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2626:-`,
        fs:  `cpe:2.3:a:apache:ambari:2.2.2:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2626-pwr:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2650:-`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_2650-pwr:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.419:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_3500yl:-`,
        fs:  `cpe:2.3:a:checkpoint:next_generation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_3500yl:k.11.32`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_4000m:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.476:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_4000m:c.07.23`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_4000m:c.08.22`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_explorer:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_4000m:c.09.09`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_4000m:c.09.15`,
        fs:  `cpe:2.3:h:ibm:flex_system_manager_node_8731:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_5400zl:-`,
        fs:  `cpe:2.3:a:php_ireport_project:php_ireport:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_5400zl:k.11.32`,
        fs:  `cpe:2.3:a:rubyonrails:jquery-rails:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_6200yl:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_6200yl:k.11.32`,
        fs:  `cpe:2.3:a:conky:conky:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_8000m:-`,
        fs:  `cpe:2.3:a:netscape:communicator:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:-`,
        fs:  `cpe:2.3:a:hp:dynrootdisk:a.1.1.0.344:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:08.0.01c`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:08.0.01d`,
        fs:  `cpe:2.3:a:oracle:customer_intelligence:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:08.0.01e`,
        fs:  `cpe:2.3:a:wayne_allen:postie:1.5.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:08.0.01f`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6ccd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:08.0.01g`,
        fs:  `cpe:2.3:a:apple:keynote:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:08.0.01h`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:08.0.01i`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:procurve_switch_9300m:08.0.01j`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1685.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h:10.74`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h:10.80`,
        fs:  `cpe:2.3:a:user_import_project:user_import:6.x-4.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.02`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp3:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.03`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.0:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.31`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.32`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2650-pwr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.41`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.3:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.45`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.46`,
        fs:  `cpe:2.3:a:mcafee:asset_baseline_monitor_agent:3.5.0.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.50`,
        fs:  `cpe:2.3:a:php:pear:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.53`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns8200x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.54`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.55`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.07.56`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.53`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.55`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.56`,
        fs:  `cpe:2.3:a:sun:jre:1.1.8:update14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.57`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:08-00-02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.58`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.59`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.60`,
        fs:  `cpe:2.3:a:jenkins:git:2.6.2:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.61`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.62`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.8.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.64`,
        fs:  `cpe:2.3:o:redhat:fedora_core:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.65`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.67`,
        fs:  `cpe:2.3:a:microsoft:dynamics_ax:2012:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.69`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.70`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.71`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.72`,
        fs:  `cpe:2.3:a:microsoft:data_protection_manager:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.73`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.74`,
        fs:  `cpe:2.3:a:redhat:rhevm-reports:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.75`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.76`,
        fs:  `cpe:2.3:a:google:chrome:5.0.346.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.77`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.11.0:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.78`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.79`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.80`,
        fs:  `cpe:2.3:a:apple:itunes:7.1.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.81`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.82`,
        fs:  `cpe:2.3:a:google:update_helper:1.3.21.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.83`,
        fs:  `cpe:2.3:a:3com:3c16116-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.84`,
        fs:  `cpe:2.3:a:busybox:busybox:1.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.85`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.86`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.87`,
        fs:  `cpe:2.3:a:glub:secure_ftp:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.88`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.89`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.92:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.90`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.91`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.92`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.93`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.94`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.475:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.95`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.96`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.97`,
        fs:  `cpe:2.3:h:huawei:ar_28\/46:r0311:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.98`,
        fs:  `cpe:2.3:a:web2py:web2py:1.94.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.99`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.100`,
        fs:  `cpe:2.3:a:autodesk:backburner:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.101`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.102`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.103`,
        fs:  `cpe:2.3:a:ca:cleverpath_ecm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.104`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.105`,
        fs:  `cpe:2.3:a:lsi:sas-ir_storage_snmp_agent:3.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.106`,
        fs:  `cpe:2.3:a:phpblogger:php-blogger:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.107`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.108`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.035_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.08.109`,
        fs:  `cpe:2.3:h:hp:officejet_5500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.20`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.21`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p38:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.22`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.0.1:-:liberty_profile:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.23`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.24`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.0:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.25`,
        fs:  `cpe:2.3:h:xerox:workcentre_40_color:01.02.053.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.26`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.27`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(15\)sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.28`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.017.20053:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.29`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.2:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.30`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.31`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.32`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.33`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.35`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.36`,
        fs:  `cpe:2.3:o:ibm:zos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.37`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.0:beta-3:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.38`,
        fs:  `cpe:2.3:a:dvs_custom_notification_project:dvs_custom_notification:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.39`,
        fs:  `cpe:2.3:a:alienwp:hatch:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.40`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.41`,
        fs:  `cpe:2.3:a:163:netease_movie:4.7.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.42`,
        fs:  `cpe:2.3:a:atheme:atheme:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.43`,
        fs:  `cpe:2.3:a:edimax:print_server_utilities:4.2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.44`,
        fs:  `cpe:2.3:a:macromedia:coldfusion_fusebox:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.45`,
        fs:  `cpe:2.3:a:bluecoat:reporter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.46`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.47`,
        fs:  `cpe:2.3:a:samba:samba:1.9.17:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.48`,
        fs:  `cpe:2.3:a:apple:software_update:2.1.2.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.49`,
        fs:  `cpe:2.3:h:hp:9200c_digital_sender:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.50`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.51`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.52`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.53`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.54`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.55`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(2\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.56`,
        fs:  `cpe:2.3:a:sendmail:sendmail_pro:8.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.57`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:9.2\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.58`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.9:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.59`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17b\)sxa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.60`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.61`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.62`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro:11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.63`,
        fs:  `cpe:2.3:a:microsoft:office:2010:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.64`,
        fs:  `cpe:2.3:h:hp:h3c_routing_switch:s12508:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.65`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.66`,
        fs:  `cpe:2.3:a:google:chrome:16.0.892.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.67`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.68`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.69`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs4_presets:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.70`,
        fs:  `cpe:2.3:h:hp:scanjet_8200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.71`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.72`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.73`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.0.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.74`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:h.10.80`,
        fs:  `cpe:2.3:a:juniper:installer_service:1.3.2.12005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.01`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.02`,
        fs:  `cpe:2.3:a:mail.ru:mail.ru_dating:3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.03`,
        fs:  `cpe:2.3:a:intel:network_connections:15.4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.04`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:5.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.05`,
        fs:  `cpe:2.3:a:ibm:websphere_process_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.06`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.07`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.08`,
        fs:  `cpe:2.3:a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.02.09`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.03.00`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:1.3\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.03.01`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.5-60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.03.02`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.03.03`,
        fs:  `cpe:2.3:h:seagate:blackarmor_nas_220:st340005lsa10g-rk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pa.03.04`,
        fs:  `cpe:2.3:a:nokia:affix:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.01`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.02`,
        fs:  `cpe:2.3:a:python-gnupg_project:python-gnupg:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.03`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p386:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.04`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.05`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.06`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.07`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.08`,
        fs:  `cpe:2.3:a:core-apps:aihce_2014:6.1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.02.09`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.03.00`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.03.01`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.03.02`,
        fs:  `cpe:2.3:a:wdc:arkeia_virtual_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.03.03`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.30.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:pb.03.04`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(2.11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.04`,
        fs:  `cpe:2.3:o:huawei:s6700_firmware:v200r008c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.05`,
        fs:  `cpe:2.3:a:samba:samba:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.06`,
        fs:  `cpe:2.3:a:opus-codec:opus:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.07`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.11.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.08`,
        fs:  `cpe:2.3:a:vmware:license_server:2.5.0.64237:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.09`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.10`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.11`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.12`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.0.0.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.13`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.14`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.15`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:18.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.16`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.17`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.18`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:4.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.19`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.20`,
        fs:  `cpe:2.3:a:apple:webkit:522.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.21`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.22`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:8.0.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.23`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:3.0.0:beta.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.24`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.25`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.26`,
        fs:  `cpe:2.3:a:nobexrc:talk_radio_europe:3.3.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.27`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.28`,
        fs:  `cpe:2.3:a:plone:plone:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.29`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.30`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.21511:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.31`,
        fs:  `cpe:2.3:a:phplist:phplist:2.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.32`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:361.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.33`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.34`,
        fs:  `cpe:2.3:h:ibm:ds4100:1724:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.35`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.36`,
        fs:  `cpe:2.3:a:openstack:swift:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.37`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p175:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.38`,
        fs:  `cpe:2.3:a:microsoft:access:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.39`,
        fs:  `cpe:2.3:a:xnview:xnview:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.40`,
        fs:  `cpe:2.3:a:rhq-project:rhq:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.41`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.42`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.43`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.44`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.0:beta-rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.45`,
        fs:  `cpe:2.3:a:xerox:docushare:6.6.1:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.46`,
        fs:  `cpe:2.3:a:morbus_iff:activism:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.47`,
        fs:  `cpe:2.3:h:huawei:s6700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.48`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.49`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.14m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.50`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.51`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.52`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5800-60c-pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.53`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:r.11.54`,
        fs:  `cpe:2.3:a:wave:embassy_trust_suite:3.5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:procurve_switch_software:va.02.08`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:2.0.0.0`,
        fs:  `cpe:2.3:a:isc:bind:9.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:53.0.13.0`,
        fs:  `cpe:2.3:a:redhat:rhel_developer_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:53.0.24.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:60.0.155.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:70.0.170.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:82.0.173.0`,
        fs:  `cpe:2.3:a:nvidia:control_panel:260.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:90.0.146.0`,
        fs:  `cpe:2.3:a:arellia:arellia_common_report_pack:6.0.1103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:100.0.1.0`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:100.0.170.0`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:120.0.194.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:130.0.371.0`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:140.0.212.0`,
        fs:  `cpe:2.3:o:vmware:esx:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_assistant:140.0.213.0`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_detection:4.0.11`,
        fs:  `cpe:2.3:a:bioinformatics:ordersys:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_detection:9.7.2`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:product_detection:10.7.9.0`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:productcontext:47.0.1.0`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2010:14.0.896.64:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:productcontext:50.0.165.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:productcontext:50.0.206.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:productcontextnpi:70.0.231.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:productcontextnpi:71.0.215.0`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_array_diagnostics:9.40`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_dl120_g6:-`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_dl170h_g6:-`,
        fs:  `cpe:2.3:h:hp:0235a31w:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_dl180_g6:-`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_dl2x170h_g6:-`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.40.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_dl4x170h_g6:-`,
        fs:  `cpe:2.3:a:cisco:jabber:9.0\(.0\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_dl585:-`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs728ts:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_ilo_management_controller_package:3.0.0.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_ilo_management_controller_package:3.3.0.0`,
        fs:  `cpe:2.3:a:gnome:glib:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_ilo_monitor_service:3.1.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:sap:netweaver:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_ilo_monitor_service:3.2.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2da:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_ilo_monitor_service:3.2.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_ilo_monitor_service:3.3.0.0`,
        fs:  `cpe:2.3:h:buffalotech:wer-amg54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_ilo_monitor_service:3.3.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_lights_out:-`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_lights_out:1.70`,
        fs:  `cpe:2.3:a:emc:unisphere_central:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_lights_out:1.87`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_lights_out:2_1.00`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_lights_out:2_1.11`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_lights_out_2:-`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_lights_out_2:1.00`,
        fs:  `cpe:2.3:o:yamaha:rta55i:4.06.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_lights_out_2:1.11`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.10.0.0`,
        fs:  `cpe:2.3:a:haxx:curl:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.12.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.13.0.0`,
        fs:  `cpe:2.3:a:openpkg:openpkg:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.20.0.0`,
        fs:  `cpe:2.3:a:search_api_autocomplete_project:search_api_autocomplete:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.21.0.0`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.22.0.0`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0069:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.23.0.0`,
        fs:  `cpe:2.3:a:nero:vision:6.0.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.24.0.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_integrated_management_log_viewer:5.25.0.0`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_ml110_g6:-`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_ml150_g6:-`,
        fs:  `cpe:2.3:h:xerox:document_centre_426:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_remote_monitor_service:5.11.1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_remote_monitor_service:5.11.2.0`,
        fs:  `cpe:2.3:a:websense:websense_web_filter:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_remote_monitor_service:5.11.3.0`,
        fs:  `cpe:2.3:a:adam_zaninovich:sounder:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_remote_monitor_service:5.20.0.0`,
        fs:  `cpe:2.3:o:gehealthcare:centricity_dms_firmware:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_remote_monitor_service:5.21.0.0`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:9.00.00.2980:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_sl160z_g6:-`,
        fs:  `cpe:2.3:a:vmware:workstation_pro:12.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_sl170z_g6:-`,
        fs:  `cpe:2.3:a:adobe:robohelp:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:proliant_sl2x170z_g6:-`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:5.5:u1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_smart_array_device_manager_extension:6.2.0.32`,
        fs:  `cpe:2.3:a:webelinx:_beauty_bible_-_app_for_girls_:5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_smart_array_device_manager_extension:6.4.0.64`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:proliant_smart_array_device_manager_extension:6.6.0.32`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_1100:-`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(26\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_1200:-`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_1210_all-in-one:-`,
        fs:  `cpe:2.3:a:gnu:readline:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_1210_all-in-one:1.0`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_1210_all-in-one:1.0.0.1`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_1300:-`,
        fs:  `cpe:2.3:a:quest:messagestats_report_pack_for_blackberry:1.0.1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_2100:-`,
        fs:  `cpe:2.3:a:apache:activemq:5.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_2200:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_2400_photosmart_all-in-one:-`,
        fs:  `cpe:2.3:a:niif:shibb_auth:7.x-4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_2500_photosmart_all-in-one:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_2510_photosmart:-`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_700:-`,
        fs:  `cpe:2.3:a:vips:vips:7.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_750:-`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:psc_900:-`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:373.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:psprinters08:8.1.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_4730_mfp:cb480a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:psswcore:2.1.0`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:psswcore:2.2.0`,
        fs:  `cpe:2.3:o:iij:eil\%2fx2_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:pstaplugin:8.1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:pusb_thermal_receipt_printer_f7m67aa:-`,
        fs:  `cpe:2.3:a:novell:sentinel_log_manager:1.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:pusb_thermal_receipt_printer_fk224aa:-`,
        fs:  `cpe:2.3:a:sun:openoffice.org:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:quality_center:9.2_patch_10`,
        fs:  `cpe:2.3:h:hughes:hs3400_media_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:quality_center_client_side:10.0.0.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:quick_launch_button:-`,
        fs:  `cpe:2.3:h:hp:jg515a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:quick_launch_button:6.3`,
        fs:  `cpe:2.3:a:osisoft:pi_interface:1.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:quicktest_professional:10.0.0`,
        fs:  `cpe:2.3:a:google:chrome:0.4.154.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:quicktransfer:140.0.98.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:radia_client:3.1.0.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:radia_client:3.1.2.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:radia_notify_daemon:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:randmap:53.0.13.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:randmap:70.0.170.0`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0b.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:rapid_deployment_pack:-`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:readme:47.0.1.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:readme:50.0.206.0`,
        fs:  `cpe:2.3:a:helios:textpad:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:readme:60.0.196.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:readme:70.0.231.0`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:readme:71.0.215.0`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:release_control:9.1`,
        fs:  `cpe:2.3:a:microsoft:outlook_web_access:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:release_control:9.11`,
        fs:  `cpe:2.3:o:apple:iphone_os:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:release_control:9.12`,
        fs:  `cpe:2.3:a:oracle:industry_applications:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:release_control:9.13`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.0_build_5257:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:release_control:9.20`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:release_control:9.21`,
        fs:  `cpe:2.3:a:oracle:knowledge_management:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:remote_access_to_hp_network:6.0.0.7`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.3:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:remote_diagnostics_enabling_agent:-`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:reporter:3.8`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:restful_interface_tool:1.40`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:retail_integrated_2x20_complex_g7g29aa:-`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.23:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:retail_integrated_2x20_display_g6u79aa:-`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:retail_integrated_barcode_scanner_e1l07aa:-`,
        fs:  `cpe:2.3:a:piwik:piwik:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:retail_rp7_vfd_customer_display_qz701aa:-`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:s1000-e_vpn_firewall_appliance:jd272a`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc13:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:san%2fiq:8.0`,
        fs:  `cpe:2.3:a:mistelix:mistelix:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:san%2fiq:8.1`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.0:preview2.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:san%2fiq:8.5`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:san%2fiq:9.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:san%2fiq:9.5`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:san%2fiq:10.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sanworks:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)db1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:savedtoolsdata:1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:4.5.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:4.5.1.0`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:4.9.0.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:5.2.0.0`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:6.0.0.0`,
        fs:  `cpe:2.3:a:openkm:openkm:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:6.1.0.0`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:7.0.0.0`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:8.1.0.0`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:9.0.0.0`,
        fs:  `cpe:2.3:a:perl:perl:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:9.0.2.0`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:9.0.3.0`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:10.1.0.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:11.6.1.0`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:12.0.0.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:13.0.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:140.0.80.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.458:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan:140.0.167.0`,
        fs:  `cpe:2.3:a:microsoft:visual_basic_software_development_kit:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scan_to:2.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:scanjet_2400:-`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:scanjet_3670c:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:scanjet_4500c:-`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:scanjet_5590:-`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:scanjet_7650:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:scanjet_8200:-`,
        fs:  `cpe:2.3:a:apple:safari:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scanjet_8200_firmware:1.0`,
        fs:  `cpe:2.3:a:wpgetready:nextcellent_gallery:1.9.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scanjet_8200_firmware:1.06`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:scanjet_8200c:-`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scanjet_8200c_firmware:1.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scanjet_8200c_firmware:1.06`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:scanjet_8250:-`,
        fs:  `cpe:2.3:h:huawei:acu:v100r003c01spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scanjet_utilities:-`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scannercopy:4.5.0.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scannercopy:5.2.0.0`,
        fs:  `cpe:2.3:a:preplogic:exam_security\&#43;_2008:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scannercopy:7.0.0.0`,
        fs:  `cpe:2.3:a:litronic:netsign_cac:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:scannercopy:9.0.0.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secbladefw:5.20`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secpath1000fe:5.20`,
        fs:  `cpe:2.3:a:e-press:one_office_e-notetaker:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:secure_os:-`,
        fs:  `cpe:2.3:o:gentoo:linux:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secure_web_console:-`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secure_web_server_for_tru64:-`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secure_web_server_for_tru64:5.8.1`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secure_web_server_for_tru64:5.8.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secure_web_server_for_tru64:5.9.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secure_web_server_for_tru64:5.9.2`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:secure_web_server_for_tru64:6.3.0`,
        fs:  `cpe:2.3:o:freebsd:freebsd:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_access:6.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:rc.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_access:6.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:-`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.01`,
        fs:  `cpe:2.3:a:oracle:database_server:4.0.8:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.3:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.2`,
        fs:  `cpe:2.3:a:redhat:linux:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.4`,
        fs:  `cpe:2.3:a:google:chrome:0.3.154.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.6`,
        fs:  `cpe:2.3:a:sgi:quake_1_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.7`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.8`,
        fs:  `cpe:2.3:a:vmware:workstation:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.9`,
        fs:  `cpe:2.3:a:avonesoft:zune_video_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.1.10`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.10`,
        fs:  `cpe:2.3:a:polycom:realpresence_media_manager_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.11`,
        fs:  `cpe:2.3:a:logitech:lws_launcher:13.0.1776.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.12`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.469:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.13`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:select_identity:4.13.1`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sendmail:-`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sendmail:8.8.6`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:serialusb_thermal_receipt_printer_bm476aa:-`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:server_migration_pack_universal_edition:3.0`,
        fs:  `cpe:2.3:a:enhydra:director:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_center:6.2.8`,
        fs:  `cpe:2.3:h:hp:jg531a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:service_center_server:6.2.8`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_center_web_tier:6.28`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.10.1005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_location_protocol:1.0.9a`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager:7.02`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager:7.11`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager:9.20`,
        fs:  `cpe:2.3:a:hummingbird:connectivity:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager:9.21`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:service_manager:9.30`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs3_presets:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager:9.30`,
        fs:  `cpe:2.3:a:ibm:java:5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:service_manager:9.31`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager:9.31`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager:9.32`,
        fs:  `cpe:2.3:a:php.s3.to:tree_bbs:2002\/09\/23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:service_manager_server:7.11`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:service_manager_server:9.21`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p141:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:service_manager_server:9.30`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager_web_client:9.20`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager_web_client:9.21`,
        fs:  `cpe:2.3:a:xnview:xnview:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager_web_tier:7.11`,
        fs:  `cpe:2.3:a:pluck-cms:pluck:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager_web_tier:9.20`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager_web_tier:9.21`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager_web_tier:9.30`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.8.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_manager_web_tier:9.31`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_virtualization:3.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:service_virtualization:3.50.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:serviceguard:-`,
        fs:  `cpe:2.3:h:hp:3crevf100-73:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:serviceguard:a.11.13`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:serviceguard:a.11.14`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:serviceguard:a.11.15.00`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:serviceguard:a.11.16.00`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:serviceguard:a.11.19`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:serviceguard:a.11.20`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:shared_trace_service:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:shared_trace_service:a.07.50`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:shareins:1.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:shop_for_hp_supplies:10.0`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:shop_for_hp_supplies:14.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:9.0`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:10.10`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:10.11`,
        fs:  `cpe:2.3:a:urbantwilight:duperazor:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:10.12`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.00.4064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:10.13`,
        fs:  `cpe:2.3:a:isc:bind:9.10.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:10.14`,
        fs:  `cpe:2.3:a:sphider:sphider:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.10`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.11`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.12`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.13`,
        fs:  `cpe:2.3:o:buffalotech:bhr-4grv2_firmware:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.20`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.21`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.11.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.22`,
        fs:  `cpe:2.3:a:debian:mime-support:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.23`,
        fs:  `cpe:2.3:h:cisco:nexus_9372px:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.24`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.24.391`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.44:test1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope:11.30.521`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_components_patch:11.11.10`,
        fs:  `cpe:2.3:a:openstack:compute:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_core:11.0.0`,
        fs:  `cpe:2.3:a:ilearnwith:numbers_\&amp;_addition\!_math_games:1.4.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_core:11.10.0`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_integrations:11.0.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_integrations:11.10.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_integrations:11.11.0`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_monitoring:11.0.0`,
        fs:  `cpe:2.3:a:xnview:xnview:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_monitoring:11.10.0`,
        fs:  `cpe:2.3:a:autodesk:land_desktop:2005:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_patch:11.10.0`,
        fs:  `cpe:2.3:a:groupon:groupon_merchants:-:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_server:11.0.0`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_server:11.10.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_tools:11.0.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_tools:11.10.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.906.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_user_interface:11.0.0`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sitescope_user_interface:11.10.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:slideshow:70.0.170.0`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.4:3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_multipath_software:2.0b`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.0.0.32`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-00-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.2.0.32`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.4.0.32`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.8.0.32`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:tr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.8.0.64`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.10.0.32`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2000i:sp1:unlocked:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.10.0.64`,
        fs:  `cpe:2.3:a:usbank:academy_sports_\&#43;_outdoors_visa:1.18:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.12.0.32`,
        fs:  `cpe:2.3:a:hp:desms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.12.0.64`,
        fs:  `cpe:2.3:a:wave:esc_home_page_plugin:4.0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.14.0.32`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.14.0.64`,
        fs:  `cpe:2.3:a:terragotech:geopdf_toolbar:4.1.208:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.16.0.32`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.16.0.64`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.18.0.32`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.18.0.64`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(4g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.20.0.32`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.20.0.64`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.22.0.32`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_redundant_controller_firmware:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.22.0.64`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.24.0.32`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.023.20053:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_array_sas%2fsata_event_notification_service:6.24.0.64`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_update_manager:5.3.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.02.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_web_printing:2.15.7.0`,
        fs:  `cpe:2.3:a:radscan:network_audio_system:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_web_printing:3.5`,
        fs:  `cpe:2.3:a:avst:callxpress:7.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_web_printing:4.5`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_web_printing:4.60`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_web_printing:120.0.194.0`,
        fs:  `cpe:2.3:a:vmware:player:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_web_printing:140.0.186.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(4.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_web_printing:140.0.213.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.6:pre9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_web_printing_oc:100.0.189.0`,
        fs:  `cpe:2.3:o:vmware:esx:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smart_zero_core:4.4`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:smartssd_wear_gauge_utility:9.40`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:sn6000_stackable_8gb_12-port_single_power_fibre_channel_switch:bk780a`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:sn6000_stackable_8gb_12-port_single_power_fibre_channel_switch:bk780b`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:sn6000_stackable_8gb_24-port_dual_power_fibre_channel_switch:aw576a`,
        fs:  `cpe:2.3:h:nortel:vpn_router_1740:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:sn6000_stackable_8gb_24-port_dual_power_fibre_channel_switch:aw576b`,
        fs:  `cpe:2.3:a:citrix:ica_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:sn6000_stackable_8gb_24-port_single_power_fibre_channel_switch:aw575a`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:sn6000_stackable_8gb_24-port_single_power_fibre_channel_switch:aw575b`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.1.0-110.sles10`,
        fs:  `cpe:2.3:a:epractizelabs:subscription_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.1.1-22.sles10`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller:1.1\(0.920a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.2.0-284.sles10`,
        fs:  `cpe:2.3:a:isc:bind:9.2.4:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.2.2-20.sles10`,
        fs:  `cpe:2.3:a:ktools:photostore:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.2.5-50.sles10`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.2.6-5.sles10`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.4.0`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.5.0`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.6.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:8.7.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update2:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:snmp_agents_for_linux:9.0.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sockd:0.4`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sockd:0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_agent_for_microsoft_terminal_server:9.51.0`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_certificate_management_client:6.0.50`,
        fs:  `cpe:2.3:a:adobe:acrobat:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_certificate_management_client:6.20.50`,
        fs:  `cpe:2.3:a:lxml:lxml:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_configuration:6.0.70`,
        fs:  `cpe:2.3:o:westermo:weos:4.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_configuration:6.20.101`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_core_japanese_localization:6.20.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_core_korean_localization:6.20.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_core_simplified_chinese_localization:6.20.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_core_spanish_localization:6.20.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_cross_platform_component:6.0.41`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_cross_platform_component:6.0.85`,
        fs:  `cpe:2.3:a:idera:uptime_infrastructure_monitor:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_cross_platform_component:6.0.96`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_cross_platform_component:6.20.54`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_cross_platform_component:6.20.105`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_deployment:6.0.75`,
        fs:  `cpe:2.3:h:cisco:ipvc-3525-gw-1p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_deployment:6.20.101`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.2\(1.46\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_jre:1.4.250`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_jre:1.6.4`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_perl:5.8.84`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs725ts:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_perl:5.8.85`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_perl:5.8.87`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_process_control:6.0.51`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.0.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_process_control:6.0.80`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_process_control:6.20.52`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.15-25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_security_core:6.0.30`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_security_core:6.0.50`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(25e\)jam6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_security_core:6.20.50`,
        fs:  `cpe:2.3:a:plone:plone:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_update:2.0.37.20031205`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_update:2.0.38.20040107`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.7:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_update:3.0.2.991`,
        fs:  `cpe:2.3:o:compaq:tru64:5.0f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_update:3.0.5.1`,
        fs:  `cpe:2.3:h:cabletron:6h202-24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_update:3.0.6.3`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_update:3.0.7.14`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_xalana_xslt_processor:1.10.60`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_xalana_xslt_processor:1.10.73`,
        fs:  `cpe:2.3:a:moweather:moweather:1.40.05:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_xercesa_xml_parser:2.7.50`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:software_xercesa_xml_parser:2.7.63`,
        fs:  `cpe:2.3:o:oracle:linux:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:7.0`,
        fs:  `cpe:2.3:a:invitation_project:invitation:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:8.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:9.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:10.0`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:12.0`,
        fs:  `cpe:2.3:a:jason_savino:fp:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:13.0`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg210-10:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:14.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:50.0.152.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:60.0.155.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg238a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:70.0.170.0`,
        fs:  `cpe:2.3:a:sun:iplanet_directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:82.0.188.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:90.0.146.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:100.0.175.0`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc3300:a6901a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:120.0.194.0`,
        fs:  `cpe:2.3:a:novell:zenworks:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:130.0.373.0`,
        fs:  `cpe:2.3:h:cisco:ips_4240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:140.0.213.0`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center:140.0.214.0`,
        fs:  `cpe:2.3:a:mh-nexus:hxd_hex_editor_version:1.7.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center_and_imaging_support_tools:5.3`,
        fs:  `cpe:2.3:a:gnu:grep:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:solution_center_and_imaging_support_tools:6.0`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sonic_primo_sdk:53.0.13.0`,
        fs:  `cpe:2.3:a:oxide_project:oxide:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:sonic_primo_sdk:70.0.170.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ssl_http_server:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1659.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:53.0.13.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:53.0.24.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:60.0.155.0`,
        fs:  `cpe:2.3:o:sun:sunos:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:70.0.170.0`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-04-13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:82.0.173.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:90.0.146.0`,
        fs:  `cpe:2.3:h:grandstream:gxv3601:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:100.0.175.0`,
        fs:  `cpe:2.3:a:dell:sonicwall_global_management_system:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:100.0.272.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.0.98.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:110.0.180.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:120.0.194.0`,
        fs:  `cpe:2.3:a:i-gen:oplynx:2.01.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:140.0.212.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:status:140.0.256.0`,
        fs:  `cpe:2.3:a:spice_project:spice:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.20:-:~~~hp-ux~~`,
        fs:  `cpe:2.3:a:kajona:kajona:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.20:-:~~~redhat_enterprise_linux~~`,
        fs:  `cpe:2.3:a:ibm:net.commerce:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.20:-:~~~solaris~~`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.20:-:~~~sunos~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.20:-:~~~suse_linux~~`,
        fs:  `cpe:2.3:a:welcart:welcart_plugin:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.20:-:~~~windows_server_2003~~`,
        fs:  `cpe:2.3:a:freshplanet:songpop:1.21.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.20:-:~~~windows_server_2008~~`,
        fs:  `cpe:2.3:a:microsoft:.net_windows_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.21:-:~~~hp-ux~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.3.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.21:-:~~~redhat_enterprise_linux~~`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr6404lf-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.21:-:~~~solaris~~`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.21:-:~~~sunos~~`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.21:-:~~~suse_linux~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.21:-:~~~windows_server_2003~~`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:6.21:-:~~~windows_server_2008~~`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.00:-:~~~hp-ux~~`,
        fs:  `cpe:2.3:a:digium:asterisk:14.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.00:-:~~~redhat_enterprise_linux~~`,
        fs:  `cpe:2.3:a:frontrange:devicewall:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.00:-:~~~suse_linux~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.00:-:~~~windows_server_2003~~`,
        fs:  `cpe:2.3:a:compaq:acms:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.00:-:~~~windows_server_2008~~`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.01:-:~~~hp-ux~~`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.01:-:~~~redhat_enterprise_linux~~`,
        fs:  `cpe:2.3:a:lxml:lxml:2.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.01:-:~~~suse_linux~~`,
        fs:  `cpe:2.3:a:altiris:monitor_solution_for_dell_servers:6.1.2046:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.01:-:~~~windows_server_2003~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:7.01:-:~~~windows_server_2008~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.78:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:8.0:-:~~~windows_7~~`,
        fs:  `cpe:2.3:h:huawei:usg5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:8.0:-:~~~windows_8~~`,
        fs:  `cpe:2.3:a:cisco:tftp_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:8.0:-:~~~windows_server_2003~~`,
        fs:  `cpe:2.3:a:wp_picasa_image_project:wp_picasa_image:1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:8.0:-:~~~windows_server_2008~~`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:8.10:-:~~~windows_7~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:8.10:-:~~~windows_8~~`,
        fs:  `cpe:2.3:a:kde:kde-workspace:4.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:8.10:-:~~~windows_server_2003~~`,
        fs:  `cpe:2.3:a:keepass:keepass:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_data_protector:8.10:-:~~~windows_server_2008~~`,
        fs:  `cpe:2.3:a:python:python:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_management_software:9.5`,
        fs:  `cpe:2.3:a:altiris:deployment_server_extension_for_ibm_director:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_management_software:10.0`,
        fs:  `cpe:2.3:h:3com:3c6012-901:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_management_software:10.5`,
        fs:  `cpe:2.3:a:biscom:faxcomapi_for_faxcom_queue:9.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_management_software:11.0`,
        fs:  `cpe:2.3:a:bottomline:transform_foundation_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_operations_manager_eva_5000:-`,
        fs:  `cpe:2.3:a:finalbeta:mywebsearch:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_suite:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.04:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storage_vcs_base_firmware:-`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_aix_host_agent_files:2.22.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_command_view_xp:2.22.0`,
        fs:  `cpe:2.3:a:twilightcms:twilight_cms:5.17:*:*:ru:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_common_services_xp:1.17.0`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11._host_agent_files:2.22.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.00_11.11_host_agent_files:2.22.0`,
        fs:  `cpe:2.3:a:yahoo:messenger:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.00_11.11_host_agent_files:3.40.0`,
        fs:  `cpe:2.3:h:netgear:fvg318:1.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.23_host_agent_files:3.40.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.23pi_ia_host_agent_files:3.40.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.23pi_pa_host_agent_files:3.40.0`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.pi_ia_host_agent_files:2.22.0`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.pi_ia_host_agent_files:3.40.0`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:10.2:sr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.pi_pa_host_agent_files:2.22.0`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.958:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_hp-ux_11.pi_pa_host_agent_files:3.40.0`,
        fs:  `cpe:2.3:a:cisco:context_directory_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_library_and_tape_tools:4.7.0.0`,
        fs:  `cpe:2.3:a:symantec:enterprise_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_nas_executor_e7000:-`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:08-00-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_p2000_g3_10gbe_iscsi_dual_controller_sff_array_system:aw597a`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_p2000_g3_iscsi_dual_controller_lff_array_system:bk830a`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_p2000_g3_msa_fc%2fiscsi_dual_combo_controller_lff_array_system:aw567a`,
        fs:  `cpe:2.3:a:avg:anti-virus:7.1:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_p2000_g3_msa_fibre_channel_dual_controller_lff_array_system:ap845a`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_p2000_g3_msa_fibre_channel_dual_controller_sff_array_system:ap846a`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_p2000_g3_sas_msa_dual_controller_lff_array_system:aw593a`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_performance_advisor_xp_software:3.40.0`,
        fs:  `cpe:2.3:a:ca:etrust_iam_suite:12.0.1.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_red_hat_enterprise_linux_3.0_host_agent_files:2.22.0`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_red_hat_enterprise_linux_advanced_server_1_host_agent_files:2.22.0`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.2.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_san_switch:-`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.8.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_san_switch:2.4.10`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_san_switch:3.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storageworks_san_switch:4.2.0`,
        fs:  `cpe:2.3:a:saltstack:salt:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_secure_path:-`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.0.1064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_secure_path:4.0c`,
        fs:  `cpe:2.3:a:netbsd:ftpd:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_secure_path:4.0c:sp2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_secure_path_windows:-`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_secure_path_windows:4.0c:sp2`,
        fs:  `cpe:2.3:a:oracle:application_management:12.1:*:*:*:*:e-business_suite:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_solaris_host_agent_files:2.22.0`,
        fs:  `cpe:2.3:a:apache:synapse:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_united_linux_1.0_%2f_sles8_host_agent_files:2.22.0`,
        fs:  `cpe:2.3:a:trend_micro:interscan_web_security_suite:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_windows_host_agent_files:2.22.0::~~~~x64~`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_windows_host_agent_files:3.40.0`,
        fs:  `cpe:2.3:h:axis:2130_ptz_network_camera:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_xp_host_agent_installer:3.40.0`,
        fs:  `cpe:2.3:a:mono:mono:1.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storageworks_xp_paxp_service_host_agent:3.40.0`,
        fs:  `cpe:2.3:a:iojs:io.js:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_2610_iscsi_backup_system:3.6.5`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_2610_iscsi_backup_system:3.9.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_2620_iscsi_backup_system:3.6.5`,
        fs:  `cpe:2.3:a:webmin:usermin:1.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_2620_iscsi_backup_system:3.9.0`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0.2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4210_fc_backup_system:3.6.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4210_fc_backup_system:3.9.0`,
        fs:  `cpe:2.3:a:dot:ccdpa:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4210_iscsi_backup_system:3.6.5`,
        fs:  `cpe:2.3:a:schneider-electric:citectscada:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4210_iscsi_backup_system:3.9.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4220_backup_system:3.6.5`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4220_backup_system:3.9.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4420_backup_system:3.6.5`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4420_backup_system:3.9.0`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.0\(1\)e0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4430_backup_system:3.6.5`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_4430_backup_system:3.9.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:storeonce_backup_system_software:3.13.0`,
        fs:  `cpe:2.3:h:ibm:system_x3650_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:1.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.1ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:1.2.17`,
        fs:  `cpe:2.3:a:phillip_lougher:squashfs:1.3:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:1.2.18`,
        fs:  `cpe:2.3:a:php:php:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:2.1.01`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:2.2.00`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:2.2.10`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20000421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:2.2.13`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:2.2.14`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:2.2.16`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_d2d:2.2.17`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.3:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_virtual_storage_appliance:3.7.1`,
        fs:  `cpe:2.3:a:hp:storage_management_software:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storeonce_virtual_storage_appliance:3.7.2`,
        fs:  `cpe:2.3:o:cisco:rv215w_firmware:1.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storevirtual_4130:-`,
        fs:  `cpe:2.3:a:adobe:connect_pro_add-in_for_microsoft_outlook:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storevirtual_4330:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storevirtual_4330fc:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.333:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storevirtual_4335:-`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router:1.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storevirtual_4530:-`,
        fs:  `cpe:2.3:a:hp:bufferchm:140.0.213.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storevirtual_4630:-`,
        fs:  `cpe:2.3:a:megnicholas:clean_and_simple_contact_form:4.4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storevirtual_4730:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:storevirtual_4730fc:-`,
        fs:  `cpe:2.3:a:equis:metastock:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:storevirtual_vsa:-`,
        fs:  `cpe:2.3:a:google:android_sdk_tools:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:support_assistant:8.1.40.3`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:support_solution_framework:11.51.0027`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:support_tools_manager:-`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:support_tools_manager:a.22.00`,
        fs:  `cpe:2.3:a:w3edge:total_cache:0.9.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.1.0-104.rhel5`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.4.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.1.1-14.rhel5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.2.0-283.rhel5`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.2.2-19.rhel5`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.2.5-50.rhel5`,
        fs:  `cpe:2.3:a:microsoft:directx:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.2.6-5.rhel5`,
        fs:  `cpe:2.3:h:cisco:asa_5500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.3.0`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.3.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.8:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.3.2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.05:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.4.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.5.0`,
        fs:  `cpe:2.3:a:cyclingforfun:cycling_manager_game_cff:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.6.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.6.3`,
        fs:  `cpe:2.3:a:autodesk:autocad:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:8.7.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_health_application_and_command_line_utilities:9.0.0`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:-`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.0.0`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.4:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.0.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.826:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.0.1.104`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.0.2`,
        fs:  `cpe:2.3:a:ibm:blackice_server_protection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.0.2.106`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1`,
        fs:  `cpe:2.3:a:macromedia:flash_player:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.0-103`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.0-103%28a%29`,
        fs:  `cpe:2.3:a:isc:inn:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.0-109`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.0-118`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.0.121`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.2`,
        fs:  `cpe:2.3:a:codiad:codiad:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.2-127`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.2.127`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.3.132`,
        fs:  `cpe:2.3:a:cmcm:cm_browser_-_fast_\&amp;_secure:5.0.50:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.4`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r3.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.4-143`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.4.143`,
        fs:  `cpe:2.3:a:k5n:webcalendar:0.9.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.5`,
        fs:  `cpe:2.3:a:winzip:winzip:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.5-146`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.5.146`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.5.146:b`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg306a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.6`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.6-156`,
        fs:  `cpe:2.3:a:drupal:drupal:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.6.156`,
        fs:  `cpe:2.3:o:novell:netware:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.7`,
        fs:  `cpe:2.3:a:google:chrome:5.0.356.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.7-168`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.7.168`,
        fs:  `cpe:2.3:a:bluez:bluez:5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.8`,
        fs:  `cpe:2.3:a:geodesicsolutions:geocore_max:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.8-177`,
        fs:  `cpe:2.3:a:symantec:mail_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.8.179`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.9`,
        fs:  `cpe:2.3:a:bentley:bentley_view:8.5.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.9-178`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.10`,
        fs:  `cpe:2.3:a:apache:hadoop:0.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.10-186`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.10.186`,
        fs:  `cpe:2.3:a:jruby:jruby:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.10.186:b`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.10.186:c`,
        fs:  `cpe:2.3:a:emc:digital_assets_manager:6.5:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.11`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.11-197`,
        fs:  `cpe:2.3:a:canon:mp_navigator:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.11.197:a`,
        fs:  `cpe:2.3:h:bluecoat:proxyav:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.12-118`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.12-200`,
        fs:  `cpe:2.3:a:atlassian:jira_core:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.12.201`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.14`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.14.20`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.0.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.15`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.15-210`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.1.15.210`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3201a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.2.6`,
        fs:  `cpe:2.3:h:buffalotech:wer-ag54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:2.2.8`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.0`,
        fs:  `cpe:2.3:a:redmine:redmine:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.0-68`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.0.64`,
        fs:  `cpe:2.3:a:thoughtbot:paperclip:4.2.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.1`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.1-73`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.1.73`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.2`,
        fs:  `cpe:2.3:h:cisco:nexus_9372tx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.2-77`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.2.77`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.0.2.77:b`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:10.40.1829:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.2.2`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:3.2.7`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:15.0\(912\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.0`,
        fs:  `cpe:2.3:a:ibm:spectrum_lsf:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.0.0-95`,
        fs:  `cpe:2.3:a:gnome:glib:2.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.0.0.96`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.1.0-103`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.1.0.102`,
        fs:  `cpe:2.3:a:scilab:scilab:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.2.0`,
        fs:  `cpe:2.3:a:wppa.opajaap:wp-photo-album-plus:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.2.2.7`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd350a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.3.0`,
        fs:  `cpe:2.3:a:apache:cxf:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:6.3.1`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)se3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:7.1`,
        fs:  `cpe:2.3:h:netgear:readynas_raidiator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:7.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.255:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:7.2.1`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:7.4.0`,
        fs:  `cpe:2.3:h:cisco:1803_integrated_service_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:7.5.3.1`,
        fs:  `cpe:2.3:a:ati:hydravision:4.2.148.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:system_management_homepage:7.5.4.3`,
        fs:  `cpe:2.3:o:huawei:s2300_firmware:v100r006c03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:4.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.11:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:4.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:4.1:sp1`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.437:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)db2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:4.2:sp1`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:4.2:sp2`,
        fs:  `cpe:2.3:a:microsoft:server:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:5.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:6.0`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:6.1`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.516:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:7.4`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1036.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:systems_insight_manager:7.5`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:16.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:t510:-`,
        fs:  `cpe:2.3:a:oracle:javafx:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:t520:-`,
        fs:  `cpe:2.3:a:dlink:dwl-2100ap_firmware:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:t5540:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:t5740:-`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:t5740e:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:t610:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:t620:-`,
        fs:  `cpe:2.3:h:supermicro:h8sme-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:t820:-`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:tcp_ip_services_openvms:-`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:tcp_ip_services_openvms:5.6`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:tcp_ip_services_openvms:5.7`,
        fs:  `cpe:2.3:a:businessobjects:data_services:12.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:thinpro:4.4`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:1.1_\(3.005\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:thinpro:5.0`,
        fs:  `cpe:2.3:a:microsoft:ie_for_macintosh:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:thinpro:5.1`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:thinpro:5.2`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:thinpro:5.2.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:thinpro:6.0`,
        fs:  `cpe:2.3:o:iij:seil\%2fx1_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:thinpro:6.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:thinpro_linux:4.1`,
        fs:  `cpe:2.3:o:juniper:junos:13.1x49:d45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:thinpro_linux:4.2`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.6:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:thinpro_linux:4.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:thinpro_linux:4.4`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:thinpro_linux:5.0`,
        fs:  `cpe:2.3:a:apache:ofbiz:12.04.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:thinpro_linux:5.1`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:toolbox:1.0.0`,
        fs:  `cpe:2.3:a:hp:sitescope_tools:11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:toolbox:70.0.170.0`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.0.0.12748:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:toolbox:82.0.173.0`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:toolbox:90.0.146.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_enterprise_server:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:toolbox:100.0.170.0`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:toolbox:120.0.194.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:toolbox:140.0.428.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:topshot_laserjet_pro_m275_mfp:cf040a`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:45.4.157.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_enterprise_server:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:53.0.13.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:53.0.24.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-20-\/d:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:60.0.155.0`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:70.0.170.0`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.96.d1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:82.0.188.0`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(15\)ia:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:90.0.146.0`,
        fs:  `cpe:2.3:o:readynet_solutions:wrt300n-dd_firmware:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:100.0.170.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:110.0.180.0`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-9724ts:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:120.0.194.0`,
        fs:  `cpe:2.3:a:nero:essentials:7.2.8506:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:140.0.212.0`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:trayapp:140.0.213.0`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:-`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r3_b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0f`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0f:pk8`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.07.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0f_pk6_bl17`,
        fs:  `cpe:2.3:a:apache:hadoop:0.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0f_pk7_bl18`,
        fs:  `cpe:2.3:a:magzter:dignity_dialogue:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0f_pk8`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0f_pk8_bl22`,
        fs:  `cpe:2.3:a:purplebeanie:com_pbbooking:2.4:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0g`,
        fs:  `cpe:2.3:a:wolfssl:wolfssl:3.10.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0g:pk4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.19:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0g_pk3_bl17`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0g_pk4`,
        fs:  `cpe:2.3:h:linksys:befsx41:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:4.0g_pk4_bl22`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.0a`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.575:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1_pk3_bl17`,
        fs:  `cpe:2.3:a:jease:jease:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1_pk4_bl18`,
        fs:  `cpe:2.3:a:google:chrome:7.0.529.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1_pk5_bl19`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1_pk6_bl20`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1a`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.1.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1a:pk6`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1a_pk1_bl1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1a_pk2_bl2`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1a_pk3_bl3`,
        fs:  `cpe:2.3:a:microsoft:frontpage_server_extensions:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1a_pk4_bl21`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1a_pk5_bl23`,
        fs:  `cpe:2.3:a:mybb:mybb:1.0:pr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1a_pk6`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1af`,
        fs:  `cpe:2.3:a:cisco:unified_ip_ivr:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b:pk1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b_p3k_bl24`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b_pk1`,
        fs:  `cpe:2.3:a:polycom:tts:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b_pk2_bl22`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1663.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b1:pk3`,
        fs:  `cpe:2.3:a:adobe:contribute:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b1:pk4`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b1_pk3`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0404hd-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b1_pk4`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b2:pk4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b2_pk4`,
        fs:  `cpe:2.3:a:dell:repository_manager:1.3.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b3`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:tru64:5.1b4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.19:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:trucluster_server:-`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:trucluster_server:5.0a`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:trucluster_server:5.1`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:trucluster_server:5.1a`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:ucmdb_browser:4.0.1`,
        fs:  `cpe:2.3:h:cisco:ios:12.2so:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:uguide:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unified_functional_testing:11.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unified_functional_testing:11.5`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3016-ac-poe-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unified_functional_testing:12.0`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_cmbd_foundation:10.0`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc2505:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_cmbd_foundation:10.01`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_cmbd_foundation:10.10`,
        fs:  `cpe:2.3:a:field_group_project:field_group:7.x-1.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_cmbd_foundation:10.11`,
        fs:  `cpe:2.3:h:intel:core_2_duo_e6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_cmbd_foundation:10.20`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.5:sr_3.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_configuration_management_database:9.05`,
        fs:  `cpe:2.3:h:supermicro:x9drd-7jln4f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_configuration_management_database:10.01`,
        fs:  `cpe:2.3:a:organizer_project:organizer:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_configuration_management_database:10.10`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:universal_configuration_management_database:10.11`,
        fs:  `cpe:2.3:a:adobe:creative_suite:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unload:4.5.0`,
        fs:  `cpe:2.3:a:saltstack:salt_2015:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unload:5.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unload:6.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unload:7.0.0`,
        fs:  `cpe:2.3:a:inclind:custom_pub:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unload_support:1.0.0`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2.2:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unload_support:9.0.0`,
        fs:  `cpe:2.3:a:symantec:sav_filter_for_domino_nt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unload_support:10.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.1:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:unload_support:11.0.0`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:4.0.5.6`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.14:build110608:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:4.0.6.2`,
        fs:  `cpe:2.3:a:sympa:sympa:5.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:4.0.6.3`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1017.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:4.0.7.3`,
        fs:  `cpe:2.3:a:highlighterstudio:vineyard_all_in:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:4.0.8.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.7:01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:4.0.11.6`,
        fs:  `cpe:2.3:a:polycom:realpresence_presenterpro_software:6.1.5.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:4.0.12.1`,
        fs:  `cpe:2.3:a:isc:bind:9.3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:5.2.2.2`,
        fs:  `cpe:2.3:a:web2py:web2py:1.92.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:update:5.2.6.3`,
        fs:  `cpe:2.3:a:google:talk_plugin:1.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:value_serial%2fusb_receipt_printer_f7m66aa:-`,
        fs:  `cpe:2.3:a:packagekit_project:packagekit:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:veritas_recordnow:-`,
        fs:  `cpe:2.3:a:sysphonic:thetis:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:veritas_recordnow:3.55`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:veritas_recordnow:3.57`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(4\)xm1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:veritas_recordnow:4.56`,
        fs:  `cpe:2.3:a:php-nuke:mobile_entertainment_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:-`,
        fs:  `cpe:2.3:a:sierrawireless:sierra_wireless_ac595u_firmware_update_package:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.1.4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.1.7.770`,
        fs:  `cpe:2.3:a:openpkg:openpkg:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.1.8.780`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.1.9.790`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.1.10.800`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.1.10.801`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.2.0.820`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.2.1.830`,
        fs:  `cpe:2.3:h:loytec:lvis-3e100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:2.2.2.835`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:6.0.0.840`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:r20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:6.1.0.841`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20150430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:6.1.0.842`,
        fs:  `cpe:2.3:a:file_project:file:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:6.2.0.860`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_agent:6.3.0.870`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:-`,
        fs:  `cpe:2.3:a:barebones:yojimbo:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:1.0.1288.1`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:1.0.2241.0`,
        fs:  `cpe:2.3:a:ca:etrust_admin:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:1.0.2289.0`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:1.0.2345.0`,
        fs:  `cpe:2.3:a:apple:cups:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:1.0.3085.0`,
        fs:  `cpe:2.3:a:flatnux:flatnux:2009-02-04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:1.0.3086.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:2.0.0.50`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:2.0.1.30`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:beta4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:2.1.1.710`,
        fs:  `cpe:2.3:h:cisco:hosting_solution_engine:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:2.1.1.720`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:6.3.0.870`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:version_control_repository_manager:7.4.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:vertica:7.0.2.12`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:vertica:7.1.1`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:vertica:7.1.2`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:vertica:7.2.0`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:12.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:vertica:7.2.1`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtual_connect_enterprise_manager:6.0`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtual_connect_enterprise_manager:6.1`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62t:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtual_connect_enterprise_manager_sdk:7.4.0`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.6:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtual_rooms:-`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:20.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtual_rooms_client_launcher_plugin:1.0.0.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.2:1002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:virtual_san_appliance:-`,
        fs:  `cpe:2.3:a:crossslide_jquery_project:crossslide_jquery:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtualvault:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.27:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtualvault:4.0`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.0.0.57828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtualvault:4.5`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.5p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtualvault:4.6`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.20:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:virtualvault:4.7`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:visualize_conference_ftp:-`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:rc15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:vpn_firewall_appliance:jd270a`,
        fs:  `cpe:2.3:a:topicsviewer:topicsviewer:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:vpn_firewall_appliance:jd271a`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:vpn_firewall_appliance:jg213a`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:vpn_firewall_appliance:jg214a`,
        fs:  `cpe:2.3:a:individualsoftware:professor_teaches_access:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:vvos:-`,
        fs:  `cpe:2.3:a:oar_project:oar:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:vvos:10.24`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:vvos:11.04`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:wbem:-`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:wbem:a.01.05.08`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:wbem:a.02.00.00`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:wbem:a.02.00.01`,
        fs:  `cpe:2.3:a:zend:zendservice_api:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:-`,
        fs:  `cpe:2.3:a:hp:newcopy_cda:71.0.215.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:6.2`,
        fs:  `cpe:2.3:a:riken:xoonips:3.41:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:6.5`,
        fs:  `cpe:2.3:a:novell:netware_client:4.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:7.2`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:7.5`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:7.5.2546`,
        fs:  `cpe:2.3:a:x.org:x11:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:7.6`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:8.0`,
        fs:  `cpe:2.3:a:oracle:retail_service_backbone:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:8.1`,
        fs:  `cpe:2.3:a:andrew_levine:multiblock:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:10.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:10.2:sr3`,
        fs:  `cpe:2.3:h:lexmark:cx820dtfe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_jetadmin:10.2:sr4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:1.0.0.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:45.4.157.0`,
        fs:  `cpe:2.3:o:d-link:dir-809_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:50.0.123.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:53.0.13.0`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:53.0.24.0`,
        fs:  `cpe:2.3:h:3com:webbngss3nbxnts:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:60.0.155.0`,
        fs:  `cpe:2.3:a:symantec:deployment_solution_wise_packager:6.10.443:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:70.0.170.0`,
        fs:  `cpe:2.3:a:familyconnect_project:familyconnect:1.5.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:82.0.173.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:90.0.146.0`,
        fs:  `cpe:2.3:a:vmware:server:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:100.0.170.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:110.0.180.0`,
        fs:  `cpe:2.3:o:suse:suse_linux:6.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:120.0.194.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:130.0.132.17`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(1\)n1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:140.0.212.17`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.803:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:web_registration:140.0.213.17`,
        fs:  `cpe:2.3:a:gnome:glib:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webes_service_tools:-`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webinspect:7.8`,
        fs:  `cpe:2.3:o:lorextechnology:edge3_lh340_firmware:11.19.85_1fe3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webinspect:8.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p261:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webinspect:9.2`,
        fs:  `cpe:2.3:h:d-link:dcs-5020l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webinspect:10.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p165:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webinspect:10.1`,
        fs:  `cpe:2.3:o:sun:sunos:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webinspect:10.2`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webinspect:10.3`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.7:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webinspect:10.4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webmin-based_admin:-`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.5:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webproxy:-`,
        fs:  `cpe:2.3:h:cisco:meraki_mr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webproxy:2.0`,
        fs:  `cpe:2.3:a:posh_project:posh:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webproxy:2.1`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webproxy:a.02.00`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:webproxy:a.02.10`,
        fs:  `cpe:2.3:a:apple:motion:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:wireless_assistant:4.0.10.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:wireless_barcode_scanner_e6p34aa:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.6:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:workload_manager:-`,
        fs:  `cpe:2.3:h:qnap:ts-469u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:workload_manager:a.02.01`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.0.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:att:connect_participant_application:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.1.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:nunit.org:nunit:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.1.1::~~advanced~~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.2.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2011.1025.2151.37348:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.3.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.3.1::~~advanced~~~`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.4.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.4.1::~~advanced~~~`,
        fs:  `cpe:2.3:o:vmware:esxi:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_9000_command_view:7.5.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_p9000_device_manager:8.1.1`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.3p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_p9000_replication_manager:7.6.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp_p9000_tiered_storage_manager:8.1.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp7_command_view:8.4.1::~~advanced~~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hp:xp7_global_link_manager_software:8.1.1`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:z238_firmware:1.11`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:z238_microtower_workstation_n51:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:z240_firmware:1.11`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:z240_sff_workstation_n51:-`,
        fs:  `cpe:2.3:a:topfreegames:bike_race_free_-_top_free_game:4.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:z240_tower_workstation_n51:-`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:zbook_15_g3:-`,
        fs:  `cpe:2.3:a:microsoft:baseline_security_analyzer:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:zbook_15u_g3:-`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:zbook_17_g3:-`,
        fs:  `cpe:2.3:a:php:php:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:zbook_firmware:1.03`,
        fs:  `cpe:2.3:o:cisco:unified_sip_phone_3900_firmware:8.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:hp:zbook_firmware:1.04`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.14.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hp:zbook_studio_g3:-`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hrblock:taxcut_basic%2befile_2008:8.03`,
        fs:  `cpe:2.3:a:qemu:qemu:0.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hrblock:taxcut_delaware_2008:1.08`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:r2:*:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hrblock:taxcut_deluxe_%2b_efile_%2b_state_2010:10.4.6402`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hrblock:taxcut_maryland_2010:1.10.2401`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.1:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hrblock:taxcut_premium%2befile_2008:8.06`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.4:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hrblock:taxcut_premium%2bstate%2befile:8.07`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.17:pre14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htacg:tidy:4.9.30`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:chacha:-`,
        fs:  `cpe:2.3:a:hp:trayapp:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:desire:-`,
        fs:  `cpe:2.3:a:goforandroid:go_bookmark_widget:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:desire_hd:frg83d`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.5.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:desire_hd:gri40`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr1604hd-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:desire_s:gri40`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:droid_incredible:-`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:droid_incredible:frf91`,
        fs:  `cpe:2.3:o:gentoo:linux:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:evo_3d:-`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:evo_3d:gri40`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_3d_software:1.11.651.3`,
        fs:  `cpe:2.3:a:altova:diffdog_2011:2.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_3d_software:1.13.651.7`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_3d_software:2.08.651.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_3d_software:2.08.651.3`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_3d_software:2.17.651.5`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:evo_4g:-`,
        fs:  `cpe:2.3:a:oracle:database_server:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:evo_4g:gri40`,
        fs:  `cpe:2.3:a:hummingbird:cyberdocs:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:1.32.651.1`,
        fs:  `cpe:2.3:a:php:php:5.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:1.47.651.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:3.26.651.6`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:3.29.651.5`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:3.30.651.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:3.30.651.3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:3.70.651.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:4.22.651.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:4.24.651.1`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:4.53.651.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.747.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:4.54.651.1`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:beta4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_4g_software:4.67.651.3`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:evo_design_4g:-`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.11:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_design_4g_software:1.19.651.0`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_design_4g_software:1.19.651.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_design_4g_software:2.12.651.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p2_rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_design_4g_software:2.12.651.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:evo_view_4g:-`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_view_4g_software:1.22.651.1`,
        fs:  `cpe:2.3:h:asus:rt-n66u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_view_4g_software:1.22.651.2`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.17.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:evo_view_4g_software:2.23.651.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:glacier:frg83`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:hero:-`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:hero_software:1.29.651.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:hero_software:1.56.651.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:hero_software:2.27.651.5`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:hero_software:2.27.651.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:hero_software:2.31.651.7`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.1:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:hero_software:2.32.651.2`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:merge:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2bw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:sensation_4g:gri40`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:sensation_z710e:gri40`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:shift_4g:-`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2007.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:shift_4g_software:1.17.651.1`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:shift_4g_software:2.75.651.4`,
        fs:  `cpe:2.3:a:secondfiction:codename_birdgame:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:shift_4g_software:2.75.651.5`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:8.0.1012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:shift_4g_software:2.76.651.6`,
        fs:  `cpe:2.3:a:microsoft:windows_media_services:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:shift_4g_software:2.77.651.3`,
        fs:  `cpe:2.3:a:progress:objectstore:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:thunderbolt_4g:frg83d`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:htc:vivid:-`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:vivid_software:3.26.502`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htc:vivid_software:3.26.502.56`,
        fs:  `cpe:2.3:a:acme:thttpd:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:html-scrubber_project:html-scrubber:0.14::~~~perl~~`,
        fs:  `cpe:2.3:a:apple:apple_tv:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:0.8`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:0.9`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.250:update25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.0.5`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.7.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.2`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.4`,
        fs:  `cpe:2.3:a:busybox:busybox:1.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.5`,
        fs:  `cpe:2.3:a:ntt:webarena_service_formmail:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.12`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.13`,
        fs:  `cpe:2.3:a:hotlingo:hotlingo:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:1.55`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security:e80.41:-:vpn_blade:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:2.0`,
        fs:  `cpe:2.3:o:netbsd:netbsd:3.99.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:2.1`,
        fs:  `cpe:2.3:a:spip:spip:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:2.2`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:2.2.1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.7:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:2.4`,
        fs:  `cpe:2.3:o:lenovo:thinkserver_td350_firmware:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:2.5`,
        fs:  `cpe:2.3:a:gajennings:this:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:htmlcleaner_project:htmlcleaner:2.6`,
        fs:  `cpe:2.3:a:citrix:provisioning_services:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.01`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.2`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.03`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.257:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.5`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.7`,
        fs:  `cpe:2.3:a:hp:scan:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.8`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:0.9`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg350a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.00`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.01`,
        fs:  `cpe:2.3:a:david_king:vino:3.5.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.02`,
        fs:  `cpe:2.3:a:milesj:decoda:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.03`,
        fs:  `cpe:2.3:a:testout_corporation:labsim:3.1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.04`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.05`,
        fs:  `cpe:2.3:a:atheme:atheme:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.06`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.07`,
        fs:  `cpe:2.3:a:flashy_project:flashy:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.08`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.01:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.09`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.10`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.11`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)ea1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.14`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.824:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.15`,
        fs:  `cpe:2.3:a:gnu:automake:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:http-body_project:http-body:1.17`,
        fs:  `cpe:2.3:h:lexmark:w850:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.3.0`,
        fs:  `cpe:2.3:h:airties:rt-210:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.4.0`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.5.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.6.0`,
        fs:  `cpe:2.3:a:quest:spotlight_on_oracle:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.7.0`,
        fs:  `cpe:2.3:a:acme:thttpd:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.7.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.7.2`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.7.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.7.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httplib2_project:httplib2:0.8`,
        fs:  `cpe:2.3:a:gnu:zebra:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httpwatch:httpwatch_basic:6.2.39`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httpwatch:httpwatch_basic:7.0.24`,
        fs:  `cpe:2.3:a:samsung:ml-85g_gdi_printer_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:httrack:httrack:3.0`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:5300hi:-`,
        fs:  `cpe:2.3:a:apache:qpid:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5300hi_firmware:v100r006`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5300hi_firmware:v200r001`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5300hi_firmware:v200r002`,
        fs:  `cpe:2.3:a:designtoolkits:blocked_in_free:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5300hi_firmware:v200r003`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5300hi_firmware:v200r005`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:5310ei:-`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5310ei_firmware:v200r002`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.333:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5310ei_firmware:v200r003`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3h:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5310ei_firmware:v200r005`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:5310hi:-`,
        fs:  `cpe:2.3:a:openstack:swift:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5310hi_firmware:v200r003`,
        fs:  `cpe:2.3:o:cisco:nx-os_1000v_switch:4.0\(4\)sv1\(3b\):*:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5310hi_firmware:v200r005`,
        fs:  `cpe:2.3:a:redhat:libreport:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:5700hi:-`,
        fs:  `cpe:2.3:a:progress:openedge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5700hi_firmware:v100r006`,
        fs:  `cpe:2.3:a:vips:vips:7.11.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5700hi_firmware:v200r001`,
        fs:  `cpe:2.3:a:zend:zendservice_technorati:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5700hi_firmware:v200r002`,
        fs:  `cpe:2.3:a:novell:internet_messaging_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5700hi_firmware:v200r003`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5700hi_firmware:v200r005`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:5710ei:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5710ei_firmware:v200r002`,
        fs:  `cpe:2.3:a:ibm:connections:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5710ei_firmware:v200r003`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5710ei_firmware:v200r005`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:1.0.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:5710hi:-`,
        fs:  `cpe:2.3:a:emc:networker:8.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5710hi_firmware:v200r003`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:5710hi_firmware:v200r005`,
        fs:  `cpe:2.3:h:cisco:application_velocity_system_3120:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:6300ei:-`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:6300ei_firmware:v200r005`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p152:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:6700ei:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:6700ei_firmware:v200r005`,
        fs:  `cpe:2.3:a:apache:wicket:6.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:access_router:v200r002c01spc200`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:access_router:v200r002spc003`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:acu:v100r003c01spc100`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:acu:v200r001c00`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.423:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:acu:v200r001c00spc100`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:agile_controller-campus:v100r001c00spc315`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_agent_sap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ale_firmware:-`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar:-`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar_18-1x:r0130`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar_18-2x:r1712`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110722:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar_18-3x:r0118`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar_19%2f29%2f49:r2207`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar_28%2f46:r0311`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.5:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ar_firmware:v200r001`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ar_firmware:v200r002`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ar_firmware:v200r003`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ar_firmware:v200r005c10`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ar_firmware:v200r005c20`,
        fs:  `cpe:2.3:a:inline_entity_form_project:inline_entity_form:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ar_firmware:v200r005c30`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ar_firmware:v200r006c10`,
        fs:  `cpe:2.3:a:visiwave:site_survey:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar_g3:v200r001c00`,
        fs:  `cpe:2.3:a:joungouapps:maccabi_tel_aviv:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar_g3:v200r001c01`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar_g3:v200r002c00spc200`,
        fs:  `cpe:2.3:a:plone:plone:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar120:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar1200:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar150:-`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar160:-`,
        fs:  `cpe:2.3:a:winzip:winzip:14.0.8652:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar200:-`,
        fs:  `cpe:2.3:a:freebsd:ja-xklock:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar2200:-`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.10.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar3200:-`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar3600:-`,
        fs:  `cpe:2.3:a:adobe:camera_raw:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ar500:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:atn:v200r001c00`,
        fs:  `cpe:2.3:a:hp:database_and_middleware_automation:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:atn:v200r001c01`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_lsw_s9700:-`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s2350:-`,
        fs:  `cpe:2.3:h:cisco:vpn_3000_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s2750:-`,
        fs:  `cpe:2.3:a:debian:reportbug:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s3300hi:-`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s3700hi:-`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.100.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s5300:-`,
        fs:  `cpe:2.3:o:debian:debian_linux:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s5700:-`,
        fs:  `cpe:2.3:a:trihedral:vtscada:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s6300:-`,
        fs:  `cpe:2.3:a:apache:archiva:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s6700:-`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s7700:-`,
        fs:  `cpe:2.3:a:corel:coreldraw_capture:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s9300:-`,
        fs:  `cpe:2.3:h:sun:sun_fire:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:campus_s9300e:-`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:campus_series_switch_software:v200r001`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:campus_series_switch_software:v200r001sph013`,
        fs:  `cpe:2.3:h:huawei:nip6600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:campus_series_switch_software:v200r002`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:campus_series_switch_software:v200r002sph005`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:campus_series_switch_software:v200r003`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:campus_series_switch_software:v200r003sph005`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:campus_series_switch_software:v200r005`,
        fs:  `cpe:2.3:h:polycom:viewstation_128:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:campus_series_switch_software:v200r005c00spc300`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:cx200:v100r005`,
        fs:  `cpe:2.3:a:apache:camel:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:cx300:v100r005`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p365:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:cx600:v200r002`,
        fs:  `cpe:2.3:a:usebb:usebb:0.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:cx600:v600r001`,
        fs:  `cpe:2.3:a:association_min_ajlik_project:association_min_ajlik:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:cx600:v600r002`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:cx600:v600r003`,
        fs:  `cpe:2.3:o:huawei:s9300e_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:document_security_management:v100r002c03spc005`,
        fs:  `cpe:2.3:a:logitech:high_quality_video:12.10.1113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200_usg2200:v200r003c00`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200_usg5100:v200r003c00`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200e-b:v100r005c01`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200e-c:v200r003c00`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.15.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200e-usg2100:v100r005c01`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200e-x1:v100r005c01`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200e-x2:v100r005c01`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200x3:v200r003c00`,
        fs:  `cpe:2.3:a:cisco:supervisor_desktop:80.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200x5:v200r003c00`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e200x7:v200r003c00`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(5\)sr2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e303_modem:ch2e303sm`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:e303_modem_firmware:22.157.18.00.858`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:e3236_firmware:e3236s-2tcpu-22.146.29.00.00`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:x64-std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:e3236_firmware:webui-13.100.10.00.03`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:e3276_firmware:e3276s-150tcpu-22.265.03.00.00`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:e3276_firmware:webui-13.100.09.00.03`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e355:ch1e355sm`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:e355_firmware:21.157.37.01.910`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.0.2:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:e355_web_ui:11.001.08.00.03`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e585:-`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:0.3:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:e585u-82:-`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:echo_life:hg8247`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:echo_life_hg8247_firmware:v1r006c00s120`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:espace_7910:-`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7910:v200r002c00spc100`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7910:v200r002c00spc101`,
        fs:  `cpe:2.3:a:qemu:qemu:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7910:v200r002c00spc300`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7910:v200r002c00spc600`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.42:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7910:v200r002c00spc700`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:espace_7950:-`,
        fs:  `cpe:2.3:a:python-requests:requests:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7950:v200r002c00spc100`,
        fs:  `cpe:2.3:o:advantech:eki-1321_series_firmware:2015-10-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7950:v200r002c00spc101`,
        fs:  `cpe:2.3:a:microsoft:antispyware:1.0.509:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7950:v200r002c00spc300`,
        fs:  `cpe:2.3:h:cisco:ids_4220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7950:v200r002c00spc600`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_7950:v200r002c00spc700`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:espace_8950:-`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_8950:v200r003c00spc200`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_desktop:v100r001c02`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_desktop:v100r001c03`,
        fs:  `cpe:2.3:a:samba:samba:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_desktop:v200r001c03`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:espace_desktop:v200r003c00`,
        fs:  `cpe:2.3:a:hp:mercury_performance_center_agent:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon_8080e:v100r003c00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon_8160e:v100r003c00`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon_usg5300:v200r001`,
        fs:  `cpe:2.3:h:ibm:system_x3650_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon_usg5500:v200r002`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon_usg9300:v100r003c00`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon_usg9500:v200r001c00spc600`,
        fs:  `cpe:2.3:a:plone:plone:5.1:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon1000:v200r006c02`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17d\)sxb7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon1000e-u:v200r001`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon1000e-x:v200r002`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5116c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon100e:v200r007`,
        fs:  `cpe:2.3:o:hp:laserjet_pro_p1606dn_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon200:v200r001`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon300:v200r006c02`,
        fs:  `cpe:2.3:a:hp:centralview_fraud_risk_management:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon500:v200r006c02`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:eudemon8000e-x:v200r001c00spc600`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:gem-703l_firmware:-`,
        fs:  `cpe:2.3:o:opensuse_project:suse_linux_enterprise_desktop:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:h3c_ar%28oem_in%29:r2209`,
        fs:  `cpe:2.3:a:apache:libcloud:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:honor_4c:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_4c_firmware:chm-tl00c01_b535`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_4c_firmware:chm-tl00c01b556`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_4c_firmware:chm-tl00hc00_b535`,
        fs:  `cpe:2.3:a:php:php:5.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_4c_firmware:chm-tl00hc00b556`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_4c_firmware:chm-ul00c00b535`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(36\)cc4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_4c_firmware:chm-ul00c00b556`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:honor_6:-`,
        fs:  `cpe:2.3:a:apple:itunes:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_6_firmware:h60-l01c00b850`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_6_firmware:h60-l02c00b850`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_6_firmware:h60-l03c01b850`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_6_firmware:h60-l11c00b850`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_6_firmware:h60-l12c00b850`,
        fs:  `cpe:2.3:h:hp:laserjet_5200n:q7543a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:honor_6_firmware:h60-l21c00b850`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.1.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ips_module:-`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ips_module_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ma5200g:v200r003`,
        fs:  `cpe:2.3:a:bamboosolutions:bamboo.hello.webpart.spv3:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ma5200g:v300r003`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:mate_7:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:mate_7_firmware:mt7-cl00`,
        fs:  `cpe:2.3:a:gnome:glib:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:mate_7_firmware:mt7-tl00`,
        fs:  `cpe:2.3:h:huawei:s9303e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:mate_7_firmware:mt7-tl10`,
        fs:  `cpe:2.3:a:invensys:dasabcip:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:mate_7_firmware:mt7-ul00`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:mate_8_firmware:nxt-al10c00b197`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:mate_8_firmware:nxt-cl10c00b197`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:mate_8_firmware:nxt-dl10c00b197`,
        fs:  `cpe:2.3:a:projectsend:projectsend:155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:mate_8_firmware:nxt-tl10c00b197`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:me60:v100r005`,
        fs:  `cpe:2.3:a:juniper:network_connect:6.0.0.12141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:me60:v100r006`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:me60:v600r002`,
        fs:  `cpe:2.3:a:mollify:mollify:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:me60:v600r003`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:me60:v600r005c00spc600`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.4:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:mt882:-`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.1.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne20:v200r005`,
        fs:  `cpe:2.3:a:apache:struts:2.3.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne20e-x6:v300r005`,
        fs:  `cpe:2.3:a:zope:zope:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne40:v300r005`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne40e:v300r005`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne40e:v600r001`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne40e%2f80e:v600r002`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.7.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne40e%2f80e:v600r003`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne5000e:v300r007`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne5000e:v800r002`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne80:v300r005`,
        fs:  `cpe:2.3:a:ca:license_software:1.61.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne80e:v600r001`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:18.0.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne80e:v600r002`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ne80e:v600r003`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:ngfw_module:-`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:ngfw_module_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:f5:arx_data_manager:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:nip100:v100r001`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:nip1000:v100r001`,
        fs:  `cpe:2.3:h:hp:laserjet_m725dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:nip200:v100r001`,
        fs:  `cpe:2.3:a:gnu:grep:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:nip2100:v100r001c00`,
        fs:  `cpe:2.3:a:google:chrome:6.0.438.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:nip2200:v100r001c00`,
        fs:  `cpe:2.3:a:symantec:web_security:3.01.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:nip5100:v100r001c00`,
        fs:  `cpe:2.3:a:dell:openmanage_remote_access_components:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:nip6300:-`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:nip6300_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.8:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:nip6600:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.52:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:nip6600_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.1.0.14766:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:p2-6011:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:p2-6011_firmware:v100r001c00b042`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.05a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:p7-l10:-`,
        fs:  `cpe:2.3:a:barcodewiz:barcode_activex_control:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:p7-l10_firmware:v100r001c00b135`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:p8:-`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:p8_firmware:gra-cl10`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:p8_firmware:gra-cl100`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(1s\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:p8_firmware:gra-tl00`,
        fs:  `cpe:2.3:h:hp:laserjet_4m_plus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:p8_firmware:gra-ul10`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:p8_firmware:gra-ul100`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:quidway_firmware:v200r003c00spc300`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s2350:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s2750:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s5300:-`,
        fs:  `cpe:2.3:a:bioinformatics:ordersys:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:quidway_s5300_firmware:v200r001c00spc300`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.1\(2.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s5700:-`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s6300:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s6700:-`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s7700:-`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s9300:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:quidway_s9300_firmware:v200r001c00spc300`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_20.19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:quidway_s9300_firmware:v200r002c00spc100`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:quidway_s9300_firmware:v200r003c00spc500`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_s9700:-`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:009sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_service_process_unit_board_s7700:v200r001c00spc300`,
        fs:  `cpe:2.3:a:neorcha:usek:1.0.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_service_process_unit_board_s9300:v200r001c00spc300`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp1:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:quidway_service_process_unit_board_s9700:v200r001c00spc300`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s12700_firmware:v200r005c00`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s12700_firmware:v200r006c00`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:5.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s12700_firmware:v200r007c01`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.1.152.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s12700_firmware:v200r008c00`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s12700_firmware:v200r009c00`,
        fs:  `cpe:2.3:a:x:libxp:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s12708:-`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.34.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s12708_firmware:v200r005`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf430c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s12712:-`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s12712_firmware:v200r005`,
        fs:  `cpe:2.3:a:radiocms:radiocms:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2000:r6305`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2300:-`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2300:r6305`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2300:v100r002`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2300:v100r003`,
        fs:  `cpe:2.3:a:isc:bind:9.10.3:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2300:v100r005`,
        fs:  `cpe:2.3:o:cisco:ios:12.0wt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2300:v100r006`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:9.00.00.3250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2300_firmware:v100r006c00spc800`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.91.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2300_firmware:v100r006c01spc100`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.12:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2300_firmware:v100r006c03`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2300_firmware:v100r006c05`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.4:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2350ei:-`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2350ei_firmware:v200r001c00`,
        fs:  `cpe:2.3:h:xerox:workcentre_m175:8.47.33.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2350ei_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2350ei_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2350ei_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s2350ei_firmware:v200r006c00`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2700:r6305`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s2700:v100r006`,
        fs:  `cpe:2.3:a:submain:ghostdoc:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3000:r6305`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300:-`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300:r6305`,
        fs:  `cpe:2.3:a:php:php:5.6.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300:v100r002`,
        fs:  `cpe:2.3:a:barebones:yojimbo:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300:v100r003`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.58:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300:v100r005`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r4_p1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300:v100r006`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70-\/g:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s3300_firmware:v100r006c00spc800`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_designer:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s3300_firmware:v100r006c01spc100`,
        fs:  `cpe:2.3:o:xen:xen:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s3300_firmware:v100r006c03`,
        fs:  `cpe:2.3:a:citadel:hercules_remediation_client_for_windows:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s3300_firmware:v100r006c05`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:5.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300hi:r6305`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300hi:v100r006`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3300hi:v200r001`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3500:r6305`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3700:r6305`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3700:v100r005`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.885:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3700:v100r006`,
        fs:  `cpe:2.3:a:netscape:messenging_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3700:v200r001`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s3900:r6305`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5100:r6305`,
        fs:  `cpe:2.3:a:titus:message_classification_administration_tool:3.1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(1\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300:v100r002`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc14:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300:v100r003`,
        fs:  `cpe:2.3:a:getusedtoit:wp_slimstat:3.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300:v100r005`,
        fs:  `cpe:2.3:a:roy_baxter:better_revisions:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300:v100r006`,
        fs:  `cpe:2.3:a:redhat:cloudforms_management_engine:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v100r006c00spc800`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v100r006c01spc100`,
        fs:  `cpe:2.3:a:invensys:wonderware_information_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v100r006c03`,
        fs:  `cpe:2.3:a:sybase:advantage_database_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:topazsystems:sigplus_pro_activex_control:3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r003c00`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:s5300_firmware:v200r003c00spc500`,
        fs:  `cpe:2.3:a:sun:ray_server_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r005c00`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r005c00spc500`,
        fs:  `cpe:2.3:a:asus:ipswcom_activex_component:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r005c01`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_39:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r005c02`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r006c00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r006c00spc500`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r007c00`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r008c00`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300_firmware:v200r009c00`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300ei:-`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300ei_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300ei_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300ei_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:isc:bind:9.7.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300ei_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:20.0.0.233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300hi:v100r006`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300hi:v200r001`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300li:-`,
        fs:  `cpe:2.3:a:apache:groovy:1.9.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300li_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_75:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300li_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300li_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300li_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:clamav:clamav:0.95:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300li_firmware:v200r006c00`,
        fs:  `cpe:2.3:o:apple:iphone_os:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5300si:-`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300si_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.6.1:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300si_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:adobe:photoshop:2.5:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300si_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_xi_client_tools:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5300si_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.2.1:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5306:v100r006`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5306:v200r001`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:-:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5310hi:-`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5310hi_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.152.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5310hi_firmware:v200r002c00`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5310hi_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.51:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5310hi_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:oracle:workspace_manager:11.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5600:r6305`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5700:-`,
        fs:  `cpe:2.3:a:dell:system_e-support_tool:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5700:v100r005`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5700:v100r006`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5700:v200r001`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.0:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5700_firmware:v200r001c01`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)bx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5700_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5700_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:s5700_firmware:v200r003c00spc500`,
        fs:  `cpe:2.3:a:oracle:virtualization_secure_global_desktop:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5700_firmware:v200r003c02`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-13_w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5700_firmware:v200r005c03`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5700_firmware:v200r006c00`,
        fs:  `cpe:2.3:o:mikrotik:routeros:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5700_firmware:v200r008c00`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5700_firmware:v200r009c00`,
        fs:  `cpe:2.3:o:huawei:p8_firmware:gra-cl10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5720ei:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:4.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5720ei_firmware:v200r006c00`,
        fs:  `cpe:2.3:h:huawei:secospace_usg6600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s5720hi:-`,
        fs:  `cpe:2.3:h:oracle:sun_blade_x6450:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s5720hi_firmware:v200r006c00`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s6300:-`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s6300:v100r006`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.1.7.l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s6300:v200r001`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v100r006c00spc800`,
        fs:  `cpe:2.3:a:python:python:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v100r006c01spc100`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_entry_client:2.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v100r006c03`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:hp:sitescope_monitoring:11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-50-09:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.5\(1\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v200r005c01`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.13:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v200r005c02`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v200r008c00`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300_firmware:v200r009c00`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s6300ei:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300ei_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300ei_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p48:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300ei_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6300ei_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:google:chrome:9.0.566.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s6700:-`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta49:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s6700:v100r006`,
        fs:  `cpe:2.3:a:karenware:karen\&#39;s_power_tools:8.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s6700:v200r001`,
        fs:  `cpe:2.3:a:hp:eva_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6700_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6700_firmware:v200r001c01`,
        fs:  `cpe:2.3:a:altiris:carbon_copy_solution_documentation:6.2.1121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6700_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6700_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:castor_project:castor:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6700_firmware:v200r005c00`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6700_firmware:v200r008c00`,
        fs:  `cpe:2.3:h:cisco:wip310_wireless-g_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s6700_firmware:v200r009c00`,
        fs:  `cpe:2.3:a:bias-inc:bias_soundsoap_pe:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s7700:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sng:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s7700:v100r003`,
        fs:  `cpe:2.3:a:emc:secure_remote_services:3.0:*:*:*:virtual:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s7700:v100r006`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v100r002`,
        fs:  `cpe:2.3:o:openvas:greenbone_security_assistant:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v100r003`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v100r006`,
        fs:  `cpe:2.3:a:rapidleech:rapidleech:2.3:v42_svn322:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r001`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:5.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.10:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r002`,
        fs:  `cpe:2.3:a:futurenuke:platinum:7.6.b.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r002c00`,
        fs:  `cpe:2.3:h:3com:3c13700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r003`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_software:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:s7700_firmware:v200r003c00spc500`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r005`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa_bosh:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r006c00`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r008c00`,
        fs:  `cpe:2.3:h:huawei:s5310hi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7700_firmware:v200r009c00`,
        fs:  `cpe:2.3:a:vmware:vcenter_chargeback_manager:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s7703:-`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7703_firmware:v100r002`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.1:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7703_firmware:v100r003`,
        fs:  `cpe:2.3:a:category_tokens_project:category_tokens:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7703_firmware:v100r006`,
        fs:  `cpe:2.3:a:freso:languageicons:6.x-2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7703_firmware:v200r001`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7703_firmware:v200r002`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7703_firmware:v200r003`,
        fs:  `cpe:2.3:a:python:python:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7703_firmware:v200r005`,
        fs:  `cpe:2.3:a:adobe:color_photoshop_specific:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s7706:-`,
        fs:  `cpe:2.3:a:adobe:coldfusion:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7706_firmware:v100r002`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7706_firmware:v100r003`,
        fs:  `cpe:2.3:h:yokogawa:centum_event_viewer_package:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7706_firmware:v100r006`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7706_firmware:v200r001`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.0.212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7706_firmware:v200r002`,
        fs:  `cpe:2.3:a:henner_zeller:henplus:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7706_firmware:v200r003`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7706_firmware:v200r005`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s7712:-`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:8.0:-:*:*:*:windows_8:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7712_firmware:v100r002`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7712_firmware:v100r003`,
        fs:  `cpe:2.3:a:hp:destination_component:100.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7712_firmware:v100r006`,
        fs:  `cpe:2.3:a:torrentflux:torrentflux:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7712_firmware:v200r001`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7712_firmware:v200r002`,
        fs:  `cpe:2.3:a:rockwellautomation:factorytalk_services_platform:cpr9:sr6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7712_firmware:v200r003`,
        fs:  `cpe:2.3:a:oracle:outside_in_technology:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s7712_firmware:v200r005`,
        fs:  `cpe:2.3:a:debian:mime-support:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s7800:r6305`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:2.1.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s8500:r1631`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_broker:1.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s8500:r1632`,
        fs:  `cpe:2.3:a:gajim:gajim:0.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9300:-`,
        fs:  `cpe:2.3:o:rockwellautomation:softlogix_5800_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9300:v100r001`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9300:v100r002`,
        fs:  `cpe:2.3:o:hp:laserjet_pro_m1217nfw_multifunction_printer_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9300:v100r003`,
        fs:  `cpe:2.3:a:ipswitch:imail_client:9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9300:v100r006`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v100r002`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v100r003`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v100r006`,
        fs:  `cpe:2.3:a:nicolas_tormo:phppaleo:4.8b180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v100r006c00spc500`,
        fs:  `cpe:2.3:o:cisco:ios:12.1yh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v100r006c00spc800`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r001`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r001c00`,
        fs:  `cpe:2.3:o:juniper:ive_os:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r002`,
        fs:  `cpe:2.3:a:jgaa:warftpd:1.8.2:rc12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r002c00`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r003`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1017.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:s9300_firmware:v200r003c00spc500`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r005`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p155:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r005c00spc300`,
        fs:  `cpe:2.3:a:zoom:zoom_cloud_meetings:\@7f060008:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r006c00`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r006c00spc500`,
        fs:  `cpe:2.3:a:ca:common_services:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r008c00`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300_firmware:v200r009c00`,
        fs:  `cpe:2.3:a:ross_burton:libsocialweb:0.25.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300e_firmware:v200r001`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300e_firmware:v200r002`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300e_firmware:v200r003`,
        fs:  `cpe:2.3:a:xnview:xnview:1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9300e_firmware:v200r005`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9303:-`,
        fs:  `cpe:2.3:a:apple:cups:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303_firmware:v100r002`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303_firmware:v100r003`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303_firmware:v100r006`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303_firmware:v200r001`,
        fs:  `cpe:2.3:a:sympa:sympa:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303_firmware:v200r002`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303_firmware:v200r003`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303_firmware:v200r005`,
        fs:  `cpe:2.3:a:trihedral:vtscada:8.1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9303e:-`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303e_firmware:v200r001`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303e_firmware:v200r002`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303e_firmware:v200r003`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9303e_firmware:v200r005`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1675.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9306:-`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306_firmware:v100r002`,
        fs:  `cpe:2.3:h:siemens:ccis1425:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306_firmware:v100r003`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p168:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306_firmware:v100r006`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306_firmware:v200r001`,
        fs:  `cpe:2.3:a:apache:poi:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306_firmware:v200r002`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0579:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306_firmware:v200r003`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306_firmware:v200r005`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9306e:-`,
        fs:  `cpe:2.3:a:george_wassouf_project:george_wassouf:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306e_firmware:v200r001`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306e_firmware:v200r002`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306e_firmware:v200r003`,
        fs:  `cpe:2.3:a:tiger-fish:fancy_slide:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9306e_firmware:v200r005`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9312:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312_firmware:v100r002`,
        fs:  `cpe:2.3:a:hp:openview_performance_agent:c.04.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312_firmware:v100r003`,
        fs:  `cpe:2.3:a:organizer_project:organizer:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312_firmware:v100r006`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.22.350:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312_firmware:v200r001`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312_firmware:v200r002`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312_firmware:v200r003`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312_firmware:v200r005`,
        fs:  `cpe:2.3:a:google:googlebot-image:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9312e:-`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_34:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312e_firmware:v200r001`,
        fs:  `cpe:2.3:a:emc:networker:8.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312e_firmware:v200r002`,
        fs:  `cpe:2.3:a:google:chrome:5.0.329.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312e_firmware:v200r003`,
        fs:  `cpe:2.3:a:samba:samba:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9312e_firmware:v200r005`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9700:-`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r001`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r001c00`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r001c01`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r002`,
        fs:  `cpe:2.3:a:memcached:memcached:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r002c00`,
        fs:  `cpe:2.3:o:tropos:mesh_os:7.9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r003`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.4:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r003c00`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:s9700_firmware:v200r003c00spc500`,
        fs:  `cpe:2.3:a:gnu:gdb:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r005`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r005c00`,
        fs:  `cpe:2.3:a:redhat:jboss_data_virtualization:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r006c00`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p138:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r008c00`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9700_firmware:v200r009c00`,
        fs:  `cpe:2.3:a:edx:open_edx:2015-01-27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9703:-`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9703_firmware:v200r001`,
        fs:  `cpe:2.3:a:nowsms:now_sms_\&amp;_mms_gateway:2013.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9703_firmware:v200r002`,
        fs:  `cpe:2.3:a:hp:fax:140.0.213.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9703_firmware:v200r003`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9703_firmware:v200r005`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9706:-`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9706_firmware:v200r001`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9706_firmware:v200r002`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9706_firmware:v200r003`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9706_firmware:v200r005`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:s9712:-`,
        fs:  `cpe:2.3:a:f5:arx:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9712_firmware:v200r001`,
        fs:  `cpe:2.3:a:apple:xsan:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9712_firmware:v200r002`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9712_firmware:v200r003`,
        fs:  `cpe:2.3:a:cisco:network_assistant:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:s9712_firmware:v200r005`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:seco_versatile_security_manager:v200r002c00`,
        fs:  `cpe:2.3:a:logitech:lws_wlm_plugin:1.0.1774.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:seco_versatile_security_manager:v200r002c00spc100`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:seco_versatile_security_manager:v200r002c00spc200`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:secospace_antiddos8000:-`,
        fs:  `cpe:2.3:h:hp:jg406a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:secospace_antiddos8000_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p2_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:secospace_usg6300:-`,
        fs:  `cpe:2.3:a:ingumadev:bokken:1.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:secospace_usg6300_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.293:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:secospace_usg6500:-`,
        fs:  `cpe:2.3:a:xoops:glossaire_module:1.0:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:secospace_usg6500_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:secospace_usg6600:-`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:secospace_usg6600_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:adobe:robohelp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:svn2000:v200r001c00`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:svn3000:v100r002c02spc802b041`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.25:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:svn5000:v200r001c00`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:svn5300:v100r001c01b019`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:te30:-`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:te40:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:te50:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:te60:-`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:te60_firmware:v100r001c10b022`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:unified_security_gateway_firmware:v300r001c10`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:usg2100:-`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:usg2200:-`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/rs_firmware:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:usg5100:-`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:usg5500:-`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.03:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:usg9500:-`,
        fs:  `cpe:2.3:a:e107:e107:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:huawei:usg9500_firmware:v500r001c00`,
        fs:  `cpe:2.3:a:oracle:endeca_server:7.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:utps:1.0`,
        fs:  `cpe:2.3:a:adobe:extendscript_toolkit:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:utps_firmware:23.009.09.00.983`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:vcn500:-`,
        fs:  `cpe:2.3:a:apple:quartz_composer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:vcn500:v100r002c00spc200`,
        fs:  `cpe:2.3:h:apple:imac:mc510xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:vcn500:v100r002c00spc200b010`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:vp_9610:v100r002c02b019sp05`,
        fs:  `cpe:2.3:a:hp:service_location_protocol:1.0.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:vp_9620:v100r002c02b019sp05`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huawei:webui:11.010.06.01.858`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_server:6.1.4_build_6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:wlan_ac_6605:v200r001c00`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.1\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:huawei:wlan_ac_6605:v200r001c00spc100`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hub_project:hub:1.12.0`,
        fs:  `cpe:2.3:a:ibm:wsportal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hub_project:hub:1.12.1`,
        fs:  `cpe:2.3:a:cypherpunks:libotr:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huge-it:huge-it_catalog:1.0.7::~~~joomla~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huge-it:huge-it_catalog:1.0.7::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:tim_heuer:rss_feedreader_web_part:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huge-it:image_gallery:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huge-it:portfolio_gallery:1.0.6::~~~joomla~~`,
        fs:  `cpe:2.3:a:boost:boost:1.45.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huge-it:portfolio_gallery:1.0.6::~~~joomla%21~~`,
        fs:  `cpe:2.3:o:suse:suse_linux:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huge-it_catalog_project:huge-it_catalog:1.0.7::~~~joomla~~`,
        fs:  `cpe:2.3:a:sun:secure_global_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:hughes:hs3400_media_appliance:-`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hulihanapplications:amethyst:0.1.5`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hulihanapplications:amethyst:0.1.6`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hulihanapplications:diamondlist:0.1.6`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hulihanapplications:hulihan_bxr:0.6.8`,
        fs:  `cpe:2.3:a:debian:reprepro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:humhub:humhub:0.10.0:rc1`,
        fs:  `cpe:2.3:a:apple:keynote:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:humhub:humhub:0.20.0`,
        fs:  `cpe:2.3:a:cisco:cisco_policy_suite:7.0.3-att:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:humhub:humhub:0.20.0:b1`,
        fs:  `cpe:2.3:a:autodesk:survey:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:humhub:humhub:0.20.0:b2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:humhub:humhub:0.20.1`,
        fs:  `cpe:2.3:a:oceanavenue:ocean_avenue_mobile_pro:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:humhub:humhub:1.0.0:b1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:humhub:humhub:1.0.0:b2`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:bi_query:8.5.1`,
        fs:  `cpe:2.3:a:samba:samba:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:bi_query:9.0.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:bi_query:9.0.2.0`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:bi_query_user:9.0.1`,
        fs:  `cpe:2.3:h:cisco:sf300-24p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:collaboration:-`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:04-00-\/a:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:collaboration:5.2`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:collaboration:5.21`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:component_deployment:-`,
        fs:  `cpe:2.3:a:teradata:ole_db_access_module:12.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:connectivity:-`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:connectivity:7.1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:connectivity:9.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:connectivity:10.0`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:cyberdocs:-`,
        fs:  `cpe:2.3:a:spip:spip:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:cyberdocs:3.1`,
        fs:  `cpe:2.3:a:neevia:docuprinter:5.0:*:*:*:lt:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:cyberdocs:3.5`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:cyberdocs:3.5.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:cyberdocs:3.9`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:cyberdocs:4.0`,
        fs:  `cpe:2.3:h:dell:latitude_e5400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:deployment_wizard:2008`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:dm:-`,
        fs:  `cpe:2.3:a:aol:aim_toolbar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:dm:5.1.05`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:docs_admin_tools:-`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:docs_fusion_server:-`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:07-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:enterprise_collaboration:-`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p249:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:enterprise_collaboration:5.2`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:enterprise_collaboration:5.21`,
        fs:  `cpe:2.3:a:php:php:4.0:beta_4_patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:-`,
        fs:  `cpe:2.3:a:adobe:coldfusion:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:6.0.1.0`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.598:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:9.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:10.0`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:10.0.0.0`,
        fs:  `cpe:2.3:a:perl:perl:5.12.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:13.0`,
        fs:  `cpe:2.3:h:securecomputing:snapgear_sg560:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:14.0.0`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:2006`,
        fs:  `cpe:2.3:a:hp:scanjet_8200c_firmware:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:2007`,
        fs:  `cpe:2.3:a:phillip_lougher:squashfs:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed:2008`,
        fs:  `cpe:2.3:h:hp:officejet_6300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed_on_demand_client:-`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed_on_demand_client:4.5`,
        fs:  `cpe:2.3:o:google:android:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed_powersuite:-`,
        fs:  `cpe:2.3:a:apple:safari:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:exceed_powersuite:2008`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:hostexplorer:7.0`,
        fs:  `cpe:2.3:a:pantech:pc_usb_modem_software:1.2.4151.1109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:hostexplorer:7.0.0.0`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:hostexplorer:9.0`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:hostexplorer:9.0.0.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.8.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:hummingbird:hostexplorer:2007`,
        fs:  `cpe:2.3:a:novell:groupwise:5.57e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:humor_ironias_y_realidades_project:humor_ironias_y_realidades:0.63.13371.13576::~~~android~~`,
        fs:  `cpe:2.3:a:netease:neteaseweibo:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hunting_trophy_whitetails_project:hunting_trophy_whitetails:0.75.13441.88885::~~~android~~`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:huntington:huntington_mobile:2.1.222::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1679.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:husdawg:system_requirements_lab_for_intel:4.1.66.0`,
        fs:  `cpe:2.3:a:portfolium_project:portfolium:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:husdawg:system_requirements_lab_for_intel:4.4.22.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp2:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:husdawg:system_requirements_lab_for_intel:4.4.24.0`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:h:hp:j9586a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:perl:perl:5.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:infinitewp:infinitewp_admin_panel:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.1.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:juniper:netscreen_remote_vpn_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:apple:apple_tv:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:priorswood:acorn_comms:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:3.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.12::~~~drupal~~`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:hyonga:hanyang_university_admissions:2.1.3::~~~android~~`,
        fs:  `cpe:2.3:h:apple:iphone_4s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:-::~~open~~~`,
        fs:  `cpe:2.3:a:compaq:armada_insight_manager:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:0.9.9:7:~~open~~~`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.0::~~pro~~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.07.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.0.2::~~pro~~~`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.1.1::~~pro~~~`,
        fs:  `cpe:2.3:a:pippin_williamson:font_uploader:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.1.2::~~pro~~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.2.1::~~pro~~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.9:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.2.2::~~pro~~~`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b2:pk4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.2.3::~~pro~~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.2.4::~~pro~~~`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-doit:i-doit:1.2.5::~~pro~~~`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-escorts:i-escorts_agency_script:-`,
        fs:  `cpe:2.3:a:ijianren:jian_ren:1.5.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:i-escorts:i-escorts_directory_script:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-gen:oplynx:2.01.8`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:i-um:ium:3.3.4::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iain:gypsy:0.5`,
        fs:  `cpe:2.3:a:xnview:xnview:1.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iain:gypsy:0.6`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp4:datacenter_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iain:gypsy:0.7`,
        fs:  `cpe:2.3:a:ossec:ossec:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iain:gypsy:0.8`,
        fs:  `cpe:2.3:a:php:php:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iata:airlines_international:1::~~~android~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:4758:-`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:access_ibm_message_center:2.103`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:access_manager_for_microsoft_.net:4.0.6`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:acprunner:-`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:actuate_encyclopedia_for_ibm_maximo:6.2.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:advanced_management_module:-`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:-`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:4.72.3612.1700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:2.00`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:2.50`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.54:bbet54l`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.54:bbet54p`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.54:bbet54u`,
        fs:  `cpe:2.3:a:php:php:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.54:bbet54v`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.54:bpet54l`,
        fs:  `cpe:2.3:a:iss:blackice_agent_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.54:bpet54p`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.54:bpet54u`,
        fs:  `cpe:2.3:a:splunk:universal_forwarder:4.2.4.110225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.54:bpet54v`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.12137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.60`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.13.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62c`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62f`,
        fs:  `cpe:2.3:a:qemu:qemu:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62j`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62o`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62p`,
        fs:  `cpe:2.3:a:attachmate:reflection_pki_services_manager:1.1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62r`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.2.0:cp01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62s`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.93.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62t`,
        fs:  `cpe:2.3:a:google:chrome:4.0.223.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62u`,
        fs:  `cpe:2.3:a:apple:itunes:5.0.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bbet62y`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62c`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.07.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62f`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62j`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:ru:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62o`,
        fs:  `cpe:2.3:a:cisco:expressway:x8.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62p`,
        fs:  `cpe:2.3:a:codiad:codiad:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62r`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62s`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62t`,
        fs:  `cpe:2.3:h:cisco:aironet_ap340:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62u`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.455:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.62:bpet62y`,
        fs:  `cpe:2.3:a:hp:managed_printing_admin:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bbet64b`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_security_suite:6.5.737:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bbet64c`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-52p_ls-3100-52p-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bbet64g`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bpeo64b`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bpeo64c`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.34:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bpeo64g`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bpet64b`,
        fs:  `cpe:2.3:a:ricoh:fiery_print_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bpet64c`,
        fs:  `cpe:2.3:a:php:php:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.64:bpet64g`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.1.9.790:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.65`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:advanced_management_module_firmware:3.66:e`,
        fs:  `cpe:2.3:h:cisco:unified_computing_system_6120xp_fabric_interconnect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:advanced_settings_utility:3.62`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:advanced_settings_utility:3.70`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:advanced_settings_utility:9.21`,
        fs:  `cpe:2.3:h:xerox:workcentre_m45:4.97.20.032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:agent_controller:5.0.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:-`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.097:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:-::~~~~x64~`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:-::~~~~x86~`,
        fs:  `cpe:2.3:a:cookpad:android_activities:1.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:1.2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:1.3`,
        fs:  `cpe:2.3:a:context_project:context:7.x-3.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:2.2.1`,
        fs:  `cpe:2.3:h:juniper:mx960:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:3.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.356:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:3.2`,
        fs:  `cpe:2.3:a:otrs:faq:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:3.2.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:3.2.4`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.1.0.59776:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:3.2.5`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4`,
        fs:  `cpe:2.3:a:studiohitori:twitrocker2_android:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.0`,
        fs:  `cpe:2.3:a:oracle:mysql:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.1`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:2.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.1.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.1.2`,
        fs:  `cpe:2.3:h:hp:jf801a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.1.3`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.1.4`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.1.5`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.3\(4\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.2`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.2.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.2.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.1:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.2.1.12`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.3`,
        fs:  `cpe:2.3:a:apprain:apprain:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.3.0`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2968:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.3.1`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.3.2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:4.3.3`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5`,
        fs:  `cpe:2.3:a:openx:openx_source:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.1.0.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.1l`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.2.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.2.0.50`,
        fs:  `cpe:2.3:h:hp:arcsight_connector_appliance:c5400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.2.0.54`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.2.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.2_l`,
        fs:  `cpe:2.3:a:harris:stat_guardian_vms:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3:sp6`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.11:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3.0.10`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3.0.20`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management:10.0:*:*:*:collaborative:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3.7`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3.8`,
        fs:  `cpe:2.3:a:flane:cisco_class_locator_fast_lane:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3.9`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3_l`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:101sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5.3_ml03`,
        fs:  `cpe:2.3:h:moxa:iologic_e2260:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:5l`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:6.1`,
        fs:  `cpe:2.3:a:avaya:vsu_7500:3.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:6.1.0`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:6.1.1`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:6.1.2`,
        fs:  `cpe:2.3:a:avast:endpoint_protection_plus:8.0.1606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:7.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:7.1.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:7.1.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:aix:430`,
        fs:  `cpe:2.3:a:apache:http_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_5l:-`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_5l:5.3:sp6`,
        fs:  `cpe:2.3:a:apache:rave:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_enetwork_firewall:-`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.12:ga10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_enetwork_firewall:3.2`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p301:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_enetwork_firewall:3.3`,
        fs:  `cpe:2.3:a:apache:libcloud:0.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_parallel_systems_support_programs:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_parallel_systems_support_programs:3.1.1`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2010:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_parallel_systems_support_programs:3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_parallel_systems_support_programs:3.4`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.1.1219:unknown:online_windows_2000:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:aix_snmp:-`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:10.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algo_credit_limits:4.5.0`,
        fs:  `cpe:2.3:a:oracle:workspace_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algo_credit_limits:4.7.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algo_one:4.7.0`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algo_one:4.7.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algo_one:4.8.0`,
        fs:  `cpe:2.3:a:cisco:finesse:10.5\(1\)_su1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algo_one:4.9.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algo_one:4.9.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.5:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algo_one:5.0.0`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:algorithmics:-`,
        fs:  `cpe:2.3:a:redgraphic:sapid_cms:1.2.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:alphaworks_tftp_server:-`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:alphaworks_tftp_server:1.21`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:2.0.0.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:2.0.0.1`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:3.0.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:3.0.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:3.0.2.1`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_gateway:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:3.0.3.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:7.1.0:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:3.0.4.0`,
        fs:  `cpe:2.3:a:apache:solr:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:4.0.0.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:4.0.1.0`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.0.3.1:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:4.0.2.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.10:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:4.0.3.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:api_management:4.0.4.0`,
        fs:  `cpe:2.3:h:ibm:x340:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:application_support_facility:3.4.0:-:~~~aix~~`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:application_support_facility:3.4.0:-:~~~linux_kernel~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:application_support_facility:3.4.0:-:~~~windows~~`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:application_support_facility:3.4.0:-:~~~z%2fos~~`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:as400_firewall:-`,
        fs:  `cpe:2.3:a:ca:client_automation:12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:atlas_ediscovery_process_management:6.0.1.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:atlas_ediscovery_process_management:6.0.1.6`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:atlas_ediscovery_process_management:6.0.2`,
        fs:  `cpe:2.3:a:widgets_project:widgets:-:*:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:atlas_ediscovery_process_management:6.0.3`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:atlas_suite:-`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:autofs:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:f9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:avocent_1754_kvm:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:b2b_advanced_communications:1.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:b2b_advanced_communications:1.0.0.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:b2b_advanced_communications:1.0.0.2`,
        fs:  `cpe:2.3:a:apple:icloud:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:b2b_advanced_communications:1.0.0.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_inventory:9.2`,
        fs:  `cpe:2.3:o:gentoo:linux:1.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.0.5`,
        fs:  `cpe:2.3:a:hp:l7000_basic:140.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.0.6`,
        fs:  `cpe:2.3:h:hp:j9532a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.0.7`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.0.8`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.30.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.1.3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.1.4`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.1.5`,
        fs:  `cpe:2.3:h:canyon-tech:cn-wf514:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.1.6`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.1.7`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.5.0:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2.0`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:1.1.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2.1`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2.3`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2.4`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2.5`,
        fs:  `cpe:2.3:a:cisco:anyconnect_vpn_client:2.5.2019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2.6`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.2.7`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_platform:9.5`,
        fs:  `cpe:2.3:a:crunchify:all-in-on-webmaster:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_remote_control:9.1.2`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bigfix_remote_control:9.1.3`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_mobile_software:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:blackice_server_protection:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:bladecenter:hs22`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:bladecenter:hs22v`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:bladecenter:hs23`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-28c-pwr-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:bladecenter:hs23e`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:bladecenter:hx5`,
        fs:  `cpe:2.3:h:ibm:system_x3500_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bootable_media_creator:2.30`,
        fs:  `cpe:2.3:a:mclewin:wishlist:6.x-2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bootable_media_creator:3.00`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:bootable_media_creator:9.21`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.0.0`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.0.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.0.0::~~express~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.0.0::~~standard~~~`,
        fs:  `cpe:2.3:a:nwtc:nwtc_mobile:1.4.17:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.0.1`,
        fs:  `cpe:2.3:h:netgear:wgr614:v4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.0.1::~~advanced~~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:334.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.0.1::~~express~~~`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2104hc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.0.1::~~standard~~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(36\)ca4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.0`,
        fs:  `cpe:2.3:a:microsoft:asp.net_core:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.0::~~express~~~`,
        fs:  `cpe:2.3:o:fedoraproject:fedora_core:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.0::~~standard~~~`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(1\)ey1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.1::~~advanced~~~`,
        fs:  `cpe:2.3:a:videotelecom:russkoe_tb_hd:3.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.1::~~express~~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.1::~~standard~~~`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.2::~~advanced~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.2::~~express~~~`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:7.5.1.2::~~standard~~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.0.0`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.0.0::~~advanced~~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)sv3\(1.10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.0.0::~~express~~~`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.0.0::~~standard~~~`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.3.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.0`,
        fs:  `cpe:2.3:o:wdc:arkeia_virtual_appliance_firmware:10.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.0::~~express~~~`,
        fs:  `cpe:2.3:a:vmware:vcloud_automation_center:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.0::~~standard~~~`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_72:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.1::~~advanced~~~`,
        fs:  `cpe:2.3:h:axis:m1013_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.1::~~express~~~`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:5.x-0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.1::~~standard~~~`,
        fs:  `cpe:2.3:h:ibm:flex_system_x240_compute_node:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.2::~~advanced~~~`,
        fs:  `cpe:2.3:a:apple:apple_tv:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.2::~~express~~~`,
        fs:  `cpe:2.3:a:hp:secure_web_server_for_tru64:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.2::~~standard~~~`,
        fs:  `cpe:2.3:a:google:chrome:15.0.864.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.3::~~advanced~~~`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:2013.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.3::~~express~~~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update6:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.0.1.3::~~standard~~~`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.97.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.0`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.0::~~advanced~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.0::~~express~~~`,
        fs:  `cpe:2.3:a:google:earth:6.0.2.2074:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.0::~~standard~~~`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.1::~~advanced~~~`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.1::~~express~~~`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.1::~~standard~~~`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.2::~~advanced~~~`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.2::~~express~~~`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.0.2::~~standard~~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.8.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.5.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.5.0::~~advanced~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.5.0::~~express~~~`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.0.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.5.0::~~standard~~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.6.2::~~advanced~~~`,
        fs:  `cpe:2.3:a:hp:proliant_ilo_monitor_service:3.2.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.6.2::~~express~~~`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:-:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.6.2::~~standard~~~`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.7.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.7.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.2.4502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.7.0::~~express~~~`,
        fs:  `cpe:2.3:a:adobe:golive:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:business_process_manager:8.5.7.0::~~standard~~~`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:campaign:8.6`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:campaign:9.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:campaign:9.1.1`,
        fs:  `cpe:2.3:a:infradead:openconnect:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:campaign:9.1.2`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:case_manager:5.2.1`,
        fs:  `cpe:2.3:a:dell:resource_cd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:case_manager:5.2.1.1`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:19.0.m0.60828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:6.0`,
        fs:  `cpe:2.3:h:buffalotech:wmr-300_firmware:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.0`,
        fs:  `cpe:2.3:a:netscout:sniffer_analysis:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.1`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.1.1.7`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.1.1.8`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-11-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.1.1.11`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.1.1.12`,
        fs:  `cpe:2.3:a:zope:zope:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.1.2`,
        fs:  `cpe:2.3:a:ithoughts:ithoughtshd:4.19:*:*:*:*:iphone_os:ipad:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.2.0`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:6.8:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.2.0.1`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.2.1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:change_and_configuration_management_database:7.2.2`,
        fs:  `cpe:2.3:a:lxml:lxml:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:client_access:-`,
        fs:  `cpe:2.3:a:microsoft:forefront_unified_access_gateway:2010:sp1_update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:client_security_password_manager:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cloudscape:-`,
        fs:  `cpe:2.3:a:apache:spamassassin:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cloudscape:5.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.0.0`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.1`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.1.0`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.2`,
        fs:  `cpe:2.3:h:cisco:tandberg_880_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.2.0`,
        fs:  `cpe:2.3:a:borland:search:3.0.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.3`,
        fs:  `cpe:2.3:a:trillian:trillian:0.722:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.3.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.4:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.4`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:12.0:-:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.4.0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.5`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_analytics:11.0.6`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_business_intelligence:8.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_business_intelligence:8.4.1`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_business_intelligence:10.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_business_intelligence:10.1.1`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.1p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_business_intelligence:10.2`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_business_intelligence:10.2.1`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.0:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_business_intelligence:10.2.1.1`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:12.04:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_business_intelligence:10.2.2`,
        fs:  `cpe:2.3:o:belden:hirschmann_firmware:05.3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_command_center:10.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yi1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_command_center:10.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_command_center:10.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.21.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_disclosure_management:10.2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_express:9.0`,
        fs:  `cpe:2.3:a:emc:rsa_web_threat_detection:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_express:9.5`,
        fs:  `cpe:2.3:a:apache:poi:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_express:10.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_express:10.2.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:9.4.1`,
        fs:  `cpe:2.3:a:apple:itunes:12.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:9.4.1.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:9.5.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:9.5.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:9.5.2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:5.6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:10.1.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr3204hf-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:10.1.0.1`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a4\(1.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:10.1.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:10.1.1.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.8:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:cognos_tm1:10.2.2.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:1.0.0.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.2.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:1.0.1.0`,
        fs:  `cpe:2.3:a:google:v8:3.23.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:1.0.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(28d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:2.0.0.0`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:2.0.1.0`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:2.0.1.1`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:2.5.0.0`,
        fs:  `cpe:2.3:h:hp:3com_switch:4800g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:2.5.0.1`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:2.5.0.2`,
        fs:  `cpe:2.3:h:axis:2400_video_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:2.5.0.3`,
        fs:  `cpe:2.3:h:moxa:oncell_gateway_g3211:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:3.0.0.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:3.0.1.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1663.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:3.0.1.1`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:4.0`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0:ru6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:4.0.0.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.7.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:4.5`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:4.5.0.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:5.0`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:5.0.0.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections:5.5.0.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta66:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections_portlets:4.0`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.3.2:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections_portlets:4.5`,
        fs:  `cpe:2.3:a:eyexam:eyexam:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections_portlets:4.5.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:connections_portlets:4.5.1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_collector:3.0.0.0`,
        fs:  `cpe:2.3:a:uiu4you:universal_imaging_utility:4.6.1.0:*:*:*:live_version:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_collector:3.0.0.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_collector:3.0.0.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.10:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_collector:3.0.0.3`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_collector:3.0.0.4`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2014:-:*:*:tetsu_trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_collector:3.0.0.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_manager:8.5::~~~enterprise~~`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_manager_ondemand_for_multiplatforms:8.5`,
        fs:  `cpe:2.3:h:hp:jg811aae:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_manager_ondemand_for_multiplatforms:9.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:2.0.0`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:2.0.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:2.0.3`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:2.0.3.5`,
        fs:  `cpe:2.3:a:visiwave:site_survey:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:2.0.3.6`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:2.0.3.7`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.51.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:2.0.3.8`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_navigator:3.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:content_template_catalog:4.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:control_center:6.0.0.0`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1518-4_pn\/dp_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:4.5`,
        fs:  `cpe:2.3:a:medquiz\:_medical_chat_and_mcqs_project:medquiz\:_medical_chat_and_mcqs:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:4.5:sp10`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:5.0`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.1.06020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:5.2:sp1`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:5.2:sp4`,
        fs:  `cpe:2.3:a:pandasecurity:panda_internet_security_2014:19.01.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:5.2:sp6`,
        fs:  `cpe:2.3:a:python:python:2.6.2150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0:sp2`,
        fs:  `cpe:2.3:a:tntnet:tntnet:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.1`,
        fs:  `cpe:2.3:a:nextdc:onedc:1.7:-:-:*:-:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p369:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.3`,
        fs:  `cpe:2.3:a:isc:bind:9.6.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.3.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4`,
        fs:  `cpe:2.3:a:php:php:5.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.2`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.3`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.4`,
        fs:  `cpe:2.3:a:altiris:connector_solution_event_integration_component:6.0.1823:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.5`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.6`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.7`,
        fs:  `cpe:2.3:a:lucent:radius:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.8`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.4.9`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.2.1:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5`,
        fs:  `cpe:2.3:a:perl:perl:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5.0`,
        fs:  `cpe:2.3:a:splunk:splunk:6.4.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-02-\/d:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5.2`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5.8`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5.9`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.0.5.10`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1`,
        fs:  `cpe:2.3:a:pgp:universal_server:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.0.1`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.0.2`,
        fs:  `cpe:2.3:a:apache:http_server:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.0.3`,
        fs:  `cpe:2.3:a:sun:solstice_adminsuite:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.0.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.1.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:9.40.uc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.1.2`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.1.3`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.1.1.4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.2.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.2.0.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.762.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.2.0.3`,
        fs:  `cpe:2.3:a:ukbusinessaid:nigerias_business_directory:0.70.13414.17619:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:6.2.0.4`,
        fs:  `cpe:2.3:a:qemu:qemu:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:7.0.0.0`,
        fs:  `cpe:2.3:a:tasofro:touhou-hisouten:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:curam_social_program_management:7.0.0.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:daeja_viewone:4.1.5::~~professional~~~`,
        fs:  `cpe:2.3:a:johnsoncontrols:pegasys_p2000_server_software:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:daeja_viewone:4.1.5::~~standard~~~`,
        fs:  `cpe:2.3:a:novell:groupwise:7.02:hp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:daeja_viewone:4.1.5::~~virtual~~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:daeja_viewone:4.1.5.1::~~professional~~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:daeja_viewone:4.1.5.1::~~standard~~~`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:daeja_viewone:4.1.5.1::~~virtual~~~`,
        fs:  `cpe:2.3:a:cisco:webns:5.1_0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:daeja_viewone:5.0::~~virtual~~~`,
        fs:  `cpe:2.3:a:intel:mhlpdell:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:dashdb_local:1.0.0`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:dashdb_local:1.1.0`,
        fs:  `cpe:2.3:a:google:v8:3.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:dashdb_local:1.1.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.413:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:dashdb_local:1.2.0`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:dashdb_local:1.2.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:dashdb_local:1.3.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:dashdb_local:1.3.1`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_protection:6.1::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:squiz:mysource_matrix:3.28.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_protection:6.1.3.4::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_protection:6.3::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_protection:6.3.1::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_server_client:9.5.500.784`,
        fs:  `cpe:2.3:a:safer-networking:spybot_search_and_destroy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_server_client:9.5.700.579`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.13:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_server_client:9.7.0.441`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_server_client:9.7.400.501`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_studio:3.1.0`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.9.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_studio:3.1.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_studio_web_console:3.1.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.1:ea1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:data_studio_web_console:3.2.0`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:datapower_gateway:7.2.0.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:-`,
        fs:  `cpe:2.3:a:firebird:firebird:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.0`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(32\)s13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.4`,
        fs:  `cpe:2.3:a:apple:keynote:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.5`,
        fs:  `cpe:2.3:a:7andi-fs.co:denny\&#39;s:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.6`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.6c`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.7`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.7b`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.8`,
        fs:  `cpe:2.3:a:autodesk:3ds_max:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.8a`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.9`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.1.9a`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:4.7-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2`,
        fs:  `cpe:2.3:a:kelly_d._redding:kelredd-pruview:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2:fp1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2:fp2`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2:fp3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.7_p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2:fp4`,
        fs:  `cpe:2.3:a:imember360:imember360:3.9.005:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2:fp5`,
        fs:  `cpe:2.3:a:avaya:operational_analyst:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2:fp6`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:10g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2:fp7`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:6.14.11.9745:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2:fp8`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd348a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.2.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.62.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.10`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:07.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:8.12`,
        fs:  `cpe:2.3:a:isc:bind:9.9.3:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.0`,
        fs:  `cpe:2.3:a:gnome:glib:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.0:fp1`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp3:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1`,
        fs:  `cpe:2.3:a:divx:player:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.1`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.2:a`,
        fs:  `cpe:2.3:a:freenac:freenac:2.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.3`,
        fs:  `cpe:2.3:a:kde:ark:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.3:a`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.4`,
        fs:  `cpe:2.3:a:logitech:vid:1.10.1009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.4:a`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.6:a`,
        fs:  `cpe:2.3:a:samba:samba:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.7`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.7:a`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.8`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.9`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.8:bundle10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.10`,
        fs:  `cpe:2.3:a:cogentdatahub:cascade_datahub:6.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.0.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.1.1000.504::~~enterprise~~~`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.24.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:sebastien_sauvage:webgobbler:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5::~~express~~~`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5::~~workgroup~~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.2`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.2:a`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.3:a`,
        fs:  `cpe:2.3:a:hp:creativeprojects_dwshrek2cards1:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.3:b`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p220:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.4`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.9p21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.4:a`,
        fs:  `cpe:2.3:h:y-cam:ycw003:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.5`,
        fs:  `cpe:2.3:a:busybox:busybox:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.6:a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.7`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.8`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2003:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.9`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.17:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.0.10`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.5.800.186`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.0.0.160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:-:*:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7::~~express~~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.234:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7::~~workgroup~~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.1`,
        fs:  `cpe:2.3:a:php:php:5.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.1::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.28:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.1::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.1::~~express~~~`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.1::~~workgroup~~~`,
        fs:  `cpe:2.3:a:tibco:spotfire_automation_services:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.2`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.2::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:apple:safari:3.0.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.2::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:citrix:access_gateway:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.2::~~express~~~`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.2::~~workgroup~~~`,
        fs:  `cpe:2.3:a:mollify:mollify:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.3`,
        fs:  `cpe:2.3:a:apache:wss4j:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.3::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.3::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:hp:sendmail:8.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:b5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.3::~~express~~~`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.3::~~workgroup~~~`,
        fs:  `cpe:2.3:a:sap:netweaver_solution_manager:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.4`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_ops_center:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.4::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.4::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:grassroots_dicom_project:grassroots_dicom:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.4::~~express~~~`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0597:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.4::~~workgroup~~~`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.5`,
        fs:  `cpe:2.3:a:1024cms:1024_cms:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.5::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.5::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.50:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.5::~~express~~~`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.5::~~workgroup~~~`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.6`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.09:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.6::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.6::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:hp:storeonce_virtual_storage_appliance:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.6::~~express~~~`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.6::~~workgroup~~~`,
        fs:  `cpe:2.3:a:ssh:tectia_manager:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.7::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:apache:mod_python:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.7::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:tribulant:tibulant_slideshow_gallery:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.7::~~express~~~`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.7::~~workgroup~~~`,
        fs:  `cpe:2.3:a:apache:camel:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.494:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.8::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:h:d-link:dcs-7000l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.8::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.8::~~enterprise~~~`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.8::~~express~~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1030:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.8::~~workgroup~~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.9`,
        fs:  `cpe:2.3:a:ibm:content_collector:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.9::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.49:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.9::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.9::~~express~~~`,
        fs:  `cpe:2.3:h:hp:j9823a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.9::~~workgroup~~~`,
        fs:  `cpe:2.3:a:microsoft:ie:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.9:a`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.10`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.10::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:supmua:sup:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.10::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:3com:tippingpoint_sms_client:3.1.1.7943:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.10::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.10::~~express~~~`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.10::~~workgroup~~~`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.69:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.11`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:ccf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.11::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:application_object_library:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.11::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.10:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.11::~~express~~~`,
        fs:  `cpe:2.3:h:cisco:rvl200_4-port_ssl_ipsec_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.0.11::~~workgroup~~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.7.400.501::~~enterprise~~~`,
        fs:  `cpe:2.3:a:erlang:crypto:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:ibm:flashcopy_manager:2.2:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8::~~express~~~`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8::~~workgroup~~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.1`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2_sp2:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.1::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:h:axis:2460_network_dvr:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.1::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_server:6.1.10000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.1::~~express~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.1::~~workgroup~~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.9.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.2::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:zcubes:zpaint:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.2::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.2::~~express~~~`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.11:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.2::~~workgroup~~~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.1\(4\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.3`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.3::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.3::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.3::~~express~~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.3::~~workgroup~~~`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.4`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.4::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:avaya:mn100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.4::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_manager:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:9.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.4::~~express~~~`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.4::~~workgroup~~~`,
        fs:  `cpe:2.3:a:ca:antispyware_for_the_enterprise:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.5`,
        fs:  `cpe:2.3:a:avast:endpoint_protection_suite:8.0.1606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.5::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.5::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:h:huawei:e585u-82:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.5::~~express~~~`,
        fs:  `cpe:2.3:a:microsoft:exchange_instant_messenger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:9.8.0.5::~~workgroup~~~`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:9.dotpp.net:megalith:51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:iij:seil\/x86_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1::~~express~~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1::~~workgroup~~~`,
        fs:  `cpe:2.3:a:debian:gfax:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.1`,
        fs:  `cpe:2.3:o:yamaha:rtw65b:5.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.1::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.0.3.728:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.1::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.1::~~express~~~`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.1::~~workgroup~~~`,
        fs:  `cpe:2.3:a:cybozu:office:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.2`,
        fs:  `cpe:2.3:a:ibm:java:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.2::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:secretcircle:secret_circle_-_talk_freely:2.2.00.26:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.2::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:hp:support_tools_manager:a.22.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.2::~~express~~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:2.3\(1.57\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.2::~~workgroup~~~`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.3`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.3::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:gnu:lsh:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.3::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:h:cisco:c420_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.392.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.3::~~express~~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.4.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.3::~~workgroup~~~`,
        fs:  `cpe:2.3:a:apple:itunes:10.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.3:a`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.4::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:manageengine:netflow_analyzer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.4::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:hp:care_pack_core:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.4::~~express~~~`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.4::~~workgroup~~~`,
        fs:  `cpe:2.3:h:cisco:catalyst_3560-x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.5`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.5::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:roxio:copy_module:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.5::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:hotlingo:hotlingo:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.5::~~express~~~`,
        fs:  `cpe:2.3:a:silver-peak:vx:6.2.2.0_47968:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.1.0.5::~~workgroup~~~`,
        fs:  `cpe:2.3:o:netbsd:netbsd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:oscmax:oscmax:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:analogx:proxy:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5::~~express~~~`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5::~~workgroup~~~`,
        fs:  `cpe:2.3:a:bart_lagerweij:pe_builder:3.1.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.1::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:jruby:jruby:1.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.1::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:ca:common_services:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.134.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.1::~~express~~~`,
        fs:  `cpe:2.3:a:pfsense:suricata_package:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.1::~~workgroup~~~`,
        fs:  `cpe:2.3:a:sap:hybris:5.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.2::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:cognos_express:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.2::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:enterasys:netsight_inventory_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.2::~~express~~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.2::~~workgroup~~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.3`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.3::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.3::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:h:hp:laserjet_m5035_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.3::~~express~~~`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.40.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.3::~~workgroup~~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.3:a`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.4`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.4::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.4::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:o:draytek:vigor_2700_router_firmware:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1671.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.4::~~express~~~`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04s:sp9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.4::~~workgroup~~~`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.5`,
        fs:  `cpe:2.3:a:ca:configuration_automation_server:12.5.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.5::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.5::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.5::~~express~~~`,
        fs:  `cpe:2.3:o:apple:os_x_server:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.5::~~workgroup~~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_5e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.6`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.6::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:novell:zenworks_patch_management_server:6.3.2.700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.6::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:enyetech:coca-cola_fm_guatemala:2.0.41725:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:bmc:patrol:9.13.10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.6::~~express~~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.6::~~workgroup~~~`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.7`,
        fs:  `cpe:2.3:a:microsoft:office:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.7::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.7::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:a:t1lib:t1lib:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.7::~~express~~~`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:10.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:10.5.0.7::~~workgroup~~~`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.07.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1`,
        fs:  `cpe:2.3:a:nortel:symposium_tapi_service_provider:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1::~~express~~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1::~~workgroup~~~`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1.0.0`,
        fs:  `cpe:2.3:a:tattyan:tattyan_hptown:5_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1.0.0::~~advanced_enterprise~~~`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1.0.0::~~advanced_workgroup~~~`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.7.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:h:hp:jetdirect_610n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1.0.0::~~express~~~`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.8.0.1430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2:11.1.0.0::~~workgroup~~~`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.3:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.1`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.5`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7::~~application_server~~~`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7::~~unlimited~~~`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.5118:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.1`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.1::~~application_server~~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.125.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.1::~~unlimited~~~`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.2`,
        fs:  `cpe:2.3:a:searchblox:searchblox:6.4:build_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.2::~~application_server~~~`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(5a\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.65:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.2::~~unlimited~~~`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.3::~~application_server~~~`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass_pro:6.2.1:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_explorer:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.3::~~unlimited~~~`,
        fs:  `cpe:2.3:a:symantec:private_branch_exchange:1.3.23.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.4::~~application_server~~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.4::~~unlimited~~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.5`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.5::~~application_server~~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:illumos:illumos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.5::~~unlimited~~~`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.6`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.6::~~application_server~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.6::~~unlimited~~~`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.7`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.7::~~application_server~~~`,
        fs:  `cpe:2.3:h:cisco:5500_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.7::~~unlimited~~~`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.8`,
        fs:  `cpe:2.3:h:d-link:di-604s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.8::~~application_server~~~`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.8::~~unlimited~~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.9`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.260:update26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.9::~~application_server~~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.9::~~enterprise~~~`,
        fs:  `cpe:2.3:h:hp:jf431b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.9::~~unlimited~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)yc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.10::~~application_server~~~`,
        fs:  `cpe:2.3:a:samba:samba:2.2.7:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gnu:flash_player:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.10::~~unlimited~~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.11::~~application_server~~~`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.015:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.7.0.11::~~unlimited~~~`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.30.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8::~~application_server~~~`,
        fs:  `cpe:2.3:a:altiris:script_task_agent:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.3d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8::~~unlimited~~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.1::~~application_server~~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.1::~~unlimited~~~`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.2::~~application_server~~~`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.2::~~unlimited~~~`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.3`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_quest_recovery_manager_for_active_directory:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.3::~~application_server~~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:creative_core:app_lock:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.3::~~unlimited~~~`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.4`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.4::~~application_server~~~`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mongodb:mongodb:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.4::~~unlimited~~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.5::~~application_server~~~`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:b7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:9.8.0.5::~~unlimited~~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.19:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1::~~application_server~~~`,
        fs:  `cpe:2.3:a:microsoft:project_server:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1::~~enterprise~~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1::~~unlimited~~~`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.1::~~application_server~~~`,
        fs:  `cpe:2.3:o:cisco:catos:2.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.1::~~unlimited~~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.2`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.2::~~application_server~~~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:teradata:fastexport:13.10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.2::~~unlimited~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.3`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.3::~~application_server~~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.3::~~unlimited~~~`,
        fs:  `cpe:2.3:a:vmware:view:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.4::~~application_server~~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.4::~~unlimited~~~`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.5::~~application_server~~~`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.2:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.1.0.5::~~unlimited~~~`,
        fs:  `cpe:2.3:h:cisco:nexus_3524:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5::~~application_server~~~`,
        fs:  `cpe:2.3:a:util-linux_project:util-linux:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:freemind:freemind:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5::~~unlimited~~~`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.1::~~application_server~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p137:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.53a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.1::~~unlimited~~~`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.2::~~application_server~~~`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:sp2:developer:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:emc:documentum_foundation_services:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.2::~~unlimited~~~`,
        fs:  `cpe:2.3:a:projectforge:projectforge:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.3::~~application_server~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.3::~~unlimited~~~`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.4::~~application_server~~~`,
        fs:  `cpe:2.3:a:projectsend:projectsend:102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.4::~~unlimited~~~`,
        fs:  `cpe:2.3:h:enterasys:vertical_horizon-2402s:2.05.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.5::~~application_server~~~`,
        fs:  `cpe:2.3:a:videowhisper:live_streaming_integration_plugin:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:apache:mod_python:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.5::~~unlimited~~~`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.6::~~application_server~~~`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe_toolkits:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.6::~~unlimited~~~`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.7::~~application_server~~~`,
        fs:  `cpe:2.3:a:deskshare:auto_ftp_manager:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.199:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:10.5.0.7::~~unlimited~~~`,
        fs:  `cpe:2.3:a:google:talk_plugin:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:11.1.0.0::~~application_server~~~`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:11.1.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect:11.1.0.0::~~unlimited~~~`,
        fs:  `cpe:2.3:a:yahoo:widgets:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_connect_server:9.7.300.291`,
        fs:  `cpe:2.3:a:dvdshrink:dvdshrink:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_content_manager:-`,
        fs:  `cpe:2.3:a:datatechgroup:telecommunication_inventory_and_billing_information_data_pump:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_content_manager_toolkit:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je016a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_content_manager_toolkit:8.3`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_purescale_feature_9.8:-:-:~-~-~db2_enterprise_edition~~`,
        fs:  `cpe:2.3:a:semanticforms_project:semanticforms:-:*:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_recovery_expert:2.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_recovery_expert:3.1`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_runtime_client:9.1.401.444`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:-`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:6.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:7.0`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:7.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:8.5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:7.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.0`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.0::aix`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.0::hp_ux`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.0::linux`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.0::solaris`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.4`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.5`,
        fs:  `cpe:2.3:a:google:bionic:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.6`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.6c`,
        fs:  `cpe:2.3:a:google:chrome:7.0.541.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.7b`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5613:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.8`,
        fs:  `cpe:2.3:a:redhat:pre_execution_environment_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.8a`,
        fs:  `cpe:2.3:a:mollify:mollify:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.9`,
        fs:  `cpe:2.3:a:moodle:moodle:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.1.9a`,
        fs:  `cpe:2.3:a:usr:netwaiting:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.2`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.10`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:8.12`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:9.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:9.1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110921:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:db2_universal_database:9.1:ga`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director:-`,
        fs:  `cpe:2.3:o:juniper:junos_j:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director:3.1`,
        fs:  `cpe:2.3:h:cisco:spa_502g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director:5.10`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director:5.10.3`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director:5.20.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director_agent:-`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director_agent:2.2`,
        fs:  `cpe:2.3:a:bittorrent:sync:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director_agent:3.11`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.3.1:mu_\#4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director_agent:5.20.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director_agent_pefix_pfn:5.20.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.9:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:director_agent_pefix_su2:5.20.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:disposal_and_governance_management_for_it:6.0.1.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.16c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:disposal_and_governance_management_for_it:6.0.1.6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:disposal_and_governance_management_for_it:6.0.2`,
        fs:  `cpe:2.3:a:gnu:enscript:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:disposal_and_governance_management_for_it:6.0.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.0`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:16.0.3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.2`,
        fs:  `cpe:2.3:a:freso:languageicons:6.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.3`,
        fs:  `cpe:2.3:h:hp:jg802a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.4`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.5`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.1.06013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.6`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.7`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.8`,
        fs:  `cpe:2.3:o:apple:watchos:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.9`,
        fs:  `cpe:2.3:a:adobe:illustrator:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:8.6.0.10`,
        fs:  `cpe:2.3:o:apple:mac_os:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.2`,
        fs:  `cpe:2.3:h:cisco:pix_500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.4`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.5`,
        fs:  `cpe:2.3:a:xnview:xnview:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7\)cx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.8`,
        fs:  `cpe:2.3:a:microsoft:ie:4.71.544:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.9`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.10`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.0.11`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.2.0`,
        fs:  `cpe:2.3:h:nokia:n95:12.0.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.2.1`,
        fs:  `cpe:2.3:a:netiq:appmanager_control_center:7.0.40179.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.2.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:9.1.2.3`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:10.0.0.0`,
        fs:  `cpe:2.3:a:gentoo:portage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:distributed_marketing:10.0.0.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:17.011.30059:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:document_connect_for_application_support_facility:1.0.0.1204`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(3m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:document_connect_for_application_support_facility:1.0.0.1218`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.0`,
        fs:  `cpe:2.3:a:mediafire:mediafire:1.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.1`,
        fs:  `cpe:2.3:o:huawei:e3276_firmware:e3276s-150tcpu-22.265.03.00.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.1.0`,
        fs:  `cpe:2.3:a:colorbox_node:dennis_blake:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.1.1`,
        fs:  `cpe:2.3:a:erlang:crypto:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.1.2`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.1.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.1.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:12.0.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.1.5`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.2`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.2.0`,
        fs:  `cpe:2.3:a:emc:documentum_web_publisher:6.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.2.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.2.2`,
        fs:  `cpe:2.3:a:symantec:java_liveupdate:3.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.2.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.2.4`,
        fs:  `cpe:2.3:h:hp:0235a32b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.3`,
        fs:  `cpe:2.3:a:jruby:jruby:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.3.0`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.9:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.3.2`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:1.1.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.3.3`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.5.1.639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.3.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.3.5`,
        fs:  `cpe:2.3:a:keepass:keepass:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:8.5.3.6`,
        fs:  `cpe:2.3:a:withhive:actionpuzzlefamily_for_kakao:1.4.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.0`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.20.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.0.0`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1.0`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1.3`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1.4`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_ip_gateway_encoder_decoder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1.5`,
        fs:  `cpe:2.3:a:kryo:iodine:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1.6`,
        fs:  `cpe:2.3:o:sun:solaris:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino:9.0.1.8`,
        fs:  `cpe:2.3:a:hp:openview_event_correlation_services:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:-`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.0.1`,
        fs:  `cpe:2.3:a:broadcom:ush_host_components:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.0.1.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.0.2`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.0.4`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.0.5`,
        fs:  `cpe:2.3:a:hp:enterprise:50.0.227.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.5`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:7.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.5.1`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.5.2`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.0.00052:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.5.3`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.5.4`,
        fs:  `cpe:2.3:a:horde:imp:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:6.5.5`,
        fs:  `cpe:2.3:a:bannersky:bsk_pdf_manager:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:domino_web_access:7.0.1`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ds_storage_manager_host_software:10.8`,
        fs:  `cpe:2.3:a:oracle:self-service_human_resources:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ds_storage_manager_host_software:10.60.x5.14`,
        fs:  `cpe:2.3:a:oracle:jai:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ds_storage_manager_host_software:10.83`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ds_storage_manager_host_software:10.83.05.18`,
        fs:  `cpe:2.3:a:csounds:csound:5.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ds4100:-`,
        fs:  `cpe:2.3:h:cisco:catalyst_3560-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ds4100:1724`,
        fs:  `cpe:2.3:a:tibco:spotfire_analyst:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ds4200:1814`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:4.0:unknown:unknown:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ds4300:1722`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ds4400:1742`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ds4500:1742`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ds4700:1814`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ds4800:1815`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.4:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:e10:-`,
        fs:  `cpe:2.3:a:pkware:pkzip:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:e12:-`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:e26:-`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:e40:-`,
        fs:  `cpe:2.3:a:zend:zendto:4.06-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:e56:-`,
        fs:  `cpe:2.3:h:tp-link:archer_c5_\(1.2\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:e64:-`,
        fs:  `cpe:2.3:h:linksys:wvc11b:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:eclipse_help_system:3.4.3`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_load_balancer:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:eclipse_help_system:3.6.2`,
        fs:  `cpe:2.3:a:iconics:genesis32:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ecolab:7.0`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:egatherer:-`,
        fs:  `cpe:2.3:a:adobe:captivate:5.0.0.596:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:egatherer:2.0.0.16`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:egatherer:2.0.16`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:egatherer:2.42.243`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5068-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:2.5.0`,
        fs:  `cpe:2.3:h:cisco:spa_525g2_5-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:2.5.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:2.5.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:2.5.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:2.5.4`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:2.5.5`,
        fs:  `cpe:2.3:a:htc:shift_4g_software:1.17.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.0.0`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.0.1`,
        fs:  `cpe:2.3:a:perl:perl:5.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.0.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.0.3`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.0.4`,
        fs:  `cpe:2.3:a:atlassian:jira:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.0.5`,
        fs:  `cpe:2.3:a:csc:ssoserviceclient:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.5.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.5.1`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.5.2`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.5.3`,
        fs:  `cpe:2.3:o:cisco:broadband_operating_system:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:3.5.4`,
        fs:  `cpe:2.3:a:isaac_sukin:browserid:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:4.0.0`,
        fs:  `cpe:2.3:a:logitech:mvision:10.50.1096:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:4.0.1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:elastic_storage_server:4.0.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:embedded_websphere_application_server:7.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:9.5.0.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:9.5.0.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:9.5.0.2`,
        fs:  `cpe:2.3:a:ibm:web_content_manager:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:9.5.0.3`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:9.5.0.4`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:9.5.0.5`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:9.5.0.6`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0:feature_pack_6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.0.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.0.1`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.1.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.1.1`,
        fs:  `cpe:2.3:a:yahoo:yui:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.1.2`,
        fs:  `cpe:2.3:o:juniper:junos:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.1.3`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.1.4`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.1.5`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.2.0`,
        fs:  `cpe:2.3:a:digium:asterisk:13.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.2.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.2.2`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.3.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_contract_management:10.0.2.3`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_program_management:10.0.2.5`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_program_management:10.0.2.6`,
        fs:  `cpe:2.3:a:pdfforge:pdfcreator:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_program_management:10.0.2.7`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing:10.0.2.0`,
        fs:  `cpe:2.3:a:sun:sunpci_ii_driver_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing:10.0.2.2`,
        fs:  `cpe:2.3:a:hp:storeonce_4420_backup_system:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing:10.0.2.3`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing:10.0.2.5`,
        fs:  `cpe:2.3:a:haxx:curl:7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing:10.0.2.6`,
        fs:  `cpe:2.3:a:isaac_sukin:browserid:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing:10.0.2.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing:10.0.4.0`,
        fs:  `cpe:2.3:a:commvault:active_directory_idataagent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:9.5.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.548:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:9.5.0.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:9.5.0.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:9.5.1.0`,
        fs:  `cpe:2.3:a:redhat:freeipa:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:9.5.1.1`,
        fs:  `cpe:2.3:a:yahoo:yui:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:9.5.1.2`,
        fs:  `cpe:2.3:a:vips:vips:7.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:9.5.1.3`,
        fs:  `cpe:2.3:o:ibm:aix:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.0.0`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.0.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.1.0`,
        fs:  `cpe:2.3:a:redhat:daredevil_skk:11.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.1.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.1.2`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.78.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.1.3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00-10:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.2.0`,
        fs:  `cpe:2.3:o:suse:suse_linux:7.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.2.2`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.2.3`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_sourcing_portfolio:10.0.2.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:9.5.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:9.5.0.1`,
        fs:  `cpe:2.3:o:sun:solaris:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:9.5.0.2`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:9.5.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:9.5.0.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.0.0`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.0.1`,
        fs:  `cpe:2.3:a:cisco:pgw_2200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.1.0`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.1.1`,
        fs:  `cpe:2.3:a:siemens:sinema_server:12.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.1.2`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.1.3`,
        fs:  `cpe:2.3:a:apple:itunes:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.2.0`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.01.464:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.2.2`,
        fs:  `cpe:2.3:a:tenable:nessus:6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_spend_analysis:10.0.2.4`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.0.0`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.0.1`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.0.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.4f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.0.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.1.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.1.1`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:4.0.2:005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.1.2`,
        fs:  `cpe:2.3:a:cisco:trust_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.1.3`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.0`,
        fs:  `cpe:2.3:a:apache:hadoop:0.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.1`,
        fs:  `cpe:2.3:a:f5:enterprise_manager:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.2`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.4`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.5`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd243b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.6`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.7`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.8`,
        fs:  `cpe:2.3:a:google:chrome:16.0.908.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.9`,
        fs:  `cpe:2.3:a:splunk:splunk:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.10`,
        fs:  `cpe:2.3:a:shopware:shopware:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.11`,
        fs:  `cpe:2.3:a:dotclear:dotclear:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.12`,
        fs:  `cpe:2.3:a:vmware:zimbra_desktop:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.13`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(1o\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.14`,
        fs:  `cpe:2.3:a:apache:hadoop:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.15`,
        fs:  `cpe:2.3:a:ibm:forms_experience_builder:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.16`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.2.17`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.525:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.0.4.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.0`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_firewalls:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.9:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.3`,
        fs:  `cpe:2.3:a:skype:skype:0.93.0.18:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.4`,
        fs:  `cpe:2.3:a:clamav:clamav:0.92_p0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.6`,
        fs:  `cpe:2.3:a:emc:navisphere_service_taskbar:28.53.1.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.7`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.8`,
        fs:  `cpe:2.3:a:emisoft:online_armor:4.0.0.35:-:premium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.9`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.10`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.11`,
        fs:  `cpe:2.3:a:devicelock:devicelock:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.0.12`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30097:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.0`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1663.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.2`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.3`,
        fs:  `cpe:2.3:a:condusiv:diskeeper:10.0.608:*:*:*:server_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.4`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.5`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.6`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.7`,
        fs:  `cpe:2.3:h:d-link:dcs-5030l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.8`,
        fs:  `cpe:2.3:a:avg:internet_security:8.5:-:network:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.9`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_strategic_supply_management:10.1.1.10`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.0.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.0.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.0.3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.1.0`,
        fs:  `cpe:2.3:a:newsignature:addressfield_tokens:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.1.1`,
        fs:  `cpe:2.3:a:pcre:perl_compatible_regular_expression_library:8.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.1.2`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.0\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.2.0`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.2.2`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.2.3`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.0.0.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.2.5`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:4.6\(2\):sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.2.6`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:emptoris_supplier_lifecycle_management:10.0.2.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_business_process_framework:4.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_capture:4.1`,
        fs:  `cpe:2.3:a:adobe:connect:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_engine:4.5.1.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.5:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_engine_.net_api:4.5.5100`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_engine_client_installer:4.5.1.0`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_manager:4.0`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_manager:4.0.1`,
        fs:  `cpe:2.3:a:microsoft:urlscan:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_manager:4.5`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_manager:4.5.1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_manager:5.0.0`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_manager:5.1.0`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.00:a:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_manager:5.2.0`,
        fs:  `cpe:2.3:a:brian_akers:mod_layout:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_content_services_client_libraries:5.4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_idm_desktop:4.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_image_services:4.1.2`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:9.1\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_image_services_remote_admin_console:4.0.40`,
        fs:  `cpe:2.3:a:gentoo:portage:2.1.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_image_services_toolkit:4.0.40`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1`,
        fs:  `cpe:2.3:a:devsaran:responsive_blog:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:001`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.06:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:002`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:08.0.01e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:003`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:004`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.3.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:005`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.35.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:006`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:007`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:008`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:009`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:010`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:011`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:012`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:013`,
        fs:  `cpe:2.3:h:cisco:b440_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:014`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:015`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:0.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:016`,
        fs:  `cpe:2.3:a:transifex:transifex:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:017`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.92.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:018`,
        fs:  `cpe:2.3:a:apache:commons_fileupload:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:019`,
        fs:  `cpe:2.3:a:altiris:cmdb_report_pack:6.5.1049:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:020`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:3.5.1:021`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:4.0.2`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:4.0.2:001`,
        fs:  `cpe:2.3:a:microsoft:winsock:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:4.0.2:002`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.01:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:4.0.2:003`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:2.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:4.0.2:004`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:4.0.2:005`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:4.0.2:006`,
        fs:  `cpe:2.3:a:acme:thttpd:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_p8_application_engine:4.0.2:007`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_management_console:10.0.11639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:filenet_panagon:1.0.0`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.0.0.0`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.0.0.1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.0.0.2`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.8.2:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.0.0.3`,
        fs:  `cpe:2.3:a:linux-nis:ypserv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.1.0.0`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.1.0.1`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_direct_user_interface:1.4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.1.0.2`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.0:04:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.1.1.0`,
        fs:  `cpe:2.3:a:openx:openx:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.1.1.0::~~~cps_services~~`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.1.1.1`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:2.1.1.8::~~~check_services~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.0`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.0::~~~ach_services~~`,
        fs:  `cpe:2.3:a:saltstack:salt_2015:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.0::~~~check_services~~`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.45.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.0::~~~cps_services~~`,
        fs:  `cpe:2.3:a:libmms_project:libmms:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.1::~~~ach_services~~`,
        fs:  `cpe:2.3:a:phpexcel_project:phpexcel:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.1::~~~check_services~~`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.1::~~~cps_services~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp6:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.2::~~~ach_services~~`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.2::~~~check_services~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.2::~~~cps_services~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.3:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.3::~~~ach_services~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(26b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.3::~~~check_services~~`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.89a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.3::~~~cps_services~~`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.4::~~~ach_services~~`,
        fs:  `cpe:2.3:a:oracle:applications_framework:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.4::~~~check_services~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.4::~~~cps_services~~`,
        fs:  `cpe:2.3:a:amberdms:amberdms_billing_system:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.5::~~~ach_services~~`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.5::~~~check_services~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.5::~~~cps_services~~`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.6::~~~ach_services~~`,
        fs:  `cpe:2.3:a:prosody:prosody:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.6::~~~check_services~~`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.6::~~~cps_services~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.7::~~~ach_services~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.7::~~~check_services~~`,
        fs:  `cpe:2.3:a:python:pillow:2.9.0:dev0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.7::~~~cps_services~~`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.8::~~~ach_services~~`,
        fs:  `cpe:2.3:a:goywp:webpress:13.00.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.8::~~~check_services~~`,
        fs:  `cpe:2.3:o:freebsd:freebsd:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.8::~~~cps_services~~`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.9::~~~ach_services~~`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.9::~~~check_services~~`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:513:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.9::~~~cps_services~~`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.99:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.10::~~~ach_services~~`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.10::~~~check_services~~`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.10::~~~cps_services~~`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.11::~~~ach_services~~`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.11::~~~check_services~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.11::~~~cps_services~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:6.0.4\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.12::~~~ach_services~~`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.12::~~~check_services~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:9.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.12::~~~cps_services~~`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.13::~~~ach_services~~`,
        fs:  `cpe:2.3:h:nortel:wlan_handset_6120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.13::~~~check_services~~`,
        fs:  `cpe:2.3:h:polycom:viewstation_fx_vs_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.13::~~~cps_services~~`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.14::~~~ach_services~~`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:4.1.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.14::~~~check_services~~`,
        fs:  `cpe:2.3:a:apache:traffic_server:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.14::~~~cps_services~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.17:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.15::~~~ach_services~~`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.15::~~~check_services~~`,
        fs:  `cpe:2.3:a:zencast:zencast:1.03.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.0.15::~~~cps_services~~`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.1.0::~~~ach_services~~`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.1.0::~~~check_services~~`,
        fs:  `cpe:2.3:h:cisco:catalyst_3750:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.2.0::~~~ach_services~~`,
        fs:  `cpe:2.3:a:vmware:fusion:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.2.0::~~~check_services~~`,
        fs:  `cpe:2.3:a:telos:amhs:11.5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.2.0::~~~cps_services~~`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.2.1::~~~ach_services~~`,
        fs:  `cpe:2.3:a:microsoft:system.net.websockets.client:4.3.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.2.1::~~~check_services~~`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:financial_transaction_manager:3.0.2.1::~~~cps_services~~`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flashcopy_manager:2.1::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:oracle:mysql_enterprise_monitor:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flashcopy_manager:2.2::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:webpagetest_project:webpagetest:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flashcopy_manager:3.1::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flashcopy_manager:3.1.1::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.6.1p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flashsystem_9846-ac2:-`,
        fs:  `cpe:2.3:a:vmware:player:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flashsystem_9846-ae2:-`,
        fs:  `cpe:2.3:h:netgear:wg602:1.04.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flashsystem_9848-ac2:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flashsystem_9848-ae2:-`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.2.02075:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:flashsystem_v9000_firmware:7.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:flashsystem_v9000_firmware:7.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)e7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:flashsystem_v9000_firmware:7.6`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flex_system_manager:1.1.0`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3\(.5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flex_system_manager:1.2.0`,
        fs:  `cpe:2.3:a:hp:service_manager_web_tier:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flex_system_manager:1.2.1`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2004:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flex_system_manager:1.3.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:rc.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flex_system_manager:1.3.1`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:flex_system_manager:1.3.2.0`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:4.3:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flex_system_manager_node_7955:-`,
        fs:  `cpe:2.3:h:hp:j9638a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flex_system_manager_node_8731:-`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flex_system_manager_node_8734:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flex_system_x220_compute_node:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flex_system_x240_compute_node:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:flex_system_x440_compute_node:-`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_experience_builder:8.5`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_experience_builder:8.5.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_experience_builder:8.6.0`,
        fs:  `cpe:2.3:h:cisco:spa_509g_12-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_experience_builder:8.6.3`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_viewer:4.0.0`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.7:f:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_viewer:4.0.0.1`,
        fs:  `cpe:2.3:a:microsoft:works:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_viewer:4.0.0.2`,
        fs:  `cpe:2.3:a:openpkg:openpkg:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_viewer:4.0.0.3`,
        fs:  `cpe:2.3:a:hp:openvms_secure_web_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_viewer:8.0.0`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:4.2\(1\)sv1\(5.2\):-:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_viewer:8.0.1`,
        fs:  `cpe:2.3:h:hp:jd669a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:forms_viewer:8.0.1.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.4`,
        fs:  `cpe:2.3:a:piwik:piwik:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.5`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:small_business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.5.0.1`,
        fs:  `cpe:2.3:a:mcafee:privacy_service:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.5.0.5`,
        fs:  `cpe:2.3:a:opensis:opensis:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.5.0.27`,
        fs:  `cpe:2.3:a:ibm:java:7.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.5.0.28`,
        fs:  `cpe:2.3:a:emc:rsa_access_manager:6.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.5.0.29`,
        fs:  `cpe:2.3:a:niif:shibb_auth:7.x-4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.5.0.30`,
        fs:  `cpe:2.3:a:oracle:secure_backup:10.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:3.5.0.31`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.0`,
        fs:  `cpe:2.3:o:dlink:dir865l_firmware:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(1\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.2`,
        fs:  `cpe:2.3:a:oracle:business_intelligence:12.2.1.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.3`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.4`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.3:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.5`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.17.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.7`,
        fs:  `cpe:2.3:a:vector:vector_outage_manager:1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system:4.1.0.8`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.29:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:2.0.0`,
        fs:  `cpe:2.3:a:paypal:merchant-sdk-php:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:2.0.1`,
        fs:  `cpe:2.3:a:nortel:symposium_network_control_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:2.0.2`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:2.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:2.0.4`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:2.0.5`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:2.0.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.4:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:2.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(1a\)n2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.2`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.3`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.4`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.5`,
        fs:  `cpe:2.3:a:sigmatel:c-major_audio:5.10.4803.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.6`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.7`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.8`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.9`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.10`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:11.0.5721.5230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.11`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.12`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:9.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.13`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.14`,
        fs:  `cpe:2.3:h:apple:ipad_mini:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.15`,
        fs:  `cpe:2.3:a:avaya:interactive_response:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.16`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.17`,
        fs:  `cpe:2.3:a:cherry-software:photopad:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.18`,
        fs:  `cpe:2.3:a:smarty:smarty:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.19`,
        fs:  `cpe:2.3:a:openstack:swift:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.20`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.21`,
        fs:  `cpe:2.3:a:gnome:glib:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.22`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.23`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.24`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.25`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.26`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p427:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.27`,
        fs:  `cpe:2.3:a:livelycart:livelycart:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.28`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:general_parallel_file_system_storage_server:3.5.0.29`,
        fs:  `cpe:2.3:a:mvd:surething_cd_labeler:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:gentran_integration_suite:4.3`,
        fs:  `cpe:2.3:a:tripwire:tripwire_enterprise_agent:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:gina:-`,
        fs:  `cpe:2.3:a:kaseya:virtual_system_administrator:9.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:gina:1.0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:global_console_manager_16_firmware:1.18.0.22011`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:global_console_manager_16_firmware:1.20.0.22575`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:global_console_manager_16_firmware:1.20.0.23447`,
        fs:  `cpe:2.3:a:commpower:xml_portal:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:global_console_manager_32_firmware:1.18.0.22011`,
        fs:  `cpe:2.3:a:mcafee:securify_distributed_login_collector:v6.0.1_\(build_v601_96\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:global_console_manager_32_firmware:1.20.0.22575`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:global_console_manager_32_firmware:1.20.0.23447`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_retention_policy_and_schedule_management:6.0.1.5`,
        fs:  `cpe:2.3:a:libav:libav:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_retention_policy_and_schedule_management:6.0.1.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.1eo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_retention_policy_and_schedule_management:6.0.2`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_retention_policy_and_schedule_management:6.0.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:-`,
        fs:  `cpe:2.3:a:ibm:infosphere_metadata_workbench:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:7.0`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:7:-:government:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:7.0.4.28`,
        fs:  `cpe:2.3:a:x:libchromexvmc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:7.0.4.29`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:7.0.4.48`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:8.0`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:8.0.13`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:8.0.50.16`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.0.1:mu_\#2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:global_security_kit:8.5`,
        fs:  `cpe:2.3:h:polycom:viewstation_512:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hacmp:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hacmp:4.4`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:3.2.0:sp1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:3.3.0:sp2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(5g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:3.3.7`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:4.1`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:4.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(2\)sp1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:6.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.17:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:7.3.2.0`,
        fs:  `cpe:2.3:a:symantec:mail_security_for_domino:8.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:hardware_management_console:7.3.2.0:sp1`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver_r346:347.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:high_availability_cluster_multiprocessing:-`,
        fs:  `cpe:2.3:a:mawashimono:nikki:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:high_availability_cluster_multiprocessing:1.0`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:homepageprint:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:homepageprint:1.0.7`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0`,
        fs:  `cpe:2.3:h:yokogawa:fieldmate:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.1`,
        fs:  `cpe:2.3:a:quest:toad_for_data_analysts:2.7.0.348:*:*:*:trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.2`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.3`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2000:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.5`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.6`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.7`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.5.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.8`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.9`,
        fs:  `cpe:2.3:a:ca:cleverpath_predictive_analysis_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.10`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.11`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.12`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:host_on-demand:11.0.13`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.0`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.6.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.6.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.12`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.12.2`,
        fs:  `cpe:2.3:a:cisco:unity_connection:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.12.6`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2006:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.12.7`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.19`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.19.4`,
        fs:  `cpe:2.3:a:google:chrome:10.0.636.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.19.5`,
        fs:  `cpe:2.3:a:redgraphic:sapid_cms:1.2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.19.6`,
        fs:  `cpe:2.3:a:tibco:spotfire_desktop:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.26`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-51:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.26.1`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.4_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.26.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.28`,
        fs:  `cpe:2.3:o:zte:zxhn_h108l_firmware:4.0.0d_zrq_gr4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:1.3.28.1`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:2.0`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:2.0.42`,
        fs:  `cpe:2.3:h:intel:server_board_s5000xal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:2.0.42.1`,
        fs:  `cpe:2.3:a:phpenter:php_enter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:2.0.42.2`,
        fs:  `cpe:2.3:a:oracle:javafx:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:2.0.47`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:2.0.47.1`,
        fs:  `cpe:2.3:a:ca:brightstor_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:5.3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:37.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.0.47`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.60.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.1`,
        fs:  `cpe:2.3:a:theforeman:foreman:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.2.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p401:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.2.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p409:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.2.9`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.2.11`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.2.13`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.2.15`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_customer_relationship_management:8.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.0.2.19`,
        fs:  `cpe:2.3:a:haxx:curl:7.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.1`,
        fs:  `cpe:2.3:a:cerulean_studios:trillian:3.1:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.1.0.3`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.1.0.5`,
        fs:  `cpe:2.3:a:webmin:webmin:1.840:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:6.1.0.9`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:7.0.0.38`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:8.0.0.11`,
        fs:  `cpe:2.3:a:simplelife_project:simplelife:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server:8.5.5.6`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:http_server_ssl_module_common:1.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:i:6.1`,
        fs:  `cpe:2.3:a:redgraphic:sapid_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:i:7.1`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.61:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:i:7.2`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:i_access:7.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:i5os:-`,
        fs:  `cpe:2.3:a:bastien_nocera:libsocialweb:0.25.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ibmhsssb:-`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ics_viewer:6.0`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ilog_elixir:2.5.0::~~trial~~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.566:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ims_enterprise_suite:1.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ims_enterprise_suite:2.1`,
        fs:  `cpe:2.3:a:osticket:osticket:1.6:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:ims_enterprise_suite:2.2`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.1.0.488:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:infoprint:-`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infoprint_21:1.047012`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infoprint_controller:-`,
        fs:  `cpe:2.3:a:apple:cups:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informed_desktop_eforms:4.1.50.67`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix:-`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix:7.25_.uc1_se`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix:7.25_.uc2_se`,
        fs:  `cpe:2.3:a:audiograbber:audiograbber:1.83_se_:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix:7.25_.uc3_se`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p7_rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_client-sdk:3.0`,
        fs:  `cpe:2.3:a:ca:unicenter_asset_portfolio_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_client_sdk:-`,
        fs:  `cpe:2.3:h:yealink:voip_phone:28.2.0.128.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_client_sdk:2.90`,
        fs:  `cpe:2.3:a:jruby:jruby:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:-`,
        fs:  `cpe:2.3:a:kadu:kadu:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:7.3`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:7.31_.xd8`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.3`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.464:mr7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.4`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.tc1`,
        fs:  `cpe:2.3:a:apache:maven:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.tc2`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.tc3`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.tc4`,
        fs:  `cpe:2.3:o:scientificlinux:scientificlinux:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.tc5`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.tc7`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.tc8`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.uc1`,
        fs:  `cpe:2.3:a:oracle:oss_support_tools:8.11.16.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.uc2`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.uc3`,
        fs:  `cpe:2.3:h:xerox:document_centre_340:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.uc5`,
        fs:  `cpe:2.3:a:owncloud:owncloud:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:9.40.xc7`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:10.0`,
        fs:  `cpe:2.3:a:open_graph_importer_project:open_graph_importer:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:10.00.tc1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:10.00.tc2`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:10.00.tc4`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.5.0.880:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:10.00.tc5`,
        fs:  `cpe:2.3:h:cisco:nexus_3172:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_database_server:10.0_xc3`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:8.04:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:-`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:7.31`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:9.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:9.40.tc5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yb5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:9.40.uc1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:9.40.uc2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:9.40.uc3`,
        fs:  `cpe:2.3:h:cisco:887va_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:9.40.uc5`,
        fs:  `cpe:2.3:a:sympa:sympa:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:9.40.xc5`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.7:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:9.40.xc7`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:10.00`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:10.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1668.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:10.0.tc1`,
        fs:  `cpe:2.3:a:cisco:finesse:9.1\(1\)_es3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:10.00.tc3tl`,
        fs:  `cpe:2.3:h:supermicro:x9drff-7tg\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:10.0.xc1`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:10.0.xc3`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:11.10.tb4tl`,
        fs:  `cpe:2.3:a:apple:safari:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:11.50.xc9w2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)st2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_dynamic_server:11.70.xc7`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_extended_parallel_server:-`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_extended_parallel_server:8.40_uc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.2\(0\)zz\(99.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_extended_parallel_server:8.40_uc2`,
        fs:  `cpe:2.3:a:roxio:burn:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_i-connect:-`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_i-connect:2.90`,
        fs:  `cpe:2.3:a:luke_herrington:stickynote:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_open_admin_tool:2.0`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_open_admin_tool:3.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_open_admin_tool:3.11.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:-`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:3.3`,
        fs:  `cpe:2.3:a:apple:webkit:416.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:3.4`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:3.5`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:3.6`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:3.7`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.7:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:4.10`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:4.11`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:4.12`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:informix_web_datablade:4.13`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:1.1.0.0`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_presentation_server:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:1.1.0.1`,
        fs:  `cpe:2.3:a:zonelabs:imsecure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:1.1.0.2`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:1.2.0.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(3l\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:1.3.0.0`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:1.3.0.1`,
        fs:  `cpe:2.3:h:ibm:power_5:9113-550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:1.4.0.0`,
        fs:  `cpe:2.3:a:freenac:freenac:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:2.0.0.0`,
        fs:  `cpe:2.3:a:apple:itunes:4.6.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:2.1.0.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:2.1.0.1`,
        fs:  `cpe:2.3:o:breakingpointsystems:breakingpoint_storm_appliance_ctm:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:2.1.0.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:2.1.0.3`,
        fs:  `cpe:2.3:a:apple:itunes:12.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:2.1.1.0`,
        fs:  `cpe:2.3:a:emc:networker:7.5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:3.0.0.0`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:3.0.0.1`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.5:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:3.0.0.2`,
        fs:  `cpe:2.3:a:serena:pvcs_version_manager:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_biginsights:4.0.0.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_business_glossary:8.1.1`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-s39:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_business_glossary:8.1.2`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2012:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:-`,
        fs:  `cpe:2.3:a:kratosnetworks:neuralstar:8.3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:8.1`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r7-s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:8.5`,
        fs:  `cpe:2.3:a:web2py:web2py:1.76.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:8.5.0.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:8.7`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:9.1`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:5.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:11.3`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.27:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:11.3.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_datastage:11.3.1.2`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_fasttrack:8.1`,
        fs:  `cpe:2.3:a:ca:license_software:1.55.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_fasttrack:8.1.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_fasttrack:8.1.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_fasttrack:8.5`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:7.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_fasttrack:8.7`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_guardium:7.00`,
        fs:  `cpe:2.3:a:cisco:meraki_mx_firmware:2014-09-24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_guardium:8.00`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp5:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_guardium:8.01`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:5500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_guardium:8.2`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_guardium:8.20`,
        fs:  `cpe:2.3:a:cisco:jabber_guest:10.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_import_export_manager:8.1`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_import_export_manager:8.1.1`,
        fs:  `cpe:2.3:a:google:chrome:49.0.2623.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_import_export_manager:8.1.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_import_export_manager:8.5`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(4i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_import_export_manager:8.7`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_import_export_manager:9.1`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:108.2146.2565.38893:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.1`,
        fs:  `cpe:2.3:a:anl:bcfg2:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.5`,
        fs:  `cpe:2.3:a:f5:big-ip_domain_name_system:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.5.0.1`,
        fs:  `cpe:2.3:h:trendnet:tv-ip422wn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.5.0.2`,
        fs:  `cpe:2.3:a:microsoft:ie:7.00.5730.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.5.0.3`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.7`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-8c-si_ls-s3100-8c-si-dc-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.7.0.1`,
        fs:  `cpe:2.3:a:siemens:wincc:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:8.7.0.2`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:9.1`,
        fs:  `cpe:2.3:a:tejonstore:dieta_dukan_passo_a_passo:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:9.1.0.1`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:9.1.2`,
        fs:  `cpe:2.3:h:hp:4050_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:11.3`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:11.3.1`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ebg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server:11.5`,
        fs:  `cpe:2.3:a:adobe:illustrator:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metabrokers_%26_bridges:-`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.0.0`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050803:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.0.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.0.1.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.0.1.2`,
        fs:  `cpe:2.3:a:microsoft:works:4.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.0.1.3`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_integrated_portal:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.1.0.1`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.6:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.1.0.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.1.1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.5.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.5.0.1`,
        fs:  `cpe:2.3:h:hp:0235a0a8:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.5.0.2`,
        fs:  `cpe:2.3:a:ibm:ims_enterprise_suite:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.5.0.3`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_team_foundation_server:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.7.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:7.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.7.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:8.7.0.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1687.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:9.1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:9.1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_information_server_metadata_workbench:9.1.2.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management:9.1::~~collaborative~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management:10.0::~~collaborative~~~`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-02-19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management:10.1::~~collaborative~~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management:11.0::~~collaborative~~~`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management:11.3::~~collaborative~~~`,
        fs:  `cpe:2.3:a:ut-files:utstats:-:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management:11.4::~~collaborative~~~`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_universal_restore:11.0.17217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_collaboration_server:10.0`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_collaboration_server:10.1`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_collaboration_server:11.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_reference_data_management_hub:10.1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.004:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_reference_data_management_hub:11.0`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server:8.5`,
        fs:  `cpe:2.3:a:sympa:sympa:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server:9.0.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server:9.0.2`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20170730:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server:10.0`,
        fs:  `cpe:2.3:a:samba:samba:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server:10.1`,
        fs:  `cpe:2.3:o:wdc:my_net_firmware:1.05.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server:11.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server:11.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.341:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server:11.4`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:9.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.01.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:9.1`,
        fs:  `cpe:2.3:a:redhat:jboss_web_framework_kit:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:10.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:10.0.0.1`,
        fs:  `cpe:2.3:h:xerox:workcentre_m45:2.97.20.032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:10.0.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:10.1`,
        fs:  `cpe:2.3:a:ca:unicenter_asset_management:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:10.1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:10.1.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:11.0`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_master_data_management_server_for_product_information_management:11.3`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_metadata_workbench:8.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_metadata_workbench:8.1.1`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_metadata_workbench:8.1.2`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.2.2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_metadata_workbench:8.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(9a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_metadata_workbench:8.7`,
        fs:  `cpe:2.3:a:rsupport:lg_telepresence:2.0.12:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_configuration_manager:2.0`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_configuration_manager:2.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_configuration_manager:2.2`,
        fs:  `cpe:2.3:a:ca:unicenter_tng_jpn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.0`,
        fs:  `cpe:2.3:a:e2fsprogs_project:e2fsprogs:1.43.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.1`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a3:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.3.1`,
        fs:  `cpe:2.3:h:securecomputing:snapgear_sg710:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.3.2`,
        fs:  `cpe:2.3:a:novell:bordermanager:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.3.3`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p358:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.4.0`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.4.1`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.5.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_data_services_platform:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.5.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.1.0`,
        fs:  `cpe:2.3:a:rovicorp:sonic_update_manager:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.1.1`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.1.2`,
        fs:  `cpe:2.3:a:apache:axis:-:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.2.0`,
        fs:  `cpe:2.3:a:hp:help_and_support_center:4.4_b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.2.1`,
        fs:  `cpe:2.3:h:mutiny:mutiny_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.2.2`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.2:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.3.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.3.1`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:9.1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:9.1.0.3`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_performance_manager:5.1.0`,
        fs:  `cpe:2.3:a:transifex:transifex:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_performance_manager:5.1.1.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.7.12.11.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_performance_manager:5.1.1.1`,
        fs:  `cpe:2.3:a:debian:apt:0.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_optim_performance_manager:5.2.0.0`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_replication_server:9.7`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_replication_server:10.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(26\)p5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_replication_server:10.1.0.1`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_replication_server:10.1.0.2`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_replication_server:10.1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_replication_server:10.1.0.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_replication_server:10.2.0.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:3.0.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:3.1.0`,
        fs:  `cpe:2.3:a:google:chrome:51.0.2704.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:3.2.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:4.0`,
        fs:  `cpe:2.3:a:informationbuilders:webfocus:77.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:4.0.1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:4.1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.525.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:4.1.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:4.2`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:infosphere_streams:4.2.1`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:initiate_master_data_service:9.5`,
        fs:  `cpe:2.3:a:cir:circa_news:2.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:initiate_master_data_service:9.7`,
        fs:  `cpe:2.3:o:iij:seil\%2fneu_2fe_plus_firmware:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:initiate_master_data_service:10.0`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:initiate_master_data_service:10.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.0.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.48.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.0.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.1.0`,
        fs:  `cpe:2.3:a:openid:openid4java:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.1.2`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.1.3`,
        fs:  `cpe:2.3:a:adobe:suite_specific:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.1.4`,
        fs:  `cpe:2.3:a:microsoft:expression_web:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.1.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.2.0`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.2.1`,
        fs:  `cpe:2.3:a:divx:codec:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.2.2`,
        fs:  `cpe:2.3:a:ibm:network_appliance_data_ontap:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.2.3`,
        fs:  `cpe:2.3:o:cisco:nx-ox:6.0\(2\)a7\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:\(4\)st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.3.1`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.3.2`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.3:rc1:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.3.3`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.3.4`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.3.5`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2007:11.0.709.32:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:8.5.3.6`,
        fs:  `cpe:2.3:a:google:v8:3.22.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.0.0`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.1.1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.1.2`,
        fs:  `cpe:2.3:a:apache:camel:2.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.1.3`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.9.8:*:*:*:novatel:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.1.4`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.0-30:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.1.6`,
        fs:  `cpe:2.3:a:jruby:jruby:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inotes:9.0.1.7`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:installation_manager:1.0.0`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:installation_manager:1.7.4.3`,
        fs:  `cpe:2.3:a:rockwellautomation:rslogix_5000_design_and_configuration_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:installation_manager:1.8.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:installation_manager:1.8.1.0`,
        fs:  `cpe:2.3:a:buffalotech:whr-am54g54_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:installation_manager:1.8.2.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:installation_manager:1.8.2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:installation_manager:1.8.3.0`,
        fs:  `cpe:2.3:a:ibm:connections:3.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:integrated_management_module:-`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:integrated_management_module_2:1.00`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:integrated_management_module_2:2.00`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:integrated_management_module_firmware:1.36`,
        fs:  `cpe:2.3:h:qualcomm:msm8960:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:integrated_management_module_firmware:1.43`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp3:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:integrated_management_module_ii:-`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_foundation:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:integrated_management_module_ii_firmware:3.65`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:28.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:integrated_management_module_ii_firmware:4.15`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:9.0`,
        fs:  `cpe:2.3:a:dessci:mathplayer:2.1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:9.0.0.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2424m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:9.0.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:9.0.0.2`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:9.0.0.4`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:9.0.0.5`,
        fs:  `cpe:2.3:a:cnectd:cnectd:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:9.0.0.8`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:10.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:10.0.0.0`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:10.0.0.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:10.0.0.2`,
        fs:  `cpe:2.3:h:sophos:unified_threat_management:425:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:10.0.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:10.0.0.4`,
        fs:  `cpe:2.3:h:cisco:cs-mars:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:10.0.0.8`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:integration_bus:10.0.0.9`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:intelligent_operations_center:1.0.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:intelligent_operations_center:1.0.0.1`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:intelligent_operations_center:1.5.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:intelligent_operations_center:1.5.0.1`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:interact:8.6`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:interact:9.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:interact:9.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.1\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:interact:9.1.1`,
        fs:  `cpe:2.3:a:emc:navisphere_server_utility:6.24.0.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:interact:9.1.2`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:interact:10.0`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:internet_security_systems_blackice_defender:-`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:internet_security_systems_blackice_defender:2.9cap`,
        fs:  `cpe:2.3:a:freedomscientific:utilities:10.19.760.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:-`,
        fs:  `cpe:2.3:a:hitachi:cosminexus\/opentp1_web_web_front-endset:01-00-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.2`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.5.502.146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.4`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.5`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.14:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.7`,
        fs:  `cpe:2.3:a:osclass:osclass:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.8`,
        fs:  `cpe:2.3:a:mandrakesoft:mandrake_multi_network_firewall:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:inventory_scout:2.2.0.9`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.3:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:iseries:5.0:r2`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:iseries_as_400:-`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:iseries_as_400:4.3`,
        fs:  `cpe:2.3:a:chkrootkit:chkrootkit:0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cbd`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cbr`,
        fs:  `cpe:2.3:h:ibm:e64:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cbz`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cca`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:ccb`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:ccc`,
        fs:  `cpe:2.3:a:tenable:nessus:6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:ccd`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cce`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:ccf`,
        fs:  `cpe:2.3:a:atheme:atheme:7.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:ccg`,
        fs:  `cpe:2.3:a:autodesk:sketchbook_for_enterprise_2014:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cpie`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cpj`,
        fs:  `cpe:2.3:a:oracle:enterprise_governance_risk_and_compliance_manager:7.7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cpk`,
        fs:  `cpe:2.3:a:hummingbird:enterprise_collaboration:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cpn`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cpp`,
        fs:  `cpe:2.3:a:oracle:clinical:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:cpu`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_pc_protection:3.6:epj`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.5:cdf`,
        fs:  `cpe:2.3:h:buffalotech:whr-600d_firmware:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:cbr`,
        fs:  `cpe:2.3:o:cisco:spa300_firmware:7.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:cbz`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:cca`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:ccb`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(0\)n1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:ccc`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:ccd`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:cce`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:ccf`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:ccg`,
        fs:  `cpe:2.3:a:conky:conky:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:cch`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:cno`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:cpk`,
        fs:  `cpe:2.3:a:apache:coyote_http_connector:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_blackice_server_protection:3.6:epj`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.00c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_internet_scanner:7.0`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_internet_scanner_software:5.3`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_internet_scanner_software:6.2.1`,
        fs:  `cpe:2.3:a:pixman:pixman:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_internet_scanner_software:7.0:sp2`,
        fs:  `cpe:2.3:h:ibm:system_x3550_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_internet_scanner_software:7.2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_proventia_desktop:8.0`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_proventia_desktop:8.0.675.1790`,
        fs:  `cpe:2.3:a:adobe:presenter:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_proventia_desktop:8.0.812.1790`,
        fs:  `cpe:2.3:a:bir.gov.ph:alphalist_data_entry_and_validation:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_proventia_desktop:1780`,
        fs:  `cpe:2.3:o:juniper:junos:14.2:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:iss_proventia_network_ips:gx5008:1.5`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.9:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:iss_proventia_network_ips:gx5108:1.3`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_proventia_server_ips_for_windows:1.0.914.1780`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6:ebr`,
        fs:  `cpe:2.3:a:ca:unicenter_network_and_systems_management:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6:ebz`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6:eca`,
        fs:  `cpe:2.3:a:openstack:keystone:2014.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6:ecb`,
        fs:  `cpe:2.3:a:blingo:blingo_toolbar:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6:ecd`,
        fs:  `cpe:2.3:o:aterm:wg300hp_firmware:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6:ece`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6:ecf`,
        fs:  `cpe:2.3:a:realflex:realwin:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:3.6:ecg`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.4.1:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0`,
        fs:  `cpe:2.3:a:apache:activemq:5.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:eba`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ebf`,
        fs:  `cpe:2.3:h:hp:0235a397:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ebg`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ebh`,
        fs:  `cpe:2.3:a:ibm:b2b_advanced_communications:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ebj`,
        fs:  `cpe:2.3:a:graphicstylus:north_american_ismaili_games:5.26.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ebk`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.16.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ebl`,
        fs:  `cpe:2.3:a:techjoomla:com_socialads:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ebm`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ebr`,
        fs:  `cpe:2.3:a:ibm:leads:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:ecb`,
        fs:  `cpe:2.3:a:ca:license_software:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:epj`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:16.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_desktop:7.0:epk`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:3.2`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:5.0`,
        fs:  `cpe:2.3:a:redhat:openstack_essex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:6.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:6.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.278:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.1.8.3544:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.487:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.16`,
        fs:  `cpe:2.3:a:xnview:xnview:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.17`,
        fs:  `cpe:2.3:h:hp:3com_switch_taa_compliant:5500g-ei-pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.18`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.19`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.3`,
        fs:  `cpe:2.3:a:ca:business_protection_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.4`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.5`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.6`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.7`,
        fs:  `cpe:2.3:a:heartlogic.jp:hl-sitemanager:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_20.9`,
        fs:  `cpe:2.3:a:google:v8:3.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_21.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(4\)sv1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_21.2`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_21.3`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.1`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.10`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.2`,
        fs:  `cpe:2.3:a:wellintech:kingscada:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.364:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.4`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.5`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.6`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.7`,
        fs:  `cpe:2.3:o:hp:hp-ux:7.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.8`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_22.9`,
        fs:  `cpe:2.3:h:ibm:ds4200:1814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_network:7.0:xpu_24.39`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:5.5`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.91:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.0`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.0.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.5`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.5:sr_3.10`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.5:sr_3.2`,
        fs:  `cpe:2.3:a:ibm:platform_symphony:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.5:sr_3.3`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.5:sr_3.4`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.5:sr_3.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.5:sr_3.6`,
        fs:  `cpe:2.3:a:apple:motion:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:6.5:sr_3.7`,
        fs:  `cpe:2.3:a:cisco:ip_contact_center_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:sr_4.4`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_20.16`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_20.18`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_20.19`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.5.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_21.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_21.3`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.1`,
        fs:  `cpe:2.3:a:gnu:wget:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.10`,
        fs:  `cpe:2.3:h:nortel:ip_phone_2001:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.2`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:15.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.3`,
        fs:  `cpe:2.3:a:john_albin:zen:6.x-1.0beta1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.4`,
        fs:  `cpe:2.3:a:sybase:pylon_anywhere:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.5`,
        fs:  `cpe:2.3:a:git-scm:git:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.6`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.7`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.8`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.9`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:iss_realsecure_server_sensor:7.0:xpu_24.39`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.06.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2`,
        fs:  `cpe:2.3:a:ibm:netezza_performance_portal:2.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13`,
        fs:  `cpe:2.3:a:atheme:atheme:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.9:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.2`,
        fs:  `cpe:2.3:o:d-link:dcs-2210l_firmware:1.03.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.3`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:02-50-07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.4`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.5`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.6`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.7`,
        fs:  `cpe:2.3:a:kde:ark:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.8`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.10`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.11`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.12`,
        fs:  `cpe:2.3:a:apache:camel:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.13`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.14`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.15`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.16`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.17`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(3n\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:1.4.2.13.18`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.0.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.11.0`,
        fs:  `cpe:2.3:h:cisco:4400_wireless_lan_controller:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.11.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-02:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.11.2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.12.0`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.12.1`,
        fs:  `cpe:2.3:a:digium:asterisk:12.1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.12.2`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.12.3`,
        fs:  `cpe:2.3:a:igniterealtime:smack:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.12.4`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.12.5`,
        fs:  `cpe:2.3:a:xml-dt_project:xml-dt:0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.13.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.14.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.15.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20091031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.16`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.01.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.16.0`,
        fs:  `cpe:2.3:h:hp:jg734a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.16.1`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.16.2`,
        fs:  `cpe:2.3:a:redhat:rhel_cluster_storage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:5.0.16.3`,
        fs:  `cpe:2.3:h:hp:retail_rp7_vfd_customer_display_qz701aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.0.0`,
        fs:  `cpe:2.3:a:compaq:management_agents_for_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.1.0`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.2.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yf3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.4.0`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.5.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.511.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.6.0`,
        fs:  `cpe:2.3:a:ibm:filenet_content_engine_client_installer:4.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.7.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.8.0`,
        fs:  `cpe:2.3:a:libssh:libssh:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.8.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.9.0`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.9.1`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.9.2`,
        fs:  `cpe:2.3:a:illinois:ncsa_mosaic:2.7:b5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.10.0`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.10.1`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l3_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.11.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2610-24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.12.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.13.0`,
        fs:  `cpe:2.3:a:jquery:jquery:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.13.1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.13.2`,
        fs:  `cpe:2.3:a:openconstructor_project:openconstructor:3.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.14.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.0.16`,
        fs:  `cpe:2.3:h:rockwellautomation:slc_500_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:6.1.8`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.1.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.2.0`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.3.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.4.0`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.4.1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:12.1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.4.2`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.5.0`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.0.9`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:7.1.2`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java:8.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_2_sdk:5.0.16.13::~~technology~~~`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.0.0::~~technology~~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.11.0::~~technology~~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.11.1::~~technology~~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.11.2::~~technology~~~`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.12.0::~~technology~~~`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.12.1::~~technology~~~`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:9.0\(2\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.12.2::~~technology~~~`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.12.3::~~technology~~~`,
        fs:  `cpe:2.3:a:infoblox:if-map_client_simulator:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.12.4::~~technology~~~`,
        fs:  `cpe:2.3:a:redhat:power_tool:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.12.5::~~technology~~~`,
        fs:  `cpe:2.3:a:php:php:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.13.0::~~technology~~~`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.006:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.14.0::~~technology~~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.15.0::~~technology~~~`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.16.0::~~technology~~~`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.16.1::~~technology~~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.16.2::~~technology~~~`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.16.3::~~technology~~~`,
        fs:  `cpe:2.3:o:cisco:ios:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.16.4::~~technology~~~`,
        fs:  `cpe:2.3:a:nteloswireless:my_ntelos:1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.16.5::~~technology~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.16.6::~~technology~~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:5.0.16.8::~~technology~~~`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.0.0::~~technology~~~`,
        fs:  `cpe:2.3:a:samba:samba:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.1.0::~~technology~~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20091022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.2.0::~~technology~~~`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.3.0::~~technology~~~`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.82.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.4.0::~~technology~~~`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.5.0::~~technology~~~`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.6.0::~~technology~~~`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_command_center:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.7.0::~~technology~~~`,
        fs:  `cpe:2.3:a:microsoft:outlook.com:7.8.2.12.49.7090:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.8.0::~~technology~~~`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.8.1::~~technology~~~`,
        fs:  `cpe:2.3:a:expressjs:express:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.9.0::~~technology~~~`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.1:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.9.1::~~technology~~~`,
        fs:  `cpe:2.3:a:apple:safari:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.9.2::~~technology~~~`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.10.0::~~technology~~~`,
        fs:  `cpe:2.3:a:logitech:lws_motion_detection:13.0.1778.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.10.1::~~technology~~~`,
        fs:  `cpe:2.3:a:businessobjects:infoview:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.11.0::~~technology~~~`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.12.0::~~technology~~~`,
        fs:  `cpe:2.3:a:google:web_toolkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.13.0::~~technology~~~`,
        fs:  `cpe:2.3:a:symantec:backupexec_system_recovery:7.0.1.21475:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.13.1::~~technology~~~`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-02-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.13.2::~~technology~~~`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.5.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.14.0::~~technology~~~`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.15.0::~~technology~~~`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:6.5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.15.1::~~technology~~~`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.15.21::~~technology~~~`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:01-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.16.0::~~technology~~~`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.16.3::~~technology~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s_3.3.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.16.7::~~technology~~~`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.0.16.21::~~technology~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.1.8.2::~~technology~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.1.8.7::~~technology~~~`,
        fs:  `cpe:2.3:a:python:python:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:6.1.8.20::~~technology~~~`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.0.0::~~technology~~~`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.1.0::~~technology~~~`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.2.0::~~technology~~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.3.0::~~technology~~~`,
        fs:  `cpe:2.3:a:springsource:spring_framework:4.0.0:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.4.0::~~technology~~~`,
        fs:  `cpe:2.3:o:siemens:ccms2025_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.4.1::~~technology~~~`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp1:x32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.4.2::~~technology~~~`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.5.0::~~technology~~~`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.6.0::~~technology~~~`,
        fs:  `cpe:2.3:h:lexmark:x34x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.6.1::~~technology~~~`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.7.0::~~technology~~~`,
        fs:  `cpe:2.3:a:huawei:espace_7950:v200r002c00spc600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.8.10::~~technology~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.9.10::~~technology~~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.0.9.31::~~technology~~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.345.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.1.0.0::~~technology~~~`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:12.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.1.1.0::~~technology~~~`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.1.2.10::~~technology~~~`,
        fs:  `cpe:2.3:a:gentoo:qt-unixodbc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.1.3.10::~~technology~~~`,
        fs:  `cpe:2.3:a:sap:cm_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:7.1.3.31::~~technology~~~`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:8.0.1.10::~~technology~~~`,
        fs:  `cpe:2.3:a:gnu:cfengine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:java_sdk:8.0.2.11::~~technology~~~`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jazz_reporting_service:5.0`,
        fs:  `cpe:2.3:a:oracle:10g_enterprise_manager_grid_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jazz_reporting_service:5.0.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jazz_reporting_service:5.0.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jazz_reporting_service:6.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jazz_reporting_service:6.0.1`,
        fs:  `cpe:2.3:a:justsystems:shuriken:2009:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jazz_reporting_service:6.0.2`,
        fs:  `cpe:2.3:a:qemu:qemu:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jdk:1.4.2`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jdk:5.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(21\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jre:1.4.0`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:5.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jre:1.4.2`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jre:1.5.0`,
        fs:  `cpe:2.3:a:redmine:redmine:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:jre:5.0`,
        fs:  `cpe:2.3:a:sap:hybris:5.0.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:9.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:9.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:9.2`,
        fs:  `cpe:2.3:a:oracle:commerce_platform:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:9.2.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:9.3`,
        fs:  `cpe:2.3:a:mollify:mollify:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:9.4`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:9.5`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a5:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:10.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:10.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:kenexa_lcms_premier:10.2`,
        fs:  `cpe:2.3:a:gimp:gimp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:7.1.0`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r3:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:7.1.1`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:7.5.0`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:8.1.0`,
        fs:  `cpe:2.3:a:actividentity:corestreet_server_validation_extension_for_microsoft_internet_information_server:3.1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:8.2.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_3750_metro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:8.5.0`,
        fs:  `cpe:2.3:a:opensis:opensis:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:8.6.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:9.0.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:9.1.0`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:leads:9.1.1`,
        fs:  `cpe:2.3:a:opera:brew_browser:6.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:license_metric_tool:7.2.2`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:license_metric_tool:7.5`,
        fs:  `cpe:2.3:a:apache:hadoop:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:license_metric_tool:9.0`,
        fs:  `cpe:2.3:a:santanderbank:santander_personal_banking:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:license_metric_tool:9.0.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:license_metric_tool:9.1.0.1`,
        fs:  `cpe:2.3:a:trihedral:vtscada:8.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:license_metric_tool:9.1.0.2`,
        fs:  `cpe:2.3:a:sap:cms_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:license_metric_tool:9.2.0`,
        fs:  `cpe:2.3:a:devsaran:fresh:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:license_metric_tool_tad4d_agent:7.2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:linux_on_power:-`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:linux_on_zseries:-`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:linux_on_zseries:-::~~~~x64~`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:linux_on_zseries:-::~~~~x86~`,
        fs:  `cpe:2.3:a:gentoo:xnview:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_cc_mail:-`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_cc_mail:8.0`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:1.0.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sec2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:1.0.1.0`,
        fs:  `cpe:2.3:a:roxio:creator:10.1.207:*:*:*:gold:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:1.0.2.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:4.2.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:2.0.0.0`,
        fs:  `cpe:2.3:a:citrix:metaframe:1.8:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:2.0.1.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:2.0.1.1`,
        fs:  `cpe:2.3:a:brian_cabunac:browser_to_email_phone_message_system:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:2.5.0.1`,
        fs:  `cpe:2.3:a:adobe:photoshop:3.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:2.5.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p373:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:2.5.0.3`,
        fs:  `cpe:2.3:a:red-gate:sql_multiscript:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:3.0.0.0`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:3.0.1.0`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.9.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:3.0.1.1`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.0:-:ipad:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_connections:4.0.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:-`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.0.0:beta_28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:4.6.1`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:9.6.0-051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:4.6.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.12.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:4.6.4`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.510:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.1`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.3`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.4`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.4a`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.5`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.6`,
        fs:  `cpe:2.3:a:trustport:webfilter:5.5.0.2232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.6a`,
        fs:  `cpe:2.3:a:amazon:kindle:4.4.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.7`,
        fs:  `cpe:2.3:a:cisco:telepresence_ip_vcr_2.4:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.7a`,
        fs:  `cpe:2.3:a:altiris:express_deployment_console:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.8`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.51:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.8a`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.9`,
        fs:  `cpe:2.3:a:php:php:5.4.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.9a`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.10`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.14:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:5.0.11`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0`,
        fs:  `cpe:2.3:a:oracle:industry_applications:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.1`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.8:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.1.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.1.2`,
        fs:  `cpe:2.3:a:tenable:nessus:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.1.3`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.2.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.2.2`,
        fs:  `cpe:2.3:a:citrix:ica_program_neighborhood_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.2_cf2`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.3`,
        fs:  `cpe:2.3:a:isc:bind:9.9.9:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.4`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.0.5`,
        fs:  `cpe:2.3:a:divx:h.264_decoder:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5`,
        fs:  `cpe:2.3:a:x:libxext:1.0.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a6\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.2`,
        fs:  `cpe:2.3:a:php:php:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.2.1`,
        fs:  `cpe:2.3:a:quest:spotlight_on_oracle:7.1.0.1481:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.3.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.5\(3.10000.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.4`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.4.1`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:7.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.4.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.4.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:6.5.6`,
        fs:  `cpe:2.3:a:devicelock:devicelock:7.1.36106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.1.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.2`,
        fs:  `cpe:2.3:a:bluez:bluez:5.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.2.2`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.3.0`,
        fs:  `cpe:2.3:a:dell:sonicwall_analyzer:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.3.1`,
        fs:  `cpe:2.3:a:oracle:retail_applications:12.0in:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.4.0`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.5:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.4.1`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:7.0.4.2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.1.2401:unknown:online_windows_server_2003_x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.0`,
        fs:  `cpe:2.3:a:hp:bastille:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.0.1`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.0.2`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.0.2.1`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.0.2.2`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.0.2.3`,
        fs:  `cpe:2.3:o:huawei:s7712_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.0.2.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(2\)xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.0.1`,
        fs:  `cpe:2.3:a:oracle:configurator:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.1`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.1.1`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.1.2`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.13.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.1.3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.1.4`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.1.5`,
        fs:  `cpe:2.3:a:microsoft:infopath:2010:sp1:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.2.0`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.2.1`,
        fs:  `cpe:2.3:a:google:earth:5.2.1.1588:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.2.2`,
        fs:  `cpe:2.3:h:nortel:ip_phone_1150e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.2.3`,
        fs:  `cpe:2.3:a:digium:asterisk:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.2.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3a\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.3.0`,
        fs:  `cpe:2.3:a:rim:blackberry_desktop_software:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.3.1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.0:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.3.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)bc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.3.3`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.3.4`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.3.5`,
        fs:  `cpe:2.3:a:jan_schutze:truc:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:8.5.3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)st1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:9.0.0.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:9.0.1.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino:9.0.1.1`,
        fs:  `cpe:2.3:a:apache:httpclient:4.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_enterprise_server:-`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_enterprise_server:6.5.2`,
        fs:  `cpe:2.3:a:oracle:xvm_virtualbox:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_enterprise_server:6.5.4`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.11:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_inotes_client:-`,
        fs:  `cpe:2.3:a:hp:version_control_agent:6.1.0.841:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_inotes_client:6.5.4`,
        fs:  `cpe:2.3:a:novell:sentinel_log_manager:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_inotes_client:7.0`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_mail_server:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_r5:-`,
        fs:  `cpe:2.3:a:adobe:coldfusion:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_r5:5.0.7a`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:-`,
        fs:  `cpe:2.3:h:hp:storevirtual_4330fc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:4.5`,
        fs:  `cpe:2.3:h:hp:3com_switch:ss4_5500-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:4.6`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:4.6.1`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:5.6.181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:4.6.3`,
        fs:  `cpe:2.3:h:alcatel:omnistack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:4.6.4`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.2:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.394:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.1`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d70:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.2`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.4`,
        fs:  `cpe:2.3:h:rsa:securid:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.6`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.7`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.7a`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.15:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.8`,
        fs:  `cpe:2.3:a:mcafee:change_control:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p148:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:5.0.9a`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:6.0.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:6.0.5`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:6.5.1`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:6.5.4`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r3:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_server:7.0`,
        fs:  `cpe:2.3:a:php:pear:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_access:-`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.5.51.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_access:7.0.1`,
        fs:  `cpe:2.3:a:divx:player:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.0`,
        fs:  `cpe:2.3:a:perl:perl:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.33.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.0.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.0.2_cf2`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.0.4`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.0.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.5.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.5.1`,
        fs:  `cpe:2.3:a:serf_project:serf:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.5.2`,
        fs:  `cpe:2.3:h:novatech:orion5_dnp_slave:1.23.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.5.3`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.5.4`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:6.5.5`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:7.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:7.0.1`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_domino_web_server:7.0.2`,
        fs:  `cpe:2.3:a:monotone:monotone:0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_expeditor:6.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_expeditor:6.1.1`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_expeditor:6.2`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_expeditor:6.2.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_expeditor:6.2.2`,
        fs:  `cpe:2.3:a:boost:boost:1.64.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_expeditor:6.2.3`,
        fs:  `cpe:2.3:a:skype:skype:0.95.0.25:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_forms_viewer:3.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_forms_viewer:3.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_foundations_start:1.0`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_foundations_start:1.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_foundations_start:1.2`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_foundations_start:1.2.2`,
        fs:  `cpe:2.3:a:b-e-soft:artweaver_plus:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_foundations_start:1.2.2:c`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:6.5.6.3`,
        fs:  `cpe:2.3:a:yahoo:yahoo\!_browser:1.4.3:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:7.0.3.1`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:7.0.4.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.0.1.0`,
        fs:  `cpe:2.3:h:linksys:befw11s4:1.37.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.0.2.1`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.0.2.2`,
        fs:  `cpe:2.3:a:bea:jrockit_jre:r27.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.0.2.3`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_server_xi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.0.2.4`,
        fs:  `cpe:2.3:h:cisco:catalyst_2926f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.0.0`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.0.1`,
        fs:  `cpe:2.3:a:yahoo:yui:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.1.0`,
        fs:  `cpe:2.3:a:adobe:robohelp_server:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.1.1`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.1.2`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.1.3`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.1.4`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.1.5`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.2.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.2.1`,
        fs:  `cpe:2.3:h:lexmark:n4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.2.2`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.2.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.2.4`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.3.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.3.1`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.3.2`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.3.3`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.3.4`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:gold:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.3.5`,
        fs:  `cpe:2.3:a:spip:spip:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:8.5.3.6`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:9.0.0.0`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.033_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:9.0.1.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:9.0.1.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.011`,
        fs:  `cpe:2.3:h:trendnet:securview_wireless_internet_camera:tv-ip121wn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.021`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.031`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.041`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.051`,
        fs:  `cpe:2.3:a:athoc:enterprise_notifications_suite:6.1.8.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.061`,
        fs:  `cpe:2.3:a:hp:webinspect:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.101`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.315:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.111`,
        fs:  `cpe:2.3:a:vips:vips:7.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.131`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.141`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.4:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.151`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.161`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.171`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.0.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.181`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.15:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.191`,
        fs:  `cpe:2.3:a:microsoft:word:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.201`,
        fs:  `cpe:2.3:a:git-scm:git:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.211`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.221`,
        fs:  `cpe:2.3:a:airshowbuzz:asb.tv:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.231`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0046:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.241`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.251`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.261`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.179:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.271`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je032a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_inotes:229.281`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_mobile_connect:6.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.6e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_mobile_connect:6.1.1`,
        fs:  `cpe:2.3:a:irods:irods:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_mobile_connect:6.1.1.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_mobile_connect:6.1.2`,
        fs:  `cpe:2.3:h:cisco:ipvc-3520-gw-2b2v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_mobile_connect:6.1.3`,
        fs:  `cpe:2.3:a:x.org:libxrender:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_mobile_connect:6.1.4`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:-`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:0.2`,
        fs:  `cpe:2.3:a:apache:tomcat:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:3.0`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:3.0.0.1`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_51:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:3.0.0.2`,
        fs:  `cpe:2.3:a:iain:gypsy:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:4.2`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:4.2.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:4.2.2`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:4.5`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:4.6`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2_2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:4.6.7a`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:4.6.7h`,
        fs:  `cpe:2.3:a:hp:imc_branch_intelligent_management_system_software_module:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.824.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.1`,
        fs:  `cpe:2.3:a:samba:ppp:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.1.02`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.1a`,
        fs:  `cpe:2.3:a:jease:jease:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.1b`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.1c`,
        fs:  `cpe:2.3:o:apple:watchos:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.2a`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.2b`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.2c`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.3`,
        fs:  `cpe:2.3:a:expressjs:express:3.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.4`,
        fs:  `cpe:2.3:a:tilman_hausherr:xenu_link_sleuth:1.2j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.4a`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.5`,
        fs:  `cpe:2.3:a:gnu:grep:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.5.01`,
        fs:  `cpe:2.3:a:altiris:monitor_solution:6.0.1337:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.5.02`,
        fs:  `cpe:2.3:a:avaya:libsafe:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.6a`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(4\)xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.6a.01`,
        fs:  `cpe:2.3:h:d-link:dir-605l:b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.7`,
        fs:  `cpe:2.3:a:cisco:unified_ip_ivr:6.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.7a`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.8`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.9`,
        fs:  `cpe:2.3:a:t-mobile:my_t-mobile:\@7f0c0030:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.9a`,
        fs:  `cpe:2.3:a:bestpractical:rt:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.10`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.11`,
        fs:  `cpe:2.3:a:sun:linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0.12`,
        fs:  `cpe:2.3:a:google:chrome:6.0.462.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.0a`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:alpha2:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:5.02`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.1:cf1`,
        fs:  `cpe:2.3:a:tibco:spotfire_desktop_language_packs:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.1:cf2`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.1:cf3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.2`,
        fs:  `cpe:2.3:h:asus:rt-ac66r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.2:cf1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.2:cf2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.2.2`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.4`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.0.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.020.20039:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.7.4:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.1`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.3`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.3.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.4.1`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.5.5.438:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.4.3`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.5`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.5.1`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.5.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.5.3`,
        fs:  `cpe:2.3:a:novell:groupwise:2012:sp1_hp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.6`,
        fs:  `cpe:2.3:h:hp:750_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.6.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.6.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:6.5.6.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0`,
        fs:  `cpe:2.3:a:gnu:wget:1.11.4-1:*:*:*:gnuwin32:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.1.1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.2`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.2.1`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.2.2`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.2.3`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.3`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.3.1`,
        fs:  `cpe:2.3:o:juniper:junos:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.4`,
        fs:  `cpe:2.3:a:hp:mercury_testdirector_for_quality_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.4.0`,
        fs:  `cpe:2.3:a:ibm:qradar_risk_manager:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.4.1`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:7.0.4.2`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0`,
        fs:  `cpe:2.3:a:mcafee:remote_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.0`,
        fs:  `cpe:2.3:h:hp:trucluster_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.2`,
        fs:  `cpe:2.3:a:citrix:access_management_console_diagnostics:4.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.2.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.2.1`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.2.2`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.4:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.2.3`,
        fs:  `cpe:2.3:a:tenable:nessus:6.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.2.4`,
        fs:  `cpe:2.3:a:symantec:backupexec_system_recovery:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.2.5`,
        fs:  `cpe:2.3:o:novell:netware:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.0.2.6`,
        fs:  `cpe:2.3:h:cisco:asa_5500:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.0.0`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:gm45_gs45_pm45_sinit_51.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.0.1`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.1.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.406.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.1.1`,
        fs:  `cpe:2.3:a:dell:server_e-support_tool:1.0.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.1.2`,
        fs:  `cpe:2.3:a:minitab:bootstrapper:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.1.3`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.4.2_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.1.4`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.1.5`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.2.0`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.2.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.2.2`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.2.3`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.3`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.3.1`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.3.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.3.3`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.3.4`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:a:core:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.3.5`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.3.6`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:8.5.4`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:9.0.0.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:9.0.1.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i3\(3.78\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:9.0.1.1`,
        fs:  `cpe:2.3:a:progress:objectstore:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:r5`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes:r6`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0.1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0.2`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0.3`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0.4`,
        fs:  `cpe:2.3:a:freeradius:freeradius:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0.5`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:3.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0.9a`,
        fs:  `cpe:2.3:a:teknopoint:a_king_sperm_by_dr._seema_rao:0.63.13384.23020:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0.10`,
        fs:  `cpe:2.3:a:dell:dvdsentry:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:5.0.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:6.0`,
        fs:  `cpe:2.3:a:apache:mod_python:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_client:r5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_r5:-`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_sametime:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:4.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_sametime:0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_sametime:3.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_sametime:5.1.1`,
        fs:  `cpe:2.3:a:adobe:cmaps_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_sametime:7.5.70413`,
        fs:  `cpe:2.3:a:present-technologies:graffit_it:1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_sametime:8.0.80407`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_sametime:8.0.80822`,
        fs:  `cpe:2.3:a:citrix:metaframe_password_manager:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_sametime:8.5.1.20100709-1631::~~advanced_embedded~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.0`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.0.1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.0.1.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.0.1.3`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.15.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.21:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.0.1`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.0.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.1.1`,
        fs:  `cpe:2.3:o:cisco:conference_connection:1.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.1.2`,
        fs:  `cpe:2.3:a:fiddler2:fiddler2:2.3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.1.3`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.2.1`,
        fs:  `cpe:2.3:a:sambar:sambar_server:4.4:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.3.1`,
        fs:  `cpe:2.3:a:netscape:communicator:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.3.2`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.3.3`,
        fs:  `cpe:2.3:h:huawei:ar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_notes_traveler:8.5.3.3:interim_fix_1`,
        fs:  `cpe:2.3:h:enterasys:ang_3000_7050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_protector_for_mail_security:2.1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_protector_for_mail_security:2.5`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_protector_for_mail_security:2.5.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_protector_for_mail_security:2.8`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_protector_for_mail_security:2.8.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_quickr_for_domino:8.1.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_quickr_for_domino:8.2.0`,
        fs:  `cpe:2.3:a:atlassian:jira:2.2.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_quickr_for_domino:8.5.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_quickr_for_domino:8.5.1`,
        fs:  `cpe:2.3:a:isc:bind:9.4:b1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:-`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:1.5`,
        fs:  `cpe:2.3:a:webtrends:data_retention_services:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:2.5`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:7.0`,
        fs:  `cpe:2.3:a:redhat:rsync:2.5.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:7.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.0:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:7.5.0.1`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:7.5.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.9.0.1210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:7.5.1.1`,
        fs:  `cpe:2.3:a:samba:samba:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:7.5.1.2`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5:b:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.0.1`,
        fs:  `cpe:2.3:a:dell:system_manager:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.0.1.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.0.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.290:update29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.0.2.1`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:3.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.5`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.5.1`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.5.1.1`,
        fs:  `cpe:2.3:a:vmware:zimbra_desktop:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.5.2`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime:8.5.2.1`,
        fs:  `cpe:2.3:a:hp:bpdfax:70.0.184.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_sametime_server:-`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.0.0:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:lotus_smartsuite:-`,
        fs:  `cpe:2.3:a:open_source_development_team:sthttpd:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_symphony:1.3`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_symphony:1.3.0.20090908.0900`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_symphony:3.0.0`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2000i:sp1:unlocked:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_symphony:3.0.0.1`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_symphony:3.0.0.2`,
        fs:  `cpe:2.3:h:cisco:gss_4480_global_site_selector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_symphony:3.0.0.3`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_symphony:3.0.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.02.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotus_widget_factory:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.442:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:lotuslive_meetings_for_ibm:8.2.1`,
        fs:  `cpe:2.3:a:iss:realsecure_network:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:m15:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:m32:-`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:m49:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:m66:-`,
        fs:  `cpe:2.3:a:phpblogger:php-blogger:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:m80:-`,
        fs:  `cpe:2.3:a:ibm:api_management:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.2.0.0`,
        fs:  `cpe:2.3:h:cisco:sf300-24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.2.0.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:7.1.1:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.2.1.0`,
        fs:  `cpe:2.3:o:huawei:s9306e_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.2.1.12`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.3.2.0`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:a5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.3.2.1`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.3.2.8`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.4.0.0`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.4.0.2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.9p23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.4.1.0`,
        fs:  `cpe:2.3:a:intel:msso:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.4.1.6`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.4.2.0`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:10.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.4.2.7`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.5.0.0`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:2.3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.5.0.1`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.5.2.0`,
        fs:  `cpe:2.3:a:python:python:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.5.2.3`,
        fs:  `cpe:2.3:a:oracle:database_server:8.1.7.4:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.5.3.0`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:8.6.2:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.5.3.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.5.3.8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:7.5.3.9`,
        fs:  `cpe:2.3:h:enterasys:2h252-25r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.0.0.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.5:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.0.0.2`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.1.0.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.1.0.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.1.0.7`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.1.1.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_4507r\&#43;e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.1.1.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.0`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-30-\/f:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.5`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.6`,
        fs:  `cpe:2.3:a:webmin:usermin:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.7`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.8`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.9`,
        fs:  `cpe:2.3:a:sympa:sympa:0.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.10`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.11`,
        fs:  `cpe:2.3:h:apple:airport_express:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.12`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.2.0.13`,
        fs:  `cpe:2.3:a:roxio:creator_copy:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.5.0.0`,
        fs:  `cpe:2.3:a:ibm:websphere_cast_iron_solution:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.5.0.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.5.0.2`,
        fs:  `cpe:2.3:a:hp:business_process_monitor:8.4.316:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.5.0.3`,
        fs:  `cpe:2.3:a:gnu:queue:1.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.5.0.4`,
        fs:  `cpe:2.3:o:redhat:linux_advanced_workstation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.5.0.5`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.7:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.5.0.6`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.9.0\(198\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.5.0.7`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.6.0.0`,
        fs:  `cpe:2.3:a:apache:couchdb:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.6.0.2`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.6.0.3`,
        fs:  `cpe:2.3:a:adobe:photoshop:5.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.6.0.4`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.6.0.5`,
        fs:  `cpe:2.3:a:ca:etrust_audit_client:1.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.6.0.6`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.2.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:8.6.0.7`,
        fs:  `cpe:2.3:h:cisco:sg500x-24p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.0.0.0`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.0.0.1`,
        fs:  `cpe:2.3:a:appbelle:top_hangover_cures:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.0.0.2`,
        fs:  `cpe:2.3:a:forgerock:openam:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.0.0.3`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.0.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.1.0.0`,
        fs:  `cpe:2.3:h:hp:laserjet_2420:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.1.0.2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.1.0.3`,
        fs:  `cpe:2.3:h:f5:viprion_performance_blade_100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.1.0.4`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.1.1.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_operations:9.1.1.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.6:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.0.0.0`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.0.2.0`,
        fs:  `cpe:2.3:h:cisco:wireless_control_system:4.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.0.2.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.1.0.0`,
        fs:  `cpe:2.3:a:justsystems:rekishimail_bakumatsushishi_no_missho:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.1.0.3`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.2.1.0`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.2.1.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.2.3.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.2.3.3`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.0\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.3.0.0`,
        fs:  `cpe:2.3:o:virtualaccess:gw6110a_firmware:9.09.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.3.0.2`,
        fs:  `cpe:2.3:a:hp:secure_web_server_for_tru64:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.3.1.0`,
        fs:  `cpe:2.3:o:smc:smc8024l2_switch_firmware:2.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.3.1.5`,
        fs:  `cpe:2.3:a:grillingwithrich:grilling_with_rich:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.5.0.0`,
        fs:  `cpe:2.3:o:redhat:linux:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.5.0.1`,
        fs:  `cpe:2.3:a:sun:jre:6.0.170:update17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.5.1.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.5.1.8`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.5.1.9`,
        fs:  `cpe:2.3:a:infinitewp:infinitewp_admin_panel:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.5.2.0`,
        fs:  `cpe:2.3:a:ibm:rational_performance_tester:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:7.5.2.2`,
        fs:  `cpe:2.3:a:google:v8:3.23.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.0.0.0`,
        fs:  `cpe:2.3:a:appytimes:mr_whippet_-_yorkshire_ice:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.0.0.8`,
        fs:  `cpe:2.3:a:gfi:gfi_languard_reportpack:9.0.2009.709:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.1.0.4`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.1.0.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.1.0.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.1.0.7`,
        fs:  `cpe:2.3:a:gnu:bash:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.0`,
        fs:  `cpe:2.3:a:nvidia:pvsonydll:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:21.0.0.242:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.5`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.3:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.7`,
        fs:  `cpe:2.3:a:microp_project:microp:0.1.1.1600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.8`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.9`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.10`,
        fs:  `cpe:2.3:a:otrs:otrs:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.2.0.11`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.5.0.0`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.5.0.1`,
        fs:  `cpe:2.3:a:apache:subversion:0.37.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.5.0.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.5.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.5.0.4`,
        fs:  `cpe:2.3:a:brocade:data_center_fabric_manager:10.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.5.0.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.5.0.6`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.5.0.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.0`,
        fs:  `cpe:2.3:a:idevspot:isupport:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.2`,
        fs:  `cpe:2.3:a:citrix:online_plug-in:11.2.0.31560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.3`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.03.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.4`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.5`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.6`,
        fs:  `cpe:2.3:o:yahama:rt60w:5.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.8`,
        fs:  `cpe:2.3:a:opnet:it_guru:16.0.0.10353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.9`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.10`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:8.6.0.11`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_light:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.0.0.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.0.0.1`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.0.0.2`,
        fs:  `cpe:2.3:h:huawei:ne80e:v600r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.0.0.3`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.0.0.4`,
        fs:  `cpe:2.3:a:gentoo:xnview:1.90.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.0`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.1`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.2`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.3`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.13.0.knots20160814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.5`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.6`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.6249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.7`,
        fs:  `cpe:2.3:a:tibco:slingshot:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.8`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.9`,
        fs:  `cpe:2.3:a:magzter:dealside_institutional:3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.0.10`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.1\(6b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.1`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.1.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5208l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.1.1`,
        fs:  `cpe:2.3:o:siemens:cfmw1025_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.1.2`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.1.3`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.1.4`,
        fs:  `cpe:2.3:a:apache:wicket:6.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.2`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:3.26.651.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:9.1.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:marketing_platform:10.0`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-11-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mashups_center:3.0.0.1`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_anywhere:7.5.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_anywhere:7.5.1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.0:cf01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_anywhere:7.5.1.2`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.1`,
        fs:  `cpe:2.3:a:php:php:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.2`,
        fs:  `cpe:2.3:o:huawei:usg9500_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)s0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.6`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.6.1`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.7`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.2.8`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:6.5`,
        fs:  `cpe:2.3:o:cisco:ios:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.2.00096:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1`,
        fs:  `cpe:2.3:a:microsoft:word:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.1`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.2`,
        fs:  `cpe:2.3:a:stunnel:stunnel:4.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.3`,
        fs:  `cpe:2.3:a:4t-niagara:tray_minimizer_free:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.5`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.6`,
        fs:  `cpe:2.3:a:microsoft:learning_essentials:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.7`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.8`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.9`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.11`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.12`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.20:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.1.13`,
        fs:  `cpe:2.3:a:google:chrome:5.0.384.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.1.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5\(1\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.0`,
        fs:  `cpe:2.3:a:mautic:mautic:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.2:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.2`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.6.0.626:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.3`,
        fs:  `cpe:2.3:a:horde:groupware:1.0:rc1:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.4`,
        fs:  `cpe:2.3:a:oracle:siebel_ui_framework:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.5`,
        fs:  `cpe:2.3:a:microsoft:html_help:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.6`,
        fs:  `cpe:2.3:a:tuxfamily:vhffs:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.7`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.8`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.9`,
        fs:  `cpe:2.3:a:twibright:links:2.7:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.5.0.10`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.6`,
        fs:  `cpe:2.3:a:joyent:node.js:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.6.0.0`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.6.0.1`,
        fs:  `cpe:2.3:a:bea:weblogic_mobility_server:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.6.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(3\)m2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management:7.6.0.3`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:6.2.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.1`,
        fs:  `cpe:2.3:a:drupal:drupal:6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5`,
        fs:  `cpe:2.3:a:seotoaster:seotoaster:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.2:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.3`,
        fs:  `cpe:2.3:a:schneider-electric:concept:2.6:sr7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.4`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.5`,
        fs:  `cpe:2.3:a:ca:etrust_audit_irecorder:1.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.6`,
        fs:  `cpe:2.3:a:google:chrome:12.0.722.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.7`,
        fs:  `cpe:2.3:a:adobe:dreamweaver:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.5.0.8`,
        fs:  `cpe:2.3:a:oracle:apex:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_asset_management_essentials:7.6`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.1\(6\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_energy_optimization:7.1`,
        fs:  `cpe:2.3:a:opentext:enterprise_library_content_archiving:2.1.0.271:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:-`,
        fs:  `cpe:2.3:a:compaq:trucluster:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.5`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.5.0.0`,
        fs:  `cpe:2.3:a:apache:apr-util:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.5.0.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.5.0.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.939.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.5.0.3`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.5.0.4`,
        fs:  `cpe:2.3:a:debian:qpopper:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.5.0.5`,
        fs:  `cpe:2.3:a:xoops:xoops:2.5.6:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_government:7.5.0.6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.1`,
        fs:  `cpe:2.3:a:quagga:quagga:0.97.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p432:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.5.0.0`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.5.0.1`,
        fs:  `cpe:2.3:a:apple:cups:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.5.0.2`,
        fs:  `cpe:2.3:h:cisco:aironet_1850e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.5.0.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.11.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.5.0.4`,
        fs:  `cpe:2.3:a:jease:jease:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.5.0.5`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.5.0.6`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_life_sciences:7.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.11.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:-`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.1`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.5`,
        fs:  `cpe:2.3:a:apache:poi:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.5.0.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.5.0.1`,
        fs:  `cpe:2.3:o:microsoft:windows_98:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.5.0.2`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(4\)es25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.5.0.3`,
        fs:  `cpe:2.3:h:schneider-electric:bmxp342030:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.5.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.5.0.5`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_nuclear_power:7.5.0.6`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.1`,
        fs:  `cpe:2.3:a:x:libxres:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.5`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.5.0.0`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.5.0.1`,
        fs:  `cpe:2.3:a:microweber:microweber:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.5.0.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.5.0.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.5.0.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.5.0.5`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_oil_and_gas:7.5.0.6`,
        fs:  `cpe:2.3:o:yealink:voip_phone_firmware:28.72.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:-`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s7502e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.5`,
        fs:  `cpe:2.3:a:webmin:usermin:1.470:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.5.0.0`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.5.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.5.0.2`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.00:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.5.0.3`,
        fs:  `cpe:2.3:a:mcafee:personal_firewall_plus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.5.0.4`,
        fs:  `cpe:2.3:h:cisco:675_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.5.0.5`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_transportation:7.5.0.6`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:-`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.1`,
        fs:  `cpe:2.3:a:microsoft:office:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.5`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.5.0.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.5.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(6b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.5.0.2`,
        fs:  `cpe:2.3:h:kodak:professional_8670_ps_thermal_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.5.0.3`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.8f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.5.0.4`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp5:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.5.0.5`,
        fs:  `cpe:2.3:a:smartertools:smarterstats:5.3.3819:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_for_utilities:7.5.0.6`,
        fs:  `cpe:2.3:a:apache:struts:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_industry_solutions:7.5.0.0`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_industry_solutions:7.5.0.1`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:16.0.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_industry_solutions:7.5.0.2`,
        fs:  `cpe:2.3:h:supermicro:x9drff:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_industry_solutions:7.5.0.3`,
        fs:  `cpe:2.3:a:altiris:console_data:6.5.1156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_industry_solutions:7.5.0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.650:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_industry_solutions:7.5.0.5`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.567:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_industry_solutions:7.5.0.6`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_integration_composer:6.2.0.0`,
        fs:  `cpe:2.3:a:posh_project:posh:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_service_desk:6.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_service_desk:6.2.8`,
        fs:  `cpe:2.3:a:livetecs:timeline:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_service_desk:7.1.1.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_service_desk:7.1.1.8`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30244:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_service_desk:7.1.1.11`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:maximo_service_desk:7.1.1.12`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p94:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:mcs-7815-1000:-`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:mcs-7815i-2.0:-`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:mcs-7835i-2.4:-`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_isas:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:mcs-7835i-3.0:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:messagesight:-`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.2.072.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:messagesight_jms_client:1.0.0.0`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:messagesight_jms_client:1.0.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:messagesight_jms_client:1.1.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.0.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.1:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.0.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.0.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.0.3`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.5.0`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.5.1`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.6.0`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.6.1`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:5.0.6.2`,
        fs:  `cpe:2.3:a:gnome:evolution:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:6.0.0.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:6.0.0.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.709.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:6.0.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:6.1.0.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mobile_foundation:6.1.0.1`,
        fs:  `cpe:2.3:a:forgerock:openam:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_agent_for_unix_logs:6.2.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_agent_for_unix_logs:6.2.1`,
        fs:  `cpe:2.3:h:symantec:firewall_vpn_appliance_200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_agent_for_unix_logs:6.2.2`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.1.1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_agent_for_unix_logs:6.2.3`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_server_%28ms%29_and_shared_libraries_%28ax%29:6.2.0`,
        fs:  `cpe:2.3:a:docker:docker:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_server_%28ms%29_and_shared_libraries_%28ax%29:6.2.1`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:6.0.304.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_server_%28ms%29_and_shared_libraries_%28ax%29:6.2.2`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.154:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_server_%28ms%29_and_shared_libraries_%28ax%29:6.2.3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:monitoring_server_%28ms%29_and_shared_libraries_%28ax%29:6.3.0`,
        fs:  `cpe:2.3:a:novell:groupwise_messenger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:mq_appliance_m2000:8.0.0.3`,
        fs:  `cpe:2.3:h:logitech:quickcam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:multi-enterprise_integration_gateway:1.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:navio_nc_browser:-`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce:-`,
        fs:  `cpe:2.3:a:social_microblogging_pro_project:social_microblogging_pro:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce:2.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce:3.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce:3.1`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:9.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce:3.1.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce:3.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce_hosting_server:-`,
        fs:  `cpe:2.3:o:juniper:ive_os:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce_hosting_server:3.1.1`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce_hosting_server:3.1.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce_hosting_server:3.2`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce_pro:-`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.2.0.820:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.commerce_start:-`,
        fs:  `cpe:2.3:a:santafox:santafox:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.data:-`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.data:7.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:net.data:7.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:netezza:6.0.5`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.4d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:netezza:6.0.8`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:netezza:7.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp4:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:netezza_performance_portal:2.0.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:netezza_performance_portal:2.0.0.1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:netezza_performance_portal:2.0.0.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:netezza_performance_portal:2.0.0.3`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:netezza_performance_portal:2.0.0.4`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.16:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:netfinity_remote_control:-`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:network_appliance_data_ontap:-`,
        fs:  `cpe:2.3:a:apache:cxf:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:network_appliance_data_ontap:7.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:network_appliance_data_ontap:7.1`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.6:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:network_appliance_data_ontap:7.1.0.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:network_appliance_data_ontap:7.2:rc1`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:network_appliance_data_ontap:7.2:rc2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:network_appliance_data_ontap:7.2:rc3`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.10.1014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:network_station_manager:-`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:notes_traveler:9.0.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.9:rc2:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:notes_traveler_companion:1.0::~~~windows_phone~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(3e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:notes_traveler_companion:1.1::~~~windows_phone~~`,
        fs:  `cpe:2.3:a:roxio:recordnow_copy:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.0.0`,
        fs:  `cpe:2.3:a:compaq:open_san_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.0.1`,
        fs:  `cpe:2.3:a:tenable:nessus:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.0.2`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.0.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.0.4`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc8:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.0.5`,
        fs:  `cpe:2.3:h:google:mini_search_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.1.0`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.2.0`,
        fs:  `cpe:2.3:a:josh_fradley:burden:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.2.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.2.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.2.3`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.2.4`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:5.5.2.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.0.1.1`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.1.65.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.0.1.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.0.1.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.0.1.4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.0.1.5`,
        fs:  `cpe:2.3:a:gajim:gajim:0.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.1.0.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.1.0.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.1.0.1.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.2.0.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.2.1.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:6.2.1.1`,
        fs:  `cpe:2.3:a:lenovo:system_update:5.06.0027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:7.0.0.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:7.0.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:openpages_grc_platform:7.0.0.2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:operational_decision_manager:7.5`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.7:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:operational_decision_manager:8.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.1\(4\)er1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:operational_decision_manager:8.5`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:optim_performance_manager:4.1.1`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:optim_performance_manager:4.1.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:optim_performance_manager:5.1.0`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_explorer:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:optim_workload_replay:2.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:optim_workload_replay:2.1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:optim_workload_replay:2.1.0.2`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_390:-`,
        fs:  `cpe:2.3:a:microsoft:access:2002:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:-`,
        fs:  `cpe:2.3:a:unadf_project:unadf:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:4.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:5.2`,
        fs:  `cpe:2.3:a:rockwellautomation:factorytalk_services_platform:cpr9:sr5.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:v4r2`,
        fs:  `cpe:2.3:a:ibm:tivoli_common_reporting:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:v4r2m0`,
        fs:  `cpe:2.3:a:roxio:recordnow_data:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:v4r3`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:v4r4`,
        fs:  `cpe:2.3:a:skype:skype:0.98.0.28:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:v4r5`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:v5r1`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:v5r2m0`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os_400:v5r3m0`,
        fs:  `cpe:2.3:h:avaya:cajun_m770-atm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:os2:-`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6a:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:os2_ftp_server:-`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:os2_ftp_server:4.0`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:3.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:os2_ftp_server:4.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:os2_ftp_server:4.3`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:packaging_utility:1.7.4.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:packaging_utility:1.8.0.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:packaging_utility:1.8.1.0`,
        fs:  `cpe:2.3:a:apache:rave:0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:packaging_utility:1.8.2.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:packaging_utility:1.8.2.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:packaging_utility:1.8.3.0`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0g_pk4_bl22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:parallel_environment:-`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.6\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:parallel_environment:3.2`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_at\&amp;t_wifi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:parallel_environment:4.1`,
        fs:  `cpe:2.3:h:hp:j9587a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.2`,
        fs:  `cpe:2.3:a:zoneminder:zoneminder:1.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.3`,
        fs:  `cpe:2.3:a:gannett:lansing_state_journal_print:6.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.5`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.175.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.7`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.5sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.8`,
        fs:  `cpe:2.3:a:macromedia:flash_player:7.0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.9`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.10`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.11`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.12`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.13`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:me:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.14`,
        fs:  `cpe:2.3:h:axis:700_network_document_server:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.15`,
        fs:  `cpe:2.3:a:cisco:webex_node_for_mcs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:6.0.16`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:personal_communications:12.0.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.441.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:platform_symphony:5.2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.412.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:platform_symphony:5.2::~~developer~~~`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:platform_symphony:6.1`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_298_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:platform_symphony:6.1.0::~~developer~~~`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:platform_symphony:6.1.0.1`,
        fs:  `cpe:2.3:a:adobe:air:20.0.0.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:platform_symphony:6.1.1`,
        fs:  `cpe:2.3:a:adobe:fireworks_cs5:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:platform_symphony:6.1.1::~~developer~~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9110-51a`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9110-510`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:ga:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9111-285`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9111-520`,
        fs:  `cpe:2.3:a:perlexpress:perl_express:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9113-550`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:11.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9115-505`,
        fs:  `cpe:2.3:o:arbiter:power_sentinel_1133a_firmware:11jun2012:rev421:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9116-561`,
        fs:  `cpe:2.3:a:google:chrome:6.0.470.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9117-570`,
        fs:  `cpe:2.3:a:microsoft:entourage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9118-575`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9123-710`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9124-720`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9131-52a`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9133-55a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9405-520`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9406-520`,
        fs:  `cpe:2.3:a:bioinformatics:ordersys:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9406-525`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9406-550`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9406-570`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:power_5:9407-515`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_201_201`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.40.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_202_201`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_219_201`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_222_201`,
        fs:  `cpe:2.3:h:avaya:tn2602ap_ip_media_resource_320_circuit_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_233_201`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_258_201`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_259_201`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:15.0\(938\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_261_201`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_284_201`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.427:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_298_201`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_299_201`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)mr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_320_201`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:165:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_332_201`,
        fs:  `cpe:2.3:a:hp:unload:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_338_201`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_358_201`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_371`,
        fs:  `cpe:2.3:a:docker:docker:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_382_382`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(10\)w5\(18f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_403_382`,
        fs:  `cpe:2.3:a:lxml:lxml:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_415_382`,
        fs:  `cpe:2.3:a:divx:codec:6.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_417`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_418`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:power_5_system_firmware:sf240_418_382`,
        fs:  `cpe:2.3:a:survey.com:survey.com_mobile:3.2.16:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powerha_system_mirror:-`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powerkvm:2.1`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powerkvm:2.1.0.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.57.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powerkvm:2.1.1.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powerkvm:2.1.1.2`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powerkvm:2.1.1.3`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powerkvm:3.1`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powerkvm:3.1.0.1`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.0.0::~~express~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.0.0::~~standard~~~`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.14:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.0.1::~~express~~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.0.1::~~standard~~~`,
        fs:  `cpe:2.3:a:drupal:drupal:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.0.2::~~express~~~`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.0.2::~~standard~~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.0.3::~~express~~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.0.3::~~standard~~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.1.0:-:~-~express~~~:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.1.0:-:~-~standard~~~:-`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.1.1:-:~-~express~~~:-`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:powervc:1.2.1.1:-:~-~standard~~~:-`,
        fs:  `cpe:2.3:a:cete:dynamicpdf_for_.net:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:proventia_network_ips_gx5008:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:proventia_network_ips_gx5008:1.5`,
        fs:  `cpe:2.3:a:perl:perl:0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:proventia_network_ips_gx5108:-`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.5.1:sp5:alpha:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:proventia_network_ips_gx5108:1.3`,
        fs:  `cpe:2.3:h:tp-link:tl-wr841nd_\(10.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.0.0.0`,
        fs:  `cpe:2.3:a:busybox:busybox:0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.0.0.1`,
        fs:  `cpe:2.3:a:elsop:linkscan:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.0.0.2`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.0.0.3`,
        fs:  `cpe:2.3:a:justsystems:just_smile:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.0.0.4`,
        fs:  `cpe:2.3:a:google:urchin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.1.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.1.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.1.0.2`,
        fs:  `cpe:2.3:a:roxio:recordnow_data:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.1.0.3`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:1.1.0.4`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureapplication_system:2.0.0.0`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:pureedge_viewer:6.5.0`,
        fs:  `cpe:2.3:a:redhat:cluster_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.1`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.3`,
        fs:  `cpe:2.3:a:opalvoip:portable_tool_library:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.4`,
        fs:  `cpe:2.3:a:typo3:typo3:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.5`,
        fs:  `cpe:2.3:a:netease:netease_cloudalbum:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.7`,
        fs:  `cpe:2.3:a:webizz:alma_corinthiana:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_incident_forensics:7.2.8`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_risk_manager:7.1.0`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.99:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_risk_manager:7.2.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.1\(6b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_risk_manager:7.2.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_risk_manager:7.2.2`,
        fs:  `cpe:2.3:h:cisco:c5000rsm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_risk_manager:7.2.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.532.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_risk_manager:7.2.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p408:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.0.0`,
        fs:  `cpe:2.3:a:softmotion3d:softmotion:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.0.1`,
        fs:  `cpe:2.3:a:libmimedir_project:libmimedir:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.1.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.1.0:mr1`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_edp:2.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.2.0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.2.1`,
        fs:  `cpe:2.3:a:schneider-electric:proclima:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.2.2`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_agent_framework:3.3.1048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.2.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.2.4`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.2.5`,
        fs:  `cpe:2.3:a:pd-admin:pd-admin:4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.2.6`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_security_information_and_event_manager:7.2.7`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.034:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_vulnerability_manager:7.2.0`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_vulnerability_manager:7.2.1`,
        fs:  `cpe:2.3:a:siemens:scalance_s_firmware:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_vulnerability_manager:7.2.2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_vulnerability_manager:7.2.3`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:qradar_vulnerability_manager:7.2.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:quickfile:1.0.0.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:5.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:quickfile:1.1.0.0`,
        fs:  `cpe:2.3:h:buffalotech:whr-ampg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:quickfile:1.1.0.1`,
        fs:  `cpe:2.3:o:juniper:junos:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:r07:-`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:racf:-`,
        fs:  `cpe:2.3:a:keepass:keepass:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_agent_controller:7.0.3.3`,
        fs:  `cpe:2.3:a:microsoft:metadirectory_services:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:5.2::enterprise`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:5.4::enterprise`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:10.6_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:5.5.0::enterprise`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:5.5.0.1::enterprise`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:5.5.0.2::enterprise`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:5.6.0::enterprise`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:5.6.0.3::enterprise`,
        fs:  `cpe:2.3:a:smartcat:our_team_showcase:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.0.0::enterprise`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.0.0.1::enterprise`,
        fs:  `cpe:2.3:a:google:chrome:5.0.361.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.0.0.2::enterprise`,
        fs:  `cpe:2.3:a:digium:asterisk:13.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.0.0.3::enterprise`,
        fs:  `cpe:2.3:a:plone:plone:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.0.1::enterprise`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.261.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.0.1.1::enterprise`,
        fs:  `cpe:2.3:a:teradata:dynamic_workload_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.5.0::enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.5.0.0::enterprise`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan:8.5.0.1::enterprise`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan_source:8.0.0.0`,
        fs:  `cpe:2.3:a:microsoft:lync:2010:*:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan_source:8.0.0.1`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan_source:8.0.0.2`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan_source:8.5.0.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_appscan_source:8.5.0.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec:13.0.5204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.1`,
        fs:  `cpe:2.3:h:hp:0235a32e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p69:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.3`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.5`,
        fs:  `cpe:2.3:a:compaq:sanworks_resource_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.6`,
        fs:  `cpe:2.3:a:logitech:lws_twitter:13.20.1166.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.7`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.8`,
        fs:  `cpe:2.3:a:sun:jre:6.0.240:update24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_asset_analyzer:6.1.0.9`,
        fs:  `cpe:2.3:a:lazgosoftware:keystore_explorer:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_automation_framework:3.0`,
        fs:  `cpe:2.3:a:sun:java_system_access_manager:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_automation_framework:3.0.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.34:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_automation_framework:3.0.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_desk:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_automation_framework:3.0.0.3`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_automation_framework:3.0.0.4`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_automation_framework:3.0.0.5`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_build_forge:7.1.0`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.0:sp1b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_change:4.7`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_change:5.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_change:5.2`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_change:5.3`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:2.1.1063`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.0.1.1`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1`,
        fs:  `cpe:2.3:h:huawei:eudemon1000e-u:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.0.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1`,
        fs:  `cpe:2.3:a:netscape:communicator:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.2`,
        fs:  `cpe:2.3:a:isc:bind:9.8.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p330:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.4`,
        fs:  `cpe:2.3:a:innominate:mguard_smart:hw-101020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.5`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.6`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.7`,
        fs:  `cpe:2.3:a:quagga:quagga:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.8`,
        fs:  `cpe:2.3:h:cisco:vpn_3005_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.1.9`,
        fs:  `cpe:2.3:a:cross-rss_plugin_project:wp-cross-rss:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.1`,
        fs:  `cpe:2.3:a:gnu:automake:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.4`,
        fs:  `cpe:2.3:o:sun:java_desktop_system:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.5`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.7`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.9`,
        fs:  `cpe:2.3:a:conrad_hotel_project:conrad_hotel:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.10`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.12`,
        fs:  `cpe:2.3:a:redhat:ddskk-xemacs:11.6.0-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.15`,
        fs:  `cpe:2.3:a:corestreet:certificate_validation_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:7.1.2.16`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p357:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0`,
        fs:  `cpe:2.3:a:htc:evo_3d_software:1.11.651.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.3`,
        fs:  `cpe:2.3:a:symantec:vrtsccg:5.0.442:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.4`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_broker:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.5`,
        fs:  `cpe:2.3:o:novell:leap:42.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.6`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.7`,
        fs:  `cpe:2.3:a:haxx:curl:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.8`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:6.21.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.0.9`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.1`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.1.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.453:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase:8.0.1.2`,
        fs:  `cpe:2.3:a:envialosimple:email_marketing_y_newsletters:1.97:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase_lt:2.1.1063`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearcase_lt:7.0.1.1`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix_5570_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:-`,
        fs:  `cpe:2.3:a:triumfant:triumfant_agent:1.1.3.3165:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:2.1.1063`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:2.1.1112`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)sl1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:5.00`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:5.20`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:6.00`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:6.10`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:6.12`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:7:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:6.13`,
        fs:  `cpe:2.3:h:hp:j9588a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:6.14`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:6.15`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:6.16`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.609.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.0`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.0.0.0`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.0.0.1`,
        fs:  `cpe:2.3:a:docker:docker:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.0.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.0.1.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.0.1.1-ifix01`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.0.1`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.0.2`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1`,
        fs:  `cpe:2.3:a:isc:bind:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.1`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.3`,
        fs:  `cpe:2.3:a:siemens:scalance_s_firmware:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.4`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.5`,
        fs:  `cpe:2.3:a:juniper:junos_space:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.6`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x2270_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.7`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.8`,
        fs:  `cpe:2.3:a:apple:itunes:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.1.9`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2`,
        fs:  `cpe:2.3:a:logitech:ereg:1.20.138.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.1`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.3`,
        fs:  `cpe:2.3:a:vmware:gsx_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.4`,
        fs:  `cpe:2.3:a:rack_project:rack:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.5`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.7`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.8`,
        fs:  `cpe:2.3:h:linksys:befsru31:1.40.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.9`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.40.5106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.10`,
        fs:  `cpe:2.3:a:vmware:capacityiq:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.11`,
        fs:  `cpe:2.3:o:ibm:global_console_manager_16_firmware:1.20.0.22575:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:7.1.2.12`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0`,
        fs:  `cpe:2.3:a:phplist:phplist:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.2`,
        fs:  `cpe:2.3:a:sun:sunvts:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.3`,
        fs:  `cpe:2.3:a:salome-platform:salome:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.4`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.5`,
        fs:  `cpe:2.3:a:zooeffect:zooeffect:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.6`,
        fs:  `cpe:2.3:a:vmware:view:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.8`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.9`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.10`,
        fs:  `cpe:2.3:a:arellia:arellia_application_control_report_pack:6.1.1202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.11`,
        fs:  `cpe:2.3:a:jessgramp:minicms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.12`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.08:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.13`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.14`,
        fs:  `cpe:2.3:a:vtiger:crm:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.15`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.14:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.0.16`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1008:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1.2`,
        fs:  `cpe:2.3:a:google:admob:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1.3`,
        fs:  `cpe:2.3:h:juniper:netscreen-idp:3.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1.4`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1.5`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.9:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1.8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:8.0.1.9`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:2007`,
        fs:  `cpe:2.3:a:ibm:director_agent:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_clearquest:2008`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:3.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:3.0.1`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:3.0.1.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:3.0.1.2`,
        fs:  `cpe:2.3:o:cisco:catos:3.0\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:3.0.1.3`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:3.0.1.4`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.1.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:3.0.1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:3.0.1.6`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0`,
        fs:  `cpe:2.3:a:websvn:websvn:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.localization:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0.1`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0.2`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0044:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0.3`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0.4`,
        fs:  `cpe:2.3:a:oracle:retail_xstore_point_of_service:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0.5`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0.6`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:4.0.7`,
        fs:  `cpe:2.3:a:emc:networker:7.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:5.0`,
        fs:  `cpe:2.3:a:call-cc:chicken:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:5.0.0`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:5.0.1`,
        fs:  `cpe:2.3:a:apple:itunes:5.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:5.0.2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.45:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:6.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:6.0.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:6.0.1`,
        fs:  `cpe:2.3:a:david_king:vino:2.19.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_collaborative_lifecycle_management:6.0.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:7.1`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:7.6.2.1`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:7.6.2.2`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:7.6.2.3`,
        fs:  `cpe:2.3:a:prosody:prosody:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:7.6.2.4`,
        fs:  `cpe:2.3:a:juniper:network_connect:6.3.0.13725:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.0.1.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.0.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.0.3`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.0.3.1`,
        fs:  `cpe:2.3:h:cisco:80-7112-01_for_the_unity-svrx255-2a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.0.3.2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.8.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.0.3.3`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.5.0`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.5.0.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2009-12-25c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_developer_for_system_z:8.5.1`,
        fs:  `cpe:2.3:a:keepass:keepass:0.98:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_administrator:6.0`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.15.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_administrator:6.0.0.1`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_server:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_server:5.1.1`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_server:5.1.1.1`,
        fs:  `cpe:2.3:a:akiva:webboard:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_server:5.1.1.2`,
        fs:  `cpe:2.3:a:tollgrade:smartgrid_lighthouse_sensor_management_system:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_server:5.2`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_server:5.2.0.1`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_server:5.2.0.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_directory_server:5.2.1`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:7.5.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0.1`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0.2`,
        fs:  `cpe:2.3:a:ntt:050_plus:4.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0.3`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0.4`,
        fs:  `cpe:2.3:h:ibm:storwize_v3700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0.5`,
        fs:  `cpe:2.3:a:hp:photo_gallery:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0.6`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:4.0.7`,
        fs:  `cpe:2.3:a:ham3d:ham3d_shop_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:5.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:5.0.0`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:5.0.1`,
        fs:  `cpe:2.3:h:lexmark:cx825de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:5.0.2`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.63:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:6.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:6.0.1`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:6.0.2`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_plant_applications:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:6.0.3`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_doors_next_generation:6.0.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.0.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:1.0`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:cs3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:1.0.0.1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0.0`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0.3`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0.6`,
        fs:  `cpe:2.3:a:antti_alamki:prh_search:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:4.0.7`,
        fs:  `cpe:2.3:a:samba:samba:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:5.0`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20141013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:5.0.0`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.98.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:5.0.1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.4.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:5.0.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:6.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:6.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:6.0.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:6.0.2`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_engineering_lifecycle_manager:6.0.3`,
        fs:  `cpe:2.3:a:drupal-id:counter_module:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.4.0.1`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.4.1.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.4.1.1`,
        fs:  `cpe:2.3:a:pmail:pegasus:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.4.1.2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.4.1.3`,
        fs:  `cpe:2.3:h:siemens:scalance_w784-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5.0.1`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5.0.2`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5.1`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:12.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5.1.1`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5.2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.4.121.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5.2.1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5.2.2`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a5\(1.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.5.2.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.6`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.6.0.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_focal_point:6.6.1`,
        fs:  `cpe:2.3:a:m2_technologies:optimalsite:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:1.6.0.12`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:1.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:8.0.8.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:9.0.8.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.374:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:10.0.9.0`,
        fs:  `cpe:2.3:h:xerox:workcentre:7655:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:10.0.10.0`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:11.0.3.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:11.0.4.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:11.0.5.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(5\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:11.0.5.1`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:11.0.6.0`,
        fs:  `cpe:2.3:a:thinkshout:mandrill:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_host_on-demand:11.0.6.1`,
        fs:  `cpe:2.3:a:justsystems:just_jump:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_insight:1.1.1.5`,
        fs:  `cpe:2.3:a:splunk:splunk:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.0`,
        fs:  `cpe:2.3:a:oracle:listener:7.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.30.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.1`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.2.1`,
        fs:  `cpe:2.3:a:egroupware:egroupware_enterprise_line:11.1.20110804-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.4`,
        fs:  `cpe:2.3:a:f5:firepass:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.4.2`,
        fs:  `cpe:2.3:o:cisco:firepower_extensible_operating_system:1.1\(1.86\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.4.3`,
        fs:  `cpe:2.3:a:gnu:tar:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.4.4`,
        fs:  `cpe:2.3:a:microsoft:html_help_workshop:4.74.8702.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.4.5`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_key_server:8.1.4.6`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.03:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_server:2.1.79`,
        fs:  `cpe:2.3:a:altiris:inventory_pack_for_servers:6.1.1058.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_server:7.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing:10.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_server:7.0.1.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_server:7.1`,
        fs:  `cpe:2.3:a:otrs:otrs:1.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_server:7.5`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_license_server_tl:2.0.0.0`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:104sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_performance_tester:8.3.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_performance_tester:8.3.0.1`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_performance_tester:8.3.0.2`,
        fs:  `cpe:2.3:a:php:php:5.5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_performance_tester:8.3.0.3`,
        fs:  `cpe:2.3:o:hp:hp-ux:b.11.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_performance_tester:8.5.0`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.30.0040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_performance_tester:8.5.0.1`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_performance_tester:8.5.0.2`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:5.5.0.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:5.5.0.1`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac_afr:6.1.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:5.5.0.2`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:5.6.0.0`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:5.6.0.1`,
        fs:  `cpe:2.3:a:symantec:vrtsaa:5.0.443:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:5.6.0.2`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:2.7.0_j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:5.6.0.3`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.0.0.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.0.0.1`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.0.0.2`,
        fs:  `cpe:2.3:a:barebones:yojimbo:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.0.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.0.1.1`,
        fs:  `cpe:2.3:a:microsoft:jet:4.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.5.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.5.0.1`,
        fs:  `cpe:2.3:a:mcafee:privacy_service:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.5.0.2`,
        fs:  `cpe:2.3:a:winzip:winzip:15.5.9510:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.5.0.3`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.5.0.4`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_policy_tester:8.5.0.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:2.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:2.0.0.1`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:2.0.0.2`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:2.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:2.0.1.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:3.0`,
        fs:  `cpe:2.3:a:ca:brightstor_mobile_backup:r4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:3.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:3.0.1.1`,
        fs:  `cpe:2.3:a:piwik:piwik:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:3.0.1.2`,
        fs:  `cpe:2.3:a:viddy:viddy:1.3.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:3.0.1.3`,
        fs:  `cpe:2.3:a:adobe:media_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:3.0.1.4`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:3.0.1.5`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:3.0.1.6`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0`,
        fs:  `cpe:2.3:h:d-link:dir-605l:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.0.1`,
        fs:  `cpe:2.3:a:dedecms:dedecms:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.0.2`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs5:12.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.1`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.3`,
        fs:  `cpe:2.3:a:isc:bind:9.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.4`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.1.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.5`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.4mrb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:4.0.7`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:5.0`,
        fs:  `cpe:2.3:a:isc:bind:9.9.3:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:5.0.0`,
        fs:  `cpe:2.3:o:cisco:asa_with_firepower_services:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:5.0.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:5.0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:6.0`,
        fs:  `cpe:2.3:o:dell:sonicwall_secure_remote_access_firmware:8.0.0.1-16sv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:6.0.0`,
        fs:  `cpe:2.3:a:matroska:libmatroska:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:6.0.1`,
        fs:  `cpe:2.3:a:altsoft:xml2pdf_workstation_2007:1.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:6.0.2`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.51.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_quality_manager:6.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xs2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:1.0`,
        fs:  `cpe:2.3:a:oracle:webcenter_sites:11.1.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:1.0.0.1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:2.0`,
        fs:  `cpe:2.3:o:netgear:r6400_firmware:1.0.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:2.0.0.1`,
        fs:  `cpe:2.3:a:samba:samba:3.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:2.0.0.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:2.0.0.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.7_p0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:2.0.0.4`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.0`,
        fs:  `cpe:2.3:h:hp:ibrix_x9300:aw539d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.0.1`,
        fs:  `cpe:2.3:h:brickom:fb-100ap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.0.1.1`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.0.1.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.352:*:*:*:esr:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.0.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.0.1.4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.0.1.5`,
        fs:  `cpe:2.3:a:ca:brightstor_san_manager:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.0.1.6`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.5.50.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:3.5`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.0.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.0.2`,
        fs:  `cpe:2.3:a:fusebox:fusebox:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.1`,
        fs:  `cpe:2.3:a:wpsymposium:wp_symposium:13.02:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.5`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.6`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.7:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requirements_composer:4.0.7`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requisitepro:2.1.1063`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requisitepro:2.1.1202`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_requisitepro:7.0.1.1-ifix02`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:3.0`,
        fs:  `cpe:2.3:h:hp:2200_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:3.0.0.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:3.0.1`,
        fs:  `cpe:2.3:a:nec:universal_raid_utility:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:4.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:4.0.1`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.2.255:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:4.0.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:4.0.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:4.0.4`,
        fs:  `cpe:2.3:a:freso:languageicons:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:4.0.5`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:4.0.6`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:4.0.7`,
        fs:  `cpe:2.3:a:vmware:player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:5.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:5.0.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:5.0.1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.1.171.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:5.0.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:6.0`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:6.0.0`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:6.0.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.928.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:6.0.2`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_rhapsody_design_manager:6.0.3`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_service_tester:8.3.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_service_tester:8.3.0.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_service_tester:8.3.0.2`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_service_tester:8.3.0.3`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_service_tester:8.5.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_service_tester:8.5.0.1`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_service_tester:8.5.0.2`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:8.5.0`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.9.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:8.5.1`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:8.5.1.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:8.5.5`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:8.5.5.1`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:8.5.5.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:8.5.5.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager_im_and_presence_service:10.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:8.5.5.4`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_382_382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:9.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2dx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:9.0.0.1`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:9.1.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s_3.4.4s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:9.1.1`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance:a5\(2.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:9.1.2`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:9.1.2.1`,
        fs:  `cpe:2.3:a:phorum:phorum:5.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect:9.5.0`,
        fs:  `cpe:2.3:a:igrafx:igrafx:14.1.2.1331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:3.0`,
        fs:  `cpe:2.3:a:hp:network_automation:9.22.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:3.0.0`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.8:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:3.0.0.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:3.0.1`,
        fs:  `cpe:2.3:a:rack_project:rack:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.241.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.05:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0.3`,
        fs:  `cpe:2.3:a:process-one:ejabberd:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:11.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0.5`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.1.7.l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0.6`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:4.0.7`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:5.0`,
        fs:  `cpe:2.3:h:hp:jf816a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:5.0.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd337a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:5.0.1`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:5.0.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:6.0`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:3.2.78.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:6.0.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:6.0.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:6.0.2`,
        fs:  `cpe:2.3:o:cisco:hosting_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_design_manager:6.0.3`,
        fs:  `cpe:2.3:a:typo3:typo3:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:8.5.0`,
        fs:  `cpe:2.3:a:microsoft:ie:5.0.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:8.5.1`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:8.5.1.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:8.5.5`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:8.5.5.2`,
        fs:  `cpe:2.3:a:adobe:document_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:8.5.5.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:8.5.5.4`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:9.0.0`,
        fs:  `cpe:2.3:a:apple:itunes:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:9.0.0.1`,
        fs:  `cpe:2.3:a:grape_project:grape:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:9.1.0`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:9.1.1`,
        fs:  `cpe:2.3:a:debian:apt:0.8.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:9.1.2`,
        fs:  `cpe:2.3:a:usr:bvrp_software_modem_helper:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:9.1.2.1`,
        fs:  `cpe:2.3:a:mark_burdett:securelogin:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software:9.5.0`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_for_websphere_software%27:8.5.5.1`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:8.5.0`,
        fs:  `cpe:2.3:a:catbot_project:catbot:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:8.5.1`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.53:-:solaris:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:8.5.1.0`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:8.5.5`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:8.5.5.1`,
        fs:  `cpe:2.3:a:novell:zenworks_patch_management_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:8.5.5.2`,
        fs:  `cpe:2.3:a:prosody:prosody:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:8.5.5.3`,
        fs:  `cpe:2.3:a:plone:plone:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:8.5.5.4`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:9.0.0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r11_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:9.0.0.1`,
        fs:  `cpe:2.3:a:busybox:busybox:0.60.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:9.1.0`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf287a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:9.1.1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.0.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:9.1.2`,
        fs:  `cpe:2.3:a:citrix:provisioning_services:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:9.1.2.1`,
        fs:  `cpe:2.3:h:fortinet:fortigate-3815d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_software_architect_realtime:9.5.0`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_system_architect:3.1`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_system_architect_suite:11.3.1`,
        fs:  `cpe:2.3:a:citrix:command_center:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:2.0`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.1.1.366:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:2.0.0.1`,
        fs:  `cpe:2.3:a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.7.0:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:2.0.0.2`,
        fs:  `cpe:2.3:a:rovicorp:sonic_cineplayer_decoder_pack:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:3.0`,
        fs:  `cpe:2.3:a:corel:coreldraw_visual_basic_for_applications:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:3.0.1`,
        fs:  `cpe:2.3:h:meinberg:lantime_m900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:3.0.1.1`,
        fs:  `cpe:2.3:a:symantec:web_security:3.01.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:3.0.1.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:3.0.1.3`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:3.0.1.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.7:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:3.0.1.5`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:3.0.1.6`,
        fs:  `cpe:2.3:a:cisco:webns:8.10.3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.0.1`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.0.2`,
        fs:  `cpe:2.3:h:siemens:scalance_xr-300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.1`,
        fs:  `cpe:2.3:a:websvn:websvn:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.3`,
        fs:  `cpe:2.3:a:one_you_fitness_project:one_you_fitness:1.399:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.4`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.5`,
        fs:  `cpe:2.3:o:belden:hirschmann_firmware:09.0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.6`,
        fs:  `cpe:2.3:a:codiad:codiad:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:4.0.7`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:5.0`,
        fs:  `cpe:2.3:o:d-link:dcs-2332l_firmware:1.08.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:5.0.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:5.0.1`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:5.0.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:6.0`,
        fs:  `cpe:2.3:a:google:v8:3.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:6.0.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:6.0.1`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_team_concert:6.0.3`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.0`,
        fs:  `cpe:2.3:a:dest-unreach:socat:2.0.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.0.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1023:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.0.2`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.0.3`,
        fs:  `cpe:2.3:h:cisco:clean_access:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.0.4`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.1`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.1.1`,
        fs:  `cpe:2.3:a:hp:headless_server_registry_update:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.1.2`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.1.3`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.1.4`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.0217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.0.1.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.0`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.0.1`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.0.2`,
        fs:  `cpe:2.3:a:csc:e-tes_scheduled_reminder:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.0.3`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.1.1`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.1.2`,
        fs:  `cpe:2.3:a:umn:mapserver:4.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.1.3`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.5.1.4`,
        fs:  `cpe:2.3:h:intel:q57_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.6.0`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.6.0.1`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.1:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.6.0.2`,
        fs:  `cpe:2.3:a:adobe:livecycle_workflow:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.6.0.3`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.1.a0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.7.0`,
        fs:  `cpe:2.3:h:d-link:dcs-6212l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_virtualization_server:8.7.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.563:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.0`,
        fs:  `cpe:2.3:h:dell:kvm_dmpu108e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.0.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.2.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.0.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yf2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.0.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_endpoint_manager:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.1`,
        fs:  `cpe:2.3:a:hp:process_resource_manager:c.01.08.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.1.1`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.1.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.44.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.1.3`,
        fs:  `cpe:2.3:a:eaton:proview:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.1.4`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.0.1.5`,
        fs:  `cpe:2.3:a:baseurl:yum:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.0.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.0.2`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.0.3`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.1`,
        fs:  `cpe:2.3:h:draytek:vigor_2700_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.1.1`,
        fs:  `cpe:2.3:a:nortel:helmsman:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.1.2`,
        fs:  `cpe:2.3:h:axis:2130_ptz_network_camera:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.1.3`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.5.1.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.6.0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.15-210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.6.0.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.6.0.2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.6.0.3`,
        fs:  `cpe:2.3:a:roxio:central_copy:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.7.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_test_workbench:8.7.0.1`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_testmanager:2.1.1063`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rational_testmanager:7.0.1.1`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:5.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:3.0.0`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:3.0.0.1`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:3.0.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0\(3a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:4.0.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:4.0.1`,
        fs:  `cpe:2.3:a:gentoo:webmin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:4.0.2`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:4.0.3`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:4.0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:4.0.5`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:4.0.6`,
        fs:  `cpe:2.3:a:quantum:vision:4.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:4.0.7`,
        fs:  `cpe:2.3:a:blaine_lang:maestro:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:5.0`,
        fs:  `cpe:2.3:a:buffalotech:wer-am54g54_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:5.0.1`,
        fs:  `cpe:2.3:a:debian:mime-support:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:5.0.2`,
        fs:  `cpe:2.3:a:wordpress_responsive_preview_project:wordpress_responsive_preview:1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:6.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:6.0.1`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:6.0.2`,
        fs:  `cpe:2.3:h:dell:kvm_1082ds:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:rhapsody_design_manager:6.0.3`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:s07:-`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:s08:-`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:s18:-`,
        fs:  `cpe:2.3:a:ni:teststand:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:s28:-`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_edge_85_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:s38:-`,
        fs:  `cpe:2.3:a:juniper:installer_service:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:s54:-`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:7.0.0.0`,
        fs:  `cpe:2.3:a:kajona:kajona:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:7.5.0.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update4:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:7.5.0.1`,
        fs:  `cpe:2.3:a:phil_schwartz:denyhosts:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:7.5.1.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:7.5.1.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:7.5.1.2`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp2:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.0.0.0`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.0.1.0`,
        fs:  `cpe:2.3:a:modpagespeed:mod_pagespeed:0.10.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.0.1.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.0.2.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.0.2.1`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.5.0.0`,
        fs:  `cpe:2.3:a:redhat:wu_ftpd:2.6.1-16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.5.1.0`,
        fs:  `cpe:2.3:a:mercurial:mercurial:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.5.1.1`,
        fs:  `cpe:2.3:a:apache:mod_perl:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.5.2.0`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:8.5.2.1`,
        fs:  `cpe:2.3:a:augeas:augeas:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:9.0.0.0`,
        fs:  `cpe:2.3:a:symantec:netbackup:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime:9.0.0.1`,
        fs:  `cpe:2.3:a:apache:org.apache.sling.servlets.post:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime_meeting_server:8.5.1`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime_proxy_server_and_web_client:9.0.0.0`,
        fs:  `cpe:2.3:a:microsoft:ie:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sametime_proxy_server_and_web_client:9.0.0.1`,
        fs:  `cpe:2.3:a:herac:tuxguitar:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:san_volume_controller:-`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller:6.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller:6.2`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller:6.3`,
        fs:  `cpe:2.3:a:hummingbird:hostexplorer:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller:6.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17d\)sxb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p208:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.2`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.3`,
        fs:  `cpe:2.3:a:novell:netmail:3.0.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.4`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.06.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.5`,
        fs:  `cpe:2.3:a:nokia:affix:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.6`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.7`,
        fs:  `cpe:2.3:a:checkpoint:provider-1:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.8`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.9`,
        fs:  `cpe:2.3:a:vmware:fusion:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.1.0.10`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.2.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.2.0.1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.2.0.2`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.2.0.3`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.2.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.2.0.5`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_presentation_server:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.2.0.6`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.3.0.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.3.0.1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.1.1.8:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.3.0.2`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.3.0.3`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.3.0.4`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.3.0.5`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.3.0.6`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.3.0.7`,
        fs:  `cpe:2.3:h:apple:imac:mb420xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.0.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.0.2`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.0.3`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.0.4`,
        fs:  `cpe:2.3:a:intel:network_connections:16.8.46.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.1.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.1.2`,
        fs:  `cpe:2.3:a:gnu:gdb:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.1.3`,
        fs:  `cpe:2.3:a:microsoft:ie:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.1.4`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.1.5`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.1.6`,
        fs:  `cpe:2.3:o:schneider_electric:telvent_rtu_firmware:c3414-500-s02j1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.1.7`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:6.4.1.8`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.1.0.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.1.0.1`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.1.0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.12:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.1.0.3`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.1.0.5`,
        fs:  `cpe:2.3:a:apache:apr-util:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.1.0.6`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.1.0.7`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:8.2.2:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.2.0.0`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.2.0.1`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.2.0.2`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:san_volume_controller_software:7.2.0.3`,
        fs:  `cpe:2.3:a:yahoo:yui:2.9.0:pr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:sas_connectivity_module:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:sas_connectivity_module_firmware:1.3.3.004`,
        fs:  `cpe:2.3:a:google:chrome:0.2.149.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:sas_raid_module:-`,
        fs:  `cpe:2.3:a:php:php:5.6.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:sas_raid_module_firmware:1.3.3.004`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sbma_smi_provider:1.0.0`,
        fs:  `cpe:2.3:a:solarwinds:toolset:10.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:secureway:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:secureway_directory:3.2.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:secureway_firewall:-`,
        fs:  `cpe:2.3:a:intsig:camscanner_-phone_pdf_creator:3.4.0.20140624:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:secureway_firewall:4.2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:secureway_firewall:4.2.1`,
        fs:  `cpe:2.3:a:cuore:help:1.3.5:*:*:*:*:ec-cube:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0`,
        fs:  `cpe:2.3:a:fortinet:forticlient:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.999:21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.1`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.2`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.3`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_assurance:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.4`,
        fs:  `cpe:2.3:o:huawei:s5300li_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.5`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.6`,
        fs:  `cpe:2.3:a:intel:proset_for_wired_connections:7.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.7`,
        fs:  `cpe:2.3:o:dlink:des-3800_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.8`,
        fs:  `cpe:2.3:o:huawei:s9300e_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.9`,
        fs:  `cpe:2.3:h:ibm:iss_proventia_network_ips:gx5108:1.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.10`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.11`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_36:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.12`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.13`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.14`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.621:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.15`,
        fs:  `cpe:2.3:a:core-apps:digital_content_newfronts_2014:6.0.7.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.16`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp4:adv_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.17`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:7.0.0.18`,
        fs:  `cpe:2.3:a:exim:exim:4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:9.0.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:9.0.0.1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager:9.0.1.0`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0a3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_9.0_firmware:9.0.0`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20160404:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_9.0_firmware:9.0.0.1`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_mobile:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_9.0_firmware:9.0.1.0`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.08.4428:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_9.0_firmware:9.0.2.0`,
        fs:  `cpe:2.3:a:cisco:finesse:10.0\(1\)_su1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_9.0_firmware:9.0.2.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_9.0_firmware:9.0.3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_9.0_firmware:9.0.3.1`,
        fs:  `cpe:2.3:a:installatron:gatequest_file_manager:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:security_access_manager_appliance:9.0`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_enterprise_single_sign-on:8.2`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.0.0:m3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_mobile:8.0.0.2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_mobile:8.0.0.5`,
        fs:  `cpe:2.3:a:redhat:rsync:2.4.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_mobile:8.0.1`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_mobile:8.0.1.2`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.0.0.14874:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_mobile:8.0.1.3`,
        fs:  `cpe:2.3:a:adobe:cmaps_cs4:2.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_mobile:8.0.1.4`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:8.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.0.2`,
        fs:  `cpe:2.3:a:nuance:omnipage:16.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.0.5`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.1.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.1.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.45:devel:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.1.3`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.0.1066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.1.4`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r9_b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:security_access_manager_for_mobile_appliance:8.0`,
        fs:  `cpe:2.3:a:apache:hadoop:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_mobile_software:8.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.localization:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:6.0`,
        fs:  `cpe:2.3:h:hp:trucluster_server:5.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:6.1`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.2600.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:6.1.1`,
        fs:  `cpe:2.3:a:redhat:jboss_fuse_service_works:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0.0`,
        fs:  `cpe:2.3:a:altiris:package_server_wmi_provider:6.0.1057:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0.0.9`,
        fs:  `cpe:2.3:h:moxa:oncell_gateway_g3111:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0.0.10`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.0:rc3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0.0.11`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0.0.12`,
        fs:  `cpe:2.3:h:hp:0235a38r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0.0.13`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0.0.14`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:7.0.0.15`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.0`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.0.5`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.1:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.0.22`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r009c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.0.31`,
        fs:  `cpe:2.3:a:xchat:xchat:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.1.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.8.0.870:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.1.1`,
        fs:  `cpe:2.3:a:symantec:private_branch_exchange:1.3.31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.1.2`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.1.3`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web:8.0.1.4`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:1.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.3`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.4`,
        fs:  `cpe:2.3:a:hummingbird:exceed:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.5`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.12:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.6`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.7`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.8`,
        fs:  `cpe:2.3:a:google:chrome:10.0.618.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.9`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.8.1-250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.10`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.70:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.11`,
        fs:  `cpe:2.3:h:hp:4200ln_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.12`,
        fs:  `cpe:2.3:a:cisco:firepower_threat_defense:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.13`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.14`,
        fs:  `cpe:2.3:a:apple:imovie:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.15`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.16`,
        fs:  `cpe:2.3:h:avaya:definity_one_media_server:r10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.0.1`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.0.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.0.3`,
        fs:  `cpe:2.3:a:google:chrome:17.0.950.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.0.5`,
        fs:  `cpe:2.3:a:gnome:glib:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1`,
        fs:  `cpe:2.3:o:cisco:telepresence_system_software_ix:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.3:pre-1.0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1.2`,
        fs:  `cpe:2.3:a:sybase:easerver:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1.3`,
        fs:  `cpe:2.3:a:concord:ehealth_console:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1.4`,
        fs:  `cpe:2.3:a:apple:apple_application_support:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:security_access_manager_for_web_appliance:7.0`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_for_windows_servers:10.1.5629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:security_access_manager_for_web_appliance:8.0`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web_software:7.0`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_access_manager_for_web_software:8.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:5.6.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:6.0.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:7.0.509.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:6.0.1.0:-:enterprise`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:6.0.2.0:-:enterprise`,
        fs:  `cpe:2.3:o:novell:netware:6.5:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:6.1.1.0:-:enterprise`,
        fs:  `cpe:2.3:a:openttd:openttd:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:7.9:-:standard`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.0:-:standard`,
        fs:  `cpe:2.3:a:ibm:agent_controller:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.0.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.0.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.0.0.2:-:enterprise`,
        fs:  `cpe:2.3:a:adobe:indesign:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.0.1.0:-:enterprise`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.0.1.1:-:enterprise`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.0.11:-:enterprise`,
        fs:  `cpe:2.3:a:busybox:busybox:0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.5:-:standard`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.5.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.5.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.6:-:standard`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.6.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.6.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/r_firmware:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.6.0.2:-:enterprise`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.7:-:standard`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.7.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:5.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.7.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.8:-:standard`,
        fs:  `cpe:2.3:o:google:android:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.8.0.0:-:enterprise`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.5.94.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:8.8.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0::standard`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:zend:zendto:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.1.0::standard`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.1.1::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)mr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.2.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.2.0::~~standard~~~`,
        fs:  `cpe:2.3:a:mdickie:popscene:1.04:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.2.1::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.2.1::~~standard~~~`,
        fs:  `cpe:2.3:a:websense:websense_email_security:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.3.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:microsoft:visio_viewer:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.3.0::~~standard~~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8zg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.3.1::~~enterprise~~~`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.3.1::~~standard~~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.3.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan:9.0.3.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:7.0`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.0`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.0.0.1`,
        fs:  `cpe:2.3:a:itu:space_validation:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.0.0.2`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.5`,
        fs:  `cpe:2.3:a:skype:skype:0.98.0.68:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.5.0.1`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.6`,
        fs:  `cpe:2.3:a:xbuffy_project:xbuffy:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.6.0.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.7`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.2.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:8.8`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:9.0`,
        fs:  `cpe:2.3:a:otrs:faq:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:9.0.0.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:9.0.2`,
        fs:  `cpe:2.3:a:vmware:view:5.0.0:u2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_appscan_source:9.0.3`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_directory_server:-`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd3.t665:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_directory_server:6.3.1`,
        fs:  `cpe:2.3:a:debian:apache:1.3.34.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_directory_server:6.3.1.1`,
        fs:  `cpe:2.3:a:cisco:email_security_virtual_appliance:8.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_directory_server:6.3.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_directory_server:6.3.1.3`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_directory_server:6.3.1.4`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_directory_server:6.3.1.5`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_directory_server:6.3.1.6`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:8.2`,
        fs:  `cpe:2.3:a:juniper:junos_pulse_secure_access_service:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:9.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:9.1`,
        fs:  `cpe:2.3:a:isc:bind:9.10.4:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:9.5`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:10.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:10.0.1`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:01-03-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:10.1`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.40:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:10.01`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.116:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:10.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium:10.1.2`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:1.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium_database_activity_monitor:8.2`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium_database_activity_monitor:9.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium_database_activity_monitor:9.1`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:7.4.102.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium_database_activity_monitor:9.5`,
        fs:  `cpe:2.3:a:debian:toolchain-source:3.0.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium_database_activity_monitor:10.0`,
        fs:  `cpe:2.3:a:cisco:unified_service_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium_database_activity_monitor:10.01`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_guardium_database_activity_monitor:10.1`,
        fs:  `cpe:2.3:a:embedthis:appweb:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.7d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.3`,
        fs:  `cpe:2.3:a:ibm:notes_traveler_companion:1.1:*:*:*:*:windows_phone:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.4`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.5`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.22m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.6`,
        fs:  `cpe:2.3:o:xen:xen:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.7`,
        fs:  `cpe:2.3:a:google:chrome:46.0.2490.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.8`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.9`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:20051007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.10`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.11`,
        fs:  `cpe:2.3:a:orderingapps:sweatshop:2.96:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.12`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.13`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.14`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:5.1.0.15`,
        fs:  `cpe:2.3:o:tp-link:tl-wdr3500_\(1.0\)_firmware:141113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:6.0.0`,
        fs:  `cpe:2.3:a:double-take_software:double-take:4.5.1.1869.6.s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:6.0.0.0`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:6.0.0.1`,
        fs:  `cpe:2.3:a:pwicorp:privatefirewall:7.0.20.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:6.0.0.2`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:3.00.0616:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:6.0.0.3`,
        fs:  `cpe:2.3:a:opnet:ace_analyst:16.0.0.8934:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:6.0.0.4`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_identity_manager:7.0.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0.0`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0.1`,
        fs:  `cpe:2.3:a:symantec:norton_internet_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0.2`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0.3`,
        fs:  `cpe:2.3:o:xen:xen:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0.5`,
        fs:  `cpe:2.3:a:zeromq:zeromq:4.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0.6`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.5.0.7`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.6.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.6.0.1`,
        fs:  `cpe:2.3:a:oracle:forms:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_key_lifecycle_manager:2.6.0.2`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_firmware:5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_firmware:5.1.1`,
        fs:  `cpe:2.3:a:gnu:automake:1.4:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_firmware:5.3.1`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_firmware:5.3.2`,
        fs:  `cpe:2.3:a:koha:koha:3.16.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:security_network_protection_xgs_3100:-`,
        fs:  `cpe:2.3:a:meta_tags_quick_project:meta_tags_quick:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:security_network_protection_xgs_4100:-`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:security_network_protection_xgs_5100:-`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.37.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:security_network_protection_xgs_7100:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.14.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_xgs_firmware:5.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_xgs_firmware:5.1.1`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_141:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_xgs_firmware:5.1.2`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_xgs_firmware:5.1.2.1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_xgs_firmware:5.2`,
        fs:  `cpe:2.3:h:apple:ipod_touch:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:security_network_protection_xgs_firmware:5.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_privileged_identity_manager:2.0.0`,
        fs:  `cpe:2.3:a:gnu:automake:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_privileged_identity_manager:2.0.1`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_privileged_identity_manager:2.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_privileged_identity_manager_virtual_appliance:2.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)dc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_qradar_incident_forensics:7.2.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(1q\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_qradar_incident_forensics:7.2.1`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_qradar_incident_forensics:7.2.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.20:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_qradar_incident_forensics:7.2.3`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.21:-:*:*:*:redhat_enterprise_linux:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_qradar_incident_forensics:7.2.4`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_qradar_incident_forensics:7.2.5`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.291:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_qradar_incident_forensics:7.2.6`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2626-pwr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.0`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:beta5:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.0.0.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.0.0.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.0.0:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.0.0.3`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.10.4570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.0.0.4`,
        fs:  `cpe:2.3:a:ca_lottery_results_project:ca_lottery_results:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.0.0.5`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.0.0.6`,
        fs:  `cpe:2.3:a:php:php:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.1.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.1.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.1.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.1.0.3`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.1.1.0`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:security_siteprotector_system:3.1.1.1`,
        fs:  `cpe:2.3:a:emc:documentum_d2:4.6:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:serverguide:9.60`,
        fs:  `cpe:2.3:h:avaya:sg203:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:service_delivery_manager:7.2.1.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp4005:cb503a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:service_delivery_manager:7.2.2.0`,
        fs:  `cpe:2.3:a:bea:tuxedo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:smart_analytics_system_5600:7200`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_5600_software:-`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.970:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_5600_software:9.7`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ebr:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:smart_analytics_system_7600:-`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:1.2.0`,
        fs:  `cpe:2.3:a:post_to_twitter_project:post_to_twitter:0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:1.2.0.100`,
        fs:  `cpe:2.3:a:atlassian:jira:2.6.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:1.2.1.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:1.2.2.0`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:1.2.4.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:1.3.0.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:1.3.0.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.0.0`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.0.0.100`,
        fs:  `cpe:2.3:a:nokia:qt_creator:2.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.0.1.0`,
        fs:  `cpe:2.3:a:hp:creativeprojects_package_basic1:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.0.2.0`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.0.3.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.0.4.0`,
        fs:  `cpe:2.3:a:barracuda:web_filter:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.1.1.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.1.2.0`,
        fs:  `cpe:2.3:a:easy_tips_for_glowing_skin_project:easy_tips_for_glowing_skin:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7700:2.1.3.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:1.2.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:1.2.0.100`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:1.2.1.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:1.2.2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker_explorer:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:1.2.4.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:1.3.0.0`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:1.3.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.0.0`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe-java_toolkits:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.0.0.100`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.0.1.0`,
        fs:  `cpe:2.3:a:rsa:archer_egrc_platform:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.0.2.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.0.3.0`,
        fs:  `cpe:2.3:a:simplerisk:simplerisk:20130915-001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.0.4.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.400.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.1.2.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smart_analytics_system_7710:2.1.3.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_analytics_log_analysis:1.1.0`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_analytics_log_analysis:1.2.0`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:3.0.9348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:-`,
        fs:  `cpe:2.3:a:endulujans:eyvah\!_bosandim_ozgurum:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.0`,
        fs:  `cpe:2.3:h:intel:7500_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.0.0`,
        fs:  `cpe:2.3:a:apple:xcode:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.0.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.0.2`,
        fs:  `cpe:2.3:a:google:v8:3.25.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.0.3`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.56.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.0.5`,
        fs:  `cpe:2.3:a:apple:mac_os_runtime_for_java:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.0.6`,
        fs:  `cpe:2.3:a:sun:rte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.1.0`,
        fs:  `cpe:2.3:o:huawei:s9306_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.1.1`,
        fs:  `cpe:2.3:a:php:php:5.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.1.2`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.5.1.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_control_desk:7.6`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:smartcloud_provisioning:2.1.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:sng:-`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:sng:2.1`,
        fs:  `cpe:2.3:a:cupidsystems:cis_webserver:3.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:sng:2.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:social_media_analytics:1.2.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:social_media_analytics:1.2.0.1`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.902:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:4.5.167`,
        fs:  `cpe:2.3:o:cisco:ios:15.0sa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:4.5.168`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:4.5.169`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:4.5.173`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:4.5.175`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:4.5.176`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:4.5.178`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:ga:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.0.1060`,
        fs:  `cpe:2.3:a:navicat:navicat:10.0:*:*:*:premium:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.0.1061`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.0.1064`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.0.1065`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.0.1066`,
        fs:  `cpe:2.3:a:hp:power_manager_remote_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.0.1069`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.1`,
        fs:  `cpe:2.3:a:libav:libav:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.1.20`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3`,
        fs:  `cpe:2.3:a:hp:array_diagnostic_utility:7.80.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.31`,
        fs:  `cpe:2.3:a:redhat:libtirpc:0.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.33`,
        fs:  `cpe:2.3:a:mcafee:security_center:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.34`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.37`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.38`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:12.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.39`,
        fs:  `cpe:2.3:o:yamaha:rtx1200:10.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.40`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.41`,
        fs:  `cpe:2.3:a:google:v8:3.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.42`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1053.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.44`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.47`,
        fs:  `cpe:2.3:a:hp:business_process_monitor:9.3:patch_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.48`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.6:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.49`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.52`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.53`,
        fs:  `cpe:2.3:a:x:libxext:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.54`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.55`,
        fs:  `cpe:2.3:a:hp:color_laserjet_cp4520-cp4020_series_screen_fonts:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.3.56`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x51:d15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.1`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.2`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0578:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.3`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:14.0.1.609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.4`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.5`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.7`,
        fs:  `cpe:2.3:a:ca:secure_content_manager:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.0.8`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.09`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.10`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0082:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.11`,
        fs:  `cpe:2.3:a:exim:exim:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.12`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.13`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.5.14`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.30.0039`,
        fs:  `cpe:2.3:a:emc:rsa_authentication_manager:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.30.0040`,
        fs:  `cpe:2.3:a:suse:webyast:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:6.30.0044`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:7.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1031:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:7.0.0.0`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:7.0.0.1`,
        fs:  `cpe:2.3:h:okidata:c9500_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:7.0.0.2`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:soliddb:7.0.0.3`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.004:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_lsf:8.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(6f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_lsf:9.1.1`,
        fs:  `cpe:2.3:a:macromedia:flash_player:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_lsf:9.1.2`,
        fs:  `cpe:2.3:a:siemens:comos:9.2.6.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_lsf:9.1.3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_lsf:10.1.0.1`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_protect_for_virtual_environments:7.1::~~~vmware~~`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_protect_snapshot:4.1::~~~vmware~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100722:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.0.0`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.1`,
        fs:  `cpe:2.3:a:emc:navisphere_agent:26.5.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.2`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.3`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.4`,
        fs:  `cpe:2.3:a:magzter:nano_digest:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.5`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.7`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.9`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.1.1.10`,
        fs:  `cpe:2.3:a:adobe:connect:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.2.0.0`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_entry_client:9.31:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.2.0.1`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.2.0.2`,
        fs:  `cpe:2.3:a:plone:plone:3.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.2.0.3`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.2.1`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_direct_user_interface:1.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spectrum_scale:4.2.2.0`,
        fs:  `cpe:2.3:a:avast:premier:11.1.2261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_analytic_server:1.0.0.0`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_analytic_server:1.0.1.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_analytical_decision_management:6.0.0.0`,
        fs:  `cpe:2.3:a:sun:ipmitool:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_analytical_decision_management:6.1.0.0`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_analytical_decision_management:6.2.0.0`,
        fs:  `cpe:2.3:a:adobe:indesign:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_analytical_decision_management:7.0.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:45.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_analytical_decision_management:7.0.0.1`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:4.1.1.1`,
        fs:  `cpe:2.3:a:ourtoolbar:productivity_toolbar:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:4.1.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:4.1.1.3`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:4.2.1`,
        fs:  `cpe:2.3:a:brocade:san_health_professional:1.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:4.2.1.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:4.2.1.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:4.2.1.3`,
        fs:  `cpe:2.3:a:apple:keynote:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:5.0.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:5.0.0.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:5.0.0.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:5.0.0.3`,
        fs:  `cpe:2.3:a:foconet:foconet:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:5.0.1`,
        fs:  `cpe:2.3:a:krisonav:krisonav:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:5.0.2`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-05-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_collaboration_and_deployment_services:6.0.0.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_data_collection:6.0`,
        fs:  `cpe:2.3:a:eviware:soapui:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_data_collection:6.0.1`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_data_collection:6.0.1.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_data_collection:7.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.0.0.0`,
        fs:  `cpe:2.3:a:tag1consulting:support_timer:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.0.0.1`,
        fs:  `cpe:2.3:a:quest:toad_for_data_analysts:2.6.1.568:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.0.0.2`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.1.0.0`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5601:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.1.0.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.1.0.2`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.2.0.0`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.2.0.1`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:sp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.2.0.2`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:14.2.0.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.240:update24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:15.0.0.0`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:15.0.0.1`,
        fs:  `cpe:2.3:a:packagekit_project:packagekit:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:15.0.0.2`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:15.0.0.3`,
        fs:  `cpe:2.3:a:adgjm:angel_browser:1.68b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:16.0.0.0`,
        fs:  `cpe:2.3:a:perl:perl:0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:16.0.0.1`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.20-68.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:16.0.0.2`,
        fs:  `cpe:2.3:a:adobe:bridge_cs5:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:17.0.0.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:17.0.0.1`,
        fs:  `cpe:2.3:a:trioniclabs:sentinel:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_modeler:17.1.0.0`,
        fs:  `cpe:2.3:a:apache:wss4j:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_samplepower:3.0.0.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_samplepower:3.0.1.0`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_samplepower:3.0.1.1`,
        fs:  `cpe:2.3:a:samba:samba:3.0.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_statistics:19.0.0.1`,
        fs:  `cpe:2.3:a:redhat:package_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_statistics:20.0.0.2`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_statistics:21.0.0.2`,
        fs:  `cpe:2.3:o:hp:jg813aae:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_statistics:22.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_statistics:22.0.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_statistics:23.0.0.2`,
        fs:  `cpe:2.3:a:altova:databasespy_2008:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_statistics:23.0.0.3`,
        fs:  `cpe:2.3:a:apache:solr:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:spss_statistics:24.0.0.0`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_b2b_integrator:5.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_b2b_integrator:5.1`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_b2b_integrator:5.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_b2b_integrator:5.2.1`,
        fs:  `cpe:2.3:a:projectsend:projectsend:375:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_b2b_integrator:5.2.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.13.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_b2b_integrator:5.2.4`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_b2b_integrator:5.2.5`,
        fs:  `cpe:2.3:a:microsoft:office:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_b2b_integrator:5.2.6`,
        fs:  `cpe:2.3:o:huawei:s9703_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect:4.1.0.0`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect:4.1.0.1`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect:4.1.0.2`,
        fs:  `cpe:2.3:a:fusionforge:fusionforge:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect:4.1.0.3`,
        fs:  `cpe:2.3:a:adobe:coldfusion_8_.net_integration_services:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_direct_user_interface:1.4.0.0`,
        fs:  `cpe:2.3:a:hp:printer_utility:1.6.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_direct_user_interface:1.4.0.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.32.376:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_direct_user_interface:1.4.0.3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_direct_user_interface:1.4.0.6`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_direct_user_interface:1.4.0.7`,
        fs:  `cpe:2.3:a:pgp:desktop_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_direct_user_interface:1.4.0.10`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_direct_user_interface:1.5.0.0`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_direct_user_interface:1.5.0.1`,
        fs:  `cpe:2.3:a:david_leonard:pkstat:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_enterprise_http_option:1.3.02`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_connect_enterprise_http_option:1.4.00`,
        fs:  `cpe:2.3:a:symantec:encryption_management_server:3.3.0:mp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.2.0`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.2.0.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.3.0`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.3.0.1`,
        fs:  `cpe:2.3:a:crear.ne.jp:al-mail32:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.3.0.2`,
        fs:  `cpe:2.3:a:h5ai_project:h5ai:0.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.3.0.3`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.3.0.4`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.4.0`,
        fs:  `cpe:2.3:a:pgp:desktop_for_windows:10.0.3:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.4.0.0`,
        fs:  `cpe:2.3:a:winzip:winzip:10.0.6698:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.4.0.1`,
        fs:  `cpe:2.3:o:honeywell:excel_web_xl_1000c500_300_i\/o_uukl:2.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.4.1`,
        fs:  `cpe:2.3:a:cobblerd:cobbler:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.4.2`,
        fs:  `cpe:2.3:a:eshtery.she7ata:eshtery_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_control_center:5.4.2.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_file_gateway:-`,
        fs:  `cpe:2.3:a:timuz:bike_racing_2014:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_file_gateway:1.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_file_gateway:2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_file_gateway:2.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_file_gateway:2.2`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_integrator:5.0`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.05.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_integrator:5.1`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_multi-channel_fulfillment_solution:8.0`,
        fs:  `cpe:2.3:h:fortinet:fortigate-200b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_order_management:8.5`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_secure_proxy:3.2.0.0`,
        fs:  `cpe:2.3:a:condor_project:condor:7.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_secure_proxy:3.3.0.1`,
        fs:  `cpe:2.3:a:google:chrome:16.0.895.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_secure_proxy:3.4.0.0`,
        fs:  `cpe:2.3:a:teradata:putsrc:3.5.2.14a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_secure_proxy:3.4.1.0`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_secure_proxy:3.4.1.2`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_secure_proxy:3.4.1.5`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_secure_proxy:3.4.1.6`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_secure_proxy:3.4.1.7`,
        fs:  `cpe:2.3:a:hp:jetadmin:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:8.0`,
        fs:  `cpe:2.3:h:xerox:workcentre:245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:8.5`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.0`,
        fs:  `cpe:2.3:a:santiagosarceda:elforro.com:2.4.3.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.1`,
        fs:  `cpe:2.3:a:debian:fsp:2.81.b18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.2`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.4`,
        fs:  `cpe:2.3:h:ovislink:airlive_od-2025hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.5`,
        fs:  `cpe:2.3:a:samba:samba:3.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.6`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.7`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.8`,
        fs:  `cpe:2.3:a:ibm:security_guardium_database_activity_monitor:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.9`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.10`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(19a\)gs6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.11`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.12`,
        fs:  `cpe:2.3:a:mozilla:mozilla_mail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.13`,
        fs:  `cpe:2.3:a:daiki_ueno:libfep:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.14`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(2a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.15`,
        fs:  `cpe:2.3:a:attachmate:installer_service:8.00.0001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.16`,
        fs:  `cpe:2.3:a:keepass:keepass:0.95:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.17`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.18`,
        fs:  `cpe:2.3:a:xymon:xymon:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.19`,
        fs:  `cpe:2.3:h:loytec:lip-3ectb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.20`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.9.p-3520a-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.21`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.22`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.23`,
        fs:  `cpe:2.3:h:moxa:oncell_gateway_g3151:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.24`,
        fs:  `cpe:2.3:a:solltech:dias:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.25`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.26`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.27`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.28`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.29`,
        fs:  `cpe:2.3:o:yamaha:rtx1200:10.01.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.30`,
        fs:  `cpe:2.3:h:nvidia:quadro_p5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.31`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.32`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.33`,
        fs:  `cpe:2.3:a:mcafee:quarantine_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.34`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.35`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_netscaler:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.36`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.37`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.6:pl3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.38`,
        fs:  `cpe:2.3:a:digium:asterisk:c.1.0_beta5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.39`,
        fs:  `cpe:2.3:o:cisco:ios:12.4mdb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.40`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.41`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.42`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.43`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.8.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.44`,
        fs:  `cpe:2.3:h:airties:air_6372:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.45`,
        fs:  `cpe:2.3:a:simplerealtytheme:advanced_text_widget_plugin:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.46`,
        fs:  `cpe:2.3:a:quickheal:antivirus_pro:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0`,
        fs:  `cpe:2.3:a:commpower:dc_directory_admin:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.1`,
        fs:  `cpe:2.3:a:redhat:jboss_portal:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.2`,
        fs:  `cpe:2.3:a:90meter:cac_smartcard_manager-90:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.4`,
        fs:  `cpe:2.3:a:ibm:content_navigator:2.0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.5`,
        fs:  `cpe:2.3:a:x.org:libxv:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.6`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.7`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.8`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.9`,
        fs:  `cpe:2.3:a:solarwinds:orion_voip_\&amp;_network_quality_manager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.10`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.11`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.12`,
        fs:  `cpe:2.3:a:ninjaforms:ninja_forms:2.9.42:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.13`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.14`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.15`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.1.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.16`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.17`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2010.302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize:v7000`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.56.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:storwize_unified_v7000:-`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.3.0.0`,
        fs:  `cpe:2.3:a:emulex:hbanyware:3.1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.3.1.0`,
        fs:  `cpe:2.3:a:shaklee_product_catalog_project:shaklee_product_catalog:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.0.0`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.0.1`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1a_pk5_bl23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.0.2`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.0.3`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.0.4`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.0.5`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r13b03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.1.0`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.1.1`,
        fs:  `cpe:2.3:a:oracle:secure_global_desktop:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.2.0`,
        fs:  `cpe:2.3:a:citrix:xenapp_document_library:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.2.1`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.3.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg259a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.3.1`,
        fs:  `cpe:2.3:a:alienwp:hatch:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_unified_v7000_software:1.4.3.2`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:storwize_v3500:-`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.5:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.24:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.2`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.4`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x4540:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.5`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.7`,
        fs:  `cpe:2.3:a:apache:libcloud:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:6.4.1.8`,
        fs:  `cpe:2.3:a:microsoft:excel:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.1.0.0`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.1.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.1.0.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_readiness_assessment_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.1.0.3`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.1.0.5`,
        fs:  `cpe:2.3:a:apache:poi:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.1.0.6`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.2.0.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp1:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.2.0.1`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.2.0.2`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3500_software:7.2.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:storwize_v3700:-`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:11.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.3`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.4`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.5`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.6`,
        fs:  `cpe:2.3:a:illinois:ncsa_mosaic:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:6.4.1.8`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.1.0.0`,
        fs:  `cpe:2.3:a:microsoft:small_business_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.1.0.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.1.0.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.15a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.1.0.3`,
        fs:  `cpe:2.3:o:cisco:mds_9000_nx-os:5.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.1.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.1.0.6`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.1.0.7`,
        fs:  `cpe:2.3:a:gnu:radius:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.2.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.2.0.1`,
        fs:  `cpe:2.3:a:microsoft:visual_foxpro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.2.0.2`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v3700_software:7.2.0.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:storwize_v5000:-`,
        fs:  `cpe:2.3:a:apache:camel:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.1.0.2`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.1.0.3`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.1.0.4`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.1.0.5`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.1.0.6`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.0.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.1.0.7`,
        fs:  `cpe:2.3:a:apache:wss4j:1.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.2.0.0`,
        fs:  `cpe:2.3:a:preplogic:exam_security\&#43;_\(2008\):3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.2.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.5-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.2.0.2`,
        fs:  `cpe:2.3:a:hideyuki_chikada:perltreebbs:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v5000_software:7.2.0.3`,
        fs:  `cpe:2.3:a:rovicorp:sonic_activation_module:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:storwize_v7000:-`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.7:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.0`,
        fs:  `cpe:2.3:a:novell:iprint:5.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.1`,
        fs:  `cpe:2.3:h:ibm:smart_analytics_system_7600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.2`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.7.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.3`,
        fs:  `cpe:2.3:a:siemens:comos:9.1:457:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.4`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.4.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.5`,
        fs:  `cpe:2.3:a:emc:documentum_webtop:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.6`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd3.mxx60:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.7`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.8`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.9`,
        fs:  `cpe:2.3:a:microsoft:publisher:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.1.0.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(60\)ez10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.2.0.0`,
        fs:  `cpe:2.3:a:roxio:central_copy:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.2.0.1`,
        fs:  `cpe:2.3:o:sophos:web_appliance_firmware:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.2.0.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.2.0.3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.2.0.4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.329:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.2.0.5`,
        fs:  `cpe:2.3:h:cisco:1802_integrated_service_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.2.0.6`,
        fs:  `cpe:2.3:a:perl:perl:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.3.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.3.0.1`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.3.0.2`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:13.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.3.0.3`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_platform:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.3.0.4`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.12.10:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.3.0.5`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.425:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.3.0.6`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.3.0.7`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.0.0`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.0.1`,
        fs:  `cpe:2.3:a:intel:network_connections:16.1.53.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.0.3`,
        fs:  `cpe:2.3:a:x.org:libx11:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.0.4`,
        fs:  `cpe:2.3:a:mongodb:mongodb:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.1.1`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.1.2`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.1.3`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.1.4`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.1.5`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.1.6`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.1.7`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:6.4.1.8`,
        fs:  `cpe:2.3:a:mybb:mybb:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.1.0.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.1.0.1`,
        fs:  `cpe:2.3:a:binarymoon:timthumb:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.1.0.2`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:20.0.0.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.1.0.3`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.1.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.27:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.1.0.6`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.1.0.7`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.2.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)ea1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.2.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.2.0.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update6:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_software:7.2.0.3`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:storwize_v7000_unified:-`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_unified_software:1.3.0.0`,
        fs:  `cpe:2.3:a:scriptsfeed:business_directory_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_unified_software:1.3.2.0`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_unified_software:1.3.2.3`,
        fs:  `cpe:2.3:a:cisco:business_edition_3000_software:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_unified_software:1.4.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.74c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_unified_software:1.4.0.4`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r75.40:vs:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_unified_software:1.4.1.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_unified_software:1.4.1.1`,
        fs:  `cpe:2.3:a:david_king:vino:2.11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:storwize_v7000_unified_software:1.4.2.0`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:surepos_500:-`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:system_data_repository:-`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_dcs3700_storage_subsystem:1818`,
        fs:  `cpe:2.3:a:opera:opera_browser:15.00:next:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds3200:1726`,
        fs:  `cpe:2.3:a:misterpark:le_grand_bleu:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds3300:1726`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds3400:1726`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds3512:1746`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds3524:1746`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds3950_express:1814`,
        fs:  `cpe:2.3:a:apple:java_1.4:2:18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds5020_disk_controller:1814-20a`,
        fs:  `cpe:2.3:a:apache:struts:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds5100_storage_controller:1818`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_ds5300_storage_controller:1818`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_storage_virtualization_engine_ts7700:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:system_storage_virtualization_engine_ts7700_firmware:-`,
        fs:  `cpe:2.3:a:cisco:jabber:9.7\(4\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x_idataplex_direct_water_cooled_dx360_m4_server:-`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x_idataplex_dx360_m2_server:-`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x_idataplex_dx360_m3_server:-`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x_idataplex_dx360_m4_server:-`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.0.2:-:-:en-us:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3100_m4:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3200_m3:-`,
        fs:  `cpe:2.3:a:ibm:algo_credit_limits:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3250_m3:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3250_m4:-`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3300_m4:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.32:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3400_m2:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.359:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3400_m3:-`,
        fs:  `cpe:2.3:a:oracle:knowledge_management:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3500_m2:-`,
        fs:  `cpe:2.3:a:openstack:swift:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3500_m3:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3500_m4:-`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3530_m4:-`,
        fs:  `cpe:2.3:a:sap:afaria:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3550_m2:-`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3550_m3:-`,
        fs:  `cpe:2.3:a:northropgrumman:fileversion:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3550_m4:-`,
        fs:  `cpe:2.3:h:juniper:netscreen-idp_100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3620_m3:-`,
        fs:  `cpe:2.3:a:freesql:freesql:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3630_m3:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3630_m4:-`,
        fs:  `cpe:2.3:a:file_project:file:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3630_m4_hd:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3650_m2:-`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3650_m3:-`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3650_m4:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.31:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3650_m4_hd:-`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3690_x5:-`,
        fs:  `cpe:2.3:a:codehaus:redback:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3750_m4:-`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3850_x5:-`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:system_x3950_x5:-`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:systems_director:5.20`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0083:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:systems_director:6.3.6.0`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:8.7`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:8.7.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:8.7.1`,
        fs:  `cpe:2.3:a:teradata:teradata_manager:13.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:8.8`,
        fs:  `cpe:2.3:h:intel:xircom_rex_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:8.8.0`,
        fs:  `cpe:2.3:a:candlepinproject:candlepin:0.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:8.8.1`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:8.8.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:9.0`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:9.0.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.322.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_consumer_experience:9.0.2`,
        fs:  `cpe:2.3:a:usebb:usebb:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:8.6`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:8.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.8.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:8.8`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:9.0.0`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:9.0.0a`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:9.0.1`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:9.0.1a`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:9.0.2`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tealeaf_customer_experience:9.0.2a`,
        fs:  `cpe:2.3:a:adobe:freehand:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:telelogic_license_server:2.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:thinkvantage_power_manager:1.0.18`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:thinkvantage_tpm:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:-`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.17:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:3.9`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:4.1`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:5.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:5.1.0.10`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:6.0.0`,
        fs:  `cpe:2.3:a:symantec:workspace_streaming:6.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:6.0.0.17`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:6.1.0`,
        fs:  `cpe:2.3:a:wali:walisms_cn:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_for_e-business:6.1.1`,
        fs:  `cpe:2.3:h:hp:jg404a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_identity_manager_solution:-`,
        fs:  `cpe:2.3:a:google:chrome:5.0.381.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_access_manager_identity_manager_solution:5.1`,
        fs:  `cpe:2.3:a:gnu:bash:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.1.2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-16p-si_ls-5100-16p-si-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.2`,
        fs:  `cpe:2.3:h:linksys:wap11:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.3`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.5`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.6`,
        fs:  `cpe:2.3:a:zope:zope:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.7`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.8`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.1`,
        fs:  `cpe:2.3:h:radiothermostat:ct50:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.2`,
        fs:  `cpe:2.3:a:magicstamp:magic_stamp:2.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.3`,
        fs:  `cpe:2.3:h:cisco:aironet_3600i:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.4`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:1.5\(.1.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.5`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.6`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.7`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2009:13.0.835.32:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.8`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs4_third_party_content:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.9`,
        fs:  `cpe:2.3:a:hummingbird:exceed:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.10`,
        fs:  `cpe:2.3:o:hp:tru64:4.0g:pk4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.7:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.1`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.2`,
        fs:  `cpe:2.3:o:freebsd:freebsd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.3`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:a.01.08.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.4`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.99.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.5`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.6`,
        fs:  `cpe:2.3:a:linear_case_project:linear_case:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.2`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.0`,
        fs:  `cpe:2.3:a:hp:performance_access:10.50.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.1`,
        fs:  `cpe:2.3:a:apple:quicktime:7.2.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.4`,
        fs:  `cpe:2.3:h:intel:active_management_technology:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.5`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.3.0`,
        fs:  `cpe:2.3:a:splunk:splunk:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.3.0.0`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.3.0.1`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.1:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.3.0.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_application_dependency_discovery_manager:7.3.0.3`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_discovery_for_distributed:7.2.2`,
        fs:  `cpe:2.3:a:ca:license_software:1.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_discovery_for_distributed:7.2.2.0`,
        fs:  `cpe:2.3:o:juniper:ive_os:7.1r13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_discovery_for_distributed:7.5`,
        fs:  `cpe:2.3:a:gnu:readline:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:1.0.5.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:6.0`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:6.2`,
        fs:  `cpe:2.3:h:cisco:edge_340:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.1`,
        fs:  `cpe:2.3:a:altiris:patch_management:6.2.3643:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.1.1.12`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_basic_runtime_for_visual_studio_2008:10.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.1.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.2`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.2.0.1`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.2.1.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.2.1.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_asset_management_for_it:7.2.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_base_services:1.0.5.3`,
        fs:  `cpe:2.3:o:trustix:secure_linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_base_services:7.1.1.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_business_service_manager:-`,
        fs:  `cpe:2.3:a:nec:sockscap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_business_service_manager:4.1`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_business_service_manager:4.1.1`,
        fs:  `cpe:2.3:a:sgi:xfsprogs:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_business_systems_manager:-`,
        fs:  `cpe:2.3:a:divx:converter:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_business_systems_manager:3.1`,
        fs:  `cpe:2.3:a:sparkjava:spark:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_change_and_configuration_management_database:1.0.5.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.455.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_common_reporting:2.1`,
        fs:  `cpe:2.3:a:qemu:qemu:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_common_reporting:2.1.1`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_common_reporting:2.1.1.2`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_common_reporting:3.1`,
        fs:  `cpe:2.3:a:yaml-fuer-drupal:linkchecker:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_common_reporting:3.1.0.1`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor_le:3.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_common_reporting:3.1.0.2`,
        fs:  `cpe:2.3:a:bouqs_-_flowers_simplified_project:bouqs_-_flowers_simplified:1.8.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_common_reporting:3.1.2`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:7.0:2005q4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_common_reporting:3.1.2.1`,
        fs:  `cpe:2.3:a:ca:unicenter_service_level_management:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_configuration_manager:-`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_configuration_manager:4.2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.8.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_configuration_manager_for_atm:-`,
        fs:  `cpe:2.3:a:magzter:gr8\!_tv:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_configuration_manager_for_atm:2.1`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_continuous_data_protection_for_files:-`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.7:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_continuous_data_protection_for_files:3.1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:3.2.2`,
        fs:  `cpe:2.3:a:endonesia:endonesia:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:4.1`,
        fs:  `cpe:2.3:a:acme:thttpd:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:5.2.0`,
        fs:  `cpe:2.3:a:duplicator_project:duplicator:0.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.0`,
        fs:  `cpe:2.3:h:ibm:advanced_management_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.0.0.7`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.0.0.8`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.0.0.73`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.0.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.1`,
        fs:  `cpe:2.3:a:x.org:libx11:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.2`,
        fs:  `cpe:2.3:a:evan_dandrea:usb-creator:0.2.38.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.3`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.4`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.6`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.7`,
        fs:  `cpe:2.3:a:bioinformatics:ordersys:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.8`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.0.8:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.9`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p1_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.11`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.12`,
        fs:  `cpe:2.3:a:hp:universal_configuration_management_database:9.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.13`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.14`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0569:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.15`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.17`,
        fs:  `cpe:2.3:a:google:update_helper:1.3.21.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.18`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.19`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.20`,
        fs:  `cpe:2.3:h:logitech:itouch_keyboard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.21`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.22`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:2011205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.23`,
        fs:  `cpe:2.3:a:karsten_dusterloh:mnenhy:0.7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.24`,
        fs:  `cpe:2.3:a:mit:kerberos:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.25`,
        fs:  `cpe:2.3:a:vmware:tools:8.6.0.6261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.26`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.27`,
        fs:  `cpe:2.3:a:gnu:gnash:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.28`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.29`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.30`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.31`,
        fs:  `cpe:2.3:a:mcafee:vulnerability_manager:7.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.32`,
        fs:  `cpe:2.3:a:ca:server_protection_suite:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.33`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.34`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.1.91.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.35`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.36`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.37`,
        fs:  `cpe:2.3:h:cisco:anomaly_guard_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.38`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(21\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.39`,
        fs:  `cpe:2.3:a:freebsd:heimdal:0.4e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.40`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.41`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.30.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.42`,
        fs:  `cpe:2.3:a:cisco:firepower_threat_defense:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.43`,
        fs:  `cpe:2.3:a:paypal:transactional_information_soap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.44`,
        fs:  `cpe:2.3:a:quick_page\/post_redirect_project:quick_page\/post_redirect:5.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.45`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.46`,
        fs:  `cpe:2.3:h:hp:3com_switch:e4510-24g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.47`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.48`,
        fs:  `cpe:2.3:a:symantec:raptor_firewall:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.49`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.50`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.51`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.52`,
        fs:  `cpe:2.3:a:redhat:rhel_application_stack:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.53`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.54`,
        fs:  `cpe:2.3:a:hp:performance_agent:4.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.55`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.56`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.53:-:hp-ux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.57`,
        fs:  `cpe:2.3:a:jease:jease:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.58`,
        fs:  `cpe:2.3:h:lexmark:c920:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.59`,
        fs:  `cpe:2.3:a:redhat:resteasy:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.60`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0071:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.61`,
        fs:  `cpe:2.3:a:ibm:quickfile:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.62`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.63`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.0\(1\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.64`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.65`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.5d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.1.0.66`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.8:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.0`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.2`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.3`,
        fs:  `cpe:2.3:a:perl:perl:2.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.426:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.6`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma601xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.7`,
        fs:  `cpe:2.3:a:perl:perl:5.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.8`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.10`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.11`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.12`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.13`,
        fs:  `cpe:2.3:h:juniper:idp75:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.14`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.15`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.19`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.20`,
        fs:  `cpe:2.3:a:logitech:videocall\&#43;callmanager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.21`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.22`,
        fs:  `cpe:2.3:a:percona:percona_server:5.7.11-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.23`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.24`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.51.020.2725:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.25`,
        fs:  `cpe:2.3:a:samba:ppp:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.26`,
        fs:  `cpe:2.3:o:advantech:vesp211-eu_firmware:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.27`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.29`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1012.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.30`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.31`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.2.2:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.32`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_gateway:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.33`,
        fs:  `cpe:2.3:o:hp:laserjet_pro_m1212nf_mfp_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.34`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.35`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.36`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-60:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.37`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1014:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.38`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.39`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_agent:11.0.17318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.40`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.41`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.2.0.42`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.0`,
        fs:  `cpe:2.3:a:red-gate:sql_comparison_sdk:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.2`,
        fs:  `cpe:2.3:h:cisco:vpn_500_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.8`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.9`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.583:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.10`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.11`,
        fs:  `cpe:2.3:h:linksys:wet11:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.12`,
        fs:  `cpe:2.3:a:opscode:chef:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.14`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.15`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_performance_manager:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.17`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.18`,
        fs:  `cpe:2.3:a:hp:web_registration:82.0.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.19`,
        fs:  `cpe:2.3:h:cisco:catalyst_2820:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.21`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.22`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_antivirus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.23`,
        fs:  `cpe:2.3:a:netscape:navigator:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.24`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.25`,
        fs:  `cpe:2.3:a:microsoft:access:2010:sp2:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.26`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.27`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.28`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.29`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.30`,
        fs:  `cpe:2.3:a:openstack:essex:2012.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.31`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.32`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.33`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.34`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r71.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.0.35`,
        fs:  `cpe:2.3:a:apache:groovy:2.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.1.0`,
        fs:  `cpe:2.3:a:siemens:scalance_x308-2m_firmware:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.1.5`,
        fs:  `cpe:2.3:a:mcafee:scan_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.1.6`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.1.7`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.1.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.3.1.9`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_directory_server:6.4.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_endpoint_manager:8.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_endpoint_manager:8.1`,
        fs:  `cpe:2.3:a:sun:staroffice:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_endpoint_manager:8.2`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_endpoint_manager:8.2:patch3`,
        fs:  `cpe:2.3:a:horde:imp:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_endpoint_manager:9.1`,
        fs:  `cpe:2.3:o:tp-link:tl-wr840n_firmware:3.13.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_endpoint_manager:9.1.1117`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r304.125:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_endpoint_manager_mobile_device_management:9.0`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_enterprise_console:-`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.1.1`,
        fs:  `cpe:2.3:a:spamtitan:webtitan:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.1.1.12`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.1.1.13`,
        fs:  `cpe:2.3:a:orbitscripts:orbit_open_ad_server:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0`,
        fs:  `cpe:2.3:a:php:php:5.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.1`,
        fs:  `cpe:2.3:a:ibm:java:6.0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.3`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.8`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.1\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.9`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:49.1.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.10`,
        fs:  `cpe:2.3:h:hp:8\/20q_fibre_channel_switch_8_port:aq233a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.11`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.12`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.13`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.14`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:05-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.15`,
        fs:  `cpe:2.3:a:samba:samba:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.16`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.0.17`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.8.65951.477:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p204:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.2`,
        fs:  `cpe:2.3:a:e107:e107:0.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.4`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.5`,
        fs:  `cpe:2.3:o:oracle:solaris:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.6`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.7`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.6.0.1356:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.8`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.1.9`,
        fs:  `cpe:2.3:a:openstack:neutron:juno-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.2`,
        fs:  `cpe:2.3:a:intel:network_connections:14.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5c\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.4`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.5`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.6`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.7`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.8`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.9`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.10`,
        fs:  `cpe:2.3:a:saurabh_gupta:tiny_server:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.11`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.12`,
        fs:  `cpe:2.3:a:google:chrome:53.0.2785.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.14`,
        fs:  `cpe:2.3:a:alvaro_herrera:pl\/php:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.15`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.7.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.16`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager:6.2.2.17`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.1.1`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)s7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.2`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.3`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.8`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.9`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.10`,
        fs:  `cpe:2.3:a:erlang:crypto:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.11`,
        fs:  `cpe:2.3:a:reality66:cart66_lite:1.5.1.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.1`,
        fs:  `cpe:2.3:a:redhat:bigmem_kernel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.1.3`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.1.4`,
        fs:  `cpe:2.3:a:oracle:oracle_berkeley_db:11.2.5.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.2`,
        fs:  `cpe:2.3:a:ibm:rational_service_tester:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_firewall_toolbox:-`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.1.171.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_firewall_toolbox:1.2`,
        fs:  `cpe:2.3:a:chyrp:chyrp:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:-`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:4.6`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.0.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.7.1.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.0.0.6`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.0.0.10`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.0.0.11`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.0.0.12`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.0.0.13`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.0.0.14`,
        fs:  `cpe:2.3:h:cisco:6400_nrp_2:12.1dc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.0.0.15`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.4`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.4.2.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.5`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.6`,
        fs:  `cpe:2.3:o:cisco:aireos:7.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.7`,
        fs:  `cpe:2.3:a:hp:xp_p9000_replication_manager:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.8`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.9`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.10`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.1.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.11`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.12`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.13`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.14`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_identity_manager:5.1.0.15`,
        fs:  `cpe:2.3:a:xda-developers:xda-developers:3.9.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_integrated_portal:2.1`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_integrated_portal:2.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.1.1\(30\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_integration_composer:7.2.0.0`,
        fs:  `cpe:2.3:a:yumenomachi:demaecan:2.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_integration_composer:7.2.2.2`,
        fs:  `cpe:2.3:a:drupal:drupal:7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_it_asset_management_for_it:6.2.8`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_it_asset_management_for_it:7.1.1.7`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_it_asset_management_for_it:7.1.1.8`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_it_asset_management_for_it:7.1.1.11`,
        fs:  `cpe:2.3:a:moodle:moodle:3.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_it_asset_management_for_it:7.1.1.12`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_management_framework:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_management_framework:3.6`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:-:developer:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_management_framework:3.6.1`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-8c-si_ls-s3100-8c-si-ac-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_management_framework:3.7`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_management_framework:3.7.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_management_framework:4.1.1`,
        fs:  `cpe:2.3:a:defence:defence.pk:2.4.13.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.1.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.1.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.0`,
        fs:  `cpe:2.3:h:intel:mobile_intel_qs67_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.0.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.0.2`,
        fs:  `cpe:2.3:a:news_revolution_-_bahrain_project:news_revolution_-_bahrain:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.0.3`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.1`,
        fs:  `cpe:2.3:a:mcafee:advanced_threat_defense:3.4.4.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.1.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.1.1`,
        fs:  `cpe:2.3:h:hp:3com_router:6080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.1.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.1.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.96.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.1.4`,
        fs:  `cpe:2.3:a:radscan:network_audio_system:1.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.0`,
        fs:  `cpe:2.3:a:hp:software_configuration:6.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.1`,
        fs:  `cpe:2.3:a:efence_project:efence:1.3.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.4`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.b1.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.5`,
        fs:  `cpe:2.3:a:jedit:jedit:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.6`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.7`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.8`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.2.9`,
        fs:  `cpe:2.3:h:hp:h3c_router:sr8812:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.3`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.3.0`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.3.1`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.3.2`,
        fs:  `cpe:2.3:h:cisco:sf300-48:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.3.3`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.3.4`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.2.3.5`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.3.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.3.0.1`,
        fs:  `cpe:2.3:a:ibm:lotus_symphony:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.3.0.2`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.60:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.3.0.3`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.3.0.4`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:14.04:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.3.0.5`,
        fs:  `cpe:2.3:a:microsoft:excel_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.3.0.6`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator:3.3.1048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring:6.3.0.7`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring_express:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_monitoring_express:6.1.0`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp3:tablet_pc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fimpact:6.1.1`,
        fs:  `cpe:2.3:a:andrew_levine:multiblock:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:1.0.0.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.0`,
        fs:  `cpe:2.3:a:microsoft:pocket_internet_explorer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.0.4`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:7.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.0.5`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:8.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.1.0`,
        fs:  `cpe:2.3:a:agilebits:knox:1.6.0:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.1.1`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.1.2`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(0.7\)pan:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.1.3`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.1.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.1.5`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.3.1.6`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.4.0`,
        fs:  `cpe:2.3:a:revouninstaller:uninstaller:1.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.4.0.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2fomnibus:7.4.0.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je028a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0:tiv-ncreporter-if0001`,
        fs:  `cpe:2.3:a:c4plans:k-tool:3.31.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0:tiv-ncreporter-if0002`,
        fs:  `cpe:2.3:a:netiq:self_service_password_reset:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0.2`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0.3`,
        fs:  `cpe:2.3:a:gfi:gfi_reportcenter_framework:3.6.2009.630:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0.4`,
        fs:  `cpe:2.3:a:hp:photo_gallery:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0.5`,
        fs:  `cpe:2.3:a:apache:ignite:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0.6`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0.7`,
        fs:  `cpe:2.3:a:hp:scannercopy:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool%2freporter:2.2.0.8`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool_application_service_monitors:4.0.0`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.2.03013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool_application_service_monitors:4.0.1`,
        fs:  `cpe:2.3:a:cisco:internet_streamer_content_delivery_system:3.1.2b54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool_security_manager:-`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool_security_manager:1.3.0`,
        fs:  `cpe:2.3:a:ssh:tectia_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool_system_service_monitors:4.0.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool_system_service_monitors:4.0.1`,
        fs:  `cpe:2.3:a:microsoft:picture_it:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netcool_webtop:2.1.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.935.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.6i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:1.4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:5.0`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:5.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:f9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:5.2`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:5.3`,
        fs:  `cpe:2.3:a:nero:nero:9.0.9.100:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:5.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:6.0`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:6.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:7.1.4`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview:7.1.5`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview_access_services:-`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview_os_380:-`,
        fs:  `cpe:2.3:a:huawei:s7700_firmware:v200r003c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_netview_os_390:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.956.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_network_storage_manager:-`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_omegamon_xe_for_messaging:601`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_omegamon_xe_for_messaging_on_z%2fos:601`,
        fs:  `cpe:2.3:h:hp:jf806a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_opc_tracker_agent:-`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.0.1679:unknown:online_windows_2000:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_express:-`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_os_deployment:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_os_deployment:5.1.0.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_os_deployment:5.1.0.116`,
        fs:  `cpe:2.3:a:tenable:nessus:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_os_deployment:7.1.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_os_deployment:7.1.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_os_deployment:7.1.1.1`,
        fs:  `cpe:2.3:a:roxio:burn:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_os_deployment:7.1.1.2`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-355:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_provisioning_manager_os_deployment:7.1.1.3`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:a.01.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_remote_control:5.1.2`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_secureway_policy_director:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_secureway_policy_director:3.0.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.371:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_secureway_policy_director:3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_secureway_policy_director:3.7`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_secureway_policy_director:3.7.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_secureway_policy_director:3.8`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_desk:-`,
        fs:  `cpe:2.3:a:apple:xcode:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_desk:6.2`,
        fs:  `cpe:2.3:a:cisco:jabber_guest:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager_for_vmware:6.4.2:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.1.0`,
        fs:  `cpe:2.3:a:microsoft:jet:4.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.1.0.0`,
        fs:  `cpe:2.3:a:miniclip:mini_pets:2.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.1.1`,
        fs:  `cpe:2.3:a:microsoft:visio:2002:sp2:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.1.1.7`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.1.1.8`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.1.1.11`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.1.1.12`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)dc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.2`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.2.0.0`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.2.0.1`,
        fs:  `cpe:2.3:o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.2.1.0`,
        fs:  `cpe:2.3:a:divx:content_uploader:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.2.1.2`,
        fs:  `cpe:2.3:h:cisco:rv082_dual_wan_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_service_request_manager:7.2.2`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:-`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:2.1.0`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:2.2.0`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:2.2.1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:3.1.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.736.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:3.1.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.30:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:3.2.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.06:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:3.2.1`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:4.1.0`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:4.1.0.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager:6.1.3`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager_for_vmware:3.1::~~~vmware~~`,
        fs:  `cpe:2.3:a:david_king:vino:2.7.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager_for_vmware:3.1.1::~~~vmware~~`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager_for_vmware:3.2::~~~vmware~~`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager_for_vmware:6.3::~~~vmware~~`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager_for_vmware:6.4::~~~vmware~~`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager_for_vmware:6.4.2::~~~vmware~~`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_flashcopy_manager_for_vmware:6.4.3::~~~vmware~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)sv3\(1.5b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:-`,
        fs:  `cpe:2.3:a:siemens:wincc:7.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:4.2`,
        fs:  `cpe:2.3:a:abbyy:finereader:5.0:-:office:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:4.2.1`,
        fs:  `cpe:2.3:h:supermicro:x7spa-hf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.1.8`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.2.5.1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.2.7`,
        fs:  `cpe:2.3:a:indusoft:web_studio:7.1:sp2_p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.2.8`,
        fs:  `cpe:2.3:a:oracle:marketing:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.2.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.3.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:9.40.uc5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.3.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.3.2`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.3.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.4.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.4.3.4`,
        fs:  `cpe:2.3:a:yodobashi:yodobashi:1.2.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.4.3.6`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.5`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.5.0`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2002:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.5.2`,
        fs:  `cpe:2.3:a:mono:mono:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.5.3`,
        fs:  `cpe:2.3:a:citrix:xenapp_reports:4.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.5.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.424.6:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.5.4.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.5.4.2`,
        fs:  `cpe:2.3:a:gnu:realtime_linux_security_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:5.5.4.3`,
        fs:  `cpe:2.3:a:ibm:spss_samplepower:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1`,
        fs:  `cpe:2.3:h:enterasys:ssr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.1`,
        fs:  `cpe:2.3:a:zodiacdm:aboutme-plugin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.4`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.5`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.5.4`,
        fs:  `cpe:2.3:a:mahara:mahara:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.5.5`,
        fs:  `cpe:2.3:a:xnview:xnview:1.93.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.1.5.6`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.373:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.2.0`,
        fs:  `cpe:2.3:a:smarty:smarty:2.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.2.1`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb991xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.2.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.2.3`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.2.4`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.2.4.7`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3.0`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3.0.5`,
        fs:  `cpe:2.3:a:buffalotech:wer-ag54_firmware:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3.0.15`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3.0.17`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3.1`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3.1.2`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.40:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3.2.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:ga:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.3.6`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.28:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.0`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.0.4`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.0.5`,
        fs:  `cpe:2.3:a:compaq:enterprise_volume_manager-command_scripter:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.0.7`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.1.0`,
        fs:  `cpe:2.3:o:huawei:ar_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.1.1`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.1.3`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.1.7`,
        fs:  `cpe:2.3:a:lyften:com_lyftenbloggie:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.2.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.10.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.2.2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1305.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.2.3`,
        fs:  `cpe:2.3:o:cisco:staros:21.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.2.4`,
        fs:  `cpe:2.3:a:tibco:formvine:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.2.100`,
        fs:  `cpe:2.3:a:busybox:busybox:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.2.200`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.2.500`,
        fs:  `cpe:2.3:a:heartlogic.jp:hl-sitemanager:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.2.600`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.3`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:6.4.3.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53_97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1..5.100`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.0.1`,
        fs:  `cpe:2.3:o:sophos:web_appliance_firmware:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.0.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.0.3`,
        fs:  `cpe:2.3:a:mcafee:agent:4.6.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.1`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.1.1`,
        fs:  `cpe:2.3:o:google:android:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.1.2`,
        fs:  `cpe:2.3:a:cypherpunks:pidgin-otr:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.1.100`,
        fs:  `cpe:2.3:h:cisco:building_broadband_service_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.1.200`,
        fs:  `cpe:2.3:a:ibm:websphere_enterprise_service_bus:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.1.300`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.3`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.3.000`,
        fs:  `cpe:2.3:o:virtualaccess:gw6110a_firmware:9.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.3.1`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.3.2`,
        fs:  `cpe:2.3:a:themepunch:slider_revolution:3.0.95:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.3.100`,
        fs:  `cpe:2.3:a:macromedia:contribute:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.4`,
        fs:  `cpe:2.3:h:nortel:wlan_access_point_2225:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.4.1`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.4.2`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.407:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.5.200`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.6`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.6.4`,
        fs:  `cpe:2.3:a:openstack:havana:havana-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.6.6`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:7.1.7`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager:8.1.0.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:-`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.0.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.1.8.0`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.1.8.1`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.2`,
        fs:  `cpe:2.3:a:docker:docker:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.2.5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.243:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.2.5.2`,
        fs:  `cpe:2.3:a:smartsound:common_data:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.3`,
        fs:  `cpe:2.3:a:ca:internet_security_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.3.5.2`,
        fs:  `cpe:2.3:o:dell:sonicwall_secure_remote_access_firmware:7.5.1.0-38sv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.3.5.3`,
        fs:  `cpe:2.3:a:nextapp:echo:3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.4.1.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.4.1.2`,
        fs:  `cpe:2.3:a:instatalks:instatalks:1.3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.4.2.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.5.0.0`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_client:5.5.0.91`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_express:-`,
        fs:  `cpe:2.3:a:smarty:smarty:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_express:5.3`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:3.5.604`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.96.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:3.5.705`,
        fs:  `cpe:2.3:a:ibm:java:6.0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:3.5.801`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:3.5.802`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:3.5.804`,
        fs:  `cpe:2.3:a:redhat:jboss_drools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_131:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.2`,
        fs:  `cpe:2.3:a:oracle:html_db:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.2.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.1m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.3.0`,
        fs:  `cpe:2.3:a:qemu:qemu:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.4.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p182:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.6.0`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:5.5.7`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p234:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.0.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update8:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.0.1`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:1.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.1.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.2.0`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:2.3.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.3.0`,
        fs:  `cpe:2.3:a:gajim:gajim:0.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.4.0`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.5`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.5.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.5.2`,
        fs:  `cpe:2.3:a:websense:triton_web_security_gateway:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.6`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.6.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.6.1`,
        fs:  `cpe:2.3:h:mcafee:intrushield_security_management_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.6.2`,
        fs:  `cpe:2.3:a:gnu:groff:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.7`,
        fs:  `cpe:2.3:a:baramundi:management_suite:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.7.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.7.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.09.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.7.2`,
        fs:  `cpe:2.3:a:paypal:payments_standard:20120427:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.8`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.8.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.8.1`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.8.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.9`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.9.0`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.47.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.9.1`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p255:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.10.0`,
        fs:  `cpe:2.3:a:aol:aim:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.10.1`,
        fs:  `cpe:2.3:h:intel:d845pt_motherboard:p01-0012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.11`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.9h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.11.0`,
        fs:  `cpe:2.3:a:ibm:aix_parallel_systems_support_programs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.11.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.12`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_fastback:6.1.12.1`,
        fs:  `cpe:2.3:a:mystorexpress:tienda_virtual:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.3.1.1`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.6.0_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.3.1.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.3.1.3`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.1.1001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.3.1.5`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.0.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.2:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.0.2`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.1`,
        fs:  `cpe:2.3:a:spip:spip:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.2`,
        fs:  `cpe:2.3:a:op5:system-portal:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.3`,
        fs:  `cpe:2.3:a:ibm:powerha_system_mirror:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.4`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.1.7`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:7.1.0.1`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:milestone2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:7.1.0.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:7.1.1.1`,
        fs:  `cpe:2.3:a:divx:web_player:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:7.1.2.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_mail:-`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:6.61:sp2a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.0.1`,
        fs:  `cpe:2.3:h:hp:jg296a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.0.2`,
        fs:  `cpe:2.3:a:apache:ignite:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.2.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.2.1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.3.0`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:5.2.0`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:5.3.0`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:5.4.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:5.5.0`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:6.1.0`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:6.2.0`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r9_p1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:6.3.0`,
        fs:  `cpe:2.3:a:naver:nhn_japan_naver_line:2.5.5:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:6.3.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:6.3.3`,
        fs:  `cpe:2.3:a:apple:itunes:4.7.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:6.4.0`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_space_management:7.1.0`,
        fs:  `cpe:2.3:a:yahoo:yui:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.0.0`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.1.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.2.0`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.2.1`,
        fs:  `cpe:2.3:a:apache:subversion:0.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.3.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:6.4`,
        fs:  `cpe:2.3:a:simone_tellini:mod_accounting:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:6.4.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(10\)w5\(18g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:6.4.1.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(2\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:7.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.231:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:7.1.0.0`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:7.1.0.1`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments:7.1.0.2`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:4.1.0::~~~vmware~~`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:-:driveshield:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:4.1.1::~~~vmware~~`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:4.1.2::~~~vmware~~`,
        fs:  `cpe:2.3:a:microsoft:groove_server:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:4.1.3::~~~vmware~~`,
        fs:  `cpe:2.3:h:ibm:ds4300:1722:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:6.3.1::~~~vmware~~`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:6.3.2::~~~vmware~~`,
        fs:  `cpe:2.3:a:icinga:icinga:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:6.4.1::~~~vmware~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:7.1.0::~~~vmware~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:7.1.1::~~~vmware~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p397:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:7.1.2::~~~vmware~~`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:7.1.3::~~~vmware~~`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:toolscenter_suite:9.60`,
        fs:  `cpe:2.3:a:symantec:product_authorization_service:4.3.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:totalstorage_ds400:-`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:totalstorage_ds400:4.15`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:trading_partner_interchange:-`,
        fs:  `cpe:2.3:a:exim:exim:4.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:trading_partner_interchange:4.2.1`,
        fs:  `cpe:2.3:a:process-one:ejabberd:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:trading_partner_interchange:4.2.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:traveler:8.5.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:16.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:traveler:9.0`,
        fs:  `cpe:2.3:h:lexmark:e460dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:traveler:9.0.1`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:2.1`,
        fs:  `cpe:2.3:a:phillip_lougher:squashfs:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:2.5`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:2.6`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:2.7`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.0`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.2314.1003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.1`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.2`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.2.1`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.0.0`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.29:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.290:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.0.2`,
        fs:  `cpe:2.3:a:adobe:photoshop:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.1.0`,
        fs:  `cpe:2.3:a:novell:small_business_suite:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.1.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:9.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.1.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:11.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.2.0`,
        fs:  `cpe:2.3:o:netgear:r7900_firmware:1.0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.2.1`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.2.3`,
        fs:  `cpe:2.3:a:openstack:swift:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.2.4`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.3.2.5`,
        fs:  `cpe:2.3:a:sun:one_administration_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.0.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.29.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.1.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan_vpn_client:1.4.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.1.2`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.1.3`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.2.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.05:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.2.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.2.2`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.2.3`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.2.4`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.4.2.5`,
        fs:  `cpe:2.3:a:real:realplayer:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.0.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.14.1592:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.0.1`,
        fs:  `cpe:2.3:h:3com:3c16485:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.0.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.1`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_30-20_poe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.1.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.1.1`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.1.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.1.3`,
        fs:  `cpe:2.3:a:busybox:busybox:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:3.5.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:8.0`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:10.4`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.5.40_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:tririga_application_platform:10.5`,
        fs:  `cpe:2.3:a:apache:qpid:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ts3100:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:ts3200:-`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:u2_universe:-`,
        fs:  `cpe:2.3:h:3com:tippingpoint_50:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:u2_universe:10.0.0.9`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:updatexpress_system_packs_installer:9.60`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0`,
        fs:  `cpe:2.3:o:freebsd:freebsd:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.1`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.2`,
        fs:  `cpe:2.3:a:flock:flock:0.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.3`,
        fs:  `cpe:2.3:a:ayatana_project:unity:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.4`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp6:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.5`,
        fs:  `cpe:2.3:a:emc:networker:7.6.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.6`,
        fs:  `cpe:2.3:a:aker:secure_mail_gateway:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.7`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.8`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.424.5:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.10`,
        fs:  `cpe:2.3:a:atlassian:jira:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.11`,
        fs:  `cpe:2.3:a:cisco:webns:7.20_\(03.10\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.12`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:dev1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.0.1.13`,
        fs:  `cpe:2.3:o:ibm:aix:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.0.1`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_client:6.1.20000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.0.3`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.0.4`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.1`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.4`,
        fs:  `cpe:2.3:a:openstack:compute:2013.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.5`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.6`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.7`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.1.8`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:11.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.2`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_controller_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.3`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.0-14:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.1.3.2`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.2.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.2.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.2.0.201`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.2.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:urbancode_deploy:6.2.1.1`,
        fs:  `cpe:2.3:a:pyyaml:libyaml:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:vios:1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(10d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:vios:1.4`,
        fs:  `cpe:2.3:a:zodiacdm:aboutme-plugin:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:1.4.1.2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:1.5`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:vios:1.5`,
        fs:  `cpe:2.3:a:busybox:busybox:1.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:1.5.1.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p402:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:1.5.2.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:1.5.2.6`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.22.265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:vios:2.0`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:vios:2.1`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.1.0.0`,
        fs:  `cpe:2.3:a:httrack:httrack:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.1.2.10`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sy10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.1.2.12`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.1.2.13`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:9.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.1.3.10`,
        fs:  `cpe:2.3:a:citrix:secure_gateway:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.0.0`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.0.10`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.0.11`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.0.12`,
        fs:  `cpe:2.3:a:apprain:apprain:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.0.13`,
        fs:  `cpe:2.3:a:ibm:rational_change:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(1.20\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.1`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.625.1:*:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.4`,
        fs:  `cpe:2.3:a:magzter:inspire_weddings:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.4:fp-25_sp-02`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:rc.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.5`,
        fs:  `cpe:2.3:a:microsoft:outlook:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.6`,
        fs:  `cpe:2.3:a:oracle:http_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.7`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.61:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.8`,
        fs:  `cpe:2.3:a:cisco:spark:2015-07-04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.1.9`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.2.0`,
        fs:  `cpe:2.3:a:debian:apt:0.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.2.1`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:01-01-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.2.2`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.2.3`,
        fs:  `cpe:2.3:a:absolute:computrace:8.0.885:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.2.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.625.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.2.5`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.2.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p91:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.2.70`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:6.3.0.870:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.0`,
        fs:  `cpe:2.3:a:redmine:redmine:0.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.1`,
        fs:  `cpe:2.3:a:openttd:openttd:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.2`,
        fs:  `cpe:2.3:a:koha:koha:3.14.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.3`,
        fs:  `cpe:2.3:a:checkpoint:remote_access_clients:e75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.4`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.50`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.51`,
        fs:  `cpe:2.3:a:ibm:leads:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.52`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.60`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.70`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.3.80`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.4.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.4.10`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.4.21`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.4.22`,
        fs:  `cpe:2.3:a:apache:struts:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.4.23`,
        fs:  `cpe:2.3:a:samba:samba:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.4.30`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.5.0`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:vios:2.2.5.10`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:visualage_for_java:-`,
        fs:  `cpe:2.3:a:isc:bind:9.2.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:watson_developer_cloud:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_content_manager:6.1.5`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_content_manager:7.0.0.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_content_manager:7.0.0.1:cf002`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_content_manager:7.0.0.1:cf003`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_content_manager:7.0.0.1:cf004`,
        fs:  `cpe:2.3:a:apache:subversion:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_content_manager:8.0.0.0:cf003`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:16.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_content_manager_production_analytics:4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:6.1.5`,
        fs:  `cpe:2.3:a:webmin:webmin:1.630:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:7.0.1.1`,
        fs:  `cpe:2.3:h:dell:optiplex_390:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:7.0.1.2`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:7.0.1.3`,
        fs:  `cpe:2.3:o:cisco:spa_500_series_ip_phone_firmware:7.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:7.0.1.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-50-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:8.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:8.0.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:8.0.0.1`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:8.0.0.2`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:8.0.0.3`,
        fs:  `cpe:2.3:a:pmail:mercury_mail_transport_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:8.5`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:web_experience_factory:8.5.0.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:-`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:017:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:-:-:~~~z%2fos~~`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:2.0`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.12:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.0`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.0.0.3:-:community`,
        fs:  `cpe:2.3:a:erik_michaels-ober:multi_xml:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.0.2`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.0.2.1`,
        fs:  `cpe:2.3:h:cisco:ips_4520_sensor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.0.2.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p161:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.0.2.3`,
        fs:  `cpe:2.3:a:apple:itunes:12.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.0.2.4`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.0.21`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.5`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(6b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.5.1`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization_manager:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.5.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.5.3`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:3.52`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:4.0.1`,
        fs:  `cpe:2.3:a:cobblerd:cobbler:2.4.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:4.0.2`,
        fs:  `cpe:2.3:h:apple:imac:m9823xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:4.0.3`,
        fs:  `cpe:2.3:a:cisco:application_velocity_system:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:4.0.4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.386:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.0`,
        fs:  `cpe:2.3:a:autodesk:autocad_architecture_2010:6.0.70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.1`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.1`,
        fs:  `cpe:2.3:a:oracle:agile_engineering_data_management:6.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.3`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.4`,
        fs:  `cpe:2.3:a:mayan-edms:mayan_edms:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.5`,
        fs:  `cpe:2.3:a:cisco:ids_sensor_software:4.1\(4\)e0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.6`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.7`,
        fs:  `cpe:2.3:o:gehealthcare:discovery_530c_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.8`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.9`,
        fs:  `cpe:2.3:a:novell:identity_manager:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.10`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.11`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:0.25.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.12`,
        fs:  `cpe:2.3:a:plataformatec:devise:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.13`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.394:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.14`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_server:5.0.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.15`,
        fs:  `cpe:2.3:a:nokia:sgsn_dx200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.0.2.16`,
        fs:  `cpe:2.3:a:apple:apple_tv:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.0`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.0.2`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.0.3`,
        fs:  `cpe:2.3:a:citrix:delivery_services_console_report_center:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.0.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.0.5`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a6\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.1`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.2`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:11.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.3`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.4`,
        fs:  `cpe:2.3:a:apache:camel:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.5`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.6`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.7`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.8`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.9`,
        fs:  `cpe:2.3:a:netscape:communicator:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.10`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.11`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.12`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.14`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.15`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.16`,
        fs:  `cpe:2.3:a:northropgrumman:ecgs:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:5.1.1.17`,
        fs:  `cpe:2.3:a:compaq:insight_manager_xe:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0`,
        fs:  `cpe:2.3:a:google:toolbar:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.0.1`,
        fs:  `cpe:2.3:h:ibm:e56:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.0.2`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.2.2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.0.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.3`,
        fs:  `cpe:2.3:a:oracle:industry_applications:13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.5`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.7`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.9`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.11`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.13`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.15`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.1.17`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_server:6.1.3_build_8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2`,
        fs:  `cpe:2.3:a:gajennings:this:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.1`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.2`,
        fs:  `cpe:2.3:a:plone:plone:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.694.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.4`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp2:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.5`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.13:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.7`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.9`,
        fs:  `cpe:2.3:a:huntington:huntington_mobile:2.1.222:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.11`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.13`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.75:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.15`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.17`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.19`,
        fs:  `cpe:2.3:a:senkas:kolibri:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.22`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.23`,
        fs:  `cpe:2.3:a:samba:samba:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.24`,
        fs:  `cpe:2.3:a:python:python:2.6.6150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.25`,
        fs:  `cpe:2.3:a:isc:inn:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.27`,
        fs:  `cpe:2.3:o:google:android:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.28`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.29`,
        fs:  `cpe:2.3:a:bea:aqualogic_enterprise_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.30`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.01.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.31`,
        fs:  `cpe:2.3:a:novell:imanager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.32`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)pi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.33`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.15.277:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.35`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_338_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.37`,
        fs:  `cpe:2.3:a:sap:netweaver:7.0:sp15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.39`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.41`,
        fs:  `cpe:2.3:a:hp:openview_configuration_management:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.0.2.43`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.1.1.3711.11:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.6.0\(220\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.4.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.2`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.10.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.5`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.7`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.9`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.1:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.11`,
        fs:  `cpe:2.3:a:php:php:5.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.12`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.3.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.13`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1026:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.14`,
        fs:  `cpe:2.3:a:mozilla:durian_web_application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.15`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.17`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.19`,
        fs:  `cpe:2.3:h:sun:fire_x4440_server:sw_2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.21`,
        fs:  `cpe:2.3:a:altiris:client_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.23`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.29.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.25`,
        fs:  `cpe:2.3:o:cisco:ios:15.1m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.27`,
        fs:  `cpe:2.3:a:hp:icewall_smart_device_option:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.29`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.31`,
        fs:  `cpe:2.3:a:hansotools:hanso_player:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.33`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.35`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:2.6.32.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.37`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.39`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.41`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.43`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.45`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.0.47`,
        fs:  `cpe:2.3:a:firaxis:sid_meiers_civilization_iv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.1`,
        fs:  `cpe:2.3:a:arcsight:arcsight_console:5.0.1.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.3`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.5`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:06-70-\/g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.6`,
        fs:  `cpe:2.3:a:qbnz:geshi:1.0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.7`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:6.1.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)bc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.1`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_developer_suite:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.2`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.3`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:3.29.651.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.4`,
        fs:  `cpe:2.3:a:apache:libcloud:0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.5`,
        fs:  `cpe:2.3:a:python:python:3.3.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.7`,
        fs:  `cpe:2.3:h:huawei:e200e-b:v100r005c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.8`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.9`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.10`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.11`,
        fs:  `cpe:2.3:a:openx:openx:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.12`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.13`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_os_deployment:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.14`,
        fs:  `cpe:2.3:a:twimp-wp_project:twimp-wp:0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.15`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.1.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.16`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.17`,
        fs:  `cpe:2.3:h:hp:j9447a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.18`,
        fs:  `cpe:2.3:a:emc:sourceone_email_management:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.19`,
        fs:  `cpe:2.3:a:jamalbates:jamal_bates_show:1.3.14.254:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.21`,
        fs:  `cpe:2.3:a:ibm:net.commerce:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.22`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.23`,
        fs:  `cpe:2.3:a:otrs:faq:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.24`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.25`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-3:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.27`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.29`,
        fs:  `cpe:2.3:a:debian:apt-cacher:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.31`,
        fs:  `cpe:2.3:a:google:chrome:10.0.635.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.32`,
        fs:  `cpe:2.3:a:openstack:glance:2015.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.33`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.34`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.35`,
        fs:  `cpe:2.3:a:digia:qt:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.36`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.37`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.38`,
        fs:  `cpe:2.3:a:emc:retrospect_client:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.0.0.39`,
        fs:  `cpe:2.3:a:hp:destinations:140.0.77.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.1::~~lombardi~~~`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.1::lombardi`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.9:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:7.2::lombardi`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.834.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.3`,
        fs:  `cpe:2.3:a:apache:hadoop:0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.4`,
        fs:  `cpe:2.3:a:netscape:directory_server:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.5`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.6`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp3:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.7`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.8`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.9`,
        fs:  `cpe:2.3:a:ibm:infosphere_replication_server:10.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.10`,
        fs:  `cpe:2.3:a:util-linux_project:util-linux:2.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.11`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.0.0.12`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.0.0`,
        fs:  `cpe:2.3:a:spotlightyour:spotlightyour:4.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.0.0:-:liberty_profile`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.0.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:x7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.0.1:-:liberty_profile`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.0.2`,
        fs:  `cpe:2.3:a:oracle:java_db:10.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.0.2:-:liberty_profile`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.0`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.0:-:liberty_profile`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.1`,
        fs:  `cpe:2.3:a:phplist:phplist:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.1:-:liberty_profile`,
        fs:  `cpe:2.3:a:wokamoto:wp-cron_dashboard:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.2`,
        fs:  `cpe:2.3:a:sas:base_sas:9.3:ts1m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.2:-:liberty_profile`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.3`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.3:-:~~liberty_profile~~~`,
        fs:  `cpe:2.3:a:ibm:cognos_express:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.4`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.5`,
        fs:  `cpe:2.3:h:cisco:nexus_9332pq:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.6`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.7`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.3.0.3690:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.8`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:8.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.9`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.7.2\(256\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:8.5.5.9::~~liberty~~~`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:9.0.0.0`,
        fs:  `cpe:2.3:a:citrix:xenapp_commands:6.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server:16.0.0.2::~~liberty~~~`,
        fs:  `cpe:2.3:a:iopus:imacros:6.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.11`,
        fs:  `cpe:2.3:a:cabextract:cabextract:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.13`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.15`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.17`,
        fs:  `cpe:2.3:a:apache:struts:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.19`,
        fs:  `cpe:2.3:a:gnome:glib:2.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.21`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(3\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.23`,
        fs:  `cpe:2.3:a:kvirc:kvirc:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.25`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.27`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.29`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.31`,
        fs:  `cpe:2.3:a:ipswitch:imail:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.33`,
        fs:  `cpe:2.3:a:unitronics:visilogic_oplc_ide:9.8.0.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.35`,
        fs:  `cpe:2.3:a:apple:safari:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.37`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_9.0_firmware:9.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.39`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.41`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.43`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.45`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.47`,
        fs:  `cpe:2.3:a:cybozu:kunai_browser_for_remote_service:-:beta:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_application_server_toolkit:6.1`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_business_modeler_advanced:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_business_modeler_basic:-`,
        fs:  `cpe:2.3:a:sun:nss:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_caching_proxy_server:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_caching_proxy_server:3.6`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_caching_proxy_server:4.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:49.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_caching_proxy_server:5.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_cast_iron_solution:7.0.0`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_cast_iron_solution:7.0.0.1`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_cast_iron_solution:7.0.0.2`,
        fs:  `cpe:2.3:a:cisco:meetingtime:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_cast_iron_solution:7.5.0.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_cast_iron_solution:7.5.0.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_cast_iron_solution:7.5.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:5.6.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:5.6.1.1`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:9.0.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:5.6.1.2`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_server:11.0:sp2:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:5.6.1.3`,
        fs:  `cpe:2.3:a:mcafee:data_loss_prevention_endpoint:9.3.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:5.6.1.4`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:5.6.1.5`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.1`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.2`,
        fs:  `cpe:2.3:a:safer-networking:spybot_search_and_destroy:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.3`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.01.0600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.016.20039:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.5`,
        fs:  `cpe:2.3:a:adobe:pdf_settings_cs4:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.6`,
        fs:  `cpe:2.3:a:infoblox:netmri:6.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.7`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.7:pl2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.8`,
        fs:  `cpe:2.3:a:google:chrome:6.0.430.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.9`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.10`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:6.0.0.11`,
        fs:  `cpe:2.3:a:vmware:tools:9.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0:feature_pack_5`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0:feature_pack_6`,
        fs:  `cpe:2.3:a:anusthanokarehasya:baglamukhi:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0:feature_pack_7`,
        fs:  `cpe:2.3:a:hp:openview_security_core:2.20.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0:feature_pack_8`,
        fs:  `cpe:2.3:a:digium:asterisk:14.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:13.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.1`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.2`,
        fs:  `cpe:2.3:a:roxio:sonic_recordnow:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.569:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.4`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.5`,
        fs:  `cpe:2.3:o:cisco:staros:14.0\(600\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.6`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:1.0.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.7`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.8`,
        fs:  `cpe:2.3:a:flatpress:flatpress:0.804:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:7.0.0.9`,
        fs:  `cpe:2.3:a:apache:subversion:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.0.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.0.1`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.0.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.0.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.0.17`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.0.18`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.5.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.0.19`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.1.0`,
        fs:  `cpe:2.3:a:samba:samba:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.1.9`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.1.10`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.1.11`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.1.12`,
        fs:  `cpe:2.3:o:asus:wrt_firmware:3.0.0.4.376_1071:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.1.13`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.3.0`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.3.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.3.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.3.3`,
        fs:  `cpe:2.3:a:mysql:eventum:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.3.4`,
        fs:  `cpe:2.3:a:nokia:pc_suite:7.1.180.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.4.0`,
        fs:  `cpe:2.3:o:alliedtelesis:img646bd_firmware:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.4.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.4.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.4.3`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.4.4`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce:8.0.4.5`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce_suite:-`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce_suite:3.1.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce_suite:3.2`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert8:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce_suite:4.0.1`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce_suite_marketplace:-`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce_suite_service_provider:-`,
        fs:  `cpe:2.3:a:staples:staples_usb-to-serial_adapter:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_commerce_suite_start:-`,
        fs:  `cpe:2.3:a:mcafee:e-business_server:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_dashboard_framework:-`,
        fs:  `cpe:2.3:a:apple:safari:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_dashboard_framework:6.1.5`,
        fs:  `cpe:2.3:a:teeworlds:teeworlds:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_dashboard_framework:7.0.1`,
        fs:  `cpe:2.3:o:sun:solaris:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:websphere_datapower_xc10_appliance:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.440:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.0.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.4.7\(2229\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.0.0.1`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.0.0.2`,
        fs:  `cpe:2.3:a:gnu:enscript:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.0.0.3`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.1.0.0`,
        fs:  `cpe:2.3:a:sony:micro_vault_fingerprint_access_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.1.0.1`,
        fs:  `cpe:2.3:a:php:php:5.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.1.0.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.175:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.1.0.3`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.803:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.5`,
        fs:  `cpe:2.3:a:amd:app_sdk_runtime:2.4.650.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.0`,
        fs:  `cpe:2.3:a:plone:plone:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.1`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.2`,
        fs:  `cpe:2.3:a:animoca:fashion_style:3.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0.260:update26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_developer_for_system_z:7.0`,
        fs:  `cpe:2.3:a:hp:virtualvault:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_eclipse_platform:3.0.1`,
        fs:  `cpe:2.3:a:rsa:keon_certificate_authority_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_eclipse_platform:3.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_edge_server_caching_proxy:-`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_edge_server_caching_proxy:5.0.2`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.10:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_enterprise_service_bus:7.0`,
        fs:  `cpe:2.3:a:hp:lefthand_p4000_virtual_san_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_everyplace_server:-`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_everyplace_server:2.1.3`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_everyplace_server:2.1.4`,
        fs:  `cpe:2.3:h:axis:250s_video_server:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_everyplace_server:2.1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.0:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extended_deployment_compute_grid:8.0.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extended_deployment_compute_grid:8.0.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)t10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extended_deployment_compute_grid:8.0.0.2`,
        fs:  `cpe:2.3:a:zillionmuslims:zillion_muslims:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extended_deployment_compute_grid:8.0.0.3`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extended_deployment_compute_grid:8.5.0.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:7.1.0`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:7.1.1`,
        fs:  `cpe:2.3:a:juniper:installer_service:7.1.0.18193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.5.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.5.0.1`,
        fs:  `cpe:2.3:a:gentoo:syslinux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.5.0.2`,
        fs:  `cpe:2.3:a:spip:spip:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.0`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.112.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.2`,
        fs:  `cpe:2.3:o:openvas:greenbone_security_assistant:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.3`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.5`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.2:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.6`,
        fs:  `cpe:2.3:a:busybox:busybox:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.7`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale:8.6.0.8`,
        fs:  `cpe:2.3:a:isc:bind:9.2.2:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:7.0.0.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-00-\/i:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:7.1.0.0`,
        fs:  `cpe:2.3:a:cisco:as5300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:7.1.0.2`,
        fs:  `cpe:2.3:o:asus:rt-n14u_firmware:3.0.0.4.356:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:7.1.0.3`,
        fs:  `cpe:2.3:h:yokogawa:stardom_fcn\/fcj_opc_server:-:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:7.1.1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:7.1.1.1`,
        fs:  `cpe:2.3:a:altiris:svs_task_server_plugin_language_pack:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.5.0.0`,
        fs:  `cpe:2.3:o:xen:xen:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.5.0.1`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.5.0.2`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.5.0.3`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.6.0.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.6.0.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.6.0.2`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.6.0.3`,
        fs:  `cpe:2.3:a:adobe:stock_photos_cs3:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_extreme_scale_client:8.6.0.4`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_host_on-demand:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_host_on-demand:6.0`,
        fs:  `cpe:2.3:a:tumbleweed:validation_authority_publisher:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_host_on-demand:7.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_host_on-demand:8.0`,
        fs:  `cpe:2.3:h:siemens:scalance_w788-1pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_host_on-demand:9.0`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_ilog_rule_team_server:7.1.1`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.3.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.1`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.2`,
        fs:  `cpe:2.3:a:websense:triton_web_security:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.3`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.4`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.5`,
        fs:  `cpe:2.3:a:rpm:rpm:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.6`,
        fs:  `cpe:2.3:a:apache:ranger:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.7`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak_classic:1.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.8`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.9`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.10`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:6.1.0.11`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:7.0.`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:7.0.0.1`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:7.0.0.2`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:7.0.0.3`,
        fs:  `cpe:2.3:a:apple:apple_application_support:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:7.0.0.4`,
        fs:  `cpe:2.3:a:haxx:curl:7.49.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:7.0.0.5`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:7.0.0.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:7.0.0.7`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:8.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:8.0.0.1`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:8.0.0.2`,
        fs:  `cpe:2.3:a:olat:olat:7.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:8.0.0.3`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:8.0.0.4`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:8.0.0.5`,
        fs:  `cpe:2.3:a:opnet:ace_analyst_documentation:15.0.0.8623:*:*:*:plus:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker:8.0.0.7`,
        fs:  `cpe:2.3:a:ca:unicenter_network_and_systems_management:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker_explorer:7.0.0.1`,
        fs:  `cpe:2.3:h:snapgear:560:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_message_broker_toolkit:6.0.0.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:-`,
        fs:  `cpe:2.3:a:apache:openoffice.org:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:5.30.0`,
        fs:  `cpe:2.3:a:gnu:gnats:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.1.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.1.1`,
        fs:  `cpe:2.3:a:adobe:photoshop:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_81:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.1`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.2`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.3`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.4`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:7.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.7`,
        fs:  `cpe:2.3:o:cisco:nx-os:8.3\(0\)cv\(0.342\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.8`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.9`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:6.0.2.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p405:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.0.1`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:3_prelude:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.0.2`,
        fs:  `cpe:2.3:h:nvidia:quadro_k420:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.1`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.2`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.3`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.4`,
        fs:  `cpe:2.3:a:ibm:sterling_b2b_integrator:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.5`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20090522:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.6`,
        fs:  `cpe:2.3:h:intel:active_management_technology:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.7`,
        fs:  `cpe:2.3:a:apple:safari:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.8`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.9`,
        fs:  `cpe:2.3:a:apple:motion:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.11`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.0.1.12`,
        fs:  `cpe:2.3:h:cisco:spa_502g_1-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.1`,
        fs:  `cpe:2.3:a:teamviewer:teamviewer:3.6.5523:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.1.0.1`,
        fs:  `cpe:2.3:a:mcafee:application_control:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.1.0.2`,
        fs:  `cpe:2.3:a:oracle:identity_manager:11.1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.1.0.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.1.0.4`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.1.0.5`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.1.0.6`,
        fs:  `cpe:2.3:a:google:chrome:4.0.235.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.5`,
        fs:  `cpe:2.3:o:freebsd:freebsd:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.5.0.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.5.0.2`,
        fs:  `cpe:2.3:a:netartmedia:iboutique:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.5.0.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.5.0.4`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.5.0.5`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.5.0.7`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security_vpn:r75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:7.5.0.8`,
        fs:  `cpe:2.3:a:zencast:zencast:1.00.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:8.0`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:8.0.0.1`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:8.0.0.2`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:8.0.0.3`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:8.0.0.4`,
        fs:  `cpe:2.3:a:lemurmonitors:bluedriver:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:8.0.0.5`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:8.0.0.6`,
        fs:  `cpe:2.3:a:cisco:webns:5.10.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:8.0.0.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:9.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:9.0.0.1`,
        fs:  `cpe:2.3:a:apple:keynote:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:9.0.3`,
        fs:  `cpe:2.3:h:alcatel:switched_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq:9.0.4`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.37.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_explorer:7.0.1.5`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_explorer:7.5.0.0`,
        fs:  `cpe:2.3:a:prestashop:prestashop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_explorer:7.5.0.1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.012:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_explorer:7.5.0.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_explorer:7.5.0.3`,
        fs:  `cpe:2.3:a:apple:cups:1.1.19:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_explorer:7.5.0.4`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_explorer:8.0.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_explorer:8.0.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_internet_pass_thru:2.1.0.1::~~~websphere_mq~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.10:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_light:1.0`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_mq_light:1.0.0.1`,
        fs:  `cpe:2.3:a:ca:brightstor_storage_resource_manager:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_plugin:-`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:1.0`,
        fs:  `cpe:2.3:a:apache:struts:2.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.0.0.0`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.0.0.1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.4.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.0.1.6`,
        fs:  `cpe:2.3:a:ibm:emptoris_program_management:10.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.0.0`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.0.1`,
        fs:  `cpe:2.3:a:topazsystems:e-signatures_sigplus:3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.0.2`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.0.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.0.4`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.0.5`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_network_compliance_manager:7.50.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.0.6`,
        fs:  `cpe:2.3:a:allegrosoft:rompager:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.5.0`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.5.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.5.2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:6.1.5.3`,
        fs:  `cpe:2.3:a:percona:percona_server:5.7.10-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.0`,
        fs:  `cpe:2.3:a:vips:vips:7.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.0:-`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.0:cf001`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1`,
        fs:  `cpe:2.3:a:blackberry:qnx_momentics_tool_suite:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:-`,
        fs:  `cpe:2.3:a:logitech:lws_pictures_and_video:13.30.1395.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf002`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf003`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf004`,
        fs:  `cpe:2.3:a:cisco:jabber:9.0\(.4\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf005`,
        fs:  `cpe:2.3:a:hp:update:4.0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf006`,
        fs:  `cpe:2.3:a:ibm:jre:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf007`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf008`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf009`,
        fs:  `cpe:2.3:o:lorextechnology:edge2_lh330_firmware:11.17.38-33_1d97a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf010`,
        fs:  `cpe:2.3:h:cisco:telepresence_quick_set_sx20:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.1:cf019`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:-`,
        fs:  `cpe:2.3:a:isc:bind:8.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf011`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf012`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf013`,
        fs:  `cpe:2.3:a:bilyoner:bilyoner:4.6.2:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf014`,
        fs:  `cpe:2.3:h:hp:vpn_firewall_appliance:jd270a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf015`,
        fs:  `cpe:2.3:a:cisco:unity_connection:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf016`,
        fs:  `cpe:2.3:a:plataformatec:devise:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf017`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf018`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf019`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf020`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf021`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p33:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf022`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf23`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf24`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(28\)w5-30b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf25`,
        fs:  `cpe:2.3:h:huawei:campus_s5300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf26`,
        fs:  `cpe:2.3:a:hp:creativeprojects_package_variety3:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:7.0.0.2:cf27`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0`,
        fs:  `cpe:2.3:o:ibm:aix:5.2.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.0:-`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.0:cf01`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.5.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.0:cf02`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:3200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.0:cf03`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.0:cf04`,
        fs:  `cpe:2.3:a:sun:sdk:1.5.0_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.0:cf05`,
        fs:  `cpe:2.3:a:docker:docker:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1:-`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a5\(2.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1:cf04`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1:cf05`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:2.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1:cf06`,
        fs:  `cpe:2.3:h:intel:i915_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1:cf07`,
        fs:  `cpe:2.3:a:sun:solstice_adminsuite:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1:cf08`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.6.622:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1:cf09`,
        fs:  `cpe:2.3:h:cisco:7200_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.0.0.1:cf12`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.5`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.28:cert1:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:8.5.0.0`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal:9.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_portal_unified_task_list_portlet:6.0.1`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_process_server:7.0`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_real_time:2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_real_time:3.0`,
        fs:  `cpe:2.3:a:citrix:access_essentials:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.0.0`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.0.0.1`,
        fs:  `cpe:2.3:o:bluecoat:cacheos_ca:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.0.0.2`,
        fs:  `cpe:2.3:a:emc:isilon_insightiq:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.1.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.1.0.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.1.0.2`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.02:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.1.0.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.1.0.4`,
        fs:  `cpe:2.3:h:apple:imac:mb322xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.1.0.5`,
        fs:  `cpe:2.3:o:eucalyptus:eustore:emi_0400376721:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.2.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.2.0:-:advanced_lifecycle`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.3.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.3.0.1`,
        fs:  `cpe:2.3:a:htc:shift_4g_software:2.75.651.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.3.0.2`,
        fs:  `cpe:2.3:h:cisco:tandberg_990_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.3.0.3`,
        fs:  `cpe:2.3:a:zend:zendrest:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.3.0.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:6.3.0.5`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.0.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.21:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.0.0.1`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.0.0.2`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.0.0.3`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.0.0.4`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.0.0.5`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.5`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.5.0.0`,
        fs:  `cpe:2.3:a:altiris:diagnostics:6.1.7631.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.5.0.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.5.0.2`,
        fs:  `cpe:2.3:a:mytoursapp:revel_in_the_rideau_lakes:1.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:7.5.0.3`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:8.0`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:8.0.0`,
        fs:  `cpe:2.3:a:social_connect_project:social_connect:1.0.4:*:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:8.0.0.1`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:8.0.0.2`,
        fs:  `cpe:2.3:a:debian:elvis_tiny:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_service_registry_and_repository:8.5`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.3.0.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.242:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.3.0.6`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.4.0.0`,
        fs:  `cpe:2.3:a:symantec:private_branch_exchange:1.3.28.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.4.0.1`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.4.0.2`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.4.0.3`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.4.0.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.4.1.0`,
        fs:  `cpe:2.3:a:whmcs:whmcs:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_transformation_extender:8.4.1.1`,
        fs:  `cpe:2.3:a:standards_based_linux_instrumentation_project:standards-based_linux_common_information_model_client:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:6.1`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:6.1.1`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_set:07-50-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:6.1.1.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:6.1.1.2`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:6.1.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:6.1.1.4`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:6.1.1.5`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:7.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:7.0.0.1`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:7.0.0.2`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:7.0.0.3`,
        fs:  `cpe:2.3:o:iij:seil\%2fx2_firmware:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:7.0.0.4`,
        fs:  `cpe:2.3:a:scilab:scilab:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:7.0.0.5`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:websphere_virtual_enterprise:7.0.0.6`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.0.0::~~consumer~~~`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.0.1::~~consumer~~~`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:digium:asterisk:10.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.0.2::~~consumer~~~`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:symantec:livestate_recovery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.0.3::~~consumer~~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pixman:pixman:0.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.5.0::~~consumer~~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.5.0::~~enterprise~~~`,
        fs:  `cpe:2.3:o:suse:suse_linux:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.5.1::~~consumer~~~`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.11.262.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.5.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:abb:test_signal_viewer:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.6.0::~~consumer~~~`,
        fs:  `cpe:2.3:a:redhat:openshift:3.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.6.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.6.1::~~consumer~~~`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:7.102.101.223:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.6.1::~~enterprise~~~`,
        fs:  `cpe:2.3:h:mcdata:intrepid_director_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.6.2::~~consumer~~~`,
        fs:  `cpe:2.3:a:novell:imanager:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:5.0.6.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.0.0.0::~~consumer~~~`,
        fs:  `cpe:2.3:a:bmc:control-m\/forecast:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.0.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.0.0.1::~~consumer~~~`,
        fs:  `cpe:2.3:h:dell:powerconnect_6224:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.0.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.0.0.2::~~consumer~~~`,
        fs:  `cpe:2.3:a:apache:subversion:0.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.0.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.1.0.0::~~consumer~~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:08-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.1.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.1.0.1::~~consumer~~~`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.pi_pa_host_agent_files:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:worklight:6.1.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.00:-:*:*:esx:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:workload_deployer:3.1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:workload_deployer:3.1.0.1`,
        fs:  `cpe:2.3:h:linksys:wag54gs:1.00.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:workload_deployer:3.1.0.2`,
        fs:  `cpe:2.3:a:microsoft:visio_viewer:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:workload_deployer:3.1.0.6`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:workload_deployer:3.1.0.7`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibm:wsportal:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20110321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:x330:-`,
        fs:  `cpe:2.3:a:ecryptfs:ecryptfs-utils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:x340:-`,
        fs:  `cpe:2.3:a:ewww_image_optimizer_plugin_project:ewww_image_optimizer_plugin:2.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:x342:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:x345:-`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.47.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:xiv_storage_system:2810`,
        fs:  `cpe:2.3:a:skype:skype:1.3.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:xiv_storage_system:2812-114`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:xiv_storage_system_gen3:2810`,
        fs:  `cpe:2.3:a:apache:activemq:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ibm:xiv_storage_system_gen3:2812-114`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:xiv_storage_system_gen3_firmware:11.1.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:xiv_storage_system_gen3_firmware:11.1.0:a`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:-`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.22:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.3`,
        fs:  `cpe:2.3:o:cisco:staros:19.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.4`,
        fs:  `cpe:2.3:a:openstack:swift:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.5`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(16\)ia:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.6`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.7`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.8`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.9`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.282:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.11`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_sametime:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.12`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:z%2fos:1.13`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:zos:-`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ibm:zos:6.0.1`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibon:ibon:3.2.1::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibotta:ibotta_-_better_than_coupons.:2.5.1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:sterling_order_management:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibs_mappro_project:ibs_mappro:0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibus_project:ibus:1.5.2`,
        fs:  `cpe:2.3:a:pgp:desktop_for_windows:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ibus_project:ibus:1.5.4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:icbc:industrial_and_commercial_bank_of_china:2.4::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.335.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icecomm:turboprep_web:1.1.30`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:10.6\(3\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icekirin:di_long_weibo:1.9.9`,
        fs:  `cpe:2.3:a:oxwall:oxwall:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icewarp:webmail:4.1`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.6.0`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.6.1`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.6.2`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.7.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.2:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.7.1`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.7.2`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.7.3`,
        fs:  `cpe:2.3:a:gajim:gajim:0.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.7.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.8.0`,
        fs:  `cpe:2.3:a:mcafee:protectionpilot:1.1.1:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.8.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(15\)aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.8.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd305a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.8.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6.5ae:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.8.4`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.5:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.8.5`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.8.6`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.9.0`,
        fs:  `cpe:2.3:o:freebsd:freebsd:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.9.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.9.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.9.3`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.9.4`,
        fs:  `cpe:2.3:a:magzter:indian_cement_review:3.01:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.9.5`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.10.0`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.10.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.10.2`,
        fs:  `cpe:2.3:a:symantec:liveupdate:1.80.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icinga:icinga:1.10.3`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.960:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icoasoft:potrace:1.11`,
        fs:  `cpe:2.3:a:roxio:dla:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:1.6`,
        fs:  `cpe:2.3:a:citrix:licensing:7.6.0.11011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:1.6.1`,
        fs:  `cpe:2.3:a:mumble:mumble:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:1.6.2`,
        fs:  `cpe:2.3:a:microsoft:picture_it:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:1.6.3`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:1.6.4`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:2.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:2.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:2.2`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:2.3`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:10.04.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:2.4`,
        fs:  `cpe:2.3:a:pbboard:pbboard:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icofx:icofx:2.5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.0:build110427`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.5p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.0:build110502`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4.5004:*:*:*:*:symbian_os:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.0:build110508`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.0:build110510`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.0:build110512`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.5:build120405`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.6:build120405`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.7:build120405`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.8:build120518`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.10:build110519`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.10:build110523`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.12:build110528`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.14:build110608`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.16:build110612`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.20:build110707`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.01b50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.24:build1110801`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.26:build110823`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.30:build110920`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:2.40:build111016`,
        fs:  `cpe:2.3:a:nero:drivespeed:3.99.5.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:3.0:build121022`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_for_plsql:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconcool:pdfcool_studio:3.32:build130330`,
        fs:  `cpe:2.3:a:sap:netweaver:7.0:ehp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:8.05`,
        fs:  `cpe:2.3:a:apache:hive:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:9.0`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:9.1`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:9.01`,
        fs:  `cpe:2.3:a:google:chrome:4.0.240.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:9.2`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(3y\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:9.13`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.9:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:9.20`,
        fs:  `cpe:2.3:a:vmware:infrastructure_virtualcenter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:9.21`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:bizviz:9.22`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:dialog_wrapper_module_activex_control:8.4.165.0`,
        fs:  `cpe:2.3:a:ibm:lotus_quickr_for_domino:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:8.05`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.01:-:*:*:*:redhat_enterprise_linux:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:9.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:9.1`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:9.01`,
        fs:  `cpe:2.3:a:nero:mediaplayer:1.4.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:9.2`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:9.13`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:9.20`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2009.113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:9.21`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:genesis32:9.22`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iconics:webhmi:9.0`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icq:icq:-`,
        fs:  `cpe:2.3:a:bestpractical:rtfm:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icsharpcode:sharpdevelop:3.2.6466`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.3.1::~~~java~~`,
        fs:  `cpe:2.3:a:ibm:http_server:2.0.42.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.3.1.1::~~~java~~`,
        fs:  `cpe:2.3:o:cisco:ons_15600:1.1\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.4::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:adobe:stock_photos_cs3:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.4.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.4.1.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:5.0:r1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.4.1.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.4.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.5::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:doug_poulin:command_school_student_management_system:1.06.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.6::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.7::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:63reasons:supercron:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.8::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:h:hp:cf066a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:1.8.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.0::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.1.065.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.0::~~~java~~`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.0.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3a9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.0.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r008c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.2::~~~java~~`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.4::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.16:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.4::~~~java~~`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp5:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.6::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:o:cisco:unified_wireless_ip_phone_7920_firmware:1.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.6::~~~java~~`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.6.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je018a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.6.1::~~~java~~`,
        fs:  `cpe:2.3:h:hp:laserjet_p4014:cb507a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.6.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.16.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:2.8::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.4:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.0::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1658.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.0::~~~java~~`,
        fs:  `cpe:2.3:a:apache:http_server:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:google:v8:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.2::~~~java~~`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.2.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.4::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:vmware:gsx_server:2.0.0_build_2050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.4::~~~java~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.483.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.4.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.4.1::~~~java~~`,
        fs:  `cpe:2.3:h:buffalotech:bhr-4grv2_firmware:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.4.2::~~~java~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.426:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.4.3::~~~java~~`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.4.4::~~~java~~`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.4.5::~~~java~~`,
        fs:  `cpe:2.3:h:intel:server_board_s5000vsa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.6::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.6::~~~java~~`,
        fs:  `cpe:2.3:h:hp:3com_router:3041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.6.1::~~~java~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.8::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.8::~~~java~~`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.8.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.13.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:3.8.1::~~~java~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.0::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.0::~~~java~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.0.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.0.1::~~~java~~`,
        fs:  `cpe:2.3:a:opsview:opsview:4.3:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:gnu:coreutils:5.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.2::~~~java~~`,
        fs:  `cpe:2.3:a:apache:cordova:5.2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.2.0.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.2.0.1::~~~java~~`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.0-103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.2.1::~~~java~~`,
        fs:  `cpe:2.3:a:boost:boost:1.58.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.4::~~~java~~`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:2.0.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.4.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.4.1::~~~java~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.4.1.1::~~~java~~`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.4.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:compute_cluster:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.4.2::~~~java~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.4.2.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.62.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.4.2.1::~~~java~~`,
        fs:  `cpe:2.3:h:polycom:hdx_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.6::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.6::~~~java~~`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.6.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.6.1::~~~java~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.09.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.8::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:3.0:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.8::~~~java~~`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.16:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.8.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.8.1::~~~java~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:4.8.1.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:49.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:h:foundrynet:fes_9604_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:49.1::~~~java~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:49.1.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:elipse:e3:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:49.1.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:h:schneider-electric:tburjr900:00002eh0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:50.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:50.1::~~~java~~`,
        fs:  `cpe:2.3:h:polycom:viewstation_mp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:50.1.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:50.1.1::~~~java~~`,
        fs:  `cpe:2.3:a:altiris:cmdb_and_asset_management_language_pack:6.5.1021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:50.1.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1054:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:51.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:51.1::~~~java~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:51.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:apple:software_update:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:51.2::~~~java~~`,
        fs:  `cpe:2.3:a:perblue:parallel_kingdom_mmo:\@7f070019:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:52.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:h:cisco:3925e_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:52.1::~~~java~~`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:53.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:53.1::~~~java~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.3:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:54.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:54.1::~~~java~~`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:54.1.1::~~~java~~`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:55.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:emc:rsa_data_protection_manager_software_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:55.1::~~~java~~`,
        fs:  `cpe:2.3:o:netbsd:netbsd:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:56.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:56.1::~~~java~~`,
        fs:  `cpe:2.3:a:expressjs:express:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:57.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:57.1::~~~java~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.246.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:58.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:o:ibm:aix:5.2.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:58.1::~~~java~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:58.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:58.2::~~~java~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(28c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:59.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:telos:amhs:12.7.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:59.1::~~~java~~`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:60.1::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:60.1::~~~java~~`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:60.2::~~~c%2fc%2b%2b~~`,
        fs:  `cpe:2.3:a:shrew:vpn_client:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icu-project:international_components_for_unicode:60.2::~~~java~~`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icz:sencha_sns:1.0.0`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icz:sencha_sns:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.265.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:icz:sencha_sns:1.0.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:id:id-software:3.7`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:id:id-software:3.7.1`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:id:id-software:3.7.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:id:libdigidoc:3.6.0.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ideamk:eps_viewer:3.2`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:identicentric:simaxs:1.0.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2010.211.1740.31663:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:idera:pointcheck:1.1.0.14`,
        fs:  `cpe:2.3:a:mcafee:firewall_enterprise_admin_console:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idera:uptime_infrastructure_monitor:6.0`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idera:uptime_infrastructure_monitor:7.2`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idera:uptime_infrastructure_monitor:7.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idera:uptime_infrastructure_monitor:7.6`,
        fs:  `cpe:2.3:a:siemens:scalance_x308-2m_firmware:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:autohost:3.0`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.597:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:idevcart:1.09`,
        fs:  `cpe:2.3:a:f5:linerate:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:isupport:1.0`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.17.4808:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:isupport:1.02`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:isupport:1.06`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:isupport:1.8`,
        fs:  `cpe:2.3:a:3ivx:mpeg-4:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:nixieaffiliate:1.9`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:phphostbot:1.0`,
        fs:  `cpe:2.3:a:samba:samba:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:phphostbot:1.06`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:phphostbot:2.0`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:phplinkexchange:1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.6.4\(4072\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:phplinkexchange:1.01`,
        fs:  `cpe:2.3:h:hp:1500_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idevspot:textads:2.08`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:idleman:leed:1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idleman:leed:1.5`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_virtualization:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idm_computer_solutions:ultraedit:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idrt:marvin_teaches_fingerspelling_ii:1.0.0`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.2:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:idt:idt_audio:1.0.6124.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p207:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idt:idt_audio:1.0.6159.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idt:idt_audio:1.0.6274.0`,
        fs:  `cpe:2.3:a:eeye:retina:5.11.6.1879:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:idt:idt_audio:1.0.6292.0`,
        fs:  `cpe:2.3:a:php:php:5.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ienvisage:pakistan_cricket_news:1.21.38.6504::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6e.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:0.91`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:11:developer-preview:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.4.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.7.0.2090:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.4.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1666.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.4.3`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.4.4`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update6:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.4.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)yb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.4.6`,
        fs:  `cpe:2.3:h:asus:rt-n66r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.4.7`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.0.4:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.4.8`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.1`,
        fs:  `cpe:2.3:a:x.org:libxrender:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.2`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.3`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.4`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.5`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.6`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.7`,
        fs:  `cpe:2.3:a:openidm_project:openidm:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.8`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.5.9`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:cca:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.0`,
        fs:  `cpe:2.3:a:idevspot:phplinkexchange:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.3`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:git3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.5`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.6`,
        fs:  `cpe:2.3:a:google:v8:3.24.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.7`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3p\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.8`,
        fs:  `cpe:2.3:a:qmania:aloha_guide:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.6.9`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.0`,
        fs:  `cpe:2.3:h:huawei:s2300:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.1`,
        fs:  `cpe:2.3:a:spip:spip:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.2`,
        fs:  `cpe:2.3:o:yamaha:rta55i:4.06.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.3`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.4`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.5`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.6`,
        fs:  `cpe:2.3:a:ca:etrust_intrusion_detection:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.7`,
        fs:  `cpe:2.3:o:huawei:honor_6_firmware:h60-l12c00b850:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.8`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.7.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.0`,
        fs:  `cpe:2.3:a:apple:safari:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.2`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.3`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.4`,
        fs:  `cpe:2.3:a:adobe:illustrator:13.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.5`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0001_3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.6`,
        fs:  `cpe:2.3:a:php:php:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.7`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.8`,
        fs:  `cpe:2.3:o:f5:tmos:4.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.8.9`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.2`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.239:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.4`,
        fs:  `cpe:2.3:o:asus:wl-330nul_firmware:3.0.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.5`,
        fs:  `cpe:2.3:a:mcafee:securify_studio:v6.0.1_\(build_v601_98\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.6`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)ew2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.8`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.50.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:2.9.9`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.3`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.4`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.5`,
        fs:  `cpe:2.3:a:citrix:access_essentials:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.6`,
        fs:  `cpe:2.3:a:google:chrome:7.0.540.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.7`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.8`,
        fs:  `cpe:2.3:h:dlink:des-3810:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.0.9`,
        fs:  `cpe:2.3:a:nortel:periphonics:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.0`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.1`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.2`,
        fs:  `cpe:2.3:a:microsoft:photodraw:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.3`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.4`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.5`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.6`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.7`,
        fs:  `cpe:2.3:a:biat:biatnet:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.565:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.1.9`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.2.0`,
        fs:  `cpe:2.3:h:axis:2401_video_server:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.3.9`,
        fs:  `cpe:2.3:a:cisco:catalyst_5xxx_supervisor_software:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.4.0`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.4.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.4.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ifdefined:bugtracker.net:3.4.3`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:openfire:3.9.1`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-8024:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:openfire:3.9.2`,
        fs:  `cpe:2.3:a:blair_williams:pretty_link_lite:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:2.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)scj1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:2.2.1`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.0.0`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.0.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.0.2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.0.3`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.1.0`,
        fs:  `cpe:2.3:a:nextapp:echo:3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.2.0`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.2.1`,
        fs:  `cpe:2.3:a:bluecoat:director:5.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.2.2`,
        fs:  `cpe:2.3:h:sophos:unified_threat_management:525:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.3.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.3.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:3.4.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.3.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:rc1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-02-16`,
        fs:  `cpe:2.3:a:quest:capacity_manager_for_oracle:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-02-18`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-02-19`,
        fs:  `cpe:2.3:a:ibm:rational_testmanager:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-02-20`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-02-21`,
        fs:  `cpe:2.3:a:aticts:aticts:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-02-23`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-02`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-03`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:2.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-10`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.9:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-11`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.0:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-12`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.0.338:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-13`,
        fs:  `cpe:2.3:a:hummingbird:exceed:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-16`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-18`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-21`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-25`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-26`,
        fs:  `cpe:2.3:a:redhat:dtach:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-03-29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-04-06`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.0:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-04-09`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-04-13`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack:4.0.0:snapshot-2014-04-15`,
        fs:  `cpe:2.3:a:ibm:tivoli_continuous_data_protection_for_files:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igniterealtime:smack_api:4.0.1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.50.4:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.2`,
        fs:  `cpe:2.3:a:veeam:backup_and_replication:5.0.2.230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.3`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.4`,
        fs:  `cpe:2.3:a:boka:siteengine:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.5`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.6`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.7`,
        fs:  `cpe:2.3:a:perl:perl:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.8`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.9`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.10`,
        fs:  `cpe:2.3:a:websupergoo:abcupload:4.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.11`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.12`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.13`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.2:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.14`,
        fs:  `cpe:2.3:a:tidestone:formula_one_activex_control:6.3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.15`,
        fs:  `cpe:2.3:h:hp:2600c_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.16`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.17`,
        fs:  `cpe:2.3:a:apache:roller:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.18`,
        fs:  `cpe:2.3:a:apple:safari:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.19`,
        fs:  `cpe:2.3:a:seopanel:seo_panel:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.20`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.21`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.22`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.23`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.24`,
        fs:  `cpe:2.3:a:activestate:komodo_edit:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.25`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.7:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.26`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.1.4:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.27`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.28`,
        fs:  `cpe:2.3:a:apache:struts:2.3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.29`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.30`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.31`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.32`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.33`,
        fs:  `cpe:2.3:a:atmail:atmail:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.34`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.35`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.36`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.37`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:5.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.38`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.39`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.40`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.41`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.42`,
        fs:  `cpe:2.3:a:perl:perl:5.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.43`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.44`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.1.45`,
        fs:  `cpe:2.3:a:naver:nhn_japan_naver_line:3.4.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.2.0`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.2.1`,
        fs:  `cpe:2.3:a:redhat:rhel_extras:5:*:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.2.2`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.2.3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.2.4`,
        fs:  `cpe:2.3:a:avaya:libsafe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.2.5`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs3_client:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.2.6`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.0`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:0.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.1`,
        fs:  `cpe:2.3:a:libssh:libssh:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.2`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.0.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.3`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.4`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.0:-:small_business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.0:-:liberty_profile:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.447:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.7`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.8`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.9`,
        fs:  `cpe:2.3:h:symantec:gateway_security_320:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.10`,
        fs:  `cpe:2.3:a:oracle:sysfw:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.11`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.12`,
        fs:  `cpe:2.3:a:apache:opennlp:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.13`,
        fs:  `cpe:2.3:a:skype:skype:0.98.0.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.14`,
        fs:  `cpe:2.3:a:rhq-project:rhq:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.15`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.16`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.17`,
        fs:  `cpe:2.3:a:google:v8:3.17.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.18`,
        fs:  `cpe:2.3:h:cisco:1811_integrated_service_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.19`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.20`,
        fs:  `cpe:2.3:a:x.org:x11:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.21`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.22`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.23`,
        fs:  `cpe:2.3:a:md-systems:simplenews:7.x-1.1:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.24`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.25`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:6300:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.26`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.27`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.28`,
        fs:  `cpe:2.3:a:atlasrr:right_track_software:10.0_freeware:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.29`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.0.0.12305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.30`,
        fs:  `cpe:2.3:a:aceviral:angry_gran_toss:1.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.31`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.32`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:06-70-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.33`,
        fs:  `cpe:2.3:a:ciphertrust:ironmail:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.34`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.35`,
        fs:  `cpe:2.3:a:shoutcast:dnas:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.36`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.66a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.37`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.38`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.39`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.40`,
        fs:  `cpe:2.3:o:oracle:linux:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.41`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.42`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.7.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.43`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.45.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.44`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.45`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.46`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.47`,
        fs:  `cpe:2.3:a:google:chrome:4.0.269.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.48`,
        fs:  `cpe:2.3:a:ibm:filenet_image_services:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.49`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.50`,
        fs:  `cpe:2.3:a:hp:trayapp:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.51`,
        fs:  `cpe:2.3:a:hp:openview_select_access:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.52`,
        fs:  `cpe:2.3:a:hp:arcsight_logger:6.0.0.7307.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.53`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.54`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.55`,
        fs:  `cpe:2.3:a:qemu:qemu:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.56`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.26-74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.57`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.58`,
        fs:  `cpe:2.3:h:hp:j9825a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.59`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.60`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.49:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.3.61`,
        fs:  `cpe:2.3:o:cisco:ids:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.0`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.1`,
        fs:  `cpe:2.3:a:jenkins-ci:build_failure_analyzer:1.5.0:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.2`,
        fs:  `cpe:2.3:a:ibm:sterling_b2b_integrator:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.3`,
        fs:  `cpe:2.3:a:netscape:communicator:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.4`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.5`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.6`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.7`,
        fs:  `cpe:2.3:a:hitachi:job_management_partner_1\/it_desktop_management-manager:09-50-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.8`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.9`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_client:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.10`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.11`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.12`,
        fs:  `cpe:2.3:a:apple:quicktime:7.66.71.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.13`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.4.14`,
        fs:  `cpe:2.3:a:goforandroid:go_twiwidget:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:0.081:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.3`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.4`,
        fs:  `cpe:2.3:a:citrix:hdx_mediastream_for_flash_server:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.6`,
        fs:  `cpe:2.3:a:avaya:vpnmanager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.7`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.8`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.9`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.10`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.11`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.12`,
        fs:  `cpe:2.3:a:teradata:statistics_wizard:13.10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.13`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.57:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.14`,
        fs:  `cpe:2.3:a:teradata:tpump:13.10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.15`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.16`,
        fs:  `cpe:2.3:a:kde:koffice:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.17`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:7.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.18`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.19`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.20`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.17:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.21`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.22`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.23`,
        fs:  `cpe:2.3:h:dell:latitude_d630:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.24`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.25`,
        fs:  `cpe:2.3:a:bandoo:windows_searchqu_toolbar:3.0.0.112202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.26`,
        fs:  `cpe:2.3:a:freso:languageicons:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.5.28`,
        fs:  `cpe:2.3:a:news_project:news:3.0.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.0`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.2`,
        fs:  `cpe:2.3:a:xfree86:x11perf:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.3`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.4`,
        fs:  `cpe:2.3:a:novell:groupwise:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.5`,
        fs:  `cpe:2.3:h:cisco:air-ct5760:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.6`,
        fs:  `cpe:2.3:h:supermicro:x9drff-ig\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.7`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.8`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.9`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.10`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.11`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.12`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.14`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.15`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.17`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.18`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.1.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.19`,
        fs:  `cpe:2.3:a:kozos:easyctf:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.20`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2.8.717.2342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.21`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.2p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.22`,
        fs:  `cpe:2.3:a:avaya:ip600_media_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.23`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.24`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.25`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.26`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.27`,
        fs:  `cpe:2.3:a:apache:struts:2.3.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.28`,
        fs:  `cpe:2.3:a:ibm:qradar_vulnerability_manager:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.29`,
        fs:  `cpe:2.3:a:redhat:kdelibs:2.2-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.30`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:6.3.1:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.6.31`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.1sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.4`,
        fs:  `cpe:2.3:a:apache:hadoop:0.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.5`,
        fs:  `cpe:2.3:a:mit:cgiemail:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.6`,
        fs:  `cpe:2.3:a:safenet-inc:luna_sa_client_software:4.4.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.7`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.9`,
        fs:  `cpe:2.3:o:rockwellautomation:compactlogix_controller_1769_firmware:20.018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.10`,
        fs:  `cpe:2.3:h:hp:jg497a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.11`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-72-\/e:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.12`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.1:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.13`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.14`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.16`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.17`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.07.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.18`,
        fs:  `cpe:2.3:a:gratta_\&amp;_vinci\?_project:gratta_\&amp;_vinci\?:0.21.13167.93474:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.19`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:pl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.20`,
        fs:  `cpe:2.3:a:steve_lockwood:ticketyboo_news_ticker:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.21`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.22`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.23`,
        fs:  `cpe:2.3:a:emc:documentum_administrator:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.24`,
        fs:  `cpe:2.3:a:redmine:redmine:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.25`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc5:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.26`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.27`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.3.1t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.28`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.29`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.30`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5e.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.31`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.32`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.33`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.34`,
        fs:  `cpe:2.3:a:apache:activemq:5.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.35`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.36`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta34:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.37`,
        fs:  `cpe:2.3:a:apache:camel:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.38`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:r2:sp1:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.39`,
        fs:  `cpe:2.3:h:siemens:scalance_w788-2pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.40`,
        fs:  `cpe:2.3:a:uninett:mod_auth_mellon:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.41`,
        fs:  `cpe:2.3:a:otrs:otrs:0.5:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.42`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-0.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.43`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.7.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.44`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.45`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.2.3:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.46`,
        fs:  `cpe:2.3:o:asus:rt-n65u_firmware:3.0.0.4.346:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.47`,
        fs:  `cpe:2.3:a:vmware:ace:2.0.1_build_55017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.48`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.49`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1037:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.50`,
        fs:  `cpe:2.3:a:cogentdatahub:cascade_datahub:6.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.51`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.52`,
        fs:  `cpe:2.3:a:redhat:openshift_origin:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.53`,
        fs:  `cpe:2.3:a:google:chrome:12.0.702.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.54`,
        fs:  `cpe:2.3:a:splunk:splunk:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.55`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.56`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.33:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.57`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.58`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.7.59`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2012-t-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.0`,
        fs:  `cpe:2.3:a:meta_tags_quick_project:meta_tags_quick:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.1`,
        fs:  `cpe:2.3:a:pennytalk:pennytalk_mobile:2.0.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.2`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:919:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.4`,
        fs:  `cpe:2.3:a:cisco:unified_provisioning_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.5`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.647:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.7`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.8`,
        fs:  `cpe:2.3:a:erlang:crypto:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.9`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.10`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.11`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:4.24.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.13`,
        fs:  `cpe:2.3:a:apache:subversion:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.14`,
        fs:  `cpe:2.3:a:vbwebdesigner:brevir_harian_v2:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.15`,
        fs:  `cpe:2.3:a:ibm:content_navigator:2.0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.16`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.17`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.9.3753:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.18`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.19`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.20`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.21`,
        fs:  `cpe:2.3:a:advanceprotech:advanceware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.22`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.23`,
        fs:  `cpe:2.3:a:novell:edirectory:8.5.12a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.24`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.25`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.26`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.27`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.28`,
        fs:  `cpe:2.3:o:scientificlinux:scientificlinux:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.29`,
        fs:  `cpe:2.3:a:polldaddy_polls_\&amp;_ratings_plugin_project:polldaddy_polls_\&amp;_ratings:2.0.24:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.30`,
        fs:  `cpe:2.3:a:tumbleweed:validation_authority:4.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.31`,
        fs:  `cpe:2.3:a:google:chrome:5.0.367.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.32`,
        fs:  `cpe:2.3:h:huawei:5300hi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.33`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.2.2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.34`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)sy1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.35`,
        fs:  `cpe:2.3:a:autodesk:design_review_2009:9.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.36`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.37`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.38`,
        fs:  `cpe:2.3:a:dell:controlvault_host_components_installer:1.7.324.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.39`,
        fs:  `cpe:2.3:a:openstack:horizon:2013.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.40`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.41`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.42`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.43`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.44`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.25:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.45`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.46`,
        fs:  `cpe:2.3:a:samba:samba:4.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.47`,
        fs:  `cpe:2.3:o:debian:debian_linux:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.48`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.4.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.49`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.50`,
        fs:  `cpe:2.3:a:mozilla:mozilla_suite:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.51`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.52`,
        fs:  `cpe:2.3:a:roxio:burn_virtual_folder_install:1.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.8.53`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-51-\/k:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.9.0`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.4.6:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.9.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.9.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.9.3`,
        fs:  `cpe:2.3:a:menalto:gallery:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.9.4`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.9.5`,
        fs:  `cpe:2.3:a:artifex:mupdf:1.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.9.6`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:0.9.7`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.0`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.1`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)sv3\(1.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.3`,
        fs:  `cpe:2.3:a:digium:asterisk:c.1.6.2:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.4`,
        fs:  `cpe:2.3:a:michael_vogt:ubuntu-system-service:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:17.0.938.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.7`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.8`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.9`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.10`,
        fs:  `cpe:2.3:a:shavlik:netchk_configure:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.11`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.12`,
        fs:  `cpe:2.3:a:sambar:sambar_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.13`,
        fs:  `cpe:2.3:a:gnome:epiphany:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.14`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.0.15`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.0`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.2`,
        fs:  `cpe:2.3:a:gnu:automake:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.3`,
        fs:  `cpe:2.3:o:cisco:staros:18.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.4`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2013:cumulative_update_13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.5`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.7`,
        fs:  `cpe:2.3:a:redhat:cloudforms:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.9`,
        fs:  `cpe:2.3:a:sharethis:sharethis:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.10`,
        fs:  `cpe:2.3:h:xerox:workcentre_275:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.11`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.12`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.13`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.14`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.15`,
        fs:  `cpe:2.3:a:prosoft-technology:radiolinx_controlscape:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.17`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.18`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.1.19`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.2.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.748.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.1`,
        fs:  `cpe:2.3:a:google:search_appliance_software:7.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.2`,
        fs:  `cpe:2.3:a:gnome:glib:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p335:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.4`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.6`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.5.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.7`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.8`,
        fs:  `cpe:2.3:a:xml-dt_project:xml-dt:0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.9`,
        fs:  `cpe:2.3:h:tp-link:tl-wdr4300_\(1.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.10`,
        fs:  `cpe:2.3:a:pixman:pixman:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.11`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.13`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.14`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.15`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.3.16`,
        fs:  `cpe:2.3:a:ibus_project:ibus:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.4.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.4.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.4.2`,
        fs:  `cpe:2.3:h:cisco:cache_engine_505:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.4.3`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:12.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.19:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.1`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.3`,
        fs:  `cpe:2.3:a:qt:qt:5.9.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.5`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.9.0:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.6`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.7`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.8`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.9`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.10`,
        fs:  `cpe:2.3:a:simgear:simgear:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.11`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_sysoev:nginx:1.5.12`,
        fs:  `cpe:2.3:h:cisco:7960_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.01`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.17`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.427:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.26`,
        fs:  `cpe:2.3:h:cisco:asr_9006:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.34`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.35`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.36`,
        fs:  `cpe:2.3:a:emc:digital_assets_manager:6.5:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.37`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.38`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.40`,
        fs:  `cpe:2.3:a:symantec:data_center_security_server:6.0.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.41`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.42`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.43`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.44`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:pre.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.45`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.47`,
        fs:  `cpe:2.3:a:twitter:groupama_toujours_la:1.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.48`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.3.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.50`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.51`,
        fs:  `cpe:2.3:a:quest:benchmark_factory_for_databases:5.7.1.504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.52`,
        fs:  `cpe:2.3:a:php-fusion:expanded_calendar_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.53`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.54`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.55`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.56`,
        fs:  `cpe:2.3:a:veritas:file_system_management_services_provider:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.57`,
        fs:  `cpe:2.3:a:qemu:qemu:2.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.58`,
        fs:  `cpe:2.3:o:asus:rt-n65u_firmware:3.0.0.3.176:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.59`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.61`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.62`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_application_server_control:9.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.63`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.64`,
        fs:  `cpe:2.3:a:apple:apple_tv:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.65`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.50:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.66`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.67`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.0:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.68`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.69`,
        fs:  `cpe:2.3:a:cisco:webns:7.50.1.05s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.70`,
        fs:  `cpe:2.3:o:huawei:s2350ei_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.71`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.72`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.73`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.74`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.75`,
        fs:  `cpe:2.3:a:avg:internet_security:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.76`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.77`,
        fs:  `cpe:2.3:a:osehra:vista:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.80`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.81`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.82`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.83`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.84`,
        fs:  `cpe:2.3:a:adobe:flex_sdk:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.85`,
        fs:  `cpe:2.3:h:apple:imac:ma589xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.86`,
        fs:  `cpe:2.3:h:cisco:rvs4000_4-port_gigabit_security_router_-_vpn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.87`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.90`,
        fs:  `cpe:2.3:a:geniuscloud:smart_browser:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.92`,
        fs:  `cpe:2.3:a:terrarienbilder:terrarienbilder.com_forum:3.8.20:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.93`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.94`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.95`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.9501`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.9502`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.9503`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.24-72.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.9504`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.9505`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.9506`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.34.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igor_vlasenko:html-template-pro:0.9507`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.3:b-beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igrafx:igrafx:12.2.1`,
        fs:  `cpe:2.3:o:cisco:catos:8.2\(1\)glx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igrafx:igrafx:14.1.2`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igrafx:igrafx:14.1.2.1331`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.75`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-00-\/i:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.76`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.77`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.78`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.79`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.80`,
        fs:  `cpe:2.3:a:php:php:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.81`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.0.5.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.90`,
        fs:  `cpe:2.3:a:autodesk:raster_design:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.91`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.92`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.1\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.93`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.94`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.8:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_light:0.95`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.10`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k_secure:14.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.11`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.12`,
        fs:  `cpe:2.3:a:apple:personal_web_sharing:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.13`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.14`,
        fs:  `cpe:2.3:a:google:v8:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.20`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.21`,
        fs:  `cpe:2.3:o:cisco:ios:11.2xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.22`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:06-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.23`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.24`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.31`,
        fs:  `cpe:2.3:a:adrian_chadd:rtg2:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.32`,
        fs:  `cpe:2.3:a:typemoon:witch_on_the_holy_night:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.40`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10\)ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.41`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.42`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.43`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.44`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)m4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.50`,
        fs:  `cpe:2.3:a:combodo:itop:1.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.51`,
        fs:  `cpe:2.3:a:barandisolutions:shareyourcart:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.52`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1062:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.53`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p417:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.54`,
        fs:  `cpe:2.3:h:softbank:mobile_wi-fi_router:102hw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.55`,
        fs:  `cpe:2.3:a:x:libxfont:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.56`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.5i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.57`,
        fs:  `cpe:2.3:a:spice_project:spice:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.58`,
        fs:  `cpe:2.3:a:oracle:providers_for_asp.net_help:11.1.620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.59`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.60`,
        fs:  `cpe:2.3:a:indusoft:web_studio:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.61`,
        fs:  `cpe:2.3:h:linksys:befw11s4:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.62`,
        fs:  `cpe:2.3:a:netsarang:xmanager:3.0.218:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.63`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.64`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.65`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.66`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.67`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.7:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.68`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.69`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.70`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.71`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:x64-datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.72`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)so4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.73`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.74`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.75`,
        fs:  `cpe:2.3:a:hp:service_manager:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.76`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1p\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.77`,
        fs:  `cpe:2.3:o:freebsd:freebsd:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.78`,
        fs:  `cpe:2.3:o:yamaha:rta52i:4.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.79`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.80`,
        fs:  `cpe:2.3:a:digium:asterisk:11.15.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.82`,
        fs:  `cpe:2.3:a:yunlai:a\&#43;:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional:1.83`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.6:mp4:*:*:*:mac:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional_oem:1.82`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:igreks:milkystep_professional_oem:1.83`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144n_firmware:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iii:encore_discovery_solution:4.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iii:sierra:1.2_3`,
        fs:  `cpe:2.3:a:openbsd:openbsd:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:eil%252fx2_firmware:1.00`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:eil%252fx2_firmware:4.31`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:eil%252fx2_firmware:4.32`,
        fs:  `cpe:2.3:a:gollos:gollos:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fb1_firmware:1.00`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1683.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fb1_firmware:4.30`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)sv3\(1.5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fb1_firmware:4.31`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fb1_firmware:4.32`,
        fs:  `cpe:2.3:a:novell:groupwise:8.02:hp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fb1_firmware:4.50`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fneu_2fe_plus_firmware:1.80`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fneu_2fe_plus_firmware:2.05`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fneu_2fe_plus_firmware:2.15`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.2:_nil_:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fneu_2fe_plus_firmware:2.16`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fneu_2fe_plus_firmware:2.17`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fturbo_firmware:1.80`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.2.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fturbo_firmware:2.05`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fturbo_firmware:2.15`,
        fs:  `cpe:2.3:a:jruby:jruby:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fturbo_firmware:2.16`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fturbo_firmware:2.17`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx1_firmware:1.00`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx1_firmware:4.30`,
        fs:  `cpe:2.3:a:oracle:database_server:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx1_firmware:4.31`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx1_firmware:4.32`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx2_firmware:1.00`,
        fs:  `cpe:2.3:a:cimon:cmnview:2.14.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx2_firmware:1.80`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx2_firmware:4.30`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx2_firmware:4.50`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.21.177:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx86_firmware:1.00`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx86_firmware:2.80`,
        fs:  `cpe:2.3:a:attachmate:reflection_administrator\&#39;s_toolkit:14.0.3670:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx86_firmware:2.81`,
        fs:  `cpe:2.3:a:jruby:jruby:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx86_firmware:2.82`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%252fx86_firmware:3.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p347:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil%2fb1:-`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:iij:seil%2fb1_firmware:-`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:3.51`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:3.60`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:3.70`,
        fs:  `cpe:2.3:a:isc:bind:8.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:3.75`,
        fs:  `cpe:2.3:a:smartertools:smarterstats:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:3.90`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.515:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:3.91`,
        fs:  `cpe:2.3:a:apache:struts:2.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.00`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.30`,
        fs:  `cpe:2.3:a:tequilagames:battlefriends_at_sea_gold:1.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.31`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.01:-:*:*:*:suse_linux:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.32`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:3.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.34`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.40`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.41`,
        fs:  `cpe:2.3:a:mohachat:moha_chat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.53`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.60`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fb1_firmware:4.70`,
        fs:  `cpe:2.3:a:hp:color_laserjet_cp4520-cp4020_series_user_guide:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil%2fneu_2fe_plus:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8\)ea1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iij:seil%2fneu_2fe_plus_firmware:-`,
        fs:  `cpe:2.3:a:irislink:readiris:11.0.5062:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil%2fturbo:-`,
        fs:  `cpe:2.3:a:apple:quicktime:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iij:seil%2fturbo_firmware:-`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil%2fx1:-`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iij:seil%2fx1_firmware:-`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:3.51`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:3.60`,
        fs:  `cpe:2.3:h:rockwellautomation:logix_5000_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:3.70`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0-p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:3.75`,
        fs:  `cpe:2.3:a:redhat:spacewalk-java:2.1.148-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:3.90`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:3.91`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.00`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.30`,
        fs:  `cpe:2.3:a:jordan_de_laune:mp3_player:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.31`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.32`,
        fs:  `cpe:2.3:a:busybox:busybox:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.34`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.40`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0a2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.41`,
        fs:  `cpe:2.3:a:emerson:deltav_workstation:11.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.50`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.53`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.60`,
        fs:  `cpe:2.3:a:juniper:junos_space:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx1_firmware:4.70`,
        fs:  `cpe:2.3:a:vinay_sajip:python-gnupg:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil%2fx2:-`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_31:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iij:seil%2fx2_firmware:-`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:3.51`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:3.60`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_7911g:8.0\(4\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:3.70`,
        fs:  `cpe:2.3:a:intel:network_connections:14.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:3.75`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:3.90`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.001:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:3.91`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.00`,
        fs:  `cpe:2.3:a:tibco:spotfire_professional:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.30`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.31`,
        fs:  `cpe:2.3:a:ilovegame:longjiang:2.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.32`,
        fs:  `cpe:2.3:a:openttd:openttd:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.34`,
        fs:  `cpe:2.3:a:logitech:lws_wlm_plugin:1.20.1166.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.40`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.41`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.53`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.60`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil%2fx2_firmware:4.70`,
        fs:  `cpe:2.3:a:adobe:after_effects:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil%2fx86:-`,
        fs:  `cpe:2.3:a:xnview:xnview:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iij:seil%2fx86_firmware:-`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil_b1:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.50`,
        fs:  `cpe:2.3:a:google:toolbar_for_internet_explorer:7.0.1710.2246:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.51`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.52`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.53`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.7:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.54`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.55`,
        fs:  `cpe:2.3:a:sonicwall:aventail_webifiers:10.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.56`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.57`,
        fs:  `cpe:2.3:o:siemens:ccmd3025-dn18_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.58`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.59`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.60`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.61`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.62`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.63`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.64`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1655.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.65`,
        fs:  `cpe:2.3:a:vmware:vcloud_automation_center:6.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.66`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.67`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.68`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0804hf-l-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.69`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.70`,
        fs:  `cpe:2.3:a:google:v8:3.22.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.71`,
        fs:  `cpe:2.3:a:apache:synapse:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.72`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.73`,
        fs:  `cpe:2.3:a:boa:boa:0.94.14.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.74`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs5.1:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.75`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_for_plsql:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.76`,
        fs:  `cpe:2.3:a:cisco:webex_advanced_recording_format_player:27.25.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.77`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.78`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.79`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.80`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.81`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.82`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.83`,
        fs:  `cpe:2.3:a:citrix:presentation_server_administration_snap-in:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.84`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.85`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.86`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.87`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.88`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.89`,
        fs:  `cpe:2.3:a:nokia:affix:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.90`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.91`,
        fs:  `cpe:2.3:a:citrix:presentation_server_administration_snap-in:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.92`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.93`,
        fs:  `cpe:2.3:a:isc:bind:9.1.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.94`,
        fs:  `cpe:2.3:a:hp:icewall_federation_agent:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.95`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.96`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.6:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.97`,
        fs:  `cpe:2.3:a:gnu:screen:3.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.98`,
        fs:  `cpe:2.3:a:emc:powerpath:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:2.99`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:6.0:u1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.00`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.01`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.02`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.03`,
        fs:  `cpe:2.3:a:debian:apt:0.7.17:exp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.04`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.05`,
        fs:  `cpe:2.3:a:hp:scan:4.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.06`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bpeo64b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.07`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.0.10.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.08`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.09`,
        fs:  `cpe:2.3:a:ibm:tivoli_it_asset_management_for_it:7.1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.10`,
        fs:  `cpe:2.3:a:microsoft:ie_for_macintosh:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.11`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1296.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.12`,
        fs:  `cpe:2.3:o:qnap:ss-839_firmware:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.13`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.14`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.16`,
        fs:  `cpe:2.3:a:fourelle:venturi_client:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.17`,
        fs:  `cpe:2.3:o:freebsd:freebsd:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.18`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.19`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.20`,
        fs:  `cpe:2.3:h:pgp:e-ppliance_300:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.21`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.22`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.23`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.24`,
        fs:  `cpe:2.3:a:buronya:dil_bilgisi_kurallari:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.25`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.26`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.27`,
        fs:  `cpe:2.3:h:fortinet:fortigate-5001a-sw:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.28`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.29`,
        fs:  `cpe:2.3:a:apple:safari:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.30`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.31`,
        fs:  `cpe:2.3:a:oracle:forms_builder:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.32`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5602:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.33`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.34`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.1.2:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.35`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.36`,
        fs:  `cpe:2.3:a:arellia:arellia_common_language_pack:6.0.1101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.37`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:cpk:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.38`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:gold:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.39`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.40`,
        fs:  `cpe:2.3:a:microsoft:ie:5.50.4522.1800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.41`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.42`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.43`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.44`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.45`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.46`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.19:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.47`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.48`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.1:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.49`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.50`,
        fs:  `cpe:2.3:a:appsworld:condor_s.e.:1.399:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.51`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.52`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.53`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.54`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.55`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.56`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.57`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.58`,
        fs:  `cpe:2.3:a:mobbtech:follow_mania_for_instagram:1.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.59`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.60`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.61`,
        fs:  `cpe:2.3:a:microsoft:office:2003:*:student_teacher:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.62`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.63`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:2.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.64`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.65`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.66`,
        fs:  `cpe:2.3:a:arduino_json_project:arduino_json:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.67`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.68`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.69`,
        fs:  `cpe:2.3:a:winzip:winzip:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.70`,
        fs:  `cpe:2.3:a:oracle:logging_utilities:6.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.71`,
        fs:  `cpe:2.3:a:roxio:cineplayer:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.72`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.73`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.74`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.75`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.76`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.77`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a4:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.78`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.79`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.80`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.81`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.82`,
        fs:  `cpe:2.3:a:isc:bind:9.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.83`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.84`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.85`,
        fs:  `cpe:2.3:a:acme:thttpd:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.86`,
        fs:  `cpe:2.3:o:huawei:5300hi_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.87`,
        fs:  `cpe:2.3:a:fedex:ship_manager_server:10.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.88`,
        fs:  `cpe:2.3:a:pulseinfotech:com_flipwall:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.89`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.1.601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.90`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.91`,
        fs:  `cpe:2.3:h:linksys:befsx41:1.44.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.92`,
        fs:  `cpe:2.3:h:hp:0231a791:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.93`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.94`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.95`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.96`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.97`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.98`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.0.3:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:3.99`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.00`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.01`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.02`,
        fs:  `cpe:2.3:a:redhat:certificate_system:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.03`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:7.1:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.04`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.05`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.06`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.07`,
        fs:  `cpe:2.3:a:digia:qt:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.08`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.09`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.10`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.11`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.5:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.13`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.173:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.14`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.15`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.16`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.17`,
        fs:  `cpe:2.3:a:php:php:5.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.18`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.19`,
        fs:  `cpe:2.3:o:ewon:ewon_firmware:10.0s0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.20`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.21`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.22`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.23`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.24`,
        fs:  `cpe:2.3:a:busybox:busybox:1.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.25`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.26`,
        fs:  `cpe:2.3:a:google:talk:1.0.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.27`,
        fs:  `cpe:2.3:a:web2py:web2py:1.77.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.28`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.29`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:5.3.1.0606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.30`,
        fs:  `cpe:2.3:h:tp-link:tl-wr741nd_\(5.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.31`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.32`,
        fs:  `cpe:2.3:a:emc:navisphere_server_utility:6.24.0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.33`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.34`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.35`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.36`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.37`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.38`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.39`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.40`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:3.1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.41`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.20:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.42`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.43`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:462:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.44`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.45`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.46`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.47`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.48`,
        fs:  `cpe:2.3:h:hp:cf116a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.49`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.50`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.999:22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.51`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.52`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.53`,
        fs:  `cpe:2.3:a:ibm:tivoli_integration_composer:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.54`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.55`,
        fs:  `cpe:2.3:a:xnview:xnview:1.68.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.56`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.57`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.58`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.59`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.60`,
        fs:  `cpe:2.3:o:debian:debian_linux:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.61`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.62`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_b1_firmware:4.71`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:6.x-4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil_plus:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.18.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.82`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_servers_software:x7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.83`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:5.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.84`,
        fs:  `cpe:2.3:h:hp:laserjet_9050_mfp:q3721a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.85`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.32.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.86`,
        fs:  `cpe:2.3:a:symantec:mail_security_for_microsoft_exchange:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.87`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.88`,
        fs:  `cpe:2.3:a:raritan:power_iq:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.89`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.90`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.13:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.91`,
        fs:  `cpe:2.3:a:yahoo:yui:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.92`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:s4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.93`,
        fs:  `cpe:2.3:a:redhat:pam_smb:1.1.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.94`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security_mi_server_r73:3.0.0:hfa2.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.95`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.96`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.97`,
        fs:  `cpe:2.3:a:almas:compiere:j300_a01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.98`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp3:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:1.99`,
        fs:  `cpe:2.3:h:lucent:wavelan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.01`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.02`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.94:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.03`,
        fs:  `cpe:2.3:a:totalseminars:network\&#43;_demo:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.04`,
        fs:  `cpe:2.3:a:hp:arcsight_connector_appliance:6.4.0.6881.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.05`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.06`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.07`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.08`,
        fs:  `cpe:2.3:a:owncloud:owncloud:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.09`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.10`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.11`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.12`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update1:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.13`,
        fs:  `cpe:2.3:a:apple:motion:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.14`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1022:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.15`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_user:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.16`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.17`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_plus_firmware:2.18`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil_turbo:-`,
        fs:  `cpe:2.3:a:microsoft:site_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.82`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:-:cloud:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.83`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.84`,
        fs:  `cpe:2.3:a:libiitech:pet_salon:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.85`,
        fs:  `cpe:2.3:a:qemu:qemu:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.86`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.87`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:12.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.88`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.89`,
        fs:  `cpe:2.3:o:apple:os_x_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.90`,
        fs:  `cpe:2.3:a:serv-u:serv-u:5.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.91`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.92`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.93`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.94`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p376:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.95`,
        fs:  `cpe:2.3:a:hrblock:taxcut_premium\&#43;state\&#43;efile:8.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.96`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.97`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.98`,
        fs:  `cpe:2.3:a:hp:compaqhttpserver:9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:1.99`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.00`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.01`,
        fs:  `cpe:2.3:a:jenkins:git:2.4.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.02`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.5:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.03`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.04`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.05`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.06`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.07`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.08`,
        fs:  `cpe:2.3:h:fortinet:fortigate-310b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.09`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.10`,
        fs:  `cpe:2.3:a:s3ql_project:s3ql:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.11`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.12`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.13`,
        fs:  `cpe:2.3:a:sas:jmp:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.14`,
        fs:  `cpe:2.3:a:crawlability:vbseo:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.15`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:11.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.16`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.17`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:10.04:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_turbo_firmware:2.18`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil_x1:-`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.50`,
        fs:  `cpe:2.3:a:google:chrome:4.0.223.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.51`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.2:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.52`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.53`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.54`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.55`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.56`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:14.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.57`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.58`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.59`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.14.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.60`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc2425:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.61`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.62`,
        fs:  `cpe:2.3:a:knowledgetree:knowledgetree:3.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.63`,
        fs:  `cpe:2.3:a:apache:ignite:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.64`,
        fs:  `cpe:2.3:a:apache:struts:1.1:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.65`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.66`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.67`,
        fs:  `cpe:2.3:a:apple:motion:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.68`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.69`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110809:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.70`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.0.1679:online_windows_2000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.71`,
        fs:  `cpe:2.3:a:beehive_forum:beehive_forum:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.72`,
        fs:  `cpe:2.3:a:project-redcap:redcap:4.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.73`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp2:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.74`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.75`,
        fs:  `cpe:2.3:a:posh_project:posh:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.76`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.77`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.78`,
        fs:  `cpe:2.3:a:steema:teechart_activex_control:version_5.0:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.79`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.12:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.80`,
        fs:  `cpe:2.3:h:lexmark:c52x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.81`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.82`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.83`,
        fs:  `cpe:2.3:a:cisco:iscsi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.84`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta31:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.85`,
        fs:  `cpe:2.3:a:novell:groupwise:8.00:hp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.86`,
        fs:  `cpe:2.3:a:adobe:bridge_cs3:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.87`,
        fs:  `cpe:2.3:a:libssh:libssh:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.88`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.89`,
        fs:  `cpe:2.3:a:amazon:ec2_api_tools_java_library:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.90`,
        fs:  `cpe:2.3:o:yahama:rtx1200:10.01.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.91`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.92`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.5.cdf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.93`,
        fs:  `cpe:2.3:h:juniper:mx80:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.94`,
        fs:  `cpe:2.3:a:piwik:piwik:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.95`,
        fs:  `cpe:2.3:a:redhat:rhel_productivity:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.96`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.5:u3a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.97`,
        fs:  `cpe:2.3:a:xnview:xnview:1.90.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.98`,
        fs:  `cpe:2.3:a:apache:commons-compress:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:2.99`,
        fs:  `cpe:2.3:a:vmware:player:3.1.4.16648:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.00`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.01`,
        fs:  `cpe:2.3:a:adobe:device_central_cs3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.02`,
        fs:  `cpe:2.3:h:hp:value_serial\/usb_receipt_printer_f7m66aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.03`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.04`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.pi_pa_host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.05`,
        fs:  `cpe:2.3:a:agi:planetary_data_supplement:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.06`,
        fs:  `cpe:2.3:a:humhub:humhub:0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.07`,
        fs:  `cpe:2.3:h:dell:latitude_2110_netbook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.08`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.09`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.10`,
        fs:  `cpe:2.3:a:oracle:database_server:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.11`,
        fs:  `cpe:2.3:o:apple:mac_os:7.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.12`,
        fs:  `cpe:2.3:a:adobe:spelling_dictionaries_support_for_adobe_reader:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.13`,
        fs:  `cpe:2.3:a:idm_computer_solutions:ultraedit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.14`,
        fs:  `cpe:2.3:a:teamquest:view:10.2.2476:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.15`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.16`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.17`,
        fs:  `cpe:2.3:a:horde:horde_groupware:5.2.11:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.18`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak2:2.0.24.1:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.19`,
        fs:  `cpe:2.3:a:autodesk:autocad_mechanical:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.20`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.21`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.22`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.24`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.2.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.25`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.26`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.27`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_remote_agent_for_windows_servers:9.1.4691:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.28`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6ccf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.29`,
        fs:  `cpe:2.3:a:altiris:linux_pack_for_patch_management_solution_for_dell_servers:6.2.1128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.30`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.31`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.32`,
        fs:  `cpe:2.3:a:google:chrome:10.0.614.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.33`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.34`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.35`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.36`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.37`,
        fs:  `cpe:2.3:a:apache:roller:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.38`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.39`,
        fs:  `cpe:2.3:h:apple:imac:ma200xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.40`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.41`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.42`,
        fs:  `cpe:2.3:a:php:pear:1.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.43`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.44`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.45`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.46`,
        fs:  `cpe:2.3:o:juniper:junose_e:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.47`,
        fs:  `cpe:2.3:a:otrs:faq:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.48`,
        fs:  `cpe:2.3:a:sun:sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.49`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.50`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.2.1:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.51`,
        fs:  `cpe:2.3:a:synology:video_station:1.2-0447:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.52`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.53`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.54`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.55`,
        fs:  `cpe:2.3:h:hp:3com_switch:ss4_switch_5500g-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.56`,
        fs:  `cpe:2.3:a:clamav:clamav:0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.57`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.58`,
        fs:  `cpe:2.3:a:emc:cava:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.59`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.98:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.60`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.61`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.62`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.63`,
        fs:  `cpe:2.3:a:nortel:cs1000e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.64`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.65`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.66`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.67`,
        fs:  `cpe:2.3:a:aimluck:aipo-asp:4.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.68`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:9.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.69`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.70`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.22a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.71`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.72`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.73`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3020-dc-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.74`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.75`,
        fs:  `cpe:2.3:a:typo3:neos:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.76`,
        fs:  `cpe:2.3:a:php:php:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.77`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.78`,
        fs:  `cpe:2.3:a:digium:asterisk:13.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.79`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.80`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.81`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:11.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.82`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.83`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.84`,
        fs:  `cpe:2.3:a:boeing:imis_application_suite:5.2.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.85`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.86`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.87`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.88`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_76:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.89`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.90`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.91`,
        fs:  `cpe:2.3:a:apache:axis:1.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.92`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.93`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.94`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.95`,
        fs:  `cpe:2.3:a:tibco:spotfire_analytics_platform_for_aws:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.96`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.97`,
        fs:  `cpe:2.3:a:mozilla:firefox:23.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.98`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:3.99`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.00`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.01`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.02`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.03`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.04`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.05`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.06`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.07`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.08`,
        fs:  `cpe:2.3:a:web2py:web2py:1.76.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.09`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.7.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.10`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.11`,
        fs:  `cpe:2.3:a:wpsolr:wpsolr-search-engine:7.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.12`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.13`,
        fs:  `cpe:2.3:a:intel:proset_wireless:12.0.4000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.14`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.15`,
        fs:  `cpe:2.3:a:senatorinn:senator_inn_\&amp;_spa:1.2.2.160:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.16`,
        fs:  `cpe:2.3:a:mozilla:firefox:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.17`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.18`,
        fs:  `cpe:2.3:a:isc:bind:9.10.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.19`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update5:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.20`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.21`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.22`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.23`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.24`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.25`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.26`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.27`,
        fs:  `cpe:2.3:a:haxx:curl:7.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.28`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.5:sr_3.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.29`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.30`,
        fs:  `cpe:2.3:o:advantech:vesp211-232_firmware:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.31`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.32`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_launcher:1.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.33`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.34`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.35`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.36`,
        fs:  `cpe:2.3:o:engardelinux:secure_community:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.37`,
        fs:  `cpe:2.3:o:cisco:ios:12.2cy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.38`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.39`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.40`,
        fs:  `cpe:2.3:a:tibco:spotfire_statistics_services:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.41`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.42`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.43`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7962g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.44`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1281.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.45`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.46`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_audit_integration_component:6.2.1004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.47`,
        fs:  `cpe:2.3:a:xnview:xnview:1.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.48`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.49`,
        fs:  `cpe:2.3:a:adobe:flash_playe_for_linux:9.0.115.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.50`,
        fs:  `cpe:2.3:a:php:php:5.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.51`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.52`,
        fs:  `cpe:2.3:a:adobe:photodeluxe:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.53`,
        fs:  `cpe:2.3:a:oracle:sysfw:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.54`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-beta1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.55`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.56`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.57`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6.5e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.58`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.59`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.60`,
        fs:  `cpe:2.3:a:digia:qt:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.61`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p211:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.62`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x1_firmware:4.71`,
        fs:  `cpe:2.3:a:jenkins:git:1.3.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil_x2:-`,
        fs:  `cpe:2.3:a:netiq:snmp_trap_receiver:1.3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.50`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.51`,
        fs:  `cpe:2.3:a:microsoft:ie:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.52`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.53`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.54`,
        fs:  `cpe:2.3:a:google:chrome:5.0.317.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.55`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.56`,
        fs:  `cpe:2.3:a:vmware:vrealize_operations:6.2.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.57`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.4:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.58`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1671.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.59`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.60`,
        fs:  `cpe:2.3:a:sony:sonicstage_mastering_studio:2.1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.61`,
        fs:  `cpe:2.3:o:cisco:cg-os:cg4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.62`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.63`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.64`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.65`,
        fs:  `cpe:2.3:a:logitech:cddrv_installer:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.66`,
        fs:  `cpe:2.3:a:lsi:mr_hhr:0.5.503:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.67`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.68`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.69`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.70`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.71`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.72`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.73`,
        fs:  `cpe:2.3:a:ca:brightstor_san_manager:1.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.74`,
        fs:  `cpe:2.3:a:samba:samba:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.75`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.76`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.77`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.16:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.78`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6s\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.79`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.80`,
        fs:  `cpe:2.3:a:justin_dodge:hotblocks:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.81`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.82`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.83`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.84`,
        fs:  `cpe:2.3:a:ibm:tivoli_endpoint_manager:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.85`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:08.0.01c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.86`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.87`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.17.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.88`,
        fs:  `cpe:2.3:a:digia:qt:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.89`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.90`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.91`,
        fs:  `cpe:2.3:a:php:phpsquidpass:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.92`,
        fs:  `cpe:2.3:a:redhat:rhel_cluster:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.93`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.94`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.95`,
        fs:  `cpe:2.3:a:ca:cleverpath_predictive_analysis_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.96`,
        fs:  `cpe:2.3:a:goforandroid:go_note_widget:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.97`,
        fs:  `cpe:2.3:a:isc:bind:9.10.2:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.98`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:2.99`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.01`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.02`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.03`,
        fs:  `cpe:2.3:a:riverbed:steelapp_traffic_manager:9.6:9620140312:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.04`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.05`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.594:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.06`,
        fs:  `cpe:2.3:h:lexmark:x46x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.07`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_ras_for_unix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.08`,
        fs:  `cpe:2.3:a:ca:unicenter_management_portal:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.09`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd7.d4xxwtpf_wvga_mb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.10`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.11`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.12`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.11:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.13`,
        fs:  `cpe:2.3:a:silanis:approveit_xhtml_signature_module:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.14`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.15`,
        fs:  `cpe:2.3:a:emc:avamar:5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.16`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:7.1.2:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.17`,
        fs:  `cpe:2.3:a:ca:desktop_protection_suite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.18`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.19`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.20`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_performance_manager:1.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.21`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.22`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.23`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.24`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.25`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.26`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.27`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.28`,
        fs:  `cpe:2.3:a:php:animated_smiley_generator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.29`,
        fs:  `cpe:2.3:h:intel:d845bg_motherboard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.30`,
        fs:  `cpe:2.3:a:cisco:socialminer:10.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.31`,
        fs:  `cpe:2.3:a:softwareag:webmethods:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.32`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.33`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.815:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.34`,
        fs:  `cpe:2.3:a:suse:linux_enterprise_debuginfo:11:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.35`,
        fs:  `cpe:2.3:a:winpcap:winpcap:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.36`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:11.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.37`,
        fs:  `cpe:2.3:a:cisco:intercloud_fabric:3.1.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.38`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.39`,
        fs:  `cpe:2.3:a:ubercart_views_project:uc_views:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.40`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.9.3754:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.41`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.42`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.2.6-5.rhel5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.43`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.44`,
        fs:  `cpe:2.3:a:phome:empirecms:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.45`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.46`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.47`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.48`,
        fs:  `cpe:2.3:h:hp:5820_vpn_firewall_module:jd255a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.49`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.50`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.51`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:5.0.0:beta1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.52`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.431:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.53`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.54`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.55`,
        fs:  `cpe:2.3:a:kdirstat_project:kdirstat:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.56`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.57`,
        fs:  `cpe:2.3:a:ibm:java:5.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.58`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:-:*:solaris:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.59`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp1:datacenter_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.60`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.61`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.62`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.63`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.64`,
        fs:  `cpe:2.3:a:apache:geronimo:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.65`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.66`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.67`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.68`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.69`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.70`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.71`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.04.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.72`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.73`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.74`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.75`,
        fs:  `cpe:2.3:a:sun:solstice_backup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.76`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.77`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.78`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:rc.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.79`,
        fs:  `cpe:2.3:a:netscape:navigator:_navigator:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.80`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:*:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.81`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.82`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.83`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.84`,
        fs:  `cpe:2.3:a:acronis:snapdeploy_management_agent:3.0.3470:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.85`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.86`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p140:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.87`,
        fs:  `cpe:2.3:a:shavlik:netchk_compliance:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.88`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.89`,
        fs:  `cpe:2.3:a:e107:e107:0.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.90`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.91`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.92`,
        fs:  `cpe:2.3:a:lingotek:lingotek:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.93`,
        fs:  `cpe:2.3:a:smarty:smarty:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.94`,
        fs:  `cpe:2.3:a:huawei:campus_series_switch_software:v200r003sph005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.95`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.96`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.1.3.312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.97`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.98`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:3.99`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.15.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.00`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.01`,
        fs:  `cpe:2.3:a:ca:antivirus_gateway:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.02`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.03`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.04`,
        fs:  `cpe:2.3:a:git-scm:git:1.3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.05`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.06`,
        fs:  `cpe:2.3:o:ge:multilink_ml3000_firmware:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.07`,
        fs:  `cpe:2.3:a:motorola:airdefense_personal_manager:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.08`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.09`,
        fs:  `cpe:2.3:o:huawei:s6300ei_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.10`,
        fs:  `cpe:2.3:a:google:chrome:7.0.531.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.11`,
        fs:  `cpe:2.3:h:dell:poweredge_1950:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.12`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.13`,
        fs:  `cpe:2.3:a:gnu:readline:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.14`,
        fs:  `cpe:2.3:a:doorkeeper_project:doorkeeper:1.4.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.15`,
        fs:  `cpe:2.3:a:pop-hub:iq_test:3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.16`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.130.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.17`,
        fs:  `cpe:2.3:a:citrix:xenserver:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.18`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.4:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.19`,
        fs:  `cpe:2.3:a:perl:perl:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.20`,
        fs:  `cpe:2.3:a:apache:struts:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.21`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.22`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.23`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.24`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.25`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.26`,
        fs:  `cpe:2.3:a:motorola:airdefense_personal_agent:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.27`,
        fs:  `cpe:2.3:a:roxio:sonic_recordnow:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.28`,
        fs:  `cpe:2.3:a:wiccle:wiccle_web_builder:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.29`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.30`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.31`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.32`,
        fs:  `cpe:2.3:a:php:php:5.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.33`,
        fs:  `cpe:2.3:a:hp:hpptoocool:0.105.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.34`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.35`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.36`,
        fs:  `cpe:2.3:a:nokia:qt_creator:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.37`,
        fs:  `cpe:2.3:o:cisco:mds_9000_nx-os:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.38`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.39`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.40`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.41`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.42`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_101:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.43`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.2.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.44`,
        fs:  `cpe:2.3:a:apache:hadoop:0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.45`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.46`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.47`,
        fs:  `cpe:2.3:a:ca:igateway:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.48`,
        fs:  `cpe:2.3:h:xerox:workcentre_m35:2.28.11.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.49`,
        fs:  `cpe:2.3:a:gebrauchtwagenreport:dekra_used_car_report:3.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.50`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.51`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.52`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.53`,
        fs:  `cpe:2.3:o:hp:tru64:5.1a_pk5_bl23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.54`,
        fs:  `cpe:2.3:o:cisco:ios_xr:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.55`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.56`,
        fs:  `cpe:2.3:a:condor_project:condor:7.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.57`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.58`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.59`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:11.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.60`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.61`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.06:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.62`,
        fs:  `cpe:2.3:a:cabextract:cabextract:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x2_firmware:4.71`,
        fs:  `cpe:2.3:h:schneider-electric:bmxnoe0100h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iij:seil_x86_fuji:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.70`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.71`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.72`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.13:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.73`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.655:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.74`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.75`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.76`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.77`,
        fs:  `cpe:2.3:a:realacademiabellasartessanfernando:real_academia_de_bellas_artes:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.78`,
        fs:  `cpe:2.3:o:cisco:rv215w_wireless-n_vpn_router_firmware:1.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.79`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_unified_software:1.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.80`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.81`,
        fs:  `cpe:2.3:h:rockwellautomation:1769_compactlogix_5370_l3_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.82`,
        fs:  `cpe:2.3:h:cisco:vpn_5000_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.83`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.84`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.85`,
        fs:  `cpe:2.3:a:hp:trayapp:140.0.213.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.86`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.87`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.88`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.89`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.90`,
        fs:  `cpe:2.3:a:samba:samba:3.0.28:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.91`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.823:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.92`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.93`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.94`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.95`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.96`,
        fs:  `cpe:2.3:a:drupal:drupal:7.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.97`,
        fs:  `cpe:2.3:a:teradata:wintools:2.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.98`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0594:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:1.99`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.10:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.00`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.01`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:7.0.230.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.02`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.03`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):juno-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.04`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.05`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.06`,
        fs:  `cpe:2.3:a:keepass:keepass:0.99:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.07`,
        fs:  `cpe:2.3:a:citrix:app_delivery_setup_tools:1.0.1.211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.08`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.09`,
        fs:  `cpe:2.3:a:ibm:security_qradar_incident_forensics:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.10`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:11.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.11`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.12`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.13`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.14`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.15`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.16`,
        fs:  `cpe:2.3:a:x2engine:x2crm:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.17`,
        fs:  `cpe:2.3:a:gnupg:gpgee:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.18`,
        fs:  `cpe:2.3:a:microsoft:office_proofing_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.19`,
        fs:  `cpe:2.3:h:ibm:power_5:9405-520:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.20`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.21`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.22`,
        fs:  `cpe:2.3:a:samba:samba:3.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.23`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg9000-20:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.24`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.25`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.26`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:21.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.27`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.28`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.29`,
        fs:  `cpe:2.3:a:open-classifieds:open_classifieds:1.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.30`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.31`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.32`,
        fs:  `cpe:2.3:a:avast:endpoint_protection_suite_plus:8.0.1606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.33`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.34`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.35`,
        fs:  `cpe:2.3:a:adobe:livecycle_data_services:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.36`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.37`,
        fs:  `cpe:2.3:o:huawei:s5300ei_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.38`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.39`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.40`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.41`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.42`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.43`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.44`,
        fs:  `cpe:2.3:a:twin_lin_project:twin_lin:5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.45`,
        fs:  `cpe:2.3:h:nvidia:geforce_920m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.46`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.47`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.48`,
        fs:  `cpe:2.3:a:citrix:xenapp_advanced_configuration:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.49`,
        fs:  `cpe:2.3:a:adobe:coldfusion:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.50`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.51`,
        fs:  `cpe:2.3:a:filemaker:filemaker_server:10.0.2.206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.52`,
        fs:  `cpe:2.3:a:oracle:database_server:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.53`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.4:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.54`,
        fs:  `cpe:2.3:a:boost:boost:1.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.55`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.612:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.56`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.350:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.57`,
        fs:  `cpe:2.3:a:juniper:junipersetup_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.58`,
        fs:  `cpe:2.3:h:cisco:catalyst_7600_ws-svc-nam-1:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.59`,
        fs:  `cpe:2.3:a:openssl:openssl:1.1.0g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.60`,
        fs:  `cpe:2.3:o:suse:suse_linux:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.61`,
        fs:  `cpe:2.3:a:jease:jease:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.62`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.3.300.270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.63`,
        fs:  `cpe:2.3:a:intel:mwlssafe:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.64`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.65`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.66`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.1:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.67`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.68`,
        fs:  `cpe:2.3:a:google:chrome:6.0.460.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.69`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.30.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.70`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:unstable2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.71`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.72`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.73`,
        fs:  `cpe:2.3:a:imember360:imember360:3.7.002:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.74`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.75`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1311.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.76`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.77`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.78`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.79`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.80`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0d_pk9_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.81`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.82`,
        fs:  `cpe:2.3:a:bullguard:premium_protection:14.1.287:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.83`,
        fs:  `cpe:2.3:a:vmware:fusion:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.84`,
        fs:  `cpe:2.3:a:gnu:screen:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.85`,
        fs:  `cpe:2.3:a:google:chrome:10.0.619.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.86`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.87`,
        fs:  `cpe:2.3:o:d-link:dcs-2530l_firmware:1.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.88`,
        fs:  `cpe:2.3:a:drupal:drupal:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.89`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.90`,
        fs:  `cpe:2.3:a:sm3ny:www.sm3ny.com:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.91`,
        fs:  `cpe:2.3:a:ibm:intelligent_operations_center:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.92`,
        fs:  `cpe:2.3:h:creston:dm-txrx-100-str:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.93`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.94`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.95`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.96`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak2:2.0.33.7:-:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.97`,
        fs:  `cpe:2.3:a:zope:zope:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.98`,
        fs:  `cpe:2.3:o:freebsd:freebsd:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:2.99`,
        fs:  `cpe:2.3:a:redhat:up2date:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.00`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.01`,
        fs:  `cpe:2.3:a:adobe:community_help:3.4.973:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.02`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)st8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.03`,
        fs:  `cpe:2.3:a:oracle:workflow:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.04`,
        fs:  `cpe:2.3:h:zyxel:p-660hw:_t1:v3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.05`,
        fs:  `cpe:2.3:a:aptexx:resident_anywhere:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.06`,
        fs:  `cpe:2.3:a:adobe:flash_player:22.0.0.192:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.07`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.08`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.09`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.10`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.11`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0.2112:online_windows_server_2003_x64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.12`,
        fs:  `cpe:2.3:a:bellyhoodcom_project:bellyhoodcom:3.4.23:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.13`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.14`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:269:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.15`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l3_controller_firmware:20.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.16`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_51:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.17`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.18`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.19`,
        fs:  `cpe:2.3:a:google:chrome:16.0.891.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.20`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.21`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.22`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.30`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.58:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iij:seil_x86_fuji_firmware:3.31`,
        fs:  `cpe:2.3:a:logitech:lws_gallery:13.30.1379.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iirf:ionic%27s_isapi_rewrite_filter:2.1.1.25`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iirf:ionic%27s_isapi_rewrite_filter:2.1.1.26`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ijianren:jian_ren:1.5.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sxi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.0`,
        fs:  `cpe:2.3:a:cisco:unified_presence_server:9.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.1`,
        fs:  `cpe:2.3:a:anl:bcfg2:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.1.47`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.2`,
        fs:  `cpe:2.3:a:batch:batch_library:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.3`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.4`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.5`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.6`,
        fs:  `cpe:2.3:a:git-scm:git:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.9`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.10`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.11`,
        fs:  `cpe:2.3:a:wellintech:kinggraphic:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.12`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.14`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.2.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.15`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.16`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.17`,
        fs:  `cpe:2.3:h:htc:vivid:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.18`,
        fs:  `cpe:2.3:a:altiris:monitor_pack_for_altiris_infrastructure:6.0.1057:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.19`,
        fs:  `cpe:2.3:a:redhat:tcpdump:3.6.2-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.20`,
        fs:  `cpe:2.3:h:linksys:wet11:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.21`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.2:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.22`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.23`,
        fs:  `cpe:2.3:a:rocomotion:p_link_compact:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.24`,
        fs:  `cpe:2.3:a:pandasecurity:panda_global_protection_2014:7.01.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.25`,
        fs:  `cpe:2.3:a:hp:ftp_print_server:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.26`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.27`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.28`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:3.1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.29`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.30`,
        fs:  `cpe:2.3:a:anark:client:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.31`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_base_platform:12.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.32`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.18.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.33.3`,
        fs:  `cpe:2.3:a:hp:support_tools_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.34`,
        fs:  `cpe:2.3:a:fasttoggle_project:fasttoggle:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.34.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.34.2`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.35`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.36`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6ecd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.37`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.4p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.38`,
        fs:  `cpe:2.3:h:lexmark:n8130:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.39`,
        fs:  `cpe:2.3:a:sas:sas_enterprise_guide:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.40`,
        fs:  `cpe:2.3:h:supermicro:x9dax-itf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.41`,
        fs:  `cpe:2.3:a:drupal:drupal:6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.42`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.43`,
        fs:  `cpe:2.3:a:oracle:industry_applications:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.44`,
        fs:  `cpe:2.3:a:ibm:service_delivery_manager:7.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.45`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.46`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.47`,
        fs:  `cpe:2.3:a:oman_news_project:oman_news:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.48`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.49`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.30-25.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.50`,
        fs:  `cpe:2.3:h:huawei:campus_s2750:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:1.51`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.0`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.996:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.00`,
        fs:  `cpe:2.3:a:ibm:spss_analytical_decision_management:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.1`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.3`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.11.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.4`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.5`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.61:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.6`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.6.1`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.7`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.15.0.369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.8`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:16.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.9`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.10`,
        fs:  `cpe:2.3:h:apple:imac:ma406xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.11`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.12`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.13`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:4.0.0.1628:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.14`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.15`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1010.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.16`,
        fs:  `cpe:2.3:a:apple:ibooks_author:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.17`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p57:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.18`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.19`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.20`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.30`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.31`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.02b11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.31.1`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.31.2`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.31.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.40`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0000_0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.41`,
        fs:  `cpe:2.3:a:docker:docker:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.42`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.43`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.44`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2009:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.45`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.46`,
        fs:  `cpe:2.3:a:splunk:splunk:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.47`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.4:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.48`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.49`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.50`,
        fs:  `cpe:2.3:h:hp:jg866a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.51`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.52`,
        fs:  `cpe:2.3:a:springcm:privia_platform:5.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.53`,
        fs:  `cpe:2.3:h:blackberry:z10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.54`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1042:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.55`,
        fs:  `cpe:2.3:a:cisco:ssl_vpn_client:1_1_2_169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.56`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.60`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:6.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.61`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.62`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.62.1`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.63`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.64`,
        fs:  `cpe:2.3:a:debian:adequate:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.65`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.66`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.67`,
        fs:  `cpe:2.3:o:juniper:junos:5.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.68`,
        fs:  `cpe:2.3:a:acquia:commons:7.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.69`,
        fs:  `cpe:2.3:a:ca:workload_automation_ae:11.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.70`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.71`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:2.72`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.00`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.01`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.02`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.03`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.04`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.00.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.05`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.06`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.07`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.08`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.09`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.85:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.10`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.11`,
        fs:  `cpe:2.3:a:ca:directory:r12:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.12`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.13`,
        fs:  `cpe:2.3:a:cisco:jabber_guest:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.14`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:2.3\(1.55\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.141`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.4.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.1415`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.14159`,
        fs:  `cpe:2.3:o:windriver:platform_sa:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.141592`,
        fs:  `cpe:2.3:a:mcafee:spamkiller:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.1415926`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.14159265`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.1:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20091009`,
        fs:  `cpe:2.3:h:d-link:di-604up:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20091017`,
        fs:  `cpe:2.3:a:apple:itunes:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20091022`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20091023`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20091031`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20091113`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20091202`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20091218`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100102.3`,
        fs:  `cpe:2.3:a:progress:openedge:10.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100122`,
        fs:  `cpe:2.3:o:siemens:ccis1425_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100212`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100302`,
        fs:  `cpe:2.3:h:ibm:flex_system_x220_compute_node:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100312`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100403`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(9\)aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100427`,
        fs:  `cpe:2.3:a:nefarious2_project:nefarious2:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100501`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100504`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100515`,
        fs:  `cpe:2.3:a:qualcomm:gobi_single_installer_package_for_novatel:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100518`,
        fs:  `cpe:2.3:a:ibm:tivoli_continuous_data_protection_for_files:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100518.2`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp5:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100610`,
        fs:  `cpe:2.3:o:brocade:fabric_os:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100623`,
        fs:  `cpe:2.3:a:microsoft:security_compliance_manager:2.0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100722`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100804`,
        fs:  `cpe:2.3:a:trillian:trillian:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100815`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100831`,
        fs:  `cpe:2.3:a:hancom:hancom_office_2010_se:8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20100926`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p183:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20101019`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20101023`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20101112`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20101129`,
        fs:  `cpe:2.3:a:magzter:cleo_malaysia:3.01:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20101201`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20101231`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20110105`,
        fs:  `cpe:2.3:a:redhat:network_proxy:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20110123`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20110124`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20110225`,
        fs:  `cpe:2.3:h:huawei:quidway_service_process_unit_board_s9300:v200r001c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20110321`,
        fs:  `cpe:2.3:a:microsoft:word:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki:ikiwiki:3.20160121`,
        fs:  `cpe:2.3:a:webmin:usermin:1.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110401`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110420`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110424`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110515`,
        fs:  `cpe:2.3:o:apple:airport_base_station_firmware:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110608`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110926`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20111005`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120125`,
        fs:  `cpe:2.3:a:digi:www_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120131`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.4f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120425`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120526`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120527`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20130504`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ikiwiki_hosting_project:ikiwiki_hosting:0.20130926`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilch:cms:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilch:ilch_cms:2.0`,
        fs:  `cpe:2.3:a:splunk:splunk:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilearnwith:alphabet_%26_spelling_kids_games:1.4.2::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilearnwith:animals%21_kids_preschool_games:1.6.1::~~~android~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilearnwith:counting_%26_addition_kids_games:1.8.1::~~~android~~`,
        fs:  `cpe:2.3:h:cisco:wide_area_application_engine_nm-wae-502:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilearnwith:fun_preschool_creativity_game:1.6.2::~~~android~~`,
        fs:  `cpe:2.3:h:huawei:usg2100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilearnwith:numbers_%26_addition%21_math_games:1.4.3::~~~android~~`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilexeng:lrgs:-`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.7.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.7.2`,
        fs:  `cpe:2.3:a:ca:license_software:1.90.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.7.3`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:01-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.7.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.7.5`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.7.6`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.7.7`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.8.0`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:2.8.1`,
        fs:  `cpe:2.3:a:raphael_assenat:libmikmod:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:3.0.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(3s\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:3.0.1`,
        fs:  `cpe:2.3:a:f5:big-ip:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:3.0.2`,
        fs:  `cpe:2.3:a:google:chrome:3.0.193.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:3.0.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:3.0.4`,
        fs:  `cpe:2.3:o:d-link:dsr-250n_firmware:1.05b20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilia_alshanetsky:fudforum:3.0.4.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilias:ilias:4.4.1`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1056:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iliumsoft:ewallet:6.0::~~professional~~~`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.0.5:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:illinois:ncsa_mosaic:2.0`,
        fs:  `cpe:2.3:a:bzip:bzip2:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:illinois:ncsa_mosaic:2.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:illinois:ncsa_mosaic:2.7:-`,
        fs:  `cpe:2.3:a:lutim_project:lutim:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:illinois:ncsa_mosaic:2.7:b5`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:illumos:illumos:-`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:illumos:illumos:r13723`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilove:ilove_-_free_dating_%26_chat_app:1.3.3::~~~android~~`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ilovegame:longjiang:2.0.6::~~~android~~`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_desktop:11.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:im5_fans_planet_project:im5_fans_planet:2.3.1::~~~android~~`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:image_metadata_cruncher_project:image_metadata_cruncher:-::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:image_title_project:image_title:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:usaf:accm:1.0.0.1047:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagecms:imagecms:4.0.0:b`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:10.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagecms:imagecms:4.2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagecms:imagecms:4.5.2`,
        fs:  `cpe:2.3:a:rainbow:sentinel_system_driver:5.39.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:intel:expressway_cloud_access_360:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:avg:anti-virus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:ofbiz:12.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rsa:envision:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:iirf:ionic\&#39;s_isapi_rewrite_filter:2.1.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-3510c_firmware:t380sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.7.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emery_berger:hoard:2.1.2:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.7.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.8.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:message_queuing:1.11_build_29_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.8.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:ie:7.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.16:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:citrix:access_management_console_legacy_tools:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.23.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:trillian:trillian:0.521:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.10::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)t8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:1.9.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:d-link:dap-2310_firmware:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:r-company:unzipper:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.8.1p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.17::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(17\)cc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.21::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.23::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:http_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.25::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.27::~~~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.30::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s7506e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cloudera:cloudera_cdh:cdh3:0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.33::~~~wordpress~~`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.40::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.57::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:6.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.58::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.59::~~~wordpress~~`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2012:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.61::~~~wordpress~~`,
        fs:  `cpe:2.3:o:opensuse:leap:42.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.63::~~~wordpress~~`,
        fs:  `cpe:2.3:o:google:android:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.65::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5\(1\)su5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.66::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.66.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rsa:ace_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.66.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.66.26::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:catalyst_6506-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.66.27::~~~wordpress~~`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.66.29::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.66.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:blaine_lang:maestro:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.66.33::~~~wordpress~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.71::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mysql:mysql_connector\/odbc:3.51.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.74::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apprain:apprain:0.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.76::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.77::~~~wordpress~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.78::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:software_perl:5.8.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.78.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:intel:d845pt_motherboard:p02-0015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.0.79::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cypherpunks:libotr:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagely:nextgen_gallery:2.1.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gsview:gsview:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:-`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:4.2.7`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:4.2.9`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.0.9.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.2`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.2.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.2.4.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.2.6`,
        fs:  `cpe:2.3:a:componentone:vsflexgrid:8.0.20072.239:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.0`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:4.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.2`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.0:alpha_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.3`,
        fs:  `cpe:2.3:h:securecomputing:samsung_adsl_modem:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.4`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0087:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.5`,
        fs:  `cpe:2.3:h:sun:fire_x4100m2_server:sw_2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.6`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.7`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.8`,
        fs:  `cpe:2.3:h:hp:jh198a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.8.2`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.3.9`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4`,
        fs:  `cpe:2.3:a:hp:smart_web_printing:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.0.5`,
        fs:  `cpe:2.3:h:hp:jg597a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.1.2`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.2.3`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.3`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.3.11`,
        fs:  `cpe:2.3:a:lucent:vitalnet:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.4.5`,
        fs:  `cpe:2.3:h:huawei:s5300:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.5.1`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.6.3`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.7`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.21:-:*:*:*:suse_linux:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.7.4`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.8`,
        fs:  `cpe:2.3:h:axis:2400_video_server:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.8.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.4.9.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5`,
        fs:  `cpe:2.3:a:creative_core:app_lock:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.1.4`,
        fs:  `cpe:2.3:a:mandrakesoft:mandrake_single_network_firewall:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.2.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.3.2`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.3.2.1.2.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.4.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.4.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.5.3`,
        fs:  `cpe:2.3:a:hp:jg787a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.6`,
        fs:  `cpe:2.3:a:norman:security_suite:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.6.0_2003-04-09`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.6.0_20030409`,
        fs:  `cpe:2.3:a:trimble:sketchup_viewer:13.0.4124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.138:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.7.15`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.7.31`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.7.35`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.7q8`,
        fs:  `cpe:2.3:a:hp:ocr_software_by_i.r.i.s:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:5.5.7q16`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je033a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0`,
        fs:  `cpe:2.3:a:cubicfactory:cubic_cms:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.0.7`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.295:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.1.4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.2`,
        fs:  `cpe:2.3:h:cisco:nexus_5596t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.2.5`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.2.7`,
        fs:  `cpe:2.3:a:hp:sitescope:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.3`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.3.5`,
        fs:  `cpe:2.3:a:microsoft:excel:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.4`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.4.4`,
        fs:  `cpe:2.3:a:dell:openmanage_client_instrumentation:7.1.382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.5`,
        fs:  `cpe:2.3:a:ipswitch:imail_server:2006.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.5.3`,
        fs:  `cpe:2.3:a:google:checkout-php:1.2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.6`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.6.1`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.6.2`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.7`,
        fs:  `cpe:2.3:a:mozilla:firefox:42.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.7.3`,
        fs:  `cpe:2.3:a:samba:samba:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.8`,
        fs:  `cpe:2.3:a:securecomputing:sidewinder_g2:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.0.8.3`,
        fs:  `cpe:2.3:a:nullsoft:winamp:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.0.9`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.1`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.1.6`,
        fs:  `cpe:2.3:a:oracle:customer_relationship_management_technical_foundation:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.2`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac_afr:6.1.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.2.7`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.3`,
        fs:  `cpe:2.3:o:cray:unicos:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.3.7`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.3:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.7.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.4.5`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.1.0.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.5`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.7.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.5.8`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.6`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.6.9`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.5:*:*:*:*:aix:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.7`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.7.5`,
        fs:  `cpe:2.3:a:ibm:security_guardium_database_activity_monitor:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:108.2146.2565.38893:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.8.7`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.1.9.4`,
        fs:  `cpe:2.3:a:drupal:drupal:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.4.e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.0.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.0.4`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.0.7`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.0.8`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6a:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.1`,
        fs:  `cpe:2.3:a:nvidia:control_panel:275.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.1.7`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.2`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.3:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.2.5`,
        fs:  `cpe:2.3:o:alcatel:aos:5.1.6.463:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.3`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.3.4`,
        fs:  `cpe:2.3:a:alkacon:opencms:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.3.6`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.4`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.4.3`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.4.5`,
        fs:  `cpe:2.3:a:altiris:agent_for_pocket_pc:6.1.1141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.5`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:037:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.6`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.3.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.7`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.8`,
        fs:  `cpe:2.3:a:isc:bind:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.8.0`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.2.5-50.rhel5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.8.1`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.8.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.8.3`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.9`,
        fs:  `cpe:2.3:a:dolphin-browser:dolphin_browser_hd:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.2.9.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.0.0`,
        fs:  `cpe:2.3:a:python:python:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.0.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.0.2`,
        fs:  `cpe:2.3:o:hp:tru64:4.0g_pk3_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.0.4`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.0.5`,
        fs:  `cpe:2.3:a:php:pear:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.0.7`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.0.8`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1-6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1-7`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.95:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1.2.`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1.3`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1.4`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1.5`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1.6`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.3.22:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.1.7`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a4:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-0`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-04-15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-1`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-2`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-3`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-4`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-5`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-7`,
        fs:  `cpe:2.3:a:sas:base_sas:9.4:ts1m0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2-8`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:07-56:-:standard:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.1`,
        fs:  `cpe:2.3:a:worldtamilbayan:world_tamil_bayan:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:17.009.20058:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.4`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.5:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.5`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.6`,
        fs:  `cpe:2.3:a:gittigidiyor:gittigidiyor:1.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.7`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.2.8`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-0`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-1`,
        fs:  `cpe:2.3:a:ibm:websphere_edge_server_caching_proxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-2`,
        fs:  `cpe:2.3:o:nokia:symbian_os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.1.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-4`,
        fs:  `cpe:2.3:a:advantech:webaccess:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-6`,
        fs:  `cpe:2.3:o:arubanetworks:instant_access_point_firmware:4.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-7`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-8`,
        fs:  `cpe:2.3:a:axis:camera_station:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3-9`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf816a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3.1`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3.3`,
        fs:  `cpe:2.3:o:sophos:web_appliance_firmware:3.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:41.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3_3`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3_5`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.3_6`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4`,
        fs:  `cpe:2.3:a:debian:base-config:2.53.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-0`,
        fs:  `cpe:2.3:a:ibm:http_server:7.0.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-1`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(2b\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-3`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1015:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-4`,
        fs:  `cpe:2.3:a:microsoft:windows_script:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-5`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-6`,
        fs:  `cpe:2.3:a:symantec:on_command_discovery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-8`,
        fs:  `cpe:2.3:a:hp:vertica:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-9`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.4-10`,
        fs:  `cpe:2.3:a:vmware:tools:9.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.5`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.5-0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.5-4`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.5-5`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.5-6`,
        fs:  `cpe:2.3:a:coreftp:core_ftp:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.5-7`,
        fs:  `cpe:2.3:a:goahead:goahead_webserver:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.5-9`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.5-10`,
        fs:  `cpe:2.3:o:windriver:wrlinux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-1`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-2`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-4`,
        fs:  `cpe:2.3:a:mobage:tiny_tower:1.7.0.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-5`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.10.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-6`,
        fs:  `cpe:2.3:h:supermicro:x9drff-it\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-7`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-8`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.2:1003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-9`,
        fs:  `cpe:2.3:a:microsoft:word:2000:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.6-10`,
        fs:  `cpe:2.3:a:f5:linerate:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-0`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-1`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-2`,
        fs:  `cpe:2.3:a:mitfahrgelegenheit:mitfahrgelegenheit.at:2.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-3`,
        fs:  `cpe:2.3:a:dest-unreach:socat:2.0.0:b7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-4`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-5`,
        fs:  `cpe:2.3:o:iodata:ts-wptcam_camera_firmware:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-7`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-9`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.7-10`,
        fs:  `cpe:2.3:o:juniper:junos:14.2:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8`,
        fs:  `cpe:2.3:a:gnu:bash:1.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-0`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-2`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-3`,
        fs:  `cpe:2.3:a:sun:jre:1.3.0:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-5`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-6`,
        fs:  `cpe:2.3:a:apple:xcode:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-7`,
        fs:  `cpe:2.3:a:vips:vips:7.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-9`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.8-10`,
        fs:  `cpe:2.3:a:google:chrome:5.0.348.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.1yj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-0`,
        fs:  `cpe:2.3:h:novatech:orionlx_dnp_master:1.27.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-2`,
        fs:  `cpe:2.3:a:teradata:fastexport:13.10.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-4`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-5`,
        fs:  `cpe:2.3:a:sharethis:sharethis:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-6`,
        fs:  `cpe:2.3:a:ibm:algo_one:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-7`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-8`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-9`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.3.9-10`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1019:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-0`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_workstation:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-4`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-5`,
        fs:  `cpe:2.3:a:phpthumb_project:phpthumb:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-6`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-7`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-8`,
        fs:  `cpe:2.3:a:tripwire:via_agent:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-10`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.0-11`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1`,
        fs:  `cpe:2.3:h:avaya:cajun_p550r:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-0`,
        fs:  `cpe:2.3:a:cisco:telepresence_vx_clinical_assistant:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-1`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-2`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-3`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.03b27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-4`,
        fs:  `cpe:2.3:a:codoforum:codoforum:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-5`,
        fs:  `cpe:2.3:o:sgi:irix:6.0.1:*:xfs:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-6`,
        fs:  `cpe:2.3:a:trillian:trillian:0.723:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-7`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.7:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-8`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.1-9`,
        fs:  `cpe:2.3:a:emc:navisphere_server_utility:6.20.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-0`,
        fs:  `cpe:2.3:a:umn:mapserver:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-1`,
        fs:  `cpe:2.3:a:hp:care_pack_products:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-2`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-4`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-5`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-6`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-7`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-8`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.21:-:*:*:*:hp-ux:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-9`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.2-10`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-1`,
        fs:  `cpe:2.3:a:citrix:xenserver:6.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-2`,
        fs:  `cpe:2.3:a:ibm:content_collector:3.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-3`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-5`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-6`,
        fs:  `cpe:2.3:a:google:chrome:11.0.682.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-7`,
        fs:  `cpe:2.3:a:microsoft:system.net.http:4.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-8`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.3-10`,
        fs:  `cpe:2.3:h:lucent:ascend_tnt_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.4`,
        fs:  `cpe:2.3:a:php:php:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.4-0`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-281c_firmware:t410sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.4-1`,
        fs:  `cpe:2.3:a:connections_project:connections:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.4-3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.4-5`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.4-7`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.4-8`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5-0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5-1`,
        fs:  `cpe:2.3:a:kiragames:unblock_me_free:1.4.4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5-2`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5-3`,
        fs:  `cpe:2.3:a:altiris:network_discovery_documentation:6.0.1025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5-4`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5-6`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5-7`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.5-9`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_server:5.0.201:rp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-0`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-2`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-3`,
        fs:  `cpe:2.3:a:isc:bind:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-4`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-5`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.17.304:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-6`,
        fs:  `cpe:2.3:a:xnview:xnview:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-8`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.6-9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-1`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-2`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-3`,
        fs:  `cpe:2.3:a:quagga:quagga:0.96.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-4`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.32-bzr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-5`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-6`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-7`,
        fs:  `cpe:2.3:a:php:php:5.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-8`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-9`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.7-10`,
        fs:  `cpe:2.3:a:ca:inoculateit_agent_for_exchange:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-0`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-3`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-4`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-5`,
        fs:  `cpe:2.3:a:skype:skype:1.4.0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-6`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-7`,
        fs:  `cpe:2.3:a:hp:6000e609_basicweb:140.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-8`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-9`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.8-10`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.4:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxe3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9-0`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9-2`,
        fs:  `cpe:2.3:a:microsoft:lync:2013:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9-3`,
        fs:  `cpe:2.3:a:att:connect_participant_application:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9-5`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.0:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9-7`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9-8`,
        fs:  `cpe:2.3:a:sun:openwindows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9-9`,
        fs:  `cpe:2.3:a:nintex:workflow:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.4.9-10`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0`,
        fs:  `cpe:2.3:a:tenable:nessus:6.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-0`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-1`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma600xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-2`,
        fs:  `cpe:2.3:a:rhq-project:rhq:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-3`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-4`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.9.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-5`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-6`,
        fs:  `cpe:2.3:a:serf_project:serf:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-7`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-8`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-9`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.0-10`,
        fs:  `cpe:2.3:a:clamav:clamav:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p258:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.795.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-2`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-3`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:08.0.01i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-4`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_xenapp_agent:5.3.4132.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-5`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.99.905:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-6`,
        fs:  `cpe:2.3:a:ocportal:ocportal:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-7`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-9`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.1-10`,
        fs:  `cpe:2.3:a:scripteen:free_image_hosting_script:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2`,
        fs:  `cpe:2.3:a:life_story_of_sheikh_mujib_project:life_story_of_sheikh_mujib:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-0`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.34a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-2`,
        fs:  `cpe:2.3:a:i-um:ium:3.3.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-3`,
        fs:  `cpe:2.3:a:kingsoft:kingsoft_antivirus:2010.04.26.648:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-4`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-5`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-6`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-7`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-8`,
        fs:  `cpe:2.3:a:symantec:veritas_dmp_dsm_solution:5.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-9`,
        fs:  `cpe:2.3:a:skype:skype:0.97.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.2-10`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-1`,
        fs:  `cpe:2.3:a:core-apps:ira\&#39;s_59th_annual_conference:6.0.7.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-3`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-4`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-5`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.1:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-6`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.19:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-7`,
        fs:  `cpe:2.3:a:gnome:glib:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-8`,
        fs:  `cpe:2.3:a:netscape:navigator:8.0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.3-10`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-1`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-3`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:3.0.306:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-4`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-5`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-6`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-7`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.2462.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-8`,
        fs:  `cpe:2.3:a:vmware:gsx_server:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-9`,
        fs:  `cpe:2.3:o:hp:800_series_firmware:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.4-10`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5`,
        fs:  `cpe:2.3:a:cisco:finesse:10.5\(1\)_es2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-1`,
        fs:  `cpe:2.3:a:synology:ds_audio:3.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-2`,
        fs:  `cpe:2.3:a:solarwinds:ip_address_manager_web_interface:3.0:hotfix1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-3`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-4`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-5`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-6`,
        fs:  `cpe:2.3:a:git-scm:git:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-7`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-8`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-9`,
        fs:  `cpe:2.3:h:fujitsu:arrows_tab_lte_f-01d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.5-10`,
        fs:  `cpe:2.3:a:drupal:drupal:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-2`,
        fs:  `cpe:2.3:a:osticket:osticket:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-3`,
        fs:  `cpe:2.3:h:emc:cloud_tiering_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-5`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-6`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.7.1.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-7`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-8`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-9`,
        fs:  `cpe:2.3:a:apache:httpclient:4.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.6-10`,
        fs:  `cpe:2.3:a:etoolkit:love_collage_-_photo_editor:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.0.3.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-1`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-2`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-4`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.0.1.1-ifix01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-5`,
        fs:  `cpe:2.3:a:rpm:rpm:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-6`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-7`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-8`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.7-9`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8`,
        fs:  `cpe:2.3:a:emulex:fibre_channel_hbanyware:2.1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-0`,
        fs:  `cpe:2.3:a:hp:select_identity:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-1`,
        fs:  `cpe:2.3:a:sysphonic:thetis:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-2`,
        fs:  `cpe:2.3:a:plotsoft:pdfill_pdf_editor:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-4`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-5`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-6`,
        fs:  `cpe:2.3:a:isc:bind:8.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-7`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:8.5.6-106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-8`,
        fs:  `cpe:2.3:a:e-xoopport:samsara:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.8-9`,
        fs:  `cpe:2.3:a:avaya:visual_messenger_tm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-0`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-1`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-2`,
        fs:  `cpe:2.3:a:apache:couchdb:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-5`,
        fs:  `cpe:2.3:a:barebones:yojimbo:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-6`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.5:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-7`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:11.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-8`,
        fs:  `cpe:2.3:a:csc:xmlwebservice:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.5.9-10`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0`,
        fs:  `cpe:2.3:a:basercms:basercms:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.332.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-1`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-2`,
        fs:  `cpe:2.3:a:oracle:e-business_intelligence:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-3`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-4`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-5`,
        fs:  `cpe:2.3:o:cisco:staros:18.1.0.59780:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-6`,
        fs:  `cpe:2.3:a:naranjascontocados:naranjas_con_tocados:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-7`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-8`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-9`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.0-10`,
        fs:  `cpe:2.3:a:rpm:rpm:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-07-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-0`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-1`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-2`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-3`,
        fs:  `cpe:2.3:h:hp:officejet_pro_8500:cb022a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-4`,
        fs:  `cpe:2.3:a:viralheat:argyle_social:2011-04-26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-5`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-6`,
        fs:  `cpe:2.3:a:adobe:after_effects:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-7`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-8`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.01:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-9`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.1-10`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(3b\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.447.1:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-1`,
        fs:  `cpe:2.3:a:analog:soundmax:5.12.01.3890:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-2`,
        fs:  `cpe:2.3:a:dell:touchpad:7.2.101.215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-3`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-4`,
        fs:  `cpe:2.3:a:ibm:platform_symphony:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-5`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-6`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-7`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-8`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-9`,
        fs:  `cpe:2.3:a:haxx:curl:7.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.2-10`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3`,
        fs:  `cpe:2.3:a:jruby:jruby:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-0`,
        fs:  `cpe:2.3:a:apache:hadoop:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-1`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-2`,
        fs:  `cpe:2.3:a:telligent:evolution:7.5.0.32466:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-3`,
        fs:  `cpe:2.3:a:netscape:communicator:4.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-4`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-5`,
        fs:  `cpe:2.3:o:juniper:junos:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-6`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.3-10`,
        fs:  `cpe:2.3:a:apple:webkit:51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4`,
        fs:  `cpe:2.3:a:dell:controlvault_host_components_installer:2.0.20.159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-0`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-1`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-4`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-5`,
        fs:  `cpe:2.3:a:typoheads:formhandler:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-6`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-7`,
        fs:  `cpe:2.3:a:hioa:student_id:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.4-10`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5`,
        fs:  `cpe:2.3:h:ibm:iseries_as_400:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-0`,
        fs:  `cpe:2.3:a:siemens:simatic_wincc_sm\@rtclient_lite:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-1`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-2`,
        fs:  `cpe:2.3:a:divx:player:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-3`,
        fs:  `cpe:2.3:h:apple:ipad:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-4`,
        fs:  `cpe:2.3:a:microsoft:interdev:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-5`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-6`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-7`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-8`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-9`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.5-10`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.0-68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-1`,
        fs:  `cpe:2.3:a:gnu:gzip:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-2`,
        fs:  `cpe:2.3:a:intel:2915abg_proset_wireless:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-3`,
        fs:  `cpe:2.3:a:bizagi:business_process_management_suite:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-4`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-5`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-6`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-7`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-8`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-9`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.6-10`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-2`,
        fs:  `cpe:2.3:h:supermicro:x9drg-htf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-3`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-4`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-5`,
        fs:  `cpe:2.3:o:freebsd:freebsd:9.1:release-p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-6`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-50-\/f:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-7`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-8`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-9`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.7-10`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-0`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-1`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-2`,
        fs:  `cpe:2.3:h:lexmark:xc8160dte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-3`,
        fs:  `cpe:2.3:o:cisco:cisco_ons_15454_system_software:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-4`,
        fs:  `cpe:2.3:h:d-link:dsl-2760u-e1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-5`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-6`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-7`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.5.3.818:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-8`,
        fs:  `cpe:2.3:a:ibm:aix_snmp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-9`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.8-10`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-1`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-2`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp2:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-3`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-4`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-5`,
        fs:  `cpe:2.3:a:redhat:network_satellite_server:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-6`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-8`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-9`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.6.9-10`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-0`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-2`,
        fs:  `cpe:2.3:a:pro_bet_tips_project:pro_bet_tips:0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-4`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-5`,
        fs:  `cpe:2.3:a:gnu:zebra:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.111.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-7`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-8`,
        fs:  `cpe:2.3:a:adobe:adobe_air:4.0.0.1628:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p167:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.0-10`,
        fs:  `cpe:2.3:a:haxx:curl:7.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-0`,
        fs:  `cpe:2.3:a:barebones:yojimbo:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-2`,
        fs:  `cpe:2.3:h:3com:tippingpoint_5000e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-3`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-4`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-08-15a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-5`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-6`,
        fs:  `cpe:2.3:a:zenprise:zenprise_device_manager:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-7`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-8`,
        fs:  `cpe:2.3:h:zte:zxhn_h108n_r1a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-9`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.0.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.1-10`,
        fs:  `cpe:2.3:a:schneider-electric:proclima:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-1`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-2`,
        fs:  `cpe:2.3:a:wftpserver:wing_ftp_server:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-3`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-4`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-5`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.06b53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-6`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-7`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-8`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-9`,
        fs:  `cpe:2.3:h:3com:3c17707-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.2-10`,
        fs:  `cpe:2.3:a:gnu:glibc:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5216a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-1`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-2`,
        fs:  `cpe:2.3:a:apache:struts:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.491:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-4`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-5`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-6`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.0.0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-7`,
        fs:  `cpe:2.3:a:ca:etrust_security_command_center:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-8`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-9`,
        fs:  `cpe:2.3:a:x:libxi:1.5.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.3-10`,
        fs:  `cpe:2.3:a:intel:network_connections:16.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-0`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:1.2.5:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-1`,
        fs:  `cpe:2.3:h:xerox:workcentre_32_color:01.02.077.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-3`,
        fs:  `cpe:2.3:a:collabnet:subversion:1.4.6-r28521:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-5`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.649:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-8`,
        fs:  `cpe:2.3:a:php:php:5.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-9`,
        fs:  `cpe:2.3:o:cisco:unified_wireless_ip_phone_7920_firmware:1.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.4-10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.271:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-0`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.2_a:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-2`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-3`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-5`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:10.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-6`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-7`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-8`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-9`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.5-10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-1`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-2`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-4`,
        fs:  `cpe:2.3:a:citrix:delivery_services_console_knowledge_base:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-5`,
        fs:  `cpe:2.3:h:cisco:ios:12.0sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-6`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120705:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-7`,
        fs:  `cpe:2.3:a:peel:peel_shopping:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-8`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-9`,
        fs:  `cpe:2.3:a:orderingapps:buckhorn_grill:2.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.6-10`,
        fs:  `cpe:2.3:a:lingotek:lingotek:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-0`,
        fs:  `cpe:2.3:a:d-coda:contactme:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.9.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-2`,
        fs:  `cpe:2.3:a:addisgag:addis_gag_funny_amharic_pic:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-3`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-4`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-5`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.28:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-6`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-7`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-8`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc2300:a6899a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-9`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.7-10`,
        fs:  `cpe:2.3:a:red-gate:sql_response:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-0`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-1`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-2`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-3`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd1.m2xx0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-4`,
        fs:  `cpe:2.3:h:dell:latitude_xt2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-5`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-6`,
        fs:  `cpe:2.3:a:altiris:monitor_for_notification_server_metric:6.0.1057:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-7`,
        fs:  `cpe:2.3:a:quantum:xtalk_management_console:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-8`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-9`,
        fs:  `cpe:2.3:a:citrix:program_neighborhood_client:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.8-10`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20091202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-4`,
        fs:  `cpe:2.3:a:manugistics:rfq:7.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-5`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-6`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-7`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-8`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-9`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.7.9-10`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0`,
        fs:  `cpe:2.3:a:siemens:scalance_xr-300_firmware:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-0`,
        fs:  `cpe:2.3:a:gnu:gzip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-2`,
        fs:  `cpe:2.3:a:debian:guilt:0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.417.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-4`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-5`,
        fs:  `cpe:2.3:h:huawei:s5300hi:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-6`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-8`,
        fs:  `cpe:2.3:a:apple:quicktime:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-9`,
        fs:  `cpe:2.3:h:hp:jg184a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.0-10`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-0`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-1`,
        fs:  `cpe:2.3:a:ibm:websphere_extended_deployment_compute_grid:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-2`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-3`,
        fs:  `cpe:2.3:a:microsoft:html_help:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-4`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-5`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-6`,
        fs:  `cpe:2.3:a:citadel:ux:6.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-7`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-8`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_access:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.1-10`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-0`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-1`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-2`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:9.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-3`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-4`,
        fs:  `cpe:2.3:a:usebb:usebb:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-5`,
        fs:  `cpe:2.3:a:vips:vips:7.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-6`,
        fs:  `cpe:2.3:a:securityinnovation:ntru_tcg_software_stack:2.1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-7`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-8`,
        fs:  `cpe:2.3:h:cisco:as5400xm_universal_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-9`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.2-10`,
        fs:  `cpe:2.3:a:netartmedia:car_portal:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-0`,
        fs:  `cpe:2.3:a:ontariosystems:artiva_healthcare:5.2:mr5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-1`,
        fs:  `cpe:2.3:a:microsoft:virtual_pc:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-2`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-3`,
        fs:  `cpe:2.3:a:apache:tomcat:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-4`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:4.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-5`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-6`,
        fs:  `cpe:2.3:a:ntp:ntp:p91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-8`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-9`,
        fs:  `cpe:2.3:h:xerox:copycentre_c75:1.001.02.0715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.3-10`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.807:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-2`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-4`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-5`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-6`,
        fs:  `cpe:2.3:h:cisco:b420_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-7`,
        fs:  `cpe:2.3:a:shavlik:netchk_compliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-8`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-9`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:3.0:unknown:unknown:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.4-10`,
        fs:  `cpe:2.3:a:hp:bufferchm:53.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-0`,
        fs:  `cpe:2.3:a:divx:codec:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-3`,
        fs:  `cpe:2.3:a:infoware:mapsuite:1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-4`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-6`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-7`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-8`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-9`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.1:sp1:2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.5-10`,
        fs:  `cpe:2.3:a:qnap:iartist_lite:1.4.53.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-0`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.15:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-2`,
        fs:  `cpe:2.3:h:hp:laserjet_9040_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-4`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_lan_management_solution:3.0:december_2007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-5`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-6`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-8`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-9`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6-10`,
        fs:  `cpe:2.3:a:mkssoftware:mks_toolkit:9.2.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6.2`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6.7`,
        fs:  `cpe:2.3:o:freebsd:freebsd:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.6.9`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:5.5\(0.46.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-0`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-1`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-3`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-6`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-7`,
        fs:  `cpe:2.3:a:libav:libav:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-8`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-9`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.7-10`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-0`,
        fs:  `cpe:2.3:a:paperthin:commonspot_content_server:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-2`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_50-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-3`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-4`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-5`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-6`,
        fs:  `cpe:2.3:a:apache:axis:1.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-7`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-8`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.7.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-9`,
        fs:  `cpe:2.3:h:huawei:ar_g3:v200r002c00spc200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.8-10`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-0`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-3`,
        fs:  `cpe:2.3:a:lxml:lxml:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-4`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-5`,
        fs:  `cpe:2.3:a:mcafee:vulnerability_manager:7.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-6`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-7`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:6.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-8`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.2.1.6506:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-9`,
        fs:  `cpe:2.3:a:exim:exim:4.82.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.8.9-10`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.181.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-1`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-1:beta`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.15:*:*:*:desktop:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-2`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.0.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-3`,
        fs:  `cpe:2.3:h:lexmark:c540:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-4`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-5`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-6`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-7`,
        fs:  `cpe:2.3:a:rovicorp:sonic_dla:4.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-8`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-9`,
        fs:  `cpe:2.3:a:adobe:flash_player:20.0.0.286:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.0-10`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-0`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xh3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-2`,
        fs:  `cpe:2.3:a:buffalotech:whr-am54g54_firmware:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-3`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x52:d15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-4`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.3f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-5`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-6`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.24_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-7`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1240ag:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-8`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(22\)sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-9`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.1-10`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-0`,
        fs:  `cpe:2.3:a:perl:perl:2.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-07-25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-2`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.1r2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-3`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-4`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.51:-:hp-ux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-5`,
        fs:  `cpe:2.3:a:gnu:readline:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-6`,
        fs:  `cpe:2.3:a:cisco:unity_connection:9.1\(1.10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-7`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30306:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-8`,
        fs:  `cpe:2.3:a:divx:web_player:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-9`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.2-10`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-0`,
        fs:  `cpe:2.3:a:ibm:db2:9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p245_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-2`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-3`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:4.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-5`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-8`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-9`,
        fs:  `cpe:2.3:a:symantec:brightmail_antispam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.3-10`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-0`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_ibm:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-2`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-3`,
        fs:  `cpe:2.3:a:vmware:consolidated_backup_framework:1.5.0.2192:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-5`,
        fs:  `cpe:2.3:a:ca:license_software:1.63.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-6`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-7`,
        fs:  `cpe:2.3:h:hp:procurve_switch_4000m:c.09.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-8`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-9`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.4-10`,
        fs:  `cpe:2.3:a:sap:sql_anywhere:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-0`,
        fs:  `cpe:2.3:a:cisco:ip_interoperability_and_collaboration_system:4.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-2`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.0.1:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.03:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-4`,
        fs:  `cpe:2.3:a:microsoft:forefront_unified_access_gateway:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-5`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-6`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-7`,
        fs:  `cpe:2.3:a:hp:uguide:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-8`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-9`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:05-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.5-10`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(3\)sr4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-0`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-1`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.1:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-2`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-4`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-5`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-6`,
        fs:  `cpe:2.3:a:microsoft:isa_server:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-7`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.6-8`,
        fs:  `cpe:2.3:a:digia:qt:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-1`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-2`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-3`,
        fs:  `cpe:2.3:h:rockwellautomation:controllogix_5570_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-5`,
        fs:  `cpe:2.3:a:gnome:libsocialweb:0.25.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-6`,
        fs:  `cpe:2.3:a:debian:apt-listchanges:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-7`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)xr4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-8`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20100512:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-9`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:5.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.7-10`,
        fs:  `cpe:2.3:a:microsoft:office:97:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-0`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.6.c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-1`,
        fs:  `cpe:2.3:a:ca:threat_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-2`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-3`,
        fs:  `cpe:2.3:a:oracle:database_mobile\/lite_server:10.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-4`,
        fs:  `cpe:2.3:a:apache:storm:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-5`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-6`,
        fs:  `cpe:2.3:h:cisco:spa_302dkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-7`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp3:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-8`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.5:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-9`,
        fs:  `cpe:2.3:a:iss:realsecure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.8-10`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-1`,
        fs:  `cpe:2.3:a:bamboosolutions:sharepoint_project_portfolio_dashboard_pack_license_install:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-2`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.5.5:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-4`,
        fs:  `cpe:2.3:a:sendcard:sendcard:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-5`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:8.5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-6`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(1\)xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-7`,
        fs:  `cpe:2.3:h:dell:poweredge_2800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-8`,
        fs:  `cpe:2.3:a:ektron:ektron_content_management_system:8.7.0.055:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-9`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.14:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-10`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-11`,
        fs:  `cpe:2.3:o:ibm:os_400:v4r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-12`,
        fs:  `cpe:2.3:a:x:libxres:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-13`,
        fs:  `cpe:2.3:a:gnome:glib:2.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-14`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-15`,
        fs:  `cpe:2.3:a:combodo:itop:0.9:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-17`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)yx1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-18`,
        fs:  `cpe:2.3:h:lexmark:cx860dte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-19`,
        fs:  `cpe:2.3:h:ibm:ds4800:1815:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-20`,
        fs:  `cpe:2.3:a:rarlab:winrar:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-21`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-22`,
        fs:  `cpe:2.3:a:nancy_wichmann:announcements:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-23`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-24`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.03b12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-25`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-26`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-27`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:6.9.9-28`,
        fs:  `cpe:2.3:a:studiohitori:twitrocker2_android:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.0-0`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:9.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-0`,
        fs:  `cpe:2.3:a:php:php:5.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-1`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-4`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.5.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-5`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-6`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-7`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.11:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-8`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4m\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-9`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.16:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.1-10`,
        fs:  `cpe:2.3:a:qemu:qemu:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-0`,
        fs:  `cpe:2.3:o:ibm:aix:5.1l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-1`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-2`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-3`,
        fs:  `cpe:2.3:a:ca:single_sign-on:r12.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-4`,
        fs:  `cpe:2.3:a:cisco:system_unified_contact_center_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-5`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-6`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.15.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-7`,
        fs:  `cpe:2.3:a:ibm:monitoring_agent_for_unix_logs:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-8`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-9`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.2-10`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-0`,
        fs:  `cpe:2.3:a:flightgear:flightgear:2017.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-1`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.5:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-3`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-4`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-5`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20141230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-6`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-7`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-8`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-9`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.1.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.3-10`,
        fs:  `cpe:2.3:h:cisco:telepresence_mx200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-0`,
        fs:  `cpe:2.3:h:siemens:sinamics_s120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-1`,
        fs:  `cpe:2.3:a:cisco:security_agent:5.0.0.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-2`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-3`,
        fs:  `cpe:2.3:a:citrix:web_interface:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-4`,
        fs:  `cpe:2.3:a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p236:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-6`,
        fs:  `cpe:2.3:a:altn:mdaemon:9.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-7`,
        fs:  `cpe:2.3:a:sierrawireless:sierra_wireless_watcher:5.0.2258.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-8`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-9`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.4-10`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-0`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-1`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-2`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-3`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-4`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-5`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-6`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.7:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-7`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-8`,
        fs:  `cpe:2.3:a:epson:photostarter:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-9`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.5-10`,
        fs:  `cpe:2.3:a:apache:struts:1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-0`,
        fs:  `cpe:2.3:a:intel:proset_wireless:12.1.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-2`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-3`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:15.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-4`,
        fs:  `cpe:2.3:a:bib2html_project:bib2html:0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-5`,
        fs:  `cpe:2.3:a:apache:poi:3.8:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-6`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.4\(1\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-7`,
        fs:  `cpe:2.3:a:freemind:freemind:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-8`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.6-9`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-0`,
        fs:  `cpe:2.3:a:check_diskio_project:check_diskio:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.691.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-2`,
        fs:  `cpe:2.3:a:apc:powerchute:2.2:-:personal:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-3`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-4`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-5`,
        fs:  `cpe:2.3:a:smarttech:notebook_software:10.0.631.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-6`,
        fs:  `cpe:2.3:a:jease:jease:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-8`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d41.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-9`,
        fs:  `cpe:2.3:a:facebook:facebook_platform:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-10`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.0:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-11`,
        fs:  `cpe:2.3:a:google:email:4.2.2.0200:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-12`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-13`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-14`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-15`,
        fs:  `cpe:2.3:a:avast:free_antivirus:11.1.2262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-16`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7-17`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemagick:imagemagick:7.0.7.7`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.0:rc1`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.0:rc2`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.0:rc3`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.0:rc4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.0:rc5`,
        fs:  `cpe:2.3:o:cisco:catos:8.3\(1\)glx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.1`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.424.4:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.4`,
        fs:  `cpe:2.3:a:bpurcell:keytool_gui:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imagemenu_project:imagemenu:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:omfg_mobile_project:omfg_mobile:1.1.26:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imapp:no_disturb:3.3::~~~android~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imapp:realtime_music_rank:5.5::~~~android~~`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.4.013::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.4.014::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.4.015::~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:client:4.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.4.016::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.4.017::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.4.018::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.000::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_server:04-00:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.001::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.002::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.429:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.003::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.3.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.004::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.235:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.005::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.006::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(5\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.007::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.008::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gajim:gajim:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.009::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:messaging:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.010::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gateway_software:2.1\(1.49\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.011::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(5e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.012::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.013::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:application_velocity_system_3120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.014::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.015::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.5.016::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sap:j2ee_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.000::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.001::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30060:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.002::~~~wordpress~~`,
        fs:  `cpe:2.3:a:plone:plone:5.1:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.003::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.004::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.005::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.006::~~~wordpress~~`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.007::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:7.0.4.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.6.008::~~~wordpress~~`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.7.001::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.7.002::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.7.003::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je021a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.7.004::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.5:sr_3.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.7.005::~~~wordpress~~`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.7.006::~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:iprint:5.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.7.007::~~~wordpress~~`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0598:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.7.008::~~~wordpress~~`,
        fs:  `cpe:2.3:a:combodo:itop:1.0.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.000::~~~wordpress~~`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.001::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.002::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.003::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.004::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.005::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.12:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.006::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kadu:kadu:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.007::~~~wordpress~~`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.008::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.009::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.016.20045:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.010::~~~wordpress~~`,
        fs:  `cpe:2.3:o:buffalotech:wex-300_firmware:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.011::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:javafx:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.012::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.013::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digia:qt:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.8.014::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.9.000::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:network_satellite:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.9.001::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sgi:irisconsole:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.9.002::~~~wordpress~~`,
        fs:  `cpe:2.3:a:drupal:drupal:7.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.9.003::~~~wordpress~~`,
        fs:  `cpe:2.3:o:huawei:e3276_firmware:webui-13.100.09.00.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.9.004::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.9.005::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imember360:imember360:3.9.006::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imgburn:imgburn:2.5.0.0`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imgburn:imgburn:2.5.1.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.292:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imgburn:imgburn:2.5.6.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imgpals:img_pals_photo_host:1.0`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120718:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:immigrer:forum_ic:3.3.12::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:immunize:immunize_canada:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:ceph:0.94.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imop:long:1.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.3:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:impactlabs:pointless:2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imperva:securesphere:9.0.0.5`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impi:impi_mobile_security:2.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impliedbydesign:navigate:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:sp1:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:impliedbydesign:navigate:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0`,
        fs:  `cpe:2.3:o:quantum:scalar_i500_firmware:i8.2.2.1_\(646g.gs002\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0:beta1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.18:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0:beta2`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0:final`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0073:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0:rc1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0:rc2`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0:rc3`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0.1`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0.2`,
        fs:  `cpe:2.3:a:osisoft:pi_interface:1.0.4.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.0.3`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.765:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:6.0.0:*:*:*:*:solaris:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1:alpha1`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1:alpha2`,
        fs:  `cpe:2.3:o:vmware:esxi:4.0:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1:beta1`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1:final`,
        fs:  `cpe:2.3:a:call-cc:chicken:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1:rc1`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1:rc2`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_syslog:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1:rc3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.1`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.1:final`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.1:rc1`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.1:rc2`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp4:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.2:final`,
        fs:  `cpe:2.3:a:xnview:xnview:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.2:rc1`,
        fs:  `cpe:2.3:a:david_king:vino:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.2:rc2`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.3:beta`,
        fs:  `cpe:2.3:a:ibm:integration_bus:9.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.3:final`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.1.3:rc1`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2:alpha1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2:alpha2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.2:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2:beta`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2:final`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2:rc1`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2:rc2`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.2:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.1:beta`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.1:final`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.1:rc1`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.3:beta`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7905g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.3:final`,
        fs:  `cpe:2.3:a:fusebox:fusebox:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.3:rc1`,
        fs:  `cpe:2.3:a:cisco:jabber:9.0\(.2\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.3:rc2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.4:final`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.5:final`,
        fs:  `cpe:2.3:a:alexis_wilke:protected_node:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.6:final`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.2.7:final`,
        fs:  `cpe:2.3:a:cisco:webns:7.50.0.11s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.3`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.3.1:final`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.3.2`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.3.5`,
        fs:  `cpe:2.3:a:mcafee:firewall_admin_console:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresscms:impresscms:1.3.6.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresspages:impresspages_cms:1.0.12`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0587:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresspages:impresspages_cms:1.0.13`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresspages:impresspages_cms:1.0.15`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:impresspages:impresspages_cms:2.0.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:improved_user_search_in_backend_project:improved_user_search_in_backend:1.2.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:python:python:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imsidesign:turbocad_deluxe:16.0`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2013:cumulative_update_11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:imsidesign:turbocad_symbols:16.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:in-mediakg:filterftp:2.0.3`,
        fs:  `cpe:2.3:a:opera:opera_browser:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:in-mediakg:filterftp:2.0.5`,
        fs:  `cpe:2.3:a:microsoft:small_business_server:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:in-portal:in-portal:4.3.1`,
        fs:  `cpe:2.3:a:sun:java_system_portal_server:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:in-portal:in-portal:5.0`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inboundnow:call_to_action:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:6.x-1.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.759.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:kaspersky:total_security_2015:15.0.2.361:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:6.x-1.1`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:6.x-1.2`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:6.x-1.3`,
        fs:  `cpe:2.3:a:uiu4you:universal_imaging_utility:4.0.3.0:*:*:*:live_version:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:6.x-1.4`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:6.x-1.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.3\(2.30\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:7.x-1.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_pdf_sdk_activex:5.0.1.820:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:7.x-1.0:rc2`,
        fs:  `cpe:2.3:a:schneider-electric:unity_pro:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inclind:custom_pub:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:vmware:esxi:5.0:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:incrediblepbx:incredible_pbx_11:2.0.6.5.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:incredimail:incredimail:2.0`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:independent:i_newspaper:%407f080184::~~~android~~`,
        fs:  `cpe:2.3:h:schneider-electric:tburjr900:06002dh0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indexisto_project:indexisto:1.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:office:2002:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:india%27s_anthem_project:india%27s_anthem:1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indianic:testimonial_plugin:2.2`,
        fs:  `cpe:2.3:a:aas9:zerocms:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indigorose:setup_factory:7.0`,
        fs:  `cpe:2.3:a:horde:groupware:1.0.8:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indigorose:setup_factory:8.0`,
        fs:  `cpe:2.3:a:emc:rsa_access_manager:6.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indihiang:web_log_analyzer:1.0`,
        fs:  `cpe:2.3:a:apache:storm:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:individualsoftware:professor_teaches_access:2007`,
        fs:  `cpe:2.3:h:supermicro:x8dtn\&#43;-f-lr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:individualsoftware:professor_teaches_excel:2007`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:individualsoftware:professor_teaches_outlook:2007`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:individualsoftware:professor_teaches_powerpoint:2007`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:individualsoftware:professor_teaches_word:2007`,
        fs:  `cpe:2.3:a:drupal:drupal:7.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inductiveautomation:ignition:7.7.2`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:5.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indus-systems:idrawings_setup:3.6.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je169a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indus-systems:idrawings_setup:3.6.2`,
        fs:  `cpe:2.3:a:web2py:web2py:1.90.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indus-systems:idrawings_setup:4.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indus-systems:idrawings_work_flow:1.0.0`,
        fs:  `cpe:2.3:a:yahoo:yafuoku\!:4.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:indusoft:web_studio:6.1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indusoft:web_studio:7.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indusoft:web_studio:7.1:-`,
        fs:  `cpe:2.3:a:microsoft:office_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indusoft:web_studio:7.1:sp1`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indusoft:web_studio:7.1:sp2`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.05.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:indusoft:web_studio:7.1:sp2_p4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infineon:trusted_platform_module:3.0.2::~~professional~~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infinite_automation_systems:mango_automation:2.4.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infinitewp:infinitewp_admin_panel:2.4.2`,
        fs:  `cpe:2.3:h:supermicro:x9dre-tf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infinitewp:infinitewp_admin_panel:2.4.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infinitiusa:infiniti_roadside_assistance:1.1::~~~android~~`,
        fs:  `cpe:2.3:h:supermicro:x9dax-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:info-zip:unzip:6.0`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:9.0.083.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:info-zip:unzip:6.10b`,
        fs:  `cpe:2.3:h:ibm:integrated_management_module_2:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoblox:if-map_client_simulator:1.0.0.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.475.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoblox:netmri:6.0.2.42`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoblox:netmri:6.1.2`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoblox:netmri:6.2.1`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoblox:netmri:6.2.1.48`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoblox:netmri:6.8.2.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoblox:netmri:6.8.4`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_client:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoblox:netmri:6.8.5`,
        fs:  `cpe:2.3:a:hub_project:hub:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infohr:hr_human_resource_information_system:7.9`,
        fs:  `cpe:2.3:a:novell:groupwise:8.01:hp:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infor:eclient:7.3.2.3`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infor:enspire_distribution_management_solution:7.3.2.7`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:02-00-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informaciondelvaticano:noticias_del_vaticano:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informant-systems:snmp_informant:2010.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:mapping_template:1.0.0`,
        fs:  `cpe:2.3:a:innominate:mguard_industrial_rs:bd-501010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:powercenter:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:powercenter:7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:powercenter:7.1.2`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:8.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:powercenter:7.1.3`,
        fs:  `cpe:2.3:a:anthony_mills:s3_video:0.981:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:powercenter_connect:7.1.2`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:powerconnect_for_ibm_mqseries:6.2.1`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:powerexchange_client_for_powercenter:7.1.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informatica:xconnect_for_business_objects:2.0.0`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.93.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:informationbuilders:webfocus:77.0`,
        fs:  `cpe:2.3:a:centrify:centrify_suite:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:informationbuilders:webfocus:77.1`,
        fs:  `cpe:2.3:h:sun:fire_x4450_server:sw_2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infotecs:vipnet_client:3.2.10`,
        fs:  `cpe:2.3:a:vmware:horizon_view:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infotecs:vipnet_coordinator:3.2.10`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infotecs:vipnet_personal_firewall:3.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infotecs:vipnet_safedisk:4.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoware:mapsuite:1.0.35`,
        fs:  `cpe:2.3:a:shopizer:shopizer:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infoware:mapsuite:1.1.48`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:1.00`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:1.10`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:1.20`,
        fs:  `cpe:2.3:a:epson:copy_utility:3.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:1.30`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:1.40`,
        fs:  `cpe:2.3:h:cisco:c260_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.00`,
        fs:  `cpe:2.3:a:sunil_nanda:blue_wrench_video_widget:2.0.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.01`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.10`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.11`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.12`,
        fs:  `cpe:2.3:a:codiad:codiad:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.20`,
        fs:  `cpe:2.3:a:perl:perl:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.21`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.22`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.0.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.23`,
        fs:  `cpe:2.3:a:lansuite:lansuite:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.24`,
        fs:  `cpe:2.3:a:apache:ofbiz:11.04.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.25`,
        fs:  `cpe:2.3:a:facebook:instaroid_-_instagram_viewer:1.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:2.26`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.00`,
        fs:  `cpe:2.3:a:ca:unicenter_dsm_agent_\&#43;_software_delivery_plugin:11.2.4000.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.01`,
        fs:  `cpe:2.3:o:cisco:ios_xr_for_prp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.02`,
        fs:  `cpe:2.3:a:piwik:piwik:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.11`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.12`,
        fs:  `cpe:2.3:a:ayuntamientodecoana:ayuntamiento_de_coana:0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.13`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.14`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.15`,
        fs:  `cpe:2.3:a:humhub:humhub:1.0.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.16`,
        fs:  `cpe:2.3:h:cisco:ios:12.4xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.17`,
        fs:  `cpe:2.3:a:enghouseinteractive:ivr_pro:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.18`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.19`,
        fs:  `cpe:2.3:a:conky:conky:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.20`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.4.0.46.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:3.99`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.00`,
        fs:  `cpe:2.3:a:novell:netmail:3.10d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.01`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:18.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.02`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.03`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.04`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.5.0_a:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.05`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.06`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.07`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.08`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p390:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:infradead:openconnect:4.99`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:infusionsoft_project:infusionsoft:1.5.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingen-studios:conquest_of_fantasia:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.251:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:1.0`,
        fs:  `cpe:2.3:a:samba:samba:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:1.3.0`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:1.3.1`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:2.1.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:2.2.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:2.2.1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:2.2.2`,
        fs:  `cpe:2.3:a:csounds:csound:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:2.8.0`,
        fs:  `cpe:2.3:a:hp:openview_certificate_management_client:1.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:2.8.1`,
        fs:  `cpe:2.3:a:uiga:personal_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:2.8.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingo_renner:apache_solr:2.8.3`,
        fs:  `cpe:2.3:a:apple:webkit:125.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingumadev:bokken:1.5`,
        fs:  `cpe:2.3:a:koha:koha:3.14.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingumadev:bokken:1.5-3`,
        fs:  `cpe:2.3:a:fallacystudios:stoner\&#39;s_handbook_l-_bud_guide:7.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ingumadev:bokken:1.5-5`,
        fs:  `cpe:2.3:a:quest:toad_group_policy_manager:10.0.0.33:*:*:*:freeware:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingumadev:bokken:1.6`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingumadev:bokken:1.6-1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ingy:spoon:0.24::~~~perl~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.37`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.38.1`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.39`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.40`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_software_delivery_solution_for_windows:6.1.1080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.41`,
        fs:  `cpe:2.3:a:ansys:mechanical:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.42`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.42.2`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:6.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.43`,
        fs:  `cpe:2.3:a:google:chrome:40.0.2214.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.44`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.44.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.45.1`,
        fs:  `cpe:2.3:a:netiq:security_manager_agent:6.0.0.194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.46`,
        fs:  `cpe:2.3:a:comcast:xfinity_constant_guard_mobile:3.1.140603:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.47`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.47:pre0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.47:pre1`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.47:pre2`,
        fs:  `cpe:2.3:a:digia:qt:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.47:pre3`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.47:pre4`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.48`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.48:pre0`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-233:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.48:pre1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.48.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.48.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.790.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.48.3`,
        fs:  `cpe:2.3:a:gnu:cfengine:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.48.3.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inkscape:inkscape:0.48.4`,
        fs:  `cpe:2.3:a:combodo:itop:1.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.17`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.18`,
        fs:  `cpe:2.3:a:pixman:pixman:0.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.19`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ecd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20`,
        fs:  `cpe:2.3:a:mono:mono:1.1.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20:10`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20:1464`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20:1529`,
        fs:  `cpe:2.3:a:drupal:drupal:6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20:1561`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20:1573`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20:1600`,
        fs:  `cpe:2.3:h:hp:color_laserjet_8550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20:304`,
        fs:  `cpe:2.3:a:debian:reportbug:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline:ihtml:2.20:919`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline_entity_form_project:inline_entity_form:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline_entity_form_project:inline_entity_form:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.3ma:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline_entity_form_project:inline_entity_form:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:catalyst_12xx_supervisor_software:4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline_entity_form_project:inline_entity_form:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline_entity_form_project:inline_entity_form:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:python:python:3.3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inline_entity_form_project:inline_entity_form:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:jetadmin:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inlinks_project:inlinks:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:creativeprojects_package_variety1:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inmatrix:zoom_player:8.00`,
        fs:  `cpe:2.3:a:atmail:atmail:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inmatrix:zoom_player:8.1.1`,
        fs:  `cpe:2.3:o:yahama:rtx1200:10.01.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inmatrix:zoom_player:8.1.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:da:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inmatrix:zoom_player:8.1.6`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inmatrix:zoom_player:8.5`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.11.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inmatrix:zoom_player:8.6`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inmatrix:zoom_player:8.6.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inmatrix:zoom_player:8.10`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:eagle_mguard:bd-301010`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.0\(1\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:eagle_mguard:hw-201000`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_blade:hw-104020`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_blade:hw-104050`,
        fs:  `cpe:2.3:h:dell:poweredge_2600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_delta:bd-201000`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_delta:hw-103050`,
        fs:  `cpe:2.3:a:microsoft:ie:6.0.2900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:3.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:3.1.1`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:4.0.4`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:4.1.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:4.2.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_common_reporting:3.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:5.0.1`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:5.1.6`,
        fs:  `cpe:2.3:a:microsoft:vbscript:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:6.0.2`,
        fs:  `cpe:2.3:a:horde:groupware:5.0.3:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:6.1.5`,
        fs:  `cpe:2.3:h:netgear:me102:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:7.0.2`,
        fs:  `cpe:2.3:a:apache:subversion:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:7.1.1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:7.2.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:7.3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:7.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:7.5.0`,
        fs:  `cpe:2.3:a:microsoft:sysinternals_debugview:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:7.6.4`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.02:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:7.6.6`,
        fs:  `cpe:2.3:a:oracle:mysql_workbench_ce:5.2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:8.0.0`,
        fs:  `cpe:2.3:a:livezilla:livezilla:4.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:8.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:8.0.2`,
        fs:  `cpe:2.3:a:apache:ambari:2.4.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:8.0.3`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:8.1.1`,
        fs:  `cpe:2.3:o:zte:zxv10_w300_firmware:w300v1.0.0f_er1_pe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:8.1.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:innominate:mguard_firmware:8.1.3`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_industrial_rs:bd-501000`,
        fs:  `cpe:2.3:a:microsoft:office:xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_industrial_rs:bd-501010`,
        fs:  `cpe:2.3:a:adobe:download_assistant:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_industrial_rs:bd-501020`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_industrial_rs:hw-105000`,
        fs:  `cpe:2.3:a:microsoft:office_communicator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_pci:bd-111010`,
        fs:  `cpe:2.3:a:oracle:retail_applications:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_pci:bd-111020`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.0:b2:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_pci:hw-102020`,
        fs:  `cpe:2.3:a:siemens:ruggedcom_network_management_software:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_pci:hw-102050`,
        fs:  `cpe:2.3:a:allaire:homesite:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_smart:bd-101010`,
        fs:  `cpe:2.3:a:sun:net_connect_software:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_smart:bd-101020`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_smart:hw-101020`,
        fs:  `cpe:2.3:h:xerox:workcentre_5755:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innominate:mguard_smart:hw-101050`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innopage:giga_hobby:1.0.6::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool_security_manager:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:innovaphone:innovaphone_pbx:10.00:sr11`,
        fs:  `cpe:2.3:a:apple:webkit:85.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:1.07`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.91:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:2.02`,
        fs:  `cpe:2.3:a:corel:painter:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:2.04`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:gold:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:2.99:alpha`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.00`,
        fs:  `cpe:2.3:a:snowhall:silurus_system:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.01`,
        fs:  `cpe:2.3:a:redhat:rhel_developer_suite:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.02`,
        fs:  `cpe:2.3:a:carahsoft:jabber_outlook_add-in:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.03:alpha`,
        fs:  `cpe:2.3:a:python:python:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.04`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.05:beta`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.06`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.07`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.07:beta1`,
        fs:  `cpe:2.3:a:citrix:provisioning_services:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.07:beta2`,
        fs:  `cpe:2.3:a:hp:readme:60.0.196.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.07:pl2`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs6:13.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.08`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.7.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.09`,
        fs:  `cpe:2.3:a:commvault:exchange_mailbox_archiver_agent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.10`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.11`,
        fs:  `cpe:2.3:o:debian:debian_linux:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.12`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inria:ocaml:3.12.1`,
        fs:  `cpe:2.3:a:skype:skype:0.95.0.36:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:insanevisions:adaptcms:3.0.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:insite:node_basket:7.x-1.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:emc:networker:8.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspiration:text_to_speech_xp:1.0.0`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.588:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.2`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.721.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.4`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.5`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.7`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.8`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.9`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.10`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.6210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.11`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.12`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.13`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.14`,
        fs:  `cpe:2.3:a:siemens:scalance_s_firmware:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.15`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.7:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.16`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.1.17`,
        fs:  `cpe:2.3:a:c-icap_project:c-icap:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.2.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.2.7`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:1.2.8`,
        fs:  `cpe:2.3:a:autodesk:viz:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:2.0.0`,
        fs:  `cpe:2.3:h:nec:ix1050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:2.0.1`,
        fs:  `cpe:2.3:a:open_explorer_beta_project:open_explorer_beta:0.253:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:2.0.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inspire_ircd:inspircd:2.0.5`,
        fs:  `cpe:2.3:o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instachat:instachat_-instagram_messenger:1.6.2::~~~android~~`,
        fs:  `cpe:2.3:a:ca:internet_security_suite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:installatron:gatequest_file_manager:0.2.5`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:installshield:isscript:3.0.185`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp2:datacenter_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instantasp:instantforum:3.4.0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instantasp:instantforum:4.1.0`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instantasp:instantforum:4.1.1`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:beta_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instantasp:instantforum:4.1.2`,
        fs:  `cpe:2.3:a:jamroom:search_module:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instantasp:instantforum:4.1.3`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instantphp:jobs_pro:1.6.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instantphp:jobs_pro:1.6.4`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.11-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instantsoft:instantcms:1.10.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instaroid_-_instagram_viewer_project:instaroid_-_instagram_viewer:1.2.1::~~~android~~`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:3.0.0.3.162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:instatalks:instatalks:1.3.1::~~~android~~`,
        fs:  `cpe:2.3:a:ca:introscope_agent_for_.net_3.0:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2100_proset_wireless:-`,
        fs:  `cpe:2.3:a:happyworm:jplayer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2100_proset_wireless:7.1.4.5`,
        fs:  `cpe:2.3:a:archangelmgt:weblog:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2200bg_proset_wireless:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2200bg_proset_wireless:8`,
        fs:  `cpe:2.3:o:yamaha:rtw65i:5.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2200bg_proset_wireless:9`,
        fs:  `cpe:2.3:h:cisco:891_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2200bg_proset_wireless:9.0.3.9`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.20.020.1692:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2200bg_proset_wireless:10`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2915abg_proset_wireless:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2915abg_proset_wireless:8`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2915abg_proset_wireless:9`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:2915abg_proset_wireless:10`,
        fs:  `cpe:2.3:h:cisco:ons_15454sdh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:3450_chipset:-`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:460t_switch:-`,
        fs:  `cpe:2.3:o:suse:linux_enterprise:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:5500_chipset:-`,
        fs:  `cpe:2.3:h:cisco:catalyst_4510r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:5520_chipset:-`,
        fs:  `cpe:2.3:a:ibm:personal_communications:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:7500_chipset:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:1.0`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:2.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:2.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s_3.4.0as:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:2.2`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:2.5`,
        fs:  `cpe:2.3:a:7sage:7sage_lsat_prep_-_proctor:2.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:2.6`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:4.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:3.0`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:3.1`,
        fs:  `cpe:2.3:a:awpcp:another_wordpress_classifieds_plugin:3.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:3.2`,
        fs:  `cpe:2.3:a:oracle:commerce_guided_search_and_experience_manager:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:4.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management:11.4:*:*:*:collaborative:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:4.1`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:574:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:5.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00-\/b:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:active_management_technology:6.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:active_management_technology_setup_and_configuration_service:3.0.2.6.1`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:c202_chipset:-`,
        fs:  `cpe:2.3:a:hp:service_center_web_tier:6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:c204_chipset:-`,
        fs:  `cpe:2.3:a:searchblox:searchblox:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:c206_chipset:-`,
        fs:  `cpe:2.3:a:packagekit_project:packagekit:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:c216_chipset:-`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a4:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:carrier_grade_server_tigpr2u:-`,
        fs:  `cpe:2.3:a:realtek:realtek_ac\&#39;97_audio:5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:carrier_grade_server_tsrlt2:-`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:carrier_grade_server_tsrmt2:-`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:cli_auto-configuration_utility:-`,
        fs:  `cpe:2.3:a:x:libfs:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:client_system_setup_utility:-`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:control_center:1.2.1.1007`,
        fs:  `cpe:2.3:a:progress:webspeed:3.1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:core_2_duo_e4000:-`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:core_2_duo_e6000:-`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r4-p1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:core_2_extreme_x6800:-`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:crosswalk:19.49.514.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845bg_motherboard:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845bg_motherboard:p01-0012`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845bg_motherboard:p02-0015`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845bg_motherboard:p03-0021`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.5p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845bg_motherboard:p04-0023`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.01:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845bg_motherboard:p05-0024`,
        fs:  `cpe:2.3:a:kaseya:virtual_system_administrator:6.5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:-`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:p04-0018`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:p05-0022`,
        fs:  `cpe:2.3:a:spice_project:spice:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:p06-0024`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:p07-0029`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:p08-0031`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:p09-0035`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp2:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:p10-0038`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845hv_motherboard:p11-0040`,
        fs:  `cpe:2.3:a:cisco:content_security_management_virtual_appliance:9.0.0.087:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845pt_motherboard:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5a\)b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845pt_motherboard:p01-0012`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845pt_motherboard:p02-0015`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845pt_motherboard:p03-0021`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845pt_motherboard:p04-0023`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845pt_motherboard:p05-0024`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:p04-0018`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:p05-0022`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_extreme:2.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:p06-0024`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:p07-0029`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:p08-0031`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:p09-0035`,
        fs:  `cpe:2.3:a:louis_jimenez:custom_meta:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:p10-0038`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:d845wn_motherboard:p11-0040`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a5\(2.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:display_adapter_driver:-`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:driver_update_utility:2.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:driver_update_utility:2.1`,
        fs:  `cpe:2.3:a:wildpackets:omnipeek:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:driver_update_utility:2.2`,
        fs:  `cpe:2.3:a:mcafee:security_installer_control_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:driver_update_utility:2.3`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:enterprise_southbridge_2_bmc:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:enterprise_southbridge_bmc:-`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/r_firmware:2.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:entry_server_board_se7210tp1-e:-`,
        fs:  `cpe:2.3:o:huawei:s9706_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:entry_server_platform_sr1325tp1-e:-`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_510t:-`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.0.163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_510t:2.63`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_510t:2.64`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_520t:-`,
        fs:  `cpe:2.3:a:informatica:powercenter:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_520t:2.63`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.5.2733.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_520t:2.64`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(25\)w5\(27c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_550f:-`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_550f:2.63`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_550f:2.64`,
        fs:  `cpe:2.3:a:freedomscientific:braille:10.14.2289.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_550t:-`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_550t:2.63`,
        fs:  `cpe:2.3:a:alvaro_herrera:pl\/php:1.3.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_550t:2.64`,
        fs:  `cpe:2.3:a:apple:safari:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:express_8100:-`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:expressway_cloud_access_360:2.1`,
        fs:  `cpe:2.3:a:sun:solaris_pc_netlink:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:expressway_cloud_access_360:2.5`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:geomedia_webmap:-`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization_manager:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:graphics_accelerator_driver:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:graphics_accelerator_driver:6.14.10.4308`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:graphics_driver:15.33.42.4358`,
        fs:  `cpe:2.3:a:novell:groupwise:8.00:hp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:graphics_driver:15.36.30.4385`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:graphics_driver:15.40.4404`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:high-bandwidth_digital_content_protection:-`,
        fs:  `cpe:2.3:a:expressjs:express:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:high-bandwidth_digital_content_protection:1.0`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:16.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:i915_chipset:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:ia64:-`,
        fs:  `cpe:2.3:a:telos:pump_dms_xml:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:inbusiness_email_station:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.54.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:inbusiness_email_station:1.04`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_m1217nfw_mfp:ce844a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:indeo_video:4.5`,
        fs:  `cpe:2.3:a:ncr:ncr_sm3g_cmic_legacy:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:intelligent_platform_management_interface:2.0`,
        fs:  `cpe:2.3:a:iconics:bizviz:9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:iparty:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:iparty:1.2`,
        fs:  `cpe:2.3:a:redhat:uberfire:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:ipmi:1.5`,
        fs:  `cpe:2.3:a:digium:asterisk:12.7.0:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:lan_adapters_snmp_agent:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:487:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:lan_adapters_snmp_agent:1.0.0`,
        fs:  `cpe:2.3:a:oracle:hyperion:11.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:management_engine_components:6.0.0.1179`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mcore:5.74.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.7.:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mcore:9.3.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mcore:11.2.0`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mdriver:5.74.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd369a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mdriver:9.3.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mdriver:11.2.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mdrwifi:5.74.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mdrwifi:9.3.0`,
        fs:  `cpe:2.3:a:skype:skype:4.1.0.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mdrwifi:11.2.0`,
        fs:  `cpe:2.3:h:arbiter:power_sentinel:1133a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mhlpdell:5.74.0`,
        fs:  `cpe:2.3:a:libav:libav:10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mhlpdell:9.3.0`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mhlpdell:11.2.0`,
        fs:  `cpe:2.3:a:christopher_mitchell:smart_breadcrumb:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:miwa:5.74.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:miwa:9.3.0`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:miwa:11.2.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mlogview:5.74.0`,
        fs:  `cpe:2.3:a:f5:big-iq_security:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mlogview:9.3.0`,
        fs:  `cpe:2.3:o:cisco:catos:6.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mlogview:11.2.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p240_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mmhouse:5.74.0`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mmhouse:9.3.0`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_designer:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mmhouse:11.2.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_gm45_chipset:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:9.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_gs45_chipset:-`,
        fs:  `cpe:2.3:a:openstack:swift:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_pm45_express_chipset:-`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_qm57_chipset:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_qm67_chipset:-`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_qs57_chipset:-`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.26.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_qs57_express_chipset:-`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_qs67_chipset:-`,
        fs:  `cpe:2.3:a:hp:8500a909_edocs:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:mobile_intel_qs67_chipset:_express-`,
        fs:  `cpe:2.3:a:wotlab:community_gallery:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mpfmgr:5.74.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mpfmgr:9.3.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.35a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mpfmgr:11.2.0`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mpfwiz:5.74.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mpfwiz:9.3.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mpfwiz:11.2.0`,
        fs:  `cpe:2.3:a:dflabs:ptk:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mprosafe:9.0.0`,
        fs:  `cpe:2.3:a:basercms:basercms:3.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mscfg:9.3.0`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mscfg:11.2.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:msso:5.74.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:msso:9.3.0`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:msso:11.2.0`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mwlssafe:9.0.0`,
        fs:  `cpe:2.3:a:gnu:libcdio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mwmi:5.74.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.0\(2k\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mwmi:9.3.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mwmi:11.2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mxml:5.74.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mzconfig:5.74.0`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mzconfig:9.3.0`,
        fs:  `cpe:2.3:h:cisco:asr_9904:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:mzconfig:11.2.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:netstructure_7110:-`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:netstructure_7180:-`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:12.4.0.0`,
        fs:  `cpe:2.3:a:altova:xmlspy_2011:3.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:12.4.38.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.0.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.0.42.0`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.0.44.0`,
        fs:  `cpe:2.3:a:searchblox:searchblox:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.1.0.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.1.1.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.1.33.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.1.34.2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.2.8.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.5.0.0`,
        fs:  `cpe:2.3:a:teradata:fastexport:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:13.5.32.0`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.0.0.0`,
        fs:  `cpe:2.3:a:isc:bind:9.7.6:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.0.40.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:11.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.3.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.5.0.0`,
        fs:  `cpe:2.3:h:dell:2161ds_kvm:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.5.1.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.6.0.0`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.6.9.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_server:04-00:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.7.0.0`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:10.1.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.7.23.0`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.8.0.0`,
        fs:  `cpe:2.3:a:zarafa:webapp:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:14.8.43.0`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.0.0.0`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1-14:fix05:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.0.4.0`,
        fs:  `cpe:2.3:a:redhat:satellite:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.1.0.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:18.009.20050:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.1.29.0`,
        fs:  `cpe:2.3:a:isc:dhcpd:2.0pl5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.2.0.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.2.89.0`,
        fs:  `cpe:2.3:h:intel:express_550f:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.4.2.0`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.4.2.1`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.4.3.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.4.3.3`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.5.0.0`,
        fs:  `cpe:2.3:h:dlink:dwl-2100ap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.5.74.0`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.6.0.0`,
        fs:  `cpe:2.3:a:nvidia:wmi:275.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.6.25.0`,
        fs:  `cpe:2.3:a:sympa:sympa:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.7.0.0`,
        fs:  `cpe:2.3:h:polycom:viewstation_dcp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.7.176.0`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.8.0.0`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:15.8.76.0`,
        fs:  `cpe:2.3:a:winscp:winscp:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.0.0.0`,
        fs:  `cpe:2.3:a:abbyy:finereader:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.0.19.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:13.0.0.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.1.0.0`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.1.53.0`,
        fs:  `cpe:2.3:a:hp:proliant_remote_monitor_service:5.21.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.2.0.0`,
        fs:  `cpe:2.3:a:hp:document_viewer:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.2.49.0`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.9.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.3.0.0`,
        fs:  `cpe:2.3:a:php:php:5.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.3.48.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sg.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.4.0.0`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.4.69.0`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.6.0.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.6.126.0`,
        fs:  `cpe:2.3:a:citrix:license_server_administration:4.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.8.0.0`,
        fs:  `cpe:2.3:a:intel:network_connections:16.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:network_connections:16.8.46.0`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:pentium:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:pentuim:-`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_91:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_alerting_agent:12.0.2`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_alerting_agent:12.0.3`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cce:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:9.2.4.9`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:10.0.27.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1668.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:10.1.41.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:10.30.0`,
        fs:  `cpe:2.3:o:hp:zbook_firmware:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:11.2.0.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:12.0.0.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:08-00-01:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:12.1.0.0`,
        fs:  `cpe:2.3:a:sun:java_db:10.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:12.2.0.0`,
        fs:  `cpe:2.3:o:apple:airport_base_station_firmware:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:12.2.41.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:12.3.0.0`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.50.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:pro_network_connections:12.3.31.0`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare_professional:4.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:pro_wireless_3945abg:-`,
        fs:  `cpe:2.3:a:apple:cups:1.1.19:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:pro_wireless_3945abg:1.1.21`,
        fs:  `cpe:2.3:a:borland:caliberrm_sdk:10.0.212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:processor_graphics:8.15.10.2418`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:processor_id_utility:3.6.0`,
        fs:  `cpe:2.3:a:mybboard:mybb:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:processor_id_utility:4.22.0`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:prosafe_for_wired_connections:8.0.5`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:prosafe_for_wired_connections:99.99.9999`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.0:cf04:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset:6.5.2001`,
        fs:  `cpe:2.3:a:debian:apt:0.8.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset%2fwireless_wifi_api:12.1.2000`,
        fs:  `cpe:2.3:a:php:php:5.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_for_wired_connections:7.10.0`,
        fs:  `cpe:2.3:a:hp:centralview_fraud_risk_management:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_for_wired_connections:9.0.0`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_for_wired_connections:9.20.0`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.4:*:free:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:10.1.1.4`,
        fs:  `cpe:2.3:a:apache:ignite:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:11.1.0`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:11.5.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:12.0.4000`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.23.0:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:12.1.1000`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:12.2.0`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:12.4.3000`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:12.4.4000`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:13.0.0`,
        fs:  `cpe:2.3:o:ibm:aix:5.3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:13.1.1000`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:13.2.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:13.2.1000`,
        fs:  `cpe:2.3:a:cisco:unity_connection_software:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:13.3.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:13.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:13.5.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.364:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:14.0.2000`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(13.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:proset_wireless:14.2.0`,
        fs:  `cpe:2.3:a:emc:clariion_procedure_generator:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:q35_express_chipset:-`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l2_controller_firmware:20.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:q57_chipset:-`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.04:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:q67_express_chipset:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.5\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:qm77_chipset:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.54:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:qs77_chipset:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:qs77_chipset:-::~~express~~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:rapid_storage_technology:9.6.0.1014`,
        fs:  `cpe:2.3:a:safemode_project:safemode:1.2.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:rapid_storage_technology:10.1.0.1008`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_s5000pal:-`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_s5000psl:-`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_s5000vcl:-`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_s5000vsa:-`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.20c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_s5000xal:-`,
        fs:  `cpe:2.3:h:cisco:892_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_s5000xvn:-`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_sc5400ra:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_scb2:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.4:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_sds2:-`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_se7500wv2:-`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_se7501hg2:-`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_board_shg2:-`,
        fs:  `cpe:2.3:a:christian_johansson:restrict_node_page_view:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:server_configuration_wizard:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p110:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:server_control:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_platform_spsh4:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_platform_sr870bh2:-`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_platform_sr870bn4:-`,
        fs:  `cpe:2.3:a:saltstack:salt_2015:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:server_platform_srsh4:-`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:shiva_access_manager:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:1.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:1.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:2nd_gen_i5_i7_sinit_1.9.bin`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:2nd_gen_i5_i7_sinit_51.bin`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:8.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:gm45_gs45_pm45_sinit_21.bin`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:gm45_gs45_pm45_sinit_51.bin`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:i5_i7_dual_sinit_18.bin`,
        fs:  `cpe:2.3:a:isc:bind:9.6.1b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:i5_i7_dual_sinit_51.bin`,
        fs:  `cpe:2.3:a:zoner:zoner_antivirus_free:-:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:i7_quad_sinit_20.bin`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:i7_quad_sinit_51.bin`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:q35_sinit_18.bin`,
        fs:  `cpe:2.3:a:eeye:retina:5.11.10.1972:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:sinit_authenticated_code_module:q35_sinit_51.bin`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:system_setup_utility:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:threading_building_blocks:2.2.013`,
        fs:  `cpe:2.3:a:citrix:desktop_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:trusted_execution_technology_sinit_authenticated_code_module:1.1`,
        fs:  `cpe:2.3:o:xen:xen:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:intel:trusted_execution_technology_sinit_authenticated_code_module:1.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:wimax_network_service:1.5.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.19369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intel:wimax_network_service:1.5.2`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0_pl2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:wireless_wifi_link_4965agn:-`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:wireless_wifi_link_4965agn:1.1.21`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:x58_chipset:-`,
        fs:  `cpe:2.3:a:google:v8:3.24.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:xircom_rex_6000:-`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:intel:xircom_rex_6000:1`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:97:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelitycorp:four_seasons_beverly_hills:%407f050007::~~~android~~`,
        fs:  `cpe:2.3:a:sun:openoffice.org_installer:1.0.9221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intellectualflame:brightest_led_flashlight:1.2.4::~~~android~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r340.00:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:intellegere:thanodi_-_setswana_translator:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:atcom:netvolution:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:elitius:1.0`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:esyndicat:2.2`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:esyndicat:2.3`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:1.0.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.4d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:1.0.0:beta`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:1.0.0:rc`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:1.2.0`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.0.0:beta`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.0.0:rc`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.0.1`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.0.2`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.0.3`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.0.4`,
        fs:  `cpe:2.3:o:f5:tmos:9.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.1.0`,
        fs:  `cpe:2.3:a:websense:websense_web_filter:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.1.0:beta2`,
        fs:  `cpe:2.3:h:alliedtelesis:img624a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.1.0:rc2`,
        fs:  `cpe:2.3:h:d-link:dsr-1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.2.0`,
        fs:  `cpe:2.3:a:ibm:filenet_content_manager:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.2.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p406:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intelliants:subrion_cms:2.2.3`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:interactivedata:esignal:10.6`,
        fs:  `cpe:2.3:h:netgear:wgr614:v3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:interactivedata:esignal:10.6.2425`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intercom:web_kyukincho:3.0`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:intercom:web_kyukincho:3.0.030`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:interconweb:accessible_formnet_fill:3.0`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intergraph:employee_id_generator:1.6.1.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intergraph:funding_initiation_tool:1.5.28.0`,
        fs:  `cpe:2.3:a:appdeploy:free_appdeploy_repackager:1.2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intergraph:job_order_status_tool:1.6.1.0`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.00:-:*:*:*:windows_server_2003:*:*`,
    },
     
    {
        uri: `cpe:/a:intergraph:rcc_skills_codes:1.6.1.0`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intergraph:sales_price_generator:1.4.8.1`,
        fs:  `cpe:2.3:a:novell:zenworks:6.2:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intergraph:user_access_tool:1.6.1.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:2.16`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:2.17`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:2.18`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.26`,
        fs:  `cpe:2.3:h:quantum:scalar_i500:23u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.29`,
        fs:  `cpe:2.3:a:ibm:websphere_cast_iron_solution:7.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.30`,
        fs:  `cpe:2.3:h:buffalotech:wer-a54g54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.31`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.34`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_37:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.35`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.36`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.37`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.38`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.39`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.44`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.45`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha5:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.46`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.2.48`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.0`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.1`,
        fs:  `cpe:2.3:a:triumfant:triumfant_agent:4.3.4033.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.2`,
        fs:  `cpe:2.3:a:bea:weblogic_workshop:8.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.4`,
        fs:  `cpe:2.3:a:php:php:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.6`,
        fs:  `cpe:2.3:a:compaq:foundation_agents:4.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.8`,
        fs:  `cpe:2.3:a:apple:itunes:12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(13a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.13`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_idm_launcher:1.5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.14`,
        fs:  `cpe:2.3:a:apple:mac_os_nsl_manager:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.16`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.19`,
        fs:  `cpe:2.3:a:rhq-project:rhq:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.3.21`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.0`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.7`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.9`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.10`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.11`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.12`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sq.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.13`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.14`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.16`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.17`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.19`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:m6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.20`,
        fs:  `cpe:2.3:a:apple:safari:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.4.21`,
        fs:  `cpe:2.3:a:nortel:ip_softphone_2050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.1`,
        fs:  `cpe:2.3:a:hp:destinations:130.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.2`,
        fs:  `cpe:2.3:o:panasonic:network_camera_recorder:4.04r02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.3`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.2.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.4`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:2.5.2.d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.5`,
        fs:  `cpe:2.3:a:ibm:monitoring_server_\(ms\)_and_shared_libraries_\(ax\):6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.6`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.8`,
        fs:  `cpe:2.3:o:cisco:staros:17.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.9`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.11`,
        fs:  `cpe:2.3:o:sun:sunos:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.12`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.14`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.17`,
        fs:  `cpe:2.3:o:windriver:bsdos:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.19`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.20`,
        fs:  `cpe:2.3:a:oracle:email_center:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.21`,
        fs:  `cpe:2.3:o:huawei:honor_4c_firmware:chm-tl00hc00b556:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.23`,
        fs:  `cpe:2.3:a:vmware:springsource_spring_security:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.25`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.26`,
        fs:  `cpe:2.3:h:apc:2200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.28`,
        fs:  `cpe:2.3:a:saltstack:salt:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.32`,
        fs:  `cpe:2.3:h:d-link:dir-816l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intermesh:group-office:3.5.33`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:02-01-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:international-arbitration-attorney:international-arbitration-attorney.com:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:4.1.150349.920:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:internet-works:nus_newssystem:1.02`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.4:1:~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.4.1:1:~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.4.1:2:~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.5.0::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:oracle:oracle_data_provider_for_.net_help:10.2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.5.1::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:tincan:phplist:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.7.0::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:intersectalliance:system_intrusion_analysis_and_reporting_environment:3.1.4::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intervideo:home_theater:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intervideo:home_theater:2.5.13.58`,
        fs:  `cpe:2.3:h:hp:jf800a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intervideo:windvd:-`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intervideo:windvd:7.0.27.172`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2015-ac-ovs-iw-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:interworx:web_control_panel:3.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p238:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:interworx:web_control_panel:5.0`,
        fs:  `cpe:2.3:a:veritas:netbackup:5.1.0:mp2:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:interworx:web_control_panel:5.0.10`,
        fs:  `cpe:2.3:a:cisco:threat_response:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:interworx:web_control_panel:5.0.11`,
        fs:  `cpe:2.3:a:phorum:phorum:5.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:interworx:web_control_panel:5.0.12`,
        fs:  `cpe:2.3:a:tenable:nessus:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:interworx:web_control_panel:5.0.13`,
        fs:  `cpe:2.3:h:valvesoftware:steam_link:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intra-mart:webplatform%2fappframework:6.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_71:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intra-mart:webplatform%2fappframework:6.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intra-mart:webplatform%2fappframework:7.0`,
        fs:  `cpe:2.3:a:ibm:sterling_multi-channel_fulfillment_solution:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intra-mart:webplatform%2fappframework:7.1`,
        fs:  `cpe:2.3:a:runtastic:runtastic_running_\&amp;_fitness:5.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:intra-mart:webplatform%2fappframework:7.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intrinsyc:j-integra_for_exchange:2.11.0.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intsig:camdictionary:2.3.0.20131118::~~~android~~`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intsig:camscanner:1.2.2.20110823`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intsig:camscanner:1.3.2.20120116`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intsig:camscanner_-phone_pdf_creator:3.4.0.20140624::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intsig:innote:1.0.3.20131119::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.3:2.3.0t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intuit:quickbooks:2009`,
        fs:  `cpe:2.3:o:freebsd:freebsd:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intuit:quickbooks:2010`,
        fs:  `cpe:2.3:a:sympa:sympa:1.4.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intuit:quickbooks:2011`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.7p5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intuit:quickbooks:2012`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intuit:quicken:20.1.7.4`,
        fs:  `cpe:2.3:a:hp:storeonce_4430_backup_system:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intuit:quicken:20.1.8.6`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:intuit:quicken:2001::~~basic~~~`,
        fs:  `cpe:2.3:o:xen:xen:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invage:views:6.x-2.16::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2see:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invage:views:6.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.04a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invage:views:7.x-3.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:dasabcip:4.1`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:dasabcip:4.1:sp1`,
        fs:  `cpe:2.3:a:measureup:microsoft_press_training_kit_exam_prep_suite_70-685:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:dasabcip:4.1:sp2`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:daserver_runtime_components:3.0`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:daserver_runtime_components:3.0:sp1`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:daserver_runtime_components:3.0:sp2`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:dassidirect:2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:dassidirect:3.0`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:foxboro_control_software:3.1`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:foxboro_control_software:4.0`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_webscan:1.1.0.1045:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:infusion_ce%2ffe%2fscada:2.5`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1664.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:infusion_integrated_engineering_environment:-`,
        fs:  `cpe:2.3:a:freetype:freetype:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:intouch:2012`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:intouch%2fwonderware_application_server:10.0`,
        fs:  `cpe:2.3:h:hp:8800_firewall_processing_module:jd251a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:intouch%2fwonderware_application_server:10.5`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:intouch%2fwonderware_application_server:2012`,
        fs:  `cpe:2.3:a:openpkg:openpkg:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:2.0`,
        fs:  `cpe:2.3:a:vmware:player:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:2.0.001:patch01`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:2.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(1\)t0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:2.1.002:patch02`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:3.0`,
        fs:  `cpe:2.3:a:sun:netdynamics:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:3.0.200:sp2`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:3.1`,
        fs:  `cpe:2.3:a:emc:rsa_data_loss_prevention:9.6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:3.1:sp1`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:3.1:sp2`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:3.1.201:sp2`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:3.5`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_application_server:2012`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.1.20513.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_archestra_configuration_access_component_activex_control:-`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_archestra_integrated_development_environment:-`,
        fs:  `cpe:2.3:a:acme:thttpd:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_historian:10.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_historian:10.0:sp1`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_inbatch:8.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_inbatch:8.1:sp1`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_inbatch:9.0`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_inbatch:9.0:sp1`,
        fs:  `cpe:2.3:a:altiris:deployment_solution_for_network_devices_documentation:6.0.1013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_inbatch:9.0:sp2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_inbatch:9.5`,
        fs:  `cpe:2.3:a:python:python:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_inbatch:9.5:sp1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_information_server:3.1`,
        fs:  `cpe:2.3:a:simple_ads_manager_project:simple_ads_manager:2.5.94:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_information_server:4.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_information_server:4.0:sp1`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_information_server:4.0:sp1:~-~portal~~~:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_information_server:4.5`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_information_server:4.5:-:portal`,
        fs:  `cpe:2.3:h:ibm:x342:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_information_server:5.0:-:portal`,
        fs:  `cpe:2.3:a:andrew_magdy_kamal\&#39;s_network_project:andrew_magdy_kamal\&#39;s_network:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_information_server:5.5:-:~-~portal~~~:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invensys:wonderware_intouch:2012:r2`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:investintech:slimpdf_reader:-`,
        fs:  `cpe:2.3:o:wdc:my_net_firmware:1.04.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invincea:browser_protection:2.3.6596`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.0.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.0.1`,
        fs:  `cpe:2.3:a:locationvalue:restaurant_karaoke_shidax:2.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.0.2`,
        fs:  `cpe:2.3:o:huawei:s9312_firmware:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.1.2`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.0`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.1:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.0:alpha1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.0:alpha2`,
        fs:  `cpe:2.3:a:digium:asterisk:13.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.0:beta1`,
        fs:  `cpe:2.3:a:opsview:opsview:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.0:beta2`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.0:beta3`,
        fs:  `cpe:2.3:a:paymentsplus:payments_plus:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.0:beta4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1021:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.1`,
        fs:  `cpe:2.3:a:ilexeng:lrgs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.2`,
        fs:  `cpe:2.3:a:user_import_project:user_import:6.x-4.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.3`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.3.4`,
        fs:  `cpe:2.3:a:oracle:communications_converged_application_server_service_controller:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.0`,
        fs:  `cpe:2.3:a:ibm:jazz_reporting_service:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.0:alpha1`,
        fs:  `cpe:2.3:a:siemens:simatic_wincc_runtime:-:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.0:beta1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.0:beta2`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.0:beta3`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.0:beta4`,
        fs:  `cpe:2.3:h:asus:rt-ac68u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.0:beta5`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.1`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_server:5.0.200.0:rp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.2`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.16:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.3`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.4`,
        fs:  `cpe:2.3:a:microsoft:digital_image_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.5`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:invision_power_board:3.4.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.111.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.0`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.50:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.1`,
        fs:  `cpe:2.3:o:huawei:s9312e_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.2`,
        fs:  `cpe:2.3:a:netscape:fasttrack_server:3.01b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.3`,
        fs:  `cpe:2.3:a:huawei:s9300_firmware:v200r003c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.5`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.6`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2108he:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.7`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.11m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.8`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invisionpower:ip.nexus:1.5.9`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invitation_project:invitation:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invitation_project:invitation:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:invitation_project:invitation:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:invitation_project:invitation:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:digium:asterisk:11.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:inzeratyzdarma:ads_free._cz_advert:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:iobit:amc_security-_antivirus_clean:4.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:hdl-a%2fe:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2010.825.2146.37182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:hdl-a_firmware:1.07`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_rim:6.1.1091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:hdl-ah:-`,
        fs:  `cpe:2.3:a:apple:safari:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:hdl-as:-`,
        fs:  `cpe:2.3:a:htc:evo_view_4g_software:1.22.651.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:hdl2-a%2fe:-`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.11.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:hdl2-a_firmware:1.07`,
        fs:  `cpe:2.3:a:gwmicro:window-eyes:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:hdl2-ah:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:np-bbrm:-`,
        fs:  `cpe:2.3:a:busybox:busybox:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:rockdisk:-`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.03v3-1.13`,
        fs:  `cpe:2.3:a:winzip:winzip:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.03w-1.14`,
        fs:  `cpe:2.3:a:apache:spamassassin:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.03y-1.16:beta`,
        fs:  `cpe:2.3:a:grape_project:grape:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.04a-1.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-03-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.04b-1.21`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.47.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.04d-2.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.04m-2.0.1`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.04n-2.0.1`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_ms_sql_server:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.04r3-2.0.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.04t-2.0.2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:rockdisk_firmware:1.05c-2.0.3`,
        fs:  `cpe:2.3:a:david_king:vino:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:ts-ptcam%2fpoe_camera:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.488.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:ts-ptcam%2fpoe_camera_firmware:1.08`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:ts-ptcam_camera:-`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:ts-ptcam_camera_firmware:1.08`,
        fs:  `cpe:2.3:a:bluecoat:proxysg_va-5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:ts-wlc2_camera:-`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:ts-wlc2_camera_firmware:1.02`,
        fs:  `cpe:2.3:a:forgerock:openam:9.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:ts-wlcam%2fv_camera:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:ts-wlcam%2fv_camera_firmware:1.0.6`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:ts-wlcam_camera:-`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:ts-wlcam_camera_firmware:1.06`,
        fs:  `cpe:2.3:a:11in1:11in1:1.2.1:stable_12-31-2011:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iodata:ts-wptcam_camera:-`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.2.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:iodata:ts-wptcam_camera_firmware:1.0.8`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:1.8.2`,
        fs:  `cpe:2.3:a:gentoo:xnview:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.0.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.0.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.3:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.0.2`,
        fs:  `cpe:2.3:h:linksys:befvp41:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.1.0`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.2.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:4.1.1:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.2.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.3.0`,
        fs:  `cpe:2.3:a:google:chrome:15.0.861.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.3.1`,
        fs:  `cpe:2.3:a:compaq:power_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iojs:io.js:2.3.2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iomega:cd-rw_52x24x52_usb:2.0:-`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iomega:hotburn:1.0::pro`,
        fs:  `cpe:2.3:a:oracle:internet_directory:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iomega:hotburn:2.0::pro`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iomega:hotburn:2.3::pro`,
        fs:  `cpe:2.3:a:boost:boost:1.65.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iomega:hotburn:2.3.1::pro`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.21042:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iomega:hotburn:2.5.1::pro`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.2.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:iomega:iomegaware:4.0.2`,
        fs:  `cpe:2.3:a:phppgadmin_project:phppgadmin:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iomega:iomegaware:4.0.3`,
        fs:  `cpe:2.3:a:novell:securelogin:6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iopus:imacros:6.90`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ioserver:ioserver:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ioserver:ioserver:1.0.18.0`,
        fs:  `cpe:2.3:a:adobe:robohelp_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ioserver:ioserver:1.0.19.0`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ioserver:ioserver_opc_server:-`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ioserver:opc_drivers:1.0.20`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ip-phone-smart:smartalk:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ip_ban_project:ip_ban:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ipa:ilogscanner:4.0`,
        fs:  `cpe:2.3:a:ricksoft:wbs_gantt-chart:7.8.1:*:*:*:*:jira:*:*`,
    },
     
    {
        uri: `cpe:/a:ipass:ipass_open_mobile:2.4.4::~~~windows~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ipcop:ipcop:2.1.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:ipcop:ipcop:2.1.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iphone4:iphone4.tw:3.3.20::~~~android~~`,
        fs:  `cpe:2.3:a:iij:seil\/x1_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipposan:memetan:1.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ippusbxd_project:ippusbxd:1.21.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:3.0.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.1.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:3.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:3.2.0`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.5.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.7.1\(732\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.6.0`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.7.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.8.0`,
        fs:  `cpe:2.3:a:apache:subversion:0.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.9.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.10.0`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.11.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.368:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.12.0`,
        fs:  `cpe:2.3:a:nero:disc_copy_gadget_help:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.13.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.14.0`,
        fs:  `cpe:2.3:a:e-press:one_office_e-zip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iproute2_project:iproute2:4.14.1`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:5.0`,
        fs:  `cpe:2.3:a:7t:termis:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:5.0.5`,
        fs:  `cpe:2.3:a:ibm:sterling_secure_proxy:3.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:5.0.6`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:5.0.7`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:5.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jnc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.0`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.5.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.00`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.15:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(22\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.0.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.0.3`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.21.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.0.5`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.0.6`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.1`,
        fs:  `cpe:2.3:a:netgear:readynas_surveillance:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.2`,
        fs:  `cpe:2.3:a:telos:amhs:11.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.3`,
        fs:  `cpe:2.3:a:oracle:jdeveloper:10.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.4`,
        fs:  `cpe:2.3:a:emil_stjerneman:linkit:7.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:6.06`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.0.1`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.0.2`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.0.3`,
        fs:  `cpe:2.3:h:siemens:synco_ozw_web_server:ozw772.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.0.4`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.0.5`,
        fs:  `cpe:2.3:a:t1lib:t1lib:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.0.6`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.0.7`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:7.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(3i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:8.0.3`,
        fs:  `cpe:2.3:h:nortel:7250_wlan_access_point:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:8.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(26\)eb1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:8.1`,
        fs:  `cpe:2.3:a:ca:vet_antivirus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:8.01`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:8.11`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:8.12`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:8.13`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:8.22`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:10`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:10.01`,
        fs:  `cpe:2.3:a:symantec:data_insight:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:10.02`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:11`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:11.01`,
        fs:  `cpe:2.3:a:ibm:i_access:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:11.02`,
        fs:  `cpe:2.3:a:gnu:binutils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:11.03`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:2006`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:2006.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail:2006.2`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_client:9.22`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_express:8.03`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:3.3.1-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_plus:2006`,
        fs:  `cpe:2.3:a:simple_ads_manager_project:simple_ads_manager:2.6.94:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_premium:2006`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_secure_server:2006`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_server:8.2:hotfix2`,
        fs:  `cpe:2.3:a:c4plans:sg_tool:3.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_server:8.20`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_server:12.3`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_server:12.4`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_server:12.4.1.15`,
        fs:  `cpe:2.3:a:yahoo:yui:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_server:2006.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imail_server:2006.22`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imserver:2.0.5.30`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:imserver:2.0.8.1`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:2.1.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:instant_messaging:2.0.8.1`,
        fs:  `cpe:2.3:a:samba:samba:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:2.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:2.01`,
        fs:  `cpe:2.3:a:cloudbees:jenkins1.381:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:2.07`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p415:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:8.15`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:2006:-:premium`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sg_3.4.7sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:2006:-:standard`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:2006.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:2006.02:-:premium`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_collaboration_suite:2006.02:-:standard`,
        fs:  `cpe:2.3:a:apple:xcode:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ipswitch_secure_server:2006:-:premium`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:moveit_dmz:8.1`,
        fs:  `cpe:2.3:o:hp:officejet_pro_8500_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:moveit_mobile:1.2.0.962`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:moveit_mobile:1.2.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup:2005:sp1:professional`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup:2006:-:professional`,
        fs:  `cpe:2.3:a:oracle:customer_interaction_history:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:7.0`,
        fs:  `cpe:2.3:o:cisco:staros:16.0\(900\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:7.03`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_software:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:7.04`,
        fs:  `cpe:2.3:a:skyarc:mailpack:1.741:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:8.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:8.01`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:8.03`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:8.03:hotfix1`,
        fs:  `cpe:2.3:a:rosettastone:rosettastone:3.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:11`,
        fs:  `cpe:2.3:a:umn:mapserver:5.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:15.02`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:whatsup_gold:16.3`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:wincom_lpd:1.00.90`,
        fs:  `cpe:2.3:a:x.org:libx11:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:1.0.5`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2.01`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.328:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2.02`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2.03`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:3.0`,
        fs:  `cpe:2.3:a:divx:converter:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:3.0.1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:11.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:3.1.0`,
        fs:  `cpe:2.3:h:fortinet:fortigate-110c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:3.1.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:3.1.2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-16c-si_ls-s3100-16c-si-dc-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:3.1.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.6.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:3.14`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:4.00`,
        fs:  `cpe:2.3:a:be_user_log_project:be_user_log:1.1.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:4.01`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:4.02`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.10:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:5.00`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:5.01`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:5.02`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:5.03`,
        fs:  `cpe:2.3:a:sun:iplanet_certificate_management_system:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:5.04`,
        fs:  `cpe:2.3:h:unisys:fs600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:5.05`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:6.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:6.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:7.5.29.0`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:7.5.29.0:-:professional`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:12.0:-:home`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:12.0:-:pro`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:12.0.1:-:home`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:12.0.1:-:pro`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:12.2:-:home`,
        fs:  `cpe:2.3:a:gnu:glibc:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:12.2:-:pro`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:12.3`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2007`,
        fs:  `cpe:2.3:a:redhat:resteasy:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2007:-:home`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2007:-:professional`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2007.0.0.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110731:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2007.0.0.2:-:home`,
        fs:  `cpe:2.3:a:drupal:drupal:6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp:2007.1.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.1\(68\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:1.0.1`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.0b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:1.0.1.e`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:1.0.2`,
        fs:  `cpe:2.3:a:divx:divx_player:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:1.0.2.e`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:1.0.3`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.5:sr_3.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:1.0.4`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:7.102.101.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:1.0.5`,
        fs:  `cpe:2.3:a:x:libxvmc:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:2.0`,
        fs:  `cpe:2.3:a:nero:recode:3.53.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:2.0.1`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:2.0.2`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:2.0.3`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2013.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:2.0.4`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(3b\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:3.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/l:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:3.1`,
        fs:  `cpe:2.3:o:cisco:sa520:2.2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:3.1.1`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:3.1.2`,
        fs:  `cpe:2.3:a:adobe:premiere_pro_cs4:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:3.1.3`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.0.899:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:3.4`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp3:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:4.0`,
        fs:  `cpe:2.3:o:zte:zxv10_w300_firmware:1.0.0a_zrd_lk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:4.0.1`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:4.0.2`,
        fs:  `cpe:2.3:o:ibm:aix:5.2_l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:5.0.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:5.0.3`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:5.0.4`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.41.020.1973:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:5.0.5`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:5.0.8:-:limited`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:6.1.0.0`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow_set:07-50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server:7.5.1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipswitch:ws_ftp_server_with_ssh:6.1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:0.12`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:0.12.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:0.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:0.13.1`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:0.13.2`,
        fs:  `cpe:2.3:a:apache:poi:1.10:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:1.0.0`,
        fs:  `cpe:2.3:a:shopware:shopware:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:1.1.0`,
        fs:  `cpe:2.3:a:atutor:atutor:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:1.2.0`,
        fs:  `cpe:2.3:a:apprain:apprain:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:1.2.1`,
        fs:  `cpe:2.3:h:3com:webbngss3nbxnts:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ipython:ipython_notebook:2.1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.1\(1.98\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iqnect:dubstep_hero:1.9::~~~android~~`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:irata:authorize.net_module:-`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:7.2.0`,
        fs:  `cpe:2.3:h:sterlitetechnologies:sam300_ax_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:7.2.1`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:7.2.2`,
        fs:  `cpe:2.3:a:keepass:keepass:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:7.2.3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:7.3.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:7.3.0:rc1`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:7.3.1`,
        fs:  `cpe:2.3:a:hp:solution_center:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.0`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.0:beta1`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.425b:mr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.0:beta2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.0.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.0:beta3`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.9.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.0:rc1`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:alpha4:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:cf07:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.3:-:*:*:liberty_profile:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.3`,
        fs:  `cpe:2.3:h:supermicro:h8dgt-hlf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.4`,
        fs:  `cpe:2.3:a:ibm:atlas_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ircd-hybrid:ircd-hybrid:8.0.5`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irdeto:cyphercast_server_system:2.3.3`,
        fs:  `cpe:2.3:a:samba:samba:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irdeto:flexsms:1.2`,
        fs:  `cpe:2.3:a:sap:afaria:7.0.6398.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irdeto:pisys:1.3.2`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ireadercity:100_books:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ireadercity:a_very_short_history_of_japan:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:h:thomson:twg87ouir:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ireadercity:demon:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ireadercity:hesheng_80:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.3:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ireadercity:short_stories:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p127:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ireadercity:sword:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:flashpix_plugin:4.3.4.0`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:flashpix_plugin:4.32`,
        fs:  `cpe:2.3:a:linecorp:line\@:1.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:flashpix_plugin:4.33`,
        fs:  `cpe:2.3:a:orcacle:retail_point-of-service:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:-`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.70`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.80`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.85`,
        fs:  `cpe:2.3:a:oracle:retail_applications:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.90`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.95`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.97`,
        fs:  `cpe:2.3:a:ibm:informed_desktop_eforms:4.1.50.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.98`,
        fs:  `cpe:2.3:a:openstack:folsom:2012.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.98a`,
        fs:  `cpe:2.3:a:google:chrome:9.0.564.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:1.99`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.00`,
        fs:  `cpe:2.3:a:actuate:iserver:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.05`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1668.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.07`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.10`,
        fs:  `cpe:2.3:a:hummingbird:component_deployment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.12`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.15`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.12:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.17`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.18`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.20`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.22`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.25`,
        fs:  `cpe:2.3:a:microsoft:forefront_unified_access_gateway:2010:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.27`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.30`,
        fs:  `cpe:2.3:a:perrla:perrla:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.32`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.35`,
        fs:  `cpe:2.3:a:roxio:media_manager:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.37`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:7.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.40`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.50`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.52`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.7.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.55`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.60`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.63`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.65`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.66`,
        fs:  `cpe:2.3:a:firebird:firebird:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.68`,
        fs:  `cpe:2.3:a:hp:mercury_loadrunner_agent:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.80`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.82`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.83`,
        fs:  `cpe:2.3:o:belkin:n600_db_wi-fi_dual-band_n\&#43;_router_f9k1102_firmware:2.10.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.85`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.90`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.92`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.95`,
        fs:  `cpe:2.3:h:ibm:ds4400:1742:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.97`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:2.98`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.00`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24:rc1.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.02`,
        fs:  `cpe:2.3:a:microsoft:digital_image_pro:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.05`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.07`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp1:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.10`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.12`,
        fs:  `cpe:2.3:a:microsoft:vbscript:5.8:-:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.15`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.4.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.17`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.20`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.21`,
        fs:  `cpe:2.3:a:jjmatch:jj_texas_hold\&#39;em_poker:1.13.23.hd:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.25`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.30`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.33`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.35`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.36`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.78d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.50`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.47s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.51`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.60`,
        fs:  `cpe:2.3:a:ssh:tectia_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.61`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.70`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.75`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.80`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.85`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.90`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.91`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.92`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.95`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.97`,
        fs:  `cpe:2.3:a:otrs:otrs:1.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.98`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:3.99`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.00`,
        fs:  `cpe:2.3:a:serena:changeman_version_manager:8.1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.10`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.20`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.23`,
        fs:  `cpe:2.3:a:c2ae:water_lateral_sizer:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.25`,
        fs:  `cpe:2.3:a:redhat:rhx_enterprisedb_advanced_server:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.27`,
        fs:  `cpe:2.3:a:apple:cups:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.28`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.30`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.32`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.33`,
        fs:  `cpe:2.3:a:atmail:atmail:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.35`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.36`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview:4.37`,
        fs:  `cpe:2.3:h:cisco:ws-c3860:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview_plugins:4.33`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irfanview:irfanview_plugins:4.34`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_developer_suite:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irider:irider:2.21.1108`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irislink:i.r.i.s._ocr_engine:12.3.4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:irislink:iriscan_pro_office_3:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.676.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irislink:readiris:8.0::~~professional~~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irislink:readiris:9.0::~~professional~~~`,
        fs:  `cpe:2.3:a:symantec:norton_system_works:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irislink:readiris:11.0.4965::~~professional~~~`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irislink:readiris:11.0.5062::~~professional~~~`,
        fs:  `cpe:2.3:a:foxitsoftware:phantompdf:7.2.0.722:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irods:irods:4.1.10`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irods:irods:4.2.0`,
        fs:  `cpe:2.3:a:bea:aqualogic_enterprise_security:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irokez:irokez_cms:0.7.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irokez:irokez_cms:0.8.8`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:irssi:irssi:0.8.19`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irssi:irssi:0.8.20`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:irssi:irssi:1.0.2`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.1:sp3:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:irz:ruh2:-`,
        fs:  `cpe:2.3:a:david_king:vino:2.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:is_my_json_valid_project:is_my_json_valid:2.12.3::~~~node.js~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.2:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:browserid:7.x-1.0`,
        fs:  `cpe:2.3:a:scriptsfeed:recipes_listing_portal:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:browserid:7.x-1.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:browserid:7.x-1.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:browserid:7.x-1.x-dev`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.18-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.1`,
        fs:  `cpe:2.3:a:christian_johansson:restrict_node_page_view:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.3`,
        fs:  `cpe:2.3:a:python:pillow:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.4`,
        fs:  `cpe:2.3:a:paymentsplus:payments_plus:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.5`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.7`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:7.00.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.8`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.9`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.10`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.11`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.3.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.12`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.13`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.7.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:7.x-1.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:7.x-1.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:16.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:7.x-1.2`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaac_sukin:shorten:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isaca:cism:6.2.208`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:3.0.0:cr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isamu_kaneko:winny:2.0b5.7`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isamu_kaneko:winny:2.0b7.1`,
        fs:  `cpe:2.3:a:embedthis:goahead:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:-`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:3.30.651.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9`,
        fs:  `cpe:2.3:a:digia:qt:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.2`,
        fs:  `cpe:2.3:h:xerox:workcentre_m55:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.3`,
        fs:  `cpe:2.3:a:google:chrome:7.0.537.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.4`,
        fs:  `cpe:2.3:a:oracle:commerce_guided_search_and_experience_manager:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.5`,
        fs:  `cpe:2.3:a:vmware:fusion_pro:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.5:p1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.6`,
        fs:  `cpe:2.3:a:simpleflickr_project:simpleflickr:3.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.7`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2005:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.8`,
        fs:  `cpe:2.3:a:moodle:moodle:3.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.9`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:4.9.10`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.1.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.1.2`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.1.3:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2:p1`,
        fs:  `cpe:2.3:a:pixman:pixman:0.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.2:p1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.2:p2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.96.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.2:p3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.2:p4`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.2:p5`,
        fs:  `cpe:2.3:a:apache:subversion:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.2:p6`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(24\)s5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.2:p7`,
        fs:  `cpe:2.3:a:gnu:bash:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.3`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.3:t1a`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.3:t9b`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:11:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.3_t1a`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.3_t9b`,
        fs:  `cpe:2.3:a:microsoft:security_compliance_manager:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.4`,
        fs:  `cpe:2.3:a:inmatrix:zoom_player:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.5`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.6`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.2.7`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.3.0`,
        fs:  `cpe:2.3:a:esoftpro:online_photo_pro:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.3.1`,
        fs:  `cpe:2.3:h:hp:laserjet_9000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.3.2`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.3.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.447.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.3.4`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.3.5`,
        fs:  `cpe:2.3:h:cisco:catalyst_6500_ws-svc-nam-2:2.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.3.6`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.4`,
        fs:  `cpe:2.3:a:apple:java_1.5:0:16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.4.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update3:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.4.4`,
        fs:  `cpe:2.3:h:cisco:spa_512g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.4.5`,
        fs:  `cpe:2.3:a:adobe:connect:9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:8.4.7`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.4:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.0:rc1`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.0:rc2`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.0:rc3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.0:rc4`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_telus_wifi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.0:rc5`,
        fs:  `cpe:2.3:a:viewvc:viewvc:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.0:rc6`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.1`,
        fs:  `cpe:2.3:a:spip:spip:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.1:rc1`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.0.1:rc2`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.0:rc1`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.6\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.1`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.1:rc1`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.1:rc2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.1:rc3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.1:rc4`,
        fs:  `cpe:2.3:a:altiris:service_control_task:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.1:rc5`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.1:rc6`,
        fs:  `cpe:2.3:a:pyyaml:libyaml:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.1:rc7`,
        fs:  `cpe:2.3:a:libav:libav:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.2:rc1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.3`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.3:rc1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.3:rc2`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.1.3:rc3`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0`,
        fs:  `cpe:2.3:a:x:libxxf86vm:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:a1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:a2`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:a3`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:b1`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:9.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:b2`,
        fs:  `cpe:2.3:a:emc:networker:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc1`,
        fs:  `cpe:2.3:a:wb-i:contents-mall:15.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc10`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc2`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc4`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc5`,
        fs:  `cpe:2.3:a:adobe:flash_player:19.0.0.207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc6`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc7`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc8`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.2.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.0:rc9`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.1`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.1:rc1`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.1:rc2`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_3016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.2`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.2:p2`,
        fs:  `cpe:2.3:a:oracle:oracle_and_sun_systems_product_suite:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.2:p3`,
        fs:  `cpe:2.3:o:siemens:simatic_s7-400_cpu_firmware:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.2:rc1`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.3`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.3:rc1`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.3:rc2`,
        fs:  `cpe:2.3:a:nagios:nagios:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.3:rc3`,
        fs:  `cpe:2.3:a:openstack:swift:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.3:rc4`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.4:rc2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.4:rc3`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.4:rc4`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.4:rc5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.4:rc6`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.4:rc7`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.4:rc8`,
        fs:  `cpe:2.3:h:xerox:document_centre_460:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.5`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.5:b2`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.5:beta2`,
        fs:  `cpe:2.3:a:janetter:janetter:2.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.5:rc1`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.6`,
        fs:  `cpe:2.3:h:turck:bl20_programmable_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.6:rc1`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.7`,
        fs:  `cpe:2.3:a:php-nuke:myheadlines:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.7:rc1`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.7:rc2`,
        fs:  `cpe:2.3:a:huge-it:portfolio_gallery:1.0.6:*:*:*:*:joomla:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.7:rc3`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.8`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.9`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.2.9:rc1`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0544:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3`,
        fs:  `cpe:2.3:a:schneider-electric:floating_license_manager:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:b2`,
        fs:  `cpe:2.3:a:sympa:sympa:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:b3`,
        fs:  `cpe:2.3:a:opscode:chef:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:b4`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:beta2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:beta3`,
        fs:  `cpe:2.3:a:pfsense:snort_package:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:beta4`,
        fs:  `cpe:2.3:a:freeimage_project:freeimage:3.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:rc1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:rc2`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:rc3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.9.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.0:rc4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.1:b2`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.1:beta2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.1:rc1`,
        fs:  `cpe:2.3:a:mislav_marohnic:will_paginate:3.0.5:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.2`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.2:_nil_:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.2:rc1`,
        fs:  `cpe:2.3:a:unrealircd:unrealircd:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.3`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:9.1.0-000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.3:rc1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.04:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.3:rc2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.3:rc3`,
        fs:  `cpe:2.3:a:deskroll:deskroll_remote_desktop:0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.4`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:9.7.0-125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.5`,
        fs:  `cpe:2.3:a:peel:peel_shopping:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.5:p2_w1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.5:rc1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.5:rc2`,
        fs:  `cpe:2.3:a:slickedit:slickedit:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.6`,
        fs:  `cpe:2.3:a:tenable:nessus:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.3.6:rc1`,
        fs:  `cpe:2.3:a:avery:design_pro:5.5.708:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4::~~esv~~~`,
        fs:  `cpe:2.3:a:gnu:gdb:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:b1:~~esv~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ixa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r1:~~esv~~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r2:~~esv~~~`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r3:~~esv~~~`,
        fs:  `cpe:2.3:a:apache:harmony:6.0:m3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r4:~~esv~~~`,
        fs:  `cpe:2.3:a:netbsd:ftpd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r4-p1:~~esv~~~`,
        fs:  `cpe:2.3:a:field_group_project:field_group:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r5:~~esv~~~`,
        fs:  `cpe:2.3:a:hitachi:ibm_xl_c\/c\&#43;\&#43;_v8_for_aix_\&amp;_hitachi_developer\&#39;s_kit_for_java:01-00:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r5-b1:~~esv~~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.576.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r5-p1:~~esv~~~`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4:r5-rc1:~~esv~~~`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0`,
        fs:  `cpe:2.3:a:nvidia:install_application:2.275.78.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:a1`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:a2`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:-:seccenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:a3`,
        fs:  `cpe:2.3:a:git-scm:git:2.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:a4`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:a5`,
        fs:  `cpe:2.3:o:cisco:staros:18.0.0.59211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:a6`,
        fs:  `cpe:2.3:a:openssh:openssh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:b1`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_suse_linux:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:b2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:b3`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:b4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:rc1`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0:rc2`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0a1`,
        fs:  `cpe:2.3:h:cisco:dpc3939_wireless_residential_voice_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0a2`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0a3`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0a4`,
        fs:  `cpe:2.3:a:ibm:rational_license_server:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0a5`,
        fs:  `cpe:2.3:a:samba:samba:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0a6`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd7.d4xxv_vga_mb_firmware:1.24.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0b1`,
        fs:  `cpe:2.3:a:redhat:network_proxy:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0b2`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0b3`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.50:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.0b4`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.1`,
        fs:  `cpe:2.3:a:pidgin:libpurple:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.2`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.2:p2_w1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.2:rc1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.2:rc2`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3`,
        fs:  `cpe:2.3:o:ibm:aix:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:b1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xna:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:b2`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:b3`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:p1`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:p2`,
        fs:  `cpe:2.3:a:arj_software:arj_archiver:3.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:p3`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:p4`,
        fs:  `cpe:2.3:a:kajona:kajona:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:p5`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3:rc1`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_agent_exchange:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3b1`,
        fs:  `cpe:2.3:a:ups:worldship_upsdb:14.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3b2`,
        fs:  `cpe:2.3:a:news_project:news:3.0.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.4.3b3`,
        fs:  `cpe:2.3:a:x.org:x11:r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5`,
        fs:  `cpe:2.3:a:creative_core:app_lock:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0`,
        fs:  `cpe:2.3:a:gnu:grep:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:a1`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:a2`,
        fs:  `cpe:2.3:h:huawei:s6300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:a3`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:a4`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:a5`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:a6`,
        fs:  `cpe:2.3:h:nortel:ip_phone_2007:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:a7`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:b1`,
        fs:  `cpe:2.3:a:x:libxrandr:1.2.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:b2`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:b3`,
        fs:  `cpe:2.3:a:novell:zenworks_endpoint_security_management:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:p1`,
        fs:  `cpe:2.3:a:isc:bind:9.8.3:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:p2`,
        fs:  `cpe:2.3:a:aprel:exe_to_msi_converter_free:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:p2_w1`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:p2_w2`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0:rc1`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0-p1`,
        fs:  `cpe:2.3:a:vmware:virtualcenter:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0-p2`,
        fs:  `cpe:2.3:a:hp:product_assistant:53.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0-p2-w1`,
        fs:  `cpe:2.3:h:apple:imac:mb398xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0-p2-w2`,
        fs:  `cpe:2.3:a:quest:benchmark_factory_for_databases:5.5.1.379:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0a1`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0a2`,
        fs:  `cpe:2.3:a:wave:preboot_manager:3.2.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0a3`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0a4`,
        fs:  `cpe:2.3:a:minibb:minibb:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0a5`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0a6`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0a7`,
        fs:  `cpe:2.3:a:youmail:youmail_visual_voicemail_plus:2.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0b1`,
        fs:  `cpe:2.3:a:emc:vplex_geosynchrony:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0b2`,
        fs:  `cpe:2.3:a:webform_invitation_project:webform_invitation:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.0b3`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0.1:test3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1`,
        fs:  `cpe:2.3:a:hornbill:supportworks_itsm:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1:b1`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1:b2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1:b3`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1:rc1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1:rc2`,
        fs:  `cpe:2.3:o:hp:arcsight_connector_appliance_firmware:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1b1`,
        fs:  `cpe:2.3:a:apple:safari:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1b2`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.1b3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2:b1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2:p1`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2:p2`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2:p3`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.5.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2:p4`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2:rc1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2-p1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2-p2`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2-p3`,
        fs:  `cpe:2.3:a:sap:gui:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2-p4`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.2b1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.3:b1`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.3:rc1`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.5.3b1`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:6.1.15.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6::~~esv~~~`,
        fs:  `cpe:2.3:a:openpkg:openpkg:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r1:~~esv~~~`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r2:~~esv~~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r3:~~esv~~~`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r4:~~esv~~~`,
        fs:  `cpe:2.3:h:hp:mp9_g2_retail_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r4_p1:~~esv~~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r5:~~esv~~~`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r5_b1:~~esv~~~`,
        fs:  `cpe:2.3:a:netscape:collabra_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r5_p1:~~esv~~~`,
        fs:  `cpe:2.3:h:juniper:mx480:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r6:~~esv~~~`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.1.7.3363:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r6_b1:~~esv~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.4-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r6_rc1:~~esv~~~`,
        fs:  `cpe:2.3:h:linksys:wrt54g:2.00.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r6_rc2:~~esv~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r7:~~esv~~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r7_p1:~~esv~~~`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r7_p2:~~esv~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p98:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r9:~~esv~~~`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6:r9_p1:~~esv~~~`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r2`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r4`,
        fs:  `cpe:2.3:a:hp:chaivm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r4-p1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r5`,
        fs:  `cpe:2.3:o:siemens:ccid1445-dn36_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r5:p1`,
        fs:  `cpe:2.3:a:powerpc-utils_project:powerpc-utils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r5b1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r6`,
        fs:  `cpe:2.3:a:oracle:jdeveloper:9.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r6:b1`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r6:rc1`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r6:rc2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.04:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r7`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r7:p1`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r7:p2`,
        fs:  `cpe:2.3:a:apple:safari:1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r9`,
        fs:  `cpe:2.3:o:huawei:6300ei_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6-esv-r9:p1`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.0`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.68:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.0:a1`,
        fs:  `cpe:2.3:o:huawei:s9303e_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.0:b1`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.0:p1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.0:rc1`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.0:rc2`,
        fs:  `cpe:2.3:a:socialcms:socialcms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.0a1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.0b1`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.1`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.1\(.07021\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.1:b1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00-\/i:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.1:p1`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.1:p2`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.1:p3`,
        fs:  `cpe:2.3:h:cisco:8500_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.1:rc1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.1b1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2:b1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2:p1`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system:2.2\(3f\)a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2:p2`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2:p3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2:rc1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2-p1`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2-p2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2-p3`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.2b1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.3`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.3:b1`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.150:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.3:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.6.3b1`,
        fs:  `cpe:2.3:a:hp:update:4.0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0`,
        fs:  `cpe:2.3:a:hp:http_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:a1`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:a2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:a3`,
        fs:  `cpe:2.3:o:yahama:rtx1200:10.01.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:b1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:b2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:b3`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:beta`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linuxsoft_2007:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:p1`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:p2`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:rc1`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0:rc2`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0a1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0a2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.1-1:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0a3`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0b1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0b2`,
        fs:  `cpe:2.3:a:netopsystem:fead_optimizer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.0b3`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.1`,
        fs:  `cpe:2.3:h:hp:cf083a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.1:b1`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.1:p1`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.1:p2`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.1:rc1`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.1.4360:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.1b1`,
        fs:  `cpe:2.3:a:hp:thinpro_linux:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.2`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:sp2:developer:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.2:p1`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.2:p2`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_portal_server:2001:sp2a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.2:p3`,
        fs:  `cpe:2.3:a:ibm:security_qradar_incident_forensics:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.2:rc1`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:-:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.3`,
        fs:  `cpe:2.3:a:lunarcms:lunar_cms:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.3:b1`,
        fs:  `cpe:2.3:a:gnu:mailman:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.3:p1`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.3:rc1`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.4`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.4:b1`,
        fs:  `cpe:2.3:a:tryton:tryton:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.4:p1`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:6.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.4:rc1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.4b1`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.5`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.5:b1`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.5:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yd2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.5:rc2`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.6`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.6:p1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.6:p2`,
        fs:  `cpe:2.3:a:websense:websense_web_security:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.6:p3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-00-\/i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.6:p4`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.7.7`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.0`,
        fs:  `cpe:2.3:a:altiris:carbon_copy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.0:a1`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.0:b1`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.0:p1`,
        fs:  `cpe:2.3:o:seil:x1_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.0:p2`,
        fs:  `cpe:2.3:a:magzter:motor:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.0:p4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.1:b1`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.1:b2`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.1:b3`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.1:p1`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.1:rc1`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.2`,
        fs:  `cpe:2.3:a:ibm:soliddb:4.5.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.2:b1`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.2:rc1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.2:rc2`,
        fs:  `cpe:2.3:a:pointinside:point_inside_shopping_\&amp;_travel:3.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.3`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.3:p1`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.3:p2`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.3:p3`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.3:p4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.4`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.5`,
        fs:  `cpe:2.3:a:debian:apt:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.5:b1`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_production_premium:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.5:b2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.5:p1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:17.009.20044:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.5:p2`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.5:rc1`,
        fs:  `cpe:2.3:h:cisco:telepresence_codec_c40:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.5:rc2`,
        fs:  `cpe:2.3:a:debian:gfax:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.6:b1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.6:rc1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.8.6:rc2`,
        fs:  `cpe:2.3:a:netscape:communicator:4.5_beta:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0`,
        fs:  `cpe:2.3:a:delrina:form_flow:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:a1`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:a2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:a3`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:b1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.4\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:b2`,
        fs:  `cpe:2.3:a:sap:software_deployment_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:rc1`,
        fs:  `cpe:2.3:a:symantec:discovery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:rc2`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:rc3`,
        fs:  `cpe:2.3:a:htc:evo_design_4g_software:1.19.651.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.0:rc4`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.1:p1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.1:p2`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.1:p3`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.956:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.1:p4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(1g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.22:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.2:p1`,
        fs:  `cpe:2.3:a:drupal:drupal:7.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.2:p2`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.3`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.3:b1`,
        fs:  `cpe:2.3:a:symantec:im_manager:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.3:b2`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.3:p1`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.3:p2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.3:rc1`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4015:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.3:rc2`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.4:b1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.258.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.5`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.6`,
        fs:  `cpe:2.3:a:nero:essentials:7.2.4509:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.6:p1`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_firmware:bs4.4.4621.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.7:b1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.7:p1`,
        fs:  `cpe:2.3:h:d-link:dcs-931l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.7:rc1`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.7:rc2`,
        fs:  `cpe:2.3:a:apache:apr-util:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:p2`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.6:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:p3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:p4`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:rc1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:s1`,
        fs:  `cpe:2.3:a:sympa:sympa:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:s2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.333.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:s3`,
        fs:  `cpe:2.3:a:gnome:glib:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:s4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.388:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:s5`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.8:s6`,
        fs:  `cpe:2.3:h:hp:wireless_barcode_scanner_e6p34aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.9`,
        fs:  `cpe:2.3:a:git-scm:git:0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.9:b1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.9:b2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.9:p1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.9:p3`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.9:rc1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta68:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.9:s1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.9.9:s1rc1`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0:a1`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0:a2`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0:b1`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0:b2`,
        fs:  `cpe:2.3:a:vmware:esx_server:1.5.2:patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0:p1`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs4_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0:p2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_1x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0:rc1`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.0:beta1_v2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.0:rc2`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.1`,
        fs:  `cpe:2.3:a:novell:groupwise:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.1:b1`,
        fs:  `cpe:2.3:a:sun:javaserver_web_dev_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.1:b2`,
        fs:  `cpe:2.3:a:codiad:codiad:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.1:p1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.1:p2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.1:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.1:rc2`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.2:b1`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.2:p1`,
        fs:  `cpe:2.3:a:sony:digital_voice_editor:3.3.1.11240:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.2:p2`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2017:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.2:p3`,
        fs:  `cpe:2.3:h:cisco:2500_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.2:p4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.2:rc1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.8.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.2:rc2`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.3`,
        fs:  `cpe:2.3:h:ge:multilink_ml800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.3:b1`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.3:p1`,
        fs:  `cpe:2.3:h:cisco:catalyst_6000_ws-svc-nam-2:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.3:p2`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.7.00004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.3:p3`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.3:p4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.3:rc1`,
        fs:  `cpe:2.3:o:huawei:honor_4c_firmware:chm-ul00c00b535:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.4:b2`,
        fs:  `cpe:2.3:h:hp:cz255a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.4:b3`,
        fs:  `cpe:2.3:a:sophos:safeguard_easy_device_encryption_client:5.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.4:p2`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.4:p3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.10.4:rc1`,
        fs:  `cpe:2.3:a:ipswitch:imail_server:12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.11.0:a1`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.11.0:a2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.11.0:a3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.11.0:b1`,
        fs:  `cpe:2.3:a:mozilla:camino:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.11.0:b2`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.5\(1-2011o\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.11.0:b3`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.8d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:bind:9.11.0:rc1`,
        fs:  `cpe:2.3:a:winzip:winzip:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.0.0`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.0.1`,
        fs:  `cpe:2.3:a:google:v8:3.24.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.0.2`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.0.2:p1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.0.3`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.0.3:rc1`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r1`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r10`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r10_b1`,
        fs:  `cpe:2.3:a:mod_nss_project:mod_nss:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r11_b1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r11_rc1`,
        fs:  `cpe:2.3:a:x:libxrandr:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r11_rc2`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r12`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r12_b1`,
        fs:  `cpe:2.3:h:asus:rt-n56r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r2`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r3`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r3_b1`,
        fs:  `cpe:2.3:h:hp:0235a0c0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r5`,
        fs:  `cpe:2.3:a:samba:samba:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r5_b1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r5_rc1`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.2.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r5_rc2`,
        fs:  `cpe:2.3:a:augeas:augeas:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r6`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r7`,
        fs:  `cpe:2.3:h:cisco:nexus_9504:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r8`,
        fs:  `cpe:2.3:a:nvidia:nview:135.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r8_b1`,
        fs:  `cpe:2.3:a:hp:openview_storage_data_protector:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r8_rc1`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r9`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r9_b1`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:r9_rc1`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1-esv:rc1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.0:a1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1b.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.0:a2`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.0:b1`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.19:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.1`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.0.196a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.1:b1`,
        fs:  `cpe:2.3:a:apache:struts:2.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.1:b2`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.1:b3`,
        fs:  `cpe:2.3:a:google:chrome:0.1.38.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.1:p1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:5.0.0-1_43d8f09a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.1:rc1`,
        fs:  `cpe:2.3:a:sendmail:intelligent_quarantine:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.2:b1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.12-118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.2:p1`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.1.2:rc1`,
        fs:  `cpe:2.3:a:rockwellautomation:1763-l16bbb_series_b:15.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.0`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.0:a1`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.0:a2`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.0:b1`,
        fs:  `cpe:2.3:a:nextapp:echo:3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.0:b2`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.0:p1`,
        fs:  `cpe:2.3:a:techsmith:snagit:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.0:p2`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.0:rc1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.1`,
        fs:  `cpe:2.3:a:nagios:remote_plugin_executor:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.1:b1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.1:p1`,
        fs:  `cpe:2.3:a:joe_haskins:og_manager_change:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.1:rc1`,
        fs:  `cpe:2.3:a:oracle:human_capital_management:8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.2`,
        fs:  `cpe:2.3:a:netscape:proxy_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.2:b1`,
        fs:  `cpe:2.3:a:veritas:backup_exec_remote_agent:9.0.4367:sp1:windows_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.2:rc1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.3:p1`,
        fs:  `cpe:2.3:a:wokamoto:wp-cron_dashboard:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.3:p2`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.4`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.18_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.4:b1`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.4:p1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.4:p2`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.4:rc1`,
        fs:  `cpe:2.3:a:zope:zserver:1.1b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.4:rc2`,
        fs:  `cpe:2.3:a:cisco:jabber:9.1\(.0\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.5:b1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.5:p1`,
        fs:  `cpe:2.3:o:emc:data_domain:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.5:rc1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.4:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.6`,
        fs:  `cpe:2.3:a:apache:poi:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.6:b1`,
        fs:  `cpe:2.3:a:yahoo:desktop_login:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.6:rc1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.7`,
        fs:  `cpe:2.3:h:ge:multilink_ml1600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.7:b1`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.7:rc1`,
        fs:  `cpe:2.3:a:moodle:moodle:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.8`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.8:b1`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.8:rc1`,
        fs:  `cpe:2.3:a:microsoft:access:2002:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.2.8:rc2`,
        fs:  `cpe:2.3:a:font_project:font:7.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.0`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.124:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.0:a1`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.0:b1`,
        fs:  `cpe:2.3:a:spip:spip:2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.0:rc1`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(28\)w5-32a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.1:b1`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.1:rc1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.48:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.2:b1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.2:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(1\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.2:rc2`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.3:b1`,
        fs:  `cpe:2.3:h:intel:server_board_s5000pal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.5`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp:4.3.6`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.0:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp_client:-`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp_client:1.0`,
        fs:  `cpe:2.3:a:f-secure:safe_anywhere:-:-:-:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp_client:2.0`,
        fs:  `cpe:2.3:a:microsoft:ie:6.0.2800.1106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcp_client:3.0b1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:2.0.pl5`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3a10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:2.0pl5`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc1`,
        fs:  `cpe:2.3:o:ibm:aix:5.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc10`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc11`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.3:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc12`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p388:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc13`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc14`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc2`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc3`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc4`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc5`,
        fs:  `cpe:2.3:a:epson:print_cd:1.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc6`,
        fs:  `cpe:2.3:o:cisco:ios:11.0\(18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc7`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0.1:rc9`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0_b2pl9`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0052:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0_b2pl23`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0_pl1`,
        fs:  `cpe:2.3:a:drupal:drupal:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dhcpd:3.0_pl2`,
        fs:  `cpe:2.3:a:bir.gov.ph:alphalist_data_entry_and_validation:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dnsco_bind:9.9.3:s1`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_supportcenter_plus:7.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dnsco_bind:9.9.3:s1-p1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dnsco_bind:9.9.4:b1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:dnsco_bind:9.9.4:s1b1`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.27.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1009:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.4sec`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.4sec2`,
        fs:  `cpe:2.3:o:juniper:junos:13.1:r4-s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.4unoff3`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.4unoff4`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.5`,
        fs:  `cpe:2.3:a:scansoft:smart_document_scan_software:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.5.1`,
        fs:  `cpe:2.3:a:digium:asterisk:14.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.7`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:1.7.2`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controllers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:2.0`,
        fs:  `cpe:2.3:a:ansys:ls-dyna:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:2.1`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:2.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p51:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:2.2.1`,
        fs:  `cpe:2.3:a:python:python:3.3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:2.2.2`,
        fs:  `cpe:2.3:a:samba:samba:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:2.2.3`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:inn:2.4.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:kea:0.9.2`,
        fs:  `cpe:2.3:h:hp:zbook_15u_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isc:kea:1.0.0:beta`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iscripts:autohoster:2.4`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.3.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iscripts:easybiller:1.1`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iscripts:easybiller:1.2`,
        fs:  `cpe:2.3:a:oracle:siebel_crm:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iscripts:eswap:2.0`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_400_color_printer_m451:ce958a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.5.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.427:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.5.3`,
        fs:  `cpe:2.3:a:call-cc:chicken:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.5.5`,
        fs:  `cpe:2.3:o:cisco:ios:11.0\(22b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.5.6`,
        fs:  `cpe:2.3:a:koha:koha:3.16.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.5.6.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.5.6.2`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.0.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.1`,
        fs:  `cpe:2.3:a:symantec:norton_utilities:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.2`,
        fs:  `cpe:2.3:a:ca:unicenter_service_fulfillment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.634:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.4`,
        fs:  `cpe:2.3:a:skype:skype:5.0.0.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.5`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.5.1`,
        fs:  `cpe:2.3:a:apple:cups:1.1.19:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.6`,
        fs:  `cpe:2.3:a:ptc:creo_view:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishii:pukiwikimod:1.6.7.1`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishikawa_mutsumi:kon2:-`,
        fs:  `cpe:2.3:a:digi:www_server:compieuw:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ishikawa_mutsumi:kon2:0.3.9`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:islamicode:radio_bethlehem_rb2000:1::~~~android~~`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:islonline:isl_desktop_plugin:1.3.3:-:~-~windows~isl_light~~`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:islonline:isl_desktop_plugin:1.4.1:-:~-~windows~isl_light~~`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:islonline:isl_desktop_plugin:1.4.2:-:~-~windows~isl_light~~`,
        fs:  `cpe:2.3:a:t1lib:t1lib:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:islonline:isl_desktop_plugin:1.4.3:-:~-~windows~isl_light~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:islonline:isl_desktop_plugin:1.4.7:-:~-~windows~isl_light~~`,
        fs:  `cpe:2.3:a:apache:camel:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:islonline:isl_light:3.5.4`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:islonline:isl_light_remote_desktop:2.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:scilab:scilab:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isobuster:isobuster:2.8`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isode:m-link:14.6`,
        fs:  `cpe:2.3:a:securecomputing:securityreporter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isode:m-link:14.6.14`,
        fs:  `cpe:2.3:a:ibm:infosphere_import_export_manager:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isode:m-link:15.1`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isode:m-link:15.1.10`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:isode:m-link:16.0`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice:-`,
        fs:  `cpe:2.3:a:ibm:director:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent:-`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent:2.0.23`,
        fs:  `cpe:2.3:a:prosody:prosody:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent:3.0`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:4.21.1088:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent:3.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent:3.1eal`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je167a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent:3.1ebh`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.18.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_server:3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_server:3.1`,
        fs:  `cpe:2.3:a:realtek:realtek_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_server:3.6:ebz`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_server:3.6:eca`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_server:3.6:ecb`,
        fs:  `cpe:2.3:a:google:v8:3.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_server:3.6:ecd`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_server:3.6:ece`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg810-10:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_server:3.6:ecf`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_workstation:3.0`,
        fs:  `cpe:2.3:a:gnu:iceweasel:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_workstation:3.1`,
        fs:  `cpe:2.3:a:apple:itunes:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_workstation:3.1:eal`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_for_workstation:31:ebh`,
        fs:  `cpe:2.3:a:adobe:help_viewer:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_server:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.12:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_server:3.6ebz`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_server:3.6eca`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:7.2.5:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_server:3.6ecb`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.2919.3800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_server:3.6ecc`,
        fs:  `cpe:2.3:a:gotobestofprice:thai_food:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_server:3.6ecd`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_server:3.6ece`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_agent_server:3.6ecf`,
        fs:  `cpe:2.3:o:google:chrome_os:0.9.130.14:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_defender:-`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_defender:2.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_defender:2.9`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_defender:2.9:cap`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_defender:2.9cap`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:-`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:01-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cbd`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cbr`,
        fs:  `cpe:2.3:a:python:python:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cbz`,
        fs:  `cpe:2.3:a:google:chrome:14.0.812.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cca`,
        fs:  `cpe:2.3:a:libetpan_project:libetpan:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6ccb`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6ccc`,
        fs:  `cpe:2.3:a:cisco:pix_firewall_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6ccd`,
        fs:  `cpe:2.3:a:digia:qt:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cce`,
        fs:  `cpe:2.3:a:cisco:cisco_policy_suite:7.0.2-att:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6ccf`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6ccg`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cpie`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cpj`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.05:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cpk`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cpn`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_pc_protection:3.6cpu`,
        fs:  `cpe:2.3:a:palo_alto_networks:traps:3.1.2.1546:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.5.cdf`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:6.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.5cdf`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:9.0.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6cbz`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6cca`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6ccb`,
        fs:  `cpe:2.3:a:horde:imp:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6ccc`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6ccd`,
        fs:  `cpe:2.3:a:ibm:social_media_analytics:1.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6cce`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6ccf`,
        fs:  `cpe:2.3:a:skyarc:entryimexporter:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6ccg`,
        fs:  `cpe:2.3:a:augeas:augeas:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6cch`,
        fs:  `cpe:2.3:a:acronis:license_server:3.0.3470:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6cno`,
        fs:  `cpe:2.3:a:condor_project:condor:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:blackice_server_protection:3.6cpk`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:internet_scanner:-`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:internet_scanner:6.2.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.6:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:internet_scanner:7.0`,
        fs:  `cpe:2.3:a:mysql:mysql:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:internet_scanner:7.2`,
        fs:  `cpe:2.3:a:exim:exim:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:internet_security_scanner:-`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia:-`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:20.11`,
        fs:  `cpe:2.3:a:apache:roller:0.9.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:20.15`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.3`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.2919.800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.5`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.6`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.7`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.8`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.9`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.10`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.11`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_a_series_xpu:22.12`,
        fs:  `cpe:2.3:a:ibm:websphere_cast_iron_solution:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:proventia_desktop:-`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:proventia_desktop:8.0.675.1790`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:proventia_desktop:8.0.812.1790`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.2`,
        fs:  `cpe:2.3:a:altova:xmlspy_2012:0.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.3`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.4`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.5`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.6`,
        fs:  `cpe:2.3:a:emerson:deltav:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.7`,
        fs:  `cpe:2.3:a:google:chrome:12.0.715.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.10`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.11`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_g_series_xpu:22.12`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:-`,
        fs:  `cpe:2.3:a:xnview:xnview:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.1`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5137-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.2`,
        fs:  `cpe:2.3:a:schneems:wicked:0.5.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.4`,
        fs:  `cpe:2.3:h:cisco:spa_303:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.5`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.6`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.04.4197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.7`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.8`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.9`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.10`,
        fs:  `cpe:2.3:a:oracle:java_dynamic_management_kit:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_m_series_xpu:1.30`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_server:-`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:iss:proventia_server:1.0.914.1880`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:rally_albania_live_2014:0.11::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure:-`,
        fs:  `cpe:2.3:a:paul_lesniewsk:autocomplete:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure:3.2.1`,
        fs:  `cpe:2.3:a:grasshopper:grasshopper_beta:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure:3.2.2`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:-`,
        fs:  `cpe:2.3:a:veoh:veoh_web_player:1.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:3.6`,
        fs:  `cpe:2.3:a:vmware:player:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:3.6ebz`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:3.6eca`,
        fs:  `cpe:2.3:a:netwin:surgeftp:1.1h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:3.6ecb`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:3.6ecd`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:3.6ece`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.0\(1\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:3.6ecf`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:7.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:3.6ecg`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_collaboration_server:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0eba`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ebf`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ebg`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ebh`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ebj`,
        fs:  `cpe:2.3:a:x.org:x11:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ebk`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ebl`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ebm`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.9.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ebr`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0ecb`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_desktop:7.0epk`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_event_collector:-`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_event_collector:6.5`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:-`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ebr`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ebs`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ebt`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ebu`,
        fs:  `cpe:2.3:a:google:chrome:17.0.932.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ebv`,
        fs:  `cpe:2.3:a:digium:asterisk:11.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ebw`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ebx`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:eby`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ebz`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:eca`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ecb`,
        fs:  `cpe:2.3:a:apache:log4j:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ecc`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ecd`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ece`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ecf`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.8:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6:ecg`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6ebr`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6ebz`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta31:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6eca`,
        fs:  `cpe:2.3:a:intel:network_connections:15.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6ecb`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6ecc`,
        fs:  `cpe:2.3:h:hp:0235a0c2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6ecd`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6ece`,
        fs:  `cpe:2.3:a:apache:knox:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6ecf`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_guard:3.6ecg`,
        fs:  `cpe:2.3:a:f5:big-ip_configuration_utility:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_network:-`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_network:7.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_network_sensor:-`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_network_sensor:7.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_nokia:-`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_nokia:6.0`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:-`,
        fs:  `cpe:2.3:a:apple:remote_desktop:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ebr`,
        fs:  `cpe:2.3:h:cisco:sg300-10mp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ebs`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p332:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ebt`,
        fs:  `cpe:2.3:a:apache:camel:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ebu`,
        fs:  `cpe:2.3:a:ibm:spss_data_collection:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ebv`,
        fs:  `cpe:2.3:a:grouperahal:karim_rahal_essoulami:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ebw`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ebx`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:eby`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ebz`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:eca`,
        fs:  `cpe:2.3:a:qemu:qemu:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ecb`,
        fs:  `cpe:2.3:a:macromedia:jrun:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ecc`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ecd`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ece`,
        fs:  `cpe:2.3:a:irssi:irssi:0.8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ecf`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6:ecg`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:1.0.3085.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6ebz`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6eca`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:sp2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6ecb`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.0-118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6ecc`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6ecd`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6ece`,
        fs:  `cpe:2.3:a:xnview:xnview:1.17:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6ecf`,
        fs:  `cpe:2.3:a:akunamachata:paypal_express_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_sentry:3.6ecg`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_server_sensor:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.16:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_server_sensor:5.5`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_server_sensor:6.0`,
        fs:  `cpe:2.3:h:netgear:wgt624:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_server_sensor:6.0.1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_server_sensor:6.5`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_server_sensor:7.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_server_sensor:7.0:sr4.3`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_server_sensor:7.0:sr4.4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_workgroup_manager:-`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_workgroup_manager:6.6`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:realsecure_workgroup_manager:6.7`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp2:srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:site_protector_security_fusion:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:site_protector_security_fusion:2.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.15:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iss:siteprotector_console:2.7.0`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:7.3.0.118:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:cf06:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.0:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.0:-:commercial`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.0:-:core`,
        fs:  `cpe:2.3:a:commerce_balanced_payments_project:commerce_balanced_payments:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.0:a`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.0:a:commercial`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.0:a:core`,
        fs:  `cpe:2.3:a:microsoft:outlook:2010:sp2:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:-`,
        fs:  `cpe:2.3:a:webmin:webmin:1.720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:-:commercial`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_client:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:-:core`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12.05\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:a`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.12:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:a:commercial`,
        fs:  `cpe:2.3:a:percipientstudios:imagen:2.5.1:-:*:*:*:umbraco_cms:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:a:core`,
        fs:  `cpe:2.3:a:socketmail:socketmail:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:b`,
        fs:  `cpe:2.3:a:facebook:bite_it\!:1.1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:b:commercial`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.1:b:core`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0516:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.2:-`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.2:-:commercial`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.2:-:core`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.2:a`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0199:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.2:a:commercial`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:9.0.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itd-inc:bingo%21cms:1.2:a:core`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ite:smart_guardian:2.0`,
        fs:  `cpe:2.3:a:time_tracker_project:time_tracker:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:itechscripts:itechclassifieds:3.03.057`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itechscripts:proman_xpress:5.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.3.300.273:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ithoughts:ithoughtshd:4.19::~~~iphone_os~ipad~`,
        fs:  `cpe:2.3:a:vmware:update_manager:1.0.0.63985:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itiw-webdev:dino_village:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itography:itography_item_hunt:3.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itp:harpers_bazaar_art:%407f080181::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.5.1:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itriagehealth:itriage_health:5.29::~~~android~~`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itt:spectrum_xxi_management_utility:2.0.3.0`,
        fs:  `cpe:2.3:h:xerox:workcentre:m133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itu:ap7capture:1.0.6`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itu:space_validation:6.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.435:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itu:srsfix:6.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(24\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:itwitter_project:itwitter:0.04::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:data_protection:6.3:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:ivanjaros:feed_block:6.x-1.0`,
        fs:  `cpe:2.3:a:avaya:web_messenger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ivanjaros:feed_block:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:apple:software_update:2.1.3.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ivanjaros:feed_block:6.x-1.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\)ea5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ivanjaros:feed_block:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:cisco:expressway_software:x7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iveo:iveo_viewer:1.0.0`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iversemedia:archie_comics:1.07::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:iwcn:stark_crm:1.0`,
        fs:  `cpe:2.3:a:iomega:hotburn:2.3:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:aptixia_ixautomate:6.40.41.11`,
        fs:  `cpe:2.3:h:cisco:catalyst_2955:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:aptixia_ixnetwork:5.30.90.62`,
        fs:  `cpe:2.3:a:apache:struts:2.2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:ixautomateapi:6.30.24.24`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs4_support:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:ixia_appinfo:1.0.0.22`,
        fs:  `cpe:2.3:h:siemens:synco_ozw_web_server:ozw672.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:ixia_tcl:8.4.14.7`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:ixialicensing:2.50.1.19`,
        fs:  `cpe:2.3:a:emc:documentum_administrator:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:ixloadlite:3.30.66.9`,
        fs:  `cpe:2.3:a:keepass:keepass:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:ixos_easp1:5.20.400.6`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixiacom:ixreporter:4.0.20.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ixonos:checksum_tool:0.7.0`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.19.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:izarc:izarc:4.1.8`,
        fs:  `cpe:2.3:a:hp:network_node_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:j%21extensions_store:jchatsocial:2.2::~~~joomla%21~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:j2k-codec:j2k-codec:-`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabber2:jabberd2:2.1.19`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.1`,
        fs:  `cpe:2.3:a:adobe:drive_cs4:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.2`,
        fs:  `cpe:2.3:a:horde:imp:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.5`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.6`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.9:rc10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.7`,
        fs:  `cpe:2.3:a:ecava:integraxor:3.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.8`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.9`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.10`,
        fs:  `cpe:2.3:a:f5:arx:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.11`,
        fs:  `cpe:2.3:a:ca:siteminder:12.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.12`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.13`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7a\)e6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.15`,
        fs:  `cpe:2.3:o:cisco:staros:18.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.16`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.17`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.18`,
        fs:  `cpe:2.3:a:netgenius:multilink:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.20`,
        fs:  `cpe:2.3:a:gnu:bash:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.21`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.22`,
        fs:  `cpe:2.3:a:webmin:usermin:1.530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.23`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.1.24`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.0`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.2`,
        fs:  `cpe:2.3:h:alcatel:speed_touch_home:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.3`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.4`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.5`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.6`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.7`,
        fs:  `cpe:2.3:a:john_koleszar:libvpx:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.7.1`,
        fs:  `cpe:2.3:a:samsung:web_viewer:1.0.0.193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:nl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.9`,
        fs:  `cpe:2.3:a:microsoft:outlook:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.10`,
        fs:  `cpe:2.3:h:cisco:mds_9700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.11`,
        fs:  `cpe:2.3:a:ibm:emptoris_program_management:10.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.12`,
        fs:  `cpe:2.3:a:conky:conky:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.13`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.14`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.15`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jabberd2:jabberd2:2.2.16`,
        fs:  `cpe:2.3:a:google:chrome:4.0.244.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jahia:jahia_xcm:6.6.1`,
        fs:  `cpe:2.3:a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:jahia:jahia_xcm:6.6.2`,
        fs:  `cpe:2.3:h:cisco:nexus_93120tx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jakweb:gecko_cms:2.2`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jakweb:gecko_cms:2.3`,
        fs:  `cpe:2.3:a:stage_file_proxy_project:stage_file_proxy:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jam-software:treesize:2.2.1::~~free~~~`,
        fs:  `cpe:2.3:h:huawei:nip6300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jam-software:treesize:2.43::~~professional~~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jam-software:treesize:5.4.4::~~professional~~~`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jamalbates:jamal_bates_show:1.3.14.254::~~~android~~`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jambatan_pbb_semporna_project:jambatan_pbb_semporna:13523.82613::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:49.0.2623.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jamroom:search_module:1.0.0`,
        fs:  `cpe:2.3:o:hp:mpe_ix:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jamroom:search_module:1.1.0`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:2.1.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jamroom:search_module:1.1.1`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jamroom:search_module:1.2.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_bednarik:cooluri:1.0.20`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_bednarik:cooluri:1.0.30`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.2:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_bednarik:cooluri:1.0.31`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_bednarik:cooluri:1.0.32`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall_1:4.1.0:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_bednarik:cooluri:1.0.33`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.10.0`,
        fs:  `cpe:2.3:a:kana:iq:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.10.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.10.2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.15`,
        fs:  `cpe:2.3:a:lxml:lxml:2.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.17`,
        fs:  `cpe:2.3:h:triplc:nano-10_plc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.22`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.23`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.25`,
        fs:  `cpe:2.3:a:redhat:interchange:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.26`,
        fs:  `cpe:2.3:a:ssh:tectia_manager:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.27`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:1.28`,
        fs:  `cpe:2.3:a:apple:cups:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.0`,
        fs:  `cpe:2.3:a:softerra:ldap_administrator:3.5.0.1750:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.2`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.17.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.3`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_out_of_band_management_solution:6.2.1004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.4`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.6`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.7`,
        fs:  `cpe:2.3:a:augeas:augeas:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.8`,
        fs:  `cpe:2.3:a:gnome:glib:2.21.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:2.9`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:3.0`,
        fs:  `cpe:2.3:a:gnu:emacs:23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:3.0.1`,
        fs:  `cpe:2.3:a:irata:authorize.net_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:3.1`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.18.4762:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:3.2`,
        fs:  `cpe:2.3:a:hp:shared_trace_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:3.3`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.29-25.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:3.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:3.5`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_engelhardt:libhx:3.6`,
        fs:  `cpe:2.3:a:agilebits:knox:1.5.1:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:2.0`,
        fs:  `cpe:2.3:a:adobe:csi_cs4:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:199:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01:pre2`,
        fs:  `cpe:2.3:a:redhat:pam_smb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01:pre3`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01:pre4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01:pre5`,
        fs:  `cpe:2.3:a:symantec:veritas_gridnode_agent:5.0.433:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01:pre6`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01:pre7`,
        fs:  `cpe:2.3:a:vmware:server:2.0.0.2712:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01:pre8`,
        fs:  `cpe:2.3:a:acme:thttpd:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.01:pre9`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.02`,
        fs:  `cpe:2.3:a:hp:sendmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.03`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:10.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.04`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.05`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.06`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.07`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.08`,
        fs:  `cpe:2.3:a:hp:document_viewer:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.09`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.10`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.11`,
        fs:  `cpe:2.3:a:david_king:vino:3.1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.12`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.13`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.14`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.035_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.15`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_kara:linux_diskquota:3.16`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_schutze:truc:0.9.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.23.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_schutze:truc:0.10.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.437.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_schutze:truc:0.11.0`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jan_schutze:truc:0.12.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.0.0.0`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:1.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.1.0.0`,
        fs:  `cpe:2.3:h:netgear:r7300dst:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.2.0.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.2.1.0`,
        fs:  `cpe:2.3:a:adobe:adobe_php_ria_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.3.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.590:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.4.0.0`,
        fs:  `cpe:2.3:a:vevo:vevo-watch_hd_music_videos:2.0.27:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.5.0.0`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.6.0.0`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.6.1.0`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.6.2.0`,
        fs:  `cpe:2.3:a:freetype:freetype:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.6.3.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.7.0.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.7.1.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:1.7.2.0`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.0.0.1`,
        fs:  `cpe:2.3:a:sophos:disk_encryption:5.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.0.1.0`,
        fs:  `cpe:2.3:a:pwgen_project:pwgen:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.0.2.0`,
        fs:  `cpe:2.3:a:allplayer:allplayer:5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.0.3.0`,
        fs:  `cpe:2.3:a:yahoo:yui:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.1.0.0`,
        fs:  `cpe:2.3:a:avast:internet_security:11.1.2253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.1.1.0`,
        fs:  `cpe:2.3:h:ibm:bladecenter:hx5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.1.1.1`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.1.1.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.2.0.0`,
        fs:  `cpe:2.3:h:huawei:quidway_s9700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.3.0.0`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.4.0.0`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.5.0.0`,
        fs:  `cpe:2.3:h:intel:active_management_technology:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:2.5.1.0`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.0.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.6:2.6.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.1.0.0`,
        fs:  `cpe:2.3:h:huawei:usg9500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.1.0.1`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.1.1.0`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.2.0.0`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.2.1.0`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.0.56.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.2.1.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.3.0.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janesoft:janetter:3.4.0.0`,
        fs:  `cpe:2.3:a:sebastien_sauvage:webgobbler:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.0.0.0`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.1.0.0`,
        fs:  `cpe:2.3:h:cisco:nexus_5624q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.2.0.0`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:08-00\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.2.1.0`,
        fs:  `cpe:2.3:a:perl:perl:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.3.0.0`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.4.0.0`,
        fs:  `cpe:2.3:a:autodesk:building_systems:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.5.0.0`,
        fs:  `cpe:2.3:a:gnu:emacs:21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.6.0.0`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.6.1.0`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.3.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.6.2.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.6.3.0`,
        fs:  `cpe:2.3:a:commdevices:secure_session_manager:4.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.7.0.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.7.1.0`,
        fs:  `cpe:2.3:o:checkpoint:gaia_os:r70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:1.7.2.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.223.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.0.0.1`,
        fs:  `cpe:2.3:h:kyocera:ah-k3001v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.0.1.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.0.1.152:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.0.2.0`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.0.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.1.0.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.1.1.0`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.1.1.1`,
        fs:  `cpe:2.3:a:matthew_fries:mf_gig_calendar:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.1.1.2`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.6.0.453:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.2.0.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.3.0.0`,
        fs:  `cpe:2.3:o:cisco:cisco_ons_15454_system_software:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.4.0.0`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.5.0.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:2.5.1.0`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.0.0.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.1.0.0`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.1.0.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.1.1.0`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.2.0.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.2.1.0`,
        fs:  `cpe:2.3:h:cisco:dpc2203:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.2.1.1`,
        fs:  `cpe:2.3:h:hp:pusb_thermal_receipt_printer_f7m67aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.3.0.0`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.2:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:janetter:janetter:3.4.0.0`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:php-openid:2.2.2`,
        fs:  `cpe:2.3:a:dns-sync_project:dns-sync:0.1.0:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.0:beta1`,
        fs:  `cpe:2.3:h:foundrynet:ironpoint_200_wireless_access_point:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.0:dev`,
        fs:  `cpe:2.3:a:hp:centralview_roaming_fraud_control:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.0:rc1`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.0:rc2`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.1:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)eo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.2`,
        fs:  `cpe:2.3:a:ibm:maximo_industry_solutions:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.2:rc2`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.3`,
        fs:  `cpe:2.3:a:couponphp:couponphp:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-1.4`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-2.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp4:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-2.1:beta1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.59:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-2.1:beta2`,
        fs:  `cpe:2.3:a:erlang:crypto:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-2.1:beta3`,
        fs:  `cpe:2.3:a:mybb:mybb:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-2.1:dev`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-2.1:rc1`,
        fs:  `cpe:2.3:a:hexchat_project:hexchat:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:6.x-2.2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:serena:business_mashups:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-1.0:rc2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.20:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0561:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-2.0`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-2.1`,
        fs:  `cpe:2.3:a:gnu:glibc:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-2.1:beta1`,
        fs:  `cpe:2.3:o:compal_broadband_networks:firmware:ch6640-3.5.11.7-nosh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-2.1:beta2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-2.1:beta3`,
        fs:  `cpe:2.3:o:cisco:ios_xr:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-2.1:rc1`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:rpx:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:ruby-openid:2.2.0:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager_for_vmware:3.2:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:ruby-openid:2.2.1:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:ruby-openid:2.2.2:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:ibm:java:6.0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:ruby-openid:2.2.3:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:process-one:ejabberd:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janrain:ruby-openid:2.3.0:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:o:suse:suse_linux:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.0`,
        fs:  `cpe:2.3:a:gnome:gnome-keyring:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.0.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.02:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.2.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.3`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.3.1`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:6.0:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.4`,
        fs:  `cpe:2.3:a:hp:hph_readme:70.0.260.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jansson_project:jansson:2.7`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:janusys:gridex_activex_control:2000b`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:japisoft:editix-free-xml_editor:2010`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.2`,
        fs:  `cpe:2.3:a:microsoft:works:4.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.3`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.3.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.3.2`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.1`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.8`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.10`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.11`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.12`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.13`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.7:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.14`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.15`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1081.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.16`,
        fs:  `cpe:2.3:a:phplist:phplist:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.17`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.18`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.19`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.646:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.20`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.21`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(55\)se4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.22`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.4.23`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)sz2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.5.1`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:0.6.0`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:10.6_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.0.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.0.1`,
        fs:  `cpe:2.3:h:huawei:s6300:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.1.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.1.1`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.1.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.1.3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-60:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.3.0:-`,
        fs:  `cpe:2.3:a:polycom:cma_system_software:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.3.0:rc1`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.3.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:phpcas:1.3.2`,
        fs:  `cpe:2.3:a:sun:openoffice.org:3.3.9567:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:uportal:4.0.13`,
        fs:  `cpe:2.3:a:acronis:license_server:11.0.17318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasig:uportal:4.0.13.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_a_donenfeld:cgit:0.9.1`,
        fs:  `cpe:2.3:o:schneider-electric:modicon_m221_firmware:1.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_a_donenfeld:cgit:0.9.2`,
        fs:  `cpe:2.3:a:cisco:unified_ccx:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_flatt:basic_webmail:6.x-1.0`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.6.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_flatt:basic_webmail:6.x-1.1`,
        fs:  `cpe:2.3:a:sphider:sphider:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_flatt:basic_webmail:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ebiblio:ebiblio_andalucia:1.6.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_moore:amadou:6.x-1.0`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_moore:amadou:6.x-1.1`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_moore:amadou:6.x-1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_moore:amadou:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_savino:fp:7.x-1.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_savino:fp:7.x-1.1`,
        fs:  `cpe:2.3:h:hp:0235a390:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_savino:fp:7.x-1.2`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.5.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jason_sexauer:churchcms:0.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.47.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.1`,
        fs:  `cpe:2.3:a:autodesk:sketchbook_express:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.3`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.5`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.7`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r340.65:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.8`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.9`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.7.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.10`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.11`,
        fs:  `cpe:2.3:a:arcsight:arcsight_smartconnector:4.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.12`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.13`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.14`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.16`,
        fs:  `cpe:2.3:a:apple:motion:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.17`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.31.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.19`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.21`,
        fs:  `cpe:2.3:a:puppetlabs:puppetlabs-rabbitmq:3.0.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.22`,
        fs:  `cpe:2.3:a:apple:webkit:418.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.24`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.010.20059:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:1.900.29`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:2.0.6`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_vss_provider:13.0.5204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:2.0.9`,
        fs:  `cpe:2.3:a:apple:cups:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jasper_project:jasper:2.0.12`,
        fs:  `cpe:2.3:a:nuance:dragon_naturallyspeaking:11.0.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jaumo:chat_flirt_%26_dating_heart_jaumo:2.7.5::~~~android~~`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0.2112:unknown:online_windows_server_2003_x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:queue:1.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jayj:cakifo:1.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jazan_24_project:jazan_24:1::~~~android~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jazeeraairways:jazeera_airways:2.7::~~~android~~`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jce-tech:video_niche_script:4.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jcore:jcore:1.0:pre1`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jcore:jcore:1.0:pre2`,
        fs:  `cpe:2.3:a:perl:perl:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jdm_lifestyle_project:jdm_lifestyle:6.4::~~~android~~`,
        fs:  `cpe:2.3:a:apache:subversion:0.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.7`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.7:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.8:a1`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cca:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.9`,
        fs:  `cpe:2.3:a:ibm:filenet_content_services_client_libraries:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.10`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.1.v0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.11`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.11:a1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.11:a2`,
        fs:  `cpe:2.3:a:cisco:webns:7.20.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.12`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.2:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:jean-paul_calderone:pyopenssl:0.13.1`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.1`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.2`,
        fs:  `cpe:2.3:a:ibm:spss_analytical_decision_management:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.3`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.26:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.4`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.115.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.6`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.7`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.8`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:0.9`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1289.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.1`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:0.9.7:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.2`,
        fs:  `cpe:2.3:a:apple:itunes:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(3\)m3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:16.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.5`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.6`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.7`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.8`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:1.9`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.1`,
        fs:  `cpe:2.3:a:fujitsu:interstage_application_server:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.2`,
        fs:  `cpe:2.3:a:php:php:5.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.4`,
        fs:  `cpe:2.3:a:picketlink:picketlink:2.7.0:cr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.5`,
        fs:  `cpe:2.3:a:ibm:algo_one:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.6`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1675.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.7`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.8`,
        fs:  `cpe:2.3:h:hp:sn6000_stackable_8gb_12-port_single_power_fibre_channel_switch:bk780a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jease:jease:2.9`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jedit:jedit:4.3.2`,
        fs:  `cpe:2.3:o:ibm:aix:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:hostscan_engine:3.1\(.05183\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:h:swann:srnvw-470lcd_firmware:0114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:operations_manager:9.21:*:*:*:*:linux:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.27:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sun:java_db:10.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:japisoft:editix-free-xml_editor:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mcafee:antispyware:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.0.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.12.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:319.00:-:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:word:2010:sp1:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fedoraproject:anaconda:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:posh_project:posh:2.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:magzter:india_today_telugu:3.02:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:struts:2.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.14::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.1.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:plataformatec:devise:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rmcproject:pm_fastrack:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:forms:10g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:iprint:5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tc3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_kreitner:hms-testimonials:2.2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.0\(2k\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.1`,
        fs:  `cpe:2.3:h:huawei:s7712:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.2`,
        fs:  `cpe:2.3:o:hp:mpe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.4`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.5`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.6`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.7`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.8`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.2.9`,
        fs:  `cpe:2.3:o:yahama:rta54i:4.04.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.2`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.3`,
        fs:  `cpe:2.3:a:gajim:gajim:0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(6c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.5`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.6`,
        fs:  `cpe:2.3:h:apple:imac:ma456xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.7`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.3.9`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_ortel:suds:0.4`,
        fs:  `cpe:2.3:a:suriname_radio_project:suriname_radio:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.1`,
        fs:  `cpe:2.3:a:hp:visualize_conference_ftp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.1.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.2`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.3`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.4`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-35-\/f:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.4.1`,
        fs:  `cpe:2.3:o:cisco:aireos:4.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.5`,
        fs:  `cpe:2.3:h:huawei:s3300:v100r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.6`,
        fs:  `cpe:2.3:a:icinga:icinga:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.7`,
        fs:  `cpe:2.3:a:magzter:where_atlanta:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.7.1`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.7.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.7.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:0.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.8`,
        fs:  `cpe:2.3:a:percipientstudios:imagen:2.9.0:-:*:*:*:umbraco_cms:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.8.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.8.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.8.3`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:0.9`,
        fs:  `cpe:2.3:a:apache:struts:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:1.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd011a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:1.1`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_agent:10.0.11639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:1.2`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:1.2.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:1.2.2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.8:bundle10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:1.2.3`,
        fs:  `cpe:2.3:a:novell:groupwise:7.02:hp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:4.0.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.1.1`,
        fs:  `cpe:2.3:o:mandriva:business_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.1.2`,
        fs:  `cpe:2.3:o:vmware:esxi:4.0:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.1.3`,
        fs:  `cpe:2.3:a:adobe:dreamweaver_mx:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.2.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.3`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_device_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.3.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.3.2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.3.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.4`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.5.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5`,
        fs:  `cpe:2.3:h:3com:3c16486:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.2`,
        fs:  `cpe:2.3:o:novell:netware:5.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.3`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.4`,
        fs:  `cpe:2.3:a:google:chrome:15.0.862.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.5`,
        fs:  `cpe:2.3:a:emc:networker:8.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.6`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.7`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.834:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.8`,
        fs:  `cpe:2.3:a:nih:libzip:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeff_sterup:plugin-organizer:2.5.9`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.07.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jellytap:free_app_icons_%26_icon_packs:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:hp:openview_process_control:1.50.250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:1.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.00:-:*:*:*:windows_server_2008:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:1.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:1.8.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:1.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:acquia:commons:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:1.6.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p213:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:1.9.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.9.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(4i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:20.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.2.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tibco:enterprise_administrator_sdk:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.5::~~~jenkins~~`,
        fs:  `cpe:2.3:o:d-link:dap-2695_firmware:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.5.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.6.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:juniper:junos_pulse_access_control_service:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.6.2::~~~jenkins~~`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.7::~~~jenkins~~`,
        fs:  `cpe:2.3:a:serf_project:serf:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.7.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.7.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:facebook:face_fun_photo_collage_maker_2:1.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.7.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.7.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.7.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:marked_project:marked:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.8.1::~~~jenkins~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.9.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.9.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.9.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:oracle:database_server:8.1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.10.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.10.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.11::~~~jenkins~~`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-2.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.12::~~~jenkins~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.13::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p426:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.14:beta:~~~jenkins~~`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2015-ac-ovs-i-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.14.1:beta:~~~jenkins~~`,
        fs:  `cpe:2.3:h:apple:iphone:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.14.2:beta:~~~jenkins~~`,
        fs:  `cpe:2.3:h:lexmark:x65x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15::~~~jenkins~~`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:pgp:corporate_desktop:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15.2:beta:~~~jenkins~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:x2engine:x2crm:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15.3:beta:~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)sqd5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15.6::~~~jenkins~~`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.15.7::~~~jenkins~~`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.16.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.16.1::~~~jenkins~~`,
        fs:  `cpe:2.3:o:juniper:junos:10.4r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.16.2::~~~jenkins~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je031a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.16.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:adobe:japanese_fonts_support_for_adobe_reader:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:config_file_provider:2.16.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.07.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ctb:tabe-pc:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:binarymoon:timthumb:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.1.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:vmware:tools:9.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.2.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.3.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1684.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.4.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tenable:nessus:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.4.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.5.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.5.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.5.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ubercart_views_project:uc_views:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.5.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3\(.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.5.4::~~~jenkins~~`,
        fs:  `cpe:2.3:o:iij:seil\%2fb1_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.5.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.5.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:actividentity:corestreet_desktop_validation_client:2.1.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.5.7::~~~jenkins~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.14.159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.6.0::~~~jenkins~~`,
        fs:  `cpe:2.3:h:siemens:scalance_x202-4p_irt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:datadog:0.6.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:oracle:business_intelligence_publisher:11.1.1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.3.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.4.0::~~~jenkins~~`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v200r005c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.5.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.6.0::~~~jenkins~~`,
        fs:  `cpe:2.3:h:cisco:telepresence_ix5200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.7.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.7.1::~~~jenkins~~`,
        fs:  `cpe:2.3:h:cisco:cius:7-at-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.7.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:janetter:janetter:1.7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.7.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.480.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.8.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:icewall_file_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.8.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p105:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.8.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:4.2.0.5277:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.9.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.03:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.9.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:0.9.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.0.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.0.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:samba:samba:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:webns:7.2_0.0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:netscape:navigator:4.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.7::~~~jenkins~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.8::~~~jenkins~~`,
        fs:  `cpe:2.3:a:somcloud:somtodo_-_task\/to-do_widget:2.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.9::~~~jenkins~~`,
        fs:  `cpe:2.3:a:redhat:icedtea:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.10::~~~jenkins~~`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.11::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.12::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:worklight:6.0.0.2:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.13::~~~jenkins~~`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.14::~~~jenkins~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.15::~~~jenkins~~`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.16::~~~jenkins~~`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.17::~~~jenkins~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.18::~~~jenkins~~`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.0-h1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.19::~~~jenkins~~`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.20::~~~jenkins~~`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.21::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:2.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.22::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apple:cups:1.1.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.23::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.24::~~~jenkins~~`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.25::~~~jenkins~~`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.0:alpha-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.26::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:web_content_manager:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.27::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.28::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:performance_center:12.00:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.1.29::~~~jenkins~~`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:5.1:r1e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.3.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.4.0::~~~jenkins~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:gold:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.5.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.5.53896.424:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:1.6.0:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5204a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.0::~~~jenkins~~`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.5.50.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.0:alpha-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:webns:8.20.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.0:alpha-2:~~~jenkins~~`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.0:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(26b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.0:beta-3:~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.5\(1\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:webns:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.0.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2705:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:r54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:pocketmags:terrorizer_magazine:\@7f08017a:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apache:shiro:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.7::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.8::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.9::~~~jenkins~~`,
        fs:  `cpe:2.3:h:apple:iphone:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.10::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.11::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.2.12::~~~jenkins~~`,
        fs:  `cpe:2.3:a:adobe:bridge:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:teradata:named_pipes_access_module:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.0:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.0:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs3:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.0:beta-3:~~~jenkins~~`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.0:beta-4:~~~jenkins~~`,
        fs:  `cpe:2.3:a:jruby:jruby:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:microsoft:orca:2.0.3790.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:rocklobster:contact_form_7:3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:allamericansportsware:common_controls_pack:1.01.0002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.3.5::~~~jenkins~~`,
        fs:  `cpe:2.3:h:cisco:catalyst_4500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.4.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.4.1::~~~jenkins~~`,
        fs:  `cpe:2.3:h:xerox:workcentre_m175:8.47.30.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.4.2::~~~jenkins~~`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.4.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.4.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.0:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.0:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:oracle:interaction_blending:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.0:beta-3:~~~jenkins~~`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.0:beta-4:~~~jenkins~~`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.0:beta-5:~~~jenkins~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.10:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.5.3::~~~jenkins~~`,
        fs:  `cpe:2.3:h:avaya:cajun_p130:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.6.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.6.1::~~~jenkins~~`,
        fs:  `cpe:2.3:h:symantec:nexland_wavebase_firewall_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.6.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.6.2:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.6.2:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.6.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:oracle:business_intelligence:11.2.1.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:2.6.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:8.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.0:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:cdotech:pics:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.0:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:php:php:7.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.1.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:wellintech:kinggraphic:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.2:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.2:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.3::~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.5-19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.0.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_real_time_system_manager:6.3.1006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:h:cisco:sf500-24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.2.226:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.3.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:double-take_software:double-take:5.2.2.1852.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.3.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.3.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.4.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.4.0:alpha-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:adgjm:angel_browser:1.76b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.4.0:alpha-4:~~~jenkins~~`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.4.0:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.4.0:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.4.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.5.0::~~~jenkins~~`,
        fs:  `cpe:2.3:h:cisco:ons_15600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.5.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:git:3.6.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p424:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:0.1:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:0.1:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1045:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:0.1:beta-3:~~~jenkins~~`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:0.1:beta-4:~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:spa8800_8-port_ip_telephony_gateway_firmware:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tips_and_tricks_hq:all_in_one_wordpress_security_and_firewall:3.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.11:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.4:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:redhat:jboss_fuse:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.7::~~~jenkins~~`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.8::~~~jenkins~~`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.8.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.9::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:1.10::~~~jenkins~~`,
        fs:  `cpe:2.3:a:galeriashqip:galeriashqip:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.23_bk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.0:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:o:yamaha:rt56v:4.07.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.0:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:pgp:desktop_for_mac:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.1:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:actividentity:activcard_gold_for_cac_feature_pack:3.01.2087.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.1:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.1:beta-3:~~~jenkins~~`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.1:beta-4:~~~jenkins~~`,
        fs:  `cpe:2.3:a:emc:documentum_administrator:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.1:beta-5:~~~jenkins~~`,
        fs:  `cpe:2.3:a:paragon-software:alignment_tool:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.1:beta-6:~~~jenkins~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.29:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.2::~~~jenkins~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.4::~~~jenkins~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.4:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:apple:safari:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.5::~~~jenkins~~`,
        fs:  `cpe:2.3:h:huawei:access_router:v200r002c01spc200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.7::~~~jenkins~~`,
        fs:  `cpe:2.3:a:kaseya:virtual_system_administrator:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.0.8::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(16\)b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.0:alpha-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.0:alpha-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:broadcom:management_programs:10.59.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.0:alpha-3:~~~jenkins~~`,
        fs:  `cpe:2.3:a:altitude:altitude_unified_customer_interaction:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.0:alpha-4:~~~jenkins~~`,
        fs:  `cpe:2.3:a:fortinet:connect:15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.0:beta-1:~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2_2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.0:beta-2:~~~jenkins~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.7:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:adobe:golive_cs2:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:github_branch_source:2.2.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1070.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.0.10`,
        fs:  `cpe:2.3:a:atutor:atutor:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.0.11`,
        fs:  `cpe:2.3:a:php:php:5.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.0.12`,
        fs:  `cpe:2.3:a:google:chrome:17.0.930.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.0.13`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.0.14`,
        fs:  `cpe:2.3:a:carel:plantvisorenhanced:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.0.15`,
        fs:  `cpe:2.3:o:juniper:junos_e:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.0.16`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.17`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.18`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.19`,
        fs:  `cpe:2.3:a:ibm:ims_enterprise_suite:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.20`,
        fs:  `cpe:2.3:a:opera:opera_browser:2.10:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.21`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.22`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.23`,
        fs:  `cpe:2.3:a:ixiacom:aptixia_ixautomate:6.40.41.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.24`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.25`,
        fs:  `cpe:2.3:h:alcatel:speed_touch_home:khdsaa.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.26`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec:10d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.27`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.28`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1668.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.30`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.31`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.32`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.33`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.34`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.8:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.35`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.36`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.37`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p174:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.38`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.39`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.40`,
        fs:  `cpe:2.3:h:compal_broadband_networks:cg6640e_wireless_gateway:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.41`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.42`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.64.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.43`,
        fs:  `cpe:2.3:a:vmware:workstation:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.44`,
        fs:  `cpe:2.3:o:cisco:ios:3.7.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.45`,
        fs:  `cpe:2.3:a:augeas:augeas:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.46`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.47`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.48`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:ga:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.49`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.50`,
        fs:  `cpe:2.3:h:breakingpointsystems:breakingpoint_storm_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.51`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.52`,
        fs:  `cpe:2.3:a:apache:sling_auth_core_component:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.53`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.54`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.55`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.56`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.57`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.58`,
        fs:  `cpe:2.3:a:tibco:formvine:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.59`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.60`,
        fs:  `cpe:2.3:a:mcafee:firewall_enterprise_admin_console:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.61`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.005:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.62`,
        fs:  `cpe:2.3:a:apache:maven_wagon:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.63`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.64`,
        fs:  `cpe:2.3:a:buffalotech:whr-g_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.65`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.66`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.8.1.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.67`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.1:rp1:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.68`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.69`,
        fs:  `cpe:2.3:h:axis:2400_video_server:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.70`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.71`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.72`,
        fs:  `cpe:2.3:a:color:icclib:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.73`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.74`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.3:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.75`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.7.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.76`,
        fs:  `cpe:2.3:h:xerox:workcentre_32_color:01.02.053.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.77`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass_policy_manager:6.3.0.60730:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.78`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.79`,
        fs:  `cpe:2.3:o:honeywell:excel_web_xl_1000c50_52_i\/o:2.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.80`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.81`,
        fs:  `cpe:2.3:a:dell:sonicwall_global_management_system:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.82`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.83`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.84`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.85`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg349a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.86`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.87`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.88`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.89`,
        fs:  `cpe:2.3:a:file_project:file:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.90`,
        fs:  `cpe:2.3:a:google:android_api:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.91`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.92`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.93`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.0.3.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.94`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.95`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.96`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.97`,
        fs:  `cpe:2.3:a:kamkomesan_project:kamkomesan:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.98`,
        fs:  `cpe:2.3:a:gnu:gv:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.99`,
        fs:  `cpe:2.3:a:kiosklogix:shellpro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.100`,
        fs:  `cpe:2.3:a:samba:samba:3.0.14:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.101`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3a\)e7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.102`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.103`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.104`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p443:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.105`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.106`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.802:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.107`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.108`,
        fs:  `cpe:2.3:a:cisco:cius_software:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.109`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.110`,
        fs:  `cpe:2.3:a:citrix:license_server_administration:4.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.111`,
        fs:  `cpe:2.3:a:time_tracker_project:time_tracker:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.112`,
        fs:  `cpe:2.3:a:compaq:survey_utility:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.113`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.19:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.114`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.115`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.2:cf1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.116`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.117`,
        fs:  `cpe:2.3:a:fingersoft:cartoon_camera:1.2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.118`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.119`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.120`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.121`,
        fs:  `cpe:2.3:a:adobe:cmaps:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.122`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2004:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.123`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.124`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.08.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.125`,
        fs:  `cpe:2.3:a:ibm:initiate_master_data_service:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.126`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.127`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.6.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.128`,
        fs:  `cpe:2.3:a:vmware:fusion:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.129`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.130`,
        fs:  `cpe:2.3:a:monotone:monotone:0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.131`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.132`,
        fs:  `cpe:2.3:a:submain:ghostdoc:2.5.9150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.133`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.134`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:07-52:-:standard:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.135`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.136`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.137`,
        fs:  `cpe:2.3:a:monotone:monotone:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.138`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.139`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.140`,
        fs:  `cpe:2.3:a:sun:grid_engine:6.0:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.141`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.0.0:rc:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.142`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.143`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.144`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.145`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.146`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.147`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.148`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.149`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b:pk1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.150`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.151`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.152`,
        fs:  `cpe:2.3:a:ibm:leads:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.153`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.154`,
        fs:  `cpe:2.3:h:axis:2400_video_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.155`,
        fs:  `cpe:2.3:h:zte:zxdsl_831cii:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.156`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.157`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:mobile:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.158`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.159`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.0.p-1.0.2.1-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.160`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.161`,
        fs:  `cpe:2.3:a:nortel:centrex_ip_client_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.162`,
        fs:  `cpe:2.3:h:hp:virtual_san_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.163`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.164`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_oracle_database:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.165`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.166`,
        fs:  `cpe:2.3:a:debian:apt:0.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.167`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_runtime_engine_for_.net_framework_4:13.0.1.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.168`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5404:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.169`,
        fs:  `cpe:2.3:a:mozilla:firefox:49.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.170`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.171`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.172`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.173`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.174`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.175`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.176`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_platform_emulator:2.5\(2\)ts4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.177`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.178`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.179`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.180`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.181`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.182`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.183`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.184`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.0.0:beta_11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.185`,
        fs:  `cpe:2.3:a:sun:sunone_starter_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.186`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.187`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.14:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.188`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.189`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.190`,
        fs:  `cpe:2.3:a:celluloidapp:celluloid:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.191`,
        fs:  `cpe:2.3:a:tenable:nessus:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.192`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:7.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.193`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_console:8.1.2.233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.194`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.195`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.196`,
        fs:  `cpe:2.3:a:aladdin:hasp_srm_run-time:3.10.1.6921:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.197`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.198`,
        fs:  `cpe:2.3:a:google:chrome:7.0.505.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.199`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.200`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.201`,
        fs:  `cpe:2.3:a:tincan:phplist:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.202`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.203`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.204`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.205`,
        fs:  `cpe:2.3:a:posh_project:posh:2.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.206`,
        fs:  `cpe:2.3:a:ibm:connections:1.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.207`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.209`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.210`,
        fs:  `cpe:2.3:a:apple:bonjour:1.0.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.211`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.6:mr6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.212`,
        fs:  `cpe:2.3:o:netgear:raidiator:4.2.24:-:-:*:-:-:readynas:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.213`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.214`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.215`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.216`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.4.110.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.217`,
        fs:  `cpe:2.3:a:clamav:clamav:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.218`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.3p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.219`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.220`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.221`,
        fs:  `cpe:2.3:h:hp:storevirtual_4730:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.222`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.223`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.224`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.225`,
        fs:  `cpe:2.3:a:hp:inode_management_center_pc:5.1:e0304:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.226`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.227`,
        fs:  `cpe:2.3:a:synology:video_station:1.5-0770:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.228`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.229`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.230`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.231`,
        fs:  `cpe:2.3:a:samba:samba:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.232`,
        fs:  `cpe:2.3:a:apache:camel:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.233`,
        fs:  `cpe:2.3:a:tenable:nessus:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.234`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.235`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.198:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.236`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.237`,
        fs:  `cpe:2.3:a:umn:mapserver:4.8:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.238`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.239`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.240`,
        fs:  `cpe:2.3:a:imapp:no_disturb:3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.241`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.242`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.243`,
        fs:  `cpe:2.3:a:oracle:providers_for_asp.net_help:11.1.720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.244`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.245`,
        fs:  `cpe:2.3:a:sybase:adaptive_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.247`,
        fs:  `cpe:2.3:a:samba:samba:1.9.17:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.248`,
        fs:  `cpe:2.3:a:lenovo:fingerprint_manager:8.01.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.249`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.250`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.251`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.252`,
        fs:  `cpe:2.3:a:axway:secure_messenger:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.253`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.254`,
        fs:  `cpe:2.3:a:ibm:data_protection:6.1.3.4:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.255`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.256`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.257`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.258`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.259`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.2:-:-:*:enterprise:-:-:compuset_engine`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.260`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.261`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.262`,
        fs:  `cpe:2.3:h:netgear:fvg318:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.263`,
        fs:  `cpe:2.3:a:bulbsecurity:smartphone_pentest_framework:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.264`,
        fs:  `cpe:2.3:o:d-link:dap-1350_firmware:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.265`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.266`,
        fs:  `cpe:2.3:a:fujitsu:interstage_studio:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.267`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.268`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.269`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.270`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.271`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.272`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.273`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_mid_tier:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.274`,
        fs:  `cpe:2.3:a:phpbridges_dev_team:phpbridges:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.275`,
        fs:  `cpe:2.3:a:microsoft:register_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.276`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.277`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.278`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.279`,
        fs:  `cpe:2.3:h:netgear:r7900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.280`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.281`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.282`,
        fs:  `cpe:2.3:a:jenkins:git:1.2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.283`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.284`,
        fs:  `cpe:2.3:a:web2py:web2py:1.99.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.285`,
        fs:  `cpe:2.3:a:quickzip:quick_zip:4.60.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.286`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.287`,
        fs:  `cpe:2.3:a:divx:codec:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.288`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.289`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.290`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.291`,
        fs:  `cpe:2.3:a:birebin:birebin.com_app:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.292`,
        fs:  `cpe:2.3:h:huawei:s2300:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.293`,
        fs:  `cpe:2.3:a:nuance:pdf_reader:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.294`,
        fs:  `cpe:2.3:a:postfix:postfix:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.295`,
        fs:  `cpe:2.3:o:cisco:vpn_3015_concentrator:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.296`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.297`,
        fs:  `cpe:2.3:a:1kxun:qianxun_yingshi:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.298`,
        fs:  `cpe:2.3:o:novell:suse_linux:9.3:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.299`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.300`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u6\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.301`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.302`,
        fs:  `cpe:2.3:h:cisco:ipvc-3520-gw-2b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.303`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2011.1025.2152.37348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.304`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_express:10.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.305`,
        fs:  `cpe:2.3:a:oracle:internet_expenses:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.306`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.307`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.308`,
        fs:  `cpe:2.3:h:hp:4000_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.309`,
        fs:  `cpe:2.3:a:drupal:drupal:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.310`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.311`,
        fs:  `cpe:2.3:h:d-link:dsr-150n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.312`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.313`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.314`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.315`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.316`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.317`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.318`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:4.0.4:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.319`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.320`,
        fs:  `cpe:2.3:a:steinberg:mymp3pro:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.321`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.92.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.322`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.323`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.324`,
        fs:  `cpe:2.3:a:hp:sitescope:11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.325`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.326`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:rc3:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.327`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.328`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.329`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_259_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.330`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.331`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1025:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.332`,
        fs:  `cpe:2.3:a:ca:unicenter_nsm_wireless_network_management_option:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.333`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.334`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.335`,
        fs:  `cpe:2.3:o:suse:suse_linux:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.336`,
        fs:  `cpe:2.3:a:microsoft:excel:97:sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.337`,
        fs:  `cpe:2.3:a:nero:essentials:7.2.8078:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.338`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.339`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.340`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.341`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.342`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.343`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.344`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.345`,
        fs:  `cpe:2.3:a:php:php:5.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.346`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.347`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers:2.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.348`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2002:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.349`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.350`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.351`,
        fs:  `cpe:2.3:a:vmware:workstation:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.352`,
        fs:  `cpe:2.3:o:sun:sunos:4.1psr_a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.353`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)bx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.354`,
        fs:  `cpe:2.3:a:sun:jdk:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.355`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.356`,
        fs:  `cpe:2.3:a:apple:safari:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.357`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.358`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.359`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.360`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.361`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.15.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.362`,
        fs:  `cpe:2.3:a:sun:jdk:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.363`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.364`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.365`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.366`,
        fs:  `cpe:2.3:a:isc:bind:8.2.3:t1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.367`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.368`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.369`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:1.0.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.370`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.371`,
        fs:  `cpe:2.3:a:gnu:gcc:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.372`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.373`,
        fs:  `cpe:2.3:a:dest-unreach:socat:2.0.0:b5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.374`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.283:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.375`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.376`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.377`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.378`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.379`,
        fs:  `cpe:2.3:h:extremenetworks:summit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.380`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.381`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.382`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-850:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.383`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.384`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.385`,
        fs:  `cpe:2.3:a:clamav:clamav:0.95:src2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.386`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.387`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.388`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.389`,
        fs:  `cpe:2.3:a:apache:hadoop:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.390`,
        fs:  `cpe:2.3:a:qemu:qemu:1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.391`,
        fs:  `cpe:2.3:a:luracast:restler:1.5.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.392`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:4.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.393`,
        fs:  `cpe:2.3:a:nvidia:display_driver:311.00:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.394`,
        fs:  `cpe:2.3:a:microsoft:step-by-step_interactive_training:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.395`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.396`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.397`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6ccb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.398`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.399`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.400`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.401`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.402`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.403`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.404`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.405`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.406`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.407`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.408`,
        fs:  `cpe:2.3:a:oracle:micros_cwdirect:17.018.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.409`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.409.1::~~lts~~~`,
        fs:  `cpe:2.3:a:monotone:monotone:0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.409.2::~~lts~~~`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.409.3::~~lts~~~`,
        fs:  `cpe:2.3:h:ibm:power_5:9118-575:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.410`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:7.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.411`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.412`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.413`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.414`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.415`,
        fs:  `cpe:2.3:a:roxio:media_manager:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.416`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.417`,
        fs:  `cpe:2.3:h:cisco:dpc3825:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.418`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.419`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.420`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.421`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.422`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.11.00039:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.423`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.424`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.424.1::~~lts~~~`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.424.2::~~lts~~~`,
        fs:  `cpe:2.3:a:ibm:worklight:6.0.0.0:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.424.3::~~lts~~~`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.424.4::~~lts~~~`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.424.5::~~lts~~~`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.5.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.424.6::~~lts~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.425`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.426`,
        fs:  `cpe:2.3:a:ibm:security_directory_server:6.3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.427`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.428`,
        fs:  `cpe:2.3:a:hp:network_virtualization:8.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.429`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.430`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.431`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.432`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.02:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.433`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:10.0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.434`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.435`,
        fs:  `cpe:2.3:a:embedthis:goahead:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.436`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.437`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.438`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.439`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.440`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.441`,
        fs:  `cpe:2.3:h:supermicro:x9drt-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.442`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)t12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.443`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.444`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:5.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.445`,
        fs:  `cpe:2.3:a:samba:samba:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.446`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.447`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd922a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.447.1::~~lts~~~`,
        fs:  `cpe:2.3:a:invensys:daserver_runtime_components:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.447.2::~~lts~~~`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.448`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.449`,
        fs:  `cpe:2.3:a:rutaexacta:ruta_exacta:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.450`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.451`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.452`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:7.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.453`,
        fs:  `cpe:2.3:a:xnview:xnview:1.96.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.454`,
        fs:  `cpe:2.3:a:perl:perl:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.455`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.456`,
        fs:  `cpe:2.3:a:emc:replistor:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.457`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.458`,
        fs:  `cpe:2.3:a:mapilab:advanced_security_for_outlook:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.459`,
        fs:  `cpe:2.3:a:yoshinori_tahara:mycaljp:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.460`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.461`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.462`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.463`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.464`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.465`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.466`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.466.1::~~lts~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.466.2::~~lts~~~`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.467`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.468`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.469`,
        fs:  `cpe:2.3:h:dell:precision_m4400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.470`,
        fs:  `cpe:2.3:h:xerox:colorqube_9201:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.471`,
        fs:  `cpe:2.3:a:microsoft:windows_messenger:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.472`,
        fs:  `cpe:2.3:a:cisco:content_security_management_appliance:8.3.6-039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.473`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.474`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.475`,
        fs:  `cpe:2.3:o:sun:solaris:2.6:hw5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.476`,
        fs:  `cpe:2.3:a:cloudera:hadoop:0.20.2\&#43;923.197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.477`,
        fs:  `cpe:2.3:a:webmin:usermin:1.051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.478`,
        fs:  `cpe:2.3:a:checkpoint:session_authentication_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.479`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.480`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:17.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.480.1::~~lts~~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.480.2::~~lts~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.480.3::~~lts~~~`,
        fs:  `cpe:2.3:a:oracle:applications_manager:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.480.3.1`,
        fs:  `cpe:2.3:a:perl:perl:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.481`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.482`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.4.5.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.483`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.484`,
        fs:  `cpe:2.3:a:ibm:data_studio:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.485`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.486`,
        fs:  `cpe:2.3:a:david_king:vino:2.7.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.487`,
        fs:  `cpe:2.3:a:ca:common_services:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.488`,
        fs:  `cpe:2.3:a:isc:dhcp:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.489`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.490`,
        fs:  `cpe:2.3:a:openx:openx:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.491`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.492`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_process_systems_with_cimplicity:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.493`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.494`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:9.0.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.495`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.496`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g02.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.497`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.498`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.499`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.500`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.501`,
        fs:  `cpe:2.3:h:dell:axim_x3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.502`,
        fs:  `cpe:2.3:h:d-link:dir505_shareport_mobile_companion:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.503`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.504`,
        fs:  `cpe:2.3:a:google:chrome:7.0.544.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.505`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.506`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.2:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.507`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:2.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.508`,
        fs:  `cpe:2.3:a:apache:cassandra:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.509`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:58.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.509.1::~~lts~~~`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.509.2::~~lts~~~`,
        fs:  `cpe:2.3:a:divx:player:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.509.3::~~lts~~~`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.509.4::~~lts~~~`,
        fs:  `cpe:2.3:a:dolphin-browser:dolphin_browser_cn:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.510`,
        fs:  `cpe:2.3:a:postfix:postfix:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.511`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.512`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.513`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.514`,
        fs:  `cpe:2.3:a:google:chrome:10.0.649.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.515`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.516`,
        fs:  `cpe:2.3:o:sun:solaris:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.517`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.518`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.519`,
        fs:  `cpe:2.3:a:google:chrome:4.0.229.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.520`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.521`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.1:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.522`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.523`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.524`,
        fs:  `cpe:2.3:a:icofx:icofx:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.525`,
        fs:  `cpe:2.3:o:cisco:ios:12.4yg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.526`,
        fs:  `cpe:2.3:a:logitech:videocall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.527`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.528`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.529`,
        fs:  `cpe:2.3:h:cisco:rv130w:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.530`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.531`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.532`,
        fs:  `cpe:2.3:a:xnview:xnview:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.532.1::~~lts~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.532.2::~~lts~~~`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.532.3::~~lts~~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.533`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:6.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.534`,
        fs:  `cpe:2.3:h:ibm:power_5:9407-515:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.535`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.536`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.537`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.538`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.539`,
        fs:  `cpe:2.3:a:hp:centralview_revenue_leakage_control:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.540`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.541`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.542`,
        fs:  `cpe:2.3:a:zeuscart:zeuscart:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.543`,
        fs:  `cpe:2.3:a:hp:hppfonts:1.1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.544`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd916a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.545`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20020913:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.546`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.547`,
        fs:  `cpe:2.3:a:ibm:lotus_expeditor:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.548`,
        fs:  `cpe:2.3:h:hp:cf367a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.549`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.0:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.550`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ecb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.551`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.552`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.553`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.554`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.554.1::~~lts~~~`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.554.2::~~lts~~~`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.554.3::~~lts~~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.555`,
        fs:  `cpe:2.3:o:cisco:ios:12.0w5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.556`,
        fs:  `cpe:2.3:a:posh_project:posh:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.557`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.558`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.559`,
        fs:  `cpe:2.3:h:cisco:anomaly_guard_module:5.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.560`,
        fs:  `cpe:2.3:a:civitasmedia:press-leader:1.0011.b0011:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.561`,
        fs:  `cpe:2.3:a:google:chrome:4.0.266.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.562`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.563`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.564`,
        fs:  `cpe:2.3:h:sierrawireless:raven_xe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.565`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.565.1::~~lts~~~`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.565.2::~~lts~~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.3\(0\)zn\(0.81\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.565.3::~~lts~~~`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.566`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.20:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.567`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.568`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.569`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.570`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:6.0.304.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.571`,
        fs:  `cpe:2.3:a:symantec:vrtsmh:5.0.281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.572`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.573`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.574`,
        fs:  `cpe:2.3:a:sympa:sympa:5.2b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.575`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.576`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.577`,
        fs:  `cpe:2.3:h:hp:jc086a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.578`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.579`,
        fs:  `cpe:2.3:a:gnome:glib:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.580`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.580.1::~~lts~~~`,
        fs:  `cpe:2.3:a:pivotal_software:redis:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.580.2::~~lts~~~`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.580.3::~~lts~~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.581`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.582`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.403:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.583`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.584`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.585`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.586`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.2:4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.587`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.588`,
        fs:  `cpe:2.3:a:netscape:certificate_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.589`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.590`,
        fs:  `cpe:2.3:a:ca:internet_security_suite:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.591`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.592`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.593`,
        fs:  `cpe:2.3:o:freebsd:freebsd:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.594`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.5.1681:online_windows_server_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.595`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.596`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.596.1::~~lts~~~`,
        fs:  `cpe:2.3:a:revouninstaller:uninstaller:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.596.2::~~lts~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.596.3::~~lts~~~`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.597`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.598`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.599`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.159.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.600`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.601`,
        fs:  `cpe:2.3:h:digi:cm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.602`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.603`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.604`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.605`,
        fs:  `cpe:2.3:a:sas:versioned_jar_repository:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.606`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.607`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.608`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.609`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.609.1::~~lts~~~`,
        fs:  `cpe:2.3:a:cisco:emergency_responder:11.5\(0.99833.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.609.2::~~lts~~~`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_email_engine:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.609.3::~~lts~~~`,
        fs:  `cpe:2.3:a:adobe:asset_services_cs3:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.610`,
        fs:  `cpe:2.3:a:swamiji:swamiji.tv:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.611`,
        fs:  `cpe:2.3:a:google:earth:4.2.198.2451:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.612`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.613`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.0.359:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.614`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.615`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.616`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.86:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.617`,
        fs:  `cpe:2.3:a:openafs:openafs:1.3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.618`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.619`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta55:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.620`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.621`,
        fs:  `cpe:2.3:a:dell:embassy_trust_suite_factory_installation:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.622`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.623`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.624`,
        fs:  `cpe:2.3:a:adobe:framemaker:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.625`,
        fs:  `cpe:2.3:a:docker:docker:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.625.1::~~lts~~~`,
        fs:  `cpe:2.3:a:ca:service_desk_manager:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.625.2::~~lts~~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_change_and_configuration_management_database:1.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.625.3::~~lts~~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:da:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.626`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.627`,
        fs:  `cpe:2.3:a:intel:network_connections:15.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.628`,
        fs:  `cpe:2.3:a:symantec:protection_center:12.0:*:*:*:small_business:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.629`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.630`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.631`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.9p20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.632`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.633`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.634`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.635`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xb3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.636`,
        fs:  `cpe:2.3:a:xnview:xnview:1.70.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.637`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.638`,
        fs:  `cpe:2.3:a:symantec:management_platform:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.639`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.640`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.641`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.642`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.642.1::~~lts~~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.642.2::~~lts~~~`,
        fs:  `cpe:2.3:a:red-gate:sql_refactor:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.642.3::~~lts~~~`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_33:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.642.4::~~lts~~~`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.643`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.644`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.645`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.646`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.647`,
        fs:  `cpe:2.3:h:siemens:scalance_w788-2rr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.648`,
        fs:  `cpe:2.3:a:google:chrome:7.0.512.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.649`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.650`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(2\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.651`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.651.1::~~lts~~~`,
        fs:  `cpe:2.3:o:freebsd:freebsd:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.651.2::~~lts~~~`,
        fs:  `cpe:2.3:h:hp:jg361b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.651.3::~~lts~~~`,
        fs:  `cpe:2.3:a:adobe:csi:1.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.652`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.653`,
        fs:  `cpe:2.3:a:freebsd:slashem-tty:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.654`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:11.0\(1.10000.10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.655`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:1.656`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.0`,
        fs:  `cpe:2.3:a:drupal:drupal:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.2`,
        fs:  `cpe:2.3:o:checkpoint:gaia_os:r77.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.3`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.4`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1309.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.5`,
        fs:  `cpe:2.3:a:lxml:lxml:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.6`,
        fs:  `cpe:2.3:a:exim:exim:4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.7`,
        fs:  `cpe:2.3:h:sun:fire_x2250_server:sw_1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.8`,
        fs:  `cpe:2.3:a:perl:perl:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.19.2::~~lts~~~`,
        fs:  `cpe:2.3:a:apache:camel:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:jenkins:2.31`,
        fs:  `cpe:2.3:a:apache:roller:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:knowledgetree:knowledgetree:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.20:-:*:*:*:redhat_enterprise_linux:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:adobe:motionpicture_color_files:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apple:cups:1.6:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.4.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.7::~~~jenkins~~`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.0.8::~~~jenkins~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.1.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.1.1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.6:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:novell:identity_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.1.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:aol:aim:1.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.1.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.1.4.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:vmware:vcenter_orchestrator:4.0.2.4639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:10.00.00.4036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.3.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.3.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:csc:ddoewebservice:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.7::~~~jenkins~~`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.3:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.7.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.8::~~~jenkins~~`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.9::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ultimus:ultimus_business_process_management_suite:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.10::~~~jenkins~~`,
        fs:  `cpe:2.3:o:ipcop:ipcop:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.11::~~~jenkins~~`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.2.11.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.0::~~~jenkins~~`,
        fs:  `cpe:2.3:h:axis:2490_serial_server:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tenable:nessus:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:bea:aqualogic_service_bus:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:extendsim:extendsim:6_golden_master:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:drive:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:microsoft:word:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.3.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.4.0::~~~jenkins~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.4.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:e2fsprogs_project:e2fsprogs:1.43.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.4.2::~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.4.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.4.4::~~~jenkins~~`,
        fs:  `cpe:2.3:o:sun:solaris:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:1.4.5::~~~jenkins~~`,
        fs:  `cpe:2.3:o:huawei:s5700_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:2.0.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apache:roller:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:2.0.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:2.0.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:2.1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_explorer:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:owasp_dependency-check:2.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:1.1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:1.1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:1.1.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:xdelta:xdelta3:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.2.0::~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2seg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.3.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.3.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.3.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.4.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.5.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.5.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.6.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:avaya:media_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:role-based_authorization_strategy:2.6.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:privatetunnel:privatetunnel:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.0::~~~jenkins~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:a:speed-dreams:speed_dreams:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p196:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.4::~~~jenkins~~`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:intel:network_connections:13.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.7::~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(11\)md:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.8::~~~jenkins~~`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.9::~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.15s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.10::~~~jenkins~~`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.11::~~~jenkins~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.12::~~~jenkins~~`,
        fs:  `cpe:2.3:a:cubecart:cubecart:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.13::~~~jenkins~~`,
        fs:  `cpe:2.3:a:adobe:connect:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.14::~~~jenkins~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta61:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.15::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.16::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.17::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mcafee:virusscan:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.18::~~~jenkins~~`,
        fs:  `cpe:2.3:a:phorum:phorum:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.18.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1035.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.19::~~~jenkins~~`,
        fs:  `cpe:2.3:a:roxio:recordnow_audio:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.20::~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.21::~~~jenkins~~`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_centillion:1.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.22::~~~jenkins~~`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.23::~~~jenkins~~`,
        fs:  `cpe:2.3:a:harris:intraplex_intralink-ip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.24::~~~jenkins~~`,
        fs:  `cpe:2.3:a:altiris:cmdb_solution_documentation:6.5.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.25::~~~jenkins~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.26::~~~jenkins~~`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:script_security:1.27::~~~jenkins~~`,
        fs:  `cpe:2.3:a:unify:sqlbase_clients:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0004_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.2::~~~jenkins~~`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.3::~~~jenkins~~`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.4::~~~jenkins~~`,
        fs:  `cpe:2.3:o:asus:rt-n10e_firmware:2.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.5::~~~jenkins~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.6::~~~jenkins~~`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.7::~~~jenkins~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.8::~~~jenkins~~`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.3.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.9::~~~jenkins~~`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins:sidebar_link:1.9.1::~~~jenkins~~`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:build_failure_analyzer:1.2.0:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:build_failure_analyzer:1.3.0:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:ibm:packaging_utility:1.8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:build_failure_analyzer:1.4.0:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.1.200:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:build_failure_analyzer:1.5.0:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:build_failure_analyzer:1.5.1:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:exclusion:0.6:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:juniper:junos_pulse_access_control_service:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:exclusion:0.7:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:exclusion:0.8:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:gnu:grep:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:exclusion:0.9:-:~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.40.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:h:xerox:workcentre_m35:4.97.20.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.41.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.42.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:o:ibm:os_390:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.43.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.44.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:o:nisuta:ns-wir150ne_firmware:5.07.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.45.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.46.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.47.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:kelly_d._redding:kelredd-pruview:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.48.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:altiris:task_management:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.49.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_alert:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.50.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.51.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update9:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.52.0::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:o:tp-link:tl-wrd841n_\(9.0\)_firmware:150104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:monitoring_plugin:1.52.1::~~~cloudbees_jenkins~~`,
        fs:  `cpe:2.3:a:adobe:customization_wizard:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.0`,
        fs:  `cpe:2.3:a:debian:tetex-bin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.1`,
        fs:  `cpe:2.3:a:twilio_project:twilio:7.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.2`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.3`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.0.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.4`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.5`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.6`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.7`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.8`,
        fs:  `cpe:2.3:a:ibm:worklight:6.1.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.9`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.10`,
        fs:  `cpe:2.3:h:apple:iphone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.11`,
        fs:  `cpe:2.3:a:combodo:itop:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.12`,
        fs:  `cpe:2.3:a:keepass:keepass:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.13`,
        fs:  `cpe:2.3:a:prosody:prosody:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.14`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.15`,
        fs:  `cpe:2.3:a:axis:camera_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.16`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.17`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.18`,
        fs:  `cpe:2.3:a:roxio:creator_copy:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.19`,
        fs:  `cpe:2.3:h:cisco:catalyst_8540csr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.20`,
        fs:  `cpe:2.3:a:google:picasa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.21`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.22`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.23`,
        fs:  `cpe:2.3:a:google:v8:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.24`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.25`,
        fs:  `cpe:2.3:a:hp:dynrootdisk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.26`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.27`,
        fs:  `cpe:2.3:h:cisco:catalyst_3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.28`,
        fs:  `cpe:2.3:a:redirection_project:redirection:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.29`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.30`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.31`,
        fs:  `cpe:2.3:h:brocade:silkworm_3850_fabric_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.32`,
        fs:  `cpe:2.3:a:adobe:golive_cs2:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.33`,
        fs:  `cpe:2.3:a:python:pillow:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.34`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.35`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.14:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.36`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp3:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.37`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.38`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.39`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.40`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.41`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.42`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.43`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.44`,
        fs:  `cpe:2.3:a:sybase:easerver:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.45`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller:1.0\(2j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.46`,
        fs:  `cpe:2.3:a:microsoft:works:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.47`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.11.155:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.48`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.49`,
        fs:  `cpe:2.3:a:google:chrome:14.0.814.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.50`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec:2010_r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.51`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.52`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.53`,
        fs:  `cpe:2.3:a:ibm:net.commerce:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jenkins-ci:subversion-plugin:1.54`,
        fs:  `cpe:2.3:a:php:php:5.4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.9`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.9:beta`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.9-1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3ym:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.10`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.11`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.1.6.3264:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.12`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.13`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.14`,
        fs:  `cpe:2.3:h:ibm:storwize_unified_v7000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.15`,
        fs:  `cpe:2.3:a:kde:koffice:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.16`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.17`,
        fs:  `cpe:2.3:a:emc:documentum_eroom:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jens_vagelpohl:zope-ldapuserfolder:2.18`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.808:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.02::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.1.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.03::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.04::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nakodabhairav:rajendra_suriji:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.05::~~~wordpress~~`,
        fs:  `cpe:2.3:o:juniper:junose_j:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.06::~~~wordpress~~`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x45:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.07::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wp_ban_project:wp_ban:1.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.08::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.09::~~~wordpress~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:struts:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jeremy_massel:underconstruction:1.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jesse_vincent:extension%3a%3amobileui:1.01`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jesse_vincent:extension%3a%3amobileui:1.02`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jessgramp:minicms:1.0`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jessgramp:minicms:2.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update1:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.2`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.4`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.5`,
        fs:  `cpe:2.3:h:verizon:wireless_network_extender:scs-26uc4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.6`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:2.0_rc4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ay:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.7.1000:-:basic`,
        fs:  `cpe:2.3:a:sendmail:sendmail:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.8`,
        fs:  `cpe:2.3:o:hp:hp-ux:b.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.9`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.10`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.11`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.12`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_51:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.14`,
        fs:  `cpe:2.3:a:cisco:unified_ip_ivr:7.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.15`,
        fs:  `cpe:2.3:a:apple:itunes:11.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.16`,
        fs:  `cpe:2.3:a:thycotic:secret_server:8.6.000000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.0.17`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.1.0`,
        fs:  `cpe:2.3:o:xen:xen:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetaudio:jetaudio:8.1.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetbrains:intellij_idea:9.0.3`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetbrains:intellij_idea:9.0.4`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.0f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetbrains:intellij_idea:10.5.2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.05:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetbrains:intellij_idea:11.0`,
        fs:  `cpe:2.3:o:sophos:web_appliance_firmware:3.7.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetbrains:omea_reader:2.2`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetbrains:resharper:6.1.37`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetbrains:teamcity:8.0`,
        fs:  `cpe:2.3:a:wave:wave_support_software_installer:5.12.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetico:bcwipe:3.0`,
        fs:  `cpe:2.3:a:apple:afp_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jetico:bcwipe:5.0`,
        fs:  `cpe:2.3:a:samba:samba:2.2.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jextn:com_jefaqpro:1.5.0`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jextn:com_jefaqpro:1.5.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jextn:jextn_question_and_answer:3.1.0::~~~joomla~~`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jffnms:just_for_fun_network_management_system:-`,
        fs:  `cpe:2.3:a:digium:asterisk:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jffnms:just_for_fun_network_management_system:0.8.2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jffnms:just_for_fun_network_management_system:0.8.3`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jffnms:just_for_fun_network_management_system:0.8.4:pre2`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.11.00050:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:jforum:jforum:-`,
        fs:  `cpe:2.3:a:isc:bind:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jforum:jforum:2.1.9`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2010.706.2128.36662:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jforum:jforum:3.0:beta`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgaa:warftpd:1.8.2:-`,
        fs:  `cpe:2.3:h:sitecom:wl-153:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgaa:warftpd:1.8.2:rc12`,
        fs:  `cpe:2.3:a:techsmith:snagit:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgrasp:jgrasp:1.8.8_01`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.0`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.7.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.1`,
        fs:  `cpe:2.3:a:phpspot:webshot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.2`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_920:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.3`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.4`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.5`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix_5570_controller_firmware:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.6`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.34:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.7`,
        fs:  `cpe:2.3:a:gnu:grep:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.8`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.9`,
        fs:  `cpe:2.3:a:apache:rave:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.10`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.11`,
        fs:  `cpe:2.3:a:att:natural_voices_mike_16k:1.4.0011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.12`,
        fs:  `cpe:2.3:a:sun:iplanet_messaging_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.13`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.0.14`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.1.0`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.0`,
        fs:  `cpe:2.3:a:nuance:smart_document_scan_software:2.70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.2`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.3`,
        fs:  `cpe:2.3:a:radware:web_server_directory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.4`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.5`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.6`,
        fs:  `cpe:2.3:h:siemens:s45:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.7`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.1.0.668:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.2.8`,
        fs:  `cpe:2.3:h:dell:latitude_d531:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.3.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.3.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jgroups:jgroup:3.3.2`,
        fs:  `cpe:2.3:a:sun:jre:6.0.230:update23:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:jig:movatwitouch:1.792:-:~~~android~~`,
        fs:  `cpe:2.3:a:christophe_thibault:k-meleon:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jig:movatwitouch:1.793:-:~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.8.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jig:movatwitouch_paid:1.792:-:~~~android~~`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jig:movatwitouch_paid:1.793:-:~~~android~~`,
        fs:  `cpe:2.3:a:intel:miwa:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jijitechnologies:active_directory_cleaner:3.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.5:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jijitechnologies:active_directory_cleaner:3.1.4`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jijitechnologies:active_directory_cleaner:3.2.0.0`,
        fs:  `cpe:2.3:a:web2py:web2py:1.94.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jinfra:guess_the_movie:2.982::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.0.60818.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jiujik:jiu_jik:1.4.0::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:jre:7.0:update_97:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jiuzhangtech:traffic_jam_free:1.7.7::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jiuzhangtech:word_search:2.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jjmatch:jj_texas_hold%27em_poker:1.13.23.hd::~~~android~~`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jjwwebdesign:phpbookingcalendar:1.0c`,
        fs:  `cpe:2.3:a:apple:quicktime:7.5.5:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joachim_noreiko:flag_module:7.x-3.0:beta1`,
        fs:  `cpe:2.3:h:hp:jf229a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joachim_noreiko:flag_module:7.x-3.0:rc1`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joachim_ruhs:locator:2.9.0`,
        fs:  `cpe:2.3:a:apple:safari:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joachim_ruhs:locator:2.9.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0:alpha_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joachim_ruhs:locator:3.1.5`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.5:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joachim_ruhs:locator:3.1.7`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joakim_nygard:webgrind:1.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joakim_nygard:webgrind:1.0.2`,
        fs:  `cpe:2.3:a:compaq:management_agents:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:job_fair_project:job_fair:1.0.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:emc:documentum_d2:4.5:p14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:job_manager:job_manager:0.7.22::~~~wordpress~~`,
        fs:  `cpe:2.3:a:invitation_project:invitation:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:jobranco_project:jobranco:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jochen_wiedmann:html%3a%3aep:0.2011::~~~perl~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.314.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joe_haskins:og_manager_change:7.x-2.0`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joe_haskins:og_manager_change:7.x-2.0:beta1`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joe_haskins:og_manager_change:7.x-2.1`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joe_haskins:og_manager_change:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.0.0`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.0.1`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.7.5000.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.0.2`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.1.0`,
        fs:  `cpe:2.3:a:alexis_wilke:protected_node:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.2.0`,
        fs:  `cpe:2.3:a:cisco:packet_tracer:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.2.1`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.0`,
        fs:  `cpe:2.3:o:ibm:os_400:v4r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.1`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.2`,
        fs:  `cpe:2.3:a:apple:webkit:417.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.3`,
        fs:  `cpe:2.3:a:avast:pro_antivirus:11.1.2262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2cx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.5`,
        fs:  `cpe:2.3:h:huawei:e200_usg5100:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.6`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:003z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.7`,
        fs:  `cpe:2.3:a:avaya:predictive_dialer_system:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.3.8`,
        fs:  `cpe:2.3:a:candlepinproject:candlepin:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.0`,
        fs:  `cpe:2.3:h:intel:d845pt_motherboard:p03-0021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.1`,
        fs:  `cpe:2.3:a:altova:missionkit_for_enterprise_software_architects:2010.00.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(27\)sv1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.3`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.4`,
        fs:  `cpe:2.3:a:h2o_project:h2o:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.5`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1654.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.6`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.7`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.9`,
        fs:  `cpe:2.3:a:joomlaskin:js_multi_hotel:2.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.4.10`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.5.0`,
        fs:  `cpe:2.3:a:hummingbird:exceed_on_demand_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.5.1`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.5.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.5.3`,
        fs:  `cpe:2.3:a:securityinnovation:ntru_tcg_software_stack:2.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.5.4`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.6.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.6.1`,
        fs:  `cpe:2.3:a:goautodial:goadmin_ce:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.6.2`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.0.8:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.6.3`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.7.0`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.7.1`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.7.2`,
        fs:  `cpe:2.3:a:sap:hybris:5.5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.7.3`,
        fs:  `cpe:2.3:a:red-gate:sql_data_generator:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.7.4`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.7.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.7.7`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.4.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.7.8`,
        fs:  `cpe:2.3:a:posh_project:posh:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.394:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.1`,
        fs:  `cpe:2.3:a:appnitro:machform:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2011.308.2346.42594:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.3`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.4`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:4.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.5`,
        fs:  `cpe:2.3:h:sun:cobalt_raq_4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.6`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.7`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.8`,
        fs:  `cpe:2.3:a:field_group_project:field_group:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.8.9`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:8.0.72.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.2.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.3`,
        fs:  `cpe:2.3:a:hp:data_protector:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.4`,
        fs:  `cpe:2.3:a:okcupid:okcupid_dating:3.4.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.5`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.6`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.7`,
        fs:  `cpe:2.3:a:novell:groupwise:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.9.8`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.0`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g54_firmware:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.1`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.3.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.3`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.4`,
        fs:  `cpe:2.3:o:cisco:ios:3.5.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.5`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.6`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.8`,
        fs:  `cpe:2.3:a:emc:networker_module_for_microsoft_applications:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.9`,
        fs:  `cpe:2.3:a:kktalk:kktalk:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.10`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.11`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.10.12`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.11.0`,
        fs:  `cpe:2.3:a:solarwinds:job_engine:1.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.11.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.12.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.11.2`,
        fs:  `cpe:2.3:h:apple:airport_base_station:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:1.11.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.0`,
        fs:  `cpe:2.3:a:cisco:jabber:9.6\(3\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.2`,
        fs:  `cpe:2.3:a:ibm:soliddb:4.5.175:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.3`,
        fs:  `cpe:2.3:h:cisco:catalyst_2970:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.4`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc2325:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.5`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.5:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.6`,
        fs:  `cpe:2.3:a:apache:ofbiz:11.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.7`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.8`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.9`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2009.312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.11`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.0.12`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.1.0`,
        fs:  `cpe:2.3:a:f5:big-iq_security:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.1.1`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:5.2:2004q2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.1.2`,
        fs:  `cpe:2.3:a:php:php:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.1.3`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.1.4`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joedolson:my-calendar:2.1.5`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jogamp:joal:2.0:rc11`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jogamp:jogamp:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jogoeusei:eu_sei:eusei_android_5.5::~~~android~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jogoeusei:i_know_the_movie:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:openjpa:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jogoeusei:questoes_oab:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_albin:zen:6.x-1.0`,
        fs:  `cpe:2.3:a:broadcom:widcomm_bluetooth:4.0.1.1500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_albin:zen:6.x-1.0:beta2`,
        fs:  `cpe:2.3:h:cisco:vpn_3001_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_albin:zen:6.x-1.0:beta3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_albin:zen:6.x-1.0beta1`,
        fs:  `cpe:2.3:a:ibm:security_directory_server:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_albin:zen:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_catania:server_scripts_setup:1.0`,
        fs:  `cpe:2.3:o:rockwellautomation:rslogix_emulate_5000_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_catania:server_scripts_setup:2.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.2.0.1575:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0:alpha2`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0:beta1`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:5.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0:beta2`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0:beta3`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0:beta4`,
        fs:  `cpe:2.3:a:roxio:creator_de:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0:beta5`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.19370:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0:beta6`,
        fs:  `cpe:2.3:a:google:chrome:17.0.943.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.0-rc1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.1:rc1`,
        fs:  `cpe:2.3:o:maygion:ip_camera_firmware:05.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.2`,
        fs:  `cpe:2.3:a:clip-bucket:clipbucket:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.2:rc1`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.3:beta1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.3:dev`,
        fs:  `cpe:2.3:o:debian:debian_linux:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_franklin:advertisement:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_geo:blogs_manager:1.101`,
        fs:  `cpe:2.3:o:cisco:ios:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_geo:freelancer_calendar:1.01`,
        fs:  `cpe:2.3:a:gajennings:this:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_koleszar:libvpx:0.9.0`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_koleszar:libvpx:0.9.1`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:john_koleszar:libvpx:0.9.2`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_koleszar:libvpx:0.9.5`,
        fs:  `cpe:2.3:a:apple:safari:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_koleszar:libvpx:0.9.6`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_koleszar:libvpx:0.9.7`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_koleszar:libvpx:0.9.7:p1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_koleszar:libvpx:1.0.0`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_morrissey:mod_ldap_userdir:0.9`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_morrissey:mod_ldap_userdir:1.1.7`,
        fs:  `cpe:2.3:a:pgp:e-business_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_morrissey:mod_ldap_userdir:1.1.8`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_morrissey:mod_ldap_userdir:1.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:crack:0.1.8`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_universal_restore:11.0.17318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:crack:0.2.0`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.08b51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:crack:0.3.0`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd663b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:crack:0.3.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:crack:0.3.2`,
        fs:  `cpe:2.3:a:pygments:pygments:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.1.0`,
        fs:  `cpe:2.3:a:redprairie:redprairie_application_server:2010.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.1.1`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.1.2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.1.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.1.5`,
        fs:  `cpe:2.3:a:vmware:player:4.0.0.18997:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.1.6`,
        fs:  `cpe:2.3:a:google:chrome:10.0.610.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.1.7`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.1.8`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)se2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.3`,
        fs:  `cpe:2.3:h:ibm:proventia_network_ips_gx5108:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.4`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.5`,
        fs:  `cpe:2.3:a:emc:networker:8.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.6`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.7`,
        fs:  `cpe:2.3:a:microsoft:services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.8`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.9`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.2.10`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.5.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.3.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.5-1:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.3.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.4.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.4.1`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.2.2:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.4.2`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.4.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.4.4`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.4.5`,
        fs:  `cpe:2.3:a:microsoft:ie:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.5.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.5.1`,
        fs:  `cpe:2.3:a:google:chrome:15.0.866.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)s0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.6.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1012:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.6.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.1`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.3`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.19f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.5`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.6`,
        fs:  `cpe:2.3:a:perl:perl:5.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.7.8`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.8.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.8.1`,
        fs:  `cpe:2.3:a:staperpetua:l\&#39;informatiu:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.8.2`,
        fs:  `cpe:2.3:a:apache:juddi:0.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.8.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:john_nunemaker:httparty:0.9.0`,
        fs:  `cpe:2.3:h:linksys:befvp41:1.01.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:johnsoncontrols:pegasys_p2000_server:-`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.63.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:johnsoncontrols:pegasys_p2000_server_software:3.10`,
        fs:  `cpe:2.3:a:debian:toolchain-source:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:johnsoncontrols:pegasys_p2000_server_software:3.11`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1062.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:johtru:gymnoovp:1.2::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jojocms:jojo-cms:1.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jojocms:jojo-cms:1.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_5f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jojocms:jojo-cms:1.2.1`,
        fs:  `cpe:2.3:a:nero:nero:6.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jollygiant:qws3270_secure:-`,
        fs:  `cpe:2.3:a:bzip:bzip2:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jollygiant:qws3270_secure:4.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jollygiant:qws3270_secure:4.5`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jonathan_leung:show_in_browser:0.0.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jonathan_leung:show_in_browser:0.0.2::~~~ruby~~`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:5.2.1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jonathan_leung:show_in_browser:0.0.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:homepageprint:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joobi:com_jnews:7.5.1`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_cdp:2.62.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.2`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.4`,
        fs:  `cpe:2.3:a:actualtests:questions_and_answers_for_eccouncil_312-50v7:4.2.13135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.5`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.6`,
        fs:  `cpe:2.3:a:apple:cups:1.1.23:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.7`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.8`,
        fs:  `cpe:2.3:a:pervasive:data_integrator_documentation:9.0.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.9`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.10`,
        fs:  `cpe:2.3:a:o2micro:oz776_scr_cardbus_v1.1.3.6:1.1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.11`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.12`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.13`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.14`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.48\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.0.15`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.0`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.84:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.2`,
        fs:  `cpe:2.3:a:ibm:security_guardium:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.3`,
        fs:  `cpe:2.3:a:hp:marketresearch:90.0.142.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.4`,
        fs:  `cpe:2.3:a:adobe:media_player:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.5`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.6`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r343.00:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.7`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.8`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.9`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.10`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.11`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.12`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.13`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:9.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.14`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.15`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf801a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.15:rc`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.16`,
        fs:  `cpe:2.3:a:taxonews_project:taxonews:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.17`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.18`,
        fs:  `cpe:2.3:a:otrs:otrs:0.5:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.19`,
        fs:  `cpe:2.3:a:google:v8:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.20`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.21`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:12.2:-:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.22`,
        fs:  `cpe:2.3:a:avast:premier:11.1.2260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.23`,
        fs:  `cpe:2.3:a:divx:converter:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.24`,
        fs:  `cpe:2.3:a:php:php:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.25`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.5.26`,
        fs:  `cpe:2.3:a:3com:3ctftpsvc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:alpha`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:alpha2`,
        fs:  `cpe:2.3:a:nortel:media_communication_server_5100:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta1`,
        fs:  `cpe:2.3:o:ibm:aix:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta10`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta11`,
        fs:  `cpe:2.3:a:koha:koha:3.14.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta12`,
        fs:  `cpe:2.3:o:rockwellautomation:compactlogix_controller_1769_firmware:27.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta13`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.53:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta14`,
        fs:  `cpe:2.3:a:apache:struts:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta15`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta2`,
        fs:  `cpe:2.3:a:nvidia:install_application:2.265.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta3`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta4`,
        fs:  `cpe:2.3:a:adobe:acrobat:_reader9.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta5`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.localization:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta6`,
        fs:  `cpe:2.3:a:oracle:database_server:8.1.7:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta8`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:beta9`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6:rc1`,
        fs:  `cpe:2.3:h:cisco:ons_15454_multiservice_transport_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6.1`,
        fs:  `cpe:2.3:a:yokogawa:centum_vp_software:5.03.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6.2`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6.3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6.4`,
        fs:  `cpe:2.3:a:novell:netware_ftp_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6.5`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.6.6`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.7.0`,
        fs:  `cpe:2.3:a:intel:mdrwifi:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.7.1`,
        fs:  `cpe:2.3:a:gnu:binutils:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.7.2`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.7.3`,
        fs:  `cpe:2.3:a:myrephp:myre_realty_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.7.4`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:1.7.5`,
        fs:  `cpe:2.3:h:cisco:unity_express:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(1\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.2`,
        fs:  `cpe:2.3:a:oracle:payroll:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.34:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.4`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k_secure:14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.5`,
        fs:  `cpe:2.3:a:websense:websense_email_security:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.6`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.7`,
        fs:  `cpe:2.3:a:roxio:easy_cd_creator_basic:5.3.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.8`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.8:build120518:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.9`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.10`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.11`,
        fs:  `cpe:2.3:a:microsoft:visual_j\#_.net:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.12`,
        fs:  `cpe:2.3:h:cisco:telepresence_ix5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.13`,
        fs:  `cpe:2.3:a:cdotech:edcl_tmo_incheck:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.14`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(3\)e5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.15`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.16`,
        fs:  `cpe:2.3:a:jquery:jquery:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.17`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.18`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.19`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.5.0:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.20`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.21`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2008.717.2343.40629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.22`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0576:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.23`,
        fs:  `cpe:2.3:a:haxx:curl:7.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.24`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.25`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)eb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.26`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.27`,
        fs:  `cpe:2.3:a:igniterealtime:openfire:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:2.5.28`,
        fs:  `cpe:2.3:a:rsa:authentication_manager:8.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.0.0`,
        fs:  `cpe:2.3:a:cisco:content_distribution_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.0.1`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.0.2`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.0.3`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.0.4`,
        fs:  `cpe:2.3:a:dadabik:dadabik:2.2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.1.0`,
        fs:  `cpe:2.3:a:inzeratyzdarma:ads_free._cz_advert:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.1.1`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.1.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.1.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.1.4`,
        fs:  `cpe:2.3:a:sun:one_application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.1.5`,
        fs:  `cpe:2.3:a:mesa3d:mesa:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.1.6`,
        fs:  `cpe:2.3:h:hp:color_laserjet_m775z\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.2.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.2.1`,
        fs:  `cpe:2.3:a:rack_project:rack:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.2.2`,
        fs:  `cpe:2.3:h:epson:stylus_color_850_ink_jet_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.2.3`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.9:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.2.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.2.6`,
        fs:  `cpe:2.3:a:hp:icewall_mcrp:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.2.7`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.3.0`,
        fs:  `cpe:2.3:o:yahama:rta52i:4.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.3.1`,
        fs:  `cpe:2.3:a:ca:desktop_management_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.3.2`,
        fs:  `cpe:2.3:h:sony:snc_ch240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.3.3`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.3.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.87a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.3.5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.3.6`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.0`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.5:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.0:alpha`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.0:beta1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.0:beta2`,
        fs:  `cpe:2.3:h:hp:advanced_server_9000:b.04.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.0:beta3`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.0:rc1`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:5.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.1`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.24:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.1:rc1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.1:rc2`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.2:rc1`,
        fs:  `cpe:2.3:a:drupal:drupal:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.3`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.4`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.5`,
        fs:  `cpe:2.3:o:d-link:dcs-932l_firmware:2.13.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.6`,
        fs:  `cpe:2.3:a:siemens:scalance_x308-2m_firmware:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.7`,
        fs:  `cpe:2.3:h:intel:active_management_technology:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.8`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.4.8:rc`,
        fs:  `cpe:2.3:a:entrouvert:lasso:2.0.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0`,
        fs:  `cpe:2.3:a:samba:samba:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:beta`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:beta2`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.5e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:beta3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1689.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:beta4`,
        fs:  `cpe:2.3:a:redhat:jboss_bpm_suite:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:beta5`,
        fs:  `cpe:2.3:a:spip:spip:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:rc`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:rc2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:rc3`,
        fs:  `cpe:2.3:a:lksctp:stream_control_transmission_protocol:2.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.0:rc4`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.1`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.5.1:rc`,
        fs:  `cpe:2.3:a:sun:solstice_adminsuite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.0`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.0:alpha`,
        fs:  `cpe:2.3:a:redmine:redmine:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.0:beta1`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.0:beta2`,
        fs:  `cpe:2.3:o:compaq:tru64:5.0a_pk3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.0:rc`,
        fs:  `cpe:2.3:a:adobe:acrobat:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.0:rc2`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.1`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.1:rc1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(1h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.1:rc2`,
        fs:  `cpe:2.3:a:emtec:zoc_terminal:6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.3`,
        fs:  `cpe:2.3:a:freedomscientific:braille:10.19.760.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.3:rc1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.3:rc2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.3:rc3`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.4`,
        fs:  `cpe:2.3:a:macromedia:coldfusion_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.6.5`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.14:ga7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxf7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.7.1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.7.2`,
        fs:  `cpe:2.3:a:autodesk:content_service:2.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.7.3`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.7.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.7.5`,
        fs:  `cpe:2.3:a:c-icap_project:c-icap:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:joomla%21:3.8.1`,
        fs:  `cpe:2.3:a:taxonomy_path_project:taxonomy_path:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla:session:1.3.0`,
        fs:  `cpe:2.3:a:thedevildoggamer_project:thedevildoggamer:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla-cbe:com_cbe:1.4.8`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla-cbe:com_cbe:1.4.9`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomla-cbe:com_cbe:1.4.10`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.1102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.4.0::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.0::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.2::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:gnu:automake:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.3::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.4::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04:sp18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.5::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.6::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.7::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.580.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.8::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:3.9.9::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.0.0::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.0.1::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:eviware:soapui:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.0.2::~~~joomla%21~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.0.8::~~~joomla%21~~`,
        fs:  `cpe:2.3:o:juniper:screenos:6.2.0r17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.0.9::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.0::~~~joomla%21~~`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.1::~~~joomla%21~~`,
        fs:  `cpe:2.3:h:cisco:ie-4000-16gt4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.2::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.3::~~~joomla%21~~`,
        fs:  `cpe:2.3:o:ibm:global_console_manager_32_firmware:1.20.0.22575:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.4::~~~joomla%21~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.5::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.6::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.7::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:apache:geronimo:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.8::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:debian:adequate:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaboat:com_youtubegallery:4.1.9::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joomlaskin:js_multi_hotel:2.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf431b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordan_de_laune:mp3_player:6.x-1.0`,
        fs:  `cpe:2.3:a:checkpoint:provider-1:4.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordan_de_laune:mp3_player:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordan_de_laune:mp3_player:6.x-1.1`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.01.471:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:virtualization:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.6:mp4:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mythicsoft:agent_ransack:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:8.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.59:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.9.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_ip_vcr_3.0:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.32::~~~wordpress~~`,
        fs:  `cpe:2.3:a:altiris:application_management_solution:6.1.4088:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.34::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:soliddb:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.52::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:beta35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:0.54::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:identicentric:simaxs:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gdb:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sympa:sympa:2.5.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:jordy_meow:media_file_renamer:1.7.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:10.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josh_fradley:burden:1.2`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josh_fradley:burden:1.3`,
        fs:  `cpe:2.3:h:nortel:ip_phone_2002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josh_fradley:burden:1.4`,
        fs:  `cpe:2.3:a:oracle:webcenter_interaction_identity_service_for_ldap:10.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josh_fradley:burden:1.5`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josh_fradley:burden:1.6`,
        fs:  `cpe:2.3:o:google:android:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josh_fradley:burden:1.7`,
        fs:  `cpe:2.3:a:simple_php_agenda_project:simple_php_agenda:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josh_fradley:burden:1.8`,
        fs:  `cpe:2.3:o:valvesoftware:steamos:-:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josh_roesslein:tweepy:-`,
        fs:  `cpe:2.3:h:hp:proliant_dl4x170h_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshics:contact_form_fields:6.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:security_guardium:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.0.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.1.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.2.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.3.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.3.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.3.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:adobe:air_sdk:17.0.0.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.3.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:38.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.3.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:roxio:easy_media_creator_basic_edition:7.1.0.183:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.4.0::~~~ruby~~`,
        fs:  `cpe:2.3:o:huawei:s9312_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joshua_peek:rack-ssl:1.4.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnitouch_8400_instant_communications_suite:6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:-`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.3.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:11.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.3`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.4`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.5`,
        fs:  `cpe:2.3:a:wvware:libwmf:0.2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.6`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.35.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.7`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.8`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.8.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.8.2`,
        fs:  `cpe:2.3:a:aimluck:aipo:4.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.8.3`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.8.4`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.8.5`,
        fs:  `cpe:2.3:a:redhat:jboss_bpm_suite:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.8.6`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:josso:java_open_single_sign-on_project_home:1.8.7`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joungouapps:maccabi_tel_aviv:1::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:ie:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jowangel:legend_of_trance:1::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joyent:node.js:0.6.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2xo.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:joyent:node.js:0.6.3`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:joyent:smartos:20120614`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je070a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.00.01`,
        fs:  `cpe:2.3:o:cray:unicos:9.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.01.01`,
        fs:  `cpe:2.3:o:opensuse:opensuse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.02.01`,
        fs:  `cpe:2.3:a:eeye:retina:5.12.1.2272:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.03.02`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.04.01`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.347:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.06.02`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0002_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.10.01`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.11.02`,
        fs:  `cpe:2.3:a:flurry:flurry-analytics-android:3.3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.12.05`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.16.2.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.14.01`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.15.01`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction:6.5.1.328335:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpchacha:chasys_draw_ies:4.20.01`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpmorganchase:chase_mobile:-:-:~~~android~~`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jpmorganchase:chase_mobile:2.7:-:~~~android~~`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.7.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jq_project:jq:1.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.301:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.6.1`,
        fs:  `cpe:2.3:a:php:pecl_phpdoc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.6.2`,
        fs:  `cpe:2.3:a:google:talk_plugin:2.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.6.3`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.6.4`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.7.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.7.2`,
        fs:  `cpe:2.3:a:netgenius:multilink:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.8.0`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery:1.8.1`,
        fs:  `cpe:2.3:a:apple:itunes:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jquery:jquery_ui:1.10.0:rc1`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:5.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:ecb:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:5.x-1.x-dev`,
        fs:  `cpe:2.3:o:redhat:enterprise_virtualization_manager:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:5.x-2.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.695.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:5.x-2.4`,
        fs:  `cpe:2.3:a:tibco:spotfire_deployment_kit:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:5.x-2.5`,
        fs:  `cpe:2.3:a:git-scm:git:0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:5.x-2.6`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-1.9`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-1.10`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-1.11`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.352:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-1.x:dev`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf183a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-1.x-dev`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-2.0:beta1`,
        fs:  `cpe:2.3:a:teamst:testlink:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-2.0:beta2`,
        fs:  `cpe:2.3:a:apache:pdfbox:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-2.0:beta3`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jrbcs:webform_report:6.x-2.0:beta4`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jreast:jr_east_japan:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jreast:jr_east_japan:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jrsoftware:mousetool:3.13`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:-`,
        fs:  `cpe:2.3:a:mollify:mollify:0.9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:0.9.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:0.9.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p122:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:0.9.2`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.4.981:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:0.9.8`,
        fs:  `cpe:2.3:h:cisco:catalyst_4232:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:0.9.9`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.4.4000.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:0.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.0.0:rc1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.0.0:rc2`,
        fs:  `cpe:2.3:a:oracle:identity_federation:11.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.0.0:rc3`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.0.1`,
        fs:  `cpe:2.3:a:altiris:it_analytics_symantec_endpoint_protection_pack:6.1.1048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.0.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.0.3`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.1.5:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1:b1`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1:rc1`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1:rc2`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1:rc3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1.1`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:2.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1.2`,
        fs:  `cpe:2.3:a:intel:mhlpdell:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1.3`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.12.5:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1.4`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1.5`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1.6`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.1.6:rc1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.2.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.2.0:rc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.2.0:rc2`,
        fs:  `cpe:2.3:a:csc:ssowebservice:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.3.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.17:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.3.0:rc1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.3.0:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.3.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.4.0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.4.0:rc1`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.4.0:rc2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.4.0:rc3`,
        fs:  `cpe:2.3:a:git-scm:git:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.4.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(4\)f1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.0:rc1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.0:rc2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.0:rc3`,
        fs:  `cpe:2.3:a:nq:nq_mobile_security_\&amp;_antivirus:7.2.16.00:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.1`,
        fs:  `cpe:2.3:a:digium:asterisk:11.16.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.2`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:16.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.4`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.5`,
        fs:  `cpe:2.3:a:apache:commons-compress:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.5.6`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/f:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.0:rc1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.0:rc2`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:5.1.4.0104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.0:rc3`,
        fs:  `cpe:2.3:a:ca:license_software:1.61.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.1`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.2`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.7:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.3`,
        fs:  `cpe:2.3:h:hp:0235a31r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.4`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.5`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.6`,
        fs:  `cpe:2.3:a:webmin:usermin:1.390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.7`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.7.2`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.2.2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jruby:jruby:1.6.8`,
        fs:  `cpe:2.3:a:pansi:pansi_sms:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.2.0`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.2.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2010.910.2122.36517:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.2.2`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.3.0`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.3.1`,
        fs:  `cpe:2.3:a:telos:amhs_activex_spell_checker:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.3.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.19:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.3.3`,
        fs:  `cpe:2.3:a:david_king:vino:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.3.4`,
        fs:  `cpe:2.3:a:apache:camel:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.3.5`,
        fs:  `cpe:2.3:a:jiuzhangtech:word_search:2.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.3.6`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:0.3.7`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:1.0.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:1.0.1`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:1.0.2`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:1.0.3`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:2.0.0`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:2.0.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:2.0.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:2.0.3`,
        fs:  `cpe:2.3:o:novell:netware:5.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:js-yaml_project:js-yaml:2.0.4`,
        fs:  `cpe:2.3:a:david_king:vino:2.25.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.2`,
        fs:  `cpe:2.3:a:citrix:receiver_sson:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.3`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.4`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.6`,
        fs:  `cpe:2.3:a:sun:jre:6.0.230:update23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.7`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.8`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.9`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.10`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit-32:11.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.11`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:json-c_project:json-c:0.12`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jspautsch:firstlastnames:1.1.1`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:junefabrics:pdanet_for_android:2.45`,
        fs:  `cpe:2.3:a:apache:groovy:2.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:connect_tools:1.0.0`,
        fs:  `cpe:2.3:a:git_project:git:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:dx:-`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:dx:5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:fips_infranet_controller_6500:-`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:fips_secure_access_4000:-`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:fips_secure_access_4500:-`,
        fs:  `cpe:2.3:a:skype:skype:0.97.0.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:fips_secure_access_6000:-`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-720_firmware:t390sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:fips_secure_access_6500:-`,
        fs:  `cpe:2.3:a:microsoft:message_queuing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:host_checker:6.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:http_service:-`,
        fs:  `cpe:2.3:a:pocketmags:fusion_flowers_-_weddings:\@7f0801aa:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:idp250:-`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:idp75:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:idp800:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:idp8200:-`,
        fs:  `cpe:2.3:a:measureup:microsoft_press_training_kit_exam_prep_suite_70-640:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:infranet_controller_4000:-`,
        fs:  `cpe:2.3:o:hp:z240_firmware:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:infranet_controller_4500:-`,
        fs:  `cpe:2.3:a:jease:jease:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:infranet_controller_6000:-`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:infranet_controller_6500:-`,
        fs:  `cpe:2.3:a:accusoft:imagxpress:7.0.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:installer_service:1.0.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:installer_service:1.1.0.0`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:installer_service:1.3.2.12005`,
        fs:  `cpe:2.3:a:topappsbuilder_project:animal_kaiser_zangetsu:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:installer_service:2.0.1.4429`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:installer_service:3.2`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:installer_service:7.1.0.18193`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:ive_os:7.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.409.3:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:ive_os:7.1r13`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:ive_os:7.2`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3a7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:ive_os:7.2r7`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:ive_os:7.3`,
        fs:  `cpe:2.3:h:cisco:gigabit_switch_router_12016:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:ive_os:7.3r2`,
        fs:  `cpe:2.3:a:gecu:gulf_credit_union:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:ive_os:7.4`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.6.0.19120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:ive_os:8.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junipersetup_control:-`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.1_b9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:-`,
        fs:  `cpe:2.3:a:google:chrome:4.0.247.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:4.0`,
        fs:  `cpe:2.3:a:netgear:readynas_surveillance:1.3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:4.1`,
        fs:  `cpe:2.3:o:suse:yast2-backup:2.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:4.2`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:4.3`,
        fs:  `cpe:2.3:a:hp:hppfonts:0.1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:4.4`,
        fs:  `cpe:2.3:a:apache:camel:2.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.0`,
        fs:  `cpe:2.3:a:montala:resourcespace:4.2.2816:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.0r3`,
        fs:  `cpe:2.3:a:gnu:tar:1.13.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.0r4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.1`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.2`,
        fs:  `cpe:2.3:a:vmware:workstation_pro:12.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.3`,
        fs:  `cpe:2.3:o:cray:unicos:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.4`,
        fs:  `cpe:2.3:a:apache:subversion:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.5`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:5.7`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.2.0:tp02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:6.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:6.1`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs6:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:6.2`,
        fs:  `cpe:2.3:a:atutor:atutor:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:6.3`,
        fs:  `cpe:2.3:a:apache:juddi:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:6.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:7.0`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:7.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.1:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:7.2`,
        fs:  `cpe:2.3:a:oracle:forms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:7.3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:7.4`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:7.5`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:7.6`,
        fs:  `cpe:2.3:a:mcafee:dlp_agent:9.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:8.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:8.1`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:*:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:8.2`,
        fs:  `cpe:2.3:h:enterasys:6h303-48:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:8.3`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:8.4`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:9.0`,
        fs:  `cpe:2.3:a:vmware:infrastructure_client:2.5.0.64247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:9.1`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:9.2`,
        fs:  `cpe:2.3:a:ez:ez_publish:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:9.4`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:9.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:9.6`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:10.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.2:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:10.1`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:10.2`,
        fs:  `cpe:2.3:a:rsa:securid_web_agent:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:10.3`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:10.4`,
        fs:  `cpe:2.3:a:husdawg:system_requirements_lab_for_intel:4.1.66.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:10.4r`,
        fs:  `cpe:2.3:a:gnu:libtool:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:10.4s`,
        fs:  `cpe:2.3:h:sophos:unified_threat_management:120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.0`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.1`,
        fs:  `cpe:2.3:a:promotic:promotic:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.2`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4`,
        fs:  `cpe:2.3:a:remote-rac:rac_server:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r1`,
        fs:  `cpe:2.3:a:threadflip:threadflip_\:_buy_sell_fashion:1.1.11:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r10`,
        fs:  `cpe:2.3:a:microsoft:works:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r11`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.0:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r12`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.54a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r5`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r6`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r7`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r8`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4:r9`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4r13:s2`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:11.4x27`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1:r11`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.19:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1r`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d10`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d15`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d20`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:008:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d25`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-55:-:standard:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d30`,
        fs:  `cpe:2.3:a:docker:docker:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d35`,
        fs:  `cpe:2.3:a:spice_project:spice:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d40`,
        fs:  `cpe:2.3:h:netgear:rt314:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d45`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.12:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d50`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp3:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x44:d55`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x45`,
        fs:  `cpe:2.3:a:adobe:camera_raw:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x45:d10`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x45:d15`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x45:d20`,
        fs:  `cpe:2.3:h:cisco:telepresence_mx300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x45:d30`,
        fs:  `cpe:2.3:h:alphanetworks:vdsl_asl-55052:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d10`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d15`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d20`,
        fs:  `cpe:2.3:h:lexmark:xc8160de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d25`,
        fs:  `cpe:2.3:a:kde:koffice:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d30`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d35`,
        fs:  `cpe:2.3:h:cisco:content_router_4430:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d40`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d45`,
        fs:  `cpe:2.3:h:hp:storageworks_p2000_g3_msa_fibre_channel_dual_controller_sff_array_system:ap846a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d50`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.168:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x46:d55`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x47`,
        fs:  `cpe:2.3:a:ibm:infosphere_guardium:7.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x47:d10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x47:d15`,
        fs:  `cpe:2.3:a:apple:mac_os_runtime_for_java:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x47:d20`,
        fs:  `cpe:2.3:a:electric_cloud:electriccommander:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x47:d25`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x47:d30`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.1x47:d35`,
        fs:  `cpe:2.3:a:webmin:usermin:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r1`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:2.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r3`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r5`,
        fs:  `cpe:2.3:a:gnu:findutils:4.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r6`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r7`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r8`,
        fs:  `cpe:2.3:a:microsoft:directx:7.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2:r8-s2`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.2x65`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7e.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r11`,
        fs:  `cpe:2.3:a:datanamic:dezign_for_databases:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r12`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r13`,
        fs:  `cpe:2.3:h:fortinet:fortigate-50b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r2`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r3`,
        fs:  `cpe:2.3:a:tibco:spotfire_statistics_services:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r4`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r7`,
        fs:  `cpe:2.3:a:boombatower:subuser:7.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r8`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3:r9`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3r12`,
        fs:  `cpe:2.3:a:ca:controlit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x48:d10`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sru:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x48:d15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x48:d25`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x50`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x50:d20`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x50:d30`,
        fs:  `cpe:2.3:a:hp:easy_tools:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x50:d35`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x50:d40`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:12.3x50:d45`,
        fs:  `cpe:2.3:h:fortinet:fortigate-1240b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.1`,
        fs:  `cpe:2.3:a:wp_limit_posts_automatically_project:wp_limit_posts_automatically:0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.1:r1`,
        fs:  `cpe:2.3:a:python:python:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.1:r2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.1:r3`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.1:r4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.1:r4-s2`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.1x49:d45`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.26:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.1x50:d25`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2`,
        fs:  `cpe:2.3:o:huawei:s7706_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r1`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r2`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r3`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r4`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r5`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r6`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r7`,
        fs:  `cpe:2.3:a:google:chrome:7.0.535.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r7-s1`,
        fs:  `cpe:2.3:a:apple:cups:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2:r7-s2`,
        fs:  `cpe:2.3:a:hp:bpd_scan_ent:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x51:d15`,
        fs:  `cpe:2.3:o:cisco:modular_encoding_platform_d9036_software:02.00.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x51:d20`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.2.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x51:d21`,
        fs:  `cpe:2.3:a:cisco:secure_acs_for_unix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x51:d25`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x51:d26`,
        fs:  `cpe:2.3:a:gnu:glibc:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x51:d30`,
        fs:  `cpe:2.3:a:apache:http_server:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x51:d35`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x52:d10`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x52:d15`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ez:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x52:d20`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x52:d25`,
        fs:  `cpe:2.3:a:hp:storageworks_library_and_tape_tools:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.2x52:d5`,
        fs:  `cpe:2.3:a:php:php:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3`,
        fs:  `cpe:2.3:a:enterasys:netsight_console:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r1`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r2`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:ece:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r2-s2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r3`,
        fs:  `cpe:2.3:a:cisco:content_security_management_appliance:9.7.0-006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r4`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.31.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r5`,
        fs:  `cpe:2.3:a:lucent:vitalanalysis:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r6`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r7`,
        fs:  `cpe:2.3:o:dell:sonicwall_sonicos:6.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3:r9`,
        fs:  `cpe:2.3:a:apheliontechnologies:hydfm:1.1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:13.3r9`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1:r1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1:r2`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1:r3`,
        fs:  `cpe:2.3:a:loving.fm:loving_-_couple_essentia:4.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1:r4`,
        fs:  `cpe:2.3:o:samsung:samsung_mobile:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1:r5`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1:r6`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1:r7`,
        fs:  `cpe:2.3:a:rodrigo_coimbra:nospam_pti:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1:r9`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1r7`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x50`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_33:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x51`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x51:d60`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.2.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53`,
        fs:  `cpe:2.3:a:cedrick_collomb:unlocker:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d10`,
        fs:  `cpe:2.3:a:tincan:phplist:1.1.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d15`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d16`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d25`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.4.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d26`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d27`,
        fs:  `cpe:2.3:a:tecolote:aceit:7.2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d30`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d35`,
        fs:  `cpe:2.3:a:microsoft:backoffice:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d40`,
        fs:  `cpe:2.3:a:google:chrome:8.0.559.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:d45`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x53:r1`,
        fs:  `cpe:2.3:a:redhat:kdelibs_devel:2.1.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x55`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x55:d30`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.1x55:d35`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.2:r1`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.2:r2`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.2:r3`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1.0.1753:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.2:r4`,
        fs:  `cpe:2.3:a:kozos:easyctf:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.2:r5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.2:r6`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.2:r7`,
        fs:  `cpe:2.3:a:netapp:system_manager:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:14.2r6`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:a1`,
        fs:  `cpe:2.3:a:nitropdf:nitro_pdf:6.2.0.44:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f1`,
        fs:  `cpe:2.3:a:teradata:bteq:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f2`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f2-s1`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f2-s2`,
        fs:  `cpe:2.3:h:3com:switch_4007r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f2-s3`,
        fs:  `cpe:2.3:o:ibm:aix:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f2-s4`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f3`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f4`,
        fs:  `cpe:2.3:a:samba:samba:2.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f5`,
        fs:  `cpe:2.3:a:vmware:tools:3.1.2.14166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f6`,
        fs:  `cpe:2.3:a:telligent:evolution:6.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:f7`,
        fs:  `cpe:2.3:a:gnu:gnubiff:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:r1`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:r2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:r3`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.53.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:r4`,
        fs:  `cpe:2.3:a:david_king:vino:2.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:r5`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1:r6`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1r2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d10`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.7.3:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d20`,
        fs:  `cpe:2.3:h:siemens:m45:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d30`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d35`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p43:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d40`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d45`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d50`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d55`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-5:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d60`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d65`,
        fs:  `cpe:2.3:a:apache:http_server:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d70`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d75`,
        fs:  `cpe:2.3:a:debian:apache:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x49:d80`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.0.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d20`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d21`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d210`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d25`,
        fs:  `cpe:2.3:a:graphisoft:archicad:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d30`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d32`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d33`,
        fs:  `cpe:2.3:a:openldap:openldap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d34`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.3.91a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d60`,
        fs:  `cpe:2.3:a:mono:mono:1.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d61`,
        fs:  `cpe:2.3:a:google:chrome:6.0.459.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d62`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d63`,
        fs:  `cpe:2.3:a:owncloud:owncloud_desktop:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.1x53:d70`,
        fs:  `cpe:2.3:a:microsoft:excel:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:15.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:16.1:r1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(5\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:16.1:r2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:16.1:r3`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:56.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:16.1:r4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:16.2:r1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:16.2:r2`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:sp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos:17.1:r1`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_e:-`,
        fs:  `cpe:2.3:a:openstack:horizon:2014.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_e:7.0.0`,
        fs:  `cpe:2.3:o:buffalotech:wmr-300_firmware:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_internet_software:-`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:11.2.202.644:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_internet_software:5.2`,
        fs:  `cpe:2.3:h:lexmark:e250:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_internet_software:5.4`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:9.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_j:-`,
        fs:  `cpe:2.3:a:gnome:evolution:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_j:6.3`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:2.7:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_m:-`,
        fs:  `cpe:2.3:a:xymon:xymon:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_m:6.3`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_pulse_access_control_service:4.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_pulse_access_control_service:4.2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_pulse_access_control_service:4.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_pulse_access_control_service:4.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_pulse_secure_access_service:7.1`,
        fs:  `cpe:2.3:a:gnu:grep:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_pulse_secure_access_service:7.2`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:2006.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_pulse_secure_access_service:7.3`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:m5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_pulse_secure_access_service:7.4`,
        fs:  `cpe:2.3:a:withhive:9_innings\:_2014_pro_baseball:4.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:1.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:1.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.1:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:1.2`,
        fs:  `cpe:2.3:a:web2py:web2py:1.81.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:1.3`,
        fs:  `cpe:2.3:h:siemens:scalance_x-408:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:1.4`,
        fs:  `cpe:2.3:a:oracle:apex:3.0.0.00.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:2.0`,
        fs:  `cpe:2.3:h:hp:cc522a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:11.1`,
        fs:  `cpe:2.3:a:openstack:horizon:2013.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:11.2`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:11.3`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:11.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:12.1`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:12.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:12.3`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:13.1:-`,
        fs:  `cpe:2.3:a:clamav:clamav:0.80:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space:13.1:r1.8`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_space:15.1:r1`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_space:15.2:r1`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:junos_space_ja1500_appliance:-`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:junos_space_ja2500_appliance:-`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:junos_space_virtual_appliance:-`,
        fs:  `cpe:2.3:a:adobe:download_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_t:-`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.4.3900.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junos_t:6.3`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose_e:-`,
        fs:  `cpe:2.3:a:apollogrp:riverpoint_writer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose_e:7.0.0`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_internet_security_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose_j:-`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose_j:6.3`,
        fs:  `cpe:2.3:a:hp:openvms:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose_m:-`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose_m:6.3.0`,
        fs:  `cpe:2.3:a:tibco:spotfire_deployment_kit:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose_t:-`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:junose_t:6.3`,
        fs:  `cpe:2.3:h:3com:3c16950-us:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mag2600_gateway:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mag4610_gateway:-`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mag6610_gateway:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mag6611_gateway:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx10:-`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx104:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx2010:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx2020:-`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx240:-`,
        fs:  `cpe:2.3:a:qemu:qemu:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx40:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx480:-`,
        fs:  `cpe:2.3:a:php:pear:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx80:-`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:mx960:-`,
        fs:  `cpe:2.3:a:novell:netmail:3.5.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-5200:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-5400:-`,
        fs:  `cpe:2.3:a:mahara:mahara:17.04.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-5gt:-`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-5gt:5.0`,
        fs:  `cpe:2.3:a:ca:etrust_audit_irecorder:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-idp:3.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.23.266:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-idp:3.0r1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-idp:3.0r2`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-idp_10:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-idp_100:-`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-idp_1000:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:netscreen-idp_500:-`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:netscreen-security_manager:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.1000.504:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:netscreen-security_manager_2004:-`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:8.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:netscreen_remote_security_client:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.27.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:netscreen_remote_security_client:8.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:netscreen_remote_vpn_client:-`,
        fs:  `cpe:2.3:a:sun:jre:6.0.130:update13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:netscreen_remote_vpn_client:8.0`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:-`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:1.64`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:1.66`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.0.0`,
        fs:  `cpe:2.3:a:redhat:rhel_developer_suite:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.1`,
        fs:  `cpe:2.3:a:wegoi:re-volt_2_\:_best_rc_3d_racing:1.2.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.5`,
        fs:  `cpe:2.3:a:brocade:data_center_fabric_manager:10.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.5.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.5r1`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.5r2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.5r6`,
        fs:  `cpe:2.3:a:atlassian:jira:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.0`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:9.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1`,
        fs:  `cpe:2.3:h:hp:color_laserjet_5550:q3714a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r1`,
        fs:  `cpe:2.3:h:f5:edge_fx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r2`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r3`,
        fs:  `cpe:2.3:o:ibm:linux_on_power:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.422:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r5`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r6`,
        fs:  `cpe:2.3:a:netiq:core_services:5.7.0.390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r7`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r8`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r9`,
        fs:  `cpe:2.3:a:idevspot:phphostbot:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r11`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.6.1r12`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:6.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.7.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.7.1`,
        fs:  `cpe:2.3:a:winscp:winscp:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.7.1r1`,
        fs:  `cpe:2.3:a:apache:cxf:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.7.1r2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.7.1r3`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:2.8`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.0`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.0r1`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.0r2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.0r3`,
        fs:  `cpe:2.3:a:cisco:meeting_app:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.0r4`,
        fs:  `cpe:2.3:a:ibm:lotus_mobile_connect:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.1`,
        fs:  `cpe:2.3:o:cisco:headend_system_release:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.1r1`,
        fs:  `cpe:2.3:h:hp:j9585a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.1r2`,
        fs:  `cpe:2.3:o:cisco:nx-os:1.1\(1g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.1r3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.1r4`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.5:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.1r5`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver_r343:345.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.1r6`,
        fs:  `cpe:2.3:a:php:php:5.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.1r7`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.10:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3r1`,
        fs:  `cpe:2.3:a:apache:archiva:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3r2`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3r3`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3r4`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3r5`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3r6`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3r7`,
        fs:  `cpe:2.3:a:perl:perl:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.0.3r8`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p135:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2mra:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r2`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.52:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r3`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r4`,
        fs:  `cpe:2.3:a:oracle:financial_consolidation_hub:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r5`,
        fs:  `cpe:2.3:a:drupal:drupal:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r6`,
        fs:  `cpe:2.3:a:samba:samba:3.0.21a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r7`,
        fs:  `cpe:2.3:a:google:picasa:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r8`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r9`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r10`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r11`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.339:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:3.1.0r12`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.838.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r2`,
        fs:  `cpe:2.3:o:huawei:ngfw_module_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r3`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r4`,
        fs:  `cpe:2.3:h:hp:cf068a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r5`,
        fs:  `cpe:2.3:a:drupal:drupal:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r6`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r7`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r8`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r9`,
        fs:  `cpe:2.3:a:faro:faro_ls:1.1.6.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r10`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53_92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r11`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.0r12`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:6.0\(2\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.4.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r1`,
        fs:  `cpe:2.3:a:mcafee:remote_desktop_32:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r2`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:1600:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r3`,
        fs:  `cpe:2.3:a:hexagon:erdas_apollo_ecwp:13.00.0000:-:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r6`,
        fs:  `cpe:2.3:a:hp:shop_for_hp_supplies:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r7`,
        fs:  `cpe:2.3:h:hp:jg208a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r8`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r9`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.1r10`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.2`,
        fs:  `cpe:2.3:a:docker:docker:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r1`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r2`,
        fs:  `cpe:2.3:a:pgp:desktop_for_windows:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r4`,
        fs:  `cpe:2.3:a:digium:asterisk:11.8.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r6`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r7`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r8`,
        fs:  `cpe:2.3:a:ciphertrust:ironmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:4.0.3r9`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r1`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r2`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r3`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r5`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r7`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:9.4.0.4710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r8`,
        fs:  `cpe:2.3:a:debian:dpkg:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r9`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r10`,
        fs:  `cpe:2.3:a:apple:apple_tv:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.0.0r11`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.20:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.1.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.1.0r1`,
        fs:  `cpe:2.3:a:red-gate:sql_packager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.1.0r2`,
        fs:  `cpe:2.3:a:adobe:flash_player:21.0.0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.1.0r3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.1.0r3a`,
        fs:  `cpe:2.3:a:vips:vips:7.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.1.0r4`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:vista:sp1:x64-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.2.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_configuration_manager_for_atm:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.2.0r1`,
        fs:  `cpe:2.3:h:ibm:ds4100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.2.0r2`,
        fs:  `cpe:2.3:a:citadel:hercules:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.2.0r3`,
        fs:  `cpe:2.3:a:varnish_http_accelerator_integration_project:varnish:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r2`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r3`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r4`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r5`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r6`,
        fs:  `cpe:2.3:a:microsoft:infotech_storage_system_library:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r7`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update3:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r8`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r9`,
        fs:  `cpe:2.3:a:1024cms:1024_cms:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.3.0r10`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1024.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0`,
        fs:  `cpe:2.3:a:apache:activemq_artemis:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.3:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r2`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r3`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r4`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r5`,
        fs:  `cpe:2.3:a:apache:subversion:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r6`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r7`,
        fs:  `cpe:2.3:o:corega:cg-wlbargs_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r8`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r8a`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:5.4.0r9.0`,
        fs:  `cpe:2.3:h:enterasys:dragon:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0r1`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0r2`,
        fs:  `cpe:2.3:a:peernet:file_conversion_center:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0r3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0r4`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.4:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0r5`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ebl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0r6`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0r7`,
        fs:  `cpe:2.3:a:busybox:busybox:1.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.0.0r8`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.1.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.1.0r1`,
        fs:  `cpe:2.3:a:webmin:usermin:1.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.1.0r2`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.1.0r3`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.93.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.1.0r4`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g_firmware:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.2.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:netscreen_screenos:6.2.0r1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:-`,
        fs:  `cpe:2.3:a:elinks:elinks:0.12:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:r1`,
        fs:  `cpe:2.3:a:openttd:openttd:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:r2`,
        fs:  `cpe:2.3:a:siemens:automation_license_manager:5.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:r3`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:r4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:r5`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:r6`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:r7`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_and_security_manager_software:2012.2:r8`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:6.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_connect:6.0.0.12141`,
        fs:  `cpe:2.3:a:ibm:filenet_content_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_connect:6.0.0.12875`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_connect:6.3.0.13725`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_connect:6.4.0.14619`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_connect:6.4.0.15779`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_connect:6.5.0.16091`,
        fs:  `cpe:2.3:a:libpng:libpng:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:network_connect:7.1.0.18193`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:networks_mobility_system_software:7.3`,
        fs:  `cpe:2.3:a:vmturbo:operations_manager:4.5:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:networks_mobility_system_software:7.4`,
        fs:  `cpe:2.3:a:telos:amhs:12.4.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:networks_mobility_system_software:7.5`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:networks_mobility_system_software:7.5.1.6`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_enterprise_http_option:1.4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:networks_mobility_system_software:7.6`,
        fs:  `cpe:2.3:a:microsoft:groove:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:networks_mobility_system_software:7.7`,
        fs:  `cpe:2.3:a:avast:business_security:11.1.2261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:nsm3000:-`,
        fs:  `cpe:2.3:a:epignosis:efront:3.6.15.2:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:nsmexpress:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.2.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:router_m10:-`,
        fs:  `cpe:2.3:a:apple:quicktime:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:router_m16:-`,
        fs:  `cpe:2.3:a:searchblox:searchblox:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:router_m20:-`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:router_m40:-`,
        fs:  `cpe:2.3:a:adobe:update_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:router_m5:-`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:5.4.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.0.0`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.1.0`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.2.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.2.0r15`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.2.0r16`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.2.0r17`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.2.0r18`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0:r12`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:6.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0:r14`,
        fs:  `cpe:2.3:a:avonesoft:movavi_videosuite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0:r15`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0:r16`,
        fs:  `cpe:2.3:a:ca:unicenter_service_delivery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0:r17`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0:r18`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0:r19`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-07-04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:screenos:6.3.0:r20`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:secure_access_2000:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:secure_access_2500:-`,
        fs:  `cpe:2.3:a:gajim:gajim:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:secure_access_4000:-`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:secure_access_4500:-`,
        fs:  `cpe:2.3:a:mesa3d:mesa:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:secure_access_6000:-`,
        fs:  `cpe:2.3:a:gnu:zlib:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:secure_access_6500:-`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:secure_access_700:-`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:secure_access_virtual_appliance:-`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:3.0.0.4.342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:secure_application_manager:6.3.0.14715`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:setup_client_activex_control:1.3.1.6`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:setup_client_activex_control:2.0.0.3`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:setup_client_activex_control:2.1.1.1`,
        fs:  `cpe:2.3:a:ibm:platform_symphony:6.1.1:*:*:*:developer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:smartpass:7.7`,
        fs:  `cpe:2.3:a:hp:fax_cda:71.0.215.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:smartpass:7.7:mr3`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:smartpass:8.0`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:smartpass:8.0:mr2`,
        fs:  `cpe:2.3:a:x:libxres:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx100:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx110:-`,
        fs:  `cpe:2.3:a:digium:asterisk:11.18.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx1400:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx210:-`,
        fs:  `cpe:2.3:a:schneider-electric:modbus_serial_driver:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx220:-`,
        fs:  `cpe:2.3:a:rsa:securid_web_agent:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx240:-`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx3400:-`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx3600:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx5400:-`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx550:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx5600:-`,
        fs:  `cpe:2.3:a:bannersky:bsk_pdf_manager:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx5800:-`,
        fs:  `cpe:2.3:a:apache:commons_email:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:juniper:srx650:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:unified_access_control_software:4.4`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:unified_access_control_software:5.0`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:juniper:vmx:-`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:vpn:1.0.0`,
        fs:  `cpe:2.3:a:ibm:sterling_b2b_integrator:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juniper:vpn:1.1.0.3489`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.1.0`,
        fs:  `cpe:2.3:a:grape_project:grape:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.2.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.2.1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.2.2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.2.3`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.3.0`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.3.2`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.3.3`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-3520c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:juralsulek:realurlmanagement:0.3.4`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ebl:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jurpo:jurpopage:0.2.0`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.24:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jusapp:jusapp%21:3.7.5::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:informix:7.25_.uc1_se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:just-great-software:editpad:6.7.0::~~lite~~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:just-great-software:editpad:v.5.4.6::~~professional~~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1006:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:just-great-software:powergrep:demo_3.5.0`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.58:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justin_dodge:hotblocks:6.x-1.5`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:beta2.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justin_dodge:hotblocks:6.x-1.6`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justin_dodge:hotblocks:6.x-1.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justin_dodge:hotblocks:6.x-1.8`,
        fs:  `cpe:2.3:a:mono:mono:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justin_dodge:hotblocks:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:connections:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justin_ellison:node_gallery:6.x-3.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justin_klein:wp-vipergb:1.3.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok:17`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok:2005`,
        fs:  `cpe:2.3:h:cisco:spa_501g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok:2006:-:windows`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok:2007:-:windows`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok:2008:-:windows`,
        fs:  `cpe:2.3:a:nokia:qt_creator:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok:2009:-:windows`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update4:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok_flat-rate_service:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.409.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok_smile:-`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok_subscription_service:-:windows`,
        fs:  `cpe:2.3:a:debian:apt:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:atok_x3:-:-:linux`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako:2006`,
        fs:  `cpe:2.3:a:opensolution:quick.cms:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako:2007`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1003.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako:2008`,
        fs:  `cpe:2.3:a:john_koleszar:libvpx:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako:2009`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako:2010`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako:2011`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako:2012`,
        fs:  `cpe:2.3:a:vim:vim:8.0.0376:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako:2013`,
        fs:  `cpe:2.3:a:oscommerce:online_merchant:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako_police:-`,
        fs:  `cpe:2.3:a:apple:quicktime:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako_police:2010`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_mobile:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:hanako_police3:-`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:6:-:government`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.2:interim:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:7:-:government`,
        fs:  `cpe:2.3:a:sun:netdynamics:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:10`,
        fs:  `cpe:2.3:a:jojocms:jojo-cms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:11`,
        fs:  `cpe:2.3:a:jenkins:git:2.4.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:12`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:13`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2004`,
        fs:  `cpe:2.3:h:johnsoncontrols:pegasys_p2000_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2005`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2006`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2006:-:government`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2007`,
        fs:  `cpe:2.3:a:pswitch:imail:8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2007:-:government`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2008`,
        fs:  `cpe:2.3:a:google:chrome:14.0.821.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2008:-:government`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2009`,
        fs:  `cpe:2.3:a:iconics:bizviz:9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2009:-:government`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.0.p-3531-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2009:-:trial`,
        fs:  `cpe:2.3:a:apache:activemq:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2010`,
        fs:  `cpe:2.3:h:supermicro:x9scl-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2010:-:government`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2011`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2011:-:sou`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.87.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2012:-:shou`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2013:-:gen`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2013:-:gen_trial`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2014`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2014:-:~~tetsu~~~`,
        fs:  `cpe:2.3:a:symantec:message_gateway:10.6.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:2014:-:~~tetsu_trial~~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro:bungei`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro_portable:-:oreplug`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro_portable_with_oreplug:-`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.6:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro_viewer:-`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:1.0:ur1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro_viewer:19.0.1.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro_viewer:19.0.2.0`,
        fs:  `cpe:2.3:a:emc:networker:7.6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro_viewer:19.0.3.0`,
        fs:  `cpe:2.3:a:heinz_richter:mod_auth_mda:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:ichitaro_viewer:20.0.2.0`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_frontier:-`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_jump:4`,
        fs:  `cpe:2.3:a:horde:groupware:1.1:rc4:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_online_update:-`,
        fs:  `cpe:2.3:a:epson:twain:5.71.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_school:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a6\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_school:2009`,
        fs:  `cpe:2.3:a:aol:aim:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_school:2010`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_smile:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jnb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_smile:2`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_smile:3`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:just_smile:4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:oreplug:-`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.22:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:rekishimail_bakumatsushishi_no_missho:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:rekishimail_sengokubusho_no_missho:-`,
        fs:  `cpe:2.3:a:util-linux_project:util-linux:2.29.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken:2007`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken:2007:-:corporate`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken:2008`,
        fs:  `cpe:2.3:a:google:api_search:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken:2008:-:corporate`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken:2009`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken:2009:-:corporate`,
        fs:  `cpe:2.3:a:microsoft:project:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken:2010`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken:2010:-:corporate`,
        fs:  `cpe:2.3:a:avaya:ip_soft_phone:6.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken_pro:4`,
        fs:  `cpe:2.3:a:citrix:web_interface_for_metaframe_presentation_server:4.0.45083\#28412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:justsystems:shuriken_pro:4:-:corporate`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jwcrypto_project:jwcrypto:0.3.1`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:jxplorer:jxplorer:3.2.1`,
        fs:  `cpe:2.3:a:gcspublishing:biplane_forum:3.7.14:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:jython_project:jython:2.2.1`,
        fs:  `cpe:2.3:a:umn:mapserver:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jzip:jzip:1.3`,
        fs:  `cpe:2.3:a:x:xf86-video-intel:2.99.911:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:jzip:jzip:2.0.0.132900`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k-litecodec:k-lite_codec:10.4.5`,
        fs:  `cpe:2.3:a:kde:koffice:2.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k2top:k2editor:1.5.8`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k2top:k2editor:1.5.9`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k5n:webcalendar:0.9.45`,
        fs:  `cpe:2.3:a:shavlik:netchk_compliance:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k5n:webcalendar:1.0.4`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k5n:webcalendar:1.2.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k5n:webcalendar:1.2.3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:8:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k5n:webcalendar:1.2.4`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k7computing:anti-virus_plus:14.2.0.252`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k7computing:antivirus:9.77.3565`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k7computing:k7av_sentry_device_driver:12.8.0.118`,
        fs:  `cpe:2.3:h:oracle:sparc_t4-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k7computing:k7firewall_packet_driver:14.0.1.15`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:-:*:aix:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k7computing:k7sentry.sys:12.8.0.117`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k7computing:total_security:14.2.0.252`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:k7computing:ultimate_security:14.2.0.252`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kadinlar_kulubu_kkmobileapp_project:kadinlar_kulubu_kkmobileapp:3.4.3::~~~android~~`,
        fs:  `cpe:2.3:h:cisco:unified_wireless_ip_phone_7920:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kadu:kadu:0.4.2`,
        fs:  `cpe:2.3:h:juniper:mx2010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kadu:kadu:0.4.3`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kadu:kadu:0.5:pre`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kadu:kadu:0.9.0`,
        fs:  `cpe:2.3:a:bmc:software_control-m_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kadu:kadu:0.10.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kadu:kadu:0.11.0`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kadu:kadu:0.11.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.1.0`,
        fs:  `cpe:2.3:a:sun:netdynamics:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.1.1`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.2.0`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.2.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.3.0`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.3.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.4.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.4.1`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7965g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:3.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:4.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:4.1`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:4.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:4.3`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:4.4`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:4.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.09:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kajona:kajona:4.6.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kalahari:kalahari.com_shopping:1.4.2.1::~~~android~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kallithea:kallithea:0.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kallithea:kallithea:0.2`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kamailio:kamailio:4.3.4`,
        fs:  `cpe:2.3:a:oracle:cadview-3d:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kamkomesan_project:kamkomesan:1::~~~android~~`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.91:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kan-studio:kandidat_cms:1.4.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kana:iq:7.0.2`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kana:iq:7.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:4.0\(1.57\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kana:iq:7.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kana:knowledge_editor:7.0.2.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kana:knowledge_server:7.0.2.0`,
        fs:  `cpe:2.3:a:novell:bordermanager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.1`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.4`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.5`,
        fs:  `cpe:2.3:a:hp:release_control:9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.6`,
        fs:  `cpe:2.3:a:pcman\&#39;s_ftp_server_project:pcman\&#39;s_ftp_server:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.7`,
        fs:  `cpe:2.3:a:rack_project:rack:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.8`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.9`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.10`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.12`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.13`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.14`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.15`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.16`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.13:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.17`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.18`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.19`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.20`,
        fs:  `cpe:2.3:a:gnome:glib:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.21`,
        fs:  `cpe:2.3:a:gnome:glib:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.22`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update1_b06:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.23`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.24`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3a2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.25`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.26`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.27`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.17s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.28`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.29`,
        fs:  `cpe:2.3:a:wp_microblogs_project:wp_microblogs:0.4.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.30`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.31`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p428:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.32`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.0.1.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.33`,
        fs:  `cpe:2.3:h:cisco:asr_1002-x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.34`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.35`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.36`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.37`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.47:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.38`,
        fs:  `cpe:2.3:a:piwik:piwik:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.39`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.40`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.41`,
        fs:  `cpe:2.3:a:web2py:web2py:1.93.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.42`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.43`,
        fs:  `cpe:2.3:h:hp:j9866a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.44`,
        fs:  `cpe:2.3:a:s3graphics:s3_graphics_utilities:3.6401.25d30-0427:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.45`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.46`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanboard:kanboard:1.0.47`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:1.2`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x47:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:1.3`,
        fs:  `cpe:2.3:a:ibm:worklight:6.0.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:2.0.1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:2.0.4`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:2.1.0`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:2.1.1`,
        fs:  `cpe:2.3:a:synology:diskstation_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:3.0.1`,
        fs:  `cpe:2.3:a:x.org:libxrender:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:3.0.2`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:3.0.3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:3.1.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kanich:com_searchlog:3.1.1`,
        fs:  `cpe:2.3:a:americostech:selfshot_front_flash_camera:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:kankun:smartsocket:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.07.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:beta`,
        fs:  `cpe:2.3:a:gnome:glib:2.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:beta2`,
        fs:  `cpe:2.3:a:adobe:camera_raw:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:beta3`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:beta4`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.91.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:rc1`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:rc2`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:rc3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:rc4`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:rc5`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.0:rc6`,
        fs:  `cpe:2.3:h:hp:jetdirect_250m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.2`,
        fs:  `cpe:2.3:a:perl:perl:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.3`,
        fs:  `cpe:2.3:a:radscan:network_audio_system:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.4`,
        fs:  `cpe:2.3:a:lucent:radius:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.6`,
        fs:  `cpe:2.3:a:plone:plone:5.1:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.7`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karen_stevenson:date:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karenware:karen%27s_power_tools:8.4.7`,
        fs:  `cpe:2.3:a:php:php:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karlen_walter:si_bibtex:0.2.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:broadcom:management_programs:11.88.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karsten_dusterloh:mnenhy:0.7.5.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:karsten_dusterloh:mnenhy:0.7.5.666`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaseya:virtual_system_administrator:6.5`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaseya:virtual_system_administrator:6.5.0.17`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaseya:virtual_system_administrator:7.0`,
        fs:  `cpe:2.3:a:blaine_lang:filedepot:6.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaseya:virtual_system_administrator:7.0.0.16`,
        fs:  `cpe:2.3:o:cisco:ios:15.4t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaseya:virtual_system_administrator:8.0.0.17`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing:10.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaseya:virtual_system_administrator:9.0.0.13`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaseya:virtual_system_administrator:9.1.0.3`,
        fs:  `cpe:2.3:a:apache:santuario_xml_security_for_java:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:0.7`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:1.1`,
        fs:  `cpe:2.3:a:namazu:namazu:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:1.01`,
        fs:  `cpe:2.3:a:luke_kenneth_casson_leighton:pam_ntdom:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:1.2`,
        fs:  `cpe:2.3:a:apache:poi:1.7:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:1.5`,
        fs:  `cpe:2.3:a:piwik:piwik:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:1.6`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.51:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:1.9`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.0`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.1`,
        fs:  `cpe:2.3:h:fortinet:fortigate-3140b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.2`,
        fs:  `cpe:2.3:a:mybb:ajax_forum_stat:2.0:-:*:*:*:mybb:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.10.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.3.2`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.3.3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:08-00-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.4`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.8:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.5`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.5.1`,
        fs:  `cpe:2.3:a:tibco:spotfire_professional:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kashif_masud:textdroid:2.5.2`,
        fs:  `cpe:2.3:a:webmin:usermin:1.570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kasper_skarhoj:accessible_is_browse_results:1.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ire:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaspersky:kaspersky_internet_security:11.4.4.232::~~~android~~`,
        fs:  `cpe:2.3:a:rovicorp:sonic_cineplayer_decoder_pack:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaspersky:total_security_2015:15.0.2.361`,
        fs:  `cpe:2.3:a:php:php:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kate_mobile:vk_kate_mobile:9.6.1::~~~android~~`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view_appliance_iso:6.3.33-2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello:1.5.0-14`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.2`,
        fs:  `cpe:2.3:h:hp:0235a267:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.4`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.5`,
        fs:  `cpe:2.3:a:x3cms:x3_cms:0.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.6`,
        fs:  `cpe:2.3:a:apache:hive:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.7`,
        fs:  `cpe:2.3:a:phpace:samswhois:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.9`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.10`,
        fs:  `cpe:2.3:a:avaya:integrated_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.11`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:beta_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.12`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.13`,
        fs:  `cpe:2.3:a:mollify:mollify:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.14`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.15`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.16`,
        fs:  `cpe:2.3:a:ibm:security_appscan:5.6.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.17`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:katello:katello_installer:0.0.18`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:0.0.0:-`,
        fs:  `cpe:2.3:a:apple:webkit:512.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:0.1.0`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:0.2.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:0.3.0`,
        fs:  `cpe:2.3:a:google:android_api:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:0.8.0`,
        fs:  `cpe:2.3:a:barebones:textwrangler:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:1.0.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:1.0.1`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:1.0.2`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_framework_project:kay_framework:1.1.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kay_messerschmidt:com_eventcal:1.6.4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kayako:fusion:4.40.1148`,
        fs:  `cpe:2.3:a:wolfcms:wolf_cms:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kayako:fusion:4.50.1581`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaylon:powermarks:3.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kaylon:powermarks:3.5`,
        fs:  `cpe:2.3:a:apache:roller:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kazakhstan_radio_project:kazakhstan_radio:2.5::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:global_order_promising:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:0.99`,
        fs:  `cpe:2.3:a:x.org:x11:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.01`,
        fs:  `cpe:2.3:a:netcreators:irfaq:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.03`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-backup:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.04`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.05`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.06`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.08`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.10`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.11`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.12`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:3.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.13`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.14`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.14.1`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15:-`,
        fs:  `cpe:2.3:a:wec_map_project:wec_map:3.0.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15:rc1`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15.1:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.27.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15.1:rc1`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.5.6:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15.1:rc2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15.3:rc1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.1.1.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15.4`,
        fs:  `cpe:2.3:h:cisco:telepresence_video_communication_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbd-project:kbd:1.15.5`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:3.093::pro`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:4.04::pro`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.0::le`,
        fs:  `cpe:2.3:a:adobe:photoshop:19.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.0::pro`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.02::le`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.02::pro`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.03::le`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.03::pro`,
        fs:  `cpe:2.3:h:linksys:wrt54gc:1.03.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.04::le`,
        fs:  `cpe:2.3:a:hp:shared_trace_service:a.07.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.04::pro`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.10::le`,
        fs:  `cpe:2.3:a:sap:router:720:411:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.10::pro`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.20::le`,
        fs:  `cpe:2.3:h:hp:laserjet_m4555h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kbs:weblygo:5.20::pro`,
        fs:  `cpe:2.3:a:libav:libav:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kddi:home_spot_cube:-`,
        fs:  `cpe:2.3:a:sybase:financial_fusion_consumer_banking_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:kddi:home_spot_cube_firmware:2.0`,
        fs:  `cpe:2.3:a:lightdm_project:lightdm:1.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.6`,
        fs:  `cpe:2.3:a:iconics:bizviz:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.9`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.10`,
        fs:  `cpe:2.3:h:cisco:ips_4260:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.12`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.13`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.14`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.15`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.16`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.17`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.18`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:ark:2.19`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kauth:5.0`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kauth:5.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde-workspace:4.2.0`,
        fs:  `cpe:2.3:a:sybase:sql_anywhere_documentation:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde-workspace:4.10.5`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde-workspace:4.11.13`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.21:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_applications:14.11.3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:2.2.0`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:3.5.10`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0:alpha1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0:alpha2`,
        fs:  `cpe:2.3:a:gnome:tomboy:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0:beta1`,
        fs:  `cpe:2.3:a:bluechip:bc_post2facebook:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0:beta2`,
        fs:  `cpe:2.3:a:apache:ranger:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0:beta3`,
        fs:  `cpe:2.3:a:mcafee:groupshield_for_exchange:7.0.913.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0:beta4`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0:rc1`,
        fs:  `cpe:2.3:a:wibusys:codemeter_runtime_kit:3.30.0.500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.0:rc2`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.1`,
        fs:  `cpe:2.3:a:vmware:infrastructure_update:2.5.0.64237:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.2`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.3`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.4`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.0.5`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.0`,
        fs:  `cpe:2.3:a:umn:mapserver:7.0.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.0:alpha1`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:10.1.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.0:beta1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-72-\/d:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.0:beta2`,
        fs:  `cpe:2.3:a:altiris:agent_for_unix_and_linux_documentation:6.2.1048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.0:rc`,
        fs:  `cpe:2.3:a:emulex:fibre_channel_hbanyware:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.2`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.3`,
        fs:  `cpe:2.3:a:monotone:monotone:0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.4`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.80`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.85`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.6:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.1.96`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.2:beta2`,
        fs:  `cpe:2.3:a:bizagi:business_process_management_suite:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.2:rc`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.2.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.2.1`,
        fs:  `cpe:2.3:a:apprain:apprain:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.2.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.2.3`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.2:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.2.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8\)ea:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.0:beta1`,
        fs:  `cpe:2.3:a:apple:cups:1.1.21:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.0:beta3`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.0:rc1`,
        fs:  `cpe:2.3:a:hp:productcontext:50.0.165.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.0:rc2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.0:rc3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.438:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.2`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.4`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.3.5`,
        fs:  `cpe:2.3:o:f5:tmos:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.0`,
        fs:  `cpe:2.3:a:gnu:enscript:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.0:beta1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.0:beta2`,
        fs:  `cpe:2.3:a:yourfreeworld:banner_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.0:rc1`,
        fs:  `cpe:2.3:a:novell:netmail:3.52c1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.0:rc2`,
        fs:  `cpe:2.3:a:synergy-foss:synergy:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.0:rc3`,
        fs:  `cpe:2.3:a:augeas:augeas:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.2`,
        fs:  `cpe:2.3:a:ibm:sametime:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.3`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.4`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.4.5`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.5.0`,
        fs:  `cpe:2.3:o:netbsd:netbsd:4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.5.1`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.02.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.6.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.6.1`,
        fs:  `cpe:2.3:a:analogx:atomic_timesync:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.6.2`,
        fs:  `cpe:2.3:a:emc:watch4net:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.6.3`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(23a\)bc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.6.4`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.6.5`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.7.0`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.7.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_server:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.7.2`,
        fs:  `cpe:2.3:a:helios:textpad:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.7.4`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kde_sc:4.10.5`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.15:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.10.0`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.10.1`,
        fs:  `cpe:2.3:a:smartstudy:pinkfong_tv:4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.10.2`,
        fs:  `cpe:2.3:a:symantec:veritas_authentication_service:4.3.32.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.10.3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1062.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.10.95`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-00-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.10.97`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.0`,
        fs:  `cpe:2.3:a:nortel:meridian_sl100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.2`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:14.0.0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.3`,
        fs:  `cpe:2.3:a:adobe:dreamweaver_cs4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.4`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00-\/e:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.5`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.80`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.90`,
        fs:  `cpe:2.3:a:dadabik:dadabik:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.95`,
        fs:  `cpe:2.3:a:acquia:commons:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.11.97`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.04.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.3`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.09:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.4`,
        fs:  `cpe:2.3:a:veritas:netbackup:4.5.0:mp7:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.80`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1689.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.90`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.503:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.95`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.12.97`,
        fs:  `cpe:2.3:a:ibm:jazz_reporting_service:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.13.0`,
        fs:  `cpe:2.3:a:mailcwp_project:mailcwp:1.100:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.13.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.13.2`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_cms:4.5.7:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.13.3`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.20.587:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.13.80`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.13.90`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.13.95`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.13.97`,
        fs:  `cpe:2.3:a:nagios:nagios:4.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kdelibs:4.14`,
        fs:  `cpe:2.3:a:teradata:multiload:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kmail:4.4.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kmail:5.3.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.2`,
        fs:  `cpe:2.3:a:dotproject:dotproject:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.2.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3`,
        fs:  `cpe:2.3:a:isc:bind:9.6.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3:beta1`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3:beta2`,
        fs:  `cpe:2.3:a:apache:struts:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3:beta3`,
        fs:  `cpe:2.3:a:gannett:argus_leader_print_edition:6.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.04:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3.2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3.3`,
        fs:  `cpe:2.3:a:netscape:messanger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3.4`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.3.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.4`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.4.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.4.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p126:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:1.6.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.2.0`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.2.1`,
        fs:  `cpe:2.3:h:huawei:campus_lsw_s9700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.2.2`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.3:beta1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.3:beta2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.3:beta3`,
        fs:  `cpe:2.3:a:imember360:imember360:3.4.017:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.3:beta4`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:9.00.00.3349:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.3:rc1`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.3.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.3.1`,
        fs:  `cpe:2.3:a:wdc:smartware:1.4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:koffice:2.3.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:kscreenlocker:5.5.4`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:plasma-desktop:5.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:plasma-workspace:5.1`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:11.10.tb4tl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kde:plasma-workspace:5.4.3`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kdirstat_project:kdirstat:2.7.0`,
        fs:  `cpe:2.3:a:connectiva:linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kdirstat_project:kdirstat:2.7.3`,
        fs:  `cpe:2.3:a:apache:poi:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kedit:kedit_for_windows:1.60_service_level_1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.8`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.81`,
        fs:  `cpe:2.3:a:analog:soundmax:6.10.1.5450:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.82`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.83`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.83:b`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.2:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.84`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-10-19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.85`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.13.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.86`,
        fs:  `cpe:2.3:a:apple:cups:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.87`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.88:a`,
        fs:  `cpe:2.3:h:ge:bently_nevada_3500\/22m_usb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.89`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.90:a`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:101n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.91`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.92:a`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:449:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.93:a`,
        fs:  `cpe:2.3:a:logitech:erlt:1.20.138.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.93:b`,
        fs:  `cpe:2.3:a:freetype:freetype:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.94:a`,
        fs:  `cpe:2.3:a:ibm:lotus_symphony:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.95:a`,
        fs:  `cpe:2.3:a:ibm:api_management:3.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.95:b`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.96:a`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.96:b`,
        fs:  `cpe:2.3:a:securecomputing:safeword_remoteaccess:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.97:a`,
        fs:  `cpe:2.3:h:nvidia:geforce_gtx_1070:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.97:b`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.97:c`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.98:a`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.98:b`,
        fs:  `cpe:2.3:a:apache:subversion:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.99:a`,
        fs:  `cpe:2.3:a:wysigot:wysigot:6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.99:b`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:0.99:c`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.00`,
        fs:  `cpe:2.3:o:juniper:junos:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.01`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.02`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.03`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.04`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.05`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:1.5.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.06`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.07`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.08`,
        fs:  `cpe:2.3:a:git-scm:git:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.09`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.10`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc2434:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.11`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.8:cert2_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.12`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.13`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.14`,
        fs:  `cpe:2.3:a:ibm:db2:11.1.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.15`,
        fs:  `cpe:2.3:a:siemens:simatic_pcs7:8.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.16`,
        fs:  `cpe:2.3:a:aol:aolserver:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.17`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.18`,
        fs:  `cpe:2.3:a:shopware:shopware:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.19`,
        fs:  `cpe:2.3:o:cisco:mds_9000_san-os:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.19:b`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.20`,
        fs:  `cpe:2.3:h:huawei:s2300:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.21`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.22`,
        fs:  `cpe:2.3:a:piwik:piwik:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.23`,
        fs:  `cpe:2.3:a:csc:tsrserviceclient:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:1.24`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.00`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.01`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.02`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.7.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.03`,
        fs:  `cpe:2.3:a:schneems:wicked:0.3.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.04`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.05`,
        fs:  `cpe:2.3:a:borland:starteam_sdk_runtime:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.06`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.07`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.08`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sre0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.09`,
        fs:  `cpe:2.3:a:cisco:ip_interoperability_and_collaboration_system:4.7\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.10`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.11`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.12`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:009:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.13`,
        fs:  `cpe:2.3:a:dadabik:dadabik:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.14`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.15`,
        fs:  `cpe:2.3:h:supermicro:x8dtl-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.16`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.17`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.18`,
        fs:  `cpe:2.3:a:nodejs:node.js:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.19`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:keepass:2.20`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2012-01-25a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:password_safe:1.6`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1032:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:password_safe:2.10`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:password_safe:2.13`,
        fs:  `cpe:2.3:a:kajona:kajona:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keepass:password_safe:2.16`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keil-software:photokorn_gallery:1.81`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kelly_d._redding:kelredd-pruview:0.2.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00-10:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kelly_d._redding:kelredd-pruview:0.2.2`,
        fs:  `cpe:2.3:a:novaboard:novaboard:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kelly_d._redding:kelredd-pruview:0.2.3`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kelly_d._redding:kelredd-pruview:0.2.4`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kelly_d._redding:kelredd-pruview:0.3.0`,
        fs:  `cpe:2.3:a:roderick_baier:weberknecht:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kelly_d._redding:kelredd-pruview:0.3.8`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kellygerards:mr.sausage:1.301::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:cognos_business_intelligence:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kencast:fazzt_enterprise_server:8.2.0.0`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_dompdf:0.0.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:0.1.1`,
        fs:  `cpe:2.3:a:gnu:gdb:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:0.2.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:0.3.0`,
        fs:  `cpe:2.3:h:supermicro:h8dct-hibqf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.0.0`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.0.1`,
        fs:  `cpe:2.3:a:apache:tomcat:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.0.2`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:585:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.1.0`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.1.1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.2.0`,
        fs:  `cpe:2.3:a:posh_project:posh:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.3.0`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.3.1`,
        fs:  `cpe:2.3:a:attachmate:reflection_x:13.0.0307:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.4.0`,
        fs:  `cpe:2.3:a:codiad:codiad:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kennziffer:ke_search:1.4.1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kent-web:clip-mail:3.3`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kent-web:clip_board:2.91`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kent-web:clip_board:4.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kent-web:clip_board:4.02`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.29.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kent-web:joyful_note:2.8`,
        fs:  `cpe:2.3:a:symantec:private_branch_exchange:1.3.26.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kent-web:joyful_note:5.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.170:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:kent-web:joyful_note:5.21`,
        fs:  `cpe:2.3:a:yahoo:messenger:7.5.0.814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kent-web:post-mail:6.62`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.0.1176.0`,
        fs:  `cpe:2.3:a:pygments:pygments:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.1.71.0`,
        fs:  `cpe:2.3:h:supermicro:x9srl-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.2.133.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.3.118.0`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.4.131.0`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0g_pk3_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.4.135.0`,
        fs:  `cpe:2.3:a:cisco:unified_video_advantage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.5.94.0`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.9:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.5.98.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.6.122.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ew4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.7.84.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.8.109.0`,
        fs:  `cpe:2.3:h:intel:server_board_se7500wv2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.9.170.0`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.10.205.0`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.11.250.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.11.262.0`,
        fs:  `cpe:2.3:o:y-cam:ycw001_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.11.263.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.12.140.0`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kepware:kepserverex_communications_platform:5.12.142.0`,
        fs:  `cpe:2.3:a:sympa:sympa:2.5.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kerigwa:viper:1.5.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kerio:control:8.3.0`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:kerio:control:8.3.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.56:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kerio:control:8.3.2`,
        fs:  `cpe:2.3:a:drupal:drupal:7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.1.0`,
        fs:  `cpe:2.3:a:hp:photosmart_essentials:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.2.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.2.1`,
        fs:  `cpe:2.3:a:mediawiki:rssreader:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.3.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.4.0`,
        fs:  `cpe:2.3:o:cisco:scientific_atlanta__dpr2325_firmware:2.0.2:r1262-090417:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.5.0`,
        fs:  `cpe:2.3:a:microsoft:excel:2002:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.6.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.6.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.6.2`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.6.3`,
        fs:  `cpe:2.3:a:apple:itunes:4.5.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.7.0`,
        fs:  `cpe:2.3:a:trick_question_project:trick_question:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.7.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.8.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.8.1`,
        fs:  `cpe:2.3:a:innominate:mguard_industrial_rs:bd-501000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.9.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:0.99.10.0`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.0.0`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.0.1`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.0.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.0.3`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.0.4`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.1.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.1.1`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.1.2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.1.3`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.1.4`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.5.4770.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:linux-pam:1.1.8`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:util-linux:2.14.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:util-linux:2.17.2`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p371:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kernel:util-linux:2.22`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.0`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.0:cr1`,
        fs:  `cpe:2.3:a:trillian:trillian:5.1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.2`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.3`,
        fs:  `cpe:2.3:a:pixman:pixman:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.4`,
        fs:  `cpe:2.3:a:att:natural_voices_crystal_16k:1.4.0011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.5`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:6:-:government:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.6`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:2.5.7`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:3.0.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keycloak:keycloak-nodejs-auth-utils:3.0.0:cr1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keyinternet:invex:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:x:libxext:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keymetricsoft:foldersizes:4.7.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keywen:easydl:3.04`,
        fs:  `cpe:2.3:h:moxa:iologic_e2210-t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keyword_research_project:keyword_research:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.32.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:keyword_strategy_internal_links_project:keyword_strategy_internal_links:2.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2\(1.901\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kftc:www.knote.kr_smart:1.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:sir:gnuboard:4.31.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kgb_project:kgb:1.0b4`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kicksend:kicksend%3a_share_%26_print_photos:3.3.2.18::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kicksend:kicksend_photo_prints:1.0.7::~~~android~~`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kidasa:milestones_2008:11.0.0::~~professional~~~`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kidasa:milestones_2010:12.0.0::~~professional~~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.2\(2i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kieranoshea:calendar:1.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kieranoshea:calendar:1.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:php:bloq:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:killer_screen_lock_project:killer_screen_lock:0.5::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kind_editor:4.1.12`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.01:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:3.5.6`,
        fs:  `cpe:2.3:a:eviware:soapui:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.0`,
        fs:  `cpe:2.3:a:misp:misp:2.4.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.0.1`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.0.2`,
        fs:  `cpe:2.3:a:google:sketchup:6.0:maintenance_6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.0.3`,
        fs:  `cpe:2.3:a:xavoc:xepan_cms:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.13.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.0.5`,
        fs:  `cpe:2.3:a:ubi:uplay_pc:4.6.1.3217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.0.6`,
        fs:  `cpe:2.3:a:vips:vips:7.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.1`,
        fs:  `cpe:2.3:a:myrephp:myre_business_directory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tc3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.3`,
        fs:  `cpe:2.3:a:rewardingyourself:rewardingyourself:-:*:*:*:*:blackberry:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.5`,
        fs:  `cpe:2.3:a:openstack:neutron:juno3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.6`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.7`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1\(3\)sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.8`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.9`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.10`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.11:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.11`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.3:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:kindsoft:kindeditor:4.1.12`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:kdrive:1.21.0.1878:-:~-~personal~windows~~`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:kingsoft_antivirus:2010.04.26.648`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:office_2012:8.1.0.3238`,
        fs:  `cpe:2.3:a:csounds:csound:5.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:office_2012:8.1.0.3385`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:office_2013:9.1.0.4256`,
        fs:  `cpe:2.3:a:adobe:pixel_bender_toolkit:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:personal_firewall_9:2009.05.07.70:-:plus`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:spreadsheets_2012:8.1.0.3030`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.299:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:writer_2007:-`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:5200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:writer_2010:2723`,
        fs:  `cpe:2.3:a:citrix:access_gateway_plug-in:10.0:*:*:*:enterprise:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:writer_2010:2724`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoft:writer_2012:8.1.0.3030`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110808:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kingsoftsecurity:kingsoft_antivirus:2010.04.26.648`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kinsey:infor-lawson:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p1_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kiosklogix:designerpro:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p150:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kiosklogix:shellpro:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kiragames:unblock_me_free:1.4.4.2::~~~android~~`,
        fs:  `cpe:2.3:a:capasystems:performance_guard:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kishore_asokan:kish_guest_posting_plugin:1.0`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kishore_asokan:kish_guest_posting_plugin:1.1`,
        fs:  `cpe:2.3:a:gnu:gimp:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kishore_asokan:kish_guest_posting_plugin:1.2`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kiwix:kiwix:0.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kk-osk:advance-flow:4.41`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit-32:11.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kk-osk:advance-flow_forms:4.41`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:01-02-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kktalk:kktalk:4.0.0`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kktalk:kktalk:4.1.5`,
        fs:  `cpe:2.3:a:sympa:sympa:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:klassens_project:klassens:1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:9.5\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:klever:pumpkin:2.7.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kmart:kmart:%407f0c00ef::~~~android~~`,
        fs:  `cpe:2.3:o:asus:rt-ac66u_firmware:3.0.0.4.246:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kmart:kmart:6.2.8::~~~android~~`,
        fs:  `cpe:2.3:a:atheme:atheme:7.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kmonos:xacrett:49`,
        fs:  `cpe:2.3:a:ibm:spss_statistics:24.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kmonos:xacrett:50`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kmonos:xacrett:51`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgetree:knowledgetree:3.5`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgetree:knowledgetree:3.5.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgetree:knowledgetree:3.5.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_conductor:xc3:prealpha0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgetree:knowledgetree:3.5.4a`,
        fs:  `cpe:2.3:a:nancy_wichmann:announcements:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgetree:knowledgetree:3.6`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sru:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgetree:knowledgetree:3.7`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgetree:knowledgetree:3.7.0.1`,
        fs:  `cpe:2.3:a:macromedia:dreamweaver_ultradev:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgetree:knowledgetree:3.7.0.2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:knowledgeview:knowledgeview_editorial_and_management_application:-`,
        fs:  `cpe:2.3:a:divx:player:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kodak:dc210:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kodak:image_viewer:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kodak:image_viewer:1.0.0.0`,
        fs:  `cpe:2.3:a:oracle:essbase_server:11.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kodak:professional_8670_ps_thermal_printer:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3jed:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koenigsleiten77:konigsleiten:1::~~~android~~`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kofax:virtualrescan:4.0.71`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kofax:virtualrescan:4.10.39`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kofax:virtualrescan:4.50.32`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:5.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.00`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.00:alpha1`,
        fs:  `cpe:2.3:a:simbiotnetwork:simgene:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.00:alpha2`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.00:beta`,
        fs:  `cpe:2.3:a:invensys:dassidirect:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.01`,
        fs:  `cpe:2.3:a:busybox:busybox:1.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.02`,
        fs:  `cpe:2.3:o:hp:hp-ux:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.03`,
        fs:  `cpe:2.3:a:intel:inbusiness_email_station:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.04`,
        fs:  `cpe:2.3:a:horde:imp:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.05`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control:6.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.06`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.07`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.08`,
        fs:  `cpe:2.3:a:microsoft:outlook_connector:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.09`,
        fs:  `cpe:2.3:a:adobe:photoshop:cs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.10`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.11`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.12`,
        fs:  `cpe:2.3:h:cisco:catalyst_6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.13`,
        fs:  `cpe:2.3:a:dotcms:dotcms:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.14`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.14.15`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.00`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.00:beta`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.00:pkg`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.11:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.00:rc`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_9971_firmware:9.4\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.01`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.4:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.02`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.03`,
        fs:  `cpe:2.3:a:awebsupport:aweb_cart_watching_system_for_virtuemart:2.6.0:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.04`,
        fs:  `cpe:2.3:a:redmine:redmine:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.05`,
        fs:  `cpe:2.3:a:webmin:usermin:1.550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.06`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s7503e-s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.07`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.08`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.09`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.10`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.16.11`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2016:cumulative_update_5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.18.0`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.18.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.20.00`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koha:koha:3.20.00:beta`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kokuyo:camiapp:1.21.1::~~~android~~`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kokuyo:camiapp:1.21.2::~~~android~~`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)ja5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:logitech:quickcam_software:8.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:aegirproject:hostmaster:6.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:aironet_access_point_software:8.4\(1.82\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:visual_database_tools_database_designer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:logitech:lws_videoeffects:13.0.1774.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.38.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:jf283a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:web_cache:11.1.1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.465:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:software_agent_for_microsoft_terminal_server:9.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:607:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.585:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:7-zip:p7zip:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:bpdsoftware_ini:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.9:rc1:~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.9:rc2:~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.0-109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:2.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:misc:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cabletron:2h252-25r:5.07.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows_8:consumer_preview:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:h:htc:glacier:frg83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.100.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.10:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:catos:6.4\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:encore_cs3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a5:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:trendmicro:interscan_web_security_virtual_appliance:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.2:rc1:~~~wordpress~~`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:siebel_ui_framework:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.2.1.1591:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-2830c_firmware:t450sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.4:rc2:~~~wordpress~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.95.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.4:rc3:~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:solarwinds:scp_server:1.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:me:scd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:java_virtual_machine:5.0.0.3810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x:libxfixes:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:ibm:integrated_management_module_ii_firmware:3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:-:pulse:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:d-link:dap-2330:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:f5:tmos:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tenable:nessus:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.6.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:player:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:webobjects:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r3.4_2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:netmail:3.52c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:4.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(28\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_management_suite:-:-:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:kolja_schleich:leaguemanager:3.8.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:komodia:redirector_sdk:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.6.2\(4023\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:konicaminolta:bizhub_200:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.0:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.0:rc1`,
        fs:  `cpe:2.3:a:kde:koffice:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.0:rc2`,
        fs:  `cpe:2.3:a:gentoo:media-libs_jpeg:6b:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.0:rc3`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.7:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.0:rc4`,
        fs:  `cpe:2.3:a:altiris:knowledge_base_proxy:6.0.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.0:rc5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.0:rc6`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.784.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.1:-`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2000:sp3a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.1:rc1v`,
        fs:  `cpe:2.3:a:busybox:busybox:1.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.1:rc2`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.10:ga5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.1:rc3`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.1:rc4`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.1:rc5`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.1:rc6`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.4`,
        fs:  `cpe:2.3:a:best_free_giveaways_project:best_free_giveaways:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:konqueror:konqueror:3.5`,
        fs:  `cpe:2.3:a:gnu:glibc:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.4`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.5`,
        fs:  `cpe:2.3:a:inclind:custom_pub:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.6`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.7`,
        fs:  `cpe:2.3:a:openpkg:openpkg:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.8`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.8.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.8.2`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.8.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.46.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:konstanty_bialkowski:libmodplug:0.8.8.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p263:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kony:enterprise_mobile_management:1.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kopf:outlook_attachment_remover:2.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:korenix:jetport:5601`,
        fs:  `cpe:2.3:a:moodle:moodle:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:korenix:jetport:5601f`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.9k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:korenix:jetport:5604`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:korenix:jetport:5604i`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koyotesoft:free_easy_burner:5.0.0.0`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:koz.com:ichat_rooms_server:3.0`,
        fs:  `cpe:2.3:a:libpng:libpng:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kozos:easyctf:1.0`,
        fs:  `cpe:2.3:o:dell:sonicwall_netextender_firmware:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kozos:easyctf:1.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kozos:easyctf:1.2`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kozos:easyctf:1.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kozos:easyctf:1.4`,
        fs:  `cpe:2.3:a:compaq:insight_management_agent:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kratosnetworks:neuralstar:8.3.38`,
        fs:  `cpe:2.3:a:symantec:brightmail_antispam:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:0.9.1.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:0.9.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:0.9.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:0.9.4`,
        fs:  `cpe:2.3:a:emerson:deltav_proessentials_scientific_graph:5.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:0.9.5`,
        fs:  `cpe:2.3:a:flexerasoftware:flexnet_publisher:11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:0.9.6`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.6:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:0.9.7`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.6.0.603:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:1.0.0:beta`,
        fs:  `cpe:2.3:o:d-link:dsl-2730b:ge_1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:1.0.1`,
        fs:  `cpe:2.3:a:koenigsleiten77:konigsleiten:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:1.0.2`,
        fs:  `cpe:2.3:a:barebones:yojimbo:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:1.1.35`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:2.0.1:beta`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:2.1.3`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:2.1.5`,
        fs:  `cpe:2.3:a:mirucho:listen_up\!_mirucho:1.1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:2.1.6`,
        fs:  `cpe:2.3:a:autodesk:map_3d:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:3.0.0`,
        fs:  `cpe:2.3:h:hp:jg822a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:3.0.1`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:3.0.2`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.13.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:5.1.0`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.3:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krisonav:krisonav:5.1.1`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.3.3:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:kristof_de_jaeger:bundle_copy:7.x-1.0`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kristof_de_jaeger:bundle_copy:7.x-1.x`,
        fs:  `cpe:2.3:a:wave:embassy_remote_administration_server_help_desk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krollontrack:easyrecovery:6.0.9::~~professional~~~`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krstarica:forum_krstarice:3.5.14::~~~android~~`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.3.0`,
        fs:  `cpe:2.3:o:rockwellautomation:compactlogix:19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.3.1`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.3.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.3.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.517:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.3.4`,
        fs:  `cpe:2.3:a:apple:cups:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.4.0`,
        fs:  `cpe:2.3:a:willcom-inc:wi-fi_application:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.4.1`,
        fs:  `cpe:2.3:a:logitech:quickcam_software:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.4.2`,
        fs:  `cpe:2.3:h:zyxel:p-660hw:_t1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.5.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sru:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.5.1`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.5.2`,
        fs:  `cpe:2.3:a:gnu:bash:1.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.6.0:rc1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.58:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kryo:iodine:0.7.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.7.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.184:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.3`,
        fs:  `cpe:2.3:a:docker:docker:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.4`,
        fs:  `cpe:2.3:a:openttd:openttd:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.5`,
        fs:  `cpe:2.3:a:oracle:siebel_crm:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.6`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.7`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:13.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.8`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.8.1`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.9`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.9.1`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.9.2`,
        fs:  `cpe:2.3:a:oracle:micros_cwdirect:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.9.3`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:0.9.4`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc3310:a9862a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.0`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.0.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:th:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.3`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.4`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.5`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.5.1`,
        fs:  `cpe:2.3:a:gnu:a2ps:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.596.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.8`,
        fs:  `cpe:2.3:o:cisco:spa8000_8-port_ip_telephony_gateway_firmware:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:1.9`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:2.0`,
        fs:  `cpe:2.3:a:python:python:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:2.0.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:2.1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.0:sbs5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:2.1.1`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:krzysztof_kowalczyk:sumatrapdf:2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ksoffice:office_2010:6.6.0.2477`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kth:snack_sound_toolkit:2.2.10`,
        fs:  `cpe:2.3:a:process-one:exmpp:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kth:wavesurfer:1.8.8:p4`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ktools:photostore:4.7.4`,
        fs:  `cpe:2.3:a:devsaran:company:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kubelabs:phpdug:2.0.0`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kunena:kunena:1.7.2`,
        fs:  `cpe:2.3:a:redhat:linux:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kunena:kunena:5.0.2::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:microsoft:windows_live_messenger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kunena:kunena:5.0.3::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kunena:kunena:5.0.4::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.827:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kuran%27in_bilimsel_mucizeleri_project:kuran%27in_bilimsel_mucizeleri:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:juniper:junos:13.3r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kuronecostudio:noble_sticker_%22free%22:1.0.7::~~~android~~`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.1.1`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.1.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.1.3`,
        fs:  `cpe:2.3:a:microsoft:publisher:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.1.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.1.5`,
        fs:  `cpe:2.3:o:cisco:catos:6.2\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.1.6`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.1.7`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.2.0`,
        fs:  `cpe:2.3:o:netgear:d3600_firmware:_1.0.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.2.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.2.2`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.3.0`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:0.4.0`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:1.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:1.0.0`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:1.0.1`,
        fs:  `cpe:2.3:a:webempoweredchurch:wec_discussion:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:1.1.0`,
        fs:  `cpe:2.3:a:adobe:asset_services_cs3:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:1.2.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:1.3.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:1.4.0`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurt_gusbeth:myquizpoll:2.0.6`,
        fs:  `cpe:2.3:h:netgear:fvs318:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurzweiledu:kurzweil_1000:10.0.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurzweiledu:kurzweil_1000:12.0.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kurzweiledu:kurzweil_3000:9.0.0::~~trial~~~`,
        fs:  `cpe:2.3:a:islonline:isl_light:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:3.0.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:3.0.0:beta1`,
        fs:  `cpe:2.3:a:makeitpossible:cuanto_conoces_a_un_amigo:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:3.0.0:beta2`,
        fs:  `cpe:2.3:a:apache:solr:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:3.0.1`,
        fs:  `cpe:2.3:a:beijerelectronics:h-designer:6.5.0_b180_r1967:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:3.4.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:3.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:3.4.2:rc1`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.71:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:4.0.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kvirc:kvirc:4.0.2`,
        fs:  `cpe:2.3:a:siemens:simatic_step_7:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kwoksys:information_server:2.8.3`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kwoksys:information_server:2.8.4`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kwoksys:information_server:2.8.5`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kyocera:ah-k3001v:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kyocera:ah-k3002v:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kyocera:xw300k:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kyocera:xw310k:-`,
        fs:  `cpe:2.3:a:clamav:clamav:0.96:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kyocera:xw320k:-`,
        fs:  `cpe:2.3:a:docker:docker:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:kyocera:xw320kr:-`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:kyoceramita:product_library:2.0.713`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.2.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:l-3com:decision_agent_migration_tools_installer:1.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:3.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labanquepostale:acces_compte:3.2.6::~~~android~~`,
        fs:  `cpe:2.3:h:axis:storpoint_cd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labanquepostale:labanquepostale:3.2:-:~-~-~android~~:-`,
        fs:  `cpe:2.3:h:fortinet:fortigate-5101c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labanquepostale:labanquepostale:3.2.6:-:~-~-~android~~:-`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labelgate:mora_downloader:1.0.0.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labelgate:mora_downloader:1.0.0.1`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labsmedia:clickheat:1.1.4`,
        fs:  `cpe:2.3:a:posh_project:posh:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:1.5`,
        fs:  `cpe:2.3:a:agilebits:knox:1.5.0:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:1.6`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:1.7`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.376:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:1.8`,
        fs:  `cpe:2.3:a:ubuntu_developers:language-selector:0.79.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:1.9`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1051.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.0`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.1`,
        fs:  `cpe:2.3:a:libraw:libraw:0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.2`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.3`,
        fs:  `cpe:2.3:a:cisco:rv082_dual_wan_vpn_router_firmware:4.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.5`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.7`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.8`,
        fs:  `cpe:2.3:o:dell:idrac7_firmware:1.06.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:2.9`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtam-inc:proftp:3.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:labtech_software:labtech:55.170`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lacie:lac9000436u:-`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lacie:lac9000436u_firmware:2.3.0.014`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lacie:lac9000464u:-`,
        fs:  `cpe:2.3:a:codepeople:com_multicalendar:4.8.5:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/o:lacie:lac9000464u_firmware:2.3.0.014`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lame_project:lame:3.99.5`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(1\)ed:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lancope:stealthwatch:-`,
        fs:  `cpe:2.3:a:brother:p-touch_editor:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lancope:stealthwatch:5.1.1`,
        fs:  `cpe:2.3:a:apache:cxf:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landesk:landesk_management_suite:-`,
        fs:  `cpe:2.3:a:vips:vips:7.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landesk:landesk_management_suite:8.7`,
        fs:  `cpe:2.3:o:cisco:ons_15327:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landesk:landesk_management_suite:8.8`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landesk:landesk_management_suite:9.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.624:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landesk:landesk_security_suite:8.7`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landesk:landesk_security_suite:8.8`,
        fs:  `cpe:2.3:a:abbyy:finereader:9.0:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages:1.8.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.3.7:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.7.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.3.8:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.3.9:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:qpid:0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.4.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:h:meinberg:lces:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.4.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:tribulant:tibulant_slideshow_gallery:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.4.4:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.5.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:totalseminars:cissp:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.5.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.5.6:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:php:php:5.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.7.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.7.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.7.9:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.8.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:grep:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.8.4:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.8.5:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.8.6:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p422:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.9.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.9.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.9.4:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.0.9.9:-:~~~wordpress~~`,
        fs:  `cpe:2.3:h:sony:snc_dh140t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.1.0.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.1.7:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.99.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.1.8:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.1.9:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.2.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:landing_pages_project:landing_pages_plugin:1.2.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lanier:pcl6:-`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lanier:rpcs:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(11a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansuite:lansuite:3.3.2`,
        fs:  `cpe:2.3:a:lightdm_project:lightdm:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.0.0.24`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.0.0.27`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.0.0.36`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:5.2:2005q1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.0.0.37`,
        fs:  `cpe:2.3:a:altiris:patch_management_for_windows:6.2.3644:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.0.0.40`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.0.0.41`,
        fs:  `cpe:2.3:a:atlassian:jira:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.0.0.42`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.0.0.106`,
        fs:  `cpe:2.3:a:cisco:quad:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.11`,
        fs:  `cpe:2.3:a:solarwinds:orion_server_and_application_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.12`,
        fs:  `cpe:2.3:a:freeradius:freeradius:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.14`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.16`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.18`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.21`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.27`,
        fs:  `cpe:2.3:a:acme:thttpd:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.29`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.1.0.35`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.52`,
        fs:  `cpe:2.3:a:ubnt:unifi_controller:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.54`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.2.1:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.60`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.63`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.7:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.68`,
        fs:  `cpe:2.3:a:freetype:freetype:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.70`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.77`,
        fs:  `cpe:2.3:a:quassel-irc:quassel:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.82`,
        fs:  `cpe:2.3:o:juniper:junos:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.86`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:4.2.0.90`,
        fs:  `cpe:2.3:a:acquia:mollom:6.x-2.13:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.44`,
        fs:  `cpe:2.3:a:ibm:filenet_content_engine_.net_api:4.5.5100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.48`,
        fs:  `cpe:2.3:h:storagetek:d280:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.52`,
        fs:  `cpe:2.3:a:apple:personal_web_sharing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.60`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.69`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.76`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.77`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.78`,
        fs:  `cpe:2.3:a:augeas:augeas:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.79`,
        fs:  `cpe:2.3:a:redhat:openshift_origin:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.0.0.81`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.28`,
        fs:  `cpe:2.3:a:faxtalk:faxtalk_communicator:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.29`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.31`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.45`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.49`,
        fs:  `cpe:2.3:a:avaya:libsafe:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.50`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.53`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.54`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.15.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.55`,
        fs:  `cpe:2.3:a:emc:controlcenter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.59`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.60`,
        fs:  `cpe:2.3:a:vmware:workstation:6.5.4.11892:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.61`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.377:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.62`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.63`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1656.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.64`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.48:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.65`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.1.0.66`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)za8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.15`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(13\)ca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.17`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.22`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.24`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.27`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.0\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.30`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.31`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.33`,
        fs:  `cpe:2.3:o:yamaha:rt105e:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.41`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.42`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update2:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.2.0.43`,
        fs:  `cpe:2.3:a:digium:asterisk:12.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.5`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.6`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.8`,
        fs:  `cpe:2.3:a:citrix:xenapp:6.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.12`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.3:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.13`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.15`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.17`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.21`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.2.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.22`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.24`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.25`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.28`,
        fs:  `cpe:2.3:a:litronic:fortezza:6.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.30`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.31`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d42.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.32`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.33`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:5.3.0.34`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.19`,
        fs:  `cpe:2.3:a:novell:netware_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.22`,
        fs:  `cpe:2.3:a:checkpoint:check_point_integrity_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.42`,
        fs:  `cpe:2.3:a:opnet:development_kit_module:16.0.0.10106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.45`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.48`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.51`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.63`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.6.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.64`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.0.65`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.100.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.100.21`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.100.29`,
        fs:  `cpe:2.3:a:saurabh_gupta:tiny_server:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lansweeper:lansweeper:6.0.100.75`,
        fs:  `cpe:2.3:a:oracle:mysql_enterprise_monitor:3.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lappgroup:lapp_group_catalogue:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.0`,
        fs:  `cpe:2.3:a:vmware:player:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.3`,
        fs:  `cpe:2.3:o:cisco:telepresence_system_software_ix:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.4`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.5.1249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.5`,
        fs:  `cpe:2.3:a:phpspot:php_bbs_ce:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.7`,
        fs:  `cpe:2.3:a:mcafee:firewall_reporter:5.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.8`,
        fs:  `cpe:2.3:a:symantec:livestate_recovery:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.9`,
        fs:  `cpe:2.3:a:logitech:lws_twitter:13.30.1346.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:larry_garfield:autosave:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.1`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.2`,
        fs:  `cpe:2.3:a:vmware:workstation:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.3`,
        fs:  `cpe:2.3:a:vmware:airwatch:7.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.4`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.0:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.5`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.6.1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.6.2`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.6.3`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.0.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.7`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.7.1`,
        fs:  `cpe:2.3:o:cisco:catos:7.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.7.2`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.1.1`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.60:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.2.1`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-281c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.2.2`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.3`,
        fs:  `cpe:2.3:h:cisco:ubr925:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.3.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.3.2`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cpk:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.3.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.3.4`,
        fs:  `cpe:2.3:a:citrix:online_plug-in:12.1.44.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.8.3.5`,
        fs:  `cpe:2.3:o:huawei:s7712_firmware:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.9`,
        fs:  `cpe:2.3:a:isc:bind:9.9.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.9.0.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lars_hjemli:cgit:0.9.0.2`,
        fs:  `cpe:2.3:a:justsystems:just_smile:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:last:last.fm:1.5.4`,
        fs:  `cpe:2.3:a:lucent:vitalanalysis:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:last.fm_rotation_plugin_project:lastfm-rotation_plugin:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.6sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:latex2rtf_project:latex2rtf:2.3.8`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:latexeditor:led:beta_0.53`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:1.0`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-300e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:2.1`,
        fs:  `cpe:2.3:a:labanquepostale:labanquepostale:3.2.6:-:-:-:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:2.23`,
        fs:  `cpe:2.3:a:google:chrome:16.0.905.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:2.24`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:7.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:3.0`,
        fs:  `cpe:2.3:a:luracast:restler:1.3.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:3.1`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg9000-10:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:3.2`,
        fs:  `cpe:2.3:a:php:php:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:4.0`,
        fs:  `cpe:2.3:h:buffalotech:wsr-600dhp_firmware:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:4.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)xu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.0`,
        fs:  `cpe:2.3:a:x:libxcb:1.1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.1`,
        fs:  `cpe:2.3:a:fleugel:php_weblog_system_mania:-:-:net:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p203:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.3`,
        fs:  `cpe:2.3:a:helios:textpad:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.4`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:8.0.400.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.5`,
        fs:  `cpe:2.3:a:cisco:business_edition_3000_software:8.6\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.6`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.7`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.8`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1b_pk1_bl1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:5.9`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.5:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:4.0.0.1390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.2`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.3`,
        fs:  `cpe:2.3:a:mcafee:freescan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.5`,
        fs:  `cpe:2.3:a:novell:iprint:5.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.6`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.8`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.9`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:6.95`,
        fs:  `cpe:2.3:a:hexagon:erdas_apollo_ecwp:13.00.0001:-:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:7.0`,
        fs:  `cpe:2.3:a:actualtests:comptia_sy0-201_in_exam_engine_format:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laurent_destailleur:awstats:7.1`,
        fs:  `cpe:2.3:a:bscw:bscw:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavalite:lavalite:5.2.4`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.1.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:3.5`,
        fs:  `cpe:2.3:a:apache:spamassassin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:4.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:4.5`,
        fs:  `cpe:2.3:a:avast:free_antivirus:11.1.2245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:4.6`,
        fs:  `cpe:2.3:a:apple:itunes:12.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:5.5`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.13.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:5.6`,
        fs:  `cpe:2.3:a:hp:operations_agent:11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:5.7`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:5.62`,
        fs:  `cpe:2.3:a:david_king:vino:2.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:5.71`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:5.81`,
        fs:  `cpe:2.3:o:hp:hp-ux_series_700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:5.82`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:5.83`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:6.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1059:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:6.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:7.1`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:8.0`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware:8.1.2`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lavasoft:ad-aware_2007:7.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:laytontechnology:helpbox:4.4.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lazgosoftware:keystore_explorer:4.0.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lazyer:doodle_drop:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:inmatrix:zoom_player:8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ldap-account-manager:ldap_account_manager:4.2.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ldap-account-manager:ldap_account_manager:4.3`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ldap_project:ldap:2.8.17::~~~typo3~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\)ea4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:leadoctopus:lead_octopus:-::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p302:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:leg_surgery_-_kids_games_project:leg_surgery_-_kids_games:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:publisher:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemon-s_php:gazou_bbs_plus:2.35`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemon-s_php:gazou_bbs_plus:2.36`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemon-s_php:simple_oekaki_bbs:1.20`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2009-02-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemon-s_php:simple_oekaki_bbs:1.21`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.6`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110515:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.7:beta`,
        fs:  `cpe:2.3:a:hitachi:jp1\/performance_management-manager_web_option:07-00:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.8`,
        fs:  `cpe:2.3:a:suse:manager:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.8.1`,
        fs:  `cpe:2.3:a:microsoft:works:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.8.2`,
        fs:  `cpe:2.3:a:emc:networker:8.1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.8.3`,
        fs:  `cpe:2.3:a:themebeans:blooog_theme:1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.9`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.9.1`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.9.2`,
        fs:  `cpe:2.3:a:christophe_thibault:k-meleon:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.9.3`,
        fs:  `cpe:2.3:a:f5:big-ip_enterprise_manager:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:0.9.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0:rc1`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0:rc2`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0.2`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0.3`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p345:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0.5`,
        fs:  `cpe:2.3:a:vips:vips:7.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.0.6`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.1.1`,
        fs:  `cpe:2.3:a:intel:mdrwifi:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.1.2`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.2.0`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.6.5:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.2.1`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.2.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemonldap-ng:lemonldap%3a%3a:1.2.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lemurmonitors:bluedriver:6.3.2`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lenel:lnl-2220:-`,
        fs:  `cpe:2.3:o:hp:openvms:8.3-1h1:*:integrity_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lenel:lnl-3300:-`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.2`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.3`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.182.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.4`,
        fs:  `cpe:2.3:a:marinet:marinet_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.5`,
        fs:  `cpe:2.3:h:xerox:copycentre_c90:1.001.02.073:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.6`,
        fs:  `cpe:2.3:a:divx:content_uploader:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.7`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.8`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.9`,
        fs:  `cpe:2.3:h:sun:fire_x2200_m2:2.19:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.10`,
        fs:  `cpe:2.3:a:namazu:namazu:1.0.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:rkit:0.11`,
        fs:  `cpe:2.3:a:scoutmob:scoutmob_local_deals_\&amp;_event:3.0.18:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:001`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:002`,
        fs:  `cpe:2.3:a:redhat:smart_card_manager:1.1.0-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:003`,
        fs:  `cpe:2.3:a:augeas:augeas:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:004`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:005`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp1:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:006`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.0.4:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:007`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:008`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:009`,
        fs:  `cpe:2.3:o:wdc:my_net_firmware:1.06.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:010`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:011`,
        fs:  `cpe:2.3:a:adobe:connect:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:012`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:013`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:014`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:015`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:016`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:437:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:017`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:018`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:019`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:020`,
        fs:  `cpe:2.3:a:pygments:pygments:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:021`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.2.125.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:022`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:023`,
        fs:  `cpe:2.3:a:infradead:openconnect:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:024`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:025`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:026`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:027`,
        fs:  `cpe:2.3:a:grape_project:grape:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:028`,
        fs:  `cpe:2.3:o:juniper:junos:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:029`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:030`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:031`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.965:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:032`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.9:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:033`,
        fs:  `cpe:2.3:a:zope:zope:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:034`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:035`,
        fs:  `cpe:2.3:a:haxx:curl:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:036`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.5.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:lennart_poettering:systemd:037`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:fingerprint_manager:8.01.35`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:rescue_and_recovery:4.21.16.0`,
        fs:  `cpe:2.3:a:typo3:neos:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:shareit:2.5.1.1::~~~windows~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:shareit:3.0.18_ww::~~~android~~`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:4.9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:shareit:3.5.88_ww::~~~android~~`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:shareit:3.5.98_ww::~~~android~~`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:system_update:5.06.0027`,
        fs:  `cpe:2.3:a:redhat:mcstrans:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:thinkpad_bluetooth_with_enhanced_data_rate_software:6.4.0.2900`,
        fs:  `cpe:2.3:o:cisco:ios:12.4jk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:thinkpad_bluetooth_with_enhanced_data_rate_software:6.5.1.2700`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lenovo:thinkserver_rd350:-`,
        fs:  `cpe:2.3:a:demarque:typing_pal:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lenovo:thinkserver_rd350_firmware:1.25.0`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lenovo:thinkserver_rd450:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lenovo:thinkserver_rd450_firmware:1.25.0`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lenovo:thinkserver_rd550:-`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:1.8.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:lenovo:thinkserver_rd550_firmware:1.25.0`,
        fs:  `cpe:2.3:a:hp:newcopy:50.0.206.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lenovo:thinkserver_rd650:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lenovo:thinkserver_rd650_firmware:1.25.0`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_enterprise_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lenovo:thinkserver_td350:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lenovo:thinkserver_td350_firmware:1.25.0`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.0.1`,
        fs:  `cpe:2.3:a:chillcreations:mod_ccnewsletter:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.0.3`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.1.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.1.1`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router:1.1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.2.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20091113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.2.2`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.3.0`,
        fs:  `cpe:2.3:o:novell:opensuse:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.3.1`,
        fs:  `cpe:2.3:a:amberdms:amberdms_billing_system:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.3.2`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.04.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xclarity_administrator:1.4.0`,
        fs:  `cpe:2.3:a:pctools:threatfire:4.7.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lenovo:xp_themes:1.0.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:leon_weber:pyxtrlock:0.1:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:leon_weber:pyxtrlock:0.1:beta`,
        fs:  `cpe:2.3:o:siemens:cfis1425_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:leon_weber:pyxtrlock:0.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.9:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lepide:active_directory_self_service:-`,
        fs:  `cpe:2.3:o:amd:16h_model_processor_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lepide:recoveryfix_for_ost_to_pst:11.3::~~evaluation~~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lepton-cms:lepton:1.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lepton-cms:lepton:1.1.1`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lepton-cms:lepton:1.1.2`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.3.175888.1227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lepton-cms:lepton:1.1.3`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lepton-cms:lepton:1.1.4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lester_chan:wp-downloadmanager:1.00`,
        fs:  `cpe:2.3:a:opensolution:quick.cms.lite:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lester_chan:wp-downloadmanager:1.30`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lester_chan:wp-downloadmanager:1.31`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lester_chan:wp-downloadmanager:1.40`,
        fs:  `cpe:2.3:a:cisco:1000v_virtual_ethernet_module_\(vem\):4.0\(4\):sv1\(3\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lester_chan:wp-downloadmanager:1.50`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.5.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:lester_chan:wp-downloadmanager:1.60`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1\(3\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lester_chan:wp-downloadmanager:1.61`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp11:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.00::~~~wordpress~~`,
        fs:  `cpe:2.3:a:omnistaretools:omnistar_recruiting:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.02::~~~wordpress~~`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.30::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.40::~~~wordpress~~`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass:4.5.7:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.50::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.60::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:4.0.2:003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.61::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.62::~~~wordpress~~`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.63::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:vvos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.64::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.65::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/n:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lesterchan:wp-postviews:1.66::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:rsa_data_protection_manager_software_server:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:letshare:world_cup_2014_brazil_-_xem_tv:2.6::~~~android~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:levelfourdevelopment:wp-easycart:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emberjs:ember.js:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:levelfourdevelopment:wp-easycart:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:levelfourdevelopment:wp-easycart:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:levelfourdevelopment:wp-easycart:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:levelfourdevelopment:wp-easycart:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:levelfourdevelopment:wp-easycart:2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:worklight:6.0.0.1:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:levelteninteractive:content_analysis:6.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:25xxn:-`,
        fs:  `cpe:2.3:h:netgear:r6700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c4150:-`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c510:-`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c52x:-`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c53x:-`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c540:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c543:-`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c544:-`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c546:-`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c6160:-`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c73x:-`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c77x:-`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c78x:-`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c920:-`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:c935dn:-`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cs720de:-`,
        fs:  `cpe:2.3:a:polycom:rmx_system_software:7.5.1.j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cs720dte:-`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cs725de:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cs725dte:-`,
        fs:  `cpe:2.3:a:cisco:prime_service_catalog:9.4.1_vortex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cs820de:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cs820dte:-`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.1:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cs820dtfe:-`,
        fs:  `cpe:2.3:a:apache:activemq_artemis:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx725de:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxd5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx725dhe:-`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx725dthe:-`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx820de:-`,
        fs:  `cpe:2.3:a:cisco:unified_web_and_e-mail_interaction_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx820dtfe:-`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2013:cumulative_update_16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx825de:-`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:5300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx825dte:-`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx825dtfe:-`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx860de:-`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_laptops_desktops:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx860dte:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:cx860dtfe:-`,
        fs:  `cpe:2.3:a:vips:vips:7.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e120:-`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1029:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e238:-`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e23x:-`,
        fs:  `cpe:2.3:a:ubercart_views_project:uc_views:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e240:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_it_asset_management_for_it:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e240n:-`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e250:-`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e260:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e33x:-`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:1.0.2241.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e34x:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e350:-`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e360d:-`,
        fs:  `cpe:2.3:h:axis:m1033-w_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e360dn:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e450:-`,
        fs:  `cpe:2.3:h:linksys:wrt54g:1.00.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e460:-`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e460dn:-`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:e462:-`,
        fs:  `cpe:2.3:a:simon_tatham:putty:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lexmark:markvision:-`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.29:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:lexmark:markvision:4.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lexmark:markvision_enterprise:-`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:ms811dn:-`,
        fs:  `cpe:2.3:a:gnu:queue:1.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:n4000:-`,
        fs:  `cpe:2.3:a:fujitsu:scansnap_organizer:v4.1l11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:n4050e:-`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:n70xxe:-`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2009:2.01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:n8120:-`,
        fs:  `cpe:2.3:h:intel:express_520t:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:n8130:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lexmark:printer_firmware:atl.02.048`,
        fs:  `cpe:2.3:a:google:chrome:6.0.477.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lexmark:printer_firmware:cb.02.048`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg248a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lexmark:printer_firmware:pp.02.048`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:4.0:-:coldfusion:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lexmark:printer_firmware:yk.02.048`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:t430:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:t522_network_printer:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0sx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:t632:-`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:t64x:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:2015.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:t650:-`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:t652:-`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:t654:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:t656:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:w840:-`,
        fs:  `cpe:2.3:a:bdale_garbee:as31:2.3.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:w850:-`,
        fs:  `cpe:2.3:a:kryo:iodine:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x1185:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.0.1.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x20x:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x26x:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x34x:-`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x36x:-`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x422:-`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.12:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x46x:-`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x543:-`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x544:-`,
        fs:  `cpe:2.3:o:opensuse:opensuse:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x546:-`,
        fs:  `cpe:2.3:a:netscape:directory_server:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x642:-`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x644:-`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x646:-`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:0.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x64xef:-`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x65x:-`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x73x:-`,
        fs:  `cpe:2.3:a:all_video_gallery_plugin_project:all_video_gallery_plugin:1.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x772e:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x782e:-`,
        fs:  `cpe:2.3:a:ibm:spss_analytic_server:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x85x:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:191:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x86x:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1673.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:x94x:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:xc4150:-`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:xc6152de:-`,
        fs:  `cpe:2.3:a:autodesk:land_desktop:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:xc6152dtfe:-`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:xc8155de:-`,
        fs:  `cpe:2.3:a:microsoft:word:2013:sp1:*:*:rt:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:xc8155dte:-`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:xc8160de:-`,
        fs:  `cpe:2.3:a:pocketmags:taster_magazine:\@7f080183:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:lexmark:xc8160dte:-`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lg:l-03e:-`,
        fs:  `cpe:2.3:a:lucent:vitalevent:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lg:l-04d:-`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lg:l-09c:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lg:on-screen_phone:4.3.009`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lg:optimus_g_e973:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.52`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.53`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.23:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.55`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:0.25.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.56`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.57`,
        fs:  `cpe:2.3:a:plone:plone:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.59`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:1.2:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.70`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.71`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lhaplus:lhaplus:1.72`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lianja:lianja_sql_server:1.0:rc5.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lianja:lianja_sql_server:1.0:rc5.2`,
        fs:  `cpe:2.3:h:cisco:sg300-10pp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libarchive:libarchive:3.1.2::~~~x64~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1.1\)pi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libarchive:libarchive:3.1.901a`,
        fs:  `cpe:2.3:a:google:chrome:4.0.267.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libarchive:libarchive:3.2.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libass_project:libass:0.13.3`,
        fs:  `cpe:2.3:a:redhat:redhat_package_manager:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5.1`,
        fs:  `cpe:2.3:a:k2top:k2editor:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5.5`,
        fs:  `cpe:2.3:a:emc:solutions_enabler_for_ecc:7.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5.6`,
        fs:  `cpe:2.3:a:nginx:nginx:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5.7`,
        fs:  `cpe:2.3:a:speed_software:root_explorer:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.5.8`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.6`,
        fs:  `cpe:2.3:h:lexmark:t656:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.6.1`,
        fs:  `cpe:2.3:a:novell:client_login_extension_\(cle\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.6.2`,
        fs:  `cpe:2.3:a:apache:subversion:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.6.3`,
        fs:  `cpe:2.3:h:iij:seil_x86_fuji:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.6.4`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.6.5`,
        fs:  `cpe:2.3:a:openstack:keystone:2015.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7:beta1`,
        fs:  `cpe:2.3:h:hp:elitebook_folio_1012_x2_g2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7:beta2`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7.1`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7.3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7.4`,
        fs:  `cpe:2.3:h:hp:0235a324:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7.5`,
        fs:  `cpe:2.3:a:gnu:automake:1.4:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.7.6`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:16.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8`,
        fs:  `cpe:2.3:a:oracle:cadview-3d:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8:beta2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.2`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.3`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.19.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.4`,
        fs:  `cpe:2.3:a:abb:datamanager:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.5`,
        fs:  `cpe:2.3:a:condusiv:diskeeper:10.0.593:*:*:*:server_standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.6`,
        fs:  `cpe:2.3:a:ca:controlit:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.7`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.8`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.9`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.10`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.11`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:0.8.12`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:9.21`,
        fs:  `cpe:2.3:o:redhat:linux:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:10.6`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:11.0`,
        fs:  `cpe:2.3:a:roemersoftware:free_hi-q_recorder:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:11.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:11.2`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.42.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:11.3`,
        fs:  `cpe:2.3:a:citrix:presentation_server_for_windows:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:11.6`,
        fs:  `cpe:2.3:a:apache:ofbiz:13.07.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:11.7`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(22\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:11.8`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:libav:libav:12.0`,
        fs:  `cpe:2.3:a:oracle:enterprise_governance_risk_and_compliance_manager:7.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libdwarf_project:libdwarf:2016-10-21`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libdwarf_project:libdwarf:20160115`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libdwarf_project:libdwarf:20160613`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_4g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libetpan_project:libetpan:1.7.2`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.0`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.1.3.10:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.1`,
        fs:  `cpe:2.3:a:qemu:qemu:1.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.0\(2j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.288.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.4`,
        fs:  `cpe:2.3:a:ibm:rational_license_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.5`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:5.0:*:smartphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.6`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.7`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.8`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.9`,
        fs:  `cpe:2.3:a:google:chrome:6.0.425.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.10`,
        fs:  `cpe:2.3:a:adobe:connect_enterprise_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.11`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.12`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.13`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:1.4.14`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.1`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.3:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.3`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_security_suite:5.5.062.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.5`,
        fs:  `cpe:2.3:o:ibm:aix:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.6`,
        fs:  `cpe:2.3:a:sixapart:movable_type:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.7`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.8`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.9`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(9\)ea:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12.05\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.12`,
        fs:  `cpe:2.3:h:hp:retail_integrated_2x20_complex_g7g29aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.13`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.14`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.15`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.16`,
        fs:  `cpe:2.3:a:mozilla:firefox:26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.17`,
        fs:  `cpe:2.3:a:oracle:secure_enterprise_search:10g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.18`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.92:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.19`,
        fs:  `cpe:2.3:a:openx:openx:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.20`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.0.21`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.13:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.1.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.350.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.1.2`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.1.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.1.4`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libevent_project:libevent:2.1.5:beta`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:-`,
        fs:  `cpe:2.3:h:lexmark:x64xef:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:1.95.1`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:1.95.2`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:1.95.4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:1.95.5`,
        fs:  `cpe:2.3:a:webmin:usermin:1.580:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:1.95.6`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:1.95.7`,
        fs:  `cpe:2.3:a:microsoft:works:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:1.95.8`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:2.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(18\)s5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:2.1.0`,
        fs:  `cpe:2.3:a:avst:callxpress:7.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:2.1.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libexpat:expat:2.2.0`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:4.2\(1\)vsg1\(1\):-:*:*:*:nexus_1000v:*:*`,
    },
     
    {
        uri: `cpe:/a:libgd:libgd:2.0.33`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libgd:libgd:2.1.0`,
        fs:  `cpe:2.3:a:autodesk:design_review_2013:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libgd:libgd:2.1.1`,
        fs:  `cpe:2.3:a:veeam:backup_and_replication_active_directory_restore:5.0.2.224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libgd:libgd:2.2.1`,
        fs:  `cpe:2.3:o:gentoo:linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libgd:libgd:2.2.2`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf814a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libgd:libgd:2.2.3`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.0`,
        fs:  `cpe:2.3:a:apache:rave:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.0:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.3`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.4`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.5`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.6`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.7`,
        fs:  `cpe:2.3:a:extplorer:com_extplorer:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.8`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.9`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.10`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.11`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:406:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.12`,
        fs:  `cpe:2.3:a:hp:load_generator:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.13`,
        fs:  `cpe:2.3:a:march-hare:cvsnt:2.5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.14`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d50:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.15`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.16`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:499:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.17`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.18`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.19`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.20`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.316:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.21`,
        fs:  `cpe:2.3:a:perl:perl:5.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.22`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.23`,
        fs:  `cpe:2.3:a:php:php:5.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.24`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.25`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.26`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.27`,
        fs:  `cpe:2.3:a:python:python:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.28`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(3\)n1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.29`,
        fs:  `cpe:2.3:o:xen:xen:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.30`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.31`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.32`,
        fs:  `cpe:2.3:a:sendmail:intelligent_quarantine:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.33`,
        fs:  `cpe:2.3:a:epson:usb_display:1.42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.34`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.35`,
        fs:  `cpe:2.3:a:canonical:ltsp_display_manager:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.36`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.37`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.4:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.38`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.2:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.39`,
        fs:  `cpe:2.3:a:netwitness:netwitness_live_manager:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.40`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_client:7.2.1163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.41`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.42`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:6.0.188.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.43`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.44`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.46`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.24:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.47`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.48`,
        fs:  `cpe:2.3:a:isc:bind:9.7.5:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.49`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.50`,
        fs:  `cpe:2.3:a:rpm:rpm:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.51`,
        fs:  `cpe:2.3:a:perl:perl:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.52`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.5:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.53`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_epc3925:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.54`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.55`,
        fs:  `cpe:2.3:a:google:chrome:4.0.287.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.56`,
        fs:  `cpe:2.3:a:synology:video_station:1.6-0835:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.57`,
        fs:  `cpe:2.3:a:mobile:baseball_manager_k:1.13:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.58`,
        fs:  `cpe:2.3:a:pcre:pcre:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.59`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.60`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.2:1001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.61`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.62`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.63`,
        fs:  `cpe:2.3:a:perl:perl:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.64`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.65`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf015:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.66`,
        fs:  `cpe:2.3:a:photosmash_project:photosmash:1.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.67`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.68`,
        fs:  `cpe:2.3:o:cisco:catos:5.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.69`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.70`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.71`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.73`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p344:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.74`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.75`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.76`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.77`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.78`,
        fs:  `cpe:2.3:a:altova:databasespy_2011:3.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.79`,
        fs:  `cpe:2.3:a:apache:hadoop:0.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.80`,
        fs:  `cpe:2.3:a:merethis:centreon:2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.81`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.82`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.0.1:mu_\#7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.83`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.84`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.85`,
        fs:  `cpe:2.3:a:webcreate:web_mart:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.86`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server_supplementary:6.1.z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.87`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.88`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:3.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.0.89`,
        fs:  `cpe:2.3:h:xerox:document_centre_265:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.0`,
        fs:  `cpe:2.3:h:huawei:me60:v600r005c00spc600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.1`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_developer_suite:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.2`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.4`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.5`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.6`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.7`,
        fs:  `cpe:2.3:h:hp:laserjet_9050:q7697a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.8`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.9`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.10`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.11`,
        fs:  `cpe:2.3:a:gnome:evolution:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.12`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.13`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.1sg:3.1.0sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.2.14`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_real-time_information_portal:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.0`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_operations_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.1`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4500_series_software:4.3\(1.68\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.4`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.5`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.6`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.7`,
        fs:  `cpe:2.3:a:alkacon:opencms:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.8`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.9`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.10`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.11`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.12`,
        fs:  `cpe:2.3:a:sybase:powerbuilder_virtual_machine:10.2.1.9004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.13`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.14`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.15`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.16`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.17`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.18`,
        fs:  `cpe:2.3:a:apache:commons_collections:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.19`,
        fs:  `cpe:2.3:a:php:php:5.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.20`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.3.21`,
        fs:  `cpe:2.3:a:ibm:content_navigator:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.4.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.4.1`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.4.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.4.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p166:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.4.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.4.5`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.4.6`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.0`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.1`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.2`,
        fs:  `cpe:2.3:o:cisco:spa8000_8-port_ip_telephony_gateway_firmware:5.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.4`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.5`,
        fs:  `cpe:2.3:a:altiris:express_deployment_console:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.6`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.7`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.8`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:5.x-1.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.9`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.10`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1071.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.11`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.12`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.13`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.14`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.15`,
        fs:  `cpe:2.3:a:x:libxi:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.16`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.17`,
        fs:  `cpe:2.3:a:ipswitch:imail:11.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.18`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.19`,
        fs:  `cpe:2.3:a:digium:asterisk:12.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.20`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.21`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.22`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:2.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.23`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.24`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.25`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.5.26`,
        fs:  `cpe:2.3:o:cisco:ios_xr_for_crs-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.6.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.6.1`,
        fs:  `cpe:2.3:h:advantech:vesp211-232:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.6.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(4\)mr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.0`,
        fs:  `cpe:2.3:a:mnt-tech:wp-facethumb:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.1`,
        fs:  `cpe:2.3:a:sun:storage_automated_diagnostic_environment:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.2`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-351c_firmware:t410sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10.5\)ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.4`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.5`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.6`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.7`,
        fs:  `cpe:2.3:a:openx:openx:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.8`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.9`,
        fs:  `cpe:2.3:a:greenecosystem:ges_agri_connect:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.10`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_agent_framework:3.3.1066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.11`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.12`,
        fs:  `cpe:2.3:a:plone:plone:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.13`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.0.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.14`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.15`,
        fs:  `cpe:2.3:a:oracle:jdeveloper:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.16`,
        fs:  `cpe:2.3:a:rsbac:rule_set_based_access_control:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.17`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.18`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.19`,
        fs:  `cpe:2.3:h:hp:procurve_switch_3500yl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.20`,
        fs:  `cpe:2.3:a:drupal:drupal:7.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.21`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.22`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.454:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.7.24`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.2`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.3`,
        fs:  `cpe:2.3:a:huawei:espace_desktop:v200r001c03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.4`,
        fs:  `cpe:2.3:o:f5:tmos:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.5`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.6`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.7`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.8`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.9`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2011.707.2314.39839:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.10`,
        fs:  `cpe:2.3:a:microsoft:system.net.http.winhttphandler:4.3.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.11`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.12`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.13`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.14`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.15`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.8.16`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.0`,
        fs:  `cpe:2.3:a:avonesoft:3gp_video_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.2`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.3`,
        fs:  `cpe:2.3:a:india\&#39;s_anthem_project:india\&#39;s_anthem:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.4`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.5`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.6`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.7`,
        fs:  `cpe:2.3:a:samba:samba:3.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.9`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:12.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.10`,
        fs:  `cpe:2.3:a:ni:labwindows:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.11`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.12`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.13`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.14`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.15`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.16`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.17`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.9.18`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.3.300.257:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.2`,
        fs:  `cpe:2.3:a:apple:cups:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.3`,
        fs:  `cpe:2.3:a:rpm:rpm:4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.4`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a8\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.6`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.8d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.7`,
        fs:  `cpe:2.3:a:php:php:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.8`,
        fs:  `cpe:2.3:a:ca:common_services:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.9`,
        fs:  `cpe:2.3:a:emc:documentum_foundation_services:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.10`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.2-127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.11`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.10.12`,
        fs:  `cpe:2.3:a:buffalotech:wzr-ampg144nh_firmware:1.48:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.2`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.3`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.4`,
        fs:  `cpe:2.3:a:sympa:sympa:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.7`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.8`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.9`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.10`,
        fs:  `cpe:2.3:a:intel:mmhouse:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.11`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:pl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.13`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.14`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.15`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg258a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.16`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.17`,
        fs:  `cpe:2.3:a:apache:roller:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.18`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd238a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.19`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.9:ga11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.11.20`,
        fs:  `cpe:2.3:a:karlen_walter:si_bibtex:0.2.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.0`,
        fs:  `cpe:2.3:o:cisco:rv215w_firmware:1.2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5\)b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.2`,
        fs:  `cpe:2.3:a:microsoft:directx:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.3`,
        fs:  `cpe:2.3:a:macromedia:contribute_publishing_server:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.5`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.6`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.8`,
        fs:  `cpe:2.3:o:suse:office_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.9`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.10`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:11.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.12.11`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.2`,
        fs:  `cpe:2.3:a:samba:samba:3.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.3`,
        fs:  `cpe:2.3:a:util-linux_project:util-linux:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.4`,
        fs:  `cpe:2.3:h:cisco:wireless_control_system:3.2\(51\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.5`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.6`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.7`,
        fs:  `cpe:2.3:a:esoftpro:online_guestbook_pro:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.8`,
        fs:  `cpe:2.3:o:microsoft:windows_10:-:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.9`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:3.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.10`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.50:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.11`,
        fs:  `cpe:2.3:a:ibm:db2:9.7:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.12`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.13`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.9p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.14`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.15`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.16`,
        fs:  `cpe:2.3:h:hp:graphical_pos_pole_display_qz704aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.17`,
        fs:  `cpe:2.3:a:lg:on-screen_phone:4.3.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.18`,
        fs:  `cpe:2.3:a:perl:perl:0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.19`,
        fs:  `cpe:2.3:a:sgi:irisconsole:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.20`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_firmware:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.21`,
        fs:  `cpe:2.3:a:vmware:vcloud_automation_center:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.22`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.23`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.24`,
        fs:  `cpe:2.3:a:mcafee:cloud_analysis_and_deconstructive_services:1.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.25`,
        fs:  `cpe:2.3:a:haxx:curl:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.13.26`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.1`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.2`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.3`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.4`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.6\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.5`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00-\/b:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.6`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.7`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.8`,
        fs:  `cpe:2.3:h:nortel:succession_communication_server_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.9`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.14.10`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.2`,
        fs:  `cpe:2.3:a:x:libxfixes:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.447.2:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.5`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.7`,
        fs:  `cpe:2.3:a:serena:mashup_composer:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.8`,
        fs:  `cpe:2.3:a:vmware:vrealize_orchestrator:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.9`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.68:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.10`,
        fs:  `cpe:2.3:a:divx:converter:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.11`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.12`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.13`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.14`,
        fs:  `cpe:2.3:a:e107:e107:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.16`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_firmware:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.17`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.18`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.15.19`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.0`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.1`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.2`,
        fs:  `cpe:2.3:a:netiq:appmanager_console:7.0.25063.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.3`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.4`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_management_center_for_ids_sensors:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.5`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.6`,
        fs:  `cpe:2.3:a:adobe:adobe_reader:11.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.7`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.8`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.19:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.9`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.10`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.11`,
        fs:  `cpe:2.3:a:dell:openmanage_client_instrumentation:7.5.0.647:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.12`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.13`,
        fs:  `cpe:2.3:h:hp:laserjet_m4555fskm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.14`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.11.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.15`,
        fs:  `cpe:2.3:a:ibm:sametime:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.16`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.17`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.6:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.18`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.19`,
        fs:  `cpe:2.3:a:mozilla:firefox:33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.20`,
        fs:  `cpe:2.3:h:amd:amd64:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.21`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.22`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.23`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.1:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.24`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.618:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.25`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.16.26`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.3.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.0`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:3100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.642.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.3`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.4`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.5`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.6`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.01:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.7`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs3_client:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.8`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.9`,
        fs:  `cpe:2.3:a:uplus:u\&#43;box_2.0_pad:2.0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.10`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.11`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.12`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.13`,
        fs:  `cpe:2.3:a:hp:laserjet_toolbox:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.14`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.15`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.16`,
        fs:  `cpe:2.3:a:hp:scanjet_utilities:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.17`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.18`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.19`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.20`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.21`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.4:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.22`,
        fs:  `cpe:2.3:h:dell:kvm_2162ds:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.24`,
        fs:  `cpe:2.3:a:school_administration_project:school_administration:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.25`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.4:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.26`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.27`,
        fs:  `cpe:2.3:h:3com:3cp4144:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.28`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.29`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:3.0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.30`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.31`,
        fs:  `cpe:2.3:a:cisco:telepresence_management_suite:14.3\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.32`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.33`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.34`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.35`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.36`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p169:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.37`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)mc2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.38`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.39`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.40`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.41`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.42`,
        fs:  `cpe:2.3:a:mcafee:webshield_smtp:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.17.43`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)xa4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:0.9d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.2`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.1\(3u\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.3`,
        fs:  `cpe:2.3:a:hp:service_manager_web_tier:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.4`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.6`,
        fs:  `cpe:2.3:a:microsoft:word:2010:sp2:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.7`,
        fs:  `cpe:2.3:a:novell:filr:2.0:security_update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.8`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.9`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.10`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.0:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.11`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.20.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.4ye:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.1`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.2`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.4`,
        fs:  `cpe:2.3:a:hp:product_assistant:130.0.371.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.5`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.6`,
        fs:  `cpe:2.3:a:libexpat:expat:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.7`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.8`,
        fs:  `cpe:2.3:h:hp:laserjet_3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.9`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.10`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.36:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.11`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.12`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.13`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.14`,
        fs:  `cpe:2.3:a:visiwave:site_survey:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.15`,
        fs:  `cpe:2.3:a:codiad:codiad:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.16`,
        fs:  `cpe:2.3:a:jan_schutze:truc:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.17`,
        fs:  `cpe:2.3:h:avaya:sg203:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.18`,
        fs:  `cpe:2.3:h:cisco:asr_1006_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.19`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00-05:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.20`,
        fs:  `cpe:2.3:h:siemens:spc6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.21`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.22`,
        fs:  `cpe:2.3:a:microsoft:rich_textbox_control:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.23`,
        fs:  `cpe:2.3:a:pantech:pc_card_software:2.0.a20.1215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.24`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.25`,
        fs:  `cpe:2.3:a:emc:networker:7.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.26`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.27`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.28`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.29`,
        fs:  `cpe:2.3:a:cisco:prime_home:5.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.30`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.7.1\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.31`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.32`,
        fs:  `cpe:2.3:a:samba:samba:2.2.8:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.33`,
        fs:  `cpe:2.3:o:buffalotech:airstation_extreme_n600_firmware:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.34`,
        fs:  `cpe:2.3:a:libav:libav:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.35`,
        fs:  `cpe:2.3:o:cisco:ios:15.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.36`,
        fs:  `cpe:2.3:a:apache:wicket:6.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.37`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.38`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.39`,
        fs:  `cpe:2.3:a:apache:ranger:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.21.40`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.48.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.22.0`,
        fs:  `cpe:2.3:a:debian:apt:0.7.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.22.1`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.14:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.22.2`,
        fs:  `cpe:2.3:a:h3c:secpath1000fe:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.22.3`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle:7.4.1.834:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.22.4`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.22.5`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.22.6`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.22.7`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libguestfs:libguestfs:1.23.0`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libical_project:libical:2.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libiitech:pet_salon:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:rom_walton:boinc:6.10.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libimobiledevice:libimobiledevice:1.1.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libksba_project:libskba:1.3.2`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libksba_project:libskba:1.3.3`,
        fs:  `cpe:2.3:a:acme:thttpd:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmenu-cache_project:libmenu-cache:1.0.2`,
        fs:  `cpe:2.3:a:emc:rsa_identity_management_and_governance:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmimedir_project:libmimedir:-`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:4.1.0.14766:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libming:libming:0.4.7`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmms_project:libmms:0.6`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmms_project:libmms:0.6.1`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmms_project:libmms:0.6.2`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmms_project:libmms:0.6.3`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmms_project:libmms:0.6.4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.350.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmspack_project:libmspack:0.4`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libmspack_project:libmspack:0.4-3`,
        fs:  `cpe:2.3:o:yahama:rta52i:4.01.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libndp:libndp:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.7_pre3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libndp:libndp:1.5`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.8`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.71`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.81`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.82`,
        fs:  `cpe:2.3:a:atheme:atheme:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.85`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.86`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.87`,
        fs:  `cpe:2.3:h:huawei:ar1200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.88`,
        fs:  `cpe:2.3:o:xen:xen:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.89`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.89c`,
        fs:  `cpe:2.3:a:reviewboard:djblets:0.7.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.90`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.95`,
        fs:  `cpe:2.3:a:pgp:e-business_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.96`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.97`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.98`,
        fs:  `cpe:2.3:a:google:talk_plugin:2.0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99a`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99b`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99c`,
        fs:  `cpe:2.3:a:pimpstore:aprende_a_meditar:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99d`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99e`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99f`,
        fs:  `cpe:2.3:o:cisco:ip_phone_8800_series_firmware:10.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99g`,
        fs:  `cpe:2.3:a:ibm:content_navigator:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:0.99h`,
        fs:  `cpe:2.3:a:androidebookapp:healthy_lunch_diet_recipes:3.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.00`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.0`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.0a`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.44.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.0b`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.1`,
        fs:  `cpe:2.3:a:apache:activemq:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.1a`,
        fs:  `cpe:2.3:a:openx:openx:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.1b`,
        fs:  `cpe:2.3:a:keepass:keepass:0.97:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.1c`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1049.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.1d`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.1e`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.2`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.590:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.2a`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.3a`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.3b`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.3d`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.28.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.4`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.4a`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.4b`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.4c`,
        fs:  `cpe:2.3:o:sun:solaris:2.6:hw3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.4d`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.4e`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.4f`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.5.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5a`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5b`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.5.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5c`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5d`,
        fs:  `cpe:2.3:a:cnectd:cnectd:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5e`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5f`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.12:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5g`,
        fs:  `cpe:2.3:a:hdw-tube_project:hdw-tube:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5h`,
        fs:  `cpe:2.3:h:xyplex:maxserver_xyplex_terminal_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5i`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5j`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5k`,
        fs:  `cpe:2.3:a:securelogix:computer_based_training_for_the_etm_system:5.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5l`,
        fs:  `cpe:2.3:o:microsoft:windows_98:-:scd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5m`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5n`,
        fs:  `cpe:2.3:h:cisco:3925_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5o`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.8:b2:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5p`,
        fs:  `cpe:2.3:a:google:chrome:17.0.934.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5q`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5r`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5s`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5t`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5u`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.5v`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(9e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.6`,
        fs:  `cpe:2.3:a:bytemark:symbiosis:1322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.6d`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.6e`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(5\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.6f`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a3\(2.7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.6g`,
        fs:  `cpe:2.3:a:adobe:flash_player:6.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.6h`,
        fs:  `cpe:2.3:a:justsystems:shuriken_pro:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.6i`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.6j`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.7`,
        fs:  `cpe:2.3:h:dell:latitude_e4200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.8`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.9`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.10`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.12`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.13`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.14`,
        fs:  `cpe:2.3:a:logitech:desktop_messenger:2.30.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.15`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.11.250.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.16`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.17`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.18`,
        fs:  `cpe:2.3:a:openafs:openafs:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.19`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.3.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.20`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.21`,
        fs:  `cpe:2.3:a:cisco:nac_agent:4.8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.22`,
        fs:  `cpe:2.3:o:redhat:fedora:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.23`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.079:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.24`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.25`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.26`,
        fs:  `cpe:2.3:a:mcafee:email_and_web_security:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.27`,
        fs:  `cpe:2.3:a:gnu:libtool:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.28`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.29`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.30`,
        fs:  `cpe:2.3:a:gnome:glib:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.31`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.32`,
        fs:  `cpe:2.3:a:skype:skype:0.92.0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.33`,
        fs:  `cpe:2.3:a:hp:memories_disc:1.0.4.805:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.34`,
        fs:  `cpe:2.3:a:google:chrome:10.0.620.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.35`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.37`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.38`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.39`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.0.1:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.40`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p270:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.41`,
        fs:  `cpe:2.3:h:cisco:traffic_anomaly_detector_module:5.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.42`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix_5570_controller_firmware:20.017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.43`,
        fs:  `cpe:2.3:a:apache:tika:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.44`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.45`,
        fs:  `cpe:2.3:a:gnome:glib:2.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.46`,
        fs:  `cpe:2.3:a:apache:apache_test:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.47`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.48`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.50`,
        fs:  `cpe:2.3:a:tm_software:tempo:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.51`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.52`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.53`,
        fs:  `cpe:2.3:a:wp_appointments_schedules_project:wp_appointments_schedules:1.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.54`,
        fs:  `cpe:2.3:a:apple:iphoto:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.55`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.55:rc01`,
        fs:  `cpe:2.3:a:hp:scan:10.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.56`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.56:devel`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.57`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.57:rc01`,
        fs:  `cpe:2.3:h:enterasys:roamabout_ap2000:6.04.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.58`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.59`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_20.18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.60`,
        fs:  `cpe:2.3:a:clickdesk:clickdesk_live_support-live_chat_plugin:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.61`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.62`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.63`,
        fs:  `cpe:2.3:a:pandasecurity:panda_av_pro_2014:13.01.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.64`,
        fs:  `cpe:2.3:a:hp:performance_core:10.50.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.65`,
        fs:  `cpe:2.3:a:atlassian:jira:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.0.66`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.1.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-50:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.1`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.2`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.3`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.4`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:build20110407.20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.5`,
        fs:  `cpe:2.3:a:globalscape:c\&#43;\&#43;_release_runtime:9.0.30729.4148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.6`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:6.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.7`,
        fs:  `cpe:2.3:a:spigot:dealio_toolbar:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.9`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.10`,
        fs:  `cpe:2.3:a:sympa:sympa:3.1b.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.11`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.12`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:8.0.0:03:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.13`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.14`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.15`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.16`,
        fs:  `cpe:2.3:a:macromedia:flash_player:8.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.17`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.18`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:8.03:hotfix1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.19`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.20`,
        fs:  `cpe:2.3:a:henner_zeller:henplus:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.21`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.22`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2002:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.23`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.5:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.24`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.25`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.26`,
        fs:  `cpe:2.3:a:git-scm:git:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.27`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.28`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.29`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.30`,
        fs:  `cpe:2.3:o:samsung:samsung_mobile:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.31`,
        fs:  `cpe:2.3:a:iojs:io.js:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.32`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:5.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.33`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.34`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.35`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.36`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ebv:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.37`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.38`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.39`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p414:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.40`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.60.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.41`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.42`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.43`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.43:devel`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.44`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.93.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.45`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.45:devel`,
        fs:  `cpe:2.3:h:iodata:hdl2-ah:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.46`,
        fs:  `cpe:2.3:a:street_walker_project:street_walker:0.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.46:devel`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.47`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.30.020.1829:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.47:beta`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.5sq:3.5.0sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.48`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.48:betas`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.49`,
        fs:  `cpe:2.3:a:vips:vips:7.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.50`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.51`,
        fs:  `cpe:2.3:h:huawei:eudemon_usg9500:v200r001c00spc600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.52`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.53`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1670.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.54`,
        fs:  `cpe:2.3:a:hp:sitescope_user_interface:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.55`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.2.56`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.0:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.3.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_tools:8.47.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.3`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.4`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.5`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.6`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.8`,
        fs:  `cpe:2.3:a:iss:realsecure_nokia:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.9`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.054:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.10`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7940:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.11`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.12`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.13`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.14`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.4p4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.15`,
        fs:  `cpe:2.3:a:sony:vaio_manual_cybersupport:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.16`,
        fs:  `cpe:2.3:a:acl:acl:9.1.0.213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.17`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.4.19`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.0:beta`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.1`,
        fs:  `cpe:2.3:a:vips:vips:7.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.1:beta`,
        fs:  `cpe:2.3:a:logitech:videocall\&#43;viewerclient:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.2`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.2:beta`,
        fs:  `cpe:2.3:a:sap:background_processing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.3:beta`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.4:beta`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.51:-:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.5`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r5-rc1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.5:beta`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.6`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20160403:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.6:beta`,
        fs:  `cpe:2.3:a:automon:zoella_unofficial:1.4.0.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.7`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:08.0.01g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.7:beta`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.8`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.8:beta`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-05-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.9`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.9:beta`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.363:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.10:beta`,
        fs:  `cpe:2.3:a:linux-sottises:news-tnk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.11`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.11:beta`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.12`,
        fs:  `cpe:2.3:a:citrix:xenclient_xt:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.13`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.13:beta`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.14`,
        fs:  `cpe:2.3:a:microsoft:project:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.15`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.16`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:8.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.17`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.18`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.404:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.19`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc085a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.20:beta`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.21`,
        fs:  `cpe:2.3:a:novell:imonitor:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.22`,
        fs:  `cpe:2.3:a:athoc:athocgov:6.2.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.23`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)md3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.24`,
        fs:  `cpe:2.3:a:timelessblack:timeless_black:2.10.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.25`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1.13\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.26`,
        fs:  `cpe:2.3:a:perl:perl:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.5.27`,
        fs:  `cpe:2.3:a:symantec:mail_security:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.0`,
        fs:  `cpe:2.3:h:cisco:nexus_2148t_fex_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.0:beta`,
        fs:  `cpe:2.3:a:apptreestudios:gangsta_auto_thief_iii:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.1:beta`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.2:beta`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.6:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.3`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.3:beta`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.4`,
        fs:  `cpe:2.3:a:ibm:director:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.4:beta`,
        fs:  `cpe:2.3:a:oracle:application_server:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.6`,
        fs:  `cpe:2.3:a:adastra:trace_mode_data_center:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.7`,
        fs:  `cpe:2.3:h:juniper:mx2020:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.7:beta`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.450:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.8`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.8:beta`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.1:a26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.9`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.9:beta`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.4:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.10`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.0_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.10:beta`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5b\)su6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.11`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp2:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.11:beta`,
        fs:  `cpe:2.3:a:epiqo:email:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.12:beta`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.829:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.13`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.13:beta`,
        fs:  `cpe:2.3:a:horde:imp:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.14`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.14:beta`,
        fs:  `cpe:2.3:a:google:v8:3.24.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.15`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.15:beta`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.16`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.17`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.18`,
        fs:  `cpe:2.3:a:gnu:grep:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.19`,
        fs:  `cpe:2.3:a:umn:mapserver:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.20`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.21`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.22`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.23`,
        fs:  `cpe:2.3:a:google:chrome:12.0.730.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.24`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.25`,
        fs:  `cpe:2.3:a:adcillc:simplemeta:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libpng:libpng:1.6.26`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.2.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.3.0`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:t29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(11d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.4.0`,
        fs:  `cpe:2.3:a:gizra:og_vocab:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.4.1`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.4.3`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.4.5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.4.6`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_lms:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.4.7`,
        fs:  `cpe:2.3:h:nortel:802.11_wireless_ip_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libproxy_project:libproxy:0.4.8`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.1`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.01:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.2`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1_build_41439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.3`,
        fs:  `cpe:2.3:a:x:libxcb:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.4`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.6\(1.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.5`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.6`,
        fs:  `cpe:2.3:a:cisco:secure_acs_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.7`,
        fs:  `cpe:2.3:a:file_project:file:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.13.8`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.14.0`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.14.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.14.2`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.14.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.02:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.14.4`,
        fs:  `cpe:2.3:a:anritsu:traceview:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.14.5`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.14.6`,
        fs:  `cpe:2.3:a:hp:service_manager:9.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.14.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.15.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.15.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.15.2`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.15.3`,
        fs:  `cpe:2.3:a:ups:worldship_upsvcmm:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.15.4`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.3_build_42958:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.16.1:alpha`,
        fs:  `cpe:2.3:a:ca:license_software:1.62.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libraw:libraw:0.18.1`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:3.3.202`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:3.5.2`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:4.2.4`,
        fs:  `cpe:2.3:a:f5:big-ip_protocol_security_module:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:4.3.4`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:4.3.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:4.3.6`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:4.4.0`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:4.4.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.71:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:5.0.3`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:5.0.4`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:5.0.5`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:5.2.6`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:5.2.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreoffice:libreoffice:5.3.0.0:beta2`,
        fs:  `cpe:2.3:o:oracle:solaris:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.1`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.2`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.3`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.5`,
        fs:  `cpe:2.3:a:cisco:email_security_virtual_appliance:8.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p305:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.7`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.9`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.10`,
        fs:  `cpe:2.3:a:hp:hpssupply:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.11`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.2:-:-:*:enterprise:-:-:publish_engine`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.12`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.14`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libreswan:libreswan:3.16`,
        fs:  `cpe:2.3:a:webtrends:ui_server_modules:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libsndfile_project:libsndfile:1.0.28`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.4.7`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.4.8`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.72.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.5.0`,
        fs:  `cpe:2.3:a:webmin:usermin:1.340:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.5.0:rc1`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.5.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.18d60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.5.2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.5.3`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.5.4`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.5.5`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3203a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.6.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.503.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.6.1`,
        fs:  `cpe:2.3:h:huawei:e200x7:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.6.2`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp1b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.6.3`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.6.4`,
        fs:  `cpe:2.3:a:shopware:shopware:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh:libssh:0.7.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh2:libssh2:1.4.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libssh2:libssh2:1.6.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4`,
        fs:  `cpe:2.3:a:busybox:busybox:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta18`,
        fs:  `cpe:2.3:a:cisco:meraki_ms_firmware:2014-09-24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta24`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta28`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta29`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta31`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta32`,
        fs:  `cpe:2.3:a:yokogawa:fast\/tools:r9.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta34`,
        fs:  `cpe:2.3:a:mylittleforum:my_little_forum:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta35`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta36`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.4:beta37`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.2`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:2.51:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.4`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.6`,
        fs:  `cpe:2.3:a:rpm:rpm:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.6:beta`,
        fs:  `cpe:2.3:a:netgear:readynas_surveillance:1.3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.7`,
        fs:  `cpe:2.3:a:oracle:apex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.7:alpha`,
        fs:  `cpe:2.3:h:intel:pro_wireless_3945abg:1.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.7:alpha2`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.7:alpha3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.7:alpha4`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.5.7:beta`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.483:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.6.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.6.0:beta`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.6.0:beta2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.6.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.7.0`,
        fs:  `cpe:2.3:h:apple:iphone:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.7.0:alpha`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.7.0:beta`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_server:6.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.7.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.7.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.7.2`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-08-22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.7.3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.7.4`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.8.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.8.1`,
        fs:  `cpe:2.3:a:isc:bind:9.7.4:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.8.2`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9`,
        fs:  `cpe:2.3:h:cisco:catalyst_6503-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9.0`,
        fs:  `cpe:2.3:a:emc:secure_remote_services:3.03:*:*:*:virtual:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9.0:beta`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9.1`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9.2`,
        fs:  `cpe:2.3:a:netiq:security_manager_agent:6.5.3.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9.2-5.2.1`,
        fs:  `cpe:2.3:a:symantec:protection_for_sharepoint_servers:6.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9.3`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:3.9.5`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0:alpha`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.519.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0:beta2`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0:beta3`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0:beta4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0:beta5`,
        fs:  `cpe:2.3:a:sun:one_web_server:6.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0:beta6`,
        fs:  `cpe:2.3:o:sun:solaris:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0.1`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0.2`,
        fs:  `cpe:2.3:a:ayatana_project:unity:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0.6`,
        fs:  `cpe:2.3:a:s9y:serendipity:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0.7`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.23:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff:libtiff:4.0.8`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1673.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libtiff_project:libtiff:4.0.6`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libunwind_project:libunwind:1.1`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.3.1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.4.0`,
        fs:  `cpe:2.3:a:kingsoft:kdrive:1.21.0.1878:-:-:*:personal:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.4.1`,
        fs:  `cpe:2.3:a:openbsd:openbsd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.4.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.4.3`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.4.4`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.4.5`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:3.2.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.4.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.4.7`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.0`,
        fs:  `cpe:2.3:a:google:earth:5.1.3535.3218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.1`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.3`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.5`,
        fs:  `cpe:2.3:a:websense:enterprise:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.6`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.7`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.09.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.8`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.9`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.10`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.11`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.12`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.13`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.14`,
        fs:  `cpe:2.3:a:aol:aolserver:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.15`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.16`,
        fs:  `cpe:2.3:a:python:python:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libupnp_project:libupnp:1.6.17`,
        fs:  `cpe:2.3:a:php:php:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libuv_project:libuv:0.10.33`,
        fs:  `cpe:2.3:a:google:chrome:6.0.464.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:libvncserver_project:libvncserver:0.9.10`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:5.6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:life_story_of_sheikh_mujib_project:life_story_of_sheikh_mujib:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:1.7.5`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:1.8.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:1.9.0`,
        fs:  `cpe:2.3:a:milesj:decoda:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:1.9.1`,
        fs:  `cpe:2.3:a:citrix:gotoassist:8.0.0.514:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:1.9.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:2.0.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:2.0.3`,
        fs:  `cpe:2.3:a:shavlik:netchk_configure:4.0.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:2.1.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:2.1.1`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-rc7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:2.2.0`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:2.2.1`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:2.2.5`,
        fs:  `cpe:2.3:h:wdc:my_net_n600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:3.0.0`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:3.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:3.2.0`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:3.5.0`,
        fs:  `cpe:2.3:o:raritan:px:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:3.6.0`,
        fs:  `cpe:2.3:a:horde:groupware:1.2:rc1:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:3.6.1`,
        fs:  `cpe:2.3:a:horde:groupware:1.1:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.0.0`,
        fs:  `cpe:2.3:a:ca:antispyware_for_the_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.0.0:rc1`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.0.0:rc2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.1.0`,
        fs:  `cpe:2.3:h:hp:jd660a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.1.1`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.1.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.936.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.1.3`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.2.0`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.0.0_f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.2.1`,
        fs:  `cpe:2.3:a:logitech:lws_video_mask_maker:13.10.1216.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.2.2`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.0`,
        fs:  `cpe:2.3:a:synology:diskstation_manager:4.0-2259:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.0:rc1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.4.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.0:rc2`,
        fs:  `cpe:2.3:a:cybozu:garoon:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.1`,
        fs:  `cpe:2.3:h:htc:shift_4g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.2`,
        fs:  `cpe:2.3:a:microsoft:ie:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.3`,
        fs:  `cpe:2.3:a:apple:quicktime:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.5`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp2:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.3.6`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.782.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.4.0`,
        fs:  `cpe:2.3:a:gummybearstudios:ftp_drive_\&#43;_http_server:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.4.1`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:4.4.2`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.0.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.0.0:rc1`,
        fs:  `cpe:2.3:a:apache:axis2:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.1.0`,
        fs:  `cpe:2.3:h:cisco:rv320_dual_gigabit_wan_wf_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.1.0:rc1`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.1.1`,
        fs:  `cpe:2.3:a:twistedmatrix:twistedweb:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.1.2`,
        fs:  `cpe:2.3:a:ca:unicenter_asset_management:3.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.2.0`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.24:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.2.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:5.2.3`,
        fs:  `cpe:2.3:a:apache:knox:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:6.1.2_ce_ga3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:6.1.x_ee`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:6.2:sp8:~~enterprise~~~`,
        fs:  `cpe:2.3:a:moodle:moodle:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liferay:liferay_portal:6.2.x_ee`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.24:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lifetimefitness:life_time_fitness:1.9::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.2`,
        fs:  `cpe:2.3:a:x:libxp:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.3`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.4`,
        fs:  `cpe:2.3:a:smarty:smarty:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5`,
        fs:  `cpe:2.3:o:huawei:s9706_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5:m4`,
        fs:  `cpe:2.3:a:google:chrome:14.0.810.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5:rc1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5:rc2`,
        fs:  `cpe:2.3:a:emulex:fibre_channel_hbanyware:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5:rc3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(27\)sv1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5:rc4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5:rc5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5:rc6`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liftweb:lift:2.5.1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightbox_photo_gallery_project:lightbox_photo_gallery:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moodle:moodle:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.1.1`,
        fs:  `cpe:2.3:a:schneider-electric:accutech_manager:2.00.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.1.2`,
        fs:  `cpe:2.3:a:netscape:communicator:4.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.1.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.1.4`,
        fs:  `cpe:2.3:a:jquery:jquery:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.1.5`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.1.6`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.3.0`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x45:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.3.1`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.5.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_sametime:8.0.80822:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.5.1`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.03:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.5.2`,
        fs:  `cpe:2.3:a:hp:application_information_optimizer:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.6.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.6.1`,
        fs:  `cpe:2.3:a:ibm:lotus_protector_for_mail_security:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.7.0`,
        fs:  `cpe:2.3:a:viedemerde:vdm_officiel:5.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_gtk%2b_greeter_project:lightdm_gtk%2b_greeter:1.7.1`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_project:lightdm:1.14.3`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_project:lightdm:1.16`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_project:lightdm:1.16.1`,
        fs:  `cpe:2.3:a:cisco:1000v_virtual_ethernet_module_\(vem\):4.0\(4\):sv1\(3b\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_project:lightdm:1.16.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_project:lightdm:1.16.3`,
        fs:  `cpe:2.3:h:carefusion:pyxis_supplystation:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_project:lightdm:1.16.4`,
        fs:  `cpe:2.3:a:opalvoip:portable_tool_library:2.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightdm_project:lightdm:1.22.0`,
        fs:  `cpe:2.3:a:redhat:gluster_storage:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightningtools:deliverpoint:12.0.3`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightscribe:lightscribe:1.4.74.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightscribe:lightscribe:1.4.84.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightscribe:lightscribe:1.4.124.1`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightscribe:lightscribe:1.4.136.1`,
        fs:  `cpe:2.3:a:perl:perl:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightscribe:lightscribe:1.4.142.1`,
        fs:  `cpe:2.3:a:zed_shaw:mongrel:0.3.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightscribe:lightscribe:1.6.43.1`,
        fs:  `cpe:2.3:a:apple:itunes:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightscribe:lightscribe_system_software:1.14.25.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.3.16`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.4`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.5`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cbz:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.6`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.7`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.8`,
        fs:  `cpe:2.3:a:lshell_project:lshell:0.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.9`,
        fs:  `cpe:2.3:a:websitepanel:websitepanel:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.10`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0804hf-s-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.11`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.12`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.13`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.14`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:7.2.4:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.15`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.16`,
        fs:  `cpe:2.3:a:cwt_frontend_edit_project:cwt_frontend_edit:1.2.4:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.17`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.18`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.19`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.20`,
        fs:  `cpe:2.3:a:ibm:qradar_risk_manager:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.21`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:1.03.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.22`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.23`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.a6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.24`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.25`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.26`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.27`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.28`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.29`,
        fs:  `cpe:2.3:a:redhat:jboss_wildfly_application_server:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.30`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.31`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.32`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.33`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.34`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.4.35`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lighttpd:lighttpd:1.5.0`,
        fs:  `cpe:2.3:a:erlang-solutions:mongooseim:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lightwitch:metronome:3.4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:likeheroapp:likehero_get_instagram_likes:1.0.7::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:jet:4.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.01`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.50`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.52`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.53%2b`,
        fs:  `cpe:2.3:a:parsi-font_project:parsi-font:4.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.70%2b`,
        fs:  `cpe:2.3:a:verweise-wordpress-twitter_project:verweise-wordpress-twitter:1.0.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.71%2b`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.72`,
        fs:  `cpe:2.3:a:gnu:radius:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.80%2b`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.81%2b`,
        fs:  `cpe:2.3:a:apache:camel:2.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.82%2b`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.85`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.86`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.87%2b`,
        fs:  `cpe:2.3:o:cisco:ios:12.2f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.90%2b`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:1.91%2b`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:2.05%2b`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:limesurvey:limesurvey:2.06%2b`,
        fs:  `cpe:2.3:a:meta_tags_quick_project:meta_tags_quick:7.x-2.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:limewire:limewire:4.11.3`,
        fs:  `cpe:2.3:a:kokuyo:camiapp:1.21.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:limny:limny:3.0.1`,
        fs:  `cpe:2.3:a:emc:networker:7.4:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lina_wolf:seo_pack_for_tt_news:1.0.0`,
        fs:  `cpe:2.3:a:x:libxv:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lina_wolf:seo_pack_for_tt_news:1.3.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lina_wolf:seo_pack_for_tt_news:1.3.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lincolnloop:authorize.net_echeck_module:-`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lindo:lingo:11.0.1.6`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lindo:lingo:12.0.2.20`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linear_case_project:linear_case:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:samba:samba:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linear_case_project:linear_case:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linear_case_project:linear_case:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins-ci:exclusion:0.6:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:linear_case_project:linear_case:6.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linecorp:line:4.3.0.724::~~~windows~~`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linecorp:line:4.3.1::~~~mac_os_x~~`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_verizon:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linecorp:line%40:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:dpq3925_8x4_docsis_3.0_wireless_residential_gateway_with_embedded_digital_voice_adapter:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linecorp:line%40:1.0.0::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linecorp:line%40:1.2.1::~~~android~~`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linecorp:line%40:1.2.1::~~~iphone_os~~`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lingotek:lingotek:6.x-1.0`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.02.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lingotek:lingotek:6.x-1.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lingotek:lingotek:6.x-1.3`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.2.4:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:lingotek:lingotek:6.x-1.4`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lingotek:lingotek:6.x-1.31`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lingotek:lingotek:6.x-1.40`,
        fs:  `cpe:2.3:a:juniper:secure_application_manager:6.3.0.14715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lingotek:lingotek:6.x-1.43`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linkit_project:linkit:7.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linkit_project:linkit:7.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:poi:3.0.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:1.0.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.4.1_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:1.0.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:1.2.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.7:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:1.2.5:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:1.3.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp1:compute_cluster:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:1.3.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.2.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:1.3.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.2.2-20.sles10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53_95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:fedex:fxrscadv:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:0.99.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ad-minister_project:ad-minister:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.4:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.5:-:~~~wordpress~~`,
        fs:  `cpe:2.3:h:huawei:ar200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.6:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.7:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.8:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.0.9:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:hiniarata:casebook_plugin:0.9.3:*:*:*:*:basercms:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.1.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.1.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:spip:spip:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.1.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.1.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksalpha:social_sharing_toolkit_plugin:2.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:xnview:xnview:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befcmu10:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befn2ps4:-`,
        fs:  `cpe:2.3:a:apple:quicktime:7.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befn2ps4:1.42.7`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr11:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr11:1.40.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr11:1.41`,
        fs:  `cpe:2.3:a:debian:apt:0.8.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr11:1.42.3`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.78.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr11:1.42.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr11:1.43`,
        fs:  `cpe:2.3:o:juniper:junos:14.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr11:1.43.3`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr11:1.44`,
        fs:  `cpe:2.3:a:pulsesecure:steel_belted_radius:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:0.0`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.106:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.35`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.36`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.37`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.38.5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.39`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.40.2`,
        fs:  `cpe:2.3:o:cisco:spa8000_8-port_ip_telephony_gateway_firmware:6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.41`,
        fs:  `cpe:2.3:a:apache:poi:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.42.3`,
        fs:  `cpe:2.3:h:lacie:lac9000464u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.42.7`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.43`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.43.3`,
        fs:  `cpe:2.3:a:monotone:monotone:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.44`,
        fs:  `cpe:2.3:a:dell:controlvault_diagnostics:1.1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41:1.45.7`,
        fs:  `cpe:2.3:h:cisco:2112_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41_v3:-`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.209.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr41w:-`,
        fs:  `cpe:2.3:a:vmware:view:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr81:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr81:2.42.7.1`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsr81:2.44`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsru31:-`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsru31:1.40.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.27:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsru31:1.41`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsru31:1.42.3`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.4:mr4_build_1000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsru31:1.42.7`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsru31:1.43`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.633:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsru31:1.43.3`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-tf-182_with_network_printer_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsru31:1.44`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsx41:-`,
        fs:  `cpe:2.3:h:symantec:nexland_pro100_firewall_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsx41:1.42.7`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsx41:1.43`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsx41:1.43.3`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a4\(2.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsx41:1.43.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsx41:1.44`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsx41:1.44.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befsx41:1.45.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.04:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befvp41:-`,
        fs:  `cpe:2.3:a:enyetech:coca-cola_fm_brasil:2.0.41709:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befvp41:1.01.04`,
        fs:  `cpe:2.3:o:cisco:ios_xr:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befvp41:1.39.64`,
        fs:  `cpe:2.3:a:digium:asterisk:11.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befvp41:1.40.1`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befvp41:1.40.3f`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befvp41:1.40.4`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.1.0:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befvp41:1.42.7`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:1.4.2.7`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.05:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:1.37.2`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:1.37.2b`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:1.37.9b`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:1.40.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:1.42.7`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:4.0\(2\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:1.43.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4:1.44`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4_v3:-`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:befw11s4_v4:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(3\)n1\(2.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:hpro200:-`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:hpro200:1.42.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:psus4_printserver:-`,
        fs:  `cpe:2.3:a:myrephp:myre_real_estate_software:2012:q2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:psus4_printserver:6032`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:rt31p2:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:rv082:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:spa921:-`,
        fs:  `cpe:2.3:a:apple:claris_emailer:2.0v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:spa921:1.0.0`,
        fs:  `cpe:2.3:a:abrahamtours:abraham_tours:1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:spa941:-`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wag200g:-`,
        fs:  `cpe:2.3:a:apple:itunes:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wag200g:1.01.01`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wag54gs:-`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wag54gs:1.00.06`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wap11:-`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wap11:1.3`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wap11:1.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wap11:2.2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wap54g:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.349:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wap54g:3.01`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wap55ag:-`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wap55ag:1.0.7`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wet11:-`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:unlocked:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wet11:1.4.3`,
        fs:  `cpe:2.3:a:adobe:camera_raw:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wet11:1.5.4`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wet11:1.31`,
        fs:  `cpe:2.3:a:borland:caliberrm:7.2.157.404:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wet11:1.32`,
        fs:  `cpe:2.3:a:status:statusnet:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wip_330_wireless-g_ip_phone:-`,
        fs:  `cpe:2.3:a:apache:hadoop:0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wip_330_wireless-g_ip_phone:1.0.6_a`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linksys:wpc300n_wireless-n_notebook_adapter_driver:-`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.27:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:-`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:1.00.9`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:1.42.3`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.7m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:2.00.8`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:2.02.7`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:2.04.4`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:3.01.3`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.3_build_9.0.3.1000:mr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:3.03.6`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g:4.00.7`,
        fs:  `cpe:2.3:a:microsoft:personal_web_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54g_v5:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54gc:-`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54gc:1.00.7`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54gc:1.03.0`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54gl:-`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54gl:4.30.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54gs:-`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54gs:4.50.6`,
        fs:  `cpe:2.3:a:apache:struts:2.3.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wrt54gs:4.70.6`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wvc11b:-`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:linksys:wvc11b:2.10`,
        fs:  `cpe:2.3:h:linksys:wag54gs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.0`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc6:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.2`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.3`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_products:8.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.4`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.6`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d44.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.7`,
        fs:  `cpe:2.3:a:altiris:connector_solution_quick_start:6.0.1102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.8`,
        fs:  `cpe:2.3:a:advantech:advantech_webaccess:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.8.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.9`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.12:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.10`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.07.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.2:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.3`,
        fs:  `cpe:2.3:a:libssh:libssh:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.4`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.5`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:07-56-\/g\(\*2\):-:standard:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.6`,
        fs:  `cpe:2.3:a:apple:apple_mobile_device_support:4.0.0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.8`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.6.6.636:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.9`,
        fs:  `cpe:2.3:a:google:chrome:17.0.947.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.10`,
        fs:  `cpe:2.3:a:gnu:radius:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.11`,
        fs:  `cpe:2.3:a:openttd:openttd:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.11.12`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.12`,
        fs:  `cpe:2.3:a:zemanta:related_posts:2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.12.1`,
        fs:  `cpe:2.3:a:nokia:qt_creator:2.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.12.2`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.12.3`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.12.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.12.5`,
        fs:  `cpe:2.3:a:php-nuke:pool_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.12.6`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.13`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.13.1`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.13.2`,
        fs:  `cpe:2.3:a:markdown_on_saved_improved_project:markdown_on_saved_improved:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.13.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.13.4`,
        fs:  `cpe:2.3:a:microsoft:project_server:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.13.5`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.14`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_mse_series_software:4.3\(2.18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.14.1`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.14.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.07.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.14.3`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.14.4`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.14.5`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.14.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p92:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.14.7`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.15`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.60.020.2771:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.15.1`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_aix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.15.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.15.3`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.15.4`,
        fs:  `cpe:2.3:a:lancope:stealthwatch:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.15.5`,
        fs:  `cpe:2.3:a:codiad:codiad:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.15.6`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.15.7`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.2`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.4`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.0:*:hp_ux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.5`,
        fs:  `cpe:2.3:a:skyarts:neofiler:5.4.3:-:-:*:free:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.6`,
        fs:  `cpe:2.3:o:cisco:ios:15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.7`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.8`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.051124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.10`,
        fs:  `cpe:2.3:a:streamingidiot:bodyguard_for_hire:0.18.13146.42280:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.11`,
        fs:  `cpe:2.3:o:tp-link:archer_c5_\(1.2\)_firmware:141126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.12`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.13`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.14`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.15`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.16`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_desktop_central:9.0:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.17`,
        fs:  `cpe:2.3:a:brian_altenhofel:slidebox:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.18`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.19`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1:4.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.20`,
        fs:  `cpe:2.3:a:ansys:mechanical:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.21`,
        fs:  `cpe:2.3:a:fleugel:myu-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.22`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.23`,
        fs:  `cpe:2.3:a:time_tracker_project:time_tracker:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.24`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:6000:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.25`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.26`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.27`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.284:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.28`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.29`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.30`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.16.31`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17`,
        fs:  `cpe:2.3:a:rockwellautomation:1763-l16dwd_series_b:15.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.1`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.0\(5\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.2`,
        fs:  `cpe:2.3:o:cisco:virtualization_experience_client_6000_series_firmware:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.3`,
        fs:  `cpe:2.3:a:isc:bind:9.3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.4`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf809a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.5`,
        fs:  `cpe:2.3:a:busybox:busybox:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.6`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.7`,
        fs:  `cpe:2.3:a:aol:aim_toolbar:5.96.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.8`,
        fs:  `cpe:2.3:h:hp:3com_router:3040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.9`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.10`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:9.5.1.3426:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.11`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.12`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.7.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.13`,
        fs:  `cpe:2.3:a:apache:sling_auth_core_component:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.17.14`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.18.1`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.5:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.18.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:2.1:*:ia64-as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.18.3`,
        fs:  `cpe:2.3:a:symantec:enterprise_firewall:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.18.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.18.5`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.18.6`,
        fs:  `cpe:2.3:h:lucent:orinoco_rg-1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.18.7`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.18.8`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.22`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3060-dc-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.22.2`,
        fs:  `cpe:2.3:h:intel:server_board_s5000vcl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.22.3`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.22.4`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.22.5`,
        fs:  `cpe:2.3:o:raritan:px:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.22.6`,
        fs:  `cpe:2.3:a:gnome:glib:2.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.22.7`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23`,
        fs:  `cpe:2.3:a:wizaz:wizaz_forum:3.6.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23:rc2`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23.1`,
        fs:  `cpe:2.3:a:gajim:gajim:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23.2`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.3p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23.4`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23.5`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23.6`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.23.7`,
        fs:  `cpe:2.3:h:emerson:avocent_mpu108edac:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.24:rc1`,
        fs:  `cpe:2.3:a:emc:documentum_applicationxtender_desktop:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.24:rc2`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.24:rc3`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.24:rc4`,
        fs:  `cpe:2.3:a:payment_for_webform_project:payment_for_webform:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.24:rc5`,
        fs:  `cpe:2.3:h:ibm:s08:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.27.51`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0189:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32`,
        fs:  `cpe:2.3:a:divx:codec:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.3`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.4`,
        fs:  `cpe:2.3:a:emc:my_documentum_for_desktop:6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.5`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp2:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.6`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:*:cs:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.7`,
        fs:  `cpe:2.3:o:huawei:5300hi_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)sy4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.9`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.10`,
        fs:  `cpe:2.3:a:cisco:evolved_programmable_network_manager:1.2.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.11`,
        fs:  `cpe:2.3:a:djangoproject:django:1.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.12`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.13`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.422:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.14`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.15`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp4:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.16`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.17`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.32.18`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.34.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.34.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.34.3`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:kernel:2.6.35.1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.9:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux:linux_kernel:-`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:-`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:1.2.0`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:1.3.0`,
        fs:  `cpe:2.3:a:gnome:evolution:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.1`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.5`,
        fs:  `cpe:2.3:a:yassl:cyassl:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.6`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.7`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1515-2_pn_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.8`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.9`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:4.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.10`,
        fs:  `cpe:2.3:h:hp:jg361a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.11`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.12`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.13`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.15`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.16`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.17`,
        fs:  `cpe:2.3:a:haxx:curl:7.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.18`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.19`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.20`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.21`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.22`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.23`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.24`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.25`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.26`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.27`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.28`,
        fs:  `cpe:2.3:a:docker:docker:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.29`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.30`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.31`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.32`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.33`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-20-\/e:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.34`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.35`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.36`,
        fs:  `cpe:2.3:a:oracle:hyperion_interactive_reporting:11.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.37`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.38`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.08.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.0.39`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.1.89`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.0:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.1.132`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.1`,
        fs:  `cpe:2.3:a:adobe:svg_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.3`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.4`,
        fs:  `cpe:2.3:a:oracle:database_server:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.4:rc1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.6`,
        fs:  `cpe:2.3:a:mcafee:epo_mcafee_virtual_technician:1.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.7`,
        fs:  `cpe:2.3:h:axis:207w_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.8`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.9`,
        fs:  `cpe:2.3:h:htc:desire_hd:frg83d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.10`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.0:dev3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.11`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.12`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.13`,
        fs:  `cpe:2.3:a:saltstack:salt_2015:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.13:pre15`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_anywhere:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.14`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.15`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.15:pre16`,
        fs:  `cpe:2.3:a:mascov:csapp_-_colegio_san_agustin:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.16`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.16:pre5`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:11.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.16:pre6`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:6.1.15.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.17`,
        fs:  `cpe:2.3:a:horde:horde_groupware:5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.17:pre14`,
        fs:  `cpe:2.3:a:zen-cart.jp:zen_cart:1.3:*:*:ja-jp:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.18`,
        fs:  `cpe:2.3:a:ardour:ardour:2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.19`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.20`,
        fs:  `cpe:2.3:a:pluxml:pluxml:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21`,
        fs:  `cpe:2.3:a:roxio:creator_data:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21:pre1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.0:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21:pre2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21:pre3`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21:pre4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6.5be:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21:rc1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21:rc2`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21:rc3`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.21:rc4`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.22`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.22:rc1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.22:rc2`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.22:rc3`,
        fs:  `cpe:2.3:a:f5:big-ip_websafe:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.23`,
        fs:  `cpe:2.3:a:zope:zope:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.23:rc1`,
        fs:  `cpe:2.3:a:git-scm:git:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.23:rc2`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.24`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.24:rc2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.24:rc3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.24:rc4`,
        fs:  `cpe:2.3:a:qemu:qemu:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.24:rc5`,
        fs:  `cpe:2.3:a:elefantcms:elefantcms:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.25`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.26`,
        fs:  `cpe:2.3:a:google:chrome:10.0.622.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.27:pre1`,
        fs:  `cpe:2.3:a:redhat:rhel_developer_suite:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.27:pre2`,
        fs:  `cpe:2.3:a:emc:avamar:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.27:rc1`,
        fs:  `cpe:2.3:a:ibm:quickfile:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.2.27:rc2`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.05:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.1`,
        fs:  `cpe:2.3:a:cisco:access_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.4`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.5`,
        fs:  `cpe:2.3:a:apache:solr:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.6`,
        fs:  `cpe:2.3:a:apache:camel:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.8`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.9`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.10`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.11`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.12`,
        fs:  `cpe:2.3:a:mozilla:firefox:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.13`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.2:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.14`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.15`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.16`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.17`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_258_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.18`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.19:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.19`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.20`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:17.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.21`,
        fs:  `cpe:2.3:a:sun:java_web_console:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.22`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.23`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.24`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.25`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)sy6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.26`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.27`,
        fs:  `cpe:2.3:a:gnome:glib:2.21.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.28`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.29`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.30`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.31`,
        fs:  `cpe:2.3:a:tomatocart:tomatocart:1.1.8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.32`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.27:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.33`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.34`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.12:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.35`,
        fs:  `cpe:2.3:a:gnu:grep:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.36`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.6.2\(31\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.37`,
        fs:  `cpe:2.3:a:hp:photo_and_imaging_gallery:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.38`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.39`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.40`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.41`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.42`,
        fs:  `cpe:2.3:o:checkpoint:gaia_os:r75.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.43`,
        fs:  `cpe:2.3:a:nec:socks_5:1.0r11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.44`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.45`,
        fs:  `cpe:2.3:a:ibm:autofs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.46`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.47`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.48`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.49`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.50`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.51`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre1`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre2`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre3`,
        fs:  `cpe:2.3:a:apache:tomcat:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre4`,
        fs:  `cpe:2.3:a:ibm:ims_enterprise_suite:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre5`,
        fs:  `cpe:2.3:a:apple:webkit:522:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre7`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.1.1.-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre8`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.3.99:pre9`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0`,
        fs:  `cpe:2.3:a:ibm:forms_viewer:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test1`,
        fs:  `cpe:2.3:a:sap:netweaver:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test10`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test11`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2s\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test12`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test2`,
        fs:  `cpe:2.3:a:iij:seil\/neu_2fe_plus_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test3`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test4`,
        fs:  `cpe:2.3:a:libssh2:libssh2:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test5`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test6`,
        fs:  `cpe:2.3:h:hp:laserjet_9065:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test7`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test8`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.0:test9`,
        fs:  `cpe:2.3:a:bea:weblogic_server:4.5.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.2`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.3`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.3:pre3`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.4`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.5`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.6`,
        fs:  `cpe:2.3:a:emc:rsa_security_analytics:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.7`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.8`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.9`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.11`,
        fs:  `cpe:2.3:a:adobe:flash_player:17.0.0.169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.11:pre3`,
        fs:  `cpe:2.3:a:inria:ocaml:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.12`,
        fs:  `cpe:2.3:a:google:chrome:6.0.466.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.13`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.14`,
        fs:  `cpe:2.3:a:oracle:interaction_center_intelligence:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.15`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.16`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.17`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.21.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre1`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(13\)ia:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre2`,
        fs:  `cpe:2.3:a:realvnc:realvnc:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre3`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre4`,
        fs:  `cpe:2.3:a:zed_shaw:mongrel:0.3.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre5`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre6`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre7`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre8`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.18:pre9`,
        fs:  `cpe:2.3:a:gajim:gajim:0.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.19`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.19:pre1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.0.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.19:pre2`,
        fs:  `cpe:2.3:a:ibm:rational_automation_framework:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.19:pre3`,
        fs:  `cpe:2.3:a:teradici:pcoip_host_software:3.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.19:pre4`,
        fs:  `cpe:2.3:a:apple:cfnetwork:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.19:pre5`,
        fs:  `cpe:2.3:a:emc:documentum_webtop:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.19:pre6`,
        fs:  `cpe:2.3:a:hp:network_automation:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.20`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:pl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.21`,
        fs:  `cpe:2.3:a:activestate:activeperl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.21:pre1`,
        fs:  `cpe:2.3:h:lenel:lnl-2220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.21:pre4`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.21:pre7`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.16.4763:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.22`,
        fs:  `cpe:2.3:h:cabletron:2h252-25r:5.05.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.22:pre10`,
        fs:  `cpe:2.3:a:informatica:powercenter:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.23`,
        fs:  `cpe:2.3:a:oracle:diagnostics:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.23:pre9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(27\)sbc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.24`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.25`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.26`,
        fs:  `cpe:2.3:a:retale:retale_-_weekly_ads_\&amp;_deals:2.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.27`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.27:pre1`,
        fs:  `cpe:2.3:a:adobe:reader_extended_language_support_font_pack:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.27:pre2`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.27:pre3`,
        fs:  `cpe:2.3:a:nortel:meridian_option_core_card:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.27:pre4`,
        fs:  `cpe:2.3:o:suse:suse_linux:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.27:pre5`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.28`,
        fs:  `cpe:2.3:h:omron:ns8_hmi_terminal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.29`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.29:rc1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.29:rc2`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.0\(2\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.30`,
        fs:  `cpe:2.3:a:emc:powerpath_virtual_appliance:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.30:rc2`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.30:rc3`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.31`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_pdf_sdk_activex:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.31:pre1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.32`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.32:pre1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.32:pre2`,
        fs:  `cpe:2.3:a:crunchify:all-in-on-webmaster:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.33`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.33:pre1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.33.2`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.33.3`,
        fs:  `cpe:2.3:a:redmine:redmine:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.33.4`,
        fs:  `cpe:2.3:a:emulex:ocmanager:5.0.66.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.33.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.34`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.34:rc3`,
        fs:  `cpe:2.3:a:mcafee:file_lock:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.34.1`,
        fs:  `cpe:2.3:a:getsentry:raven-ruby:0.12.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.34.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.35`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.4.35.2`,
        fs:  `cpe:2.3:a:intsig:camscanner:1.2.2.20110823:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.0`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.1`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.2`,
        fs:  `cpe:2.3:a:google:chrome:7.0.511.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.3`,
        fs:  `cpe:2.3:a:opscode:chef:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.4`,
        fs:  `cpe:2.3:a:openstack:keystone:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.5`,
        fs:  `cpe:2.3:a:microsoft:works:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.6`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:0.9.1:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.8`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.9`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.10`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.05.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.11`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.12`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.pi_ia_host_agent_files:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.13`,
        fs:  `cpe:2.3:a:freemind:freemind:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.14`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.15`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.16`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:6.0.5\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.17`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.18`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.19`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.20`,
        fs:  `cpe:2.3:a:debian:libmail-audit-perl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.21`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.48.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.22`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.23`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.24`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(27\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.25`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.26`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.27`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.28`,
        fs:  `cpe:2.3:o:juniper:junos:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.29`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_plant_applications:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.30`,
        fs:  `cpe:2.3:a:google:chrome:4.0.237.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.31`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.32`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.56b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.33`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.34`,
        fs:  `cpe:2.3:a:spip:spip:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.35`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.36`,
        fs:  `cpe:2.3:a:hp:openview_storage_data_protector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.37`,
        fs:  `cpe:2.3:a:adobe:dreamweaver_cs3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.38`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.39`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.40`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.41`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.42`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.43`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.44`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.45`,
        fs:  `cpe:2.3:a:ibm:powerkvm:2.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.46`,
        fs:  `cpe:2.3:a:hp:application_information_optimizer:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.47`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.48`,
        fs:  `cpe:2.3:a:juniper:setup_client_activex_control:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.49`,
        fs:  `cpe:2.3:a:python:python:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.50`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.51`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.52`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.1sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.53`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.54`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.55`,
        fs:  `cpe:2.3:h:juniper:mag6610_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.56`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.57`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.58`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.7.0.1530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.59`,
        fs:  `cpe:2.3:a:lenovo:xp_themes:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.60`,
        fs:  `cpe:2.3:a:php:php:5.5.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.61`,
        fs:  `cpe:2.3:a:moip_project:moip:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.62`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.63`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.64`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.65`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.66`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.67`,
        fs:  `cpe:2.3:a:apache:couchdb:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.68`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.69`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.5.75`,
        fs:  `cpe:2.3:a:quagga:quagga:0.98.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test1`,
        fs:  `cpe:2.3:h:polycom:viavideo:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test10`,
        fs:  `cpe:2.3:a:lightscribe:lightscribe_system_software:1.14.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test11`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test2`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:11.0.6000.6324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test3`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test5`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test6`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test7`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test8`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.4.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.0:test9`,
        fs:  `cpe:2.3:a:winzip:winzip:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.1`,
        fs:  `cpe:2.3:a:ibm:informix_extended_parallel_server:8.40_uc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.1:rc1`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.1:rc2`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.000:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.1:rc3`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.361:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.2`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.2:rc1`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_performance_manager:5.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.2:rc2`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.6\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.2:rc3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.3`,
        fs:  `cpe:2.3:a:nticorp:cd-maker:6.7.0.28:*:*:*:gold:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.3:rc1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.3:rc2`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.3:rc3`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.3:rc4`,
        fs:  `cpe:2.3:a:isc:bind:9.8.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.4`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.4:rc1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.4:rc2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.4:rc3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.5`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.33.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.5:rc1`,
        fs:  `cpe:2.3:a:x.org:libxrender:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.5:rc2`,
        fs:  `cpe:2.3:a:microsoft:windows_media_services:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.5:rc3`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.6`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.6:rc1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.6:rc2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.532.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.6:rc3`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.7`,
        fs:  `cpe:2.3:h:cisco:gigabit_switch_router_12012:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.7:rc1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.7:rc2`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.1.4340:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.7:rc3`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.8`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.8:rc1`,
        fs:  `cpe:2.3:a:ati:catalyst_registration:2.01.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.8:rc2`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.8:rc3`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.8:rc4`,
        fs:  `cpe:2.3:o:debian:debian_linux:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.8.1`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.9`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.9:final`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:17.2.0.59184:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.9:rc1`,
        fs:  `cpe:2.3:a:checkpoint:connectra_ngx:r62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.9:rc2`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.9:rc3`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.9:rc4`,
        fs:  `cpe:2.3:o:extremenetworks:extremeware_xos:11.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.10`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.10:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.10:rc2`,
        fs:  `cpe:2.3:a:adobe:acrobat_business_tools:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.10:rc3`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1677.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11:rc1`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11:rc2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11:rc3`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11:rc4`,
        fs:  `cpe:2.3:a:netiq:namespace_server:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11:rc5`,
        fs:  `cpe:2.3:a:levelfourdevelopment:wp-easycart:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.1`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.8:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.3`,
        fs:  `cpe:2.3:a:infinitiusa:infiniti_roadside_assistance:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.4`,
        fs:  `cpe:2.3:a:drupal:drupal:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.5`,
        fs:  `cpe:2.3:a:appbasedtechnologies:belaire_family_orthodontics:1.304:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.6`,
        fs:  `cpe:2.3:a:microsoft:office_word_viewer:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.7`,
        fs:  `cpe:2.3:h:hp:8500_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.8`,
        fs:  `cpe:2.3:a:oracle:hyperion_financial_management:11.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p215:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.10`,
        fs:  `cpe:2.3:a:cisco:broadband_access_center_telco_wireless_software:3.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.11`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.11.12`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12:rc1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12:rc2`,
        fs:  `cpe:2.3:a:microsoft:visio:2002:sp2:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12:rc3`,
        fs:  `cpe:2.3:a:openx:openx:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12:rc4`,
        fs:  `cpe:2.3:a:mcafee:network_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12:rc5`,
        fs:  `cpe:2.3:a:c-3.co.jp:webcalenderc3:0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12:rc6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.1.36:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12.2`,
        fs:  `cpe:2.3:a:compaq:foundation_agents:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12.3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12.4`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12.5`,
        fs:  `cpe:2.3:a:jease:jease:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.12.6`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.7\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(14\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13:rc1`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13:rc2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13:rc3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13:rc4`,
        fs:  `cpe:2.3:h:yealink:sip-t38g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13:rc5`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13:rc6`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13:rc7`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13.1`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13.2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13.3`,
        fs:  `cpe:2.3:a:naxtech:cms_afroditi:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13.4`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.13.5`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14`,
        fs:  `cpe:2.3:a:dotnetblogengine:blogengine.net:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14:rc1`,
        fs:  `cpe:2.3:o:asus:wrt_firmware:3.0.0.4.376.2524-g0012f52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14:rc2`,
        fs:  `cpe:2.3:a:rpm:rpm:4.9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14:rc3`,
        fs:  `cpe:2.3:a:symantec:vrtsaa:5.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14:rc4`,
        fs:  `cpe:2.3:a:microsoft:excel:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14:rc5`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14.1`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:12.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14.2`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14.3`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14.4`,
        fs:  `cpe:2.3:a:macromedia:jrun:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14.5`,
        fs:  `cpe:2.3:a:oracle:10g_reports_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14.6`,
        fs:  `cpe:2.3:a:ca:ehealth_systemedge:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.14.7`,
        fs:  `cpe:2.3:a:novell:mobility_pack:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15`,
        fs:  `cpe:2.3:a:barcodewiz:barcode_activex_control:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15:rc1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15:rc2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.10.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15:rc3`,
        fs:  `cpe:2.3:a:justsystems:hanako:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15:rc4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15:rc5`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15:rc6`,
        fs:  `cpe:2.3:o:xen:xen:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15:rc7`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.1`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.5.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.2`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0dc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.4`,
        fs:  `cpe:2.3:a:emc:storagescope_queries:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.5`,
        fs:  `cpe:2.3:a:david_king:vino:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.6`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.7`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.8`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.9`,
        fs:  `cpe:2.3:a:hp:loadrunner:11.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.10`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.15.11`,
        fs:  `cpe:2.3:a:oracle:applications_framework:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16:rc1`,
        fs:  `cpe:2.3:a:mark_burdett:securelogin:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16:rc2`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:epj:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16:rc3`,
        fs:  `cpe:2.3:a:novell:iprint:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16:rc4`,
        fs:  `cpe:2.3:a:dell:poweredge_diagnostics:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16:rc5`,
        fs:  `cpe:2.3:a:debian:mit_openafs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16:rc6`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16:rc7`,
        fs:  `cpe:2.3:a:location_module_project:location:6.x-3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.2.169.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.3`,
        fs:  `cpe:2.3:a:techsmith:snagit:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.4`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.6:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.5`,
        fs:  `cpe:2.3:a:cloudacl:safe_browser_-_the_web_filter:1.2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.6`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.7`,
        fs:  `cpe:2.3:h:intel:active_management_technology:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.8`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.9`,
        fs:  `cpe:2.3:o:fedoraproject:fedora_core:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.10`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.3.03086:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.11`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.12`,
        fs:  `cpe:2.3:a:houcine_el_jasmi_project:houcine_el_jasmi:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.13`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.14`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.15`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.16`,
        fs:  `cpe:2.3:a:thegameboss:street_racing:4.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.17`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.18`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1.1-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.19`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.20`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.21`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.22`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.23`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.609.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.24`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.25`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.26`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.27`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.28`,
        fs:  `cpe:2.3:a:hp:openview_performance_agent:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.29`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.30`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.31`,
        fs:  `cpe:2.3:a:redhat:rhel_cluster:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.32`,
        fs:  `cpe:2.3:a:minitab:minitab:14.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.33`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.11.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.34`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.35`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.36`,
        fs:  `cpe:2.3:h:cisco:hosting_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.37`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.38`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.39`,
        fs:  `cpe:2.3:a:apache:hadoop:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.40`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.41`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.42`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.43`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.44`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.45`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.46`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.17.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.47`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.48`,
        fs:  `cpe:2.3:a:kerio:control:8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.49`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20010812:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.50`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.51`,
        fs:  `cpe:2.3:a:teradata:putjre:1.4.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.52`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.0.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.53`,
        fs:  `cpe:2.3:a:gnu:glibc:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.54`,
        fs:  `cpe:2.3:a:redhat:certificate_system:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.55`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.56`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.57`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.58`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.59`,
        fs:  `cpe:2.3:a:openstack:tripleo_heat_templates:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.60`,
        fs:  `cpe:2.3:a:otrs:faq:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.61`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.16.62`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.0.00057:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17:rc1`,
        fs:  `cpe:2.3:a:ein_lookup_project:ein_lookup:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17:rc2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.17s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17:rc3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17:rc4`,
        fs:  `cpe:2.3:a:ibm:lotus_cc_mail:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17:rc5`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17:rc6`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:11.5\(0.98000.480\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.3`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.4`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.5`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_developer_suite:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.6`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.7`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.8`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.9`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.10`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.11`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.13`,
        fs:  `cpe:2.3:a:novell:imanager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.17.14`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.10:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update3:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18:rc1`,
        fs:  `cpe:2.3:a:paul_lesniewsk:autocomplete:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18:rc2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18:rc3`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18:rc4`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18:rc5`,
        fs:  `cpe:2.3:a:ubi:uplay_pc:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18:rc6`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:s6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18:rc7`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:6.20:-:*:*:*:sunos:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18.1`,
        fs:  `cpe:2.3:a:avg:internet_security:9.0:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18.2`,
        fs:  `cpe:2.3:a:emc:navisphere_agent:29.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18.3`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:011:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18.4`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_server:7.1.835:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18.5`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18.7`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.364:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.18.8`,
        fs:  `cpe:2.3:a:google:v8:3.24.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19:rc1`,
        fs:  `cpe:2.3:a:symantec:windows_liveupdate:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19:rc2`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19:rc3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_cx_context-aware_security_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19:rc4`,
        fs:  `cpe:2.3:a:microsoft:office_communicator:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19:rc5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.09.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19:rc6`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19.0`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:640:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19.2`,
        fs:  `cpe:2.3:o:ibm:i:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19.3`,
        fs:  `cpe:2.3:h:tp-link:tl-wr840n:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19.4`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19.5`,
        fs:  `cpe:2.3:h:juniper:fips_infranet_controller_6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19.6`,
        fs:  `cpe:2.3:a:sun:jre:6.0.260:update26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.19.7`,
        fs:  `cpe:2.3:a:opensis:opensis:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20:rc1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20:rc2`,
        fs:  `cpe:2.3:o:huawei:5300hi_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20:rc3`,
        fs:  `cpe:2.3:a:samba:samba:3.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20:rc4`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:a6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20:rc5`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20:rc6`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20:rc7`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.54:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.2.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.2`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.3`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.4`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.5`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.6`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.7`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.8`,
        fs:  `cpe:2.3:a:microsoft:directx:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.9`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.10`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.11`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.12`,
        fs:  `cpe:2.3:a:ibm:tivoli_common_reporting:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(1\)xa3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.14`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.15`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.16`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.17`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.18`,
        fs:  `cpe:2.3:a:microsoft:live_messenger:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.19`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.20`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.20.21`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:git1`,
        fs:  `cpe:2.3:a:islamicode:radio_bethlehem_rb2000:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:git2`,
        fs:  `cpe:2.3:a:embarcadero:er\/studio_data_architect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:git3`,
        fs:  `cpe:2.3:a:apache:axis:1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:git4`,
        fs:  `cpe:2.3:a:freedomscientific:ffdshow-fsi:10.16.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:git5`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:git6`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_admanager_plus:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:git7`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:rc1`,
        fs:  `cpe:2.3:a:pocketmags:football_espana_magazine:\@7f0801aa:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:rc2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:rc3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:rc4`,
        fs:  `cpe:2.3:h:hp:color_laserjet_enterprise_cp4525:cc493a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:rc5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.382.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:rc6`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21:rc7`,
        fs:  `cpe:2.3:a:oracle:agile_product_lifecycle_management_framework:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21.1`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21.3`,
        fs:  `cpe:2.3:a:sun:chilisoft:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21.4`,
        fs:  `cpe:2.3:h:hp:cf117a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21.5`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2006-03-09e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21.6`,
        fs:  `cpe:2.3:a:php:php:5.5.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.21.7`,
        fs:  `cpe:2.3:a:lepide:active_directory_self_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22:rc1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22:rc2`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22:rc3`,
        fs:  `cpe:2.3:a:phplist:phplist:2.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22:rc4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22:rc5`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22:rc6`,
        fs:  `cpe:2.3:a:oracle:payroll:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22:rc7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p4_beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.1`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.12.1202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(3.6\)w5\(9.0.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.3`,
        fs:  `cpe:2.3:a:intel:network_connections:16.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.4`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.0\(2049\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.5`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.6`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:2546:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.7`,
        fs:  `cpe:2.3:a:ibm:flashcopy_manager:3.1.1:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.8`,
        fs:  `cpe:2.3:a:hp:instant_toptools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.9`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.10`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.11`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.12`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.13`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.14`,
        fs:  `cpe:2.3:h:ibm:storwize_v7000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.15`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.16`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.17`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.18`,
        fs:  `cpe:2.3:a:tinc-vpn:tinc:1.1:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.19`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.8:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.20`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.21`,
        fs:  `cpe:2.3:a:microsoft:access:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.22.22`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc1`,
        fs:  `cpe:2.3:a:tenable:nessus:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc2`,
        fs:  `cpe:2.3:a:luracast:restler:1.5.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc3`,
        fs:  `cpe:2.3:h:axis:207w_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc4`,
        fs:  `cpe:2.3:o:yamaha:rt56v:4.07.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc5`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je008a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc6`,
        fs:  `cpe:2.3:a:redhat:redhat_package_manager:4.0.2-72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc7`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc8`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23:rc9`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.9.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.2`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:6:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.4`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.5`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.6`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.7`,
        fs:  `cpe:2.3:a:elegant_themes:divi:-:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.8`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.8.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.9`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.10`,
        fs:  `cpe:2.3:a:qemu:qemu:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.11`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.12`,
        fs:  `cpe:2.3:h:xerox:workcentre_7225:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.13`,
        fs:  `cpe:2.3:a:python:python:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.14`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.15`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.16`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.23.17`,
        fs:  `cpe:2.3:a:google:chrome:3.0.182.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.79a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24:rc1`,
        fs:  `cpe:2.3:a:freetype:freetype:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24:rc2`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:7.6.130.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24:rc3`,
        fs:  `cpe:2.3:a:sun:staroffice:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24:rc4`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24:rc5`,
        fs:  `cpe:2.3:a:softconcept-inc:sysflowagent:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24:rc6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p251:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24:rc7`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24:rc8`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.1.4450:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24.1`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization_manager:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24.2`,
        fs:  `cpe:2.3:a:ibm:flex_system_manager:1.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24.3`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:5.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24.4`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24.6`,
        fs:  `cpe:2.3:a:iss:realsecure_server_sensor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.24.7`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0.2.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tc5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc3`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc4`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc5`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc6`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.58:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc7`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.8:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc8`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25:rc9`,
        fs:  `cpe:2.3:a:microsoft:visual_c\#:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.2`,
        fs:  `cpe:2.3:a:qemu:qemu:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.3`,
        fs:  `cpe:2.3:a:infinite_automation_systems:mango_automation:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.4`,
        fs:  `cpe:2.3:a:emc:documentum_web_publisher:6.5:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.6`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.7`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.8`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.10`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.11`,
        fs:  `cpe:2.3:a:google:chrome:9.0.567.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.12`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.13`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.14`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.15`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1008.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.16`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10.1xbs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.17`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux_corporate_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.18`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.19`,
        fs:  `cpe:2.3:a:exiv2:exiv2:0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.25.20`,
        fs:  `cpe:2.3:a:sun:patch_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0067:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc1`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc3`,
        fs:  `cpe:2.3:a:buffalotech:whr-g_firmware:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc4`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc5`,
        fs:  `cpe:2.3:o:vmware:esx:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc6`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc7`,
        fs:  `cpe:2.3:a:php:pear:1.2b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc8`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26:rc9`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26.1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26.2`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x47:d10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26.3`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x55:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26.4`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26.5`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26.7`,
        fs:  `cpe:2.3:a:emc:networker:8.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.26.8`,
        fs:  `cpe:2.3:a:mysql:mysql:3.22.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc1`,
        fs:  `cpe:2.3:a:commvault:commnet_browser:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc2`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc3`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc4`,
        fs:  `cpe:2.3:h:ibm:infoprint:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc6`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc7`,
        fs:  `cpe:2.3:a:hp:bpd_dswizards:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc8`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27:rc9`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.1`,
        fs:  `cpe:2.3:a:ibm:java:5.0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.3`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.407.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.5`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.6`,
        fs:  `cpe:2.3:h:huawei:s3700:v100r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.9`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.10`,
        fs:  `cpe:2.3:a:apple:safari:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.11`,
        fs:  `cpe:2.3:a:ca:advantage_data_transport:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.12`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2404lf-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.13`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.14`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.15`,
        fs:  `cpe:2.3:a:mcafee:cloud_single_sign_on:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.16`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.17`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.18`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.19`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.16.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.20`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.21`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.0:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.22`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.23`,
        fs:  `cpe:2.3:a:chromium:chromium:40.0.2214.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.24`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:4.0.2:006:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.25`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.26`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.27`,
        fs:  `cpe:2.3:a:vips:vips:7.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.28`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.29`,
        fs:  `cpe:2.3:a:invensys:daserver_runtime_components:3.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.30`,
        fs:  `cpe:2.3:a:samba:samba:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.31`,
        fs:  `cpe:2.3:a:rsa:securid_software_token_converter:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.32`,
        fs:  `cpe:2.3:a:lightscribe:lightscribe:1.4.124.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.33`,
        fs:  `cpe:2.3:a:suckless:slock:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.34`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.35`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.36`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.7.1p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.37`,
        fs:  `cpe:2.3:h:cisco:ie-4000-16t4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.38`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.39`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.40`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.41`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.42`,
        fs:  `cpe:2.3:a:altiris:notification_server_email_event_receiver:6.1.1091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.43`,
        fs:  `cpe:2.3:a:google:chrome:5.0.366.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.44`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.45`,
        fs:  `cpe:2.3:a:php:php:5.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.46`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.9:bundle13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.47`,
        fs:  `cpe:2.3:a:ibm:cognos_business_intelligence:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.48`,
        fs:  `cpe:2.3:a:nero:essentials:7.2.5017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.49`,
        fs:  `cpe:2.3:a:redhat:rhel_cluster_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.50`,
        fs:  `cpe:2.3:a:sap:businessobjects_xi:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.51`,
        fs:  `cpe:2.3:a:zdstatistics_project:zdstatistics:2.0.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.52`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:5.0.0:racecar1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.53`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.54`,
        fs:  `cpe:2.3:a:redhat:openshift:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.55`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.56`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.57`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.58`,
        fs:  `cpe:2.3:o:d-link:dcs-7010l_firmware:1.08.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.59`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.60`,
        fs:  `cpe:2.3:h:ibm:mcs-7835i-3.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.61`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.27.62`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.b05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc1`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc2`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc3`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc4`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc5`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc6`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc7`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc8`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28:rc9`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.3:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.2`,
        fs:  `cpe:2.3:o:huawei:6700ei_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.3`,
        fs:  `cpe:2.3:o:microsoft:windows:2000:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.4`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.6`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.8`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_agent:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.9`,
        fs:  `cpe:2.3:a:datawatch:monarch_pro:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.28.10`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29:rc1`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29:rc2`,
        fs:  `cpe:2.3:a:buffalotech:wer-am54g54_firmware:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29:rc3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29:rc4`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29:rc5`,
        fs:  `cpe:2.3:o:cisco:vpn_3080_concentrator:4.1.7.l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29:rc6`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29:rc7`,
        fs:  `cpe:2.3:a:gnu:glibc:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29:rc8`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29.1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.30.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29.3`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29.4`,
        fs:  `cpe:2.3:a:apache:qpid:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29.5`,
        fs:  `cpe:2.3:a:ibm:filenet_image_services_toolkit:4.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.29.6`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux__optional_productivity_applications:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30:rc1`,
        fs:  `cpe:2.3:a:microsoft:directx:8.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30:rc2`,
        fs:  `cpe:2.3:o:breakingpointsystems:breakingpoint_storm_appliance_ctm:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30:rc3`,
        fs:  `cpe:2.3:a:apple:pages:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30:rc4`,
        fs:  `cpe:2.3:a:apache:qpid:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30:rc5`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30:rc6`,
        fs:  `cpe:2.3:a:network-weathermap:.network_weathermap:0.97:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30:rc7`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30:rc8`,
        fs:  `cpe:2.3:h:linksys:spa921:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.01:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.2`,
        fs:  `cpe:2.3:a:lifetimefitness:life_time_fitness:1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.6`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00-05:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.8`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.9`,
        fs:  `cpe:2.3:a:apache:groovy:2.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.30.10`,
        fs:  `cpe:2.3:h:cisco:880_3g_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.633.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc2`,
        fs:  `cpe:2.3:o:cisco:scientific_atlanta__dpr\/epr2320_firmware:2.0.2:r1262-090417:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc4`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc5`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc6`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc7`,
        fs:  `cpe:2.3:a:apple:safari:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc8`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31:rc9`,
        fs:  `cpe:2.3:a:gnome:evolution:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:1.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.2`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.3`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.05.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.4`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.5`,
        fs:  `cpe:2.3:a:cybozu:office:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.6`,
        fs:  `cpe:2.3:a:apache:openjpa:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.7`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.8`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.9`,
        fs:  `cpe:2.3:a:nortel:multimedia_communication_server_5200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.10`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.11`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.292:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.12`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.423:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.13`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1025:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.31.14`,
        fs:  `cpe:2.3:a:lightbox_photo_gallery_project:lightbox_photo_gallery:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32:rc1`,
        fs:  `cpe:2.3:a:novaboard:novaboard:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32:rc3`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32:rc4`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32:rc5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32:rc6`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32:rc7`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32:rc8`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:35.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.3`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.5`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.7`,
        fs:  `cpe:2.3:a:symantec:client_security:3.1.396:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.8`,
        fs:  `cpe:2.3:a:php:php:5.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.9`,
        fs:  `cpe:2.3:a:symantec:encryption_management_server:3.3.0:mp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.10`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.11`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je092a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.12`,
        fs:  `cpe:2.3:a:kde:koffice:2.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.13`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.14`,
        fs:  `cpe:2.3:a:emersonnetworkpower:aperture_web_application_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.15`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.16`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.0:beta-5:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.17`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.18`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.19`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.20`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.21`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.22`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.23`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.24`,
        fs:  `cpe:2.3:a:opentext:archive_administration_utilities:9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.25`,
        fs:  `cpe:2.3:a:openttd:openttd:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.26`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.27`,
        fs:  `cpe:2.3:a:grape_project:grape:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.28`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ebt:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.29`,
        fs:  `cpe:2.3:a:google:v8:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.30`,
        fs:  `cpe:2.3:a:freesshd:freesshd:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.31`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.32`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.33`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_2m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.34`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.35`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.36`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.890:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.37`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.38`,
        fs:  `cpe:2.3:a:otrs:otrs:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.39`,
        fs:  `cpe:2.3:h:hp:procurve_router:jc149b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.40`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.41`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.42`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.43`,
        fs:  `cpe:2.3:a:jojocms:jojo-cms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.44`,
        fs:  `cpe:2.3:a:samba:samba:3.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.45`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.46`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.47`,
        fs:  `cpe:2.3:a:web2py:web2py:1.96.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.48`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.49`,
        fs:  `cpe:2.3:a:citrix:application_gateway:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.50`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.51`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.52`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.53`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0-142:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.54`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.55`,
        fs:  `cpe:2.3:a:f-secure:anti-virus:9.00:*:*:*:*:windows_server:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.56`,
        fs:  `cpe:2.3:a:irdeto:cyphercast_server_system:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.57`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.32.58`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.0_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33:rc1`,
        fs:  `cpe:2.3:a:perl:perl:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33:rc2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33:rc3`,
        fs:  `cpe:2.3:a:mozilla:firefox:29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33:rc4`,
        fs:  `cpe:2.3:a:adobe:pagemaker:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33:rc5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)fx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33:rc6`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-00-\/i:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33:rc7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33:rc8`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p271:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.3`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.4`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.5`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.6`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.7_pre4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.7`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.8`,
        fs:  `cpe:2.3:a:kdirstat_project:kdirstat:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.9`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.10`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.11`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.12`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.07:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.13`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.14`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.15`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.16`,
        fs:  `cpe:2.3:o:cisco:edge_bluebird_operating_system:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.17`,
        fs:  `cpe:2.3:a:hp:thinpro_linux:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.18`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.50524.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.19`,
        fs:  `cpe:2.3:a:samba:samba:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.33.20`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34`,
        fs:  `cpe:2.3:a:hasb_e_haal_project:hasb_e_haal:1.0.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34:rc1`,
        fs:  `cpe:2.3:a:google:v8:3.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34:rc2`,
        fs:  `cpe:2.3:a:plogger:plogger:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34:rc3`,
        fs:  `cpe:2.3:a:plone:plone:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34:rc4`,
        fs:  `cpe:2.3:a:oracle:developer_suite:9.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34:rc5`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(7\)db1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34:rc6`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.99.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34:rc7`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.2.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.1`,
        fs:  `cpe:2.3:h:cisco:cache_engine_550:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.2`,
        fs:  `cpe:2.3:a:pawel_jakub_dawidek:geli:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.4`,
        fs:  `cpe:2.3:a:apache:qpid:0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.5`,
        fs:  `cpe:2.3:h:3com:3c17210-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.6`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.7`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.8`,
        fs:  `cpe:2.3:a:node_access_product_project:node_access_product:7.x-1.0:rc4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.9`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.34.10`,
        fs:  `cpe:2.3:h:hp:storevirtual_4630:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35`,
        fs:  `cpe:2.3:a:qemu:qemu:1.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35:rc1`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35:rc2`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35:rc3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35:rc4`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35:rc5`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35:rc6`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.1`,
        fs:  `cpe:2.3:a:paperthin:commonspot_content_server:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.3`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.4`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.5`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.6`,
        fs:  `cpe:2.3:a:esri:arcgis:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.7`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sg.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.8`,
        fs:  `cpe:2.3:a:emc:rsa_authentication_agent:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.9`,
        fs:  `cpe:2.3:a:citrix:password_manager_plugin:4.6.271.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.11`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.12`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.9:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.35.13`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36:rc1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36:rc2`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.0.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36:rc3`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36:rc4`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36:rc5`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.5:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36:rc6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36:rc7`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.43.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36:rc8`,
        fs:  `cpe:2.3:a:subnet:substation_server:2.7.0033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.54b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sni:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36.3`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:-:beta_2006.09.07:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.36.4`,
        fs:  `cpe:2.3:h:xerox:workcentre_238:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37`,
        fs:  `cpe:2.3:a:vmware:fusion:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37:rc1`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37:rc2`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37:rc3`,
        fs:  `cpe:2.3:a:symantec:scan_engine:5.2.8.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37:rc4`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37:rc5`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:343.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37:rc6`,
        fs:  `cpe:2.3:a:skype:skype:1.3.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37:rc7`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37:rc8`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.1:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37.2`,
        fs:  `cpe:2.3:a:hitachi:cosminexus\/opentp1_web_web_front-endset:02-50-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37.3`,
        fs:  `cpe:2.3:a:ibm:network_appliance_data_ontap:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37.4`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37.5`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.37.6`,
        fs:  `cpe:2.3:h:d-link:dsl2750u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.5.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38:rc1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38:rc2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38:rc3`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38:rc4`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38:rc5`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38:rc6`,
        fs:  `cpe:2.3:a:mobile4social:exposed_filter_data:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38:rc7`,
        fs:  `cpe:2.3:a:isc:bind:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38:rc8`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38.1`,
        fs:  `cpe:2.3:a:wp-contact_plugin_project:wp-contact-sidebar-widget:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38.2`,
        fs:  `cpe:2.3:h:lexmark:x772e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38.3`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38.4`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.5.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38.5`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38.6`,
        fs:  `cpe:2.3:a:symantec:liveupdate:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38.7`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.38.8`,
        fs:  `cpe:2.3:h:supermicro:x8sia-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39`,
        fs:  `cpe:2.3:a:avast:pro_antivirus:11.1.2241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39:rc1`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39:rc2`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39:rc3`,
        fs:  `cpe:2.3:a:ibm:sterling_secure_proxy:3.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39:rc4`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39:rc5`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39:rc6`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39:rc7`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2116he:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39.2`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39.3`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:2.6.39.4`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0:rc1`,
        fs:  `cpe:2.3:a:wellintech:kingscada:3.1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0:rc3`,
        fs:  `cpe:2.3:o:axis:m10_series_network_cameras_firmware:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0:rc4`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0:rc5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)db1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0:rc6`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0:rc7`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.1`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:9.0.2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p429:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.3`,
        fs:  `cpe:2.3:a:menalto:gallery:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.4`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.5`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.2.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.6`,
        fs:  `cpe:2.3:a:socialknowledge:aquarium_advice:3.7.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.7`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.8`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.9`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.10`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.11`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.12`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.13`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.14`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.15`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.16`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.17`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.18`,
        fs:  `cpe:2.3:a:frontrange:heat:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.19`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.20`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.307:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.21`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.22`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.23`,
        fs:  `cpe:2.3:a:mozilla:firefox:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.24`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.25`,
        fs:  `cpe:2.3:a:webyog:sqlyog:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.26`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)xw1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.27`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.28`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.29`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.30`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2010:14.0.913.64:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.31`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.32`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:6620:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.33`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.34`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.35`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2sg.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.36`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.37`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.38`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.39`,
        fs:  `cpe:2.3:a:redmine:redmine:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.40`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.41`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.42`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.43`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.04:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.44`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p100:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.45`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.46`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.47`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.48`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.49`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.50`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.51`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.52`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(4\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.53`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.370:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.54`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.55`,
        fs:  `cpe:2.3:a:gnome:evolution:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.56`,
        fs:  `cpe:2.3:o:redhat:linux:6.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.57`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.58`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.59`,
        fs:  `cpe:2.3:a:lxml:lxml:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.60`,
        fs:  `cpe:2.3:a:david_king:vino:2.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.61`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.62`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.63`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.64`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.65`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.66`,
        fs:  `cpe:2.3:a:ibm:dashdb_local:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.67`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.68`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.69`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.70`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.71`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2007:0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.72`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.73`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.74`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.75`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.76`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:175:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.77`,
        fs:  `cpe:2.3:o:openvas:greenbone_security_assistant:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.78`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.79`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.80`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.81`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.82`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.83`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.84`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.85`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.86`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.87`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:176:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.88`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.89`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.90`,
        fs:  `cpe:2.3:h:cisco:unity_server:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.91`,
        fs:  `cpe:2.3:a:google:chrome:5.0.357.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.92`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.93`,
        fs:  `cpe:2.3:a:google:chrome:12.0.702.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.94`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.95`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i2\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.96`,
        fs:  `cpe:2.3:a:fusebox:fusebox:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.97`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.98`,
        fs:  `cpe:2.3:a:vmware:player:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.99`,
        fs:  `cpe:2.3:a:ibm:web_content_manager_production_analytics:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.100`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.0.101`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1`,
        fs:  `cpe:2.3:a:veritas:netbackup:5.0.0:mp1:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1:rc1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1:rc2`,
        fs:  `cpe:2.3:h:dell:precision_mobile_m4500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1:rc3`,
        fs:  `cpe:2.3:a:newsoftinc:presto\!_pagemanager:7.15.14e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1:rc4`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.5:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.2`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.4`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.5`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.6`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.7`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.4:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.8`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:4.20.1081:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.9`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.1.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12c\)ew4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2::~~~~x86~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2:rc2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2:rc3`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2:rc4`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2:rc5`,
        fs:  `cpe:2.3:a:macromedia:extension_manager:1.7.240:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2:rc6`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2:rc7`,
        fs:  `cpe:2.3:a:fluke:linkware:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.1`,
        fs:  `cpe:2.3:h:citrix:netscaler_access_gateway:-:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.1::~~~~x86~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.2`,
        fs:  `cpe:2.3:a:corel:painter:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.3`,
        fs:  `cpe:2.3:h:hp:jg784a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.4`,
        fs:  `cpe:2.3:a:tenable:nessus:6.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.7`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.8`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.9`,
        fs:  `cpe:2.3:a:avg:internet_security:8.5:-:3-pack:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.10`,
        fs:  `cpe:2.3:h:xerox:workcentre:5655:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.11`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.12`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.13`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option_server:07-01\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.14`,
        fs:  `cpe:2.3:a:php:php:5.4.16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.15`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.8:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.16`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.17`,
        fs:  `cpe:2.3:a:sympa:sympa:3.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.18`,
        fs:  `cpe:2.3:a:microsoft:visual_interdev:6.0:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.19`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.20`,
        fs:  `cpe:2.3:h:nvidia:titan_x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.21`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.22`,
        fs:  `cpe:2.3:a:fibonacciorange:wedeal:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.23`,
        fs:  `cpe:2.3:a:david_king:vino:2.99.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.24`,
        fs:  `cpe:2.3:a:ibm:eclipse_help_system:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.25`,
        fs:  `cpe:2.3:a:nibbleblog:nibbleblog:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.26`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.27`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_4_firmware:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.28`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.29`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.30`,
        fs:  `cpe:2.3:a:x2engine:x2crm:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.64`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.65`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.66`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.67`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)m6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.68`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.69`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.70`,
        fs:  `cpe:2.3:a:interconweb:accessible_formnet_fill:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.71`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.60a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.72`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.73`,
        fs:  `cpe:2.3:a:intel:2100_proset_wireless:7.1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.74`,
        fs:  `cpe:2.3:a:apache:activemq:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.75`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.76`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.77`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.13:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.78`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.79`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:2.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.2.80`,
        fs:  `cpe:2.3:a:mozilla:firefox:50.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3:rc1`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3:rc2`,
        fs:  `cpe:2.3:a:oracle:http_server:9.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3:rc3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.3\(3.102\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3:rc4`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3:rc5`,
        fs:  `cpe:2.3:a:cisco:webns:8.20.1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3:rc6`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3:rc7`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3.1`,
        fs:  `cpe:2.3:a:contenido:contendio:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3.3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3.4`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3.5`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3.6`,
        fs:  `cpe:2.3:a:httpwatch:httpwatch_basic:6.2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3.7`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.3.8`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4::~~~~x86~`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc1:~~~~x86~`,
        fs:  `cpe:2.3:a:cisco:support_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc2`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc2:~~~~x86~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc3`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc3:~~~~x86~`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc4`,
        fs:  `cpe:2.3:a:microsoft:office_communicator:2007:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc4:~~~~x86~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sea:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc5:~~~~x86~`,
        fs:  `cpe:2.3:a:morbus_iff:activism:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc6`,
        fs:  `cpe:2.3:a:apache:hadoop:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc6:~~~~x86~`,
        fs:  `cpe:2.3:a:netiq:appmanager_control_center:7.0.10160.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc7`,
        fs:  `cpe:2.3:a:intel:mpfmgr:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4:rc7:~~~~x86~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(18\)w5\(22b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.1`,
        fs:  `cpe:2.3:a:oracle:service_contracts:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.1::~~~~x86~`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.2`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.2::~~~~x86~`,
        fs:  `cpe:2.3:a:vmware:workstation:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.3`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.3::~~~~x86~`,
        fs:  `cpe:2.3:a:microsoft:infopath:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.4`,
        fs:  `cpe:2.3:a:symantec:vrtsscmui:5.2.202.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.4::~~~~x86~`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.5`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.5::~~~~x86~`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.6`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.7`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.8`,
        fs:  `cpe:2.3:a:diabetes:diabetes_forum:3.9.30:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.9`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.10`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.11`,
        fs:  `cpe:2.3:a:csc:ddoeserviceclient:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.12`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.13`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.14`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.15`,
        fs:  `cpe:2.3:a:hyonga:hanyang_university_admissions:2.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.16`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.17`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.18`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.19`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.5\(2.13900.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.20`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.21`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.22`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.23`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.24`,
        fs:  `cpe:2.3:o:ibm:sas_connectivity_module_firmware:1.3.3.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.25`,
        fs:  `cpe:2.3:a:elsop:linkscan:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.26`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.27`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.28`,
        fs:  `cpe:2.3:h:d-link:dcs-2210l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.29`,
        fs:  `cpe:2.3:a:symantec:veritas_operations_manager:3.0.357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.30`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.31`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.4:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.32`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.33`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.552:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.34`,
        fs:  `cpe:2.3:h:hp:laserjet_9040mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.35`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.36`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.37`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.38`,
        fs:  `cpe:2.3:a:cisco:acs_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.39`,
        fs:  `cpe:2.3:a:bsd_mailx_project:bsd_mailx:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.40`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.41`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.42`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.24-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.43`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.44`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.45`,
        fs:  `cpe:2.3:a:samba:samba:2.0.5:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.46`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.30.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.47`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.48`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.49`,
        fs:  `cpe:2.3:a:vips:vips:7.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.50`,
        fs:  `cpe:2.3:a:blackberry:blackberry_enterprise_service:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.51`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ea1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.52`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.53`,
        fs:  `cpe:2.3:a:transifex:transifex:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.54`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.55`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.56`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.57`,
        fs:  `cpe:2.3:a:realnetworks:rhapsody:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.58`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.0\(2a\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.59`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.60`,
        fs:  `cpe:2.3:a:hitachi:device_manager:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.61`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.62`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.63`,
        fs:  `cpe:2.3:a:digium:asterisk:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.64`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.65`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.66`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.67`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.68`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.69`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)ew3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.70`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.71`,
        fs:  `cpe:2.3:a:mono:mono:2.10.1:*:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.72`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.73`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.74`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.75`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.76`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.77`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.75:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.78`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.79`,
        fs:  `cpe:2.3:a:mymembersfirst:tn_members_1st_fcu-rdc:1.0.28:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.80`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)ed1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.81`,
        fs:  `cpe:2.3:a:interworx:web_control_panel:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.82`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.83`,
        fs:  `cpe:2.3:o:cisco:unified_sip_phone_3900_firmware:8.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.84`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.85`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.86`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.87`,
        fs:  `cpe:2.3:a:sharethis:sharethis:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.88`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.89`,
        fs:  `cpe:2.3:a:ibm:egatherer:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.90`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.91`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.92`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:qa3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.93`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.94`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.95`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.96`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.97`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.6:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.98`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.99`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.100`,
        fs:  `cpe:2.3:a:adobe:photoshop:15.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.101`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update7:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.102`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.103`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.4.07s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.104`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.262.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.105`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.106`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:3.6ecg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.107`,
        fs:  `cpe:2.3:a:tinytap:not_lost_just_somewhere_else:1.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.108`,
        fs:  `cpe:2.3:h:hp:h3c_router:sr8802:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.109`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.1.1:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.110`,
        fs:  `cpe:2.3:a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.111`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.4.112`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.5.1`,
        fs:  `cpe:2.3:a:erlang:crypto:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.5.2`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.5.3`,
        fs:  `cpe:2.3:a:traauctions:tra_auctions_for_buyers:2.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.5.4`,
        fs:  `cpe:2.3:a:wtrootrootvizle_project:wtrootrootvizle:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.5.5`,
        fs:  `cpe:2.3:a:redhat:resteasy:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.5.6`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0-105:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.5.7`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.376:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6:rc5`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.1`,
        fs:  `cpe:2.3:o:redhat:linux:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.2`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.3`,
        fs:  `cpe:2.3:a:atmail:atmail:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.4`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.5`,
        fs:  `cpe:2.3:a:thegr:dl:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.6`,
        fs:  `cpe:2.3:a:isc:bind:9.5.3b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.7`,
        fs:  `cpe:2.3:a:gnu:glibc:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.9`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.10`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.6.11`,
        fs:  `cpe:2.3:o:zhone_technologies:gpon_2520_firmware:r4.0.2.566b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7`,
        fs:  `cpe:2.3:a:samsung:smartviewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.1`,
        fs:  `cpe:2.3:a:ibm:db2:11.1:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.2`,
        fs:  `cpe:2.3:a:vips:vips:7.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.4`,
        fs:  `cpe:2.3:a:rsa:bsafe_cert-c:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.5`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.6`,
        fs:  `cpe:2.3:a:pecio-cms:pecio_cms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.7`,
        fs:  `cpe:2.3:a:apache:geronimo:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.9`,
        fs:  `cpe:2.3:a:x.org:libxv:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.7.10`,
        fs:  `cpe:2.3:a:gnu:emacs:24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.0`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.1`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.2`,
        fs:  `cpe:2.3:h:cisco:nexus_2232tm_fex_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.4`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.5`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.359:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.6`,
        fs:  `cpe:2.3:a:gnome:glib:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.7`,
        fs:  `cpe:2.3:a:jspautsch:firstlastnames:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.8`,
        fs:  `cpe:2.3:a:payoneer_sign_up_project:payoneer_sign_up:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.9`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100102.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.10`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.11`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.12`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.8.13`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9:rc1`,
        fs:  `cpe:2.3:a:gnu:a2ps:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9:rc2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2008.717.2343.40629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9:rc3`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9:rc4`,
        fs:  `cpe:2.3:a:skype:skype:1.2.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9:rc5`,
        fs:  `cpe:2.3:a:e107:e107:2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9:rc6`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9:rc7`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.0`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.0::~~~~arm64~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(1.20\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.1`,
        fs:  `cpe:2.3:h:grandstream:gxv3601hd\/ll:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.1::~~~~arm64~`,
        fs:  `cpe:2.3:a:justsystems:just_school:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.2`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:6.0.302.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.2::~~~~arm64~`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.3`,
        fs:  `cpe:2.3:a:cobblerd:cobbler:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.3::~~~~arm64~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p161:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.4`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.4::~~~~arm64~`,
        fs:  `cpe:2.3:o:juniper:junos_space:15.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.5`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.5::~~~~arm64~`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.6`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.6::~~~~arm64~`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.7`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x50:d35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.7::~~~~arm64~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.8::~~~~arm64~`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.9`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.9::~~~~arm64~`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.10`,
        fs:  `cpe:2.3:a:novell:zenworks_desktops:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.10::~~~~arm64~`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_219_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.11`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.9.11::~~~~arm64~`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10`,
        fs:  `cpe:2.3:a:redhat:sos:2.2-29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.0::~~~~arm64~`,
        fs:  `cpe:2.3:a:tincan:phplist:2.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.1`,
        fs:  `cpe:2.3:a:novell:sentinel_log_manager:1.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.1::~~~~arm64~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.2`,
        fs:  `cpe:2.3:a:ibm:rational_insight:1.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.2::~~~~arm64~`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.3`,
        fs:  `cpe:2.3:a:apple:itunes:11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.3::~~~~arm64~`,
        fs:  `cpe:2.3:a:opera:opera_browser:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.4`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.4::~~~~arm64~`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.5`,
        fs:  `cpe:2.3:o:debian:debian_linux:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.5::~~~~arm64~`,
        fs:  `cpe:2.3:a:emulex:fibre_channel_hbanyware:2.1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.6`,
        fs:  `cpe:2.3:a:pgp:corporate_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.6::~~~~arm64~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1686.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.7`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.7::~~~~arm64~`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.8`,
        fs:  `cpe:2.3:a:debian:mime-support:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.8::~~~~arm64~`,
        fs:  `cpe:2.3:a:xnview:xnview:1.95.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)mb12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.9::~~~~arm64~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.10`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.11`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.12`,
        fs:  `cpe:2.3:a:isc:bind:9.6.3b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.13`,
        fs:  `cpe:2.3:a:teradata:data_connector:12.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.14`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1689.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.15`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.16`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.3.0:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.17`,
        fs:  `cpe:2.3:a:tumbleweed:mailgate_email_firewall:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.18`,
        fs:  `cpe:2.3:a:solarwinds:network_configuration_manager:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.19`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1\(3\)sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.20`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.19:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.21`,
        fs:  `cpe:2.3:a:divx:converter:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.22`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.23`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.24`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.25`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.26`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.27`,
        fs:  `cpe:2.3:a:oracle:payroll:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.28`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.29`,
        fs:  `cpe:2.3:o:cisco:catos:7.6\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.30`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.0:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.31`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.32`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry:242.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.33`,
        fs:  `cpe:2.3:a:thedigitalcraft:atomcms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.34`,
        fs:  `cpe:2.3:a:dotclear:dotclear:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.35`,
        fs:  `cpe:2.3:a:ibm:racf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.36`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.37`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.38`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.39`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.40`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:5.0:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.41`,
        fs:  `cpe:2.3:a:dell:wyse_device_manager:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.42`,
        fs:  `cpe:2.3:h:tropos:1310_distrubution_automation_mesh_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.43`,
        fs:  `cpe:2.3:a:gnu:automake:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.44`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.45`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.46`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_server:04-01-\/a:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.47`,
        fs:  `cpe:2.3:a:janetter:janetter:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.48`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.49`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.50`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.51`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.52`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.53`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.54`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.55`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r343.36:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.56`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.57`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.58`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.11f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.59`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.60`,
        fs:  `cpe:2.3:h:d-link:dir-601:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.61`,
        fs:  `cpe:2.3:a:cisco:pix_private_link:4.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.62`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.63`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.64`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.65`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.66`,
        fs:  `cpe:2.3:a:intel:2915abg_proset_wireless:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.67`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.68`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.69`,
        fs:  `cpe:2.3:a:adobe:acrobat:4.0.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.70`,
        fs:  `cpe:2.3:a:pixman:pixman:0.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.71`,
        fs:  `cpe:2.3:h:polycom:distributed_media_application_7000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.72`,
        fs:  `cpe:2.3:a:redhat:subscription_asset_manager:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.73`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.74`,
        fs:  `cpe:2.3:a:oracle:transportation_management:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.75`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf552a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.76`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.77`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.78`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.79`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.80`,
        fs:  `cpe:2.3:a:imapp:realtime_music_rank:5.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.81`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.82`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.83`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.67a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.84`,
        fs:  `cpe:2.3:a:sawmill:sawmill:5.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.85`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.86`,
        fs:  `cpe:2.3:a:eliteladders:elite_gaming_ladders:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.87`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.5.2.4731:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.88`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.89`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.90`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.91`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.92`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:3.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.93`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.94`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)sy1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.95`,
        fs:  `cpe:2.3:a:apache:maven:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.96`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.97`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.98`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.99`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.100`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.101`,
        fs:  `cpe:2.3:o:hp:hp-ux:b.11.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.10.102`,
        fs:  `cpe:2.3:h:buffalotech:whr-600d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.1`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.2`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(23\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.4`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.5`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.6`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:9.1.1-000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.7`,
        fs:  `cpe:2.3:a:emc:retrospect_client:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.8`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.9`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.11.10`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.4`,
        fs:  `cpe:2.3:h:oracle:sparc_t3-3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.5`,
        fs:  `cpe:2.3:a:ibm:jazz_reporting_service:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.6`,
        fs:  `cpe:2.3:a:cloudera:hadoop:0.20-sbin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.7`,
        fs:  `cpe:2.3:a:dell:kace_k1000_systems_management_appliance_software:5.5.90545:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.8`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.05_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.9`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.10`,
        fs:  `cpe:2.3:a:kde:koffice:2.3:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.11`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.12`,
        fs:  `cpe:2.3:o:oracle:es1-24_firmware:1.3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.13`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.037_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.14`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.5.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.15`,
        fs:  `cpe:2.3:a:oracle:secure_global_desktop:4.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.16`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.17`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1283.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.18`,
        fs:  `cpe:2.3:a:st:accelerometerp11:2.0.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.19`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.20`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2010.0302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.21`,
        fs:  `cpe:2.3:a:ibm:soliddb:4.5.173:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.22`,
        fs:  `cpe:2.3:a:google:earth_plug-in:6.0.3.2197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.23`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.24`,
        fs:  `cpe:2.3:a:elinks:elinks:0.12:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.25`,
        fs:  `cpe:2.3:o:cisco:ios:11.0\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.26`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.27`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:05-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.28`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp4:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.29`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.10.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.30`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.31`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.8.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.32`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.291:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.33`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.34`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.35`,
        fs:  `cpe:2.3:a:creative_minds:cm_download_manager:2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.36`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.37`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.38`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.39`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.40`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.41`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.42`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.43`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.44`,
        fs:  `cpe:2.3:a:microsoft:infopath:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.45`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.46`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.47`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.48`,
        fs:  `cpe:2.3:a:macromedia:flash_communication_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.49`,
        fs:  `cpe:2.3:a:ipswitch:imail:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.50`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.51`,
        fs:  `cpe:2.3:a:double-take_software:double-take:5.1.0.861.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.52`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.53`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.54`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.55`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.56`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.57`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.58`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.12.59`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.605:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc6:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.1:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.2`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.4`,
        fs:  `cpe:2.3:h:sun:crypto_accelerator_4000:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.5`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.6`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.core:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.7`,
        fs:  `cpe:2.3:a:autotrader.co.za:auto_trader:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.8`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_server:04-01:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.9`,
        fs:  `cpe:2.3:a:emc:networker:8.1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.13.11`,
        fs:  `cpe:2.3:a:redmine:redmine:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:-`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:rc1`,
        fs:  `cpe:2.3:a:mysql:eventum:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:rc2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:rc3`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.2.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:rc4`,
        fs:  `cpe:2.3:h:rockwellautomation:rslinx_enterprise:cpr9:sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:rc5`,
        fs:  `cpe:2.3:a:mistelix:mistelix:0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:rc6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:rc7`,
        fs:  `cpe:2.3:a:smarty:smarty:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14:rc8`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.1`,
        fs:  `cpe:2.3:a:measureup:microsoft_press_training_kit_exam_prep_suite_70-646:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(23\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.4`,
        fs:  `cpe:2.3:a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.5`,
        fs:  `cpe:2.3:a:iomega:iomegaware:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.10`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2006-11-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.11`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.12`,
        fs:  `cpe:2.3:a:flexerasoftware:flexnet_publisher:11.13.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.13`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpq2425:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.14`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.15`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.16`,
        fs:  `cpe:2.3:a:microsoft:access:2010:sp1:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.17`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.18`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.20`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.5:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.21`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.22`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.23`,
        fs:  `cpe:2.3:a:hp:hppsendfax:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.24`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.25`,
        fs:  `cpe:2.3:a:osticket:osticket:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.26`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.27`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.28`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.29`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.14:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.30`,
        fs:  `cpe:2.3:a:hp:smart_web_printing:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.31`,
        fs:  `cpe:2.3:a:innominate:mguard_smart:bd-101010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.32`,
        fs:  `cpe:2.3:a:openpkg:openpkg:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.33`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.34`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2.9.925.1706:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.35`,
        fs:  `cpe:2.3:a:benjamin_mack:seo_basics:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.36`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.37`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.38`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.39`,
        fs:  `cpe:2.3:a:ibm:rational_service_tester:8.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.40`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p151:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.41`,
        fs:  `cpe:2.3:o:xen:xen:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.42`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.43`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.44`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.45`,
        fs:  `cpe:2.3:a:nancy_wichmann:announcements:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.46`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.47`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.48`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.49`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.50`,
        fs:  `cpe:2.3:a:posh_project:posh:2.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.51`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.52`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.53`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.54`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.55`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.7.4:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.56`,
        fs:  `cpe:2.3:a:rack_project:rack:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.57`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.58`,
        fs:  `cpe:2.3:a:scilab:scilab:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.59`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.1:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.60`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.61`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.62`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.63`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.64`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.65`,
        fs:  `cpe:2.3:a:mcafee:wireless_home_network_security:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.66`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.67`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.68`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.14.79`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15:rc4`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.1`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.2`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.0:sp0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.3`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.5`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.6`,
        fs:  `cpe:2.3:a:presto-changeo:canadapost:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.7`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.8`,
        fs:  `cpe:2.3:a:autodesk:volo_view_express:2002.20.0.811:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.15.10`,
        fs:  `cpe:2.3:a:isc:inn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.16.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.16.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.16.4`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.16.5`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.16.6`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.16.7`,
        fs:  `cpe:2.3:a:ibm:datapower_gateway:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.17.3::~~~~arm64~`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.17.5`,
        fs:  `cpe:2.3:a:roxio:mydvd:10.3.349:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.17.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.17.7`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.6.1:b7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.17.8`,
        fs:  `cpe:2.3:a:shopware:shopware:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.0`,
        fs:  `cpe:2.3:a:microsoft:windows_script:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.2`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.3`,
        fs:  `cpe:2.3:a:sybase:easerver:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.4`,
        fs:  `cpe:2.3:a:ibm:iss_internet_scanner_software:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.5`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.6`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.37.5085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.7`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.8`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.7.d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.10`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.11`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.12`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.13`,
        fs:  `cpe:2.3:a:krisonav:krisonav:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.14`,
        fs:  `cpe:2.3:a:mesa3d:mesa:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.15`,
        fs:  `cpe:2.3:a:apache:camel:2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.16`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.17`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.19`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.20`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.0:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.21`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.0:*:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.22`,
        fs:  `cpe:2.3:a:grassroots_dicom_project:grassroots_dicom:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.23`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.24`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.25`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.26`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1051:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.27`,
        fs:  `cpe:2.3:a:intel:network_connections:16.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.28`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.29`,
        fs:  `cpe:2.3:a:oracle:sun_storage_common_array_manager:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.30`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.31`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.7.2:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.32`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.33`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.34`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.35`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.36`,
        fs:  `cpe:2.3:a:python:python:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.37`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.38`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.6:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.39`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.40`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0008:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.41`,
        fs:  `cpe:2.3:a:gnu:gnutls:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.42`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.08.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.43`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:108.2146.2565.38893:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.44`,
        fs:  `cpe:2.3:a:adobe:camera_raw:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.45`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.46`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.47`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.01.437:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.48`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.d0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.49`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.50`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.51`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.04.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.52`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.53`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.1:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.54`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.55`,
        fs:  `cpe:2.3:h:canon:canoscan_8440f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.56`,
        fs:  `cpe:2.3:a:compaq:storage_allocation_reporter:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.57`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.58`,
        fs:  `cpe:2.3:h:fortinet:fortigate-40c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.59`,
        fs:  `cpe:2.3:a:mcafee:visual_trace:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.60`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.61`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.62`,
        fs:  `cpe:2.3:h:logitec:lan-w300n\/rs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.63`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.64`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.65`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.18.66`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19.1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:4.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19.2`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19.3`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.26.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19.4`,
        fs:  `cpe:2.3:a:boost:boost:1.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19.5`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19.6`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19.7`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:3.19.8`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.3`,
        fs:  `cpe:2.3:a:skout:skout\:_chats._friends._fun.:4.3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.4`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.5`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_workstation:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.6`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.43.5119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.7`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.8`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.9.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.0.9`,
        fs:  `cpe:2.3:a:microsoft:windows_services_for_unix:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.0`,
        fs:  `cpe:2.3:a:redhat:network_satellite:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.4`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.5`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.7`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:174:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.8`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.9`,
        fs:  `cpe:2.3:a:memorizeit:memorizeit\!:1.7.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.10`,
        fs:  `cpe:2.3:a:debian:apt:0.8.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.11`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.12`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.13`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.14`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.15`,
        fs:  `cpe:2.3:a:vim:vim:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.16`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.17`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2:beta0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.18`,
        fs:  `cpe:2.3:a:google:android_api:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.19`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.20`,
        fs:  `cpe:2.3:a:adobe:pagemaker:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.21`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.22`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.23`,
        fs:  `cpe:2.3:a:xnview:xnview:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.1.33`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.0`,
        fs:  `cpe:2.3:a:php:php:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.1`,
        fs:  `cpe:2.3:a:veritas:netbackup:4.5.0:mp5:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.3`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:unstable0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.4`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.5`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.6`,
        fs:  `cpe:2.3:a:symantec:application_service_dashboard:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.2.8`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.3:rc1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.3:rc7`,
        fs:  `cpe:2.3:h:nortel:alteon_acedirector:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.3.0`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.3.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p109:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.3.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.3.3`,
        fs:  `cpe:2.3:a:snort:snort:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.3.5`,
        fs:  `cpe:2.3:a:debian:kernel-patch-vserver:1.9.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.3.6`,
        fs:  `cpe:2.3:a:samba:samba:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4:rc8`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.1.630:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.0`,
        fs:  `cpe:2.3:a:job_fair_project:job_fair:1.0.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.1`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.3`,
        fs:  `cpe:2.3:a:digium:asterisk:11.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.4`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r6:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.5`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.6`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1663.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.7`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2008.225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.8`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.9`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.985:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.10`,
        fs:  `cpe:2.3:a:hp:proliant_ilo_monitor_service:3.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.11`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00-09:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.12`,
        fs:  `cpe:2.3:a:ecos:embperl:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.13`,
        fs:  `cpe:2.3:a:hp:centralview_credit_risk_control:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.14`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.03.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.15`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:7.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.16`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.17`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.18`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.20`,
        fs:  `cpe:2.3:a:netscape:fasttrack_server:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.21`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7p444:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.22`,
        fs:  `cpe:2.3:a:htc:evo_3d_software:2.17.651.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.23`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:m3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.24`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.25`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.26`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.27`,
        fs:  `cpe:2.3:h:axis:panorama_ptz_camera:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.28`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.29`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.8:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.30`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.31`,
        fs:  `cpe:2.3:a:umn:mapserver:5.2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.32`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.33`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.34`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.8.1\(682\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.35`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.36`,
        fs:  `cpe:2.3:a:adobe:flash_player:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.37`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.38`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.39`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.40`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.41`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)sy03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.42`,
        fs:  `cpe:2.3:o:mozilla:firefox_os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.43`,
        fs:  `cpe:2.3:a:pansi:pansi_sms:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.44`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.45`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2-p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.46`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.47`,
        fs:  `cpe:2.3:a:isc:dhcp_client:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.48`,
        fs:  `cpe:2.3:a:estrongs:es_file_explorer:3.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.49`,
        fs:  `cpe:2.3:a:emc:vplex_geosynchrony:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.50`,
        fs:  `cpe:2.3:a:cisco:personal_assistant:1.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.51`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.52`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.53`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1030:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.54`,
        fs:  `cpe:2.3:a:apache:camel:2.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.55`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.2017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.56`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.57`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.58`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.59`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)ec2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.60`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.61`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.62`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.63`,
        fs:  `cpe:2.3:o:huawei:s5700_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.64`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.65`,
        fs:  `cpe:2.3:a:git-scm:git:0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.66`,
        fs:  `cpe:2.3:o:mandriva:linux:2008.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.67`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.68`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.69`,
        fs:  `cpe:2.3:a:adobe:flash_player:21.0.0.97:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.70`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.71`,
        fs:  `cpe:2.3:a:hitachi:jp1\/it_desktop_management-manager:09-51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.72`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.73`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.74`,
        fs:  `cpe:2.3:a:intel:mmhouse:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.75`,
        fs:  `cpe:2.3:a:f-secure:anti-virus:9.10:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.76`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.77`,
        fs:  `cpe:2.3:o:cisco:ios:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.78`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.79`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.80`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.81`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.82`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.4.83`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.5.0:rc7`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.5.1`,
        fs:  `cpe:2.3:a:altiris:it_analytics_solution_documentation:6.1.1010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.5.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.5.3`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.5.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.5.5`,
        fs:  `cpe:2.3:a:gcspublishing:slingshot_forum:3.9.14:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.5.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.3.300.268:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.6.1`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.6.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sw4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.6.3`,
        fs:  `cpe:2.3:a:suse:studio_extension_for_system_z:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.6.4`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.6.5`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.6.6`,
        fs:  `cpe:2.3:a:huawei:s5300_firmware:v200r003c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.6.7`,
        fs:  `cpe:2.3:a:google:chrome:6.0.421.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.7`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.7:rc6`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.7.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.7.4`,
        fs:  `cpe:2.3:a:f5:big-ip:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.7.6`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.7.9`,
        fs:  `cpe:2.3:a:kde:koffice:1.3:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2pi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.2`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.3`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.4`,
        fs:  `cpe:2.3:o:microsoft:windows_10:1607:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.6`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.7`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.8`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.9`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.10`,
        fs:  `cpe:2.3:a:epiqo:email:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.11`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.12`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.13`,
        fs:  `cpe:2.3:a:microsoft:jet:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.14`,
        fs:  `cpe:2.3:a:playcomo:little_dragons:1.0.256:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.15`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.010:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.16`,
        fs:  `cpe:2.3:a:ibm:security_appscan:6.1.1.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.8.17`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_user:8.0.7820.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9`,
        fs:  `cpe:2.3:a:atlassian:jira:3.8.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6a:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.2`,
        fs:  `cpe:2.3:h:hp:h3c_router:sr_20-12_w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.3`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.5`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.6`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.7`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.8`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(0\)n1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.9`,
        fs:  `cpe:2.3:a:oracle:micros_cwdirect:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.10`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.11`,
        fs:  `cpe:2.3:a:intel:graphics_driver:15.33.42.4358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.12`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.13`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.14`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-00-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.15`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update5:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.16`,
        fs:  `cpe:2.3:a:hp:scan:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.17`,
        fs:  `cpe:2.3:h:cisco:asr_1006:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.18`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.19`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_monitoring_center_for_security:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.20`,
        fs:  `cpe:2.3:h:fortinet:fortigate-1200d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.21`,
        fs:  `cpe:2.3:a:microsoft:outlook:2010:sp1:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.22`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.23`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.4:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.24`,
        fs:  `cpe:2.3:a:haxx:curl:7.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.25`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.26`,
        fs:  `cpe:2.3:a:samba:samba:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.27`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:3.5.804:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.28`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.29`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.30`,
        fs:  `cpe:2.3:a:biscom:faxcom_suite_for_windows:9.6.990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.31`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.32`,
        fs:  `cpe:2.3:a:redhat:xemacs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.33`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-655_firmware:t100sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.34`,
        fs:  `cpe:2.3:o:cisco:catos:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.35`,
        fs:  `cpe:2.3:a:altiris:software_delivery_solution_for_unix_and_linux:6.1.3006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.36`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.49.5139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.37`,
        fs:  `cpe:2.3:a:patterns:patterns:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.38`,
        fs:  `cpe:2.3:a:libuv_project:libuv:0.10.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.39`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1.1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.40`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.41`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.42`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.43`,
        fs:  `cpe:2.3:a:pcre:pcre2:10.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.9.44`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.1`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.3`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:9.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.5`,
        fs:  `cpe:2.3:o:asus:rt-ac56s_firmware:3.0.0.4.376.3715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.7`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.1.2.1510:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.8`,
        fs:  `cpe:2.3:a:pocoproject:poco_c\&#43;\&#43;_libraries:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.9`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.10`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.11`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.12`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-20:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.13`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.14`,
        fs:  `cpe:2.3:o:cisco:catos:7.2\(0.65\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.10.15`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.3.300.265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11:rc1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11:rc2`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11:rc3`,
        fs:  `cpe:2.3:a:piwik:piwik:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11:rc4`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.27.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11:rc5`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11:rc6`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11:rc7`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.5:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11.2`,
        fs:  `cpe:2.3:a:sun:ray_windows_connector:1.1:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11.3`,
        fs:  `cpe:2.3:a:atlassian:jira:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11.4`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11.7`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11.8`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.11.9`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.12`,
        fs:  `cpe:2.3:a:splunk:splunk:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.12.1`,
        fs:  `cpe:2.3:a:symantec:web_security:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.12.5`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_riverstone:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.12.6`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.12.7`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.14.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.12.8`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:2.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.12.14`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.13.2`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.13.7`,
        fs:  `cpe:2.3:a:google:chrome:7.0.516.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel:4.14`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linux:linux_kernel-rt:3.10.0`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-atm:linux-atm:-`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-atm:linux-atm:2.4`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-ha:heartbeat:-`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_7906g:8.0\(4\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-ha:heartbeat:0.4.9`,
        fs:  `cpe:2.3:a:apache:log4j:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-ha:heartbeat:1.2.4`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-ha:heartbeat:2.0.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.519:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.0`,
        fs:  `cpe:2.3:a:redhat:linux:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.1`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.2:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.2`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.280:update28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.3`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.4`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.5`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.6`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.7`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.8`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nfs:nfs-utils:1.2.9`,
        fs:  `cpe:2.3:o:microsoft:windows_95:-:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nis:rpc.yppasswdd:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-nis:ypserv:-`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-sottises:board-tnk:-`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:3.3:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-sottises:board-tnk:1.3`,
        fs:  `cpe:2.3:a:gnu:automake:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-sottises:news-tnk:-`,
        fs:  `cpe:2.3:a:nagios:plugins:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-sottises:news-tnk:1.2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:13.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linux-sottises:news-tnk:1.2.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:cgmanager:0.32`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.1.0`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.11.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.2.0`,
        fs:  `cpe:2.3:a:indusoft:web_studio:7.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.2.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.685.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.3.0`,
        fs:  `cpe:2.3:a:apache:poi:1.8:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.4.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.5.0`,
        fs:  `cpe:2.3:a:smartbear:aqtime:7.10.380.86:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.5.1`,
        fs:  `cpe:2.3:a:atastefromheaven:angel_reigns:1.2.6.185:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.5.2`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.6.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.6.1`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.6.2`,
        fs:  `cpe:2.3:a:apache:tomcat:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.6.3`,
        fs:  `cpe:2.3:a:symantec:altiris_deployment_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.6.4`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.6.5`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.7.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.7.2`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.7.3`,
        fs:  `cpe:2.3:a:cisco:webns:7.10_.0.06s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.7.4`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_lan_management_solution:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.7.4.1`,
        fs:  `cpe:2.3:h:d-link:dsr-1000n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.7.4.2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.7.5`,
        fs:  `cpe:2.3:h:snapgear:580:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.8.0`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:0.9.0`,
        fs:  `cpe:2.3:a:cisco:pix_asa_ids:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:1.0.0:beta2`,
        fs:  `cpe:2.3:a:exim:exim:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:1.0.9`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.4.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:2.0.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxcontainers:lxc:2.0.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0`,
        fs:  `cpe:2.3:o:yamaha:rta52i:4.01.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.343:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.2`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.4`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.5`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.6`,
        fs:  `cpe:2.3:o:tizen:tizen:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.7`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.8`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.0.1:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.9`,
        fs:  `cpe:2.3:a:sas:deployment_tester_client:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.10`,
        fs:  `cpe:2.3:a:webmin:usermin:1.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.11`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.12`,
        fs:  `cpe:2.3:a:qemu:qemu:0.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.14`,
        fs:  `cpe:2.3:a:vmware:workstation:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.15`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:dev3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.16`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.17`,
        fs:  `cpe:2.3:a:canon:canoscan_toolbox:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.18`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.19`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.20`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.21`,
        fs:  `cpe:2.3:a:apple:webkit:412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.22`,
        fs:  `cpe:2.3:a:djangoproject:django:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.23`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.24`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.023.20053:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.25`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.26`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.27`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.28`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.29`,
        fs:  `cpe:2.3:a:python:python:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.30`,
        fs:  `cpe:2.3:h:3com:3c13612:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.31`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.32`,
        fs:  `cpe:2.3:a:cdotech:edcl_management_console:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.33`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.34`,
        fs:  `cpe:2.3:a:codehaus:xfire:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.35`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.36`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.37`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.9.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.38`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.39`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.40`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.41`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.42`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.43`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.44`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.45`,
        fs:  `cpe:2.3:a:microsoft:iis:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.46`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.47`,
        fs:  `cpe:2.3:a:google:chrome:11.0.666.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.48`,
        fs:  `cpe:2.3:a:winscp:winscp:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.49`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.50`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.51`,
        fs:  `cpe:2.3:a:hp:operations_agent:7.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.52`,
        fs:  `cpe:2.3:a:kate_mobile:vk_kate_mobile:9.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.53`,
        fs:  `cpe:2.3:a:augeas:augeas:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.54`,
        fs:  `cpe:2.3:a:vmware:fusion:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.55`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.56`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.57`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.58`,
        fs:  `cpe:2.3:a:ecava:integraxor:3.60.4061:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.59`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r009c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.60`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.61`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.62`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.63`,
        fs:  `cpe:2.3:h:linksys:befn2ps4:1.42.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.64`,
        fs:  `cpe:2.3:o:raritan:px:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.65`,
        fs:  `cpe:2.3:a:openbsd:openssh:7.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.66`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.67`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.3:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.68`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc125a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.69`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5v:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.70`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.71`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.72`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.73`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.74`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.75`,
        fs:  `cpe:2.3:a:mollify:mollify:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.0.76`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)sg2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.1.0`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.0\(0\):sr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.2.0`,
        fs:  `cpe:2.3:o:yamaha:rt56v:4.07.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.3.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.4.0`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.957:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.5.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.6.0`,
        fs:  `cpe:2.3:a:symantec:brightmail_antispam:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.8.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.8.1`,
        fs:  `cpe:2.3:o:bluecoat:cacheos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.8.2`,
        fs:  `cpe:2.3:a:vips:vips:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.8.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.9.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.10.0`,
        fs:  `cpe:2.3:a:novell:iprint:5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.11.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.11.1`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.11.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.11.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.11.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.27b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.11.5`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.11.6`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.12.0`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:5.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.13.0`,
        fs:  `cpe:2.3:a:bikersunderground:bikers_underground:4.5.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.13.1`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.13.2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.99.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.13.3`,
        fs:  `cpe:2.3:a:x2engine:x2crm:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.13.4`,
        fs:  `cpe:2.3:a:dennis_bruecke:jquery_countdown:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.13.5`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.8.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.14.0`,
        fs:  `cpe:2.3:a:3s-software:codesys_runtime_system:2.3.9.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.14.1`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.15.0`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.16.0`,
        fs:  `cpe:2.3:a:huawei:p7-l10_firmware:v100r001c00b135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.16.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.16.2`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.16.3`,
        fs:  `cpe:2.3:a:gnome:glib:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.16.4`,
        fs:  `cpe:2.3:a:clamav:clamav:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.0`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.10.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.1`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.2`,
        fs:  `cpe:2.3:h:buffalotech:wmr-300_firmware:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je017a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.6`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1017:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.7`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.8`,
        fs:  `cpe:2.3:h:cisco:b260_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.17.9`,
        fs:  `cpe:2.3:o:sgi:irix:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.18.0`,
        fs:  `cpe:2.3:a:libgd:libgd:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.051`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.052`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.053`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:cups-filters:1.054`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.0`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.2.3.6514:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.1`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cce:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.2`,
        fs:  `cpe:2.3:a:novell:groupwise:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.5`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.6`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.10-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2009.312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.9`,
        fs:  `cpe:2.3:a:x:libchromexvmcpro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.10`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.11`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.12`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3\(1.1.112\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.13`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.14`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.15`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-03-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.16`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:linuxfoundation:foomatic-filters:4.0.17`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:linuxmint:linux_mint:17.0`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lipbrau:hearsay%3a_a_social_party_game:1.7.000::~~~android~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liquidthreads_project:liquidthreads:2.0:alpha`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liquidthreads_project:liquidthreads:2.1:alpha`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:listener-interactive:kfai_community_radio:2.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liteonit:ez-dub:5.0.3`,
        fs:  `cpe:2.3:a:ni:labwindows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.1`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:3.0.0.3.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.2`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_pocket_pc_documentation:6.1.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.3`,
        fs:  `cpe:2.3:a:microsoft:excel:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.4`,
        fs:  `cpe:2.3:h:hp:retail_integrated_barcode_scanner_e1l07aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.5`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.6`,
        fs:  `cpe:2.3:o:hp:hp_h-series_fibre_channel_switch_firmware:8.0.14.08.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.7`,
        fs:  `cpe:2.3:a:apache:axis:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.8`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:12.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.9`,
        fs:  `cpe:2.3:h:f5:big-ip_8950:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.10`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.11`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.12`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.13`,
        fs:  `cpe:2.3:a:typo3:typo3:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.0.14`,
        fs:  `cpe:2.3:a:lumension:patchlink_update_server:6.2.0.189:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litespeedtech:litespeed_web_server:4.1.11`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite_10g:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litronic:argus:3.15.6.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litronic:argus:4.0.2.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litronic:argus:5.2.1.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litronic:fortezza:6.0.0.4`,
        fs:  `cpe:2.3:h:hp:hybrid_pos_printer_with_micr_us_fk184aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litronic:fortezza:51.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litronic:netsign_cac:-`,
        fs:  `cpe:2.3:h:cisco:multiservice_platform_2651:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:litter_penguin:web_browser_%26_explorer:2.0.7::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:little_games:africa_memory:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:1.17`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:1.18`,
        fs:  `cpe:2.3:a:skype:skype:0.90.0.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:1.19`,
        fs:  `cpe:2.3:h:hp:jg408a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:2.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:2.1`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ya8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:2.3`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:2.4`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security:e80.30:-:vpn_blade:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:littlecms:little_cms_color_engine:2.5`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live_tv_browser_project:live_tv_browser:2::~~~android~~`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/ru2_firmware:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.07.15`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.07.15a`,
        fs:  `cpe:2.3:a:cisco:finesse:8.5\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.07.18`,
        fs:  `cpe:2.3:a:nvidia:display_driver:307.78:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.07.21`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.08.13`,
        fs:  `cpe:2.3:a:oracle:database_server:11.2.0.1.0:enterprise:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.08.20`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.08.22`,
        fs:  `cpe:2.3:a:visualware:myconnection_server:9.7i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.09.02`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1660.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.09.19`,
        fs:  `cpe:2.3:a:netartmedia:real_estate_portal:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.10.05`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.10.09`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.10.18`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.10.27`,
        fs:  `cpe:2.3:a:google:chrome:14.0.823.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.11.02`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.11.08`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:10.6\(2\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.11.20`,
        fs:  `cpe:2.3:a:altiris:express_deployment_server:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.11.27`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.11.28`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.11.29`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1079.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.12.02`,
        fs:  `cpe:2.3:a:blaine_lang:filedepot:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.12.19`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.12.20`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2011.12.23`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.01.07`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.01.13`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.01.25`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.01.26`,
        fs:  `cpe:2.3:a:citrix:ica_web_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.02.03`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-s30:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.02.04`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.02.29`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.03.20`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.03.22`,
        fs:  `cpe:2.3:a:ctb:tabe-pc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.04.04`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.04.18`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.04.21`,
        fs:  `cpe:2.3:a:nowbrowser:now_browser_\(material\):2.8.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.04.26`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-s39:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.04.27`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.05.03`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.05.11`,
        fs:  `cpe:2.3:a:apache:commons_fileupload:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.05.17`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.06.12`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.06.17`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.06.23`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.06.26`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.07.03`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.07.06`,
        fs:  `cpe:2.3:a:ows:scald:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.07.14`,
        fs:  `cpe:2.3:o:microsoft:windows_2000_terminal_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.07.18`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.07.24`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.07.26`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.08.08`,
        fs:  `cpe:2.3:a:busybox:busybox:1.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.08.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.08.17`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.08.20`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110826:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.08.28`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.08.29`,
        fs:  `cpe:2.3:a:rim:blackberry_desktop_software:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.08.30`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.08.31`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.09.06`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.09.07`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.3.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.09.11`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.09.12`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.09.13`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.09.27`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x51:d26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.01`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.04`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6:beta:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.11`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.12`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/l:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.16`,
        fs:  `cpe:2.3:a:mybroadband:mybroadband_tapatalk:3.9.22:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.17`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.18`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.21`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.22`,
        fs:  `cpe:2.3:a:emc:rsa_identity_management_and_governance:6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.10.24`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.11.05`,
        fs:  `cpe:2.3:a:myapp:prix_import:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.11.08`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.11.16`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.3:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.11.17`,
        fs:  `cpe:2.3:h:xerox:workcentre_m55:2.28.11.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.11.22`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.5:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.11.28`,
        fs:  `cpe:2.3:a:soprano:fonecta_verify:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.11.29`,
        fs:  `cpe:2.3:a:xnview:xnview:1.96.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.11.30`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.12.15`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.12.18`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.12.21`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.12.22`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.12.23`,
        fs:  `cpe:2.3:h:cisco:business_edition_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2012.12.24`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.8:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.03`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.04`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.05`,
        fs:  `cpe:2.3:o:microsoft:windows_2000_terminal_services:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.15`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0:ru6mp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.18`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.19`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:187:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.21`,
        fs:  `cpe:2.3:h:3com:3cr29223:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.22`,
        fs:  `cpe:2.3:a:emc:connectrix_manager:12.0.3:-:-:*:converged_network_edition:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.23`,
        fs:  `cpe:2.3:a:squid-cache:squid:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.01.25`,
        fs:  `cpe:2.3:a:apache:traffic_server:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.02.05`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.5.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.02.11`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.02.27`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.03.07`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:10.0.74.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.03.23`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.03.31`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.01`,
        fs:  `cpe:2.3:h:cisco:asr_1001-x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.04`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.05`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.06`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.08`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.62:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.16`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.21`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.22`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.23`,
        fs:  `cpe:2.3:a:symantec:management_platform:7.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.29`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.04.30`,
        fs:  `cpe:2.3:a:cubecart:cubecart:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.05.30`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.06.06`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.06.14`,
        fs:  `cpe:2.3:a:parentlink:bloom_township_206:4.0.500:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.06.18`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.06.30`,
        fs:  `cpe:2.3:a:isc:bind:9.9.1:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.07.03`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.07.16`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.07.30`,
        fs:  `cpe:2.3:a:gnome:glib:2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.07.31`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.08.05`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.08.15`,
        fs:  `cpe:2.3:a:apple:remote_desktop:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.08.16`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.08.28`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.08.31`,
        fs:  `cpe:2.3:a:schneems:wicked:0.3.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.09.07`,
        fs:  `cpe:2.3:a:vips:vips:7.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.09.08`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.09.11`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.09.18`,
        fs:  `cpe:2.3:a:novell:zenworks_endpoint_security_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.09.27`,
        fs:  `cpe:2.3:a:apache:struts:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.09.30`,
        fs:  `cpe:2.3:a:google:chrome:48.0.2564.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.01`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.4-h2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.02`,
        fs:  `cpe:2.3:a:polycom:rss_system_software:6.9j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.03`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.07`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.08`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.09`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.11`,
        fs:  `cpe:2.3:a:google:chrome:4.0.255.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.16`,
        fs:  `cpe:2.3:a:emc:atmos:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.18`,
        fs:  `cpe:2.3:a:symantec:data_center_security_server:6.5:mp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.22`,
        fs:  `cpe:2.3:a:vmware:vcenter_chargeback_manager:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.24`,
        fs:  `cpe:2.3:a:ibm:integration_bus:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.10.25`,
        fs:  `cpe:2.3:a:ibm:db2_connect:11.1.0.0:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.11.06`,
        fs:  `cpe:2.3:a:field_group_project:field_group:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.11.10`,
        fs:  `cpe:2.3:a:ibm:optim_performance_manager:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.11.14`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.11.15`,
        fs:  `cpe:2.3:a:xerox:docushare:6.6.1:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.11.25`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.11.26`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.11.29`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.03`,
        fs:  `cpe:2.3:a:stackideas:komento:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.04`,
        fs:  `cpe:2.3:a:ishikawa_mutsumi:kon2:0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.05`,
        fs:  `cpe:2.3:a:web2py:web2py:1.98.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.15`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.16`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.17`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.18`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.21`,
        fs:  `cpe:2.3:a:monotone:monotone:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.29`,
        fs:  `cpe:2.3:a:emc:documentum_web_publisher:6.5:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2013.12.31`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.07`,
        fs:  `cpe:2.3:a:openx:openx:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.11`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_97:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.13`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:sp3_alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.14`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.15`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.16`,
        fs:  `cpe:2.3:o:yahama:rt56v:4.07.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.17`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.18`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.50.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.19`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.20`,
        fs:  `cpe:2.3:o:d-link:dcs-2330l_firmware:1.13.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.21`,
        fs:  `cpe:2.3:o:siemens:ccid1445-dn18_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:live555:streaming_media:2014.01.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:liveauctions:liveauctions.tv:2.005::~~~android~~`,
        fs:  `cpe:2.3:a:hermanmiller:cad_pack_for_north_america:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livelycart:livelycart:1.2.0`,
        fs:  `cpe:2.3:a:python:python:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:2.81`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:2.91`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:2.94`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.0.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.21:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.0.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.0.5`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.1.1`,
        fs:  `cpe:2.3:a:red-gate:sql_comparison_sdk:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.2.1`,
        fs:  `cpe:2.3:a:oracle:database_server:11g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.5.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.6.1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.7.1`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:3.8.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:4.2.1`,
        fs:  `cpe:2.3:a:webmin:usermin:1.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:4.3.1`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnitouch_8460_advanced_communication_server:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:4.9.1`,
        fs:  `cpe:2.3:a:ibm:global_security_kit:8.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:5.2.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:6.0.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:6.2.1`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-600e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:6.2.3`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:6.2.4`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:6.2.6`,
        fs:  `cpe:2.3:a:mysql:eventum:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:6.2.7`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:6.2.8`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:6.2.71`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livetecs:timeline:7.1.1`,
        fs:  `cpe:2.3:a:oracle:industry_applications:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:3.1.8.3`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:3.2.0.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:4.0.1.0`,
        fs:  `cpe:2.3:a:ibm:sametime_meeting_server:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:4.0.1.1`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:4.0.1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.7.5:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:4.1.0.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:4.1.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(32\)s12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:4.2.0.4`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:4.2.0.5`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.0.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.0.1.1`,
        fs:  `cpe:2.3:a:apple:cups:1.1.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.0.1.2`,
        fs:  `cpe:2.3:h:cisco:spa901_1-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.0.1.3`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.0.1.4`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.1.0.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.1.1.0`,
        fs:  `cpe:2.3:a:apache:struts:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.1.2.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:livezilla:livezilla:5.1.2.1`,
        fs:  `cpe:2.3:a:hp:destination_component:90.0.91.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lixil:my_satis_genius_toilet:-::~~~android~~`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lksctp:stream_control_transmission_protocol:-`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lksctp:stream_control_transmission_protocol:2.6.16`,
        fs:  `cpe:2.3:a:itwitter_project:itwitter:0.04:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lksctp:stream_control_transmission_protocol:2.6.17`,
        fs:  `cpe:2.3:a:apple:bonjour:1.0.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:llvm:clang:3.5`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:localsense:localsense:1.2.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:6.x-3.0`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.54:bbet54u:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:6.x-3.0:rc1`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:6.x-3.0:rc2`,
        fs:  `cpe:2.3:a:ibm:cognos_business_intelligence:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:6.x-3.0:test3`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:6.x-3.1`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:6.x-3.1:rc1`,
        fs:  `cpe:2.3:a:mcafee:asset_manager:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:6.x-3.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:gnome:glib:2.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:7.x-3.0:alpha1`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:7.x-3.x:dev`,
        fs:  `cpe:2.3:a:jasig:uportal:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:7.x-4.x:dev`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.818:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:location_module_project:location:7.x-5.x:dev`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:locationvalue:restaurant_karaoke_shidax:1.3.3::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6s\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:locationvalue:restaurant_karaoke_shidax:2.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:exim:exim:4.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.1.0:beta`,
        fs:  `cpe:2.3:a:sphider:sphider:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.2.0:beta`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.3.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.9.0.1210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.3.0:beta`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.3.1`,
        fs:  `cpe:2.3:a:canon:imagerunner_c3220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.3.1:a`,
        fs:  `cpe:2.3:a:laytontechnology:helpbox:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.3.2`,
        fs:  `cpe:2.3:a:perl:perl:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.3.3`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:4.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.3.4`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.2.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.3.4:community`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.3:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.0:a-beta`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.0:beta`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.1:beta`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.2:beta`,
        fs:  `cpe:2.3:a:apache:opennlp:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.3:a-beta`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.005:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.3:b-beta`,
        fs:  `cpe:2.3:a:dotnetblogengine:blogengine.net:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.3:beta`,
        fs:  `cpe:2.3:a:opnet:ace_analyst:15.0.0.8652:*:*:*:plus:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.4:beta`,
        fs:  `cpe:2.3:a:ca:unicenter_enterprise_job_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe_16.1:16.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.6`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.4.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p404:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:1.5.0:beta`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.0.0:beta`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.0.1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.0.1:a`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.1.0:beta`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.1.2`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.1.2:a`,
        fs:  `cpe:2.3:a:scriptbrasil:taboada_macronews:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.2.0:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.2.1:one`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.3.0`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.3.0:rc1`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.3.1`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.3.3`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.3.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.4.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.4.0:rc1`,
        fs:  `cpe:2.3:a:moodle:moodle:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.4.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.4.2`,
        fs:  `cpe:2.3:h:hp:laserjet_4345_mfp:q3942a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.4.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.4.4`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:3.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.5.0:alpha`,
        fs:  `cpe:2.3:a:jenkins:git:1.6.0:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.5.0:alpha2`,
        fs:  `cpe:2.3:a:ibm:internet_security_systems_blackice_defender:2.9cap:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.11.0`,
        fs:  `cpe:2.3:a:sympa:sympa:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.11.0:beta`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.11.0:beta2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.11.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.11.2`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance:a5\(1.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.11.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.10.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.11.4`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.11.5`,
        fs:  `cpe:2.3:a:adobe:asset_services:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.0`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.1`,
        fs:  `cpe:2.3:a:revive-adserver:revive_adserver:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.2`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.3`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.3en`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.3enp1`,
        fs:  `cpe:2.3:h:3com:3c17709-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.3enp2`,
        fs:  `cpe:2.3:a:hideyuki_chikada:perltreebbs:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.4en`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.5`,
        fs:  `cpe:2.3:h:cisco:catalyst_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.5en`,
        fs:  `cpe:2.3:a:moodle:moodle:3.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.6`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.15-25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.12.6en`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lockon:ec-cube:2.13.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:log-chat_project:log-chat:1.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logilab:logilab-common:0.58.3`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logilab:logilab-common:0.59.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p195:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logilab:logilab-common:0.59.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logilab:logilab-common:0.60.0`,
        fs:  `cpe:2.3:a:isc:dnsco_bind:9.9.4:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logilab:logilab-common:0.61.0`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:login_security_project:login_security:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:catapultsoftware:catapult_dnp3_i\/o_driver:7.20.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:login_security_project:login_security:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:driver-soft:driver_genius:10.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:login_security_project:login_security:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:login_widget_with_shortcode_project:login_widget_with_shortcode:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fonality:fonality:14.1i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:8.00.00.4477:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:h:honeywell:falcon_xlweb_linux_controller:2.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:telenavsoftware:autonavi:4.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:login_widget_with_shortcode_project:login_widget_with_shortcode:3.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitec:lan-w300n%2fr:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fr_firmware:1.17`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fr_firmware:1.18`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:7.5.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fr_firmware:2.10a`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fr_firmware:2.17`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p330:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fr_firmware:2.27`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitec:lan-w300n%2frs:-`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta67:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2frs_firmware:1.17`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2frs_firmware:1.18`,
        fs:  `cpe:2.3:a:foliovision:foliopress_wysiwyg:2.6.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2frs_firmware:2.10a`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2frs_firmware:2.17`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2frs_firmware:2.27`,
        fs:  `cpe:2.3:a:docker:docker:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitec:lan-w300n%2fru2:-`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fru2_firmware:1.17`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fru2_firmware:1.18`,
        fs:  `cpe:2.3:o:cisco:ios:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fru2_firmware:2.10a`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fru2_firmware:2.17`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.46:devel:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitec:lan-w300n%2fru2_firmware:2.27`,
        fs:  `cpe:2.3:a:microsoft:excel:2002:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:audio_echo_cancellation_component:10.0.1439`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:audio_echo_cancellation_component:10.40.1401`,
        fs:  `cpe:2.3:a:perl:perl:5.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:audio_echo_cancellation_component:10.50.1096`,
        fs:  `cpe:2.3:a:adobe:coldfusion_builder:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:audio_echo_cancellation_component:10.51.2027`,
        fs:  `cpe:2.3:a:hp:scan:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:audio_echo_cancellation_component:11.0.1218`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:backweb:1.0`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:1.2:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:camerahelpermsi:13.0.1774.0`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:camerahelpermsi:13.25.1010.0`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.1.2-42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:camerahelpermsi:13.30.1395.0`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.66.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:cddrv_installer:4.60`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.06.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitech:cordless_freedom:-`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd3.t665_firmware:1.24.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitech:cordless_freedom_itouch_keyboard:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitech:cordless_freedom_navigator:-`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitech:cordless_freedom_pro:-`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitech:cordless_itouch_keyboard:-`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:desktop_messenger:2.30.4`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.1.2-29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:desktop_messenger:2.52.18`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:ereg:1.20.138.34`,
        fs:  `cpe:2.3:a:xchat:xchat:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:erlt:1.20.137`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:erlt:1.20.138.34`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:high_quality_video:12.0.1280`,
        fs:  `cpe:2.3:o:huawei:s9703_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:high_quality_video:12.10.1113`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.6.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:im_video_companion:1.3.0.2041`,
        fs:  `cpe:2.3:a:bitrock:bitrock_installbuilder_enterprise:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:imagestudio:7.30.0`,
        fs:  `cpe:2.3:h:hp:b5l05a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitech:itouch_keyboard:-`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:khalinstallwrapper:2.0.0`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g54_firmware:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_facebook:13.0.1777.0`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050718:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_facebook:13.20.1166.0`,
        fs:  `cpe:2.3:a:apple:itunes:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_facebook:13.30.1346.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_gallery:13.0.1778.0`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:11:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_gallery:13.20.1166.0`,
        fs:  `cpe:2.3:a:mesa3d:mesa:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_gallery:13.30.1379.0`,
        fs:  `cpe:2.3:a:plone:plone:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_help_main:13.0.1783.0`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.84.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_help_main:13.25.1016.0`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_help_main:13.30.1396.0`,
        fs:  `cpe:2.3:a:candlepinproject:candlepin:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_launcher:13.0.1776.0`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_launcher:13.20.1166.0`,
        fs:  `cpe:2.3:a:symantec:message_gateway_for_service_providers:10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_launcher:13.30.1379.0`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_motion_detection:13.0.1778.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_motion_detection:13.20.1176.0`,
        fs:  `cpe:2.3:a:apple:cups:2.0:*:*:*:development:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_motion_detection:13.30.1395.0`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_pictures_and_video:13.0.1778.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_pictures_and_video:13.25.1010.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_pictures_and_video:13.30.1395.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0404hf-al-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_twitter:13.20.1166.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(1w\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_twitter:13.30.1346.0`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc024xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_video_mask_maker:13.0.1774.0`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_video_mask_maker:13.10.1216.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_video_mask_maker:13.30.1379.0`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_videoeffects:13.0.1774.0`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_videoeffects:13.25.1005.0`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_videoeffects:13.30.1379.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_webcam_software:13.0.1774.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_webcam_software:13.20.1168.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.0.0.408:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_webcam_software:13.30.1379.0`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_wlm_plugin:1.0.1774.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_wlm_plugin:1.20.1166.0`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_wlm_plugin:1.30.1201.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_youtube_plugin:13.0.1777.0`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_youtube_plugin:13.20.1166.0`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:lws_youtube_plugin:13.30.1346.0`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:mouseware:9.79`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:mvision:10.40.1401`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:mvision:10.50.1096`,
        fs:  `cpe:2.3:a:redhat:docbook_utils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:mvision:10.51.2027`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_xgs_firmware:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:mvision:11.0.1218`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:mvision:11.10.2030`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:mvision:11.50.1169`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:logitech:quickcam:-`,
        fs:  `cpe:2.3:a:gnome:gnombe_online_accounts:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam:10.50.1096`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam:10.51.2029`,
        fs:  `cpe:2.3:h:cisco:asr_1001_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam:11.0.1218`,
        fs:  `cpe:2.3:a:horde:groupware:1.1:rc3:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam:11.10.2030`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam:11.50.1169`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam:11.70.1200`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.3\(0\)zn\(0.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam:11.80.1065`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam:11.90.1263`,
        fs:  `cpe:2.3:a:ibm:sametime:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam_for_enterprise:11.72.1069`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam_software:8.41.0`,
        fs:  `cpe:2.3:a:php:php:5.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam_software:8.47.0`,
        fs:  `cpe:2.3:a:enalean:tuleap:7.5.99.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:quickcam_software:9.2.0`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security:e80.10:-:vpn_blade:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:setpoint:4.80`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:setpoint:6.22.24`,
        fs:  `cpe:2.3:a:ibm:lotus_cc_mail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:setpoint:6.30.43`,
        fs:  `cpe:2.3:h:xerox:workcentre_m55:2.97.20.032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:umvplstandalone:10.0.1439`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:updater:1.70`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.13:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:vid:1.1.1015`,
        fs:  `cpe:2.3:a:dell:sonicwall_analyzer:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:vid:1.10.1009`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:vid:1.70.1044`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)mx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:vid_hd:7.2_%287230%29`,
        fs:  `cpe:2.3:a:estrongs:es_file_explorer:3.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:vid_hd:7.2_%287248%29`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:video_enumerator:10.0.1439`,
        fs:  `cpe:2.3:a:apache:commons-compress:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:video_enumerator:10.40.1401`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:video_enumerator:10.50.1096`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:video_enumerator:10.51.2027`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:videocall:-`,
        fs:  `cpe:2.3:a:apache:ambari:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:videocall%2bcallmanager:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:videocall%2bcomlink:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.7.0.2\(4719\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:videocall%2bvibec:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:videocall%2bviewerclient:-`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:videocall%2bwebcamxmp:-`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:webcam_software:12.0.1280`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.1.0:*:*:*:*:wotlab_burning_board:*:*`,
    },
     
    {
        uri: `cpe:/a:logitech:webcam_software:12.10.1113`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:logosquest_-_beginnings_project:logosquest_-_beginnings:1.0::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:loli_chocolate_cake_project:loli_chocolate_cake:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longluntan:gzonerc_-_the_rc_hobby_hub:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ip_phone_8800_series_firmware:10.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.0`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.1`,
        fs:  `cpe:2.3:a:datadynamics:activebar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.3`,
        fs:  `cpe:2.3:h:cisco:content_services_switch_11000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.4`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.5`,
        fs:  `cpe:2.3:a:mcafee:mcinsctl.dll:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.6`,
        fs:  `cpe:2.3:a:splunk:splunk:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.7`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.8`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player:5.9`,
        fs:  `cpe:2.3:a:winzip:winzip:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:labelgate:mora_downloader:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:etrust_audit_client:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:database_server:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:windriver:vxworks:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:log-chat_project:log-chat:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp2:compute_cluster:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longtailvideo:jw_player_for_flash_%26_html5_video_plugin:2.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:longwaveconsulting:ubercart_securetrading_payment_method_module:6.x-1.0`,
        fs:  `cpe:2.3:a:blackberry:blackberry_world:5.0.0.262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lookout:lookout:-`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lookout:lookout:2.6`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.9507:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lookout:lookout_security_%26_antivirus:8.17:-:~~~android~~`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2002:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:lookout:lookout_security_%26_antivirus:8.17-8a39d3f:-:~~~android~~`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.1\(1\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lookoutsoftware:lookout:1.3.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lorextechnology:edge:lh310`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lorextechnology:edge%2b:lh320`,
        fs:  `cpe:2.3:o:microsoft:windows:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lorextechnology:edge%2b_lh320_firmware:7-35-28-1b26e`,
        fs:  `cpe:2.3:a:oracle:siebel_core-common_components:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lorextechnology:edge_lh310_firmware:7-35-28-1b26e`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lorextechnology:edge2:lh330`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(18\)st1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lorextechnology:edge2_lh330_firmware:11.17.38-33_1d97a`,
        fs:  `cpe:2.3:a:cisco:qos_policy_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lorextechnology:edge3:lh340`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:lorextechnology:edge3_lh340_firmware:11.19.85_1fe3a`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(33\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lost_temple_project:lost_temple:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lostpassword:passware_kit:10.0.1763::~~professional_demo~~~`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lostpassword:windows_key:8.3`,
        fs:  `cpe:2.3:a:cisco:unified_intelligent_contact_management_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lotro:lord_of_the_rings_online:1.0.0::~~free_trial~~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lotum:paint-for-friends:1.5.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:louis_jimenez:custom_meta:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:louis_jimenez:custom_meta:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:hp:tru64:4.0f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:louis_jimenez:custom_meta:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:knowledge_management:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:louis_jimenez:custom_meta:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:2631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:louis_jimenez:custom_meta:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:louis_jimenez:custom_meta:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:palm:blazer:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:louis_jimenez:custom_meta:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:h:cisco:ons_15454:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:love_horoscope_guide_project:love_horoscope_guide:1::~~~android~~`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:loving.fm:loving_-_couple_essentia:4.0.1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:loytec:l-switch_and_l-ip_firmware:6.0.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:loytec:linx-100:-`,
        fs:  `cpe:2.3:a:ca:cleverpath_ecm:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:loytec:lip-3ectb:-`,
        fs:  `cpe:2.3:a:x.org:x11:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:loytec:lip-me201:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:loytec:lvis-3e100:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lrzip_project:lrzip:0.631`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lshell_project:lshell:0.9.16`,
        fs:  `cpe:2.3:a:citrix:offline_plug-in:5.2.0.1227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:dell_sas_raid_storage_manager:2.66.0`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:megaraid_storage_manager:2.29.0`,
        fs:  `cpe:2.3:a:cisco:security_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:megaraid_storage_manager:2.91.600`,
        fs:  `cpe:2.3:a:impactlabs:pointless:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:mr_hhr:0.5.503`,
        fs:  `cpe:2.3:h:cisco:application_velocity_system_3110:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:mystorage:3.0.0`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:mystorage_gca:3.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:mystorage_sas:3.0.12`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:power_console_plus_package:5.0`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:sas-ir_storage_snmp_agent:3.13.2`,
        fs:  `cpe:2.3:a:global_beauty_research_project:global_beauty_research:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:lsi:symplicity_es_storage_manager:10.70.x3.25`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.625.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:-`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:1.8`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:1.8c`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:1.8d`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:1.8e`,
        fs:  `cpe:2.3:a:isc:bind:9.1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:14.3`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:14.4`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:15.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lsoft:listserv:16.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lstc:ls-dyna:-`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lttng:ust:0.1`,
        fs:  `cpe:2.3:h:intel:express_550f:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lttng:ust:0.2`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lttng:ust:0.3`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l2_controller_firmware:20.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lttng:ust:0.4`,
        fs:  `cpe:2.3:a:emulex:hbanyware:3.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lttng:ust:0.5`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:lttng:ust:0.6`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lttng:ust:0.7`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucas_clemente_vella:libpam-pgsql:0.7`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:access_point_service_router_1500:-`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:access_point_service_router_300:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:access_point_service_router_600:-`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(5\)sr2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:ascend_max_router:-`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:ascend_max_router:5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:ascend_pipeline_router:-`,
        fs:  `cpe:2.3:h:d-link:dcs-2530l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:ascend_pipeline_router:5.0`,
        fs:  `cpe:2.3:a:php:php:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:ascend_pipeline_router:6.0`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:1.5.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:ascend_pipeline_router:6.0.2`,
        fs:  `cpe:2.3:a:david_king:vino:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:ascend_routers:-`,
        fs:  `cpe:2.3:a:adobe:photoshop:4.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:ascend_tnt_router:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:brick_80_firewall:-`,
        fs:  `cpe:2.3:a:citrix:xenapp_server_sdk:6.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:cajun_p333_network_switch:-`,
        fs:  `cpe:2.3:a:apache:subversion:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:cajun_p334_network_switch:-`,
        fs:  `cpe:2.3:a:apache:rave:0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:dslterminator:-`,
        fs:  `cpe:2.3:a:cogentdatahub:datahub_quicktrend:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:ipsec_client:10.0.0`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:orinoco_rg-1000:-`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:radius:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:radius:2.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(4d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:radius:2.0.1`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:radius:2.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:radius:2.1.2`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:security_management_server:9.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(46\)se1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalanalysis:-`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalanalysis:8.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalanalysis:8.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalanalysis:8.2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalevent:-`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalevent:8.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalevent:8.1`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalevent:8.2`,
        fs:  `cpe:2.3:a:kde:plasma-workspace:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalhelp:-`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalhelp:8.0`,
        fs:  `cpe:2.3:a:apache:struts:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalhelp:8.1`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalhelp:8.2`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalnet:-`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalnet:8.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalnet:8.1`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalnet:8.2`,
        fs:  `cpe:2.3:o:fedoraproject:fedora_core:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalsuite:-`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:11.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalsuite:8.0`,
        fs:  `cpe:2.3:a:oracle:communications_service_broker:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalsuite:8.1`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:7.6.1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucent:vitalsuite:8.2`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:lucent:wavelan:-`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lucktastic:lucktastic:1.2.6::~~~android~~`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luke_herrington:stickynote:7.x-1.0`,
        fs:  `cpe:2.3:a:sun:sdk:1.5.0_6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luke_herrington:stickynote:7.x-1.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luke_herrington:stickynote:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luke_kenneth_casson_leighton:pam_ntdom:-`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.6\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luke_kenneth_casson_leighton:pam_ntdom:0.23`,
        fs:  `cpe:2.3:a:broadcom:asf_management_applications:10.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lulusoftware:soda_pdf:5.1.183.10520`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lumberapps:quotes_in_images:3.7.5::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:4.0\(2.8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lumenera:infinity_software:5.0.2.6.4339`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lumension:patchlink:-`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lumension:patchlink_update_server:-`,
        fs:  `cpe:2.3:a:emc:powerpath:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lumension:patchlink_update_server:6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1eb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lumension:patchlink_update_server:6.2.0.181`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.1\(7\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lumension:patchlink_update_server:6.2.0.189`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lumonet_php_include_project:lumonet_php_include:1.2.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunarcms:lunar_cms:3.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunarcms:lunar_cms:3.2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunarcms:lunar_cms:3.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunarcms:lunar_cms:3.3:1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2014-09-29b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunarcms:lunar_cms:3.3:3`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunarline:continuous_compliance_monitoring_and_reporting:1.0`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunarline:cyber_intelligence_console:2.1.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunarline:scapsync:0.5.0`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:ilunascape_android:1.0.4.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.22.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:ilunascape_android:1.0.5.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.835:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.0.0`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.0.1`,
        fs:  `cpe:2.3:a:nagios:nagios:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.1.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.305.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.5.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.5.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/o:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.5.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.5.3`,
        fs:  `cpe:2.3:a:libksba_project:libskba:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.5.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.6.0`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.6.1`,
        fs:  `cpe:2.3:o:novell:suse_linux:9:*:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.6.2`,
        fs:  `cpe:2.3:h:linksys:wap54g:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.6.3`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.6.4`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:3.6.5`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.0.0`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.0.1`,
        fs:  `cpe:2.3:a:microsoft:backoffice:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.0.2`,
        fs:  `cpe:2.3:a:oracle:weblogic_workshop:8.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.0.3`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.385:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.0.5`,
        fs:  `cpe:2.3:a:ssp-europe:secure_data_space:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.0.6`,
        fs:  `cpe:2.3:a:tripwire:twoval_plug-in:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.0.7`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.1.1`,
        fs:  `cpe:2.3:a:qemu:qemu:0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.1.2`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.2.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.2.1`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.4:rc2:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.2.2`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.3.0`,
        fs:  `cpe:2.3:a:hp:unload:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.3.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.3.2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.5.0`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.5.1`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.5.2`,
        fs:  `cpe:2.3:a:david_king:vino:2.11.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.6`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.6.1`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.6.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.6.3`,
        fs:  `cpe:2.3:a:david_king:vino:2.23.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.6.4`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.6.5`,
        fs:  `cpe:2.3:a:cisco:iox:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.7.0`,
        fs:  `cpe:2.3:a:hp:customer_participation_program:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.7.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:rc.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.7.2`,
        fs:  `cpe:2.3:a:ultimus:ultimus_business_process_management_suite:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.7.3`,
        fs:  `cpe:2.3:a:musulmanin:musulmanin.com:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.7.4`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.8.0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:4.8.1`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.0:rc3`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.0.0`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.0.1`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.0.2`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.0.3`,
        fs:  `cpe:2.3:a:microsoft:powerpoint_for_mac:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.0.4`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.1:beta`,
        fs:  `cpe:2.3:a:microsoft:ftp_service:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.1.0`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.1.1`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.1.2`,
        fs:  `cpe:2.3:o:novell:netware:6.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.1.3`,
        fs:  `cpe:2.3:o:cisco:catos:4.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.1.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.1.5`,
        fs:  `cpe:2.3:a:skype:skype:3.5.0.158:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:5.1.6`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.0.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:th:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.0.1`,
        fs:  `cpe:2.3:h:cisco:ip_phone_7912:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.0.2`,
        fs:  `cpe:2.3:a:gnome:evolution:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.0.3`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.1.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.1.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.12:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.1.3`,
        fs:  `cpe:2.3:h:juniper:junos_space_ja2500_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.1.4`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.6:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.1.5`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.1.6`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.1.7`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.2`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.2.1`,
        fs:  `cpe:2.3:a:google:v8:3.12.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.3`,
        fs:  `cpe:2.3:a:hp:alm-platform_loader:11.0.4804.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.3.1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.3.2`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.3.3`,
        fs:  `cpe:2.3:a:desktopstandard:policymaker_registry_extension:2.5.1117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.3.4`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.4.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.4.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lunascape:lunascape:6.4.3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lund:meta-view:-`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:0.3.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:mclewin:wishlist:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:0.3.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:0.6.0::~~~typo3~~`,
        fs:  `cpe:2.3:h:siemens:ccid1445-dn28:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:0.9.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:sphider:sphider:1.3.4:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:0.10.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:microsoft:business_solutions_crm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.0.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:apache:archiva:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:supmua:sup:0.14.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.3::~~~typo3~~`,
        fs:  `cpe:2.3:o:d-link:dcs-932l_camera_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.4::~~~typo3~~`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.5::~~~typo3~~`,
        fs:  `cpe:2.3:a:apache:openjpa:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.6::~~~typo3~~`,
        fs:  `cpe:2.3:a:nobexrc:asylum\!:3.3.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.7::~~~typo3~~`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.8::~~~typo3~~`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:2000:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.9::~~~typo3~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.10::~~~typo3~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.12::~~~typo3~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.1.13::~~~typo3~~`,
        fs:  `cpe:2.3:a:visionsolutions:double-take:4.4.1.0.1352.s.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:breezy:breezy:1.2.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.18_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.8::~~~typo3~~`,
        fs:  `cpe:2.3:a:macromedia:breeze:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.11::~~~typo3~~`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:1.1.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.12::~~~typo3~~`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.0.0-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.13::~~~typo3~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.2.21::~~~typo3~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.1.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.3.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.4.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.4.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:8.6\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.5.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.5.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.5.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:apple:mail:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.5.3::~~~typo3~~`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_l55_controller_firmware:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.5.4::~~~typo3~~`,
        fs:  `cpe:2.3:a:snort:snort:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.5.5::~~~typo3~~`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.5.6::~~~typo3~~`,
        fs:  `cpe:2.3:h:hp:laserjet_5m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.5.7::~~~typo3~~`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.003:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2010.1125.2142.38865:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:umn:mapserver:7.0.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.4::~~~typo3~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.6::~~~typo3~~`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.8::~~~typo3~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.8:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.9::~~~typo3~~`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.10::~~~typo3~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.11::~~~typo3~~`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.3.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.14::~~~typo3~~`,
        fs:  `cpe:2.3:h:ibm:flashsystem_9846-ac2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.6.15::~~~typo3~~`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luracast:restler:1.7.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luratech:lurawave_jp2_activex_control:2.1.5.5`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:luratech:lurawave_jp2_activex_control:2.1.5.11`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lutim_project:lutim:0.7`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lvtu99:wisdom:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lwip_project:lwip:1.4.1`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:0.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.194:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:0.5.1`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:0.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:0.7`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:0.8`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:0.9`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:0.9.1`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:0.9.2`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.0`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.0.1`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.0.2`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.0.3`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.0.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.1`,
        fs:  `cpe:2.3:a:acronis:universal_restore_for_true_image_echo_server:9.7.8206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.1.1`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.1.2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.2`,
        fs:  `cpe:2.3:a:mcafee:groupshield_for_exchange:7.0.555.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.2.1`,
        fs:  `cpe:2.3:a:apache:hadoop:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.3`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.3.1`,
        fs:  `cpe:2.3:o:asus:rt-n14u_firmware:3.0.0.4.322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.3.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.3.3`,
        fs:  `cpe:2.3:a:umn:mapserver:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.3.4`,
        fs:  `cpe:2.3:a:blackberry:blackberry_world:5.0.0.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.3.5`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:1.3.6`,
        fs:  `cpe:2.3:a:cisco:webex_advanced_recording_format_player:27.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.795.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.2`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.3`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.2.2020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.4`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.5`,
        fs:  `cpe:2.3:a:plogger:plogger:-:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.6`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.8`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.9`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.10`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.2.0.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.0.11`,
        fs:  `cpe:2.3:a:isc:bind:9.10.3:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.1:alpha1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.1:beta1`,
        fs:  `cpe:2.3:o:buffalotech:whr-1166dhp_firmware:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.1:beta2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.1:beta3`,
        fs:  `cpe:2.3:a:hp:e\/a_agent_japanese_localization:8.60.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.1.1`,
        fs:  `cpe:2.3:a:freebsd:ja-xklock:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.1.2`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.1.3`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.1.4`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2:-`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2:alpha1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2:beta1`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2:beta2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2:beta3`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2:beta4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2.1`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.07.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2.2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2.3`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2.4`,
        fs:  `cpe:2.3:a:google:chrome:17.0.931.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2.5`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2.6`,
        fs:  `cpe:2.3:o:cisco:ios:11.3db:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2.7`,
        fs:  `cpe:2.3:a:synapse:ishuttle:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.2.8`,
        fs:  `cpe:2.3:a:ez:ez_publish:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3:-`,
        fs:  `cpe:2.3:a:cybozu:office:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3:alpha1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3:alpha2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4mra:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3:beta1`,
        fs:  `cpe:2.3:a:samba:samba:3.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3.1`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3.2`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3.4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3.5`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:2.3.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.535:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.0:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.0:alpha1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.0:alpha2`,
        fs:  `cpe:2.3:a:sayakbanerjee:sticky_notes:0.3.09062012.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.0:beta1`,
        fs:  `cpe:2.3:o:juniper:junos:10.4s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.0.1`,
        fs:  `cpe:2.3:a:elephantdrive:elephantdrive:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.1:beta1`,
        fs:  `cpe:2.3:a:d-link:camera_stream_client_activex_control:1.0.0.4519:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.1.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.2.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.1.1`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:008z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.1.2`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.2.0`,
        fs:  `cpe:2.3:o:freebsd:freebsd:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.2.1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.2.2`,
        fs:  `cpe:2.3:a:oracle:marketing:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.2.3`,
        fs:  `cpe:2.3:a:google:v8:3.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.2.4`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.45:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.2.5`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.0:-`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.0:rc5:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.0:beta1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.0:beta2`,
        fs:  `cpe:2.3:a:rocomotion:p_link_compact:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.0:beta3`,
        fs:  `cpe:2.3:a:adobe:camera_raw:5.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.0:beta4`,
        fs:  `cpe:2.3:a:perl:perl:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.0:beta5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.1`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:th:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.4`,
        fs:  `cpe:2.3:a:intel:proset_wireless:12.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lxml:lxml:3.3.5`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.0::~~professional~android~~`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_400_color_printer_m451:ce957a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0.300:update30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.1::~~professional~android~~`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.2::~~professional~android~~`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.3::~~professional~android~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.4::~~professional~android~~`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_unix_and_linux:6.2.1034:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.5::~~professional~android~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.6::~~~android~~`,
        fs:  `cpe:2.3:a:plone:plone:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.6::~~professional~android~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.4.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.7::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.7::~~professional~android~~`,
        fs:  `cpe:2.3:a:google:chrome:11.0.658.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.8::~~~android~~`,
        fs:  `cpe:2.3:h:fortinet:fortigate-voice-80c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.8::~~professional~android~~`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.9::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:1.9::~~professional~android~~`,
        fs:  `cpe:2.3:a:intel:network_connections:13.1.33.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.0::~~professional~android~~`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.1::~~professional~android~~`,
        fs:  `cpe:2.3:a:sendcard:sendcard:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.2::~~~android~~`,
        fs:  `cpe:2.3:h:lexmark:e240n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.2::~~professional~android~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.3::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.3::~~professional~android~~`,
        fs:  `cpe:2.3:a:eeye:retina:5.10.12.1700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.4::~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.4::~~professional~android~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.38.388:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:2.5::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1046:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:3.0::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:lyesoft:andexplorer:3.0::~~professional~android~~`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyften:com_lyftenbloggie:1.0.4`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyften:com_lyftenbloggie:1.1.0`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lyften:com_lyftenbloggie:1.5`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lynx:lynx:2.8.8:dev.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lynx:lynx:2.8.8:dev.2`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lynx:lynx:2.8.8:dev.3`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.02:pl2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:lynx:lynx:2.8.8:dev.4`,
        fs:  `cpe:2.3:a:contenido:contendio:4.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2_technologies:optimalsite:0.1`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2_technologies:optimalsite:2.4`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.0`,
        fs:  `cpe:2.3:a:oracle:advanced_collections:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.1`,
        fs:  `cpe:2.3:a:progress:objectstore:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.00:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.3`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.4`,
        fs:  `cpe:2.3:a:sas:xml_mapper:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.6`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.8`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:m2osw:tableofcontents:6.x-3.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maccabi4u:maccabi_pakal:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:python-requests:requests:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macedonia_hacienda_hotel_project:macedonia_hacienda_hotel:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2008:12.0.781.32:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mach5:mach5_analyzer:mach5_analyzer_4`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:breeze:-`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:breeze:4.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:breeze:4.1`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:breeze:5`,
        fs:  `cpe:2.3:a:wellintech:kingview:6.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:captivate:-`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:-`,
        fs:  `cpe:2.3:a:apple:itunes:7.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:2.0`,
        fs:  `cpe:2.3:a:adobe:media_encoder_cs4:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:3.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:3.0.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:3.1`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:3.1.1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:3.1.2`,
        fs:  `cpe:2.3:a:translation_widget_project:translation_widget:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:4.0`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:4.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.12s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:4.5`,
        fs:  `cpe:2.3:a:perl:perl:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:4.5.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.0:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:4.5.1:sp1`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:4.5.1:sp2`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.44:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:5.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:6.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:6.1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_explorer:7.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:7.0`,
        fs:  `cpe:2.3:a:plone:plone:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion:7.02`,
        fs:  `cpe:2.3:a:apache:ignite:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion_fusebox:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion_fusebox:4.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sxb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion_mx:7.0.0.0`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion_professional:-`,
        fs:  `cpe:2.3:a:ibm:high_availability_cluster_multiprocessing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:coldfusion_server:-`,
        fs:  `cpe:2.3:a:ibm:websphere_everyplace_server:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:contribute:-`,
        fs:  `cpe:2.3:h:hp:laserjet_4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:contribute:1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:contribute:2.0`,
        fs:  `cpe:2.3:a:jiuzhangtech:traffic_jam_free:1.7.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:contribute_publishing_server:-`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:contribute_publishing_server:1.0`,
        fs:  `cpe:2.3:a:x:libxi:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:contribute_publishing_server:1.01`,
        fs:  `cpe:2.3:a:vmware:horizon_view:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:director:5.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:dreamweaver:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:dreamweaver:6.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:dreamweaver:6.1`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:dreamweaver_ultradev:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:dreamweaver_ultradev:4.0`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:extension_manager:1.5`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(2c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:extension_manager:1.7.240`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_communication_server:1.0`,
        fs:  `cpe:2.3:a:samba:samba:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_communication_server:1.5`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd009a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_media_server:-`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_media_server:2.0_r1145`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:4.0_r12`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:5.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:5.0_r50`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:6.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:6.0.29.0`,
        fs:  `cpe:2.3:h:cisco:b460_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:6.0.40.0`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:6.0.47.0`,
        fs:  `cpe:2.3:a:cisco:personal_assistant:1.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:6.0.65.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.8.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:6.0.79.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.2.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:7.0.14.0`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:7.0.19.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:7.0.60.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.434:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:7.0.61.0`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:7.0_r19`,
        fs:  `cpe:2.3:a:microsoft:personal_web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:8.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:8.0.22.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:8.0.24.0`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:8.0.33.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:9.0`,
        fs:  `cpe:2.3:a:microsoft:pssuspend:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flash_player:9.0.16.0`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:flashpaper:2.0.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:-`,
        fs:  `cpe:2.3:a:peoplepc:peoplepal:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:2.3`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:2.3.3`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:3.0`,
        fs:  `cpe:2.3:a:perl:perl:5.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:3.0:sp1`,
        fs:  `cpe:2.3:a:citrix:online_plug-in:12.1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:3.1`,
        fs:  `cpe:2.3:a:skype:skype:0.93.1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:4.0`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:4.0:sp1`,
        fs:  `cpe:2.3:o:buffalotech:whr-600d_firmware:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:4.0:sp1a`,
        fs:  `cpe:2.3:a:heikki_hokkanen:viewgit:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:jrun:4.0_build_61650`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg242a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:matrix_screen_saver:-`,
        fs:  `cpe:2.3:a:atheme:atheme:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave:-`,
        fs:  `cpe:2.3:a:spip:spip:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave:8.0`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.6:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave:10`,
        fs:  `cpe:2.3:a:30a:30a:5.26.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave:10.1.4.20`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave_flash:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave_flash_plugin:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.07:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave_flash_plugin:6.0`,
        fs:  `cpe:2.3:h:xyplex:maxserver_1640_terminal_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave_flash_plugin:7.0`,
        fs:  `cpe:2.3:a:vips:vips:7.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:shockwave_flash_plugin:8.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:sitespring:-`,
        fs:  `cpe:2.3:a:grape_project:grape:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macromedia:sitespring:1.2.0`,
        fs:  `cpe:2.3:a:ibm:vios:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:macroplant:iexplorer:3.6.3.0`,
        fs:  `cpe:2.3:a:cisco:webns:7.20.3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.0.0:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:serf_project:serf:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.0.0:rc1:~~~ruby~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.337:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.0.0:rc2:~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.1.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.2.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.359:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.3.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.4.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.4.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:idevspot:phphostbot:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.5.0::~~~ruby~~`,
        fs:  `cpe:2.3:o:microsoft:windows_10:1607:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.5.1::~~~ruby~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madeofcode:omniauth-facebook:1.6.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:mcafee:remote_desktop_32:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:madipass:madipass_martinique:1.8::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(25\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magento:magento:1.9.1.0::~~community~~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magento:magento:1.9.2.2::~~community~~~`,
        fs:  `cpe:2.3:a:sun:cluster:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magento:magento:1.14.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:yuichiro_okuyama:tetra_filer_free:2.3.1:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:magento:magento:1.14.2.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magento:magento2:-`,
        fs:  `cpe:2.3:h:cisco:local_director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.0.0`,
        fs:  `cpe:2.3:o:f5:tmos:9.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.0.0:beta1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.0.0:rc1`,
        fs:  `cpe:2.3:a:cybozu:office:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.0.0:rc2`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.1.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.1.0:alpha1`,
        fs:  `cpe:2.3:a:ireadercity:hesheng_80:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.1.0:beta1`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns1200rx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.1.0:rc1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.6.2`,
        fs:  `cpe:2.3:a:paypal:mass_pay:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.7.0.0`,
        fs:  `cpe:2.3:a:ssh:secure_shell:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.7.0.0:alpha1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.7.0.0:beta1`,
        fs:  `cpe:2.3:a:altiris:task_management_pack_language_pack:6.0.1033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.7.0.0:rc1`,
        fs:  `cpe:2.3:a:civitasmedia:mt._airy_news:1.0069.b0069:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.7.0.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.24:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magentocommerce:magento:1.7.0.2`,
        fs:  `cpe:2.3:a:artifex:mupdf:2009.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magic_hills:wonderplugin_audio_player:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magicam_photo_magic_editor_project:magicam_photo_magic_editor:5::~~~android~~`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magiciso:magic_iso_maker:5.5`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magiciso:magicdisc:2.7.106`,
        fs:  `cpe:2.3:a:intel:proset_wireless:13.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magicstamp:magic_stamp:2.8::~~~android~~`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magix:samplitude_producer:11.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_cms:4.5.7:-:community`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_cms:4.5.8:-:community`,
        fs:  `cpe:2.3:h:cisco:ws-c3850:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_cms:4.5.9:-:community`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:007sh:j:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_cms:5.0:-:community`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_cms:5.0.1:-:community`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_form_module:1.4.7`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(4\)sv1\(3c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_form_module:2.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_form_module:2.0.1`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magnolia-cms:magnolia_form_module:2.0.2`,
        fs:  `cpe:2.3:a:hp:panostandalone:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:autocar_india:3.03::~~~android~~`,
        fs:  `cpe:2.3:a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:bbc_knowledge_magazine:3.01::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:finesse:9.1\(1\)_es2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:bespoke:3::~~~android~~`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:business_intelligence:3::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:champak_-_hindi:3.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4.7073:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:cleo_malaysia:3.01::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:siebel_suite:8.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:dealside_institutional:3.1::~~~android~~`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.3:*:pro:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:dhanam:3.1::~~~android~~`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:digit_magazine:3.01::~~~android~~`,
        fs:  `cpe:2.3:a:just-great-software:editpad:6.7.0:*:*:*:lite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:dignity_dialogue:3::~~~android~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:electronics_for_you:3.02::~~~android~~`,
        fs:  `cpe:2.3:a:novell:access_manager_identity_server:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:english_football_magazine:3::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:epc_world:3.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:gent_magazine:3::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:global_movie_magazine:3::~~~android~~`,
        fs:  `cpe:2.3:a:vastal:freelance_zone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:gr8%21_tv:3::~~~android~~`,
        fs:  `cpe:2.3:o:netbsd:netbsd:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:halftime_magazine:3::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:honeybee_mag:3::~~~android~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:hong_kong_tatler_society:3::~~~android~~`,
        fs:  `cpe:2.3:a:apple:safari:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:hot_cars:3::~~~android~~`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.6.p-1.0.2.1-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:human_factor:3.01::~~~android~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:identity:3.01::~~~android~~`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.823:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:india_today_telugu:3.02::~~~android~~`,
        fs:  `cpe:2.3:a:divx:avi_codec_pack_pro:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:indian_cement_review:3.01::~~~android~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:indian_jeweller:3::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:rhevm-reports:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:indian_management:3::~~~android~~`,
        fs:  `cpe:2.3:a:emc:documentum_xplore:1.1:p03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:inspire_weddings:3::~~~android~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:intelligent_sme:3::~~~android~~`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:just_bureaucracy:3.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5:rc1:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:karaf_magazin:3::~~~android~~`,
        fs:  `cpe:2.3:a:ca:etrust_audit_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:legalera:3::~~~android~~`,
        fs:  `cpe:2.3:a:northropgrumman:mailroom:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:macau_business:3::~~~android~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:magzter_-magazine_%26_book_store:3.31::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:publisher:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:menaka_-_marathi:3::~~~android~~`,
        fs:  `cpe:2.3:a:avira:avira_secure_backup:1.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:motor:3::~~~android~~`,
        fs:  `cpe:2.3:a:intel:network_connections:15.2.89.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:nano_digest:3::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:penumbra_emag:3::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.2:mp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:sanctuary_asia:3::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:industry_applications:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:schon%21_magazine:3::~~~android~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.22:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:sunday_indian_oriya:3.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:touriosity_travelmag:3.1::~~~android~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0.280:update28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:travel%2bleisure:3::~~~android~~`,
        fs:  `cpe:2.3:h:barraguard:barracuda_link_balancer:230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:where_atlanta:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.4:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:where_dallas:3.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:woodcraft_magazine:3::~~~android~~`,
        fs:  `cpe:2.3:a:unzoo:unzoo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:magzter:youth_incorporated:3::~~~android~~`,
        fs:  `cpe:2.3:a:ca:release_automation:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:0.9.0`,
        fs:  `cpe:2.3:a:linecorp:line\@:1.0.0:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:0.9.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je020a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:0.9.2`,
        fs:  `cpe:2.3:a:apple:itunes:11.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.0`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.1`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.2`,
        fs:  `cpe:2.3:a:gajim:gajim:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.3`,
        fs:  `cpe:2.3:a:drweb:web_security_space:6.0.0.03100:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.4`,
        fs:  `cpe:2.3:h:lexmark:e240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.5`,
        fs:  `cpe:2.3:a:nginx:nginx:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.6`,
        fs:  `cpe:2.3:a:nobexrc:jazz_lovers_radio:3.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.7`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.8`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.10`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.812:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.11`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.12`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.0.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.13`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.14`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.0.15`,
        fs:  `cpe:2.3:a:git-scm:git:2.14.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1`,
        fs:  `cpe:2.3:a:emc:replication_manager:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0`,
        fs:  `cpe:2.3:o:d-link:dcs-6010l_firmware:1.15.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:alpha1`,
        fs:  `cpe:2.3:a:apache:struts2-showcase:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:alpha2`,
        fs:  `cpe:2.3:o:cisco:catos:5.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:alpha3`,
        fs:  `cpe:2.3:a:apple:safari:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:beta1`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:20-12-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:beta2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:beta3`,
        fs:  `cpe:2.3:a:redhat:kernel_doc:2.4.20-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:beta4`,
        fs:  `cpe:2.3:a:ibm:infosphere_business_glossary:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:rc1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)ja1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.1`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.2`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.3`,
        fs:  `cpe:2.3:a:fourkitchens:ed_readmore:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.4`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.9:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.5`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.7`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.8`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_remote_agent_for_windows_servers:10.1.5629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.1.9`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0:alpha1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.62:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0:alpha2`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0:alpha3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0:beta1`,
        fs:  `cpe:2.3:a:rovicorp:sonic_recordnow:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(27\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0:beta3`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0:beta4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.0:rc1`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.2`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8e_3.8.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.4`,
        fs:  `cpe:2.3:h:hp:jd670a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.5`,
        fs:  `cpe:2.3:a:oracle:mysql_workbench_ce:5.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.2.6`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.4.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.0:beta1`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.0:beta2`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.0:beta3`,
        fs:  `cpe:2.3:a:iss:realsecure_workgroup_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.0:beta4`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.0:rc1`,
        fs:  `cpe:2.3:h:ibm:system_x3630_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.1`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.2`,
        fs:  `cpe:2.3:h:siemens:scalance_s602:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.3`,
        fs:  `cpe:2.3:a:ibm:disposal_and_governance_management_for_it:6.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.4`,
        fs:  `cpe:2.3:a:kofax:virtualrescan:4.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.5`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.8:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.6`,
        fs:  `cpe:2.3:a:adobe:reader:11.0.15:*:*:*:desktop:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.7`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:p07-0029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.3.8`,
        fs:  `cpe:2.3:a:nero:nero:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4:rc1`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.0.61118.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4:rc2`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4:rc3`,
        fs:  `cpe:2.3:a:google:chrome:0.1.42.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4:rc4`,
        fs:  `cpe:2.3:h:cisco:1841_integrated_service_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4.0`,
        fs:  `cpe:2.3:a:hp:ibrix:6.1.251:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4.1`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4.2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4.3`,
        fs:  `cpe:2.3:a:microsoft:excel:2013:*:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4.4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.4.5`,
        fs:  `cpe:2.3:a:vmware:player:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5:rc1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.2`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:9.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.3`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.4`,
        fs:  `cpe:2.3:a:quagga:quagga:0.97.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.6`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.7`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.8`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.9`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.10`,
        fs:  `cpe:2.3:a:counterintuition:counter_intuition:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.11`,
        fs:  `cpe:2.3:h:symantec:nexland_pro800_firewall_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.12`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.5.13`,
        fs:  `cpe:2.3:a:insite:node_basket:7.x-1.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.0`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.28.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.2`,
        fs:  `cpe:2.3:a:radscan:network_audio_system:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.3`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.4`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6a:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.5`,
        fs:  `cpe:2.3:a:salome-platform:salome:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.6`,
        fs:  `cpe:2.3:h:apple:ipod_touch:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.7`,
        fs:  `cpe:2.3:h:hp:color_laserjet_2550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.8`,
        fs:  `cpe:2.3:a:debian:dpkg:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.9`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.6.10`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.7.:rc1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.7.0:-`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.7.1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.7.2`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.7.3`,
        fs:  `cpe:2.3:h:cisco:catalyst_4908g-l3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.7.4`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.7.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.7.6`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.10.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2svc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.10.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.10.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.10.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-50-09:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.10.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.10.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.10.7`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:1.10.8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.347:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04:rc1`,
        fs:  `cpe:2.3:a:drupal:drupal:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04:rc2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.0`,
        fs:  `cpe:2.3:a:xen:xen:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.1`,
        fs:  `cpe:2.3:a:ishikawa_mutsumi:kon2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.2`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.3`,
        fs:  `cpe:2.3:a:aimluck:aipo:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.4`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.5`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.6`,
        fs:  `cpe:2.3:o:iij:seil\%2fx86_firmware:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.7`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.6:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.9`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.10`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.42.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.11`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.12`,
        fs:  `cpe:2.3:a:erlang-solutions:mongooseim:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.04.13`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.10:rc1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:15.10:rc2`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04:rc1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04:rc2`,
        fs:  `cpe:2.3:a:sendmail:sendmail_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04.0`,
        fs:  `cpe:2.3:a:dustincowell:free_simple_cms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04.1`,
        fs:  `cpe:2.3:a:apple:quicktime:6.1.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04.2`,
        fs:  `cpe:2.3:a:attachmate:verastream_process_designer:6.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04.3`,
        fs:  `cpe:2.3:a:synrevoice:safe_arrival:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04.4`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04.5`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04.6`,
        fs:  `cpe:2.3:a:netapp:snapdrive:6.2.1.5029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.04.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.10:rc1`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.10:rc2`,
        fs:  `cpe:2.3:a:python:python:2.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.10.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.10.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.10.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.10.3`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:16.10.4`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:17.04:rc1`,
        fs:  `cpe:2.3:a:serf_project:serf:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:17.04:rc2`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:17.04.0`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:17.04.1`,
        fs:  `cpe:2.3:h:supermicro:x9drh-itf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahara:mahara:17.04.2`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mahasna_batik_project:mahasna_batik:1::~~~android~~`,
        fs:  `cpe:2.3:a:freeradius:freeradius:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maianscriptworld:maian_weblog:4.0`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mail.ru:mail.ru_dating:3.0::~~~android~~`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mail_on_update_project:mail_on_update:5.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:phplist:phplist:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mail_on_update_project:mail_on_update:5.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:automake:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailbird:mailbird:2.0.16.0`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailcwp_project:mailcwp:1.100::~~~wordpress~~`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.00:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:db2:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.01:-:enterprise`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.1:-:enterprise`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.2:-:enterprise`,
        fs:  `cpe:2.3:a:sympa:sympa:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.02:-:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:5.0.335.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.2:-:professional`,
        fs:  `cpe:2.3:a:frontrange:goldmine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.2:a:professional`,
        fs:  `cpe:2.3:a:ibm:rational_requisitepro:2.1.1063:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.03:-:enterprise`,
        fs:  `cpe:2.3:a:redhat:subscription_asset_manager:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.04:-:enterprise`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.5:-:professional`,
        fs:  `cpe:2.3:a:isc:bind:9.8.3:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.6:-:professional`,
        fs:  `cpe:2.3:a:keepass:keepass:0.99:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.7:-:professional`,
        fs:  `cpe:2.3:a:utsa:utsa_mobile:1.4.21:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.8:-:standard`,
        fs:  `cpe:2.3:a:netscape:commerce_server:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.9:-:standard`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.17:-:professional`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.18:-:professional`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.19:-:professional`,
        fs:  `cpe:2.3:a:netscape:collabra_server:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.21:-:enterprise`,
        fs:  `cpe:2.3:a:advancedsearchbar:advanced_search_bar:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.22:-:enterprise`,
        fs:  `cpe:2.3:a:gollum_project:gollum:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.23:-:enterprise`,
        fs:  `cpe:2.3:a:irdeto:pisys:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.24:-:enterprise`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.0.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.25:-:enterprise`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.901:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.26:-:enterprise`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.06.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.51:-:professional`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.52:-:professional`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.9:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.53::professional`,
        fs:  `cpe:2.3:a:adobe:premiere_elements_templates:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.54:-:professional`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_400_color_mfp_m475:ce864a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.70:-:professional`,
        fs:  `cpe:2.3:a:skype:skype:3.8.0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.71:-:professional`,
        fs:  `cpe:2.3:a:atlassian:jira:2.6:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.71:-:standard`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.18:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.72:-:professional`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.72:-:standard`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd664a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.73:-:professional`,
        fs:  `cpe:2.3:a:openbsd:opensmtpd:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.74:-:professional`,
        fs:  `cpe:2.3:a:docker:docker:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.75:-:professional`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.13:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.76::professional`,
        fs:  `cpe:2.3:a:i-doit:i-doit:0.9.9:7:*:*:open:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.77:-:professional`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.78:-:professional`,
        fs:  `cpe:2.3:o:ruckuswireless:zoneflex_2942__firmware:9.6.0.0.267:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.79:-:professional`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.90:-:standard`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.91:-:standard`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.92:-:standard`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.13.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.93:-:standard`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.94:-:standard`,
        fs:  `cpe:2.3:a:rpm:rpm:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.95:-:standard`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.96:-:standard`,
        fs:  `cpe:2.3:a:ibm:tivoli_remote_control:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.97:-:standard`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.98:-:standard`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.701:-:standard`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.702:-:standard`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.703:-:standard`,
        fs:  `cpe:2.3:a:skype:skype:2.6.0.74:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.704:-:standard`,
        fs:  `cpe:2.3:h:hp:scanjet_5590:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.981:-:standard`,
        fs:  `cpe:2.3:a:sun:openoffice.org:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.983:-:standard`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.985:-:standard`,
        fs:  `cpe:2.3:a:x:libxt:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:1.986:-:standard`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.0:-:enterprise`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.0:-:pro`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.01:-:enterprise`,
        fs:  `cpe:2.3:a:mcafee:scan_engine:4.4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.01:-:pro`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.02:-:enterprise`,
        fs:  `cpe:2.3:h:hp:0235a395:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.02:-:pro`,
        fs:  `cpe:2.3:a:krisonav:krisonav:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.03:-:enterprise`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.03:-:pro`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.04:-:enterprise`,
        fs:  `cpe:2.3:a:inria:ocaml:3.07:pl2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.04:-:pro`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.5:-:enterprise`,
        fs:  `cpe:2.3:a:ca:license_software:1.61.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.5:-:pro`,
        fs:  `cpe:2.3:a:lenovo:shareit:3.0.18_ww:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.6:-:enterprise`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.1.10.800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.6:-:pro`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.10:-:enterprise`,
        fs:  `cpe:2.3:a:openafs:openafs:1.3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.10:-:pro`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.11:-:enterprise`,
        fs:  `cpe:2.3:a:gnome:glib:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.11:-:pro`,
        fs:  `cpe:2.3:a:setseed:setseed_cms:5.8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.12:-:enterprise`,
        fs:  `cpe:2.3:a:php:php:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.12:-:pro`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.13:-:enterprise`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.397:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.13:-:pro`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.14:-:enterprise`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.14:-:pro`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.51:-:enterprise`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0a4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.51:-:pro`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.52:-:enterprise`,
        fs:  `cpe:2.3:h:ibm:security_access_manager_for_web_appliance:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.52:-:pro`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.53:-:enterprise`,
        fs:  `cpe:2.3:a:rocomotion:p_link_compact:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.53:-:pro`,
        fs:  `cpe:2.3:a:gajennings:this:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.61:-:enterprise`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.61:-:pro`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:7.02.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.61:-:standard`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.61:-:std`,
        fs:  `cpe:2.3:a:elipse:power:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.62:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.1:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.62:-:pro`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(2\)xf5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.62:-:standard`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.62:-:std`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.63:-:enterprise`,
        fs:  `cpe:2.3:a:wdc:diagnostics:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.63:-:pro`,
        fs:  `cpe:2.3:a:redhat:network_satellite_server:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:3.63:-:std`,
        fs:  `cpe:2.3:a:band:band_-group_sharing_\&amp;_planning:3.2.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.0:-:enterprise`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.0:-:pro`,
        fs:  `cpe:2.3:a:gnome:byzanz:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.0:-:standard`,
        fs:  `cpe:2.3:a:iscripts:eswap:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.0:-:std`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp1:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.1:-:enterprise`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:x64-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.01:-:enterprise`,
        fs:  `cpe:2.3:a:radscan:network_audio_system:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.1:-:pro`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.01:-:pro`,
        fs:  `cpe:2.3:h:supermicro:x9dr7-tf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.01:-:standard`,
        fs:  `cpe:2.3:a:apache:commons_collections:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.1:-:standard`,
        fs:  `cpe:2.3:o:ibm:aix:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.1:-:std`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.01:-:std`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.11:-:enterprise`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.11:-:pro`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:4.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.12:-:enterprise`,
        fs:  `cpe:2.3:a:businessobjects:infoview:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.12:-:pro`,
        fs:  `cpe:2.3:h:intel:express_550t:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.13:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.1\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.13:-:pro`,
        fs:  `cpe:2.3:a:oracle:jd_edwards_enterpriseone_tools:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.13:-:standard`,
        fs:  `cpe:2.3:a:zend:zendto:4.09-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.13:-:std`,
        fs:  `cpe:2.3:a:iss:site_protector_security_fusion:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.14:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.14:-:pro`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.14:-:standard`,
        fs:  `cpe:2.3:a:pinnaclesys:studio:14.0.0.7255:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.14:-:std`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.15:-:enterprise`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.15:-:pro`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.16:-:enterprise`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.16:-:pro`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:08.0.01j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.16:-:standard`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.16:-:std`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.17:-:enterprise`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:pre8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.17:-:pro`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.17:-:standard`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.17:-:std`,
        fs:  `cpe:2.3:a:mcafee:virex:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.22:-:enterprise`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.22:-:pro`,
        fs:  `cpe:2.3:a:netscape:publishingxpert:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.22:-:standard`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.22:-:std`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.766:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.23:-:enterprise`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.23:-:pro`,
        fs:  `cpe:2.3:a:apache:axis2:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.23:-:std`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.24:-:enterprise`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.24:-:pro`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.24:-:std`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.22:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.25:-:enterprise`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.25:-:pro`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.25:-:std`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_400_color_mfp_m475:ce863a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:4.26:-:pro`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailenable:mailenable:6.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailgod:letters_to_god_-_soc._network:0.1::~~~android~~`,
        fs:  `cpe:2.3:h:cisco:ons_15310-ma_sonet_multiservice_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:0.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:d-link:dcs-5030l_firmware:1.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:0.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:0.9.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:websense:websense_email_security:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:polycom:hdx_8004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:1.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:1.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:unicenter_mq_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:1.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:networker:8.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:1.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:python:pillow:2.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:1.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gwos:groundwork_monitor:6.7.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(1\)sv1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redmine:redmine:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:clonemonster:social_book_facebook_clone_monster:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.0.9.5::~~~wordpress~~`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:supermicro:h8dcl-6f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.28:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:001n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:informatica:powerconnect_for_ibm_mqseries:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd3.mxxx0_firmware:1.24.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.428:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:huawei:s9306_firmware:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:clutter_project:clutter:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mauro_lorenzutti:wfqbe:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:freedesktop:libdbus:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:commons_fileupload:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.95.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53_91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:arcserve_backup_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:p98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netcreators:irfaq:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.14361:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:0.99.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.5.9.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6:beta:~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.8:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_21.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sap:sapseculib:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.10:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:quest:benchmark_factory_for_databases:6.1.1.228:*:*:*:trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailpoet:mailpoet_newsletters:2.6.11:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailtraq:mailtraq:2.17.3.3150`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:6.0.3\(33\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.0.0`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.33:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.958.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.1.1`,
        fs:  `cpe:2.3:h:supermicro:x9drd-7ln4f-jbod:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.1.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.1.3`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.2`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.d4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.3.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.3.2`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.3.3`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mailup:wp-mailup:1.21`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:makeitpossible:cuanto_conoces_a_un_amigo:2::~~~android~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:makina-corpus:soappy:0.12.5`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.2.2:patch_level_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2000::~~~perl~~`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:10.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2001::~~~perl~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.648:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2002::~~~perl~~`,
        fs:  `cpe:2.3:a:python_bugzilla_project:python-bugzilla:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2003::~~~perl~~`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2010::~~~perl~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2011::~~~perl~~`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2012::~~~perl~~`,
        fs:  `cpe:2.3:o:apple:apple_tv:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2013::~~~perl~~`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2014::~~~perl~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2016::~~~perl~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2017::~~~perl~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p196:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2018::~~~perl~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2019::~~~perl~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malcolm_nooning:pirpc:0.2020::~~~perl~~`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malware_finder_plugin_project:malware_finder:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malwarebytes:malwarebytes_anti-exploit:1.04.1.1012::~~consumer~~~`,
        fs:  `cpe:2.3:a:quest:intrust:10.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:malwarebytes:malwarebytes_anti-malware:2.02::~~consumer~~~`,
        fs:  `cpe:2.3:a:ibm:java:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mama:mama.cn:1.02::~~~android~~`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manageengine:netflow_analyzer:-`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manageengine:oputils:7.0`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6\(3\)_b26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mandiant:highlighter:1.1.3`,
        fs:  `cpe:2.3:a:php:php:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mandrakesoft:mandrake_lam-runtime:-`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mandrakesoft:mandrake_lam-runtime:7.0.6.2mdk`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:-`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1018:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:6.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:6.1`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:7.0`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:7.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:7.2`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:7.3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:8.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.954.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:8.1`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.14:ga6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:8.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110905:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:9.0`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:9.1`,
        fs:  `cpe:2.3:h:axis:2460_network_dvr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:9.2`,
        fs:  `cpe:2.3:a:esri:arcpad:7.0.0.156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:10.0`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.905:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:10.1`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:10.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:2006`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:2007`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:2007.1`,
        fs:  `cpe:2.3:a:redhat:uberfire:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:2008.0`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:2008.0:x86_64`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:2008.1`,
        fs:  `cpe:2.3:a:manageengine:oputils:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:2008.1:x86_64`,
        fs:  `cpe:2.3:a:t1lib:t1lib:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:cs2.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux:cs3.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux_corporate_server:-`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux_corporate_server:1.0.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux_corporate_server:2.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux_corporate_server:3.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linux_corporate_server:4.0`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linuxsoft:-`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_linux:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandrakesoft:mandrake_linuxsoft_2007:-`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mandrakesoft:mandrake_multi_network_firewall:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p63:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mandrakesoft:mandrake_multi_network_firewall:2.0`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mandrakesoft:mandrake_multi_network_firewall:8.2`,
        fs:  `cpe:2.3:a:mediafire:mod_quick_form:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mandrakesoft:mandrake_single_network_firewall:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mandrakesoft:mandrake_single_network_firewall:7.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:5.3:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:business_server:1.0`,
        fs:  `cpe:2.3:a:sayakbanerjee:sticky_notes:0.2.27052012.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:corporate_server:3.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-28f-ei_ls-3600-28f-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:corporate_server:3.0::x86_64`,
        fs:  `cpe:2.3:a:git-scm:git:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:corporate_server:4.0`,
        fs:  `cpe:2.3:a:brocade:san_health_diagnostics_capture:3.1.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:corporate_server:4.0::x86_64`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:enterprise_server:5.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:linux:-`,
        fs:  `cpe:2.3:a:php:php:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:linux:2008.0`,
        fs:  `cpe:2.3:a:gnome:gdk-pixbuf:2.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:linux:2008.0::x86_64`,
        fs:  `cpe:2.3:a:redhat:pam_smb:1.1.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:linux:2008.1`,
        fs:  `cpe:2.3:a:adobe:winsoft_linguistics_plugin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:linux:2008.1::x86_64`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:linux:2009.0`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mandriva:multi_network_firewall:2.0`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:3.2.6:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manga_facts_project:manga_facts:1::~~~android~~`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.18.0`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.0`,
        fs:  `cpe:2.3:a:hummingbird:exceed:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.0:a1`,
        fs:  `cpe:2.3:a:stackideas:komento:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.0:a2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.0:rc1`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.1`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.2`,
        fs:  `cpe:2.3:a:u.s._army_cerdec:armadillo:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.3`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.4`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.12:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:0.19.5`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_113:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0:a1`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0:a2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0:a3`,
        fs:  `cpe:2.3:a:avery:avery_wizard_for_microsoft_office_word_2003:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0:rc1`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0:rc2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.3.92a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0:rc3`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.2.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0:rc4`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.1:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.0:rc5`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.1`,
        fs:  `cpe:2.3:a:buffalotech:whr-g54s_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.3`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:sp1:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.4`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.5`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.6`,
        fs:  `cpe:2.3:a:logitech:lws_webcam_software:13.30.1379.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.7`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.206.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.8`,
        fs:  `cpe:2.3:o:huawei:s9312_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.0.9`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(4\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.0:a1`,
        fs:  `cpe:2.3:a:module-signature_project:module-signature:0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.0:a2`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.0:a3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.0:a4`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:2.0.158.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.0:rc2`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.0:rc3`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_.net_server:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.1`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.2`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.4`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.5`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.6`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_endpoint_manager:8.2:patch3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.8`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.1.9`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.0:a1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.0:a2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.0:a3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.0:rc1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.0:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.0:rc2`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.1`,
        fs:  `cpe:2.3:a:ncp:vpn_secure_client:9.31:-:juniper:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.3`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.6b.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.4`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.7:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.7`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l18erm-bb1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.8`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2\(0.793\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.9`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.10`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.11`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp2b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.12`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.13`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.14`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.15`,
        fs:  `cpe:2.3:a:symantec:mail_security:5.0.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.16`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.18`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.19`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.2.20`,
        fs:  `cpe:2.3:a:digium:asterisk:11.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.0:beta1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.0:beta2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.0:beta3`,
        fs:  `cpe:2.3:a:seopanel:seo_panel:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:msde:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.0:rc2`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt_2010_language_pack:18.0.59.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.1`,
        fs:  `cpe:2.3:a:altiris:software_virtualization_agent:2.1.2095:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.2`,
        fs:  `cpe:2.3:a:gajim:gajim:0.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.3`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.5`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.6`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.7`,
        fs:  `cpe:2.3:a:compaq:insight_management_agent:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.8`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.22.178:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.10`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:1.3.11`,
        fs:  `cpe:2.3:a:microsoft:hyperlink_object_library:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.0.0:beta1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.0.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:0.1.38.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.0.0:beta3`,
        fs:  `cpe:2.3:a:logilab:logilab-common:0.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.0.0:rc1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.0.0:rc2`,
        fs:  `cpe:2.3:a:ca:unicenter_dsm_agent_\&#43;_basic_inventory_plugin:11.2.4000.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.0.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.1.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.1.1`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24:rc1.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.1.2`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.1.3`,
        fs:  `cpe:2.3:a:lostpassword:passware_kit:10.0.1763:*:*:*:professional_demo:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.2.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.2.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.15:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.2.2`,
        fs:  `cpe:2.3:h:hp:0235a20p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.2.4`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.3.0`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:unstable4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.3.1`,
        fs:  `cpe:2.3:a:oracle:diagnostics:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.3.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ixe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.4.0`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.3.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.4.1`,
        fs:  `cpe:2.3:a:microsoft:windows_media_format_runtime:11:*:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.4.2`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.5.0`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mantisbt:mantisbt:2.5.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1685.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:6.x-1.0:rc2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:6.x-1.0:rc3`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:p06-0024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:6.x-1.0:rc4`,
        fs:  `cpe:2.3:a:ip-phone-smart:smartalk:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:6.x-1.x:dev`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-2000d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:7.x-1.0`,
        fs:  `cpe:2.3:a:hp:hp-ux_containers:a.03.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:7.x-1.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:7.x-1.2`,
        fs:  `cpe:2.3:a:adobe:premiere_pro_cs4:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manuel_garcia:galleryformatter:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:hp:creativeprojects_calendartemplates1:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manugistics:rfq:7.2.2.0`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manugistics:scpo_runtime:7.1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:manugistics:webworks_foundation:7.2.2.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mapilab:advanced_security_for_outlook:1.4.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gw_3241:2.1\(1.22\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mapsmarker:leaflet_maps_marker_plugin:0.0.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.82.7`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.82.7.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.82.7.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.82.7.3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.82.7.4`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.82.7.5`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.92.9`,
        fs:  `cpe:2.3:a:arclogics:cch_teammate_nt_services:9.1.0.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.92.9.1`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.92.9.2`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.92.9.3`,
        fs:  `cpe:2.3:o:vmware:esx:1.5.2:patch3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.92.17`,
        fs:  `cpe:2.3:a:jenkins:git:2.4.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.92.17.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.92.17.2`,
        fs:  `cpe:2.3:o:d-link:dir-605l_firmware:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_deslauriers:software-properties:0.92.17.3`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.0`,
        fs:  `cpe:2.3:a:php:php:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.01`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:6.29.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.02`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.05`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r5:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.06`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.07`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.08`,
        fs:  `cpe:2.3:a:wireshark:wireshark:0.99.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.09`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.10`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.11`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.12`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.14`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.16`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.17`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.50.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.18`,
        fs:  `cpe:2.3:a:ibm:connections:2.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.19`,
        fs:  `cpe:2.3:a:openstack:swift:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_lehmann:rxvt-unicode:9.20`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1659.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marc_vertes:txt2man:1.5.5`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-backup:0.1.0`,
        fs:  `cpe:2.3:a:alfabank:alfa-bank:5.5.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-backup:0.2.0`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-backup:0.2.1`,
        fs:  `cpe:2.3:a:hp:product_assistant:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-backup:0.2.2`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-backup:0.2.3`,
        fs:  `cpe:2.3:a:isc:bind:9.9.9:s1rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-backup:0.3.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-backup:0.3.1`,
        fs:  `cpe:2.3:a:school_administration_project:school_administration:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:jabber:-:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(5\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:typo3:flow:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:drupal:drupal:8.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71-\/f:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.323.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.10.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.1.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:anti-virus_for_the_enterprise:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00-\/a:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dell:printer_software:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.17.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.4:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.17.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.17.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:up2date:3.1.23-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.19.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marcel_brinkkemper:lazyest-gallery:1.1.21::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:march-hare:cvs_suite:2.5.03`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:march-hare:cvs_suite:2008`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:march-hare:cvs_suite:2009:pre-release`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:march-hare:cvsnt:2.0.58`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.819:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:march-hare:cvsnt:2.5.01`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:march-hare:cvsnt:2.5.02`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:march-hare:cvsnt:2.5.03`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:marconi:asx-1000:-`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.0.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/h:marconi:esr-5000_enterprise_switch:-`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:marconi:forethought:-`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marconi:forethought:6.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marconi:forethought:7.1`,
        fs:  `cpe:2.3:a:dotnetblogengine:blogengine.net:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marek_gutkowski:mod_chroot:0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marek_gutkowski:mod_chroot:0.5`,
        fs:  `cpe:2.3:a:yahoo:yui:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marek_jasinski:freecommander:2009.2`,
        fs:  `cpe:2.3:a:openbsd:opensmtpd:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marekkis:watermark:0.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:debian:reprepro:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.41`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:5.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.42`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.44`,
        fs:  `cpe:2.3:a:eeye:retina:5.13.0.2389:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.47`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.49`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.9.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.50`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.51`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.53`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.55`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.60`,
        fs:  `cpe:2.3:a:sun:java_system_identity_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.61`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.39.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.1.62`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2005-07-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.0`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2015-ac-ovs-aw-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.1`,
        fs:  `cpe:2.3:a:oracle:industry_applications:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.3`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r13b04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.6`,
        fs:  `cpe:2.3:a:google:chrome:9.0.596.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.7`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.8`,
        fs:  `cpe:2.3:a:google:chrome:6.0.449.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.9`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.10`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.11`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.2.12`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.3.0`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.3.1`,
        fs:  `cpe:2.3:a:acronis:disk_director_server:10.0.2064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.3.2`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2104h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.3.3`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.3.4`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.7-p1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.3.5`,
        fs:  `cpe:2.3:a:gnu:gzip:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.3.6`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30355:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.3.7`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.3f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.20`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.21`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)ya:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.22`,
        fs:  `cpe:2.3:a:microsoft:access:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.23`,
        fs:  `cpe:2.3:a:digium:asterisk:11.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.24`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.25`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.33`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.33:a`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.34`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.35`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.40`,
        fs:  `cpe:2.3:h:seagate:wireless_plus_mobile_storage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.43`,
        fs:  `cpe:2.3:a:hp:openmail:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.46`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.47`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.48`,
        fs:  `cpe:2.3:a:isc:bind:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.50`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.51`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:5.5.54`,
        fs:  `cpe:2.3:a:sonicwall:aventail_webifiers:10.1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.0`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.1`,
        fs:  `cpe:2.3:a:divx:codec:6.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.2`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.3`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.4`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2003_server:6.3.1705:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.5`,
        fs:  `cpe:2.3:a:yellowbook:yellow_pages_local_search:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.6`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.7`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.8`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.9`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.10`,
        fs:  `cpe:2.3:a:kajona:kajona:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.11`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.12`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.13`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.14`,
        fs:  `cpe:2.3:a:nsoftware:unitronics_uniopc:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.15`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.16`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.17`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.18`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.19`,
        fs:  `cpe:2.3:a:sap:hybris:5.5.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.20`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.21`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.22`,
        fs:  `cpe:2.3:h:hp:jd433a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.23`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.24`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.26`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.28`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.0.29`,
        fs:  `cpe:2.3:a:paperthin:commonspot_content_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.0`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.1`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.2`,
        fs:  `cpe:2.3:a:contenido:contendio:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.3`,
        fs:  `cpe:2.3:a:ca:server_protection_suite:r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.4`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:3.0.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.5`,
        fs:  `cpe:2.3:a:microsoft:sql_server_desktop_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.6`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.7`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.8`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1007.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.9`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.10`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.11`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.12`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.13`,
        fs:  `cpe:2.3:a:dadabik:dadabik:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.15`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.16`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.17`,
        fs:  `cpe:2.3:a:sysaid:sysaid:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.18`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.19`,
        fs:  `cpe:2.3:a:vmware:workstation:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.20`,
        fs:  `cpe:2.3:h:nisuta:ns-wir300n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.1.22`,
        fs:  `cpe:2.3:a:drupal:drupal:6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.2.0`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.2.1`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.2.2`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mariadb:mariadb:10.2.3`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:9.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marinet:marinet_cms:-`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_burdett:securelogin:7.x-1.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s7506e-v:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_burdett:securelogin:7.x-1.1`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_burdett:securelogin:7.x-1.2`,
        fs:  `cpe:2.3:a:novell:client:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_burdett:securelogin:7.x-1.3`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:4.53.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_burdett:securelogin:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_burns:ldoce:0.0.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_evans:fog-dragonfly:0.8.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_evans:fog-dragonfly:0.8.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:cisco:clean_access_agent:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:3.0`,
        fs:  `cpe:2.3:a:apache:commons_fileupload:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:3.0.1`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.115:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:3.1`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.3.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:3.2`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.6:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:3.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.223.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:4.0`,
        fs:  `cpe:2.3:a:oracle:industry_applications:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:4.0.1`,
        fs:  `cpe:2.3:a:drupal:drupal:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:4.0.2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:4.1`,
        fs:  `cpe:2.3:a:smarty:smarty:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:5.0`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:5.0.1`,
        fs:  `cpe:2.3:a:apache:hadoop:2.0.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:5.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:5.1.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3020_concentrator:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_pilgrim:feedparser:5.1.2`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_theunissen:views_lang_switch:7.x-1.0`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_theunissen:views_lang_switch:7.x-1.1`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mark_theunissen:views_lang_switch:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:markdown_on_saved_improved_project:markdown_on_saved_improved:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:apollo_domain_os:sr10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.1`,
        fs:  `cpe:2.3:h:moxa:iologic_e2262:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.2`,
        fs:  `cpe:2.3:h:emc:ds-32m_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.3`,
        fs:  `cpe:2.3:a:nagios:nagios:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.4`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.1.2.10:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.6`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.7`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.8`,
        fs:  `cpe:2.3:a:schneems:wicked:0.1.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.0.9`,
        fs:  `cpe:2.3:a:citadel:ux:5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.0`,
        fs:  `cpe:2.3:a:tablefield_project:tablefield:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.1`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.2`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.3`,
        fs:  `cpe:2.3:a:tumbleweed:validation_authority:4.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.4`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.5`,
        fs:  `cpe:2.3:o:vmware:esx:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.6`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.7`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.11:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.8`,
        fs:  `cpe:2.3:a:adobe:freehand_mx:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.1.9`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.03.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.2`,
        fs:  `cpe:2.3:a:kingsoftsecurity:kingsoft_antivirus:2010.04.26.648:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.5`,
        fs:  `cpe:2.3:a:hp:d4100_help:70.0.260.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.5c`,
        fs:  `cpe:2.3:a:oracle:universal_work_queue:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.6`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.7`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.8`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.9`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.2.10`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.3.0`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.3.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.3.2`,
        fs:  `cpe:2.3:a:geodesicsolutions:geocore_max:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.3.3`,
        fs:  `cpe:2.3:a:factbites:factbot:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.3.4`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.0.3.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.3.5`,
        fs:  `cpe:2.3:a:aol:aim:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marked_project:marked:0.3.6`,
        fs:  `cpe:2.3:a:mahara:mahara:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketo_ma_project:marketo_ma:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0`,
        fs:  `cpe:2.3:a:transifex:transifex:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0:-:~~pro~~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.2`,
        fs:  `cpe:2.3:a:ibm:forms_viewer:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.3`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.4`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.6`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.7`,
        fs:  `cpe:2.3:a:siemens:comos:10.0.3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.8`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.9`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.10`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.11`,
        fs:  `cpe:2.3:h:hp:jg519a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.12`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marketpress:backwpup_plugin:3.0.13`,
        fs:  `cpe:2.3:a:omeka:omeka:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marksdailyapple:mark%27s_daily_apple_forum:2.9.4.3::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.33:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:markus_blaschke:tq_seo:5.0.0`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.82:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:markus_blaschke:tq_seo:5.0.1`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:markwilson:classify_for_outlook:8.8.31.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maroyaka_simple_board_project:maroyaka_simple_board:-`,
        fs:  `cpe:2.3:a:newstatpress_project:newstatpress:0.9.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_lee:multi-lingual_e-commerce_system:0.1`,
        fs:  `cpe:2.3:a:microsoft:works:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_lee:multi-lingual_e-commerce_system:0.2`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_lee:multi-lingual_e-commerce_system:0.11`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:0.1.0:a1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(25e\)jaz1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:0.1.0:b`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:0.2.0`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:1.0.0:b1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:1.0.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:1.1.0:a1`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:1.1.0:a2`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.12.1203:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:1.1.0:b1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:1.1.0:b2`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.226:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_nagy:bind-dyndb-ldap:1.1.0:rc1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.3`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf022:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.4`,
        fs:  `cpe:2.3:a:mcafee:quickclean:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.55.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.7`,
        fs:  `cpe:2.3:a:apache:libcloud:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.8`,
        fs:  `cpe:2.3:a:qemu:qemu:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.9`,
        fs:  `cpe:2.3:a:qualcomm:gobi_single_installer_package_for_zte:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.10`,
        fs:  `cpe:2.3:o:emc:data_domain:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martin_pitt:jockey:0.9.7-0ubuntu7.11`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.42`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.43`,
        fs:  `cpe:2.3:a:prosoft-technology:radiolinx_controlscape:6.00.040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.44`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.45`,
        fs:  `cpe:2.3:a:ixiacom:ixialicensing:2.50.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.46`,
        fs:  `cpe:2.3:a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.47`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.48`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.49`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:martinicreations:passmanlite_password_manager:1.50`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvell:mrvlusgtracking:1.0.0`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.10.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:marvell:mrvlusgtracking:1.0.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvell:mrvlusgtracking:1.0.7`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.0`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.501:mr9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.0:beta1`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.0:beta2`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.0:rc1`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.2`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.20.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.3`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.10:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.4`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.5`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.6`,
        fs:  `cpe:2.3:a:seebeyond:windowsinstallersetup:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.7`,
        fs:  `cpe:2.3:a:ibm:infosphere_metadata_workbench:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.8`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-3.0`,
        fs:  `cpe:2.3:h:symantec:gateway_security_360r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-3.0:alpha1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.0.899:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-3.0:beta1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-3.1`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:marvil07:vote_up_down:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.11_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:1.20`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:1.40`,
        fs:  `cpe:2.3:h:supermicro:x9drff-7t\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.00`,
        fs:  `cpe:2.3:o:d-link:dcs-931l_firmware:1.13.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.10`,
        fs:  `cpe:2.3:a:bea:weblogic_workshop:8.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.20`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:10.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.30`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:9.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.40`,
        fs:  `cpe:2.3:a:ibm:db2:11.1.0.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.50`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.60`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.70`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:2.72`,
        fs:  `cpe:2.3:a:digium:asterisk:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:3.00`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:15.0\(935\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:3.10`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:3.40`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:3.60`,
        fs:  `cpe:2.3:a:php.s3.to:php-i-board:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:3.70`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masahiko_watanabe:apsaly:3.74`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mascov:csapp_-_colegio_san_agustin:1::~~~android~~`,
        fs:  `cpe:2.3:a:livetecs:timeline:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:masquito2013:masquito_blogger:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mass_gaming_tv_project:mass_gaming_tv:1::~~~android~~`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.80:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:9.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:umn:mapserver:5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:alphaserver_sc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.0:beta:~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.0:betax:~~~wordpress~~`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mikejolley:download_monitor:1.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:citrix:xenapp:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:analytics_appmeasurement_for_flash_library:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:apc:ap9606:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:javafx:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ups:worldship_upsvcmm:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:pa-risc:-:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:unified_ip_conference_station_7936:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:libsocialweb:0.25.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.5:beta1:~~~wordpress~~`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.5:beta2:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:content_navigator:2.0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_cdm_application_software:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.6:beta:~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:warehouse_builder:11.1.0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30354:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jjwwebdesign:phpbookingcalendar:1.0c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(3c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.40:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.8:beta:~~~wordpress~~`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matchalabs:metaslider:2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathew_winstone:mobile_tools:6.x-2.0`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:4.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathew_winstone:mobile_tools:6.x-2.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathew_winstone:mobile_tools:6.x-2.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathew_winstone:mobile_tools:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:keepass:password_safe:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathijs_koenraadt:search_api_sorts:7.x-1.0`,
        fs:  `cpe:2.3:a:toocharger:smartblog:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathijs_koenraadt:search_api_sorts:7.x-1.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathijs_koenraadt:search_api_sorts:7.x-1.2`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathijs_koenraadt:search_api_sorts:7.x-1.3`,
        fs:  `cpe:2.3:a:iss:realsecure_workgroup_manager:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathijs_koenraadt:search_api_sorts:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.0.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.0.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.1.0`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.2.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.3.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.4.0`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.5.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:8.5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.6.0`,
        fs:  `cpe:2.3:h:linksys:wap11:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.7.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.7.1`,
        fs:  `cpe:2.3:a:teradata:index_wizard:13.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.7.2`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.8.0`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:4.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.8.1`,
        fs:  `cpe:2.3:h:avaya:sg5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.8.2`,
        fs:  `cpe:2.3:a:dell:xtalk_management_console:5.4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.9.0`,
        fs:  `cpe:2.3:a:f5:big-ip_enterprise_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.9.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.10.0`,
        fs:  `cpe:2.3:a:microsoft:office_multilingual_user_interface_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.11.0`,
        fs:  `cpe:2.3:a:cisco:packet_tracer:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.12.0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.12.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p459:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.13.0`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.72:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.14.0`,
        fs:  `cpe:2.3:a:adobe:breeze_licensed_server:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.15.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.16.0`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.17.0`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.17.1`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.18.0`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.18.1`,
        fs:  `cpe:2.3:a:npmjs:node_packaged_modules:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.19.0`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.20.0`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.21.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.21.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:17.0.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.22.0`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.23.0`,
        fs:  `cpe:2.3:a:adobe:camera_raw:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.24.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.24.1`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.0.60401.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.25.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.26.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1012:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:0.27.0`,
        fs:  `cpe:2.3:a:janetter:janetter:3.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.0.0`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:2.0.0.0.294-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.0.1`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.1.0`,
        fs:  `cpe:2.3:h:hp:3com_router:5232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.1.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.2.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.3.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.4.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.5.0`,
        fs:  `cpe:2.3:a:monotone:monotone:0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.5.2`,
        fs:  `cpe:2.3:a:microsoft:iis:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.6.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.7.0`,
        fs:  `cpe:2.3:a:apache:poi:3.8:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:1.7.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.0.0`,
        fs:  `cpe:2.3:a:hp:mercury_quality_center:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.1.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.1.1`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_tx9000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.2.0`,
        fs:  `cpe:2.3:a:preplogic:exam_a\&#43;_essentials_\(220-701\):3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.3.0`,
        fs:  `cpe:2.3:a:longluntan:gzonerc_-_the_rc_hobby_hub:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.4.0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.5-146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.4.1`,
        fs:  `cpe:2.3:a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.4.2`,
        fs:  `cpe:2.3:a:vmware:tools:3.1.2.12031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.5.0`,
        fs:  `cpe:2.3:a:rack_project:rack:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.6.0`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_4_firmware:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:2.7.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.0.0`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.1.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.1.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:3.6.3e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.1.3`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.1.4`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.2.0`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.2.1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.3.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.238:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.4.0`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.5:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.4.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1682.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.5.0`,
        fs:  `cpe:2.3:a:jan_schutze:truc:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.5.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.5.2`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.5.3`,
        fs:  `cpe:2.3:a:ibm:infosphere_metadata_workbench:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.6.0`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.7.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.8.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.8.1`,
        fs:  `cpe:2.3:h:cisco:sf300-48p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.9.0`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.9.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.9.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.9.3`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.10.0`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.10.1`,
        fs:  `cpe:2.3:a:moodle:moodle:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.10.2`,
        fs:  `cpe:2.3:a:drupal:drupal:7.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.10.3`,
        fs:  `cpe:2.3:a:nghttp2:nghttp2:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.11.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.11.1`,
        fs:  `cpe:2.3:a:ibm:jre:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.11.2`,
        fs:  `cpe:2.3:h:hp:jf236a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.11.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.11.4`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.11.5`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.12.0`,
        fs:  `cpe:2.3:h:huawei:s5300si:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.12.1`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.12.2`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.0.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.12.3`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.13.0`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.13.1`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.6.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.13.2`,
        fs:  `cpe:2.3:a:ca:unicenter_service_delivery:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.13.3`,
        fs:  `cpe:2.3:a:openstack:keystone:juno-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.14.0`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.14.1`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-3.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.14.2`,
        fs:  `cpe:2.3:a:logitech:video_enumerator:10.51.2027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.15.0`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.16.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.16.1`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.3:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.16.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.16.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.16.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.16.5`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.17.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.18.0`,
        fs:  `cpe:2.3:a:sun:sdk:1.3_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.18.1`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mathjs:math.js:3.19.0`,
        fs:  `cpe:2.3:a:microsoft:ie:5.50.4134.0100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrikonopc:dnp3_opc_server:1.2.3`,
        fs:  `cpe:2.3:a:apache:wicket:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrikonopc:matrikonopc_a%26e_historian:1.0.0.0`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrikonopc:matrikonopc_security_gateway:1.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrikonopc:scada_dnp3_opc_server:1.2.0`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:matrikonopc:scada_dnp3_opc_server:1.2.2.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrix42:service_store:5.3:sp3`,
        fs:  `cpe:2.3:a:samba:samba:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrixssl:matrixssl:3.8.2`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrixssl:matrixssl:3.8.5`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrixssl:matrixssl:3.8.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matroska:libebml:1.3.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:matroska:libmatroska:1.4.3`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matrox:dualhead2go:1.3.0.6`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.28`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.29`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.30`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.31`,
        fs:  `cpe:2.3:a:mozilla:mozilla_suite:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.32`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.33`,
        fs:  `cpe:2.3:a:google:v8:4.7.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.34`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_server:3.6:ecf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.35`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.36`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.92.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.37`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.38`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.39`,
        fs:  `cpe:2.3:a:saurabh_gupta:tiny_server:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.40`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.41`,
        fs:  `cpe:2.3:a:apport_project:apport:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.42`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.43`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.44`,
        fs:  `cpe:2.3:a:ibm:infosphere_replication_server:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.44:test1`,
        fs:  `cpe:2.3:a:cocodigi:martial_arts_battle_card:1.0.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.44:test2`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.44:test3`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.44:test4`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.45`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.46`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.47`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.48`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.48.1`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.49`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.50`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.51`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.19:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.52`,
        fs:  `cpe:2.3:a:cisco:unified_operations_manager:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.53`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:0.53.1`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:2011.54`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:2012.54`,
        fs:  `cpe:2.3:a:alfresco:alfresco:4.1.6.13:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:2012.55`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:2013.56`,
        fs:  `cpe:2.3:a:intel:lan_adapters_snmp_agent:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:2013.57`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:2013.58`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:2013.59`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matt_johnston:dropbear_ssh_server:2013.60`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.1.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_3i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.2.0`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.3.0`,
        fs:  `cpe:2.3:o:novell:suse_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.3.2`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.4.0`,
        fs:  `cpe:2.3:h:hp:pos_pole_display_fk225aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.4.9`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.4.10`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.5.0`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.5.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.5.0.16600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.5.2`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.5.3`,
        fs:  `cpe:2.3:a:tincan:phplist:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.5.4`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.0\(3\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.6.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.6.2`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1:4.1:sp5a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.6.3`,
        fs:  `cpe:2.3:a:pawel_jakub_dawidek:geli:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.7.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.7.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(28\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.345:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.4`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.5`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.6`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.7`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.8`,
        fs:  `cpe:2.3:a:php:php:5.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.8.9`,
        fs:  `cpe:2.3:h:cisco:c3640:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.9.0`,
        fs:  `cpe:2.3:a:apache:camel:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_booth:virt-v2v:0.9.1`,
        fs:  `cpe:2.3:h:hp:laserjet_2600n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthew_fries:mf_gig_calendar:0.9.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:0.1.0`,
        fs:  `cpe:2.3:a:libraw:libraw:0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:0.2.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.8:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:1.0.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:1.0.2`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:1.1.0`,
        fs:  `cpe:2.3:o:ibm:os_400:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:1.1.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:1.1.3`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:1.1.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_graubner:mg_help:1.1.6`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7940:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:6.x-1.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultracompare:6.40.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:6.x-1.1`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:6.x-1.2`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:6.x-1.3`,
        fs:  `cpe:2.3:h:moxa:miineport_e2_1242:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:7.x-1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:plone:plone:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:7.x-1.1`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:7.x-1.2`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:matthias_hutterer:email:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:5.x-1.0`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:5.x-1.1`,
        fs:  `cpe:2.3:a:apache:struts:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:5.x-1.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:5.x-1.x-dev`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:6.x-2.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.5.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:6.x-2.1`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:7.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:7.x-1.0:alpha4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.7.00003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:7.x-1.0:beta2`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:hp:hpssupply:140.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mattias_hutterer:taxonomy_manager:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:apache:wink:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mauro_lorenzutti:wfqbe:1.3.1`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mauro_lorenzutti:wfqbe:2.0.0`,
        fs:  `cpe:2.3:a:ibm:ics_viewer:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mauro_lorenzutti:wfqbe:2.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.630:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.0.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.0.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_hydravision_full:2009.0925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(15\)s7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.0.3`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2011:-:sou:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.0.4`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.0.5`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.1.0`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-181_with_network_printer_kit_firmware:t282cn0j421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.1.1`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.1.2`,
        fs:  `cpe:2.3:a:gnome:evolution:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.1.3`,
        fs:  `cpe:2.3:a:ananursespace:american_nurses_association:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.2.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.2.0:beta1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.2.1`,
        fs:  `cpe:2.3:a:microsoft:outlook.com:7.8.2.12.49.0430:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.2.2`,
        fs:  `cpe:2.3:a:bea:weblogic_server:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.2.3`,
        fs:  `cpe:2.3:a:microsoft:tsac_activex_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.2.4`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.3.0`,
        fs:  `cpe:2.3:a:intel:2200bg_proset_wireless:9.0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.4.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc086a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:1.4.1`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:2.0.0`,
        fs:  `cpe:2.3:a:python:pillow:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mautic:mautic:2.0.1`,
        fs:  `cpe:2.3:a:sun:java_enterprise_system:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mavenhut:solitaire_arena:1.0.15::~~~android~~`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mavili_guestbook_project:mavili_guestbook:-`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:1.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:1.2`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_manager:12.1.6:mp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:1.3`,
        fs:  `cpe:2.3:a:comicsplusapp:comics_plus:1.06:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)yt1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:1.5`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:1.6`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:1.41`,
        fs:  `cpe:2.3:a:alberto_pittoni:alguest:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.0`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.10:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.5`,
        fs:  `cpe:2.3:a:ca:unicenter_service_level_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.6`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.7`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.8`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.61`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.62`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.2.0.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.71`,
        fs:  `cpe:2.3:o:cisco:rv110w_wireless-n_vpn_firewall_firmware:1.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:2.81`,
        fs:  `cpe:2.3:a:ibm:flashcopy_manager:2.1:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.0`,
        fs:  `cpe:2.3:a:skype:skype:3.8.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.1`,
        fs:  `cpe:2.3:a:compaq:insight_management_desktop_web_agent:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.01`,
        fs:  `cpe:2.3:a:autodesk:sketchbook_pro:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.02`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.2`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.03`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.11`,
        fs:  `cpe:2.3:a:acrosoftware:cutepdf:3.6.2.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.12`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.13`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.21`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:3.22`,
        fs:  `cpe:2.3:a:netscantools:netscantools:10.31:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.0`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.01`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.3`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.5`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.6`,
        fs:  `cpe:2.3:o:cisco:ios:11.3wa4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.7`,
        fs:  `cpe:2.3:h:buffalotech:bbr-4hg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.8`,
        fs:  `cpe:2.3:a:mcafee:epo_deep_command:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.10`,
        fs:  `cpe:2.3:a:adobe:illustrator:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.11`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.12`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.480.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.20`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall_1:4.1.0:sp5a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.21`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.22`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.4:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.23`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.24`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.25`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p318:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.31`,
        fs:  `cpe:2.3:a:feedweb:feedweb:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.41`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_real-time_information_portal:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.42`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.01.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.43`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:5.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.44`,
        fs:  `cpe:2.3:a:samba:samba:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.51`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.52`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.5:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.71`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:rc3.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.72`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.73`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:4.74`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:alpha`,
        fs:  `cpe:2.3:a:mozilla:firefox:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:alpha2`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:alpha3`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf236a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:beta1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:beta2`,
        fs:  `cpe:2.3:a:adobe:bridge_cs3:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:beta3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:rc1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:rc2`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.3:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:rc3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:rc4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.509.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:rc5`,
        fs:  `cpe:2.3:h:hp:psc_2100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:rc6`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.0:rc7`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.1`,
        fs:  `cpe:2.3:a:roxio:creator_audio:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.01`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.02`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.2`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc748a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.03`,
        fs:  `cpe:2.3:a:x.org:libx11:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.04`,
        fs:  `cpe:2.3:h:schneider-electric:modicon_m221:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.4`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs3_server:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.5`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.05`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.11`,
        fs:  `cpe:2.3:a:mautic:mautic:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.12`,
        fs:  `cpe:2.3:a:agilefleet:fleetcommander:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.13`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.14`,
        fs:  `cpe:2.3:a:cupidsystems:cis_webserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.15`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.16`,
        fs:  `cpe:2.3:a:agilebits:knox:-:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.21`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.0.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.22`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.23`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.41`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.42`,
        fs:  `cpe:2.3:a:emc:rsa_web_threat_detection:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.43`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.51`,
        fs:  `cpe:2.3:a:redhat:jboss_wildfly_application_server:2.0.0:cr8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.52`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.53`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.54`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.55`,
        fs:  `cpe:2.3:a:python:python:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.56`,
        fs:  `cpe:2.3:a:samba:samba_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.57`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.58`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.59`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.111`,
        fs:  `cpe:2.3:a:lund:meta-view:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.141`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.142`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.143`,
        fs:  `cpe:2.3:a:sap:netweaver:7.0:ehp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.144`,
        fs:  `cpe:2.3:h:d-link:dir-809:a2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.145`,
        fs:  `cpe:2.3:a:php:php:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.146`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.147`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.148`,
        fs:  `cpe:2.3:a:businessobjects:businessobjects_enterprise:65.10.0.1011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.149`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.151`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_workstation_supplementary:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.152`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.27-75.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.153`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.154`,
        fs:  `cpe:2.3:a:piwik:piwik:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.155`,
        fs:  `cpe:2.3:a:avast:business_security:11.1.2260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.156`,
        fs:  `cpe:2.3:h:linksys:spa941:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.157`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.158`,
        fs:  `cpe:2.3:a:cisco:rv042g_dual_gigabit_wan_vpn_firmware:4.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.159`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.161`,
        fs:  `cpe:2.3:a:tecolote:aceit:7.3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.162`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.163`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:5.231`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.00`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.01`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.02`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.03`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.04`,
        fs:  `cpe:2.3:a:hp:version_control_agent:6.2.0.860:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.4`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.5`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.05`,
        fs:  `cpe:2.3:a:apple:itunes:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.06`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.6`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.07`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.08`,
        fs:  `cpe:2.3:a:textpattern:textpattern:1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.09`,
        fs:  `cpe:2.3:a:oracle:industry_applications:10.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.10`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.11`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r13b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.13`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.14`,
        fs:  `cpe:2.3:a:splunk:splunk:6.5.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.15`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.16`,
        fs:  `cpe:2.3:a:websense:websense:6.3.3:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.17`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.18`,
        fs:  `cpe:2.3:a:samba:samba:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.19`,
        fs:  `cpe:2.3:a:daemontools:daemon_tools_lite:4.41.3.173:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.20`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.21`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.22`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.23`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-00-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.24`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.25`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.26`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3.1sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.27`,
        fs:  `cpe:2.3:a:vips:vips:7.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.28`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.30`,
        fs:  `cpe:2.3:o:google:android:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.31`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.32`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.5:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.33`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.34`,
        fs:  `cpe:2.3:a:mollify:mollify:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.51`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.52`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.53`,
        fs:  `cpe:2.3:a:netfilter:libmnl:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.54`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.61`,
        fs:  `cpe:2.3:a:keepass:password_safe:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mawashimono:nikki:6.62`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:maximus:schoolmax:-`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:maxthon:maxthon_browser:1.6.7.35`,
        fs:  `cpe:2.3:h:rockwellautomation:1769_compactlogix_5370_l1_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maxthon:maxthon_browser:2.0`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:20.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maxthon:maxthon_browser:2.5.15`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maxthon:maxthon_cloud_browser:4.1.5.2000::~~~android~~`,
        fs:  `cpe:2.3:a:typo3:typo3:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maxtom:atomymaxsite:1.50`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.24:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maxtom:atomymaxsite:2.0`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maxtom:atomymaxsite:2.5`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maxtor:maxtor_onetouch_iii:4.0.200`,
        fs:  `cpe:2.3:a:google:chrome:10.0.607.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mayan-edms:mayan_edms:0.13`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:maygion:ip_camera_firmware:05.49`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.8.211697.2124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:maygion:ip_camera_firmware:05.53`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)eo3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:maygion:ip_camera_firmware:05.59`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:maygion:ip_camera_firmware:05.60`,
        fs:  `cpe:2.3:a:nortel:ssl_vpn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:maygion:ip_camera_firmware:6.0`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:maygion:ip_camera_firmware:6.1`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:maygion:ip_camera_firmware:6.2`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:maygion:ip_camera_firmware:09.27`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_4503-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.2`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.3`,
        fs:  `cpe:2.3:a:ricky_morse:excluded_users:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.5`,
        fs:  `cpe:2.3:a:horde:groupware:1.0:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.5.1`,
        fs:  `cpe:2.3:a:hp:marketresearch:120.0.226.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.5.2`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.5.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.5.4`,
        fs:  `cpe:2.3:a:cisco:ucs_director:4.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.6`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.6.1`,
        fs:  `cpe:2.3:a:skype:skype:4.1.0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.7`,
        fs:  `cpe:2.3:a:mediawiki:rssreader:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.7.1`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.8`,
        fs:  `cpe:2.3:o:asus:rt-ac87u_firmware:3.0.0.4.378.3754:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.8.1`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.2:sp03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.8.2`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.9`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.9.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.9.2`,
        fs:  `cpe:2.3:a:isc:bind:9.9.9:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.9.3`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.9.4`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.9.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:2.2\(1.54\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:maynard_johnson:oprofile:0.9.6`,
        fs:  `cpe:2.3:a:siemens:simatic_step_7:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mb_tickets_project:mb_tickets:3.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:knox:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mblogger_project:mblogger:1.0.04`,
        fs:  `cpe:2.3:a:apple:xcode:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mbtcreations:100_beauty_tips:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mbtcreations:atkins_diet_free_shopping_list:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:kdelibs_sound:2.1.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mbtcreations:detox_juicing_diet_recipes:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:http_server:9.0.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:advanced_threat_defense:3.4.4.14`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:advanced_threat_defense:3.4.4.142`,
        fs:  `cpe:2.3:a:jenkins:git:3.4.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.0.0.1180`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.0.0.1345`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:2.0:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.0.0.1421`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.0.0.1494`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.0.11`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.0.301`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.0.1270`,
        fs:  `cpe:2.3:a:emc:rsa_adaptive_authentication_hosted:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.0.1499`,
        fs:  `cpe:2.3:a:canonical:libpam-modules:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.0.1810`,
        fs:  `cpe:2.3:a:veritas:netbackup:5.1.0:mp3:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.0.1817`,
        fs:  `cpe:2.3:h:cisco:ubr7200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.0.1927`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.57`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.101`,
        fs:  `cpe:2.3:a:ibm:connections:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.201`,
        fs:  `cpe:2.3:a:red-gate:sql_packager:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.5.202`,
        fs:  `cpe:2.3:a:justsystems:shuriken:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.6.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.6.0.1694`,
        fs:  `cpe:2.3:o:cisco:ios:12.3tpc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.6.0.3258`,
        fs:  `cpe:2.3:a:livezilla:livezilla:4.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:agent:4.6.109`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:antispyware:-`,
        fs:  `cpe:2.3:h:hp:j9471a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:antispyware:2005`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:antispyware:2006`,
        fs:  `cpe:2.3:a:novell:filr:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:antispyware_enterprise_module:8.7.0.129`,
        fs:  `cpe:2.3:a:apache:subversion:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:antivirus_engine:-`,
        fs:  `cpe:2.3:a:apple:safari:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:antivirus_engine:4.3.20`,
        fs:  `cpe:2.3:a:totalseminars:a\&#43;_2009_book_demo:9.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:5.1.0`,
        fs:  `cpe:2.3:a:apache:santuario_xml_security_for_java:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:5.1.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:5.1.2`,
        fs:  `cpe:2.3:a:rovicorp:photoshowexpress:2.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:6.0.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.11:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:6.1.0`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.14-1.8:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:6.1.1`,
        fs:  `cpe:2.3:a:adobe:connect:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:6.1.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:6.1.3`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:application_control:6.2.0`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:asap_virusscan:-`,
        fs:  `cpe:2.3:a:koha:koha:3.16.00:pkg:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:asap_virusscan:1.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:asset_baseline_monitor:3.5.0`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.0:*:le:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:asset_baseline_monitor:3.5.0.190`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.1.10111.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:asset_baseline_monitor_agent:3.5.0`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:asset_baseline_monitor_agent:3.5.0.190`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:asset_baseline_monitor_agent:mcafee_inc`,
        fs:  `cpe:2.3:a:bundler:bundler:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:asset_manager:6.6`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:change_control:5.1.0`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:change_control:5.1.1`,
        fs:  `cpe:2.3:o:cisco:sn_5428_storage_router:3.3.1-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:change_control:5.1.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:change_control:6.0.0`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_21.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:cloud_analysis_and_deconstructive_services:1.0.0.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:cloud_analysis_and_deconstructive_services:1.0.0.4d`,
        fs:  `cpe:2.3:a:otrs:otrs:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:cloud_identity_manager:3.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.1:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:cloud_identity_manager:3.1`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:12.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:cloud_identity_manager:3.5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.509:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:cloud_single_sign_on:4.0.0`,
        fs:  `cpe:2.3:a:hp:radia_client:3.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:cloud_single_sign_on:4.0.1`,
        fs:  `cpe:2.3:a:emc:replication_manager:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:-`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.5:p5`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2973:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.5.5.438`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.5.5.568`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.5.5.577`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.5.5.580`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.5.5.588`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:8.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.6.0.438`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_3q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.6.0.453`,
        fs:  `cpe:2.3:a:ca:unicenter_data_transport_option:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.6.0.546`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.6.0.569`,
        fs:  `cpe:2.3:a:sitepark:information_enterprise_server:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.6.0.574`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(8\)p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.6.0.595`,
        fs:  `cpe:2.3:a:apache:roller:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:common_management_agent:3.6.0.603`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:data_loss_prevention_endpoint:9.3.300`,
        fs:  `cpe:2.3:a:rapid7:metasploit:4.13.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_agent:2.2.200.11`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_agent:9.0.0.416`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_agent:9.0.104.5`,
        fs:  `cpe:2.3:a:emc:documentum_capital_projects:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_agent:9.1.2.1`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.23.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_agent:9.1.6.4`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110424:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_agent:9.1.100.1`,
        fs:  `cpe:2.3:a:tasofro:touhou-hisouten:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_management_tools:2.2.300.7`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.9.2269:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_management_tools:9.0.1.7`,
        fs:  `cpe:2.3:a:perl:perl:5.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:dlp_management_tools:9.1.2.4`,
        fs:  `cpe:2.3:a:openttd:openttd:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcafee:e-appliance:-`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:e-business_server:-`,
        fs:  `cpe:2.3:a:busybox:busybox:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:e-business_server:3.5`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.1.8.2:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:e-business_server:3.6.1`,
        fs:  `cpe:2.3:o:cisco:cg-os:cg4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:e-business_server:8.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:e-business_server:8.1.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1015:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:e-business_server:8.5.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:e-business_server:8.5.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_and_web_security:5.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_and_web_security:5.5`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_and_web_security:5.6`,
        fs:  `cpe:2.3:a:skype:skype:0.94.0.28:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:5.6`,
        fs:  `cpe:2.3:o:siemens:sinamics_s\/g_family_firmware:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:6.7.1`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.0`,
        fs:  `cpe:2.3:a:setseed:setseed_cms:5.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.0.1`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.0.2`,
        fs:  `cpe:2.3:a:opnet:it_guru:15.0.0.8631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.0.3`,
        fs:  `cpe:2.3:a:citrix:receiver_enterprise:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.0.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.0.5`,
        fs:  `cpe:2.3:a:winzip:self-extractor:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.5`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.5.1`,
        fs:  `cpe:2.3:h:alcatel:speed_touch_home:khdsaa.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.5.2`,
        fs:  `cpe:2.3:o:google:android:2.3:rev1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.5.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.5.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.5.5`,
        fs:  `cpe:2.3:a:piwik:piwik:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.6`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.6.1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.6.2`,
        fs:  `cpe:2.3:a:telos:amhs:11.4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:email_gateway:7.6.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)ea3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:entercept_agent:-`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epo_deep_command:2.1`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epo_deep_command:2.2`,
        fs:  `cpe:2.3:a:hp:webmin-based_admin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epo_mcafee_virtual_technician:1.0`,
        fs:  `cpe:2.3:a:sun:solaris_pc_netlink:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epo_mcafee_virtual_technician:1.0.4.0`,
        fs:  `cpe:2.3:h:brickom:md-100ap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epo_mcafee_virtual_technician:1.0.7`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:sp1:x32-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epo_mcafee_virtual_technician:1.0.8`,
        fs:  `cpe:2.3:a:keepass:keepass:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epo_mcafee_virtual_technician:1.0.9`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17d\)sxb8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:2.0`,
        fs:  `cpe:2.3:a:open-emr:openemr:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:2.5`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:2.5:sp1`,
        fs:  `cpe:2.3:a:apple:itunes:10.5.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:2.5.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:3.0`,
        fs:  `cpe:2.3:a:hp:openvms:7.3_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:3.0:sp2a`,
        fs:  `cpe:2.3:h:ibm:san_volume_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:3.5.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:3.6.0`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:3.6.1`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.9503:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19\)ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.5.0`,
        fs:  `cpe:2.3:a:kde:ark:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.5.3`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.5.4`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.5.5`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.2p7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.5.6`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.5.7`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.0`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.1`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.2`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.3`,
        fs:  `cpe:2.3:a:vmware:tools:8.3.7.4937:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.5`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.6`,
        fs:  `cpe:2.3:h:hp:a2w75a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.7`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.8`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:4.6.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:5.0.0`,
        fs:  `cpe:2.3:h:seil:x86_fuji:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:5.0.1`,
        fs:  `cpe:2.3:a:apple:apple_tv:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:5.1.0`,
        fs:  `cpe:2.3:a:phusion:juvia:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:5.1.1`,
        fs:  `cpe:2.3:a:microsoft:directx_media:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:5.1.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator:5.3.1`,
        fs:  `cpe:2.3:a:ca:configuration_automation_agent:12.5.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator_agent:-`,
        fs:  `cpe:2.3:a:logitech:quickcam:10.51.2029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:epolicy_orchestrator_agent:3.5.0`,
        fs:  `cpe:2.3:a:ftpx:ftp_explorer:10.5.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:file_lock:5.0`,
        fs:  `cpe:2.3:a:serf_project:serf:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_admin_console:4.8`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_enterprise_admin_console:4.10`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_enterprise_admin_console:4.10.3`,
        fs:  `cpe:2.3:a:vinay_sajip:python-gnupg:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_enterprise_admin_console:4.11`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_enterprise_admin_console:5.0`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_enterprise_control_center:0.5`,
        fs:  `cpe:2.3:a:emc:replication_manager:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_enterprise_control_center:5.0.0.3686`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_reporter:5.1.0.6`,
        fs:  `cpe:2.3:a:yoshinori_tahara:mycaljp:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:firewall_reporter:5.1.0.13`,
        fs:  `cpe:2.3:a:mcafee:e-business_server:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:freescan:-`,
        fs:  `cpe:2.3:o:cray:unicos:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:groupshield_for_exchange:7.0.555.107`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:groupshield_for_exchange:7.0.716.101`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:groupshield_for_exchange:7.0.716.103`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_hp-ux:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:groupshield_for_exchange:7.0.913.100`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:hercules_administrator:4.5.0`,
        fs:  `cpe:2.3:a:croogo:croogo:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_data_loss_prevention:3.0.100.6`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_data_loss_prevention:9.0.0.416`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention:7.0.1`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention:7.0.5`,
        fs:  `cpe:2.3:h:hp:0235a0gf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention:7.0.601`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention:7.0.700`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention:7.0.800`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention:8.0.0`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_patch_management_solutions_for_dell_servers:6.2.3665:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention_server:6.0.1`,
        fs:  `cpe:2.3:h:foundrynet:fastiron_workgroup_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention_server:6.1.0`,
        fs:  `cpe:2.3:a:autodesk:autocad_civil_3d:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:host_intrusion_prevention_server:7.0.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:internet_security_suite:-`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcafee:intrushield_security_management_system:-`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1069.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:linuxshield:1.5`,
        fs:  `cpe:2.3:a:google:chrome:17.0.945.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:linuxshield:1.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:mcafee_agent:4.8.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.99.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:mcafee_agent:5.0.0`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:mcafee_virtual_technician:6.3.0.1911`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:mcinsctl.dll:-`,
        fs:  `cpe:2.3:h:siemens:cfis1425:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:neotrace_express:-`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:neotrace_pro:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_agent:-`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:6.1.15.38`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:6.1.15.39`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.05.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:7.1.5.14`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:7.1.5.15`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:7.1.15.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:7.1.15.7`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:7.5.5.8`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:7.5.5.9`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:8.1.7.2`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:network_security_manager:8.1.7.3`,
        fs:  `cpe:2.3:a:e107:e107:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:personal_firewall_plus:-`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor:5.3.0`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor:5.3.0.167`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ya11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_agent:5.2.0`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_agent:5.2.0.152`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_agent:5.2.0.153`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_agent:5.3.0`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_agent:5.3.0.167`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_agent:6.0.0`,
        fs:  `cpe:2.3:a:lucent:vitalhelp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_agent:6.0.0.278`,
        fs:  `cpe:2.3:a:broderbund:calendar_creator:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_agent:mcafee_inc`,
        fs:  `cpe:2.3:a:f5:big-ip:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:policy_auditor_content_creator:6.0.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:portalshield_for_microsoft_sharepoint_server:2.0.216.102`,
        fs:  `cpe:2.3:a:ibm:lotus_widget_factory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:privacy_service:-`,
        fs:  `cpe:2.3:a:psyced:psyced:20081120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:privacy_service:2004`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:privacy_service:2005`,
        fs:  `cpe:2.3:a:roxio:central_tools:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:privacy_service:2006`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:protectionpilot:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:protectionpilot:1.1.1`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:protectionpilot:1.1.1:p3`,
        fs:  `cpe:2.3:a:altova:xmlspy_2011:2.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:protectionpilot:1.5.0`,
        fs:  `cpe:2.3:a:php.s3.to:tree_bbs:2003\/07\/07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:quarantine_manager:7.0`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:quickclean:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.01:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:quickclean:2004`,
        fs:  `cpe:2.3:h:juniper:srx550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:quickclean:2005`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p227:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:quickclean:2006`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:remote_desktop:-`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:2.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:remote_desktop_32:2.1.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:remote_desktop_32:3.0`,
        fs:  `cpe:2.3:a:devsaran:professional_theme:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:rogue_system_detection_sensor:2.0.0`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d43.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:rogue_system_detection_sensor:4.5.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:rogue_system_detection_server:2.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:saas_endpoint_protection:5.2.0`,
        fs:  `cpe:2.3:a:emc:retrospect_client:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:saas_endpoint_protection:5.2.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2009.312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:saas_endpoint_protection:5.2.2`,
        fs:  `cpe:2.3:a:redmine:redmine:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:saas_endpoint_protection:5.2.3`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:saas_endpoint_protection:5.2.4`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:scan_engine:-`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:scan_engine:4.4.00`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:securify_distributed_login_collector:v6.0.1_%28build_v601_96%29`,
        fs:  `cpe:2.3:a:hp:insight_control_performance_management:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:securify_securvantage_studio:v5.2_%28build_v5.2_385%29`,
        fs:  `cpe:2.3:a:adobe:pdf_ifilter:9.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:securify_studio:v6.0.1_%28build_v601_98%29`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:securify_studio:v6.0_%28build_v60_270%29`,
        fs:  `cpe:2.3:o:oracle:linux:6:7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_center:4.3`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-4000d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_center:6.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_center:6.0.22`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_idm_launcher:1.5.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_center:6.0.23`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_center:7.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_center:7.1`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_center:7.2`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.34:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_for_microsoft_exchange:7.6.7718.105`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_installer_control_system:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:security_scan_plus:2.0.181.2`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_51:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:securitycenter:-`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:securitycenter_agent:-`,
        fs:  `cpe:2.3:a:vasco:identikey_authentication_server:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:securitycenter_agent:6.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:siteadvisor:3.3.133`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.2.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:siteadvisor_enterprise:1.7.0.144`,
        fs:  `cpe:2.3:a:jan_schutze:truc:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:siteadvisor_enterprise:1.7.1000`,
        fs:  `cpe:2.3:a:apache:camel:2.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:spamkiller:-`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:spamkiller:5.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:spamkiller:6.0`,
        fs:  `cpe:2.3:a:sybase:pylon_anywhere:6.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:spamkiller:7.0`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:superscan:4.0`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:17.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virex:-`,
        fs:  `cpe:2.3:a:apache:commons_email:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virex:7.7`,
        fs:  `cpe:2.3:a:instantasp:instantforum:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan:-`,
        fs:  `cpe:2.3:a:radicale:radicale:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan:4.0.3`,
        fs:  `cpe:2.3:a:ibm:integration_bus:9.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan:4.4`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan:4.5`,
        fs:  `cpe:2.3:a:yoshinori_tahara:mycaljp:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan:4.5.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan:7.0`,
        fs:  `cpe:2.3:a:giantrobot:zipcart:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan:8.0.0`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan:10.0.27`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.26:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:7.1.0`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.0i`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(18b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.0i:p11`,
        fs:  `cpe:2.3:a:spip:spip:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.5i`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.6.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.7.0`,
        fs:  `cpe:2.3:a:tenon:itools:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.7.00003`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.7.00004`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.7i`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine:1.3\(0.876\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.8.0`,
        fs:  `cpe:2.3:a:gnu:gzip:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_enterprise:8.8.1000`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_mobile_enterprise:2.1.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:-`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:4.0`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1000.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:4.0.3`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:4.5`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:4.5.1`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:5.0`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:6.0`,
        fs:  `cpe:2.3:a:juniper:installer_service:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:7.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:7.1`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:8.0`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.4p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:virusscan_security_center:9.0`,
        fs:  `cpe:2.3:h:supermicro:x9drt-hf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:visual_trace:-`,
        fs:  `cpe:2.3:a:google:chrome:10.0.638.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:visual_trace:3.25`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0.4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:vulnerability_manager:7.0.11`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:vulnerability_manager:7.5.4`,
        fs:  `cpe:2.3:a:justsystems:ichitaro_portable:-:oreplug:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:vulnerability_manager:7.5.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcafee:web_gateway:7.0`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.0.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.2.0.9`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.3.2.4`,
        fs:  `cpe:2.3:a:gnome:screensaver:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.3.2.6`,
        fs:  `cpe:2.3:h:cisco:catalyst_6624:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.3.2.8`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.3.2.9.`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.4.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.436.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.4.1`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.4.1.3`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:web_gateway:7.4.2`,
        fs:  `cpe:2.3:a:suse:suse_linux_standard_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:webshield:-`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:webshield_smtp:4.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:webshield_smtp:4.1`,
        fs:  `cpe:2.3:a:csounds:csound:5.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:wireless_home_network_security:-`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcafee:wireless_home_network_security:2006`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mccabe:iq:8.0.8.7`,
        fs:  `cpe:2.3:a:jig:movatwitouch_paid:1.792:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mccabe:iq:8.1.0.0`,
        fs:  `cpe:2.3:a:new_atlanta:bluedragon:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcdata:intrepid_6064_director_switch:-`,
        fs:  `cpe:2.3:a:drupal:drupal:7.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcdata:intrepid_6140_director_switch:-`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.825.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcdata:intrepid_director_switch:-`,
        fs:  `cpe:2.3:o:iodata:ts-ptcam_camera_firmware:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcdata:sphereon_3232_fabric_switch:-`,
        fs:  `cpe:2.3:a:netgear:readynas_surveillance:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcdata:sphereon_4300_fabric_switch:-`,
        fs:  `cpe:2.3:a:sony:sonicstage_mastering_studio:2.1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mcdata:sphereon_4500_fabric_switch:-`,
        fs:  `cpe:2.3:h:f5:big-ip_8400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mckenziecreations:virtual_real_estate_manager:3.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mclewin:wishlist:6.x-2.1:beta`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mclewin:wishlist:6.x-2.2`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mclewin:wishlist:6.x-2.4`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.2.0.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mclewin:wishlist:6.x-2.6`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mclewin:wishlist:7.x-2.5`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mclewin:wishlist:7.x-2.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mclewin:wishlist:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mcmguides:pdg_gold_for_ncos_2009:4.5`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:r19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:corel:wordperfect:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:php:mysql_banner_exchange:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:o:linuxmint:linux_mint:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:a:novell:netware_client:4.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:beta4:~~~drupal~~`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:beta5:~~~drupal~~`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:6.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p195:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:rc3:~~~drupal~~`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:rc4:~~~drupal~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:rc5:~~~drupal~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je100a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.0:rc6:~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.1:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.2:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.3:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.4:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:6.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:7.x-1.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:7.x-1.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:7.x-1.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:e107:e107:0.7.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:7.x-1.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:7.x-1.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:7.x-1.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:7.x-1.1:-:~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(55\)se3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:md-systems:simplenews:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(52\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mdickie:hard_time:1.111::~~~android~~`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mdickie:popscene:1.04::~~~android~~`,
        fs:  `cpe:2.3:a:splunk:splunk:4.2.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:h:supermicro:x9drl-ef:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:razerzone:razer_comms_-_gaming_messenger:1.3.07:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:teradata:fastload:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:lwip_project:lwip:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:krisonav:krisonav:1.1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:6.x-2.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2000i:sp2:unlocked:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:me_aliases_project:me_aliases:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:struts:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:measureup:certification_preparation:1.0.0`,
        fs:  `cpe:2.3:a:exim:exim:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:measureup:microsoft_press_training_kit_exam_prep_suite_70-640:1.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5\)e2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:measureup:microsoft_press_training_kit_exam_prep_suite_70-642:1.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.406:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:measureup:microsoft_press_training_kit_exam_prep_suite_70-646:1.0.0`,
        fs:  `cpe:2.3:a:microsoft:frontpage_server_extensions:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:measureup:microsoft_press_training_kit_exam_prep_suite_70-685:1.0.0`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mediabridge:medialink_mwn-wapr300n:-`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.10.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mediabridge:medialink_mwn-wapr300n_firmware:5.07.50`,
        fs:  `cpe:2.3:a:vmware:tools:8.4.6.16648:*:*:*:solaris:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediachance:multimon_taskbar:2.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediacodec:windows_essentials_media_codec_pack:3.2`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.0.0`,
        fs:  `cpe:2.3:a:roxio:audio_module:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.0.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.0.2`,
        fs:  `cpe:2.3:a:banner_effect_header_project:banner_effect_header:1.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.0.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.0.4`,
        fs:  `cpe:2.3:a:microsoft:onenote:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.0.5`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.03.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.0.6`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.0.7`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.1.0`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.1.1`,
        fs:  `cpe:2.3:a:bloomyou:bloomyou_valentine:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.1.2`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.1.3`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.1.4`,
        fs:  `cpe:2.3:h:hp:jf814a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.1.5`,
        fs:  `cpe:2.3:a:vmware:player:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:1.1.7`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1681.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.0.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.0.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.0.3`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.0.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.0.5`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.0.6`,
        fs:  `cpe:2.3:a:perl:perl:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.0.7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.0`,
        fs:  `cpe:2.3:h:cisco:rv180w_wireless-n_multifunction_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.1`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1290.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.4`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.0.832.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.5`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.6`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:331.00:-:*:*:unix:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.8`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.1.9`,
        fs:  `cpe:2.3:a:featured_comments_plugin_project:featured_comments:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.2.0`,
        fs:  `cpe:2.3:o:asus:rt-ac68u_firmware:3.0.0.4.374_4561:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.2.1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.4.013:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.2.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.488:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.2.3`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.2.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.2.5`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l2_controller_firmware:21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.3.0`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.3.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.3.3`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.4.0`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.4.1`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:95:osr2.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.4.2`,
        fs:  `cpe:2.3:a:pluck-cms:pluck:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.4.3`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.5.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.6.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.6.1`,
        fs:  `cpe:2.3:a:altiris:out_of_band_management_solution_documentation:6.2.1012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.6.2`,
        fs:  `cpe:2.3:a:isc:bind:9.6.0a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.6.3`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.6.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.6.5`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.7.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2010.825.2146.37182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.8.0`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.768:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.8.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.758.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.8.2`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.9.0`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.9.1`,
        fs:  `cpe:2.3:a:atvise:webmi2ads:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.9.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.9.3`,
        fs:  `cpe:2.3:a:redhat:lv:4.49.4-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.9.4`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.9.5`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.99.904:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.10.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.10.1`,
        fs:  `cpe:2.3:a:adrian_chadd:rtg2:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.10.2`,
        fs:  `cpe:2.3:a:sybase:easerver:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.10.3`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.16.5:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.11.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.8_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.11.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.11.2`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaelementjs:mediaelement.js:2.20.1`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafire:mediafire:1.1.1::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafire:mod_quick_form:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:beta2`,
        fs:  `cpe:2.3:h:f5:global-site:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:beta4`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:beta5`,
        fs:  `cpe:2.3:a:ibm:maximo_for_oil_and_gas:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:pgp:e-business_server:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc2`,
        fs:  `cpe:2.3:h:hp:jd655a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc3`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc4`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc5`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.0.0.716:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc6`,
        fs:  `cpe:2.3:a:pixman:pixman:0.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc7`,
        fs:  `cpe:2.3:a:vmware:esx_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc8`,
        fs:  `cpe:2.3:a:f-secure:anti-virus:9.00:*:*:*:*:citrix_servers:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0:rc9`,
        fs:  `cpe:2.3:a:hp:device_discovery:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.0-beta3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17\)zd3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.2`,
        fs:  `cpe:2.3:a:wolfcms:wolf_cms:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.5`,
        fs:  `cpe:2.3:a:idevspot:phphostbot:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(4\)xaf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:-`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:beta1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:beta2`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:mikejolley:download_monitor:1.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:rc2`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:rc3`,
        fs:  `cpe:2.3:a:pass4sure:questions_and_answers_for_comptia_sy0-301:5.7.13201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:rc4`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:rc5`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:rc6`,
        fs:  `cpe:2.3:a:cisco:finesse:10.6\(1\)_su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:rc7`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.0:rc8`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.1`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction_content_service_for_windows_files:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.2`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.3`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.3.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.6`,
        fs:  `cpe:2.3:a:sharethis:sharethis:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:nagios:nagios:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:alpha2`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.core:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:alpha3`,
        fs:  `cpe:2.3:a:apache:wicket:6.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:alpha4`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:alpha5`,
        fs:  `cpe:2.3:a:webmin:usermin:1.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:beta1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:beta2`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:beta4`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.5131:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:beta5`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:rc1`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.48.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:rc2`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:rc3`,
        fs:  `cpe:2.3:a:altiris:carbon_copy:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:rc4`,
        fs:  `cpe:2.3:a:namazu:namazu:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:rc5`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:rc6`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:rc7`,
        fs:  `cpe:2.3:a:jenkins:git:2.6.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.0:rc8`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.1`,
        fs:  `cpe:2.3:a:adobe:color_recommended_settings_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.2`,
        fs:  `cpe:2.3:a:debian:adequate:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediafront:mediafront:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:acme:thttpd:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaonlinecenter:lagu_pop_indonesia:2::~~~android~~`,
        fs:  `cpe:2.3:a:corel:coreldraw_photo_paint:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaplayercodecpack:media_player_codec_pack:3.8.0`,
        fs:  `cpe:2.3:a:redhat:jboss_fuse_esb_enterprise:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediaplayercodecpack:media_player_codec_pack:3.9.6`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:checkuser:2.3:-:~~~mediawiki~~`,
        fs:  `cpe:2.3:a:ipswitch:imail_server:2006.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.2.0`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.08:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.2.1`,
        fs:  `cpe:2.3:a:adobe:illustrator:16.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.2.2`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:50.1.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.2.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.2.4`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.2.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.2.6`,
        fs:  `cpe:2.3:a:libav:libav:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.0`,
        fs:  `cpe:2.3:a:combodo:itop:0.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.1`,
        fs:  `cpe:2.3:a:splunk:splunk:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.2`,
        fs:  `cpe:2.3:a:symantec:intruder_alert_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.3`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.6`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.7`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.8`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.5_build_719:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.9`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner_documentation:16.0.0.10107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.10`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.11`,
        fs:  `cpe:2.3:a:condor_project:condor:7.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.12`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.13`,
        fs:  `cpe:2.3:a:skalfa:skadate_lite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.14`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.3.15`,
        fs:  `cpe:2.3:a:x:libxfixes:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4:beta1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4:beta2`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4:beta3`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4:beta4`,
        fs:  `cpe:2.3:a:dotnetblogengine:blogengine.net:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4:beta5`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4:beta6`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.0`,
        fs:  `cpe:2.3:a:tenable:securitycenter:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.2`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.3`,
        fs:  `cpe:2.3:a:microsoft:works:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.4`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.5`,
        fs:  `cpe:2.3:a:vmware:vix:1.10.0.12331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.6`,
        fs:  `cpe:2.3:a:python:python:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.7`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.8`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.9`,
        fs:  `cpe:2.3:h:cisco:security_monitoring_analysis_and_response_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.10`,
        fs:  `cpe:2.3:h:intel:server_board_se7501hg2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.11`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.12`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.13`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_laptops_desktops:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.4.14`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:alpha1`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:alpha2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3610-52p_ls-3610-52p-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:beta1`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:beta2`,
        fs:  `cpe:2.3:a:perl:perl:2.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:beta3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:beta4`,
        fs:  `cpe:2.3:a:imember360:imember360:3.9.001:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:rc2`,
        fs:  `cpe:2.3:o:yamaha:rta52i:4.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:rc3`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5:rc4`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.0`,
        fs:  `cpe:2.3:h:supermicro:x9drt-h6f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.1`,
        fs:  `cpe:2.3:o:cisco:ons_15600:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.2`,
        fs:  `cpe:2.3:a:ibm:http_server:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.3`,
        fs:  `cpe:2.3:a:justsystems:just_online_update:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.4`,
        fs:  `cpe:2.3:a:toocharger:trombinoscope:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.5`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.6`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.3041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.7`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.5.8`,
        fs:  `cpe:2.3:a:nuance:omnipage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.0`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.7.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.3`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.4`,
        fs:  `cpe:2.3:a:biscom:faxcomapi_for_faxcom_queue:9.6.990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.5`,
        fs:  `cpe:2.3:a:oracle:communications_service_broker:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.6`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.7`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.9`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.10`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.11`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.6.12`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.7.0`,
        fs:  `cpe:2.3:a:ca:enterprise_log_manager:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.7.1`,
        fs:  `cpe:2.3:a:google:v8:3.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.7.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_eventlog_analyzer:9.0:9002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.7.3`,
        fs:  `cpe:2.3:a:vmware:player:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.8.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.181.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.8.1`,
        fs:  `cpe:2.3:a:corel:coreldraw_windows_shell_extension:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.8.2`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.5:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.8.3`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.8.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.8.5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.9.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p269:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.9.0:rc2`,
        fs:  `cpe:2.3:a:apple:cups:1.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.9.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect_server:9.7.300.291:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.9.2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.9.3`,
        fs:  `cpe:2.3:a:msevensoftware:msecure:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.9.4`,
        fs:  `cpe:2.3:a:ibm:sametime:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.9.5`,
        fs:  `cpe:2.3:a:ubuntu_developers:apt-xapian-index:0.44ubuntu7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.9.6`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.10.0`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.1.3674.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.10.0:rc1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.10.0:rc2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.10.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.10.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.10.3`,
        fs:  `cpe:2.3:a:paypal:payments_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.10.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.023.20056:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.11`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.11.0`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.11.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.11.1`,
        fs:  `cpe:2.3:a:file_project:file:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.11.2`,
        fs:  `cpe:2.3:a:adobe:help_center:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.12.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.12.0:rc1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.12.1`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a5\(3.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.12.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.12.3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.12.4`,
        fs:  `cpe:2.3:h:cisco:nexus_5020:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.13.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.13.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.13.0:rc2`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_icons_for_juniper:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.13.1`,
        fs:  `cpe:2.3:a:kajona:kajona:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.13.2`,
        fs:  `cpe:2.3:a:bea:aqualogic_analytics:2.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.13.3`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.13.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.14.0`,
        fs:  `cpe:2.3:a:avg:anti-virus:9.0:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.14.0:rc1`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.14.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.15.0`,
        fs:  `cpe:2.3:a:commvault:media_agent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.15.0:rc1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0062:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.15.1`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.15.2`,
        fs:  `cpe:2.3:a:logitech:audio_echo_cancellation_component:10.50.1096:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.15.3`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.15.4`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.15.5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.16.0`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.16.0:beta1`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.16.0:beta2`,
        fs:  `cpe:2.3:o:intel:trusted_execution_technology_sinit_authenticated_code_module:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.16.0:beta3`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.16.1`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.8.4:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.16.2`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:11.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.17`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.3.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.17:beta_1`,
        fs:  `cpe:2.3:a:combodo:itop:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.17.0`,
        fs:  `cpe:2.3:a:sir:gnuboard:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.17.0:rc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.17.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.17.2`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.17.3`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.17.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18:beta_1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18.0`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18.0:rc1`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.8.817:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18.1`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18.2`,
        fs:  `cpe:2.3:a:ephiphanyheathdata:cardio_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18.3`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18.4`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18.5`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.18.6`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.39:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19:beta_1`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19:beta_2`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.1`,
        fs:  `cpe:2.3:a:roxio:creator:1.0.439:*:*:*:starter:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.2`,
        fs:  `cpe:2.3:a:apple:itunes:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.4`,
        fs:  `cpe:2.3:a:serena:vm_web_client:810000818:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.5`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.3.1:fix02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.6`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:sp1:x32-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.7`,
        fs:  `cpe:2.3:a:microsoft:enhanced_mitigation_experience_toolkit:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.8`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.9`,
        fs:  `cpe:2.3:a:arcanadev:adtempus:2.1.0004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.10`,
        fs:  `cpe:2.3:a:kbd-project:kbd:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.11`,
        fs:  `cpe:2.3:a:shopware:shopware:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.12`,
        fs:  `cpe:2.3:a:ca:messaging:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.13`,
        fs:  `cpe:2.3:a:apache:knox:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.14`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.15`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:8.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.16`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.17`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.21`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:5.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.22`,
        fs:  `cpe:2.3:a:appearingbusiness:magic_balloonman_marty_boone:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.19.23`,
        fs:  `cpe:2.3:o:checkpoint:gaia_os:r71.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20`,
        fs:  `cpe:2.3:a:hp:proliant_remote_monitor_service:5.11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20.1`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20.2`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:fp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20.4`,
        fs:  `cpe:2.3:h:hp:jd664a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20.5`,
        fs:  `cpe:2.3:a:christopher_mitchell:smart_breadcrumb:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20.6`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20.7`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.20.8`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.0.2:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.1`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.2`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.3`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.36:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.5`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.6`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.7`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_9.0_firmware:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.8`,
        fs:  `cpe:2.3:a:inria:ocaml:2.99:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.9`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.19.4867:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.10`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.21.11`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.0:rc1`,
        fs:  `cpe:2.3:h:3com:3crx506-96:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp4:srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.2`,
        fs:  `cpe:2.3:a:getscoop:kontan_kiosk:\@7f07025e:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.3`,
        fs:  `cpe:2.3:a:apple:safari:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.5`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.7`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.4\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.8`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.12`,
        fs:  `cpe:2.3:a:goforandroid:go_note_widget:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.13`,
        fs:  `cpe:2.3:h:fortinet:fortigate-3950b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.14`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.842.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.22.15`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.1`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.5`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.6`,
        fs:  `cpe:2.3:a:apache:camel:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.7`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.9`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.10`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:340.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.23.14`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1.0.2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.24.0`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.24.1`,
        fs:  `cpe:2.3:h:fortinet:fortigate-1500d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.24.2`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.24.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.25.0`,
        fs:  `cpe:2.3:a:hp:trayapp:140.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.25.1`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.25.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.26.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.26.2`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.26.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.26.4`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:mediawiki:1.27.0`,
        fs:  `cpe:2.3:a:web2py:web2py:1.84.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:rssreader:0.2`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:rssreader:0.2.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.11:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:rssreader:0.2.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:rssreader:0.2.3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:rssreader:0.2.4`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-255p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mediawiki:rssreader:0.2.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:medquiz%3a_medical_chat_and_mcqs_project:medquiz%3a_medical_chat_and_mcqs:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:megalab:the_uploader:2.0.4`,
        fs:  `cpe:2.3:a:epson:scan_pdf_extensions:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:megnicholas:clean_and_simple_contact_form:4.4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:ims-lantime_m1000:-`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-16t-si_ls-s3100-16t-si-ac-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:ims-lantime_m3000:-`,
        fs:  `cpe:2.3:a:microsoft:iemobile:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:ims-lantime_m500:-`,
        fs:  `cpe:2.3:a:jetbrains:intellij_idea:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:lantime_m100:-`,
        fs:  `cpe:2.3:a:git-scm:git:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:lantime_m200:-`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:eca:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:lantime_m300:-`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:lantime_m400:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:lantime_m600:-`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:lantime_m900:-`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:lces:-`,
        fs:  `cpe:2.3:o:apple:os_x_server:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meinberg:network_time_protocol:4.2.4p7%40copenhagen-o`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:5.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meinberg:network_time_protocol:4.2.4p8%40lennon-o-lpv`,
        fs:  `cpe:2.3:o:f5:tmos:4.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:meinberg:ntp_server_firmware:6.0`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:0.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meinberg:ntp_time_server_monitor:0.9g`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meinberg:syncfire_1100:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meipai:meipai:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:irfanview:flashpix_plugin:4.3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meitalk:meitalk:%407f060012::~~~android~~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:meizu:mx:-`,
        fs:  `cpe:2.3:a:libav:libav:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:melodigram:melodigram:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:member_approval_plugin_project:member_approval:131109::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:cups:1.1.19:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.0`,
        fs:  `cpe:2.3:o:yahama:rtw65i:5.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.0:beta1`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.0:beta2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.0:deprecated`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.21:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_supply_chain_management_order_management:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.3`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.4`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.5`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.4:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.6`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.7`,
        fs:  `cpe:2.3:h:corega:cg-wlbargmh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.8`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.11.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.9`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.10`,
        fs:  `cpe:2.3:a:redhat:libpng:1.2.2-20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:5.x-1.x:dev`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.0`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.1`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.6.398:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.2`,
        fs:  `cpe:2.3:a:php:pear:1.2b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.3`,
        fs:  `cpe:2.3:a:essentialobjects:eo.web_controls_2011:9.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.4`,
        fs:  `cpe:2.3:a:dell:controlpoint_connection_manager:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.4:rc1`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2009.211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.5:rc1`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.6`,
        fs:  `cpe:2.3:a:eaton:elcsoft:2.4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.8`,
        fs:  `cpe:2.3:o:cisco:ios:3.7.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.9`,
        fs:  `cpe:2.3:a:hp:software_process_control:6.20.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.9:rc1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.10`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcache_project:memcache:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.2.7`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.2.8`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.2`,
        fs:  `cpe:2.3:a:boost:boost:1.62.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.3`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.4`,
        fs:  `cpe:2.3:a:apache:poi:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.6`,
        fs:  `cpe:2.3:a:visionsolutions:double-take:4.4.1.0.1352.s.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.7`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.8`,
        fs:  `cpe:2.3:a:gnu:gzip:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.9`,
        fs:  `cpe:2.3:a:thinkshout:mandrill:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.10`,
        fs:  `cpe:2.3:a:sap:gui_for_windows:7.20_compilation_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.11`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.12`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.13`,
        fs:  `cpe:2.3:a:apache:poi:3.10:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.14`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.080:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.15`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memcached:memcached:1.4.16`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:memorizeit:memorizeit%21:1.7.2::~~~android~~`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:1.5.7`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:1.6`,
        fs:  `cpe:2.3:a:libndp:libndp:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:1.6:alpha3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.03:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:12.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.1.1`,
        fs:  `cpe:2.3:a:microsoft:pskill:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.1.2`,
        fs:  `cpe:2.3:a:ibm:content_navigator:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.2.1`,
        fs:  `cpe:2.3:a:mopl:phone_for_google_voice_\&amp;_gtalk:1.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.2.2`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.2.3`,
        fs:  `cpe:2.3:h:moxa:iologic_e2212:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.2.4`,
        fs:  `cpe:2.3:a:hp:thinpro_linux:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:2.2.6`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.9:bundle11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:4.01:*:*:ru:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0:beta1`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.0.5:pl2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0:beta2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0:beta3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0:rc1`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0:rc2`,
        fs:  `cpe:2.3:a:nero:infotool:5.99.5.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.1`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.2`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.3`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.4`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2013:cumulative_update_10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.5`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.01.00051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.6`,
        fs:  `cpe:2.3:a:redhat:rhel_extras:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.7`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.15a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.8`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:menalto:gallery:3.0.9`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.05.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merant:dimensions:-`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merant:merant_tracker:8.0.0.4`,
        fs:  `cpe:2.3:a:netty_project:netty:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mercadolibre:mercadolibre:3.8.7::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mercurial:mercurial:3.2.3`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.593:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mercurial:mercurial:3.7.2`,
        fs:  `cpe:2.3:h:securecomputing:sch_i730_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mercurial:mercurial:3.7.3`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mercurycom:mr804:8.0`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mercurycom:mr804_firmware:3.8.1`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4`,
        fs:  `cpe:2.3:o:d-link:dir-600l_firmware:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2.1`,
        fs:  `cpe:2.3:a:pocketmags:wasps_official_programmes:\@7f080130:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2.2`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2.3`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2.4`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:sp4_patch2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2.5`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2.6`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2.7`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:1.4.2.8`,
        fs:  `cpe:2.3:a:symantec:vrtsccscmserver:5.2.202.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:b2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:b3`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:b4`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.8p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:b5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:b6`,
        fs:  `cpe:2.3:a:intel:driver_update_utility:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:rc1`,
        fs:  `cpe:2.3:a:cnn:cnnmoney_portfolio:1.03:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:rc2`,
        fs:  `cpe:2.3:a:ibm:java:6.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:rc3`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:rc4`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0:rc5`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:5.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.0.2`,
        fs:  `cpe:2.3:a:juniper:junos_space:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.0`,
        fs:  `cpe:2.3:a:bongomovie_project:bongomovie:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.1`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.2`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0072:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.3`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.6`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(5b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.7`,
        fs:  `cpe:2.3:h:nortel:survivable_remote_gateway:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.8`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.9`,
        fs:  `cpe:2.3:a:nas4free:nas4free:9.1.0.1.804:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.10`,
        fs:  `cpe:2.3:a:apache:camel:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.11`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.1.13`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.2`,
        fs:  `cpe:2.3:a:novell:libzypp:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.2:b1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.2:rc1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.2:rc2`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.2.1`,
        fs:  `cpe:2.3:o:huawei:s7703_firmware:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.2.2`,
        fs:  `cpe:2.3:a:peribit:sequence_reduction_system_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.0:rc3`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.1`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.2`,
        fs:  `cpe:2.3:a:popoinnovation:slotmachine:1.03:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.3`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.4`,
        fs:  `cpe:2.3:h:polycom:viewstation_512:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.5`,
        fs:  `cpe:2.3:a:videocharge:videocharge_studio:2.9.0.632:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.6`,
        fs:  `cpe:2.3:h:ibm:flex_system_x440_compute_node:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.7`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server_for_windows:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.8`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.9`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.2p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:merethis:centreon:2.3.9-4`,
        fs:  `cpe:2.3:a:debian:xsabre:0.2.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:8.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:8.0.1`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:8.0.2`,
        fs:  `cpe:2.3:a:citadel:webcit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:8.0.3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:8.0.4`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:8.0.5`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:9.0`,
        fs:  `cpe:2.3:a:pfsense:pfsense:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:9.0.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.08:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:9.0.2`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:9.0.3`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.17:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:9.1`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mesa3d:mesa:9.1.1`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meta_tags_quick_project:meta_tags_quick:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meta_tags_quick_project:meta_tags_quick:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meta_tags_quick_project:meta_tags_quick:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sre1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meta_tags_quick_project:meta_tags_quick:7.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meta_tags_quick_project:meta_tags_quick:7.x-2.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meta_tags_quick_project:meta_tags_quick:7.x-2.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meta_tags_quick_project:meta_tags_quick:7.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:mitsubishielectric:mc-worx_suite:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:meta_tags_quick_project:meta_tags_quick:7.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metacase:metaedit:2.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metaclassy:byword:2.0.0`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metaclassy:byword:2.0.1`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metaclassy:byword:2.0.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metaclassy:byword:2.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metago:astro_file_manager_with_cloud:astro-4.4.592::~~~android~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metalgenix:genixcms:0.0.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metalogix:migration_manager_for_sharepoint:4.1.1303`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metalogix:selective_restore_manager_for_sharepoint_backups:4.1.904`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metalogix:sharepoint_extensions_web_service:4.1.1204`,
        fs:  `cpe:2.3:a:sendmail:sendmail:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metalogix:sharepoint_extensions_web_service:4.1.1303`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metalogix:sharepoint_extensions_web_service:4.1.1304`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metastorm:process_manager:8.1.8.4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:metroseoul:metro_news:1.6.5::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:vrtsaa:5.0.281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mgsasia:qin_story:1::~~~android~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mh-nexus:hxd_hex_editor_version:1.7.7.0`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mibizapps:absolute_lending_solutions:1.0073.b0073::~~~android~~`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mibizapps:accurate_lending:1.0021.b0021::~~~android~~`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mibizapps:no_fuss_home_loans:1.0035.b0035::~~~android~~`,
        fs:  `cpe:2.3:a:david_king:vino:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:michael_biebl:policykit:0.103`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.31:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:michael_staatz:sofortueberweisung2commerce:2.0.0`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:michael_vogt:ubuntu-system-service:0.2.2`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:beta3.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:michael_vogt:ubuntu-system-service:0.2.3`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:michael_vogt:ubuntu-system-service:0.2.4`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microcart_project:microcart:1.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microchip_technology_inc.:mplab_tools:8.70`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:0.02:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:microfocus:enterpriselink:5.0`,
        fs:  `cpe:2.3:a:administration_views_project:administration_views:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microfocus:rumba:7.4.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microfocus:rumba:9.4.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg252a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microfocus:server:5.1.99`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microfocus:server:5.100.157`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:micronet:sp916bm:-`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:micronet:sp916bm:1.9`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microp_project:microp:0.1.1.1600`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:micropact:icomplaints:8.0`,
        fs:  `cpe:2.3:a:novell:client:2.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:micropact:icomplaints:8.0.2.1.8.8014`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:-`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.0:beta2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.0:gold`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.0:sp1`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:1.2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.0:sp2`,
        fs:  `cpe:2.3:a:microsoft:works:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.0:sp3`,
        fs:  `cpe:2.3:a:scott_reynen:node_embed:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.1`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.1:2003sp1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.1:gold`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.1:sp1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.9.4:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.1:sp1:2003`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.1:sp1:sdk`,
        fs:  `cpe:2.3:a:apache:roller:0.9.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.1:sp2`,
        fs:  `cpe:2.3:h:apple:imac:m9363xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:1.1:sp3`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:2.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:2.0:gold`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:2.0:sp1`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:2.0:sp2`,
        fs:  `cpe:2.3:a:differencegames:hidden_memory_-_aladdin_free\!:1.0.31:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.42:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:3.0:gold`,
        fs:  `cpe:2.3:h:cisco:sg500-28:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:3.0:sp2`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:3.5`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:3.5:sp1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:3.5.1`,
        fs:  `cpe:2.3:a:apache:camel:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:4.0`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:4.0:beta1`,
        fs:  `cpe:2.3:a:inria:ocaml:3.03:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:4.5`,
        fs:  `cpe:2.3:a:redcarpet_project:redcarpet:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:4.5.1`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:4.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:4.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p289:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:4.6.1`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_framework:4.6.2`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:.net_windows_server:-`,
        fs:  `cpe:2.3:a:e107:e107:2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:1.0`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:1.1`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2.0`,
        fs:  `cpe:2.3:a:dialogic:host_media_processing_software_release:3.0.225:service_update_225:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:95`,
        fs:  `cpe:2.3:a:luracast:restler:1.5.6:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:97`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.1:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2000`,
        fs:  `cpe:2.3:h:cisco:call_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2000:sp1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1310.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2000:sp2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2000:sp3`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2000:sr1`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2002`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2002:sp1`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2002:sp2`,
        fs:  `cpe:2.3:a:apache:activemq:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2002:sp3`,
        fs:  `cpe:2.3:h:cisco:pix_firewall_506:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2003`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:r55p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2003:sp1`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2003:sp2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2007`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2007:sp3`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2010:sp1:~~~~x64~`,
        fs:  `cpe:2.3:a:haxx:curl:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2010:sp1:~~~x64~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2010:sp1:~~~x86~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2010:sp2:~~~~x64~`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2010:sp2:~~~x64~~`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2010:sp2:~~~x86~~`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2013`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2013::~~~~x64~`,
        fs:  `cpe:2.3:a:cisco:unified_ccx:8.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2013::~~~x64~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.391.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access:2013::~~~x86~~`,
        fs:  `cpe:2.3:a:gnu:gdb:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:access_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.0\(2a\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:active_directory:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:active_directory_application_mode:-`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.8:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:active_directory_federation_services:1.0`,
        fs:  `cpe:2.3:a:web2py:web2py:1.95.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:active_directory_federation_services:1.1`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:active_directory_federation_services:2.0`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:active_directory_federation_services:2.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_replication_server:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:active_directory_lightweight_directory_service:-`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:active_directory_services:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:activesync:-`,
        fs:  `cpe:2.3:a:productcart:productcart:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:activesync:4.1`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:activex:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ampx:-`,
        fs:  `cpe:2.3:h:3com:total_control_netserver_card:3.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:antigen:-`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.0.3.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:antispyware:-`,
        fs:  `cpe:2.3:a:richard_cook:rgpg:0.2.0:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:antispyware:1.0.509`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:antispyware:1.0.509:beta1`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net:-`,
        fs:  `cpe:2.3:a:apache:roller:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net:1.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:9.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net:1.1`,
        fs:  `cpe:2.3:a:pargovernment:gv:950.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net:1.1:sp1`,
        fs:  `cpe:2.3:h:supermicro:x9drd-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_core:1.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_core:1.1`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.9:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_core:2.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_signalr:1.1.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch_5400zl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_signalr:1.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_signalr:1.1.2`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_signalr:1.1.3`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_signalr:1.1.4`,
        fs:  `cpe:2.3:a:ows:scald:6.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_signalr:2.0.0`,
        fs:  `cpe:2.3:a:teamquest:view:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:asp.net_signalr:2.0.1`,
        fs:  `cpe:2.3:a:matrixssl:matrixssl:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:atlas_framework:-`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:background_intelligent_transfer_service:6.6`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:backoffice:-`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:backoffice:4.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:backoffice:4.5`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:backoffice_resource_kit:-`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:backoffice_resource_kit:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)yu1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:baseline_security_analyzer:-`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:baseline_security_analyzer:1.0`,
        fs:  `cpe:2.3:h:hp:0235a328:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:baseline_security_analyzer:1.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:bing:4.2.0:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.480.4.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:bing:4.2.1:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:garyjohnson2012:gary_johnson_for_president_\&#39;12:0.75.13439.53899:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000:sp1a`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000:sp1a:developer`,
        fs:  `cpe:2.3:a:arellia:arellia_application_control_report_language_pack:6.1.1102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000:sp1a:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000:sp1a:standard`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:0.9.4:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000:sp2`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000:sp2:developer`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000:sp2:enterprise`,
        fs:  `cpe:2.3:a:redmine:redmine:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2000:sp2:standard`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2002`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2002:sp1`,
        fs:  `cpe:2.3:o:cisco:ios:11.2wa3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2004`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix_md:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2004:sp1`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2012-ac-ovs-w-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2004:sp2`,
        fs:  `cpe:2.3:a:omeka:omeka:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2010`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2013`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.1:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_server:2013:r2`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:-`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000:sp1a`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000:sp1a:developer`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000:sp1a:enterprise`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cpp:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000:sp1a:standard`,
        fs:  `cpe:2.3:a:citrix:access_management_console_framework:4.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000:sp2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000:sp2:developer`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.13-1.8:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000:sp2:enterprise`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(55\)se6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2000:sp2:standard`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2002`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.93:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2004`,
        fs:  `cpe:2.3:a:redmine:redmine:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2004:sp1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.6:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:biztalk_srv:2004:sp2`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:business_solutions_crm:-`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:business_solutions_crm:1.2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:cabarc:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:capicom:-`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:class_package_export_tool:-`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:2.6:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:class_package_export_tool:5.0.2752`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:clip_art:-`,
        fs:  `cpe:2.3:a:yokogawa:centum_vp:r4.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:clip_art:1.0`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:-`,
        fs:  `cpe:2.3:a:gnu:zebra:0.93a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2000`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2000:sp1`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak3:3.0.0:beta32:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2000:sp2`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2002`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2002:sp1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2002:sp4`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2007:sp2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2009`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commerce_server:2009:r2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(23\)sv1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commercial_internet_system:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commercial_internet_system:2.0`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110714:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:commercial_internet_system:2.5`,
        fs:  `cpe:2.3:a:apache:ambari:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:content_management_server:-`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:content_management_server:2001`,
        fs:  `cpe:2.3:h:ovislink:airlive_wl2600cam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:content_management_server:2001:sp1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:content_management_server:2002`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:content_management_server:2002:sp2`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.4.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:1.5`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.0`,
        fs:  `cpe:2.3:h:buffalotech:whr-1166dhp_firmware:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.1`,
        fs:  `cpe:2.3:h:3com:3c17205-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.1.1.3711.11`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.1.1.3711.11:ga`,
        fs:  `cpe:2.3:a:gnu:gdb:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.5`,
        fs:  `cpe:2.3:a:igrafx:igrafx:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.5:gold`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:6.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.5:sp1`,
        fs:  `cpe:2.3:a:red-gate:sql_dependency_tracker:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.5:sp2`,
        fs:  `cpe:2.3:a:nero:menu_templates_starter_kit:9.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.5:sp3`,
        fs:  `cpe:2.3:a:web2py:web2py:1.97.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.6:gold`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.6:sp1`,
        fs:  `cpe:2.3:a:jordan_de_laune:mp3_player:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.6:sp2`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.7`,
        fs:  `cpe:2.3:h:rockwellautomation:plc-5_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.7:gold`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.7:sp1`,
        fs:  `cpe:2.3:a:webges:imig_2012:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.8`,
        fs:  `cpe:2.3:a:prothemedesign:mimbo_pro:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.8:sp1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.8:sp2`,
        fs:  `cpe:2.3:a:e107:e107:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_access_components:2.12.4202.3`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.9.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_engine:-`,
        fs:  `cpe:2.3:a:3par:inform_command_line_interface:2.3.1.330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_engine:1.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_engine:2000`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_protection_manager:2006`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:data_protection_manager:2007`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:debug_interface_access_software_development_kit:-`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6a:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:desktop_engine:2000`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:dhcp_client_service:-`,
        fs:  `cpe:2.3:h:lexmark:e450:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:digital_image:2006:unknown:starter`,
        fs:  `cpe:2.3:a:vmware:vcenter_chargeback_manager:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:digital_image_pro:-`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:digital_image_pro:7.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:digital_image_pro:9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:digital_image_suite:-`,
        fs:  `cpe:2.3:a:social_stats_project:social_stats:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:digital_image_suite:9`,
        fs:  `cpe:2.3:h:ibm:integrated_management_module_2:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:-`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:5.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:6.1`,
        fs:  `cpe:2.3:a:freedomscientific:video_intercept:10.14.2289.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:7.0`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:7.0a`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:7.1`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:8.0`,
        fs:  `cpe:2.3:a:rob_loach:sharethis:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:8.0a`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:8.1`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:8.1a`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:8.1b`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:1.1.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:8.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:9.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:9.0a`,
        fs:  `cpe:2.3:a:apache:struts:2.1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:9.0b`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:9.0c`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:10.0`,
        fs:  `cpe:2.3:a:estrongs:es_file_explorer:1.6.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:10.1:-`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:11.0`,
        fs:  `cpe:2.3:a:monotone:monotone:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx:11.1`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx_files_viewer_control:-`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx_media:-`,
        fs:  `cpe:2.3:a:altiris:express_deployment_server:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx_media:6.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx_sdk:-`,
        fs:  `cpe:2.3:o:alliedtelesis:img616lh_firmware:\&#43;2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:directx_sdk:february_2006`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:distributed_transaction_coordinator:-`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.10.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:dynamics_ax:4.0:sp2`,
        fs:  `cpe:2.3:a:hp:storeonce_2610_iscsi_backup_system:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:dynamics_ax:2009:sp1`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:dynamics_ax:2012`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:dynamics_ax:2012:r2`,
        fs:  `cpe:2.3:a:oracle:goldengate:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:dynamics_ax:2012:r3`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:edge:-`,
        fs:  `cpe:2.3:h:buffalotech:wex-300_firmware:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:enhanced_mitigation_experience_toolkit:3.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:entourage:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.53:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:entourage:2001`,
        fs:  `cpe:2.3:a:oracle:industry_applications:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:entourage:2004`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:-`,
        fs:  `cpe:2.3:a:sap:commoncryptolib:8.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:-:-:x64`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:3.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:4.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:95`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:97`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(5\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:97:gold`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:97:sp1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:97:sp2`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.05.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:97:sr1`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.23:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:97:sr2`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2000`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:ecf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2000:gold`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2000:sp1`,
        fs:  `cpe:2.3:a:redhat:rhel_extras:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2000:sp1a`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2000:sp2`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2000:sp3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2000:sr1`,
        fs:  `cpe:2.3:a:microsoft:skype_for_business:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2000:sr1a`,
        fs:  `cpe:2.3:a:digium:asterisk:12.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2001`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2002`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2002:gold`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:tablet_pc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2002:sp1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2002:sp2`,
        fs:  `cpe:2.3:a:fusionforge:fusionforge:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2002:sp3`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_unix_and_linux_documentation:6.2.1032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2003`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2003:gold`,
        fs:  `cpe:2.3:a:aol:explorer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2003:sp1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2003:sp2`,
        fs:  `cpe:2.3:a:ibm:iss_proventia_desktop:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2003:sp3`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2004`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2007`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2007:sp2`,
        fs:  `cpe:2.3:a:conky:conky:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2007:sp3`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-00-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010:sp1`,
        fs:  `cpe:2.3:o:opensuse:opensuse:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010:sp1:~~~~x64~`,
        fs:  `cpe:2.3:a:samba:samba:3.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010:sp1:~~~x64~~`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010:sp1:~~~x86~~`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3a.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010:sp2:~~~~x64~`,
        fs:  `cpe:2.3:h:cisco:unity_server:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010:sp2:~~~~x86~`,
        fs:  `cpe:2.3:a:aventinobrand:aventino_brand:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010:sp2:~~~x64~~`,
        fs:  `cpe:2.3:a:powerdns:authoritative_server:2.9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2010:sp2:~~~x86~~`,
        fs:  `cpe:2.3:a:busybox:busybox:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2013`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2013::~~~~x64~`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2013::~~~x64~~`,
        fs:  `cpe:2.3:a:7-zip:p7zip:16.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2013::~~~x86~~`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2013:sp1`,
        fs:  `cpe:2.3:a:kde:koffice:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2013:sp1:~~rt~~~`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2013:sp3`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel:2016`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_2013_rt:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_for_mac:2011`,
        fs:  `cpe:2.3:a:packagekit_project:packagekit:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_for_mac:2016`,
        fs:  `cpe:2.3:a:symantec:symantec_antivirus_filtering_\&#43;for_domino:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_rt:2013:sp1`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_viewer:-`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_viewer:-:sp2`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_viewer:2003`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:3.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:excel_viewer:2007`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:9.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_instant_messenger:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_instant_messenger:4.5`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-02:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_instant_messenger:4.6`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:-`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:4.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:5.0`,
        fs:  `cpe:2.3:a:php:blog_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:5.0:sp1`,
        fs:  `cpe:2.3:a:samba:samba:3.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:5.0:sp2`,
        fs:  `cpe:2.3:a:perl:perl:5.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:5.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(3.3\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:5.5:sp1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:5.5:sp2`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:5.5:sp3`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:5.5:sp4`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2000`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ebh:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2000:sp1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2000:sp2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2000:sp3`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2003`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2003:sp1`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2003:sp2`,
        fs:  `cpe:2.3:a:xen:xen:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2007`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2007:sp1`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2007:sp2:x64`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2007:sp3`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2010`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2010:-:x64`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.0:rev31030:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2010:sp1`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2010:sp2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2010:sp3`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2013:cumulative_update_10`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2013:cumulative_update_11`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2013:cumulative_update_13`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2013:cumulative_update_16`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2013:cumulative_update_2`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2013:cumulative_update_3`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2013:cumulative_update_7`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2013:sp1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2016`,
        fs:  `cpe:2.3:a:emailarchitect:emailarchitect_email_server:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2016:cumulative_update_2`,
        fs:  `cpe:2.3:a:drupal:drupal:6.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_server:2016:cumulative_update_5`,
        fs:  `cpe:2.3:h:hp:0235a38p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:-`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:4.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:5.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:5.0:sp1`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:9.0.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:5.0:sp2`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:5.5`,
        fs:  `cpe:2.3:h:nec:ix1020:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:5.5:sp1`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:5.5:sp2`,
        fs:  `cpe:2.3:h:dell:latitude_xt3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:5.5:sp3`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:9.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:5.5:sp4`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:2000`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:2000:sp1`,
        fs:  `cpe:2.3:a:acronis:true_image_echo_enterprise_server:9.5.8018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:2000:sp2`,
        fs:  `cpe:2.3:a:oracle:commerce_guided_search_and_experience_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:2000:sp3`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:12.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:2003`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:2003:sp1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:2003:sp2`,
        fs:  `cpe:2.3:h:huawei:s9300:v100r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:exchange_srv:2007`,
        fs:  `cpe:2.3:a:wk12olslogin_project:wk12olslogin:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:expression_design:-`,
        fs:  `cpe:2.3:o:microsoft:virtual_machine_manager:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:expression_design:-:sp1`,
        fs:  `cpe:2.3:a:demandmedia:pluck_sitelife:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:expression_design:2`,
        fs:  `cpe:2.3:a:openx:openx:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:expression_design:3`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:expression_design:4`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:3.6.7.c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:expression_media:-`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.4.0.2540:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:expression_web:-`,
        fs:  `cpe:2.3:a:justin_dodge:hotblocks:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:expression_web:2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:file_transfer_manager:-`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system:2.2\(5b\)a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:forefront_client_security:1.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.6:1004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:forefront_endpoint_protection_2010:-`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:forefront_security:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.8:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:forefront_unified_access_gateway:2010`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:forefront_unified_access_gateway:2010:sp1`,
        fs:  `cpe:2.3:a:hp:bufferchm:110.0.180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:forefront_unified_access_gateway:2010:sp1_update1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:forefront_unified_access_gateway:2010:update1`,
        fs:  `cpe:2.3:a:mumble:mumble:1.2.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:forefront_unified_access_gateway:2010:update2`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:foundation_class_library:-`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:foundation_class_library:7.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.11:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage:-`,
        fs:  `cpe:2.3:a:louis_jimenez:custom_meta:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage:97`,
        fs:  `cpe:2.3:a:fluik:office_jerk_free:1.7.13:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage:98`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.04:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage:2000`,
        fs:  `cpe:2.3:a:ibm:http_server:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage:2002`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_link_for_microsoft_visio:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage:2003`,
        fs:  `cpe:2.3:a:telelogic:telelogic_license_server:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage:2003:sp3`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_products:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage_express:-`,
        fs:  `cpe:2.3:a:cisco:digital_content_manager:15.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage_server_extensions:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1299.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage_server_extensions:2000`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:frontpage_server_extensions:2002`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ftp_service:7.0`,
        fs:  `cpe:2.3:o:elecsyscorp:director_dnp3_outstation_kernel:2.6.32.11:ael1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ftp_service:7.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.19:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:greetings:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:greetings:2000`,
        fs:  `cpe:2.3:o:opcsystems:opc_systems.net:8.00.0023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:greetings:2002`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:groove:2007`,
        fs:  `cpe:2.3:o:siemens:simatic_s7-400_cpu_firmware:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:groove_server:2010`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:groove_server:2010:sp1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:grpconv:-`,
        fs:  `cpe:2.3:a:ca:license_software:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:help_file_viewer:-`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:home_publishing:-`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:home_publishing:2000`,
        fs:  `cpe:2.3:a:krollontrack:easyrecovery:6.0.9:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:host_integration_server:2004:sp1`,
        fs:  `cpe:2.3:a:erau:embry-riddle:1.4.04:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:hotmail:-`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:html_help:-`,
        fs:  `cpe:2.3:a:adobe:connect:9.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:html_help:1.4`,
        fs:  `cpe:2.3:a:yaml-fuer-drupal:linkchecker:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:html_help_workshop:-`,
        fs:  `cpe:2.3:a:simulationexams:itesetup:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:html_help_workshop:4.02.0002`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:html_help_workshop:4.03.0002`,
        fs:  `cpe:2.3:a:apache:struts:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:html_help_workshop:4.74`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.03:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:html_help_workshop:4.74.8702.0`,
        fs:  `cpe:2.3:a:teradata:sql_assistant:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:hyperlink_object_library:-`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:icm_color_management_module:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:-`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:3.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:3.0.1`,
        fs:  `cpe:2.3:a:janetter:janetter:2.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:3.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:3.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:3.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.0.1:sp1`,
        fs:  `cpe:2.3:a:f5:big-ip:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.0.1:sp2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.01`,
        fs:  `cpe:2.3:a:lxml:lxml:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.1`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.01:sp1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.20:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.5`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.40.308`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.40.520`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.70.1155`,
        fs:  `cpe:2.3:a:mcafee:email_and_web_security:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.70.1158`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.70.1215`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.70.1300`,
        fs:  `cpe:2.3:a:symantec:critical_system_protection:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.71.544`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.71.1008.3`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.71.1712.6`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.72.2106.8`,
        fs:  `cpe:2.3:a:paymentsplus:payments_plus:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.72.3110.8`,
        fs:  `cpe:2.3:a:telos:amhs:12.8.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:4.72.3612.1713`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.0`,
        fs:  `cpe:2.3:a:cacti:cacti:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.0.1`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.0.1:sp1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.0.1:sp2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.0.1:sp3`,
        fs:  `cpe:2.3:h:hp:laserjet_9040_mpf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.0.1:sp4`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.0518.10`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.0910.1309`,
        fs:  `cpe:2.3:a:barton:ngircd:19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.2014.0216`,
        fs:  `cpe:2.3:a:invensys:infusion_integrated_engineering_environment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.2314.1003`,
        fs:  `cpe:2.3:o:google:android:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.2516.1900`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.6.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.2614.3500`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a3\(2.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.2919.800`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.2919.3800`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.5.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.2919.6307`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.2920.0000`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:alpha1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.3103.1000`,
        fs:  `cpe:2.3:a:google:chrome:14.0.836.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.3105.0106`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.1.2.233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.3314.2101`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.3315.1000`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.3502.1000`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_web_standard:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.00.3700.1000`,
        fs:  `cpe:2.3:h:juniper:router_m40:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.01`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.1`,
        fs:  `cpe:2.3:o:redhat:linux:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.01:sp1`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.01:sp2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.01:sp3`,
        fs:  `cpe:2.3:a:microsoft:windows_services_for_unix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.01:sp4`,
        fs:  `cpe:2.3:h:huawei:te40:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.2.3`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.3.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.5`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.5:preview`,
        fs:  `cpe:2.3:a:php-nuke:inp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.5:sp1`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.5:sp2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.50.3825.1300`,
        fs:  `cpe:2.3:a:vmware:data_recovery:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.50.4030.2400`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.50.4134.0100`,
        fs:  `cpe:2.3:a:vmware:vsphere_host_update_utility:4.0.0.7797:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.50.4134.0600`,
        fs:  `cpe:2.3:o:yamaha:rt60w:5.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.50.4308.2900`,
        fs:  `cpe:2.3:a:softerra:ldap_administrator:2008.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.50.4522.1800`,
        fs:  `cpe:2.3:a:devicelock:devicelock:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:5.50.4807.2300`,
        fs:  `cpe:2.3:a:microsoft:access:2010:sp2:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.551:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6:sp1`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.2462.0000`,
        fs:  `cpe:2.3:a:cogentdatahub:opc_datahub:6.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.2479.0006`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.0.2600`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.2600.0000`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.0.2800`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.0.2800.1106`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.2800.1106`,
        fs:  `cpe:2.3:h:huawei:s9300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.0.2900`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.0.2900.2180`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.2900.2180`,
        fs:  `cpe:2.3:o:cisco:ciscoworks_1105_hosting_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.3663.0000`,
        fs:  `cpe:2.3:o:y-cam:yck003_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.3718.0000`,
        fs:  `cpe:2.3:a:spice_project:spice:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.3790.0000`,
        fs:  `cpe:2.3:a:hp:application_lifecycle_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.3790.1830`,
        fs:  `cpe:2.3:a:quotes_of_travis_barker_project:quotes_of_travis_barker:0.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:6.00.3790.3959`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.235:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7`,
        fs:  `cpe:2.3:o:nec:ews-ux_v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.0`,
        fs:  `cpe:2.3:a:dexis:imaging_suite:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.0:beta`,
        fs:  `cpe:2.3:a:janetter:janetter:2.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.0:beta1`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.0:beta2`,
        fs:  `cpe:2.3:a:hp:eva_3000_array_control_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.0:beta3`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.06:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.0.5730:unknown:gold`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.0.5730.11`,
        fs:  `cpe:2.3:a:goahead:goahead_webserver:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.00.5730.1100`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.2.2:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.00.6000.16386`,
        fs:  `cpe:2.3:a:linux-ha:heartbeat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:7.00.6000.16441`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:8`,
        fs:  `cpe:2.3:h:d-link:dcs-2132l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:8.0.6001`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:8.0.6001:beta`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie:9`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie_for_macintosh:5.0`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.14.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie_for_macintosh:5.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie_for_macintosh:5.1.1`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie_for_macintosh:5.2.3`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:ie_toolbar:-`,
        fs:  `cpe:2.3:a:rocomotion:p_link_compact:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iemobile:6.8`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iemobile:6.12`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:1.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:2.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update3:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:3.0`,
        fs:  `cpe:2.3:a:vmware:player:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:4.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:4.0:alpha`,
        fs:  `cpe:2.3:a:hexagon:erdas_apollo_ecwp:13.00.0000:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:5.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:5.1`,
        fs:  `cpe:2.3:a:usebb:usebb:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:5.06`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:6.0`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:6.0:beta`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:7.0`,
        fs:  `cpe:2.3:a:fractalconcept:mod_lisp:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:7.5`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:iis:8.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:08.0.01d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:index_server:-`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:index_server:2.0`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:indexing_service:-`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.14.4707:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:indexing_service:-::windows_2000`,
        fs:  `cpe:2.3:o:juniper:junos:9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:infopath:-`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:infopath:2003`,
        fs:  `cpe:2.3:a:apple:safari:4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:infopath:2007`,
        fs:  `cpe:2.3:a:litter_penguin:web_browser_\&amp;_explorer:2.0.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:infopath:2010:sp1:x64`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:6.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:infopath:2010:sp1:x86`,
        fs:  `cpe:2.3:a:spice_project:spice:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:infopath:2013`,
        fs:  `cpe:2.3:a:apache:http_server:0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:infotech_storage_system_library:-`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:interdev:1.0`,
        fs:  `cpe:2.3:a:bikersromagna:bikers_romagna:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:interix:-`,
        fs:  `cpe:2.3:a:appthemes:classipress:3.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:interix:2.2`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_authentication_service_helper_com_component:-`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:5.01:sp4`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.5.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:6`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.04:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:6:sp1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:7`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:7.0.5730`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_designer:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:8`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:9`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.0.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:10`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:11:-`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.27.362:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:11:developer-preview`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.03.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_explorer:11:release-preview`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:95:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:1.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:2.0`,
        fs:  `cpe:2.3:a:advantech:webaccess:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:3.0`,
        fs:  `cpe:2.3:a:findingscience:mod_auth_openid:0.4:*:*:*:*:apache:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:3.0:unknown:unknown:ja`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:3.0:unknown:unknown:ko`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:4.2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:3.0:unknown:unknown:zh`,
        fs:  `cpe:2.3:a:x:libxcb:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:4.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:4.0:alpha`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:4.0:unknown:unknown:ja`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:4.0:unknown:unknown:ko`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:4.0:unknown:unknown:zh`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:5.0`,
        fs:  `cpe:2.3:a:emerson:deltav_workstation:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:5.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:6.0`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_server:6.0:beta`,
        fs:  `cpe:2.3:a:richard_cook:rgpg:0.2.2:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:internet_information_services:5.0`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:isa_server:-`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:isa_server:2000`,
        fs:  `cpe:2.3:a:hp:color_laserjet_4600_toolbox:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:isa_server:2000:fp1`,
        fs:  `cpe:2.3:a:fermononrespiri:fermononrespiri_mobile:3.8.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:isa_server:2000:sp1`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:isa_server:2000:sp2`,
        fs:  `cpe:2.3:a:apple:quicktime:6.2.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:isa_server:2004`,
        fs:  `cpe:2.3:h:selinc:sel-3530:r123-v0-z002001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:isa_server:2004:sp1`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:isa_server:2004:sp2`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:java_virtual_machine:-`,
        fs:  `cpe:2.3:a:condusiv:diskeeper:10.0.608:*:*:*:server_standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:java_virtual_machine:1.1`,
        fs:  `cpe:2.3:a:jzip:jzip:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:java_virtual_machine:5.0.0.3810`,
        fs:  `cpe:2.3:a:qlogic:sansurfer:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(1\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:3.5`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:3.5.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:3.51`,
        fs:  `cpe:2.3:a:microsoft:visual_interdev:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:4.0`,
        fs:  `cpe:2.3:a:redhat:libtirpc:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:4.0:sp1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.05.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:4.0:sp2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:4.0:sp3`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:4.0:sp4`,
        fs:  `cpe:2.3:a:adobe:flash_player:22.0.0.192:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:4.0:sp5`,
        fs:  `cpe:2.3:a:idevspot:isupport:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jet:4.0.8618.0`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jscript:5.6`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jscript:5.7`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:jscript:5.8`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:learning_essentials:-`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:learning_essentials:1.0`,
        fs:  `cpe:2.3:o:honeywell:excel_web_xl_1000c50u_52_i\/o_uukl:2.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:learning_essentials:1.1`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:learning_essentials:1.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.277:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:live_meeting:2007`,
        fs:  `cpe:2.3:h:hp:ce994a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:live_messenger:9.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.801:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2010::attendant_x64`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2010::attendant_x86`,
        fs:  `cpe:2.3:a:nih:libzip:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2010::attendee`,
        fs:  `cpe:2.3:a:oracle:database_server:7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2010::x64`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2010::x86`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2013`,
        fs:  `cpe:2.3:h:logitech:cordless_freedom_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2013:-:x64`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2013:-:x86`,
        fs:  `cpe:2.3:a:microsoft:sysinternals_debugview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync:2013:sp1`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync_basic:2013:-:x64`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp2:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync_basic:2013:-:x86`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync_room_system:-`,
        fs:  `cpe:2.3:a:op5:monitor:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync_server:2010`,
        fs:  `cpe:2.3:a:citadel:ux:6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:lync_server:2013`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:malware_protection_engine:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:malware_protection_engine:1.1.10600.0`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:malware_protection_engine:1.1.10701.0`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:media_player:6.3`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:media_player:6.4`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:media_player:7`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:message_compiler:-`,
        fs:  `cpe:2.3:a:microsoft:sql_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:message_queuing:-`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta33:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:metadirectory_services:-`,
        fs:  `cpe:2.3:o:oracle:linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:metadirectory_services:2.2`,
        fs:  `cpe:2.3:a:opalvoip:portable_tool_library:2.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:redhat:stronghold:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:openx:openx:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.0:beta0001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ca:etrust_audit_irecorder:1.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(4\)sr1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:apple:safari:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:gnu:libc:5.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:h:dell:kace_k1100s_systems_management_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1029:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:wibu:codemeter_runtime:5.10c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.0.899:p14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:o:netbsd:netbsd:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.1:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:kde:ark:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:novell:client_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:netscape:navigator:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp1:media_center:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.core:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:vmware:server:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.core:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:h:ibm:ds4700:1814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.core:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.core:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:hp:operations_agent:11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.core:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.core:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:h:nortel:ip_phone_2004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.core:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.cors:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.cors:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:splunk:splunk:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.cors:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-02-\/d:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.cors:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:hp:toolbox:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.cors:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.cors:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.cors:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2irc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:lynx:lynx:2.8.8:dev.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:h:logitech:cordless_freedom_itouch_keyboard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:citrix:xenapp_advanced_configuration:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:new-year-firework_project:new-year-firework:1.1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.23:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:emulex:hbanyware:3.3a14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:samba:samba:4.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.498:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:apache_friends:xampp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.localization:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.localization:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.localization:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.localization:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.localization:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.localization:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.5:*:free:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.localization:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:emc:powerpath:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:5.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:david_king:vino:3.1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(3\)sn1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:06-70-\/g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:x:libxvmc:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:janetter:janetter:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:h:enterasys:6h352.25:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:iss:site_protector_security_fusion:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:lightningtools:deliverpoint:12.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(3e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:lindo:lingo:11.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:h:supermicro:x9spu-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:ebr:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)xn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6ecb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:digium:asterisk:12.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.0.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:2015.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.0.3::~~~asp.net~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.4.2.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.1.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:hp:ole_point_of_sale_driver:1.13.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:digia:qt:4.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.1.2::~~~asp.net~~`,
        fs:  `cpe:2.3:a:openbsd:openssh:7.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft_data_access_components:-`,
        fs:  `cpe:2.3:a:compaq:sanworks_resource_monitor:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft_forefront_protection_2010:-::~~~exchange_server~~`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:microsoft_tech_companion:1.0.6::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf014:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:microsoft:mn-500_wireless_base_station:-`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.30.020.1926:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:money:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.0\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:money:2000`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:money:2001`,
        fs:  `cpe:2.3:a:altiris:inventory_merge_module_msi:6.1.1075.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:money:2006`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:-`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:1.0`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:2.0`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:3.1`,
        fs:  `cpe:2.3:a:microsoft:outlook:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:3.2`,
        fs:  `cpe:2.3:o:cisco:vpn_500_concentrator:6.0.21.0002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:3.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:4.0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.0-103\(a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:4.01`,
        fs:  `cpe:2.3:a:cisco:catalyst_29xx_supervisor_software:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:4.01:::ru`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:5.0`,
        fs:  `cpe:2.3:a:hero-maps-pro_project:hero-maps-pro:2.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:6.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:6.2`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:6.21`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:6.22`,
        fs:  `cpe:2.3:a:adobe:pdistiller:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:ms-dos:7.0`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msde:-`,
        fs:  `cpe:2.3:o:cisco:rv110w_wireless-n_vpn_firewall_firmware:1.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msde:2000`,
        fs:  `cpe:2.3:a:emc:rsa_identity_management_and_governance:6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_chat_control:-`,
        fs:  `cpe:2.3:a:symantec:ams:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:1.0`,
        fs:  `cpe:2.3:a:vmware:tools:8.0.2.16474:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:2.2`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:3.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:3.6`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.1:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:4.0`,
        fs:  `cpe:2.3:a:skype:skype:3.8.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:4.5`,
        fs:  `cpe:2.3:a:hp:photosmart_disclabel_printondisc:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:4.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.7:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:4.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.450:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:6.0`,
        fs:  `cpe:2.3:a:apple:safari:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:6.1`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:6.2`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.1\(2\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:7.0`,
        fs:  `cpe:2.3:a:atlassian:jira:2.4.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger:7.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger_service:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger_service_for_exchange:4.5`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_messenger_service_for_exchange:4.6`,
        fs:  `cpe:2.3:a:symantec:veritas_commandcentral:5.1.294.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_setup_bulletin_board_services:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:msn_setup_bulletin_board_services:4.71.0.10`,
        fs:  `cpe:2.3:a:mcafee:dlp_management_tools:2.2.300.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:netmeeting:-`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.9:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:netmeeting:2.1`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:netmeeting:3`,
        fs:  `cpe:2.3:a:apache:archiva:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:netmeeting:3.0.1`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_form_module:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:netmeeting:3.0.1_4.4.3385`,
        fs:  `cpe:2.3:a:digium:asterisk:11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:netmeeting:3.01`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:network_monitor:-`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:-`,
        fs:  `cpe:2.3:a:john_catania:server_scripts_setup:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:3.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_8510csr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:4.0`,
        fs:  `cpe:2.3:h:cisco:xr_12410:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:4.3`,
        fs:  `cpe:2.3:h:siemens:scalance_x204irt:-:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:95`,
        fs:  `cpe:2.3:a:inline:ihtml:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:97`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:97:::ja`,
        fs:  `cpe:2.3:a:apple:cups:1.3:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:97:::ko`,
        fs:  `cpe:2.3:a:busybox:busybox:1.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:97:::zh`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:98`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p214:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2000`,
        fs:  `cpe:2.3:a:ibm:sametime:8.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2000:sp1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.332:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2000:sp2`,
        fs:  `cpe:2.3:a:netshinesoftware:com_netinvoice:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2000:sp3`,
        fs:  `cpe:2.3:a:apple:apple_mobile_device_support:3.3.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2001`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2001:sr1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2001:sr1:mac_os`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2002:sp3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2003`,
        fs:  `cpe:2.3:a:thingslabo:things_bbs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2003::~~student_and_teacher~~~`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2003::student_teacher`,
        fs:  `cpe:2.3:a:quest:toad_data_modeler:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2003:sp1`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_monitor_solution_for_dell_servers:6.1.1063:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2003:sp2`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2003:sp3`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2004`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2004::mac`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::basic`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::enterprise`,
        fs:  `cpe:2.3:a:libass_project:libass:0.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::home_and_student`,
        fs:  `cpe:2.3:a:xnotestopwatch:xnote_stopwatch:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::mobile`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::professional`,
        fs:  `cpe:2.3:a:ca:etrust_integrated_threat_management:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::professional_plus`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::small_business`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::standard`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(3\)m7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007::ultimate`,
        fs:  `cpe:2.3:a:apache:camel:2.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007:sp1`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007:sp1:professional`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007:sp2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007:sp2:professional`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2007:sp3`,
        fs:  `cpe:2.3:a:apache:mod_python:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2008::mac`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2010`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2010::x86`,
        fs:  `cpe:2.3:a:hp:hp-ux_containers:a.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2010:sp1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2010:sp1:x64`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2010:sp1:x86`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2010:sp2:x64`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2010:sp2:x86`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2011::mac`,
        fs:  `cpe:2.3:a:cms-center:simple_web_content_management_system:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2013`,
        fs:  `cpe:2.3:h:xerox:document_centre_480:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2013::~~~rt~~`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2013:-:~-~-~-~x64~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00-06:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2013:-:~-~-~-~x86~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2013:sp1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2013:sp1:~~~rt~~`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:2016`,
        fs:  `cpe:2.3:a:hummingbird:exceed:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:xp`,
        fs:  `cpe:2.3:a:fortinet:connect:14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:xp:sp1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:xp:sp2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.777.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office:xp:sp3`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_2013_rt:-`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_communications_server:-`,
        fs:  `cpe:2.3:a:cisco:catalyst_29xx_supervisor_software:2.1.502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_communicator:-`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1a_pk4_bl21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_communicator:2005`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_communicator:2007`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_communicator:2007:r2`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_compatibility_pack:-:sp2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_compatibility_pack:-:sp3`,
        fs:  `cpe:2.3:a:red-gate:sql_backup:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_compatibility_pack:2007:sp2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_converter_pack:-`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_infopath:-`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_infopath:2003`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_infopath:2003:sp1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_multilingual_user_interface_pack:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_multilingual_user_interface_pack:2003`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_multilingual_user_interface_pack:2003:sp2`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_proofing_tools:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)jk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_proofing_tools:2003`,
        fs:  `cpe:2.3:h:cisco:rv042g_dual_gigabit_wan_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_proofing_tools:2003:sp2`,
        fs:  `cpe:2.3:a:altiris:helpdesk_solution_documentation:6.0.1044:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_apps:2010`,
        fs:  `cpe:2.3:a:google:chrome:6.0.410.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_apps:2010:sp1`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_apps:2010:sp2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_apps:2013`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_apps_server:2013`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_components:-`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_components:2000`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_components:2002`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_components:2003:sp3`,
        fs:  `cpe:2.3:a:google:v8:3.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_web_components:xp`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_word_viewer:-`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_word_viewer:2003`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:office_word_viewer:2003:sp3`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:onenote:-`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:onenote:2003`,
        fs:  `cpe:2.3:h:cisco:asr_1002-x_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:onenote:2007`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:onenote:2007:sp3`,
        fs:  `cpe:2.3:a:sir:gnuboard:4.31.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:onenote:2013`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_72:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:open_xml_file_format_converter:-::mac`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:1.1`,
        fs:  `cpe:2.3:a:tumbleweed:mailgate_email_firewall:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:2.0`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62j:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:2.0.3790.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:3.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:3.1.4000.1830`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:4.0`,
        fs:  `cpe:2.3:a:kicksend:kicksend\:_share_\&amp;_print_photos:3.3.2.18:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:4.0.6001`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:4.5`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:4.5.6001`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:orca:11.6`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:-`,
        fs:  `cpe:2.3:h:hp:t820:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:97`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:98`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2000`,
        fs:  `cpe:2.3:a:actuate:iserver:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2000:sp2`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2000:sp3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2000:sr1`,
        fs:  `cpe:2.3:a:pip-installer:pip:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2002`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2002:sp1`,
        fs:  `cpe:2.3:a:apple:safari:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2002:sp2`,
        fs:  `cpe:2.3:a:microweber:microweber:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2002:sp3`,
        fs:  `cpe:2.3:a:safenet-inc:administrative_management_center:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2003`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2003:sp1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2003:sp3`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2007`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2007:sp1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2007:sp2`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2007:sp3`,
        fs:  `cpe:2.3:h:brocade:silkworm_12000_director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2010:sp1:~~~~x64~`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2010:sp1:~~~x64~~`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2010:sp1:~~~x86~~`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2010:sp2:~~~~x64~`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2010:sp2:~~~x64~~`,
        fs:  `cpe:2.3:a:synology:cloud_station:3.1-3317:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2010:sp2:~~~x86~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.10.169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2013`,
        fs:  `cpe:2.3:a:splunk:splunk:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2013:-:~-~-~-~x64~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2013:-:~-~-~-~x86~`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2013:sp1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2016`,
        fs:  `cpe:2.3:a:exim:exim:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:2016::~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:umn:mapserver:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook:xp`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook.com:7.8.2.10.47.7365::~~~android~~`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook.com:7.8.2.11.48.4848::~~~android~~`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook.com:7.8.2.12.49.0430::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook.com:7.8.2.12.49.5701::~~~android~~`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook.com:7.8.2.12.49.6434::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1\(2.49\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook.com:7.8.2.12.49.7090::~~~android~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg219a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook.com:7.8.2.12.49.7564::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:net.commerce:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_2013_rt:-`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.57.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_2013_rt:-:sp1`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_connector:2002`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.3\(0.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:-`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:4.0`,
        fs:  `cpe:2.3:a:digium:asterisk:14.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:4.01`,
        fs:  `cpe:2.3:a:phpspot:php_bbs_rss_builder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:4.01:sp2`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:4.5`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:4.72.2106.4`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:4.72.3120.0`,
        fs:  `cpe:2.3:o:cisco:catos:7.1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:4.72.3612.1700`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.0`,
        fs:  `cpe:2.3:a:sap:hybris:5.4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.0.1`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.0.2`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.0.3`,
        fs:  `cpe:2.3:a:ca:etrust_siteminder_policy_server:6.0.506.223:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.01`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.279:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.02`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.6:mp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.5`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.5:sp1`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:5.5:sp2`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:6.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.7.1r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:6.00.2800.1106`,
        fs:  `cpe:2.3:a:cdotech:edcl_aimt:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:6.00.2900.2180`,
        fs:  `cpe:2.3:a:apache:activemq_artemis:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:6.00.2900.5512`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_express:7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5.3\)wc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:a:google:chrome:9.0.600.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_rt:2013:sp1`,
        fs:  `cpe:2.3:h:hp:laserjet_cm3530_multifuction_printer:cc520a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_web_access:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_web_access:2003`,
        fs:  `cpe:2.3:a:google:chrome:10.0.634.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:outlook_web_access:2016`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:personal_web_server:-`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:personal_web_server:1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p184:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:personal_web_server:1.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:personal_web_server:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(1\)ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:personal_web_server:4.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1047.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:photodraw:-`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.0.1:*:*:*:*:wotlab_burning_board:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:photodraw_2000:1.0`,
        fs:  `cpe:2.3:a:infradead:openconnect:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:picture_it:-`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0404hf-u-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:picture_it:7.0`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:picture_it:9`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0804hf-al-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:picture_it:2002`,
        fs:  `cpe:2.3:a:erlang:crypto:2.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pinyin_ime:2010::~~~~x64~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pinyin_ime:2010::~~~x64~~`,
        fs:  `cpe:2.3:a:radius_extension_project:radius:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pinyin_ime:2010::~~~x86~~`,
        fs:  `cpe:2.3:a:allroundautomations:pl\/sql_developer:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:plus:-`,
        fs:  `cpe:2.3:a:teamst:testlink:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_ie:-`,
        fs:  `cpe:2.3:a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_ie:1.0`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_ie:1.1`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_ie:2.0`,
        fs:  `cpe:2.3:a:samba:samba:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_ie:3.0`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:12:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_ie:4.0`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0008:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_ie:2002`,
        fs:  `cpe:2.3:o:freebsd:freebsd:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_ie:2003`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_internet_explorer:-`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.0.0-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_internet_explorer:1.0`,
        fs:  `cpe:2.3:a:hummingbird:exceed:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_internet_explorer:1.1`,
        fs:  `cpe:2.3:a:lookoutsoftware:lookout:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_internet_explorer:2.0`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cpk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_internet_explorer:3.0`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_internet_explorer:4.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.590.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_internet_explorer:2002`,
        fs:  `cpe:2.3:a:augeas:augeas:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pocket_internet_explorer:2003`,
        fs:  `cpe:2.3:a:avaya:intuity_audix_lx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:-`,
        fs:  `cpe:2.3:a:mingle_forum_project:mingle_forum:1.0.33.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:95`,
        fs:  `cpe:2.3:a:mollify:mollify:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:97`,
        fs:  `cpe:2.3:a:teradata:tpump:13.10.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:97:::ja`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:97:::ko`,
        fs:  `cpe:2.3:a:inductiveautomation:ignition:7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:97:::zh`,
        fs:  `cpe:2.3:a:digium:asterisk:11.21.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:98`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2000`,
        fs:  `cpe:2.3:a:microsoft:silverlight:5.0.60818.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2000:sp2`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2000:sp3`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2000:sr1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2001`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:1.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2002`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.291:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2002:sp1`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.10.1006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2002:sp2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2002:sp3`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2003`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(4a\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2003:sp1`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2003:sp2`,
        fs:  `cpe:2.3:a:oracle:retail_applications:13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2003:sp3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2004`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2007`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.3:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2007:sp2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2007:sp3`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.37:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2010:sp2`,
        fs:  `cpe:2.3:a:basercms:basercms:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2013`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2013:sp1`,
        fs:  `cpe:2.3:a:viscomsoft:image_viewer_cp_pro_sdk:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2013:sp1:~~rt~~~`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint:2016`,
        fs:  `cpe:2.3:a:oracle:application_server:10.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint_for_mac:2011`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint_for_mac:2016`,
        fs:  `cpe:2.3:a:docker:docker:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint_rt:2013:sp1`,
        fs:  `cpe:2.3:a:openkm:openkm:6.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint_viewer:2003`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4010:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint_viewer:2007`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:powerpoint_viewer:2007:sp2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:producer:-`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:-`,
        fs:  `cpe:2.3:a:login_widget_with_shortcode_project:login_widget_with_shortcode:3.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:98`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2000`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2000:sr1`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2002`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2002:sp1`,
        fs:  `cpe:2.3:a:agilebits:knox:2.0.6:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2003`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.40.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2003:sp1`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2003:sp2`,
        fs:  `cpe:2.3:a:splunk:splunk:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2003:sp3`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2007`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2007:sp1`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project:2007:sp2`,
        fs:  `cpe:2.3:a:shavlik:netchk_compliance:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_multilingual_user_interface_pack:-`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_multilingual_user_interface_pack:2003`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_multilingual_user_interface_pack:2003:sp2`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:a:websense:websense_content_content_gateway:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_server:-`,
        fs:  `cpe:2.3:a:anecms:anecms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_server:2002`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_server:2003`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_server:2010`,
        fs:  `cpe:2.3:a:microsoft:office_compatibility_pack:-:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_server:2010:sp1`,
        fs:  `cpe:2.3:a:autodesk:3ds_max:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_server:2010:sp2`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_server:2013`,
        fs:  `cpe:2.3:a:rapidleech:rapidleech:2.3:rev43_svn_r397:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:project_server:2013:sp1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.02.165:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:proxy_server:-`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:proxy_server:2.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psexec:-`,
        fs:  `cpe:2.3:a:idevspot:isupport:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psexec:1.53`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psgetsid:-`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psgetsid:1.40`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:rc5:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psinfo:-`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psinfo:1.60`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pskill:-`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pskill:1.02`,
        fs:  `cpe:2.3:a:gajim:gajim:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pslist:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pslist:1.25`,
        fs:  `cpe:2.3:a:ca:etrust_audit_datatools:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psloglist:-`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psloglist:2.50`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pspasswd:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psservice:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psservice:2.11`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psshutdown:-`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:psshutdown:2.31`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pssuspend:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:pssuspend:1.04`,
        fs:  `cpe:2.3:o:suse:suse_linux:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:-`,
        fs:  `cpe:2.3:h:netgear:wgr614:v7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2000`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2002`,
        fs:  `cpe:2.3:a:gephi:gephi:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2002:sp3`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2003`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2003:sp3`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2007`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2007:sp2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.0.148.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2010:sp2`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp4:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher:2013`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_agent_core:11.0.17217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:publisher_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:register_server:-`,
        fs:  `cpe:2.3:a:emc:replication_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:remote_desktop_connection:2.1`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:remote_desktop_connection:5.1.2600.2180`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:remote_desktop_connection:6.1`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:remote_desktop_connection:7.0`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_30-20_rtvz33020as:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:remote_desktop_protocol:-`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:report_viewer:2005:sp1`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.26.1888:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:report_viewer:2008`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:rich_textbox_control:-`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:rich_textbox_control:6.0`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:security_compliance_manager:1.0.0.0`,
        fs:  `cpe:2.3:a:site2nite:big_truck_broker:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:security_compliance_manager:1.1.1.0`,
        fs:  `cpe:2.3:o:apple:watchos:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:security_compliance_manager:1.1.2.0`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:security_compliance_manager:1.1.3.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:security_compliance_manager:2.0.20.0`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:security_compliance_manager:2.5.40`,
        fs:  `cpe:2.3:o:yahama:rt56v:4.07.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:security_compliance_manager:3.0:beta`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_server:3.6:eca:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:server:2008`,
        fs:  `cpe:2.3:o:apple:mac_os:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:server_message_block:1.0`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:0.5.125.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:server_service:-`,
        fs:  `cpe:2.3:a:winzip:winzip:11.2.8094:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:service_bus:1.0`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:service_bus:1.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:services:-`,
        fs:  `cpe:2.3:a:microsoft:asp.net_signalr:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:services:2.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:services:3.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_designer:2007`,
        fs:  `cpe:2.3:a:nortel:optivity_net_architect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_designer:2007:sp1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_designer:2007:sp2`,
        fs:  `cpe:2.3:a:oracle:database_server_lite:5.0.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_designer:2007:sp3`,
        fs:  `cpe:2.3:h:netgear:r6250:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_designer:2010:sp1`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.0.41:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_designer:2010:sp2`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_designer:2013`,
        fs:  `cpe:2.3:a:nijskens_raf:admintools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_designer:2013:sp1`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_foundation:2010`,
        fs:  `cpe:2.3:a:google:urchin:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_foundation:2010:sp1`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_foundation:2010:sp2`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:56.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_foundation:2013`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_foundation:2013:sp1`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_portal_server:-`,
        fs:  `cpe:2.3:h:nvidia:geforce_gtx_965m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_portal_server:2001`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_portal_server:2001:sp1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_portal_server:2001:sp2`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_portal_server:2001:sp2a`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_portal_server:2003`,
        fs:  `cpe:2.3:a:google:earth:5.2.1.1547:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_portal_server:2003:sp1`,
        fs:  `cpe:2.3:a:john_morrissey:mod_ldap_userdir:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_portal_server:2003:sp3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.26:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:-`,
        fs:  `cpe:2.3:a:symantec:workspace_streaming:6.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2007`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2007:sp1`,
        fs:  `cpe:2.3:a:gnu:binutils:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2007:sp2`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.1.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2007:sp3`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2010`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2010:sp1`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2010:sp2`,
        fs:  `cpe:2.3:h:selinc:sel-3530-4:r107-v0-z001001-d20100818:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2013`,
        fs:  `cpe:2.3:a:philips:xperconnect:1.5.4.053:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2013:sp1`,
        fs:  `cpe:2.3:a:unisys:sma_user_interface:4.25.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server:2016`,
        fs:  `cpe:2.3:a:ni:measurementstudio:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_server_client_components_sdk:2013`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_services:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_services:2.0`,
        fs:  `cpe:2.3:a:barcodewiz:barcode_activex_control:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_services:3.0`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.68.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_services:3.0:sp3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_team_services:-`,
        fs:  `cpe:2.3:a:colorscore_project:colorscore:0.0.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sharepoint_team_services:2002`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.50401.0`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.50524.00`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.11:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.50826.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.50917.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.32:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.51204.0`,
        fs:  `cpe:2.3:o:google:chrome_os:0.9.126.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.60129.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.60310.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1o\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.60531.0`,
        fs:  `cpe:2.3:a:ibm:maximo_industry_solutions:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.60831.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.0.603310.0`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.1.10111`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:4.1.10111.0`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.0`,
        fs:  `cpe:2.3:a:samba:samba:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.0.60401.0`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.0.60818.0`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.5a:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.0.60818.0:rc`,
        fs:  `cpe:2.3:a:david_king:vino:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.0.61118.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.1.10411.0`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.1.20125.0`,
        fs:  `cpe:2.3:a:findingscience:mod_auth_openid:0.5:*:*:*:*:apache:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.1.20513.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.1.20913.0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:silverlight:5.1.30214.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:site_server:-`,
        fs:  `cpe:2.3:a:quagga:quagga:0.96.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:site_server:2.0`,
        fs:  `cpe:2.3:a:atmail:atmail:6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:site_server:3.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:site_server:3.0:unknown:commerce`,
        fs:  `cpe:2.3:a:exim:exim:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:site_server_commerce:3.0`,
        fs:  `cpe:2.3:a:sap:sql_anywhere:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:skype_for_business:2016`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.2.3:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:skype_for_business_server:2015`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:11.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:small_business_server:-`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:small_business_server:2000`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:small_business_server:2003`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:small_business_srv:-`,
        fs:  `cpe:2.3:a:mit:pgp_public_key_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:small_business_srv:2000`,
        fs:  `cpe:2.3:a:sap:business_one_2005-a:6.80.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:small_business_srv:2003`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sna_server:-`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sna_server:1.0`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.94:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sna_server:2.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0056:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sna_server:2.11`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sna_server:3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sna_server:4.0`,
        fs:  `cpe:2.3:a:hp:data_protector:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:-`,
        fs:  `cpe:2.3:a:opera:opera_mini:7.4:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2irf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:6.5`,
        fs:  `cpe:2.3:a:sliding_social_icons_project:sliding_social_icons:1.61:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0:alpha`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0:sp1`,
        fs:  `cpe:2.3:h:hp:j9451a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0:sp1_alpha`,
        fs:  `cpe:2.3:a:sun:one_messaging_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0:sp2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0:sp2_alpha`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0:sp3`,
        fs:  `cpe:2.3:a:gnome:evolution:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0:sp3_alpha`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:7.0:sp4`,
        fs:  `cpe:2.3:a:eleanor-cms:eleanor_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2000`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2000:gold`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2000:sp1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2000:sp2`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2000:sp3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(58\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2000:sp3a`,
        fs:  `cpe:2.3:a:yassl:cyassl:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2000:sp4`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:9.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2000:sp4:analysis_services`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005`,
        fs:  `cpe:2.3:o:xen:xen:4.9.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp2`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp3`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp3:express`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.02:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp3:express_advanced_services`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp3:itanium`,
        fs:  `cpe:2.3:h:supermicro:x9scff-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp3:x64`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp4`,
        fs:  `cpe:2.3:a:cabextract:cabextract:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp4:express`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp4:express_advanced_services`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.13:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp4:itanium`,
        fs:  `cpe:2.3:a:gnu:a2ps:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp4:x64`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0545:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2005:sp4:x86`,
        fs:  `cpe:2.3:a:pricegong:pricegong:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008`,
        fs:  `cpe:2.3:a:phpwiki_project:phpwiki:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2:itanium`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.09.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2:x64`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2:x86`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2_sp1:itanium`,
        fs:  `cpe:2.3:h:hp:elitebook_840_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2_sp1:x64`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.25.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2_sp1:x86`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2_sp2:itanium`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2_sp2:x64`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:r2_sp2:x86`,
        fs:  `cpe:2.3:a:hp:hppiofiles:0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp1:itanium`,
        fs:  `cpe:2.3:h:apple:imac:mb418xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp1:x32`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp1:x64`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp2:itanium`,
        fs:  `cpe:2.3:a:apache:apache-ssl:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp2:x32`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp2:x64`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp2:x86`,
        fs:  `cpe:2.3:h:netgear:wgr614:v6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp3:itanium`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.15-1.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp3:x32`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp3:x64`,
        fs:  `cpe:2.3:a:wppa.opajaap:wp-photo-album-plus:5.0.3.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2008:sp3:x86`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04s:sp8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012:-:business_intelligence`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012:-:compact`,
        fs:  `cpe:2.3:a:smarty:smarty:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012:-:developer`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012:-:enterprise`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012:-:express`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.viewfeatures:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012:-:standard`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_r5:5.0.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012:-:web`,
        fs:  `cpe:2.3:o:windriver:vxworks:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2012:sp3`,
        fs:  `cpe:2.3:a:bea:tuxedo:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2014`,
        fs:  `cpe:2.3:a:borland:starteam_sdk_for_.net:10.0.58.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2014:sp1`,
        fs:  `cpe:2.3:a:veritas:netbackup:5.0.0:mp3:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2014:sp2`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2016`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server:2016:sp1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.40_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server_desktop_engine:-`,
        fs:  `cpe:2.3:a:algosec:fireflow:6.3:b230:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server_desktop_engine:2000`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_server_reporting_services:2000:sp2`,
        fs:  `cpe:2.3:a:citrix:sharefile_mobile:2.4.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:6.0`,
        fs:  `cpe:2.3:a:samba:samba:2.2.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:6.5`,
        fs:  `cpe:2.3:a:tincan:phplist:1.1.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0:alpha`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0:sp1`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0:sp1_alpha`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_115:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0:sp2`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.10.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0:sp2_alpha`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0:sp3`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc9:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0:sp3_alpha`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:7.0:sp4`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:2000`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:2000:gold`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:2000:sp1`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.02.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:2000:sp2`,
        fs:  `cpe:2.3:a:microsoft:excel:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:2000:sp3`,
        fs:  `cpe:2.3:a:novell:web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sql_srv:2000:sp3a`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:step-by-step_interactive_training:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:subsystem_for_unix-based_applications:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sysinternals:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.0.1.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sysinternals_debugview:-`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sysinternals_debugview:4.71`,
        fs:  `cpe:2.3:a:teradata:tpump:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sysinternals_pstools:-`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sysinternals_pstools:2.04`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:sysinternals_pstools:2.05`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0b.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.net.http:4.1.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.net.http:4.3.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.net.http.winhttphandler:4.0.1::~~~asp.net~~`,
        fs:  `cpe:2.3:a:altiris:patch_management_for_windows_language_pack:6.2.3644:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.net.http.winhttphandler:4.3.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.net.security:4.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.net.security:4.3.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.0:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.net.websockets.client:4.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.86:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.net.websockets.client:4.3.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.text.encodings.web:4.0.0::~~~asp.net~~`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system.text.encodings.web:4.3.0::~~~asp.net~~`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system_center_configuration_manager:-`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system_center_operations_manager:2007:r2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:system_center_operations_manager:2007:sp1`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:-`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:1.2`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:1.2:sp1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:1.2:sp2`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:1.2:sp3`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:1.2:sp4`,
        fs:  `cpe:2.3:o:hp:thinpro:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:2.0`,
        fs:  `cpe:2.3:a:google:sketchup:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:2.0:sp1`,
        fs:  `cpe:2.3:a:ca:unicenter_exchange_management_console:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:2.50.2726`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:2003`,
        fs:  `cpe:2.3:a:quest:intrust:10.4.0.853:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:2007`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_server:2012`,
        fs:  `cpe:2.3:a:yahoo:yahoo\!_browser:1.4.5:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:-`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:1.2`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:1.2:sp1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:1.2:sp2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:1.2:sp3`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:1.2:sp4`,
        fs:  `cpe:2.3:a:avaya:communication_manager:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:2.0`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.1.2_b26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:2.0:sp1`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:systems_management_srv:2003`,
        fs:  `cpe:2.3:a:xceed:xceed_components:3.2.8312.9580:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:telnet_client:-`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:telnet_client:5.1.2600.2180`,
        fs:  `cpe:2.3:h:cabletron:6h302-48:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:teredo:-`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:terminal_server:-`,
        fs:  `cpe:2.3:a:vips:vips:7.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:tsac_activex_control:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p380:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:urlscan:-`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:urlscan:2.5`,
        fs:  `cpe:2.3:a:google:checkout-php:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:vbscript:5.6`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:vbscript:5.7`,
        fs:  `cpe:2.3:a:samba:samba:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:vbscript:5.8`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:vbscript:5.8:-:x64`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p66:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:viewer:-`,
        fs:  `cpe:2.3:a:microsoft:activex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:virtual_machine_manager:2007`,
        fs:  `cpe:2.3:a:cisco:jabber:9.1\(.3\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_machine_manager:2007`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.251:*:smart:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_machine_manager:2008`,
        fs:  `cpe:2.3:a:python:python:3.4:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_machine_manager:2012:r2`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_pc:-`,
        fs:  `cpe:2.3:h:hp:jg183a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_pc:6.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_pc:6.1`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:1.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_pc:6.2`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_pc:2004`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_server:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_server:2005`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_secure_server:2006:-:premium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:virtual_server:2005:r2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:-`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-10-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2000`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2000:sp2`,
        fs:  `cpe:2.3:a:google:chrome:11.0.677.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2000:sr1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.3.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2000:sr1:enterprise`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2002`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2002:sp1`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2002:sp2`,
        fs:  `cpe:2.3:a:apache:httpclient:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2002:sp2:pro`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2002:sp2:professional`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.38:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2002:sp2:standard`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.44:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2002:sp2:std`,
        fs:  `cpe:2.3:a:qualcomm:extensible_diagnostic_monitor:03.09.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2003`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.14:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2003:sp1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2003:sp2`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2003:sp2:multilingual_user_interface_pack`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2003:sp3`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultracompare:6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2007`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2007:sp1`,
        fs:  `cpe:2.3:a:vmware:workstation:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2007:sp2`,
        fs:  `cpe:2.3:a:apple:bonjour:2.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2007:sp3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2010:sp1:x64`,
        fs:  `cpe:2.3:a:tenable:nessus:6.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2010:sp1:x86`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p99:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2010:sp2`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2013:sp1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio:2016`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.325:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_2000:-:sp2`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_2003-:sp3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.11.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_2007:-:sp1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_multilingual_user_interface_pack:-`,
        fs:  `cpe:2.3:a:emc:rsa_security_analytics:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_multilingual_user_interface_pack:2003`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_viewer:2002`,
        fs:  `cpe:2.3:a:google:earth_plug-in:6.1.0.4857:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_viewer:2003`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_viewer:2007`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_viewer:2010`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_viewer:2010:sp1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.17:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_viewer:2010:sp1:x64`,
        fs:  `cpe:2.3:a:hp:creativeprojects_calendartemplates1:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visio_viewer:2010:sp1:x86`,
        fs:  `cpe:2.3:a:cisco:tacacs\&#43;:f4.0.4alpha:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1yf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:5.0`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:6.0`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:6.0::runtime_extended_files`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:6.2`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:6.3`,
        fs:  `cpe:2.3:a:divx:web_player:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:6.4`,
        fs:  `cpe:2.3:a:oracle:application_testing_suite:12.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:2002`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.3.0:cp02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic:2003`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic_software_development_kit:-`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic_software_development_kit:5.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic_software_development_kit:6.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic_software_development_kit:6.2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic_software_development_kit:6.3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basic_software_development_kit:6.4`,
        fs:  `cpe:2.3:a:isc:bind:9.10.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_basics:6.0::~~rt~~~`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c:-`,
        fs:  `cpe:2.3:a:sybase:easerver:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%23:-`,
        fs:  `cpe:2.3:a:google:earth:5.2.0.5932:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%23:2002`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%23:2003`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%2b%2b:-`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%2b%2b:8.0`,
        fs:  `cpe:2.3:a:buffalotech:whr-g_firmware:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%2b%2b:2002`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.11.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%2b%2b:2003`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%2b%2b:2005:sp1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_c%2b%2b:2008:sp1`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.3.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_database_tools_database_designer:-`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_database_tools_database_designer:7.0`,
        fs:  `cpe:2.3:a:monotone:monotone:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_foxpro:-`,
        fs:  `cpe:2.3:a:ipswitch:imail:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_foxpro:6.0`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_foxpro:8.0:sp1`,
        fs:  `cpe:2.3:a:redhat:network_proxy:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_foxpro:9.0:sp1`,
        fs:  `cpe:2.3:a:curtis_galloway:libexif:0.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_foxpro:9.0:sp2`,
        fs:  `cpe:2.3:o:cisco:staros:17.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_interdev:-`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_interdev:1.0`,
        fs:  `cpe:2.3:h:advantech:eki-1321:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_interdev:6.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_interdev:6.0:sp6`,
        fs:  `cpe:2.3:a:skype:skype:0.97.0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_j%23:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_j%23_.net:2003`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_j%2b%2b:-`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:-`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.12:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0`,
        fs:  `cpe:2.3:a:netease:youdao_dictionary:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0::enterprise`,
        fs:  `cpe:2.3:a:gnu:tar:1.15.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0:sp1`,
        fs:  `cpe:2.3:h:linksys:wrt54gs:4.70.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0:sp2`,
        fs:  `cpe:2.3:h:apple:imac:ma063xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0:sp3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0:sp4`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1.\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0:sp5`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:07-52:-:enterprise:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:6.0:sp6`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:97`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2002`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2002:gold`,
        fs:  `cpe:2.3:a:php:php:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2002:sp1`,
        fs:  `cpe:2.3:a:roxio:media_manager:9.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2003`,
        fs:  `cpe:2.3:h:oberthur:id-one_cosmo:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2003:gold`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2003:sp1`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2005`,
        fs:  `cpe:2.3:a:microsoft:digital_image_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2008:sp1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2010`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc474b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2010:sp1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2012`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)svf4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio:2013`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:-`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2000`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2000:sp1`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:3.30.651.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2002`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2002:gold`,
        fs:  `cpe:2.3:a:microsoft:visio:2000:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2002:sp1`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2003`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2003:gold`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2003:sp1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2005`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-03-02:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_.net:2005:sp1`,
        fs:  `cpe:2.3:a:atlassian:jira:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:visual_studio_team_foundation_server:2013`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:web_applications:2010:sp1`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:web_applications:2010:sp2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5.4sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:webtv:-`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1016:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:1.0`,
        fs:  `cpe:2.3:a:sgminer_project:sgminer:4.1.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:2.0`,
        fs:  `cpe:2.3:a:rsa:envision:3.3.6_build_0115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:3.0`,
        fs:  `cpe:2.3:a:esri:arcgis_spatial_analyst:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:3.1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:3.11`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:2000`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:2000:sp4`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:server_2008:unknown:itanium`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:server_2008:unknown:x32`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:server_2008:unknown:x64`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista::x32-enterprise`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:alpha3:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista::x32-ultimate`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista::x64-enterprise`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.0.359:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista::x64-ultimate`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista:sp1`,
        fs:  `cpe:2.3:a:verifone:vericentre_web_console:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista:sp1:x32-enterprise`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista:sp1:x32-ultimate`,
        fs:  `cpe:2.3:a:david_king:vino:2.27.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista:sp1:x64`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista:sp1:x64-enterprise`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows:vista:unknown:x64`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:95`,
        fs:  `cpe:2.3:a:hp:sitescope:11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:95:gold`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p434:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:95:osr2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.15:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:95:osr2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:10.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:95:osr2.5`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:95:sp1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.16:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:98`,
        fs:  `cpe:2.3:o:hp:hp-ux:7.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:98:beta`,
        fs:  `cpe:2.3:a:php:php:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:98:gold`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:98:scd`,
        fs:  `cpe:2.3:a:kadu:kadu:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:me`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1028.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:me:gold`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a4:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-9x:me:scd`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:-`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:1.0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:1.01`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:2.0`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:2.10`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:2.11`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:2.12`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:3.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:9.1:ga:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:3.0.9348`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:3.0.11171`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_lights_out_2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:4.0`,
        fs:  `cpe:2.3:h:juniper:secure_access_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:4.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:4.2`,
        fs:  `cpe:2.3:a:novell:groupwise:7.01:ir1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:4.20.1081`,
        fs:  `cpe:2.3:a:emc:powerpath:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:4.21.1088`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p481:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:5.0`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:5.1.1700`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-ce:5.2.318`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:3.1`,
        fs:  `cpe:2.3:a:google:chrome:17.0.937.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:3.5`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.5.750.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:3.51`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:gold`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:4.3.0:cp10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:gold:embedded`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.272:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:gold:enterprise`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:gold:server`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:gold:terminal_srv`,
        fs:  `cpe:2.3:a:busybox:busybox:0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:gold:workstation`,
        fs:  `cpe:2.3:h:apple:imac:mc509xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.8.2\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp1:embedded`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:6.00.2900.2180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp1:enterprise`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp1:server`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp1:terminal_srv`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20091023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp1:workstation`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:195:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(5c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp2:embedded`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp2:enterprise`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp2:server`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.05.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp2:terminal_srv`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp2:workstation`,
        fs:  `cpe:2.3:a:plone:plone:4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp3:embedded`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp3:enterprise`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp3:server`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp3:terminal_srv`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp3:workstation`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp4`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp4:embedded`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.23:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp4:enterprise`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp4:server`,
        fs:  `cpe:2.3:h:hp:2500c_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp4:terminal_srv`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp4:workstation`,
        fs:  `cpe:2.3:h:h3c:f1000-e_vpn_firewall:0235a26g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp5`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp5:embedded`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp5:enterprise`,
        fs:  `cpe:2.3:a:hp:ssl_http_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp5:server`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.417:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp5:terminal_srv`,
        fs:  `cpe:2.3:o:google:android:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp5:workstation`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6`,
        fs:  `cpe:2.3:o:canonical:ubuntu_touch:15.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6:embedded`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6:enterprise`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6:server`,
        fs:  `cpe:2.3:a:symantec:client_security:3.1.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6:terminal_srv`,
        fs:  `cpe:2.3:a:mozilla:firefox:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6:workstation`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6a`,
        fs:  `cpe:2.3:a:apache:camel:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6a:embedded`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6a:enterprise`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.3.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6a:server`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6a:terminal_srv`,
        fs:  `cpe:2.3:a:optimalpayments:neteller_direct_payment_api:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sp6a:workstation`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sru`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sru:embedded`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.0:pr:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sru:enterprise`,
        fs:  `cpe:2.3:a:sambar:sambar_server:4.2:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sru:server`,
        fs:  `cpe:2.3:h:hp:jetdirect_680n_eio_802.11b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sru:terminal_srv`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:4.0:sru:workstation`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000`,
        fs:  `cpe:2.3:a:cisco:jabber:9.7\(1\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:beta3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:gold`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:gold:adv_srv`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.3p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:gold:datacenter_srv`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:gold:pro`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.37:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:gold:srv`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:rc1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1082.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:rc2`,
        fs:  `cpe:2.3:a:webbynode:webbynode:1.0.5.2:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp1`,
        fs:  `cpe:2.3:h:adtran:netvanta_7100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp1:adv_srv`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp1:datacenter_srv`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp1:pro`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp1:srv`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp2`,
        fs:  `cpe:2.3:a:rubyonrails:jquery-rails:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp2:adv_srv`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp2:datacenter_srv`,
        fs:  `cpe:2.3:o:xen:xen:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp2:pro`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp2:srv`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp3`,
        fs:  `cpe:2.3:a:emc:networker:7.4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp3:adv_srv`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp3:datacenter_srv`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp3:pro`,
        fs:  `cpe:2.3:a:mike_peachey:authen\:\:externalauth:0.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp3:srv`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp4`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp4:adv_srv`,
        fs:  `cpe:2.3:a:boeing:drs_wiring_illuminator_web:1.10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp4:datacenter_srv`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp4:pro`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2000:sp4:srv`,
        fs:  `cpe:2.3:a:sympa:sympa:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows-nt:2003`,
        fs:  `cpe:2.3:a:sendmail:managed_mta:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003`,
        fs:  `cpe:2.3:a:symantec:ghost_solutions_suite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:compute_cluster`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.8.0.910:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:datacenter`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:enterprise`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:itanium`,
        fs:  `cpe:2.3:a:hccgmbh:mycare2x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:std`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sbc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:storage`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:x64`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:x64-datacenter`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:x64-enterprise`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:gold:x64-std`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2`,
        fs:  `cpe:2.3:a:juniper:junos_internet_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:compute_cluster`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:datacenter`,
        fs:  `cpe:2.3:a:ibm:db2:10.1:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:enterprise`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:std`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:storage`,
        fs:  `cpe:2.3:a:serf_project:serf:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:x64`,
        fs:  `cpe:2.3:o:joyent:smartos:20120614:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:x64-datacenter`,
        fs:  `cpe:2.3:a:invensys:infusion_ce\/fe\/scada:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:x64-enterprise`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:r2:x64-std`,
        fs:  `cpe:2.3:h:brother:mfc-j4410dw:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp1:compute_cluster`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.7.1000:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp1:datacenter`,
        fs:  `cpe:2.3:a:qemu:qemu:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp1:enterprise`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp1:itanium`,
        fs:  `cpe:2.3:a:x:libxfixes:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp1:std`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p452:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp1:storage`,
        fs:  `cpe:2.3:a:samba:samba:3.0.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp1:x64`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp2`,
        fs:  `cpe:2.3:a:acme:thttpd:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp2:compute_cluster`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp2:datacenter`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp2:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:14.0.833.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp2:itanium`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p178:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp2:std`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_deployment:11.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp2:storage`,
        fs:  `cpe:2.3:a:redhat:network_proxy:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:2003:sp2:x64`,
        fs:  `cpe:2.3:a:mixpanel_project:mixpanel:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows-nt:2008`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:vista`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:vista:sp1:x64-home_premium`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:vista:sp1:x64-ultimate`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.2136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp`,
        fs:  `cpe:2.3:a:starcms:starcms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:gold`,
        fs:  `cpe:2.3:h:apple:802.11n:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:gold:embedded`,
        fs:  `cpe:2.3:a:pixman:pixman:0.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:gold:media_center`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:gold:pro`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:gold:tablet_pc`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp1:embedded`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp1:media_center`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp1:pro`,
        fs:  `cpe:2.3:h:hp:j9539a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp1:tablet_pc`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp2`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.0.0.15751:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp2:embedded`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp2:media_center`,
        fs:  `cpe:2.3:a:exim:exim:4.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp2:pro`,
        fs:  `cpe:2.3:a:google:v8:3.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp2:tablet_pc`,
        fs:  `cpe:2.3:o:hp:tru64:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows-nt:xp:sp2:x64`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.1:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:-::~~~~x64~`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.0.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:-::~~~~x86~`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:-:gold:~~~~x64~`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.0:e0101:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:-:gold:~~~~x86~`,
        fs:  `cpe:2.3:o:cisco:ons_15454_system_software:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:1511::~~~~x64~`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:1511::~~~~x86~`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:1607::~~~~x64~`,
        fs:  `cpe:2.3:a:acme:thttpd:2.20:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:1607::~~~~x86~`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:1703`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_3d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:1703::~~~~x64~`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_10:1709::~~~~x64~`,
        fs:  `cpe:2.3:a:microsoft:ie:7.0.5730:unknown:gold:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-`,
        fs:  `cpe:2.3:a:macromedia:contribute:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:beta3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.12.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:gold`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:gold:advanced_server`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:gold:datacenter_server`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:gold:professional`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.569:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:gold:server`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:da:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:rc1`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:rc2`,
        fs:  `cpe:2.3:a:justsystems:just_school:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp1:advanced_server`,
        fs:  `cpe:2.3:h:cisco:crs_performance_route_processor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp1:datacenter_server`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp1:professional`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp1:server`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp2:advanced_server`,
        fs:  `cpe:2.3:a:suse:kiwi:4.98.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp2:datacenter_server`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.16.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp2:professional`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp2:server`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.18:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp3:advanced_server`,
        fs:  `cpe:2.3:h:hp:jd663a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp3:datacenter_server`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp3:professional`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp3:server`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp4`,
        fs:  `cpe:2.3:a:php:php:5.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp4:advanced_server`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp4:datacenter_server`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp4:professional`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.88:-:*:*:sunos:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:-:sp4:server`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000:beta3`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_2000_resource_kit:-`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000_terminal_services:-`,
        fs:  `cpe:2.3:a:openstack:devstack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_2000_terminal_services:-`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000_terminal_services:-:sp1`,
        fs:  `cpe:2.3:a:adobe:breeze_licensed_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_2000_terminal_services:-:sp1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000_terminal_services:-:sp2`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_2000_terminal_services:-:sp2`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2000_terminal_services:-:sp3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.385:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_2000_terminal_services:-:sp3`,
        fs:  `cpe:2.3:a:mcafee:firewall_enterprise_admin_console:4.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_2003:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.33:prebeta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.04.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:compute_cluster`,
        fs:  `cpe:2.3:a:pgp:freeware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:datacenter`,
        fs:  `cpe:2.3:a:wpmembership:wpmembership:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:enterprise`,
        fs:  `cpe:2.3:a:tincan:phplist:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:itanium`,
        fs:  `cpe:2.3:a:qsxgroup:outlook_express_backup_wizard:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:standard`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.6:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:storage`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:x64`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:x64-datacenter`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:x64-enterprise`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:gold:x64-standard`,
        fs:  `cpe:2.3:a:sun:java_system_access_manager:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:compute_cluster`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:datacenter`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:enterprise`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:standard`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:storage`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:x64`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:x64-datacenter`,
        fs:  `cpe:2.3:o:apple:apple_tv:9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:x64-enterprise`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2:x64-standard`,
        fs:  `cpe:2.3:a:apple:safari:3.0.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:r2_sp2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(05\)wc8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp1`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1_pk3_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp1:compute_cluster`,
        fs:  `cpe:2.3:a:menalto:gallery:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp1:datacenter`,
        fs:  `cpe:2.3:a:apple:safari:1.0.0b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp1:enterprise`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp1:itanium`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp1:standard`,
        fs:  `cpe:2.3:a:goodiware:goodreader:1.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp1:storage`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp1:x64`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp2`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view_appliance_iso:6.4.45-2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp2:compute_cluster`,
        fs:  `cpe:2.3:a:hp:jetadmin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp2:datacenter`,
        fs:  `cpe:2.3:a:ibm:cognos_command_center:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp2:enterprise`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp2:itanium`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp2:standard`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp2:storage`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_2003_server:-:sp2:x64`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-::~~~~x64~`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-::~~~~x86~`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-::x64`,
        fs:  `cpe:2.3:o:yamaha:srt100:10.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-::x86`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-:-:x32`,
        fs:  `cpe:2.3:a:samba:samba:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-:-:x64`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-:-:x86`,
        fs:  `cpe:2.3:a:x:libxt:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-:beta`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-:sp1:x32`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-:sp1:x64`,
        fs:  `cpe:2.3:a:emc:retrospect_client:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-:sp1:x86`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_7:-:sp2`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_8:-:-:x64`,
        fs:  `cpe:2.3:a:tm_software:tempo:7.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_8:-:-:x86`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_8:consumer_preview`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(5g\)2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_8.1:-:-:~-~-~-~x64~`,
        fs:  `cpe:2.3:a:x:libxinerama:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_8.1:-:-:~-~-~-~x86~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.354.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_95:-`,
        fs:  `cpe:2.3:a:novell:groupwise:2012:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_95:-:gold`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_95:-:osr2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_newspad:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_95:-:osr2.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_95:-:osr2.5`,
        fs:  `cpe:2.3:o:huawei:s7712_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_95:-:sp1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_95:-:sr2`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:7.0.164.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_98:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.3:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_98:-:beta`,
        fs:  `cpe:2.3:a:gnu:glibc:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_98:-:gold`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_98:-:scd`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_98:beta`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_98_plus_pack:-`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.95:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_98se:-`,
        fs:  `cpe:2.3:a:adobe:output_module:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:-`,
        fs:  `cpe:2.3:a:openssl:openssl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:1.0`,
        fs:  `cpe:2.3:o:d-link:dsr-250_firmware:1.08b44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:1.01`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:2.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:2.10`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:2.11`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:2.12`,
        fs:  `cpe:2.3:a:midgard-project:midguard2:10.05.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:3.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:3.0.9348`,
        fs:  `cpe:2.3:a:vips:vips:7.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:3.0.11171`,
        fs:  `cpe:2.3:a:cognos:go\!_office:8.4.2155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:4.0`,
        fs:  `cpe:2.3:a:adobe:color_recommended_settings:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:4.1`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:4.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:4.20.1081`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:4.21.1088`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:5.0`,
        fs:  `cpe:2.3:a:perl:perl:5.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:5.1.1700`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_ce:5.2.318`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_data_access_components:6.0`,
        fs:  `cpe:2.3:a:e2fsprogs_project:e2fsprogs:1.43.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_defender:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_digital_rights_management:-`,
        fs:  `cpe:2.3:a:mostafa_shemeas_project:mostafa_shemeas:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_essentials:2011`,
        fs:  `cpe:2.3:a:microsoft:office_web_components:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_essentials:2012`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_event_viewer:-`,
        fs:  `cpe:2.3:a:hp:e\/a_agent_korean_localization:8.60.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_explorer:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_help:-`,
        fs:  `cpe:2.3:a:apache:subversion:0.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_live_messenger:-`,
        fs:  `cpe:2.3:a:netscape:navigator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_live_messenger:8.0`,
        fs:  `cpe:2.3:a:microsoft:capicom:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_live_messenger:8.1`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_live_messenger:8.5`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_live_messenger:8.5.1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_live_onecare:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(58\)ses:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_mail:-`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_me:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:5.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_me:-:gold`,
        fs:  `cpe:2.3:a:ibm:security_guardium:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_me:-:scd`,
        fs:  `cpe:2.3:a:att:connect_participant_application:9.5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_encoder:9_series`,
        fs:  `cpe:2.3:a:intel:driver_update_utility:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_format_runtime:-`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:13.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_format_runtime:7.1`,
        fs:  `cpe:2.3:a:microsoft:word:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_format_runtime:9`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(5\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_format_runtime:9.5`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:6.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_format_runtime:11`,
        fs:  `cpe:2.3:a:usfbcm:usf_bcm:252847:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_format_runtime:11::x64`,
        fs:  `cpe:2.3:a:xymon:xymon:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:-`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:6.3`,
        fs:  `cpe:2.3:a:vmware:workstation:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:6.4`,
        fs:  `cpe:2.3:a:vmware:virtual_infrastructure_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:7`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.10.22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:7.1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0002_5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:8`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:8.00.00.4477`,
        fs:  `cpe:2.3:o:cisco:rvs4000_firmware:1.3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:9.00.00.2980`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:9.00.00.3250`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:9.00.00.3349`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:10`,
        fs:  `cpe:2.3:a:ssfcu:security_service_mybranch_app:7.88.00.145:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:10.00.00.3646`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:10.00.00.3990`,
        fs:  `cpe:2.3:a:osisoft:pi_opc_da_interface:2.3.16.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:10.00.00.4019`,
        fs:  `cpe:2.3:a:microsoft:visio:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:10.00.00.4036`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:11`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:11.0.5721.5145`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:11.0.5721.5230`,
        fs:  `cpe:2.3:a:emc:smarts_network_configuration_manager:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:11.0.6000.6324`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p125:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:12`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_player:xp`,
        fs:  `cpe:2.3:a:ca:integrated_threat_management:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_rights_manager:-`,
        fs:  `cpe:2.3:a:wali:walisms_cn:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_rights_manager:4.0`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.38:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_rights_manager:4.1`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_services:-`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ebs:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_services:4.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_services:4.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_services:9`,
        fs:  `cpe:2.3:a:radicale:radicale:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_services:9.1`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.7.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_media_services:2008`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_messaging:-`,
        fs:  `cpe:2.3:a:payment_for_webform_project:payment_for_webform:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_messenger:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_messenger:5.0`,
        fs:  `cpe:2.3:a:f5:big-ip_configuration_utility:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_mobile:5.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:5.0`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:0.98:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:5.0::pocket_pc`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:5.0::smartphone`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:6.0`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:6.0::pro`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp7:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:6.0::standard`,
        fs:  `cpe:2.3:a:ibm:control_center:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:6.1`,
        fs:  `cpe:2.3:a:xen_carousel_plugin_project:xen_carousel:0.12.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:8.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:x7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:8.1`,
        fs:  `cpe:2.3:h:hp:pa-risc:_nil_:_nil_:32bit:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:2003`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:2003_se`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_mobile:2005`,
        fs:  `cpe:2.3:a:apache:struts:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_movie_maker:2.1.4026.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_movie_maker:2.6`,
        fs:  `cpe:2.3:a:google:earth_plug-in:6.1.0.4738:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:-`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0088:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.0.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.1`,
        fs:  `cpe:2.3:a:xrdp:xrdp:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2bc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.486:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.5.1:sp1`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.5.1:sp2`,
        fs:  `cpe:2.3:a:apple:quicktime:7.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.5.1:sp3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.5.1:sp4`,
        fs:  `cpe:2.3:a:samba:samba:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.5.1:sp5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.5.1:sp5:alpha`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:3.51`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.375:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0`,
        fs:  `cpe:2.3:h:dlink:dir865l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:gold`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:gold:embedded`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:gold:enterprise`,
        fs:  `cpe:2.3:a:augeas:augeas:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:gold:server`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.93:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:gold:terminal_server`,
        fs:  `cpe:2.3:h:netgear:rt338:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:gold:workstation`,
        fs:  `cpe:2.3:a:microsoft:interix:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp1:embedded`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp1:enterprise`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp1:server`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp1:terminal_server`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp1:workstation`,
        fs:  `cpe:2.3:a:freetibet:herbal_guide:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp2`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp2:embedded`,
        fs:  `cpe:2.3:h:juniper:srx5600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp2:enterprise`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp2:server`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp2:terminal_server`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p198:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp2:workstation`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd345a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp3`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp3:embedded`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp3:enterprise`,
        fs:  `cpe:2.3:a:python:python:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp3:server`,
        fs:  `cpe:2.3:h:cisco:catalyst_7600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp3:terminal_server`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp3:workstation`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.01.4093:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp4`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp4:embedded`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.30:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp4:enterprise`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp4:server`,
        fs:  `cpe:2.3:a:e107:e107:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp4:terminal_server`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp4:workstation`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.3.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp5`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.446:mr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp5:embedded`,
        fs:  `cpe:2.3:a:debian:base-config:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp5:enterprise`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:2.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp5:server`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp5:terminal_server`,
        fs:  `cpe:2.3:a:sophos:safeguard_easy_device_encryption_client:5.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp5:workstation`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6`,
        fs:  `cpe:2.3:a:gnu:rush:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6:embedded`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6:enterprise`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6:server`,
        fs:  `cpe:2.3:a:ibm:lotus_foundations_start:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6:terminal_server`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6:workstation`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6a`,
        fs:  `cpe:2.3:h:juniper:secure_access_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6a:embedded`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6a:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6a:server`,
        fs:  `cpe:2.3:a:zend:zendto:4.03-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6a:terminal_server`,
        fs:  `cpe:2.3:a:apple:webkit:418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sp6a:workstation`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sru`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sru:embedded`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sru:enterprise`,
        fs:  `cpe:2.3:a:ibm:websphere_everyplace_server:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sru:server`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20\)st6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sru:terminal_server`,
        fs:  `cpe:2.3:a:isaac_sukin:browserid:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_nt:4.0:sru:workstation`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_nt_helper_components:-`,
        fs:  `cpe:2.3:o:mandriva:linux:2008.1:*:x86_64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_nt_option_pack:-`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_rt:-`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_rt:-:gold`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_rt_8.1:-`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp1515:cc377a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_script:5.6`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_script:5.7`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_script:5.8`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.16:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_script_host:-`,
        fs:  `cpe:2.3:h:alliedtelesyn:cable_dsl_router_at-ar220e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_script_host:5.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_script_host:5.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6.6e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2003:-::x64`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2003:-:sp2`,
        fs:  `cpe:2.3:a:redmine:redmine:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2003:-:sp2:itanium`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2003:-:sp2:x64`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ebz:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-::itanium`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-::x32`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-::x64`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-::x86`,
        fs:  `cpe:2.3:a:autodesk:cad_manager_tools:16.0.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:gold`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5.4:*:server_x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:gold:datacenter`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:06-70-\/c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:gold:enterprise`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:gold:hpc`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:gold:itanium`,
        fs:  `cpe:2.3:a:microsoft:office_proofing_tools:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:gold:standard`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:gold:storage`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p215:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:gold:web`,
        fs:  `cpe:2.3:h:tp-link:tl-wrd841nd_\(10.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:r2:itanium`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2010.0211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:r2:x64`,
        fs:  `cpe:2.3:a:apache:hadoop:2.1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp1`,
        fs:  `cpe:2.3:a:canonical:ltsp_display_manager:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp1:enterprise`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp1:enterprise_x64`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.418:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:datacenter`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.19:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:enterprise_x64`,
        fs:  `cpe:2.3:a:git-scm:git:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:hpc`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:itanium`,
        fs:  `cpe:2.3:a:apache:archiva:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:standard`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:storage`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:web`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.1\(3\)sr3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:x32`,
        fs:  `cpe:2.3:a:php:pear:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:x64`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:-:sp2:x86`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:r2`,
        fs:  `cpe:2.3:h:linksys:hpro200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:r2::itanium`,
        fs:  `cpe:2.3:a:digium:asterisk:10.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:r2::x64`,
        fs:  `cpe:2.3:a:openstack:ceilometer:2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:r2:sp1`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:r2:sp1:itanium`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.09.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2008:r2:sp1:x64`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2012:-`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2012:-:gold`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2012:r2:-:~-~datacenter~~~`,
        fs:  `cpe:2.3:a:oracle:http_server:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2012:r2:-:~-~essentials~~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2012:r2:-:~-~standard~~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_server_2016:-`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_services_for_unix:-`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_services_for_unix:3.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:windows_services_for_unix:3.5`,
        fs:  `cpe:2.3:a:michael_biebl:policykit:0.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.386:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-::x64`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-::x64-enterprise`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-::x64-ultimate`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(1\)w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-::x86`,
        fs:  `cpe:2.3:a:redhat:kie_workbench:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-::x86-enterprise`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-::x86-ultimate`,
        fs:  `cpe:2.3:a:vmware:player:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:beta`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:beta1`,
        fs:  `cpe:2.3:a:otrs:otrs:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:beta2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.1.185.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:gold`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d40.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp1`,
        fs:  `cpe:2.3:a:bittorrent:bittorrent:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp1:x64`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp1:x64-enterprise`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp1:x64-home_premium`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_pocket_pc:6.1.1141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp1:x64-ultimate`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp1:x86-enterprise`,
        fs:  `cpe:2.3:a:atutor:atutor:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp1:x86-ultimate`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp2`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_vista:-:sp2:x64`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-`,
        fs:  `cpe:2.3:a:apache:wink:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-::x64`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-::x86`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold`,
        fs:  `cpe:2.3:a:ibm:workload_deployer:3.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold:64-bit-2002`,
        fs:  `cpe:2.3:a:sap:ecl_viewer:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold:64-bit-2003`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:nl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold:embedded`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)a\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold:home`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold:media_center`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold:professional`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p367:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold:tablet_pc`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:gold:x64`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p79:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp1:embedded`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp1:home`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp1:media_center`,
        fs:  `cpe:2.3:a:novell:edirectory:85.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp1:professional`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp1:tablet_pc`,
        fs:  `cpe:2.3:a:apache:camel:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp1:x64`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp2`,
        fs:  `cpe:2.3:a:horde:gollem:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp2:embedded`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp2:home`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp2:media_center`,
        fs:  `cpe:2.3:a:ibm:security_directory_server:6.3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp2:professional`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp2:tablet_pc`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp2:x64`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp2:x86`,
        fs:  `cpe:2.3:a:vinay_sajip:python-gnupg:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp3`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1311.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp3:embedded`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp3:home`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp3:media_center`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp3:professional`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf228a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp3:tablet_pc`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:-:sp3:x86`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:sp2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:sp3`,
        fs:  `cpe:2.3:h:hp:laserjet_5100:v.29.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:sp3:unknown:english`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windows_xp:unknown:sp3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.611.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:microsoft:windowst:vista:sp1:x64-ultimate`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:wins:-`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:winsock:-`,
        fs:  `cpe:2.3:a:citrix:cloudplatform:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:winsock:2.0`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:1.0`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:1.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:1.1a`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:6.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:95`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:97`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:97:sr1`,
        fs:  `cpe:2.3:a:ntop:ntopng:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:97:sr2`,
        fs:  `cpe:2.3:a:bssys:rbs_bs-client:3.17.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:98`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xg4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:98:sr1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:98:sr1:mac_os`,
        fs:  `cpe:2.3:a:moodle:moodle:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:98:sr2`,
        fs:  `cpe:2.3:a:google:chrome:16.0.886.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:98:sr2:mac_os`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:97:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2000`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2000:sp2`,
        fs:  `cpe:2.3:a:skype:skype:4.2.0.169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2000:sp3`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.76:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2000:sr1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2000:sr1a`,
        fs:  `cpe:2.3:o:gehealthcare:optima_mr360_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2000:sr2`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2001`,
        fs:  `cpe:2.3:o:ekahau:b4_staff_badge_tag_firmware:1.4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2002`,
        fs:  `cpe:2.3:a:lightdm_project:lightdm:1.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2002:sp1`,
        fs:  `cpe:2.3:a:adminsystems_cms_project:adminsystems_cms:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2002:sp2`,
        fs:  `cpe:2.3:a:puppetlabs:puppetlabs-rabbitmq:3.1.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2002:sp3`,
        fs:  `cpe:2.3:a:scilab:scilab:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2003`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2003:sp2`,
        fs:  `cpe:2.3:a:iojs:io.js:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2003:sp3`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2004`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.0:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2007`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2007:sp2`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2007:sp3`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2010:sp1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2010:sp1:~~~~x64~`,
        fs:  `cpe:2.3:h:ibm:m49:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2010:sp1:~~~x64~~`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2010:sp1:~~~x86~~`,
        fs:  `cpe:2.3:a:logitech:setpoint:6.22.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2010:sp2`,
        fs:  `cpe:2.3:o:netbsd:netbsd:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2010:sp2:~~~~x64~`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_mac_documentation:6.2.1036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2010:sp2:~~~x64~~`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:58.2:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2010:sp2:~~~x86~~`,
        fs:  `cpe:2.3:a:plone:plone:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2013`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2013:-:~-~-~rt~~`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2013:sp1`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2013:sp1:~~rt~~~`,
        fs:  `cpe:2.3:h:fortinet:fortianalyzer-4000b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word:2016`,
        fs:  `cpe:2.3:a:microsoft:indexing_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word_for_mac:2011`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word_for_mac:2016`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word_multilingual_user_interface_pack:2007`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word_rt:2013:sp1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp5:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word_viewer:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:word_viewer:2003`,
        fs:  `cpe:2.3:a:att:connect_participant_application:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:wordperfect_converter:-`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:-`,
        fs:  `cpe:2.3:o:honeywell:excel_web_xl_1000c1000_600_i\/o:2.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:2.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:3.0`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.0.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:4.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:4.0a`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:4.5`,
        fs:  `cpe:2.3:a:adobe:bridge_cs5:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:4.5a`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:6.0`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.5.2.1:-:-:en-us:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:7.0`,
        fs:  `cpe:2.3:a:apache:solr:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:8`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:8.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:8.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.0.2-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:9.0`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:2000`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:2001`,
        fs:  `cpe:2.3:a:nobexrc:fabuestereo_88.1_fm:3.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:2002`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:2003`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:2004`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:2005`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.1\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works:2006`,
        fs:  `cpe:2.3:a:qtranslate_project:qtranslate:2.5.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works_6-9_file_converter:-`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:works_spreadsheet:-`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:microsoft:xbox_360:-`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:microsoft:xbox_360:4532`,
        fs:  `cpe:2.3:a:cisco:webex:4.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/h:microsoft:xbox_360:4548`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.416:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:xml_core_services:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:xml_core_services:2.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s_3.4.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:xml_core_services:3.0`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.8.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:xml_core_services:4.0`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:xml_core_services:5.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:xml_core_services:6.0`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.006:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:xml_parser:-`,
        fs:  `cpe:2.3:h:yokogawa:daqopc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:xml_parser:2.6`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:zero_administration_kit:-`,
        fs:  `cpe:2.3:o:redhat:linux:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsoft:zero_administration_kit:1.0`,
        fs:  `cpe:2.3:h:hp:jh179a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microstrategy:microstrategy:9.2.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microstrategy:microstrategy_office:9.2.200.63`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsys:promotic:8.0.10`,
        fs:  `cpe:2.3:h:hp:storageworks_san_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microsys:promotic:8.3.10`,
        fs:  `cpe:2.3:a:unisys:enterprise_output_manager:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microweber:microweber:0.8`,
        fs:  `cpe:2.3:a:saltstack:salt:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microweber:microweber:0.95`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:microweber:microweber:0.830`,
        fs:  `cpe:2.3:a:gluster:glusterfs:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:midgard-project:midgard2:10.05.7.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:midgard-project:midguard2:10.05.7.1`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miethner-scripting:dz_erotik_auktionshaus_v4rgo:-`,
        fs:  `cpe:2.3:a:novell:groupwise_webaccess:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mifashow:mifashow_hairstyles:3.7::~~~android~~`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:6.9.355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mig:migme:4.03.002::~~~android~~`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.10.186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:netapp:system_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.3.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:excel:97:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.3.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:hp:unload_support:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.1ca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ni:lookout:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:1.0.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:b230_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:2.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:2.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:2.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:windows_media_format_runtime:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mightymess:soundcloud_is_gold:2.2.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d42.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.04b58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.1.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:h:buffalotech:airstation_extreme_n600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:autodesk:autocad_mechanical:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.0:rc3:~~~drupal~~`,
        fs:  `cpe:2.3:a:webform_invitation_project:webform_invitation:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.1:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.2:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.2:rc2:~~drupal~~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.3:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3202a:a.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:lightdm_project:lightdm:1.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.4:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:juniper:junos_space:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:manugistics:webworks_foundation:7.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.5:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.1.2:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.5:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:h:huawei:s3700:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:freso:languageicons:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.6:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.6:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.6:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:o:hp:hp-ux_series_800:10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:migrate_project:migrate:7.x-2.7:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.3.3`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_database_control:10.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.4`,
        fs:  `cpe:2.3:a:atlassian:jira:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.5`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.5.2`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.5.3`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:r14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.5.4`,
        fs:  `cpe:2.3:a:autotrace_project:autotrace:0.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.5.5`,
        fs:  `cpe:2.3:o:y-cam:ycb001_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_carr:flogr:2.5.6`,
        fs:  `cpe:2.3:a:dynamixsolutions:arabic_prawn:0.0.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_peachey:authen%3a%3aexternalauth:0.05`,
        fs:  `cpe:2.3:a:qt:qt:5.9.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_peachey:authen%3a%3aexternalauth:0.08`,
        fs:  `cpe:2.3:h:digi:cm:32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_peachey:authen%3a%3aexternalauth:0.11`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.7.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:apache:roller:0.9.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.0:beta3`,
        fs:  `cpe:2.3:a:ark-web:a-form_bamboo:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.0:beta4`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.2`,
        fs:  `cpe:2.3:a:cisco:ciscoworks:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.3`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.4`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg510-25:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mike_stefanello:og_features:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:fedoraproject:fedora_core:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mikejolley:download_monitor:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:word:2010:sp1:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:mikejolley:download_monitor:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:pix_firewall_515e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mikejolley:download_monitor:1.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wilson_steven:mangosweb_enhanced:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mikejolley:download_monitor:1.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:h:buffalotech:bhr-4grv2_firmware:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mikejolley:download_monitor:1.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mikejolley:download_monitor:1.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mikejolley:download_monitor:1.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:webcore:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mikejolley:download_monitor:3.3.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:f5:tmos:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mikiurl_wordpress_eklentisi_project:mikiurl_wordpress_eklentisi:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mikrotik:routeros:5.0`,
        fs:  `cpe:2.3:a:apache:cocoon:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mikrotik:routeros:5.15`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.7.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:milan:fastport_print_server:-`,
        fs:  `cpe:2.3:a:nonghyup:smart_calculator:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:2.2`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe_ssl-j:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:2.3`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.5.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:2.4`,
        fs:  `cpe:2.3:a:trillian:trillian:0.74:f:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:2.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_supervisor_mse_8050_software:2.3\(1.32\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:2.6`,
        fs:  `cpe:2.3:a:freenac:freenac:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:2.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:2.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:2.9`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.311:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:3.0`,
        fs:  `cpe:2.3:h:linksys:befsr11:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:3.1`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:3.2`,
        fs:  `cpe:2.3:a:novell:modular_authentication_service:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:3.3`,
        fs:  `cpe:2.3:a:openstack:neutron:juno-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:3.3.1`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:milesj:decoda:3.3.3`,
        fs:  `cpe:2.3:a:docker:docker:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0`,
        fs:  `cpe:2.3:h:citrix:application_gateway_for_cisco:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:alpha2`,
        fs:  `cpe:2.3:h:cisco:catalyst_6513:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:alpha4`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:alpha5`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:alpha6`,
        fs:  `cpe:2.3:a:bearidlock:bear_id_lock:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:alpha7`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:alpha8`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.1`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mime_mail_module_project:mimemail:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindjet:mindmanager:9.2.504`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindless_behavior_fan_base_project:mindless_behavior_fan_base:1::~~~android~~`,
        fs:  `cpe:2.3:a:nancy_wichmann:taxonomy_list:6.x-1.2:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gimp:gimp:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.14.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sophos:enterprise_console:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:software_xalana_xslt_processor:1.10.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p442:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:evolution:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnipcx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.10::~~~wordpress~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sap:mobile_platform:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ayatana_project:unity:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindreantre:threewp_email_reflector:1.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mindrot:jbcrypt:0.3`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.4.2:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:mingle_forum_project:mingle_forum:1.0.33.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:siemens:automation_license_manager:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mingle_forum_project:mingle_forum:1.0.34::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mini-stream:rm-mp3_converter:3.1.2.1.2010.03.30`,
        fs:  `cpe:2.3:a:monotone:monotone:0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mini_group:tv_guide:5.4.3::~~~android~~`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mini_mail_dashboard_widget_project:mini_mail_dashboard_widget:1.42::~~~wordpress~~`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.43:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minibb:minibb:3.1`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniclip:anger_of_stick_3:1.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:arubanetworks:airwave:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniclip:istunt_2:1.1.2::~~~android~~`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.2\(3\)sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniclip:mini_pets:2.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniclip:rail_rush:1.9.0::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:bootstrapper:1.0.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(1\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:license_manager:1.2`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:license_manager:1.3`,
        fs:  `cpe:2.3:a:oracle:xvm_virtualbox:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:minitab:14.2.0`,
        fs:  `cpe:2.3:a:roxio:backontrack:4.0:*:*:*:pe:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:minitab:15.1.30:::en`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:minitab:16.1.1`,
        fs:  `cpe:2.3:a:google:v8:3.17.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:minitab:16.1.1.0`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:quality_companion:3.1.0`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf283a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:minitab:software_update_manager:1.0.0.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:1.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:1.1`,
        fs:  `cpe:2.3:h:dlink:dcs-950g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:1.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:1.3`,
        fs:  `cpe:2.3:a:lunarcms:lunar_cms:3.3:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:1.4`,
        fs:  `cpe:2.3:a:horde:imp:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:1.5`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:1.7`,
        fs:  `cpe:2.3:a:adobe:flash_video_encoder:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:1.8`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miniupnp_project:miniupnpd:2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:git6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mintboard:mintboard:0.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mintboard:mintboard:0.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mirror_photo_%26_shape_project:mirror_photo_%26_shape:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mirucho:listen_up%21_mirucho:1.1.8::~~~android~~`,
        fs:  `cpe:2.3:a:hp:creativeprojects_package_variety2:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mislav_marohnic:will_paginate:3.0:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mislav_marohnic:will_paginate:3.0.1:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mislav_marohnic:will_paginate:3.0.2:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mislav_marohnic:will_paginate:3.0.3:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mislav_marohnic:will_paginate:3.0.4:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mislav_marohnic:will_paginate:3.0.5:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:sophos:disk_encryption:5.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:misli:misli.com_app:-::~~~android~~`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:misp:misp:2.4.68`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mistelix:mistelix:0.1:-`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.1\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mistelix:mistelix:0.2`,
        fs:  `cpe:2.3:a:nero:discspeed:4.99.5.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mistelix:mistelix:0.3`,
        fs:  `cpe:2.3:a:netartmedia:car_portal:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mistelix:mistelix:0.21`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mistelix:mistelix:0.22`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg510-5:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mistelix:mistelix:0.30`,
        fs:  `cpe:2.3:a:mclewin:wishlist:7.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mistelix:mistelix:0.31`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:misterpark:hydrogen_water:1::~~~android~~`,
        fs:  `cpe:2.3:o:novell:opensuse:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:misterpark:le_grand_bleu:1::~~~android~~`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:misterpark:re%3akyu:1::~~~android~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:cgiemail:-`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:53.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:cgiemail:1.6`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-28p-ei_ls-3600-28p-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:-`,
        fs:  `cpe:2.3:a:checkpoint:provider-1:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:4`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:5.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:4.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.0:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.1\(1.59\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2.3`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.4:*:pro:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2.4`,
        fs:  `cpe:2.3:a:apple:ichat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2.5`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2.6`,
        fs:  `cpe:2.3:a:webmastersite:wsn_guest:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2.7`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.2.8`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.6m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.3`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.08.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.3:alpha1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.3.1`,
        fs:  `cpe:2.3:a:vmware:ovf_tool:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.3.2`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.3.3`,
        fs:  `cpe:2.3:a:apache:mod_imap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.3.4`,
        fs:  `cpe:2.3:a:gajim:gajim:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.3.5`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:02-08-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.3.6`,
        fs:  `cpe:2.3:o:beetel:450tc2_router_firmware:tx6-0q-005_retail:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.4`,
        fs:  `cpe:2.3:a:hp:ocr_software_by_i.r.i.s.:12.3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.4.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.734.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.4.2`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_firmware:9.3:\(2\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.4.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.4.4`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:6.14.11.9728:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.5`,
        fs:  `cpe:2.3:h:supermicro:x9srd-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.5.1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.5.2`,
        fs:  `cpe:2.3:a:ibm:security_guardium:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.5.3`,
        fs:  `cpe:2.3:a:ibm:iss_internet_scanner_software:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.6`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.6.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.6.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2010.211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.7`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.12.4202.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.7.1`,
        fs:  `cpe:2.3:a:emulex:common_san_management:31.23.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.8`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_si7_i\/o_driver:7.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.8.1`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:11.04.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.8.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.8.3`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.8.4`,
        fs:  `cpe:2.3:o:genexia:drgos:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.8.5`,
        fs:  `cpe:2.3:a:oracle:application_management:12.2:*:*:*:*:e-business_suite:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.8.6`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x47:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.9`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.9.1`,
        fs:  `cpe:2.3:a:hp:asset_manager:9.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.9.2`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.9.3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.9.4`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.4:ea1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.10`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.10.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.10.2`,
        fs:  `cpe:2.3:a:menalto:gallery:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.10.3`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.10.4`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.2.5:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.11`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.11.1`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.11.2`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.11.3`,
        fs:  `cpe:2.3:h:hp:j9584a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.11.4`,
        fs:  `cpe:2.3:a:cisco:webex_training_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.11.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.12`,
        fs:  `cpe:2.3:a:hp:ldap-ux_integration:b.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.12.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:betax:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.12.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.12.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.13`,
        fs:  `cpe:2.3:a:sun:iplanet_certificate_management_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.13.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.13.2`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.10b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.13.3`,
        fs:  `cpe:2.3:a:keepass:keepass:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.13.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.13.6`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.14:alpha1`,
        fs:  `cpe:2.3:a:citrix:xenserver:5.6:fp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.14:beta1`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.14:beta2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.14.2`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.14.3`,
        fs:  `cpe:2.3:a:gnu:readline:4.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.14.4`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:3.2.116.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.14.5`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.15`,
        fs:  `cpe:2.3:a:roxio:cd_creator:6.1.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.15.1`,
        fs:  `cpe:2.3:a:websense:triton_web_security:7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.15.1:beta1`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5-1.15.1:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5_1.0`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5_1.0.6`,
        fs:  `cpe:2.3:o:cisco:ios:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5_1.1`,
        fs:  `cpe:2.3:a:nextgenupdate:nextgenupdate:3.1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5_1.1.1`,
        fs:  `cpe:2.3:h:hp:cz250a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5_1.2:beta1`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5_1.2:beta2`,
        fs:  `cpe:2.3:h:hp:psc_1100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos:5_1.3.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.9.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:kerberos_ftp_client:-`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.0.p-3520a-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:pgp_public_key_server:-`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:pgp_public_key_server:0.9.2`,
        fs:  `cpe:2.3:a:debian:mit_kerberos:5.1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mit:pgp_public_key_server:0.9.4`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mitfahrgelegenheit:mitfahrgelegenheit.at:2.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mitre:risk_radar:1.0.0`,
        fs:  `cpe:2.3:a:openstack:folsom:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mitsubishicars:mitsubishi_road_assist:1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mitsubishielectric:mc-worx_suite:8.02`,
        fs:  `cpe:2.3:a:ecommercemajor_project:ecommercemajor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mitsubishielectric:mx4_scada:7.10`,
        fs:  `cpe:2.3:a:apple:safari:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mitsubishielectric:mx4_scada:7.20`,
        fs:  `cpe:2.3:a:aol:aim:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miura:ubercart_bulk_stock_updater:-`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:miway:miway_insurance_ltd:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mixpanel_project:mixpanel:6.x-1.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.236.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mixpanel_project:mixpanel:6.x-1.0:beta1`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mixpanel_project:mixpanel:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mjsware:m-player:4.3`,
        fs:  `cpe:2.3:a:atlassian:jira:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mkssoftware:mks_platform_components_x:8.6.200`,
        fs:  `cpe:2.3:a:ca:vet_antivirus:10.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mkssoftware:mks_toolkit:8.7.300`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mkssoftware:mks_toolkit:9.2.200`,
        fs:  `cpe:2.3:a:ca:etrust_audit_aries:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.1.0`,
        fs:  `cpe:2.3:a:rim:blackberry_software:4.0:sp1_bundle83:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.1.1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110701:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.1.2`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.1.3`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.1.4`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.2.0`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.2.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.2.2`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.3.0`,
        fs:  `cpe:2.3:a:ca:message_queuing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.3.1`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.43.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.3.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.3.4`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.4.0`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.5.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/n:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.5.1`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.5.2`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_30-40_poe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.6.0`,
        fs:  `cpe:2.3:a:apple:itunes:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.7.0`,
        fs:  `cpe:2.3:a:intel:iparty:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.7.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.7.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zj2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(1\)sy2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.8.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.8.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1038:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.8.1.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.8.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.8.2-webinterface`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:0.8.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.0.0`,
        fs:  `cpe:2.3:a:adobe:coldfusion_8:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.0.0:rc1`,
        fs:  `cpe:2.3:a:haxx:curl:7.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.0.0:rc2`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:cno:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.0.0:rc3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.0.0:rc4`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.1.0`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l1_controller_firmware:20.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.1.0:rc1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.1.0:rc2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.1.0:rc3`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.1.1:rc1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.0`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.0:rc1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.0:rc2`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.1`,
        fs:  `cpe:2.3:a:ostenta:yawpp:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.5`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.6`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.6.1`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.7`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.0.7.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.8`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.9`,
        fs:  `cpe:2.3:h:xerox:colorqube_9203:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.9:rc1`,
        fs:  `cpe:2.3:a:apache:camel:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.9:rc2`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.007:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.10`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.11`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.12`,
        fs:  `cpe:2.3:a:clamav:clamav:0.91:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.12:rc1`,
        fs:  `cpe:2.3:a:emc:documentum_xcp:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.12:rc2`,
        fs:  `cpe:2.3:a:microsoft:indexing_service:-:*:windows_2000:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.12:rc3`,
        fs:  `cpe:2.3:o:cisco:ios:11.3t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.12:rc4`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.13`,
        fs:  `cpe:2.3:a:ibm:net.data:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.13:rc1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.14`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.15`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.16`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mlmmj:mlmmj:1.2.17`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.1::~~~typo3~~`,
        fs:  `cpe:2.3:h:cisco:traffic_anomaly_detector_module:5.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:microsoft:office:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.4::~~~typo3~~`,
        fs:  `cpe:2.3:a:apple:bonjour:1.0.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.5::~~~typo3~~`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.6::~~~typo3~~`,
        fs:  `cpe:2.3:o:redhat:fedora_core:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.7::~~~typo3~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:0.1.8::~~~typo3~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:1.8.1::~~~typo3~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:1.8.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:erlang:crypto:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:1.8.3::~~~typo3~~`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:1.9.0::~~~typo3~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(2\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:1.9.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mm_forum_project:mm_forum:1.9.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:google:earth:4.3.7284.3916:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.1.19`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.1.20`,
        fs:  `cpe:2.3:a:adobe:media_player:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.10`,
        fs:  `cpe:2.3:a:borland:starteam_sdk_runtime:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.13`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.14`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.1.0.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.15`,
        fs:  `cpe:2.3:a:smarty:smarty:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.16`,
        fs:  `cpe:2.3:a:alex_feinman:iso_recorder:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.17`,
        fs:  `cpe:2.3:a:hitachi:cosminexus\/opentp1_web_web_front-endset:02-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.18`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.19`,
        fs:  `cpe:2.3:a:digium:asterisk:c.2.3:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.20`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.21`,
        fs:  `cpe:2.3:a:oracle:mysql_examples_and_samples:5.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.22`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.23`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.24`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.25`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.02.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.26`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.2.42`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.0:a-beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.0`,
        fs:  `cpe:2.3:a:symantec:vrtsmh:5.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.1`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.2`,
        fs:  `cpe:2.3:h:hp:b3g85a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.4`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.5`,
        fs:  `cpe:2.3:a:ibm:parallel_environment:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.6`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.7`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.8`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.9`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.10`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:9.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnogosearch:mnogosearch:3.3.12`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnt-tech:wp-facethumb:0.1`,
        fs:  `cpe:2.3:a:apache:qpid:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnt-tech:wp-facethumb:0.2`,
        fs:  `cpe:2.3:a:atcom:netvolution:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mnt-tech:wp-facethumb:0.3`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.1.4:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mnt-tech:wp-facethumb:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.04:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobage:tiny_tower:1.7.0.8::~~~android~~`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.12.1203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobatek:mobaxterm:8.2`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobbtech:follow_mania_for_instagram:1.2.1::~~~android~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobfox:madserve:2.0`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobfox:madserve:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1\)dc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobgams:fairy_princess_makeover_salon:1.7::~~~android~~`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobile:baseball_manager_k:1.13::~~~android~~`,
        fs:  `cpe:2.3:a:apache:hadoop:2.0.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobile_domain_project:mobile_domain:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tribulant:tibulant_slideshow_gallery:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mobile_face_project:mobile_face:0.74.13432.91159::~~~android~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobile4social:exposed_filter_data:6.x-1.0`,
        fs:  `cpe:2.3:o:redhat:fedora:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobile4social:exposed_filter_data:6.x-1.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobile4social:exposed_filter_data:6.x-1.2`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobile4social:exposed_filter_data:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobileappcity:childcare:1.399::~~~android~~`,
        fs:  `cpe:2.3:a:hp:update:5.2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobileappspartner:parque_imperial:1.02::~~~android~~`,
        fs:  `cpe:2.3:a:ubi:uplay_pc:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobileappsuite:grandma%27s_grotto:1::~~~android~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobilecraft:bilgi_yarisi:1.8::~~~android~~`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:7.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiledeluxe:big_win_slots_-_slot_machines:1.11.2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_management_center_for_ips_sensors:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiledeluxe:solitaire_deluxe:2.8.5::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobileeventguide:ids_2013:1.21::~~~android~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobileeventguide:uber_b2b:1.9::~~~android~~`,
        fs:  `cpe:2.3:a:citrix:licensing:6.7.9019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobilesoft:meteo_belgique:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobilityware:freecell_solitaire:2.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.5:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:mobilityware:spider_solitaire:3.0.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:epc3928_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobilizedsolutions:aloha_stadium_-_hawaii:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:3300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloapps:anderson_musaamil:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.12:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.4:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.5:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_ccx_editor:8.0.1161.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:huawei:ar_firmware:v200r006c10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:debian:mit_kerberos:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:git:1.5.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nba:sacramento_kings:6.0.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vips:vips:7.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:openssl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7906g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(0.17\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:java:6.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.7.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.851.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.7.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.7.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:python:python:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.99.905:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mccabe:iq:8.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:derby:10.7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.3.0t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:2.1.24:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntt:050_plus:4.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.8.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.9.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:1.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:storeonce_4210_iscsi_backup_system:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:2.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:f5:tmos:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:2.3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:barebones:yojimbo:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiloud:mobiloud:2.3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gajim:gajim:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobiscope:mobiscope_local:1.05::~~~android~~`,
        fs:  `cpe:2.3:a:hp:asset_manager_cloudsystem_chargeback:9.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobisynapse:moffice-outlook_sync:3.1`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/r_firmware:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobitrips:dubrovnik_guided_walking_tours:1.3.2::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mobleeps:job_mobleeps:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:op5:system-op5config:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mochiweb_project:mochiweb:2.1.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mochiweb_project:mochiweb:2.2.0`,
        fs:  `cpe:2.3:a:ibm:netezza_performance_portal:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mochiweb_project:mochiweb:2.2.1`,
        fs:  `cpe:2.3:o:opensuse:opensuse:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mochiweb_project:mochiweb:2.3.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.1:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mochiweb_project:mochiweb:2.3.1`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mochiweb_project:mochiweb:2.3.2`,
        fs:  `cpe:2.3:a:cisco:unified_cdm_platform_software:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mochiweb_project:mochiweb:2.4.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mocoga:kakao_bingo_garden:1.0.14::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mod_nss_project:mod_nss:1.0`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg810-25:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mod_nss_project:mod_nss:1.0.2`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mod_nss_project:mod_nss:1.0.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.48.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mod_nss_project:mod_nss:1.0.4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mod_nss_project:mod_nss:1.0.5`,
        fs:  `cpe:2.3:a:citadel:hercules:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mod_nss_project:mod_nss:1.0.6`,
        fs:  `cpe:2.3:a:libexpat:expat:1.95.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mod_nss_project:mod_nss:1.0.7`,
        fs:  `cpe:2.3:a:novell:iprint:5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mod_nss_project:mod_nss:1.0.8`,
        fs:  `cpe:2.3:h:cisco:rv120w_wireless-n_vpn_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modelisme:modelisme.com_forum%2fportail:3.6.9::~~~android~~`,
        fs:  `cpe:2.3:h:huawei:espace_7950:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moderndecoration:interior_design:1::~~~android~~`,
        fs:  `cpe:2.3:a:scott_reynen:node_embed:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modpagespeed:mod_pagespeed:0.10.19.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modpagespeed:mod_pagespeed:0.10.22.4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modpagespeed:mod_pagespeed:0.10.22.6`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.0.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.0.1`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.0.2`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.0.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.0.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.1.0`,
        fs:  `cpe:2.3:a:phorum:phorum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.1.1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2\(1.198\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.1.2`,
        fs:  `cpe:2.3:a:oracle:database_server_lite:5.0.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.1.3`,
        fs:  `cpe:2.3:a:php:phorum:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.1.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.1.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.51:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.2`,
        fs:  `cpe:2.3:a:microsoft:index_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.4`,
        fs:  `cpe:2.3:a:f5:big-iq_security:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.5`,
        fs:  `cpe:2.3:a:ibm:director:5.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.6`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.7`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.8`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.9`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.10`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.8:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.11`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.12`,
        fs:  `cpe:2.3:a:pheonixcontact-software:multiprog:5.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.5.13:dev1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.3.1:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.0:rc1`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.1:rc1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.2:rc1`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.5.5050.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.3`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.3:rc1`,
        fs:  `cpe:2.3:a:sophos:unified_threat_management_software:9.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.4`,
        fs:  `cpe:2.3:h:cisco:c1721:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.4:rc1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.5`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.7`,
        fs:  `cpe:2.3:a:safenet-inc:sentinel_protection_installer:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.6.8`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.0:rc3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.1`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.2`,
        fs:  `cpe:2.3:o:cisco:catos:2.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.4`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.5`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.6`,
        fs:  `cpe:2.3:a:blair_williams:pretty_link_lite:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.7.7`,
        fs:  `cpe:2.3:a:tibco:slingshot:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.8.0:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsecurity:modsecurity:2.8.0:rc1`,
        fs:  `cpe:2.3:a:dotcms:dotcms:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modsimconnected:modsim_world_2014:2.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:exim:exim:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.39`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.40`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.43`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.44`,
        fs:  `cpe:2.3:h:y-cam:ycb003:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.45`,
        fs:  `cpe:2.3:a:webshophun:webshop_hun:1.062s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.47`,
        fs:  `cpe:2.3:a:isc:bind:9.8.6:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.48`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.384:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.49`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.50`,
        fs:  `cpe:2.3:h:hp:laserjet_p4015:cb509a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.51`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.52`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.53`,
        fs:  `cpe:2.3:a:git-scm:git:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.54`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.55`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.58`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.0.59`,
        fs:  `cpe:2.3:a:facebook:macedonia_hacienda_hotel:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.1.9`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.2.0`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.6.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.2.2`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.2.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.2.4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.3.5`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.4.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.4.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.6.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.6.6`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.7.1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.2.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.7.2`,
        fs:  `cpe:2.3:o:xen:xen:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.1`,
        fs:  `cpe:2.3:a:keepass:keepass:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.2`,
        fs:  `cpe:2.3:a:tony_freixas:ubercart_product_keys:6.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.3`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.4`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.2k3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.5`,
        fs:  `cpe:2.3:a:google:chrome:11.0.660.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.7`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.8`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.9`,
        fs:  `cpe:2.3:h:cisco:cache_engine_550:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.10`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.11`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.12`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.13`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.15`,
        fs:  `cpe:2.3:h:siemens:scalance_x201-3p_irt:-:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.16`,
        fs:  `cpe:2.3:a:netscape:fasttrack_server:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.17`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.18`,
        fs:  `cpe:2.3:o:bluecoat:proxysg:6.6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.20`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.21`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.22`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.8k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.23`,
        fs:  `cpe:2.3:a:crazybrowser:crazybrowser:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.24`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.25`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.26`,
        fs:  `cpe:2.3:a:python:python:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.27`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.3.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.28`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modssl:mod_ssl:2.8.30`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:module-signature_project:module-signature:0.73`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:module-signature_project:module-signature:0.74`,
        fs:  `cpe:2.3:o:freebsd:freebsd:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:1.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.53.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10\)aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:1.2`,
        fs:  `cpe:2.3:a:mark_burdett:securelogin:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:1.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.5.502.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:1.4`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp2:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:1.5`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:1.6`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.1`,
        fs:  `cpe:2.3:a:disney:where\&#39;s_my_perry\?_free:1.5.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.2`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.3`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.4`,
        fs:  `cpe:2.3:o:cisco:vpn_3080_concentrator:4.7.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.5`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.7`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:2.8`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:3.0`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_flashboards:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:3.1`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:3.2`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:3.3`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.45:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:3.4`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:3.5`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:4.0`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:4.1.0`,
        fs:  `cpe:2.3:a:debian:apt:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modwsgi:mod_wsgi:4.2.4`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.0`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.2:pl1`,
        fs:  `cpe:2.3:a:git-scm:git:2.1.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.3`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.4`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.5`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.6`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.9:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.0.8`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.1.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.1.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.1.2`,
        fs:  `cpe:2.3:a:drupal:drupal:7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.1.3`,
        fs:  `cpe:2.3:o:sun:sunos:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.1.4`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.1.5`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.0`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_technology_for_dodaf-modaf:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.1`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.2`,
        fs:  `cpe:2.3:a:hp:webproxy:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.686.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.4`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.5`,
        fs:  `cpe:2.3:a:clamav:clamav:0.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.6`,
        fs:  `cpe:2.3:a:gnu:glibc:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.8`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.9`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.10`,
        fs:  `cpe:2.3:a:cloudera:cloudera_cdh:cdh3:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.11`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:7.02.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.2pb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.2.13`,
        fs:  `cpe:2.3:a:ibm:filenet_capture:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.3.2:pl`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:modx:modx_revolution:2.5.7`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mohachat:moha_chat:-`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mohachat:moha_chat:0.1b7`,
        fs:  `cpe:2.3:a:redhat:rhel_developer_suite:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:0.12.3`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.13:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.3`,
        fs:  `cpe:2.3:a:elxis:elxis_cms:2009.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.4`,
        fs:  `cpe:2.3:h:hp:color_laserjet_8500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.5`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(3\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.6`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.7`,
        fs:  `cpe:2.3:o:xen:xen:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.8`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.9`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.10`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0a5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.11`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.10:-:-:*:black:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.0.12`,
        fs:  `cpe:2.3:a:novell:mobility_pack:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.0`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.2.0.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.1`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.2`,
        fs:  `cpe:2.3:a:rocklobster:contact_form_7:3.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.3`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.5`,
        fs:  `cpe:2.3:a:intel:network_connections:12.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.6`,
        fs:  `cpe:2.3:h:hp:psc_1200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.7`,
        fs:  `cpe:2.3:a:microsoft:access:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.1.8`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.0`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.3`,
        fs:  `cpe:2.3:a:fogproject:fog:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.4`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.335.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.6`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.7`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.9`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.10`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.11`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.12`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.2.13`,
        fs:  `cpe:2.3:a:vmware:tools:3.1.2.15040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.0`,
        fs:  `cpe:2.3:h:cisco:7920_wireless_ip_phone:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.1`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.2`,
        fs:  `cpe:2.3:a:cisco:content_distribution_manager_4650:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.3`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.4`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p425:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.6`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.7`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.8`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:5.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.9`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2009:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.10`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.11`,
        fs:  `cpe:2.3:a:opera:opera_browser:4.00:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.12`,
        fs:  `cpe:2.3:h:hp:3com_switch:4210-48g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.3.13`,
        fs:  `cpe:2.3:a:ibm:rational_directory_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.4.0`,
        fs:  `cpe:2.3:a:xnview:xnview:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.4.1`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:professional_plus:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.5.0`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:2.1.1.720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.5.1`,
        fs:  `cpe:2.3:a:x:libxcb:1.1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.5.2`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.5.3`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.5.4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.9:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.5.5`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.1`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.2`,
        fs:  `cpe:2.3:h:hp:storageworks_san_switch:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.3`,
        fs:  `cpe:2.3:a:david_noguera_gutierrez:dalogin:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.4`,
        fs:  `cpe:2.3:a:adobe:connect:9.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.5`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.6`,
        fs:  `cpe:2.3:a:citrix:licensing:7.5.0.11007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.7`,
        fs:  `cpe:2.3:a:emerson:deltav:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.8`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.9`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.10`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.11`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:1.6.12`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.1`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.3`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.4`,
        fs:  `cpe:2.3:a:formalms:formalms:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(44\)ex1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.6`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.0.8`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.1.0`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.1.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.1.2`,
        fs:  `cpe:2.3:h:avaya:s8710:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.1.3`,
        fs:  `cpe:2.3:a:apple:keynote:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.0`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.1`,
        fs:  `cpe:2.3:a:concursive:vermont_powder:4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p274:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.3`,
        fs:  `cpe:2.3:h:iodata:rockdisk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.4`,
        fs:  `cpe:2.3:a:vmware:vma:5.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.5`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.7`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.8`,
        fs:  `cpe:2.3:a:posh_project:posh:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.2.9`,
        fs:  `cpe:2.3:a:ilearnwith:alphabet_\&amp;_spelling_kids_games:1.4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.3.0`,
        fs:  `cpe:2.3:h:cisco:content_switching_module_with_ssl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.3.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.3.2`,
        fs:  `cpe:2.3:a:php.s3.to:tree_bbs:2004\/11\/23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.3.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.254.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.4.0`,
        fs:  `cpe:2.3:a:vmware:fusion_pro:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.4.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.5.0`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.5.1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.5.2`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.5.3`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.5.4`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.5.5`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.6.0`,
        fs:  `cpe:2.3:a:atutor:atutor:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.6.1`,
        fs:  `cpe:2.3:a:phpmysite:phpmysite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.6.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.7.0`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.7.1`,
        fs:  `cpe:2.3:a:opac_project:opac:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.8.0`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:0.93.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.8.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.8.2`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.2`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.3`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.91.p-1.0.2.1-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.4`,
        fs:  `cpe:2.3:h:avaya:cajun_p880:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.5`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:55.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.6`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.7`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.8`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.9`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.10`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.11`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.9.12`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.0`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.1`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.2`,
        fs:  `cpe:2.3:a:ajsquare:aj_auction_pro-oopd:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.3`,
        fs:  `cpe:2.3:a:hp:printer_access_tool:1.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.4`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.5`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.6`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.7`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.8`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.9`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.10`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6eca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.11`,
        fs:  `cpe:2.3:h:siemens:ccms2025:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.12`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.13`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.10.14`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp3:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.11.0`,
        fs:  `cpe:2.3:a:isamu_kaneko:winny:2.0b7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.11.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.11.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:2.11.3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp1:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.0`,
        fs:  `cpe:2.3:o:cisco:catos:7.4\(0.63\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.61:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.4`,
        fs:  `cpe:2.3:a:aol:aim:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.5`,
        fs:  `cpe:2.3:a:vmware:vcenter_operations:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.6`,
        fs:  `cpe:2.3:a:apple:itunes:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.7`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.0.98.218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.8`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.9`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.10`,
        fs:  `cpe:2.3:o:enea:ose:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.11`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.12`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.5.1.1.20090922:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.13`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.14`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.15`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.16`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2000i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.17`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:2.0:rc_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.18`,
        fs:  `cpe:2.3:a:netscape:messaging_server:3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.19`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.0.20`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.0`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.72.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta56:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.2`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.3`,
        fs:  `cpe:2.3:o:iij:seil\%2fturbo_firmware:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.4`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.5`,
        fs:  `cpe:2.3:a:cisco:content_distribution_manager_4670:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.6`,
        fs:  `cpe:2.3:a:zemanta:related_posts:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.7`,
        fs:  `cpe:2.3:a:google:chrome:13.0.775.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.8`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.9`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.uc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.10`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.11`,
        fs:  `cpe:2.3:h:nvidia:quadro_m6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.12`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.13`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.14`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.15`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.16`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3\(1\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.1.17`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.2.0`,
        fs:  `cpe:2.3:a:google:talk:1.0.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.2.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.3.0`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.3.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.4.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4mr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.4.1`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.4.2`,
        fs:  `cpe:2.3:a:citrix:metaframe:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.5.0`,
        fs:  `cpe:2.3:a:ibm:rational_change:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.5.1`,
        fs:  `cpe:2.3:h:rockwellautomation:1794-aentr_flex_i\/o_ethernet\/ip_adapter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.5.2`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.5.3`,
        fs:  `cpe:2.3:a:microsoft:remote_desktop_connection:5.1.2600.2180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.5.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je030a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.5.5`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.6.0`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.6.1`,
        fs:  `cpe:2.3:a:f5:linerate:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.6.2`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.6.3`,
        fs:  `cpe:2.3:a:opnet:modeler_documentation:16.1.0.10830:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.6.4`,
        fs:  `cpe:2.3:a:divx:converter:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.1`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.11.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.2`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5098-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17a\)sxa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.4`,
        fs:  `cpe:2.3:a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.5`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.6`,
        fs:  `cpe:2.3:a:condor_project:condor:7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.7`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.8`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.9`,
        fs:  `cpe:2.3:a:citrix:nfuse:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.10`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.11`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.12`,
        fs:  `cpe:2.3:a:lancope:stealthwatch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.13`,
        fs:  `cpe:2.3:a:oracle:common_applications_calendar:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.14`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.15`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.16`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.17`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.18`,
        fs:  `cpe:2.3:a:niif:shibboleth_authentication:7.x-4.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.19`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.91.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.20`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:3.7.21`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.0`,
        fs:  `cpe:2.3:a:webmin:usermin:1.540:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.1`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.2`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.13s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.4`,
        fs:  `cpe:2.3:a:libpng:libpng:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.5`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.6`,
        fs:  `cpe:2.3:a:dlguard:dlguard:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.7`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.0.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.1.0`,
        fs:  `cpe:2.3:a:perl:perl:5.10.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.2.0`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.2.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.2.2`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.3.0`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.3.1`,
        fs:  `cpe:2.3:a:fylet:fylet_secure_large_file_sender:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.3.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.3.3`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.4.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0\(3a\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.4.1`,
        fs:  `cpe:2.3:o:hp:3com_officeconnect_gigabit_vpn_firewall_software:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.4.2`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.4.3`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.4.4`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.4.5`,
        fs:  `cpe:2.3:a:oracle:siebel_suite:8.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.5.0`,
        fs:  `cpe:2.3:a:apache:solr:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.5.1`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_for_windows_servers:12.5.2213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.5.2`,
        fs:  `cpe:2.3:a:php-nuke:autohtml_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.6.0`,
        fs:  `cpe:2.3:a:adobe:update_manager:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.6.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.562.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.6.2`,
        fs:  `cpe:2.3:o:gehealthcare:optima_ct520_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.6.3`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.6.4`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.6.5`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.6.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.6.7`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)s13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.7.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.7.2`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:005sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.7.3`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.7.4`,
        fs:  `cpe:2.3:a:sun:n1_grid_engine:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.7.5`,
        fs:  `cpe:2.3:h:hp:elitedesk_705_g2_dm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.7.6`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update1:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.7.7`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.0`,
        fs:  `cpe:2.3:a:ibm:integration_bus:10.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.1`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.2`,
        fs:  `cpe:2.3:a:spice_project:spice:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.3`,
        fs:  `cpe:2.3:a:ncr:tas:2.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.4`,
        fs:  `cpe:2.3:a:john_koleszar:libvpx:0.9.7:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.5`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.1.0.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.6`,
        fs:  `cpe:2.3:a:usps:shipping_assistant:3.7.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.7`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.8`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.9`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.10`,
        fs:  `cpe:2.3:a:microsoft:foundation_class_library:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.11`,
        fs:  `cpe:2.3:a:python:python:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.8.12`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.1`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7945g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.2`,
        fs:  `cpe:2.3:a:boost:boost:1.37.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.3`,
        fs:  `cpe:2.3:a:mcafee:saas_endpoint_protection:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.4`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.5`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120407:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.7`,
        fs:  `cpe:2.3:a:t1lib:t1lib:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.9.8`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.10.0`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.10.1`,
        fs:  `cpe:2.3:a:hp:application_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.10.2`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.1`,
        fs:  `cpe:2.3:a:digium:asterisk:13.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.2`,
        fs:  `cpe:2.3:h:siemens:sinamics_s150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.3`,
        fs:  `cpe:2.3:a:nvidia:geforce_experience:gfe_3.1.0.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.4`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.6`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.7`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.3055:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.11.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.4.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.1`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.2`,
        fs:  `cpe:2.3:a:x:libxext:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.3`,
        fs:  `cpe:2.3:a:google:chrome:14.0.796.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.4`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:6.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.6`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.7`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.2.3:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.8`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.9`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.10`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.6\(2a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.11`,
        fs:  `cpe:2.3:a:gnome:glib:2.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.12`,
        fs:  `cpe:2.3:a:simplerealtytheme:advanced_text_widget_plugin:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.13`,
        fs:  `cpe:2.3:a:fonality:fonality:12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.14`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.15`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.16`,
        fs:  `cpe:2.3:h:sun:fire_x4200m2_server:sw_2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.17`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-05-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.18`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.19`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.20`,
        fs:  `cpe:2.3:a:skype:skype:3.6.0.244:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.21`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.22`,
        fs:  `cpe:2.3:a:openelectrical:open_electrical_webser:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.23`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.11.439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.24`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.5:*:standalone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.25`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.26`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20020710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.27`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.28`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.29`,
        fs:  `cpe:2.3:a:omeka:omeka:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:4.12.30`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.0.0`,
        fs:  `cpe:2.3:a:google:v8:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.0.1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager_for_vmware:6.4.3:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.0.3`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.0.4`,
        fs:  `cpe:2.3:a:safenet-inc:safenetmobile_pass:8.3.7.11:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.0.5`,
        fs:  `cpe:2.3:a:solarwinds:job_engine:2.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.0.6`,
        fs:  `cpe:2.3:h:hp:0235a296:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.1.0`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.7:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.1.1`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.1.2`,
        fs:  `cpe:2.3:a:apache:maven:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.2.0`,
        fs:  `cpe:2.3:a:nuphoto:nusquare:1.0.78:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.2.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.2.2`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.2.3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.95:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.2.4`,
        fs:  `cpe:2.3:a:plone:plone:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.2.5`,
        fs:  `cpe:2.3:a:hp:event_monitoring_service:a.04.20.11.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.3.0`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.3.1`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.39:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.4.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.4.1`,
        fs:  `cpe:2.3:a:stage_file_proxy_project:stage_file_proxy:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.4.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.22:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.4.3`,
        fs:  `cpe:2.3:a:emersonnetworkpower:aperture_web_services_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.4.4`,
        fs:  `cpe:2.3:a:x.org:libx11:1.5.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.5.0`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.5.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.5.2`,
        fs:  `cpe:2.3:a:adobe:dreamweaver_mx:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.6.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.6.1`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0575:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.6.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.7.0`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.9.0:*:*:*:rim:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.7.1`,
        fs:  `cpe:2.3:a:divx:divx_plus_web_player:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.7.2`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.7.3`,
        fs:  `cpe:2.3:a:netease:neteaseweibo:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.7.4`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.8.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.8.1`,
        fs:  `cpe:2.3:a:atvise:webmi2ads:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.0`,
        fs:  `cpe:2.3:a:samba:samba:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.1`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.2`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.4`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.5`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.119:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.6`,
        fs:  `cpe:2.3:h:meinberg:syncfire_1100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.7`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.8`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.9`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.10`,
        fs:  `cpe:2.3:a:ivanjaros:feed_block:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.11`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.12`,
        fs:  `cpe:2.3:h:cisco:nexus_3016:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.13`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.14`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.15`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:02-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.16`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.17`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.18`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.19`,
        fs:  `cpe:2.3:a:sendmail:multi_switch:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.20`,
        fs:  `cpe:2.3:h:buffalotech:bbr-4mg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.21`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.22`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:5.9.23`,
        fs:  `cpe:2.3:a:mcafee:epo_mcafee_virtual_technician:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.0`,
        fs:  `cpe:2.3:h:hp:laserjet_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.1`,
        fs:  `cpe:2.3:a:zonelabs:imsecure:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.2`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.3enp1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.3`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0.7.2942:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.4`,
        fs:  `cpe:2.3:a:wandisco:wandisco_subversion:1.6.16-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.5`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.3.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.6`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:3.5.604:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.8`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.9`,
        fs:  `cpe:2.3:a:sympa:sympa:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.10`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.0.11`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.5080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.1.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.1.1`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.3`,
        fs:  `cpe:2.3:a:checkpoint:connectra_ngx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.4`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.5`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.6`,
        fs:  `cpe:2.3:a:dolphin-browser:dolphin_browser_hd:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.7`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.8`,
        fs:  `cpe:2.3:a:ibm:network_appliance_data_ontap:7.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.9`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:9.0.0-461:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.10`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.11`,
        fs:  `cpe:2.3:a:microsoft:works:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.12`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.2.13`,
        fs:  `cpe:2.3:a:rssbus:rssbus_for_sharepoint:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.0`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control_option:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.2`,
        fs:  `cpe:2.3:a:qlogic:sansurfer_fc_hba_manager:5.0.1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.3`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.4`,
        fs:  `cpe:2.3:a:novell:groupwise:7.0.3:hp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.5`,
        fs:  `cpe:2.3:h:siemens:scalance_w744-1pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.6`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.7`,
        fs:  `cpe:2.3:a:shopware:shopware:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.8`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinejf:abcm2ps:6.3.9`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.3`,
        fs:  `cpe:2.3:a:fortinet:forticlient:5.2.028:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.4`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.5`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.22:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.6`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.7`,
        fs:  `cpe:2.3:a:hp:virtualvault:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.8`,
        fs:  `cpe:2.3:a:acmailer:acmailer:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.9`,
        fs:  `cpe:2.3:a:oracle:forms:4.5.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.10`,
        fs:  `cpe:2.3:a:ca:etrust_pestpatrol:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:0.11`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.2`,
        fs:  `cpe:2.3:a:citrix:xenserver:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.2.1`,
        fs:  `cpe:2.3:o:d-link:dap-1320_firmware:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.2.2`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.2.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.2.4`,
        fs:  `cpe:2.3:a:grape_project:grape:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.3.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.3.1`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r14b01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.3.2`,
        fs:  `cpe:2.3:a:scilab:scilab:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.3.5`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.3.5:rc1`,
        fs:  `cpe:2.3:a:mass_gaming_tv_project:mass_gaming_tv:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.4`,
        fs:  `cpe:2.3:a:digia:qt:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.0:beta1`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.0:beta2`,
        fs:  `cpe:2.3:h:hp:3com_router:3036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.0:beta3`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.0:beta4`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.0:beta5`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:cce:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.0:beta6`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.0:rc1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.1`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.3:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.3:rc2`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.4`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.5`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.5:a`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.5:rc1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.14:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.5a`,
        fs:  `cpe:2.3:a:intersectalliance:system_intrusion_analysis_and_reporting_environment:3.1.4:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.6`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.7`,
        fs:  `cpe:2.3:a:debian:apt:0.7.15:exp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.5.8`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.0`,
        fs:  `cpe:2.3:a:adobe:extension_manager_cs3:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.0:beta1`,
        fs:  `cpe:2.3:a:tibco:spotfire_analyst:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.0:beta2`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.0:rc1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.0:rc2`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110830:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.2`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.3`,
        fs:  `cpe:2.3:o:corega:cg-wlbaragm_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.6.4`,
        fs:  `cpe:2.3:a:openttd:openttd:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.0:beta1`,
        fs:  `cpe:2.3:a:hp:c4380_help:100.0.206.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.0:beta2`,
        fs:  `cpe:2.3:a:boombatower:subuser:7.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)sy2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.0:rc2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.1.2401:online_windows_server_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.0:rc3`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.2`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:rc16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.7.3`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.8.0`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.8.1`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:r2:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.8.2`,
        fs:  `cpe:2.3:a:busybox:busybox:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.8.3`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:8.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.8.4`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.8.6`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.8.7`,
        fs:  `cpe:2.3:a:symantec:veritas_dmp_dsm_solution:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.8.8`,
        fs:  `cpe:2.3:a:skype:skype:3.6.0.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.9.0`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-30:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.9.1`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.9.2`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.9.3`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security:e80.40:-:vpn_blade:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.9.4`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.9.5`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.1:sp1:-:*:enterprise:-:-:compuset_engine`,
    },
     
    {
        uri: `cpe:/a:moinmo:moinmoin:1.9.8`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moip_project:moip:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:bmc:patrol_perform_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moip_project:moip:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moip_project:moip:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moip_project:moip:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.33:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mol:mol_bringapont:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:xnview:xnview:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.5`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:ebz:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.5.1`,
        fs:  `cpe:2.3:a:arg0:encfs:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.6`,
        fs:  `cpe:2.3:o:yahama:rta54i:4.03.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.6.1`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:20.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.6.2`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.6.3`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.7`,
        fs:  `cpe:2.3:a:janetter:janetter:1.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.7.1`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.1.3.6323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.7.2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.32:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.8`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.9`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.9.5`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.04.312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.9.6`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.9.6.1`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.9.6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.9.6.3`,
        fs:  `cpe:2.3:a:roxio:creator_bdav_plugin:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:0.9.6.4`,
        fs:  `cpe:2.3:a:gnome:evolution:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_3500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.1`,
        fs:  `cpe:2.3:a:ibm:case_manager:5.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.5`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.5.1`,
        fs:  `cpe:2.3:a:adobe:framemaker:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.5.2`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.5.3`,
        fs:  `cpe:2.3:a:digia:qt:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.5.4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.5.5`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_desktop:11.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.0.5.6`,
        fs:  `cpe:2.3:a:novell:sentinel_log_manager:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.5`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.5.2`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.5.3`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.5.4`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.5.5`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.6`,
        fs:  `cpe:2.3:h:cisco:ons_15600_multiservice_switching_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.6.5`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:12.0\(0.99000.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.6.5.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.6.5.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.296:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.6.5.3`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.6.5.4`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:h:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.6.5.5`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mollify:mollify:1.6.5.6`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_mse_series_software:4.2\(1.43\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:1.2.0`,
        fs:  `cpe:2.3:a:apache:camel:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:1.4.0`,
        fs:  `cpe:2.3:a:oracle:interaction_blending:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:1.6.0`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.2\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:1.8.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:th:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.0`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.2`,
        fs:  `cpe:2.3:a:gnu:emacs:21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.3`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.4`,
        fs:  `cpe:2.3:a:netscape:iplanet_ical:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.5`,
        fs:  `cpe:2.3:a:eliteweaver:xclick_cart:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.7`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.0.8`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.2.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.11:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.2.1`,
        fs:  `cpe:2.3:a:tricerat:screwdrivers_client:4.0.16.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.2.2`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.2.3`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.2.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.2.5`,
        fs:  `cpe:2.3:a:apache:struts:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.2.6`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.2.7`,
        fs:  `cpe:2.3:a:intellectualflame:brightest_led_flashlight:1.2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.3.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.3.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.0`,
        fs:  `cpe:2.3:a:david_king:vino:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.1`,
        fs:  `cpe:2.3:h:3com:tippingpoint_sms_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.2`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.5.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.414:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.5`,
        fs:  `cpe:2.3:a:emc:iomega_product_registration:7.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.6`,
        fs:  `cpe:2.3:a:ibm:infosphere_import_export_manager:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.7`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.33.5071:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.8`,
        fs:  `cpe:2.3:a:lxml:lxml:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.9`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.10`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.11`,
        fs:  `cpe:2.3:h:zyxel:p-660hw_d1:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.12`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.13`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.4.14`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.5.1`,
        fs:  `cpe:2.3:a:fujitsu:interstage_studio:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.1`,
        fs:  `cpe:2.3:a:bib2html_project:bib2html:0.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.12:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.4`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.6`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.7`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.8`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.9`,
        fs:  `cpe:2.3:a:redhat:rhel_global_file_system:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.10`,
        fs:  `cpe:2.3:a:netscape:communicator:4.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.11`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:2.6.12`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:53.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.2.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.2`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.3`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.4`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.6`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.2.2:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.8`,
        fs:  `cpe:2.3:o:microsoft:windows_10:-:gold:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.9`,
        fs:  `cpe:2.3:a:libvncserver_project:libvncserver:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.10`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.11`,
        fs:  `cpe:2.3:a:hp:universal_cmbd_foundation:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.12`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.13`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.14`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.0.15`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.1`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.2`,
        fs:  `cpe:2.3:a:spice_project:spice:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p7_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.4`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:4.1.0:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.6`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.7`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_1000_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.8`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.9`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.10`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.11`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5208a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.12`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.13`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.14`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.9.4:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.15`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.03:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.16`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.2.17`,
        fs:  `cpe:2.3:a:microsoft:iis:4.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:5.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.1`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2003:-:sp2:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.3`,
        fs:  `cpe:2.3:a:cisco:videoscape_delivery_system_for_internet_streamer:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.5`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.6`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.7`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p71:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.10`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.11`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.12`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.13`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2010:14.0.909.32:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.14`,
        fs:  `cpe:2.3:a:estsoft:alzip:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.3.15`,
        fs:  `cpe:2.3:a:erlang-solutions:mongooseim:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_os_deployment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.1`,
        fs:  `cpe:2.3:a:nodeauthor_project:nodeauthor:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.2`,
        fs:  `cpe:2.3:h:hp:laserjet_9500mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.3`,
        fs:  `cpe:2.3:o:novell:suse_linux:1.0:*:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.4`,
        fs:  `cpe:2.3:h:buffalotech:fs-g54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.5`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.7`,
        fs:  `cpe:2.3:a:percipientstudios:imagen:2.5.4:-:*:*:*:umbraco_cms:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.9`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mongodb:mongodb:3.4.10`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1290.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.1.1`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.1.4`,
        fs:  `cpe:2.3:a:cisco:emergency_responder:11.5\(2.10000.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.5.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.3.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.5.1`,
        fs:  `cpe:2.3:a:codiad:codiad:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)ewa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.6.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.6.1`,
        fs:  `cpe:2.3:o:huawei:s9712_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.6.2`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.6.3`,
        fs:  `cpe:2.3:o:debian:debian_linux:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.7.0`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.7.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.8:interim:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.7.2`,
        fs:  `cpe:2.3:a:gnu:libtool:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.8.0`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.8.1`,
        fs:  `cpe:2.3:a:freedomscientific:video_intercept:10.16.3519.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.8.2`,
        fs:  `cpe:2.3:a:netscape:navigator:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.8.3`,
        fs:  `cpe:2.3:a:emc:vmware_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.8.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.8.4:2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.8.5`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.9.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.9.1`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.9.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.9.3`,
        fs:  `cpe:2.3:a:mcafee:firewall_reporter:5.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.10.0`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.10.1`,
        fs:  `cpe:2.3:a:python:python:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.10.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.10.3`,
        fs:  `cpe:2.3:a:ca:integrated_threat_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.11.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.11.1`,
        fs:  `cpe:2.3:a:barebones:textwrangler:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.12.0`,
        fs:  `cpe:2.3:a:ibm:spectrum_lsf:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.12.1`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:fp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.12.2`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.13.0`,
        fs:  `cpe:2.3:a:opnet:it_guru_documentation:15.0.0.8622:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.13.1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.13.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.20.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.20.1`,
        fs:  `cpe:2.3:a:gnu:cfengine:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.20.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.15:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.20.3`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.21.0`,
        fs:  `cpe:2.3:a:lucent:vitalhelp:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.30.0`,
        fs:  `cpe:2.3:a:perl:perl:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.31.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.32.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:0.33.0`,
        fs:  `cpe:2.3:a:platform:lsadmin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.0.0`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_l55_controller_firmware:16.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.0.1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.1.0`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.0:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.2.0`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.2.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.2.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.4.0`,
        fs:  `cpe:2.3:h:huawei:cx200:v100r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.5.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.5.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.5.2`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monkey-project:monkey_http_daemon:1.5.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:-`,
        fs:  `cpe:2.3:o:cisco:catos:7.6\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.0`,
        fs:  `cpe:2.3:a:citadel:smtp:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.0.5`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.8.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p265:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.13`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.13.4`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.13.6`,
        fs:  `cpe:2.3:o:smc:smc8024l2_switch_firmware:2.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.13.7`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.17`,
        fs:  `cpe:2.3:h:cisco:catalyst_3560:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.17.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.1.18`,
        fs:  `cpe:2.3:a:ohwada:xf-section:1.12a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:1.2.5.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p327:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:2.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.25.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono:mono:2.10.1::~~windows~~~`,
        fs:  `cpe:2.3:a:jetico:bcwipe:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mono-project:libgdiplus:2.6.7`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:-`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_indoor_fixed_dome_ip_hd_camera:5010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.5`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.6`,
        fs:  `cpe:2.3:a:ca:unicenter_tng:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.7`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.8`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.9`,
        fs:  `cpe:2.3:h:softbank:windows_mobile_smartphone:x02t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.10`,
        fs:  `cpe:2.3:a:citrix:xenserver:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.11`,
        fs:  `cpe:2.3:a:sap:netweaver_business_client_for_html:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.12`,
        fs:  `cpe:2.3:a:apache:rave:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.13`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.14`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.15`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.16`,
        fs:  `cpe:2.3:h:iodata:ts-ptcam_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.17`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:1.0.1.8n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.18`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.19`,
        fs:  `cpe:2.3:a:cisco:rv082_dual_wan_vpn_router_firmware:4.0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.20`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.21`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.22`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.23`,
        fs:  `cpe:2.3:a:oracle:secure_global_desktop:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.24`,
        fs:  `cpe:2.3:a:findingscience:mod_auth_openid:0.3:*:*:*:*:apache:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.25`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.26`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.27`,
        fs:  `cpe:2.3:a:google:chrome:7.0.536.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.28`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.29`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.30`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.31`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.32`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.33`,
        fs:  `cpe:2.3:a:apple:software_update:2.1.1.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.34`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.35`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.36`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.37`,
        fs:  `cpe:2.3:a:jforum:jforum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.38`,
        fs:  `cpe:2.3:a:zombie_detector_project:zombie_detector:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.39`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.40`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.41`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.47:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.42`,
        fs:  `cpe:2.3:h:nortel:passport_8000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.43`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:9.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.44`,
        fs:  `cpe:2.3:a:mcafee:linuxshield:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.45`,
        fs:  `cpe:2.3:a:altiris:patch_management_core_solution_for_linux:6.2.1161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.46`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.47`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.48`,
        fs:  `cpe:2.3:a:pgp:universal_server:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monotone:monotone:0.99`,
        fs:  `cpe:2.3:a:spip:spip:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.19`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.22`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5a\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.23`,
        fs:  `cpe:2.3:a:google:chrome:8.0.557.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.24`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.25`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.26`,
        fs:  `cpe:2.3:a:oracle:field_service:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.27`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.29`,
        fs:  `cpe:2.3:a:nagiosql:nagiosql:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.30`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.31`,
        fs:  `cpe:2.3:a:horde:imp:3.2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.32`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.33`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.34`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.35`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.36`,
        fs:  `cpe:2.3:a:quotezone:car_insurance_quote_comparison:2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.37`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.31.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.38`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.41`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.42`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.43`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.44`,
        fs:  `cpe:2.3:o:cisco:catos:5.1\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.48`,
        fs:  `cpe:2.3:a:rakus:maildealer:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.53`,
        fs:  `cpe:2.3:a:huge-it:portfolio_gallery:1.0.6:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.56`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma896xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.57`,
        fs:  `cpe:2.3:a:digia:qt:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.59`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.60`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:6.x-6.61`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2009.211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.5`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120404:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.6`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.7`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.8`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.9`,
        fs:  `cpe:2.3:h:dell:sonicwall_network_security_appliance_2400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.10`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.11`,
        fs:  `cpe:2.3:a:sybase:easerver:6.3.1:*:developer:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.12`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert15:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.13`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.14`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.15`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.16`,
        fs:  `cpe:2.3:a:apple:itunes:4.7.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.17`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.18`,
        fs:  `cpe:2.3:a:microfocus:server:5.1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.19`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.20`,
        fs:  `cpe:2.3:a:clamav:clamav:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.21`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.22`,
        fs:  `cpe:2.3:a:emc:networker:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.23`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.19:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:monster_menus_module_project:monster_menus:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:2.2.1240`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:2.3.1374`,
        fs:  `cpe:2.3:a:icinga:icinga:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.0.1490`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)n2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.1.1557`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.2.1651`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.14:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.3.1723`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.4.1794`,
        fs:  `cpe:2.3:a:siemens:simatic_step_7:5.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.5.1857`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.6.2022`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.7.2088`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.8.2144`,
        fs:  `cpe:2.3:h:linksys:befvp41:1.40.3f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:3.9.2269`,
        fs:  `cpe:2.3:a:vidyo:vidyo_desktop:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:4.0.2429`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.292:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:4.1.2567`,
        fs:  `cpe:2.3:a:freebsd:fetch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:montala:resourcespace:4.2.2816`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:-`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.1.1`,
        fs:  `cpe:2.3:h:ibm:totalstorage_ds400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.2.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.3.1`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.5:beta1:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.3.2`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-02-\/g:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.3.3`,
        fs:  `cpe:2.3:a:monotone:monotone:0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.3.4`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.13-61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.4.1`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.4.2`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.4.3`,
        fs:  `cpe:2.3:a:otrs:faq:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.4.4`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.4.5`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.5`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.5:beta`,
        fs:  `cpe:2.3:a:unitedplanet:intrexx:5.2:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.5.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.5.2`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.5.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6`,
        fs:  `cpe:2.3:a:apple:keynote:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6.1`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6.2`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6.4`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_security_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6.5`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6.6`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6.7`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.6.8`,
        fs:  `cpe:2.3:a:autodesk:architectural_desktop:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.7`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.7.1`,
        fs:  `cpe:2.3:h:seagate:blackarmor_nas_220:stav6000100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.7.2`,
        fs:  `cpe:2.3:a:devsaran:best_responsive:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.7.3`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.4:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.7.4`,
        fs:  `cpe:2.3:a:administration_views_project:administration_views:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.7.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.7.6`,
        fs:  `cpe:2.3:a:harris:stat_scanner:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.2`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.4`,
        fs:  `cpe:2.3:a:zodiacdm:aboutme-plugin:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.5`,
        fs:  `cpe:2.3:a:blackberry:qnx_momentics_tool_suite:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.6`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control_host:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.7`,
        fs:  `cpe:2.3:h:cisco:nexus_9336pq_aci_spine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.8`,
        fs:  `cpe:2.3:a:gentoo:libsndfile:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.9`,
        fs:  `cpe:2.3:a:rpm:rpm:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.10`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.11`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.12`,
        fs:  `cpe:2.3:a:freso:languageicons:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.13`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p259:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.8.14`,
        fs:  `cpe:2.3:a:vmware:fusion_pro:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.3`,
        fs:  `cpe:2.3:a:sun:java_system_communications_express:2005q1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.4`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x50:d45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.5`,
        fs:  `cpe:2.3:a:novell:iprint:5.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.6`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.7`,
        fs:  `cpe:2.3:a:saltstack:salt:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.8`,
        fs:  `cpe:2.3:h:cisco:asa_5500:7.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.9`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.10`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.11`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.12`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.344:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.13`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.14`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.10.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.15`,
        fs:  `cpe:2.3:a:cisco:catalyst_5xxx_supervisor_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.16`,
        fs:  `cpe:2.3:h:nortel:wlan_handset_6140:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.17`,
        fs:  `cpe:2.3:a:magzter:sunday_indian_oriya:3.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:1.9.18`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.1`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0404hf-a-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update5:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.3`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.4`,
        fs:  `cpe:2.3:a:isc:bind:9.9.6:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.6`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.7`,
        fs:  `cpe:2.3:a:mautic:mautic:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.8`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.0.9`,
        fs:  `cpe:2.3:a:ca:etrust_audit_policy_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.1`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:6.0:u1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-00-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.3`,
        fs:  `cpe:2.3:a:xdforum:xd_forum:3.9.17:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.5`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.6`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.7`,
        fs:  `cpe:2.3:a:hp:performance_center:11.52:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.8`,
        fs:  `cpe:2.3:a:oracle:application_object_library:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.9`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.1.10`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2`,
        fs:  `cpe:2.3:o:siemens:simatic_s7_1200_cpu_firmware:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.1`,
        fs:  `cpe:2.3:a:checkpoint:express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.2`,
        fs:  `cpe:2.3:a:cisco:webns:7.30_\(00.09\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.3`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.5`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.6`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.824:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.9.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.8`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.9`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.2.11`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3`,
        fs:  `cpe:2.3:a:globeranger:edcl_central_reporting_server:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.2`,
        fs:  `cpe:2.3:a:mahara:mahara:15.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.3`,
        fs:  `cpe:2.3:a:symantec:wxrt_ccf_server_apppack:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.4`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sru:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.5`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.6`,
        fs:  `cpe:2.3:a:divx:player:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.7`,
        fs:  `cpe:2.3:h:cisco:aironet_600_office_extend:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.8`,
        fs:  `cpe:2.3:a:avocent:msi_server:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.9`,
        fs:  `cpe:2.3:a:apple:help_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.10`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.3.11`,
        fs:  `cpe:2.3:a:lucent:ipsec_client:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.1`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.2`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.3`,
        fs:  `cpe:2.3:h:cisco:content_services_switch_11150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.4`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:b7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.5`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.6`,
        fs:  `cpe:2.3:a:ibm:security_guardium_database_activity_monitor:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.7`,
        fs:  `cpe:2.3:h:ibm:4758:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.8`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.9`,
        fs:  `cpe:2.3:a:nero:waveeditor:5.0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.10`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.4.11`,
        fs:  `cpe:2.3:a:gnu:libtasn1:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:x7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.4`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.32:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.5`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.7`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4017:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.8`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.5.9`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:1.0.2.e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.2`,
        fs:  `cpe:2.3:a:sycamore_networks:modeler:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.3`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.60.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:f9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.5`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.6`,
        fs:  `cpe:2.3:a:apache:derby:10.10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.8`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.9`,
        fs:  `cpe:2.3:a:vinay_sajip:python-gnupg:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.10`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.6.11`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.0`,
        fs:  `cpe:2.3:a:hp:proliant_smart_array_device_manager_extension:6.4.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.0:beta`,
        fs:  `cpe:2.3:a:ipswitch:imail_server:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.0:rc1`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.0:rc2`,
        fs:  `cpe:2.3:a:smackcoders:wp_ultimate_email_marketer_plugin:1.0.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.1`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_codec_6000_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.2`,
        fs:  `cpe:2.3:o:hp:mpe_ix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.3`,
        fs:  `cpe:2.3:a:pixologic:zbrush:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.4`,
        fs:  `cpe:2.3:a:irfanview:flashpix_plugin:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.6`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.7`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.8`,
        fs:  `cpe:2.3:a:php:comoblog:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.9`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.10`,
        fs:  `cpe:2.3:o:google:chrome_os:0.9.131.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.11`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.12`,
        fs:  `cpe:2.3:h:hp:linear_barcode_scanner_qy405aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.13`,
        fs:  `cpe:2.3:a:radare:radare2:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.14`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.15`,
        fs:  `cpe:2.3:a:php:php:5.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.16`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.17`,
        fs:  `cpe:2.3:h:huawei:me60:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.7.18`,
        fs:  `cpe:2.3:h:rockwellautomation:rslinx_enterprise:cpr9:sr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.2`,
        fs:  `cpe:2.3:a:cognos:go\!_office:8.3.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.4`,
        fs:  `cpe:2.3:a:google:chrome:7.0.538.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.5`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.6`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2020:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.7`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.8`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.9`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:2.0.2:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.10`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_client:06-02-\/g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.11`,
        fs:  `cpe:2.3:a:enigmail:enigmail:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.8.12`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.72:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.2`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.3`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.4`,
        fs:  `cpe:2.3:h:sun:fire_x4240_server:sw_2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.5`,
        fs:  `cpe:2.3:o:netbsd:netbsd:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.6`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.0:alpha_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.7`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.5_build_741:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.8`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:2.9.9`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.18:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.0:beta`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.0:rc1`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.0:rc2`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.0:rc3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.0:rc4`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.1`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.2.7:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.2`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.3`,
        fs:  `cpe:2.3:a:haxx:curl:7.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.4`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.6`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.7`,
        fs:  `cpe:2.3:a:islonline:isl_light_remote_desktop:2.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.0.8`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.0`,
        fs:  `cpe:2.3:a:emc:vmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.0:beta`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.0:rc1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.0:rc2`,
        fs:  `cpe:2.3:a:john_koleszar:libvpx:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.2`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(3m\)e8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.4`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.5`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.1.6`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.0`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.0:beta`,
        fs:  `cpe:2.3:h:tp-link:tl-sc3130:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.0:rc1`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.0:rc2`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.07059:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.0:rc3`,
        fs:  `cpe:2.3:a:apache:subversion:0.33.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.0:rc4`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.0:rc5`,
        fs:  `cpe:2.3:a:dimac:jmail.net:1.1.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.1`,
        fs:  `cpe:2.3:h:arris:sbg901:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.2`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.2.3`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.3.0:beta`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.3.0:rc1`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.3.0:rc2`,
        fs:  `cpe:2.3:a:embarcadero:jbuilder_2008_r2:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.3.0:rc3`,
        fs:  `cpe:2.3:h:hp:laserjet_4200ln:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moodle:moodle:3.3.1`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mopl:phone_for_google_voice_%26_gtalk:1.0.6::~~~android~~`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:morbtay:jetty:6.1.0`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:morbus_iff:activism:6.x-2.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:morbus_iff:activism:6.x-2.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.152.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:morbus_iff:activism:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.1`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.1`,
        fs:  `cpe:2.3:a:microsoft:excel_viewer:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.2`,
        fs:  `cpe:2.3:a:vips:vips:7.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.3`,
        fs:  `cpe:2.3:o:vmware:esxi:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.4`,
        fs:  `cpe:2.3:a:open_source_development_team:sthttpd:2.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.5`,
        fs:  `cpe:2.3:a:jquery:jquery:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.5.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.6`,
        fs:  `cpe:2.3:a:tincan:phplist:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.6.1`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.6.2`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.0:ea4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.7`,
        fs:  `cpe:2.3:a:feeds_project:feeds:7.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:more-cowbell:cowbell:0.2.7.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:morequick:greenbrowser:6.0.1002`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:morequick:greenbrowser:6.1.0117`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:morequick:greenbrowser:6.1.0216`,
        fs:  `cpe:2.3:h:hp:3com_switch:ss4_5500-ei-pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:morfy_cms_project:morfy_cms:1.04`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:morpho:itemiser_3:8.17`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.0`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.0.1`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.26:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.1`,
        fs:  `cpe:2.3:a:mozilla:zamboni:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.1.1`,
        fs:  `cpe:2.3:a:symantec:powerquest_deploycenter:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.2.0`,
        fs:  `cpe:2.3:a:nero:nero:9.0.0.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.3.0`,
        fs:  `cpe:2.3:a:microsoft:data_engine:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.3.1`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.3.2`,
        fs:  `cpe:2.3:a:hp:executive_scorecard:9.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.3.3`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp2:compute_cluster:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.3.4`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.2.649:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:1.3.5`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0:alpha1`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0:alpha2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yi3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0:beta1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0:beta2`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0.0`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0.1`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0.2`,
        fs:  `cpe:2.3:h:cisco:vc240_network_bullet_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0.3`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0.4`,
        fs:  `cpe:2.3:a:jenkins:git:3.4.0:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.0.5`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.0`,
        fs:  `cpe:2.3:a:monotone:monotone:0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.2`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.6.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.3`,
        fs:  `cpe:2.3:a:directadmin:directadmin:1.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.5`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6ecf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.6`,
        fs:  `cpe:2.3:a:vips:vips:7.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.7`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.b0`,
        fs:  `cpe:2.3:a:google:v8:3.22.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.1.b1`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2:alpha0`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2:alpha1`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2:beta0`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2:beta1`,
        fs:  `cpe:2.3:a:trillian:trillian:0.635:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2:beta2`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2:beta3`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2:beta4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.0`,
        fs:  `cpe:2.3:a:1024cms:1024_cms:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.1`,
        fs:  `cpe:2.3:a:yumenomachi:demaecan:2.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.2`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.4`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.2:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.5`,
        fs:  `cpe:2.3:a:vips:vips:7.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.6`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.7`,
        fs:  `cpe:2.3:a:gnu:coreutils:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.2.8`,
        fs:  `cpe:2.3:a:apple:apple_tv:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.20.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.3.0a`,
        fs:  `cpe:2.3:a:microsoft:excel:2002:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.3.1`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.3.2`,
        fs:  `cpe:2.3:a:emc:networker:7.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.3.3`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.3.5`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.50917.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.0`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.2`,
        fs:  `cpe:2.3:o:huawei:s5300si_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.3`,
        fs:  `cpe:2.3:a:magzter:english_football_magazine:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.4`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:546:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.5`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.7`,
        fs:  `cpe:2.3:a:sun:sunforum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.8`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.19725:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:2.4.9`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0`,
        fs:  `cpe:2.3:a:status:statusnet:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0:rc2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0:rc3`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0:rc4`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0:rc5`,
        fs:  `cpe:2.3:h:huawei:s3300:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0:rc6`,
        fs:  `cpe:2.3:a:ibm:sametime:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0:rc7`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.0:rc8`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update31:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.1`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.2`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.4`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:931n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.5`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.6`,
        fs:  `cpe:2.3:a:softconcept-inc:seenet:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a0`,
        fs:  `cpe:2.3:a:freemind:freemind:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a2`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a4`,
        fs:  `cpe:2.3:a:openstack:folsom:2012.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a5`,
        fs:  `cpe:2.3:a:adobe:indesign:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a6`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a7`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a8`,
        fs:  `cpe:2.3:a:otrs:faq:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a9`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:2.3.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a90`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.11:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a91`,
        fs:  `cpe:2.3:a:haremthief:harem_thief_dating:1.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a92`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.3:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a93`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a94`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a95`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.6.1871.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a96`,
        fs:  `cpe:2.3:o:vmware:esx:1.5.2:patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a97`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a98`,
        fs:  `cpe:2.3:a:hp:operations_manager:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.a99`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.b01`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:04-00-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.b02`,
        fs:  `cpe:2.3:a:realvnc:realvnc:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.b03`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.b04`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.0.b05`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_inotes_client:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc0`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.3.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc2`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass_guest:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc3`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc4`,
        fs:  `cpe:2.3:a:apache:xerces2_java:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc5`,
        fs:  `cpe:2.3:a:google:chrome:10.0.603.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc6`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc7`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc8`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_internet_server:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1:rc9`,
        fs:  `cpe:2.3:o:cisco:ios:3.5.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.0`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.1`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.2`,
        fs:  `cpe:2.3:a:linear_case_project:linear_case:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.3`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.4`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.5`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.7`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.8`,
        fs:  `cpe:2.3:a:lumberapps:quotes_in_images:3.7.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:3.1.9`,
        fs:  `cpe:2.3:a:tibco:vault:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0:rc1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2_sp1:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0:rc3`,
        fs:  `cpe:2.3:a:advantech:advantech_webaccess:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.0`,
        fs:  `cpe:2.3:o:huawei:s9306_firmware:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:th:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.1:rc0`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(16\)p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.1:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(2\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.1:rc2`,
        fs:  `cpe:2.3:a:microsoft:directx:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.3`,
        fs:  `cpe:2.3:a:graniteds:granite_data_services:3.1.1-snapshot:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.4`,
        fs:  `cpe:2.3:a:christiancafe:christian_dating_cafe:1.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.5`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.6`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server_solution_engine:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.b0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.b1`,
        fs:  `cpe:2.3:a:novell:zenworks_asset_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.b2`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg510-20:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.d0`,
        fs:  `cpe:2.3:a:erlang:crypto:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.d1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.d2`,
        fs:  `cpe:2.3:a:iss:blackice_agent_server:3.6ece:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.d3`,
        fs:  `cpe:2.3:a:aas9:zerocms:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.0.d4`,
        fs:  `cpe:2.3:a:opera:opera_browser:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.0:rc0`,
        fs:  `cpe:2.3:a:hp:trayapp:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.0:rc1`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.0:rc2`,
        fs:  `cpe:2.3:h:intel:d845pt_motherboard:p04-0023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.0:rc3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.54.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.0:rc4`,
        fs:  `cpe:2.3:a:novell:iprint:5.90:-:*:*:*:windows_xp:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.0:rc5`,
        fs:  `cpe:2.3:a:adobe:photoshop_album:2.0:-:starter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.0:rc6`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.2`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.3`,
        fs:  `cpe:2.3:o:dell:bios:a18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.640:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.b0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.2:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.b1`,
        fs:  `cpe:2.3:a:microsoft:office:2013:sp1:*:*:*:rt:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.d0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.d1`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.1.d2`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.2.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2`,
        fs:  `cpe:2.3:h:cisco:guard:5.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.0`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.5.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.0:beta0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.0:rc0`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.0:rc1`,
        fs:  `cpe:2.3:a:oracle:developer_suite:9.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.2`,
        fs:  `cpe:2.3:a:hp:quick_launch_button:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.3`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.4`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.4:rc0`,
        fs:  `cpe:2.3:a:pantech:uml290:1.5.24.1102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.5`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-rc1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.6`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(6.8\)t0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.8_01`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:6200:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.9`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.9:rc1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.9:rc2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.10`,
        fs:  `cpe:2.3:h:softbank:panasonic_3g_handset:001p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.10:pre0`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.10:pre1`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.10:pre2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p337:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.11`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2011.524.2259.39378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.12`,
        fs:  `cpe:2.3:a:elif_keir:knftpd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.14`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.14:rc0`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.14:rc1`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:18.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.15`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.15:rc0`,
        fs:  `cpe:2.3:a:apache:commons_email:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.17`,
        fs:  `cpe:2.3:a:hitachi:developer\&#39;s_kit_for_java:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.18`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.19`,
        fs:  `cpe:2.3:o:ibm:aix:5.3_ml03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.20`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.20:rc0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.21`,
        fs:  `cpe:2.3:a:novell:iprint:5.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.22`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.23`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.8:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.23:rc0`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.03b23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.24`,
        fs:  `cpe:2.3:a:apache:solr:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.24:rc0`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:p07-0029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.24:rc1`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.25`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.26`,
        fs:  `cpe:2.3:h:cisco:catalyst_4507r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:4.2.27`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:alpha0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.7:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:alpha1`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:alpha2`,
        fs:  `cpe:2.3:a:ubi:rayman_legends:1.1.100477:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:alpha3`,
        fs:  `cpe:2.3:a:samba:samba:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:beta0`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.26a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:beta1`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:beta2`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:rc1`,
        fs:  `cpe:2.3:a:everest_poker_project:everest_poker:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:rc3`,
        fs:  `cpe:2.3:a:oce:windows_printer_driver:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0:rc4`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0.0`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.0.0:rc0`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1`,
        fs:  `cpe:2.3:h:cisco:gigabit_switch_router_12008:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1:rc0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1:rc1`,
        fs:  `cpe:2.3:o:buffalotech:wsr-600dhp_firmware:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.0`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.1`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.1:rc0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.1:rc1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.005:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.2`,
        fs:  `cpe:2.3:o:debian:debian_linux:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.2:pre0`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.3`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.25:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.3:rc0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.3:rc1`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.3:rc2`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.3:rc3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.3:rc4`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(26e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.4`,
        fs:  `cpe:2.3:a:dell:networking_guide:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.4:rc0`,
        fs:  `cpe:2.3:a:cisco:ip_contact_center_hosted:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.5`,
        fs:  `cpe:2.3:o:cisco:network_analysis_module_software:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.5:rc0`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.5:rc1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.5:rc2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.7`,
        fs:  `cpe:2.3:a:microsoft:greetings:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.7:rc0`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.8`,
        fs:  `cpe:2.3:a:roxio:backontrack:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.9`,
        fs:  `cpe:2.3:a:netscape:communicator:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.10`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.11`,
        fs:  `cpe:2.3:o:juniper:junos:13.1:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.11:rc0`,
        fs:  `cpe:2.3:a:adobe:flash_player:19.0.0.245:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.12`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.13`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:5.1.14`,
        fs:  `cpe:2.3:a:oracle:database_server:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:alpha0`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.1\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:alpha1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update1:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:alpha2`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:alpha3`,
        fs:  `cpe:2.3:a:morequick:greenbrowser:6.0.1002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta1`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta10`,
        fs:  `cpe:2.3:a:mtouch_quiz_project:mtouch_quiz:3.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta11`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta12`,
        fs:  `cpe:2.3:a:hummingbird:cyberdocs:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta14`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.6.3:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta15`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta16`,
        fs:  `cpe:2.3:a:herbs_\&amp;_flowers_dictionary_project:herbs_\&amp;_flowers_dictionary:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta17`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta2`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta3`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta4`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta5`,
        fs:  `cpe:2.3:a:microsoft:ie:6.0.2900.2180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta6`,
        fs:  `cpe:2.3:a:flyingcart:flying_cart:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta7`,
        fs:  `cpe:2.3:o:xen:xen:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta8`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:beta9`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:gold:datacenter_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:betax`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.3:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:rc0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:rc1`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:rc2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:rc3`,
        fs:  `cpe:2.3:a:vmware:tools:8.3.12.8191:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.0:rc4`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.0.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1080.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0:pre0`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0:pre1`,
        fs:  `cpe:2.3:a:apple:itunes:7.7.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0:pre2`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:02-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0:pre3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0:rc0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:8.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0:rc1`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0:rc2`,
        fs:  `cpe:2.3:a:kerigwa:viper:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.0:rc3`,
        fs:  `cpe:2.3:h:foundrynet:fastiron_800_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.93.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.1:rc0`,
        fs:  `cpe:2.3:a:tera_charts_plugin_project:tera-charts:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-351c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2:pre0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2011.524.2259.39378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2:pre1`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(3\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2:rc0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2:rc1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2:rc2`,
        fs:  `cpe:2.3:a:apptha:wordpress_video_gallery:2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2:rc3`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2:rc4`,
        fs:  `cpe:2.3:a:afsinc:metalcasting_newsstand:3.12.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.2:rc5`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.3`,
        fs:  `cpe:2.3:a:ibm:java:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.4`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update9:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.4:rc0`,
        fs:  `cpe:2.3:a:nginx:nginx:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.4:rc1`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.5`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.5:rc0`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.6`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.6:rc0`,
        fs:  `cpe:2.3:a:gnome:glib:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.6:rc1`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.7`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.8`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.9`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.10`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.11`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:5.5:u3a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.12`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.12:rc1`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:a4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.12:rc2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.12:rc3`,
        fs:  `cpe:2.3:a:cisco:sc2200:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.12:rc4`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.12:rc5`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.14`,
        fs:  `cpe:2.3:a:apache:wicket:6.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.15`,
        fs:  `cpe:2.3:a:sun:java_desktop_system:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.15:pre0`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.15:rc2`,
        fs:  `cpe:2.3:h:rockwellautomation:1768_compact_guardlogix_l4xs_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.15:rc3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.360:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.15:rc4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.15:rc5`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_cm1415fnw_color_multifunction_printer:ce862a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.16`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.19`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.20`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:6.1.21`,
        fs:  `cpe:2.3:a:avaya:ip_soft_phone:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:7.0.0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:7.0.0:m1`,
        fs:  `cpe:2.3:a:webtrees:webtrees:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:7.0.0:m2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:7.0.0:pre0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:7.0.0:pre1`,
        fs:  `cpe:2.3:o:cisco:ios:15.0mr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:7.0.0:pre3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mortbay:jetty:8.1.0:rc2`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.0`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.1`,
        fs:  `cpe:2.3:a:webmin:webmin:1.650:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.1:rc1`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.1:rc2`,
        fs:  `cpe:2.3:a:microsoft:orca:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.1:rc3`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.1:rc4`,
        fs:  `cpe:2.3:a:debian:python-imaging:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.3`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.4`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.5`,
        fs:  `cpe:2.3:a:apache:hadoop:2.0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moshe_weitzman:organic_groups:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mostafa_shemeas_project:mostafa_shemeas:1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mostgear:easy_lan_folder_share:3.2.0.100`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:123scan:2.80`,
        fs:  `cpe:2.3:a:avst:callxpress:7.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:123scan2:1.01`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:air_defense:3.3.0.3::~~personal~~~`,
        fs:  `cpe:2.3:a:lsoft:listserv:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:airdefense_personal_agent:3.1.1`,
        fs:  `cpe:2.3:a:perl:perl:5.14.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:airdefense_personal_agent:3.3.0.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:airdefense_personal_agent:3.4.0.7`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:airdefense_personal_manager:3.4.3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:motorola:android:4.1.2`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:motorola:atrix_hd:-`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:motorola:defy_xt:-:-:~-~-~-~-~republic_wireless`,
        fs:  `cpe:2.3:a:privatemsg_project:privatemsg:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:motorola:moscad_ip_gateway_firmware:-`,
        fs:  `cpe:2.3:a:gnu:cpio:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:motohelper_mergemodules:1.2.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:motorola:motorola_scanner_sdk:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:motorola:razr_hd:-`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2009:3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:motorola:razr_m:-`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mover_project:mover:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:movesti:acontact:1.8.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.10.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moweather:moweather:1.40.05::~~~android~~`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:edr-g903:-`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:edr_g903_firmware:1.0`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:edr_g903_firmware:2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:edr_g903_firmware:2.1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.2.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:edr_g903_firmware:2.2`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:edr_g903_firmware:3.4.11`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.17:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:ioadmin_firmware:3.17`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2210:-`,
        fs:  `cpe:2.3:a:relevanssi:relevanssi:3.3.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2210-t:-`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2212:-`,
        fs:  `cpe:2.3:h:hp:elitedesk_800_g2_twr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2212-t:-`,
        fs:  `cpe:2.3:a:mcafee:host_data_loss_prevention:9.0.0.416:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2214:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2214-t:-`,
        fs:  `cpe:2.3:a:python:pillow:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2240:-`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2240-t:-`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2242:-`,
        fs:  `cpe:2.3:a:jease:jease:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2242-t:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2260:-`,
        fs:  `cpe:2.3:a:ubnt:unifi_video:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2260-t:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2262:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:iologic_e2262-t:-`,
        fs:  `cpe:2.3:a:adobe:dreamweaver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:iologik_firmware:3.11`,
        fs:  `cpe:2.3:a:marek_jasinski:freecommander:2009.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:miineport_e1_4641:-`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:miineport_e1_4641_firmware:1.1.10`,
        fs:  `cpe:2.3:a:logilab:logilab-common:0.59.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:miineport_e1_7080:-`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:miineport_e1_7080_firmware:1.1.10`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:miineport_e2_1242:-`,
        fs:  `cpe:2.3:a:microsoft:project_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:miineport_e2_1242_firmware:1.1`,
        fs:  `cpe:2.3:a:accellion:kiteworks_appliance:kw2016.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:miineport_e2_4561:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je023a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:miineport_e2_4561_firmware:1.1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:miineport_e3:-`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:miineport_e3_firmware:1.0`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxa:oncell_central_manager:2.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:oncell_gateway_firmware:1.3`,
        fs:  `cpe:2.3:a:google:v8:3.24.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:moxa:oncell_gateway_firmware:1.4`,
        fs:  `cpe:2.3:a:quest:intrust_indexing_tool:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:oncell_gateway_g3111:-`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:oncell_gateway_g3151:-`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:oncell_gateway_g3211:-`,
        fs:  `cpe:2.3:a:xymon:xymon:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:moxa:oncell_gateway_g3251:-`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxa:softcms:1.2`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.4.0`,
        fs:  `cpe:2.3:a:microsoft:msn_setup_bulletin_board_services:4.71.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.4.1`,
        fs:  `cpe:2.3:a:ca:etrust_iam_suite:12.0.7.441:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.4.2`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.4.3`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.4:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.0:beta`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.1\(1.95\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.2`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.3`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.4`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.5`,
        fs:  `cpe:2.3:a:minitab:quality_companion:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.6`,
        fs:  `cpe:2.3:a:symantec:vrtsccg:5.0.433:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:moxiecode:plupload:1.5.7`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bonsai:-`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.4:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bonsai:1.3`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.2.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.2`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.4`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_1300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.6`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.8`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.9`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.10`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.12`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.14`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.14.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.14.2`,
        fs:  `cpe:2.3:a:microsoft:forefront_unified_access_gateway:2010:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.14.3`,
        fs:  `cpe:2.3:a:docker:docker:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.14.4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.14.5`,
        fs:  `cpe:2.3:a:silver-peak:vx:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.3.2:rev39009:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16:rc1`,
        fs:  `cpe:2.3:a:siemens:scalance_x308-2m_firmware:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16:rc2`,
        fs:  `cpe:2.3:a:f5:big-iq_adc:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.1`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.2`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.00:-:*:*:*:suse_linux:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.3`,
        fs:  `cpe:2.3:a:isc:bind:9.2.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.5`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.6`,
        fs:  `cpe:2.3:h:citrix:application_gateway_for_nortel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.7`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.34:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.8`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.9`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.10`,
        fs:  `cpe:2.3:a:adobe:indesign_cs4_icon_handler:6.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.16.11`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.17`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.17.1`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.17.2`,
        fs:  `cpe:2.3:a:apache:camel:2.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.17.3`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.17.4`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:12:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.17.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.15:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.17.6`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.17.7`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18:rc1`,
        fs:  `cpe:2.3:a:adobe:pdf_settings_cs5:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18:rc2`,
        fs:  `cpe:2.3:a:sas:base_sas:9.2:ts2m:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18:rc3`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.1`,
        fs:  `cpe:2.3:a:fujitsu:interstage_application_server:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.2`,
        fs:  `cpe:2.3:a:osisoft:pi_interface:1.0.5.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p131:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.4`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.5`,
        fs:  `cpe:2.3:o:verizon:fios_actiontec_mi424wr-gen31_router_firmware:40.19.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.6`,
        fs:  `cpe:2.3:a:condor_project:condor:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.6%2b`,
        fs:  `cpe:2.3:h:cisco:c460_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.7`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.8`,
        fs:  `cpe:2.3:a:freetype:freetype:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.18.9`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.19`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.10.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.19.1`,
        fs:  `cpe:2.3:a:apache:tomcat_connectors:1.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.19.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.19.3`,
        fs:  `cpe:2.3:a:skype:skype:3.1.0.112:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20:rc1`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20:rc2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20.1`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20.2`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20.4`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20.5`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20.6`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.20.7`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.36:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.21`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.21.1`,
        fs:  `cpe:2.3:a:cisco:ucs_director:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.21.2`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.21.2:rc1`,
        fs:  `cpe:2.3:a:lavalite:lavalite:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22:rc1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22.2`,
        fs:  `cpe:2.3:a:sparxsystems:enterprise_architect:7.0.827:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22.3`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22.4`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.1:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22.5`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22.6`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.22.7`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.23`,
        fs:  `cpe:2.3:o:iij:seil\%2fx2_firmware:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.23.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.379.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.23.2`,
        fs:  `cpe:2.3:a:grape_project:grape:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.23.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:2.23.4`,
        fs:  `cpe:2.3:a:sapien:primalscript:4.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0:rc1`,
        fs:  `cpe:2.3:a:ca:cleverpath_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.0`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.1`,
        fs:  `cpe:2.3:a:kent-web:clip-mail:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.3`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:12.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.5`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.6`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.7`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_apppack:5.1.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.8`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.9`,
        fs:  `cpe:2.3:h:hp:procurve_switch_1700-24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.10`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.0.11`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.1.0`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.1.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.1.3`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.1.4`,
        fs:  `cpe:2.3:a:logitech:mouseware:9.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2:rc1`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.6:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2:rc2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.614:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.1`,
        fs:  `cpe:2.3:a:augeas:augeas:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.3`,
        fs:  `cpe:2.3:a:leg_surgery_-_kids_games_project:leg_surgery_-_kids_games:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.4`,
        fs:  `cpe:2.3:a:apache:subversion:0.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.5`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.6`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.7`,
        fs:  `cpe:2.3:h:schneider-electric:tburjr900:00002dh0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.8`,
        fs:  `cpe:2.3:h:ibm:mcs-7835i-2.4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.9`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.2.10`,
        fs:  `cpe:2.3:a:c\/ssolutions:risk\&#43;_for_microsoft_project:2.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.3`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.8:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.3.1`,
        fs:  `cpe:2.3:a:kieranoshea:calendar:1.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.3.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.3.3`,
        fs:  `cpe:2.3:a:express:express:2.5.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.3.4`,
        fs:  `cpe:2.3:a:ibm:intelligent_operations_center:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.671:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4:rc1`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.2`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.126:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.3`,
        fs:  `cpe:2.3:a:isc:bind:9.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.4`,
        fs:  `cpe:2.3:a:telos:xacta_assessment_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.5`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.6`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.7`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.8`,
        fs:  `cpe:2.3:a:hp:proliant_ilo_monitor_service:3.3.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.9`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.10`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:10.0.1733:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.11`,
        fs:  `cpe:2.3:a:timely:all-in-one_event_calendar:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.12`,
        fs:  `cpe:2.3:a:apache:log4j:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.13`,
        fs:  `cpe:2.3:a:piwik:piwik:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.4.14`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.5`,
        fs:  `cpe:2.3:a:redhat:wu_ftpd:2.6.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.5.1`,
        fs:  `cpe:2.3:a:publicstuff:elk_grove_publicstuff:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.5.2`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc_3208:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.5.3`,
        fs:  `cpe:2.3:a:site_banner_project:site_banner:7.x-4.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6:rc1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_rich_text_editor:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.599.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.2`,
        fs:  `cpe:2.3:o:alcatel:aos:6.3.1.966:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.3`,
        fs:  `cpe:2.3:a:apache:juddi:0.9:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.4`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.5`,
        fs:  `cpe:2.3:a:redhat:freeipa:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.6`,
        fs:  `cpe:2.3:a:quagga:quagga:0.97.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.7`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta44:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.8`,
        fs:  `cpe:2.3:a:alkacon:opencms:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.9`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.10`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.11`,
        fs:  `cpe:2.3:a:nbe:nbe:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.12`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.6.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.7`,
        fs:  `cpe:2.3:a:praninc:facebook_facts:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.7.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.7.2`,
        fs:  `cpe:2.3:a:intel:mdriver:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:3.7.3`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.1.1:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0:rc1`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0:rc2`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.0q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.4`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.5`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.6`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.7`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.8`,
        fs:  `cpe:2.3:a:gcspublishing:homesteading_today:3.7.14:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.9`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.10`,
        fs:  `cpe:2.3:a:sympa:sympa:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.11`,
        fs:  `cpe:2.3:h:nec:ix2010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.13`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.45.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.14`,
        fs:  `cpe:2.3:a:advantech:webaccess:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.542:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.16`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.17`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.0.18`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.1.1`,
        fs:  `cpe:2.3:a:sympa:sympa:2.7b.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.1.2`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.92.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.1.3`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2:rc1`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.0.1.531:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2:rc2`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.2`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.51.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.3`,
        fs:  `cpe:2.3:a:openfabrics:ibutils:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.4`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.5`,
        fs:  `cpe:2.3:a:smarty:smarty:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)yv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.7`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0.1984:online_windows_2000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p44:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.9`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.10`,
        fs:  `cpe:2.3:a:watcha:watcha:2.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.11`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.12`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.0.471780:*:*:*:winpre2k:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.13`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.14`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.2.15`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.3`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.3.1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.3.2`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:8.5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.3.3`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.17:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4:-`,
        fs:  `cpe:2.3:a:intuit:quicken:2001:*:*:*:basic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4:rc1`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:4.10.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4:rc2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.4`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:179:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.5`,
        fs:  `cpe:2.3:a:microsoft:small_business_srv:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.6`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.7`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.38:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.8`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.9`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.10`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.4.11`,
        fs:  `cpe:2.3:a:ibm:spss_data_collection:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.5.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.5.3`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.5.4`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0-23:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:4.5.6`,
        fs:  `cpe:2.3:a:perl:perl:5.12.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(22\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:5.0:rc1`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:5.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:5.0:rc3`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:5.0.1`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:bugzilla:5.0.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:-`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.1`,
        fs:  `cpe:2.3:a:teamst:testlink:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.2`,
        fs:  `cpe:2.3:a:tincan:phplist:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.4`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.10:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.5`,
        fs:  `cpe:2.3:o:huawei:secospace_usg6600_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.6`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.7`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.5.1:*:ja:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.8`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.8:alpha1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.8.1`,
        fs:  `cpe:2.3:h:supermicro:x9db3-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.8.2`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2012-01-25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.8.3`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.8.4`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_embedded:10.0.0.533:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.8.5`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.2.0:cp03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:0.9:alpha2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.06.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:camino:1.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:durian_web_application_server:-`,
        fs:  `cpe:2.3:a:twilio_project:twilio:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:durian_web_application_server:3.02`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.3.0:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:-`,
        fs:  `cpe:2.3:a:php:php:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.2`,
        fs:  `cpe:2.3:a:hummingbird:connectivity:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.3`,
        fs:  `cpe:2.3:a:hp:network_node_manager:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.4`,
        fs:  `cpe:2.3:o:huawei:s6700_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.5`,
        fs:  `cpe:2.3:a:lumenera:infinity_software:5.0.2.6.4339:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.6`,
        fs:  `cpe:2.3:a:google:chrome:4.0.272.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.7`,
        fs:  `cpe:2.3:a:lyften:com_lyftenbloggie:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.7.1`,
        fs:  `cpe:2.3:o:huawei:quidway_s5300_firmware:v200r001c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.8`,
        fs:  `cpe:2.3:a:vmware:infrastructure_client:2.5.0.64227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.9`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.16:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.9:rc`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.9.1`,
        fs:  `cpe:2.3:a:icofx:icofx:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.9.2`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.9.3`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.10`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.2.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:0.10.1`,
        fs:  `cpe:2.3:a:symantec:mail_security_for_microsoft_exchange:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.8:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0:preview_release`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0.2`,
        fs:  `cpe:2.3:a:fuelrewards:fuel_rewards_network:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0.3`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0.6`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0.7`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.0.8`,
        fs:  `cpe:2.3:a:samba:samba:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.4.1`,
        fs:  `cpe:2.3:a:echonewshk:echo_news:beta:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5:beta1`,
        fs:  `cpe:2.3:a:boost:boost:1.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5:beta2`,
        fs:  `cpe:2.3:a:synology:video_station:1.6-0841:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.1`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.4`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.5`,
        fs:  `cpe:2.3:a:netscape:communications_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.6`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.7`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.8`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.9`,
        fs:  `cpe:2.3:a:ibm:forms_viewer:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.10`,
        fs:  `cpe:2.3:a:evan_dandrea:usb-creator:0.2.40ubuntu2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.11`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.0.12`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.2`,
        fs:  `cpe:2.3:a:egroupware:egroupware:1.8.001.20110421:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.4`,
        fs:  `cpe:2.3:a:josh_fradley:burden:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.5`,
        fs:  `cpe:2.3:a:apple:xcode:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.6`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.7`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.5.8`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update1:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:1.8`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.1`,
        fs:  `cpe:2.3:a:apple:java_1.3:1:15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.2`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.3`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.4`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.5`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.6`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.7`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_38:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.9`,
        fs:  `cpe:2.3:a:ibm:ibmhsssb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.10`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.11`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.12`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.13`,
        fs:  `cpe:2.3:o:cisco:staros:16.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.14`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.15`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.16`,
        fs:  `cpe:2.3:a:checkpw_project:checkpw:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.17`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.18`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs748t:v4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.19`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:2.0.0.20`,
        fs:  `cpe:2.3:a:attachmate:infoconnect_for_unisys:9.0.1393:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0`,
        fs:  `cpe:2.3:a:apache:derby:10.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.2`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.3`,
        fs:  `cpe:2.3:a:python:python:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.4`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.5`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.6`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.7`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.5:i1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.8`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.9`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.10`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.11`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.12`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.0.1.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.13`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.14`,
        fs:  `cpe:2.3:a:zotpress_project:zotpress:6.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.15`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.16`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.17`,
        fs:  `cpe:2.3:o:novell:opensuse:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.18`,
        fs:  `cpe:2.3:a:plone:plone:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.0.19`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.1`,
        fs:  `cpe:2.3:a:libav:libav:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.2`,
        fs:  `cpe:2.3:h:siemens:3568i_wap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.3`,
        fs:  `cpe:2.3:a:fusionforge:fusionforge:6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.4`,
        fs:  `cpe:2.3:h:cisco:aironet_1140:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.5`,
        fs:  `cpe:2.3:h:dell:truemobile_2300_wireless_broadband_router:3.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.7`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.8`,
        fs:  `cpe:2.3:h:hp:jc654a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.9`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.10`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.11`,
        fs:  `cpe:2.3:o:moxa:edr_g903_firmware:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.12`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.4.2:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.13`,
        fs:  `cpe:2.3:h:3com:141701:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.14`,
        fs:  `cpe:2.3:a:99only:buy_99_cents_only_products:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.15`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.16`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.17`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.18`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.5.19`,
        fs:  `cpe:2.3:a:hp:virtual_rooms_client_launcher_plugin:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6`,
        fs:  `cpe:2.3:a:ibm:rational_directory_server:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.2`,
        fs:  `cpe:2.3:a:david_king:vino:2.7.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.3`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.4`,
        fs:  `cpe:2.3:a:adobe:camera_raw:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.6`,
        fs:  `cpe:2.3:a:lianja:lianja_sql_server:1.0:rc5.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.7`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.8`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server_for_windows:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.9`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.10`,
        fs:  `cpe:2.3:a:altiris:server_management_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.11`,
        fs:  `cpe:2.3:a:schneider-electric:ofs_test_client_tlxcdstofs33:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.12`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.13`,
        fs:  `cpe:2.3:a:adobe:illustrator:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.14`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.15`,
        fs:  `cpe:2.3:a:metalogix:sharepoint_extensions_web_service:4.1.1304:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.16`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.17`,
        fs:  `cpe:2.3:a:hp:operations_agent:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.18`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.19`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.20`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.21`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.22`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.23`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.24`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.25`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:7.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.26`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.27`,
        fs:  `cpe:2.3:h:ibm:avocent_1754_kvm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:3.6.28`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta1`,
        fs:  `cpe:2.3:a:pageplanetsoftware:mgi_server:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta10`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta11`,
        fs:  `cpe:2.3:h:netgear:wg311v1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta12`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1673.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta2`,
        fs:  `cpe:2.3:a:govhk:government_bookstore:1.01:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta3`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta4`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta5`,
        fs:  `cpe:2.3:a:isc:bind:9.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta6`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta7`,
        fs:  `cpe:2.3:h:hp:laserjet_m4345_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta8`,
        fs:  `cpe:2.3:a:apple:itunes:11.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0:beta9`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:4.0.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-00-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:5.0`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:5.0.1`,
        fs:  `cpe:2.3:a:apple:xcode:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:6.0`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:6.0.1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:6.0.2`,
        fs:  `cpe:2.3:a:opscode:chef:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:7.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultracompare:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:7.0.1`,
        fs:  `cpe:2.3:a:google:v8:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:8.0`,
        fs:  `cpe:2.3:a:microsoft:works:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:8.0.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:9.0`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:9.0.1`,
        fs:  `cpe:2.3:a:novell:zenworks:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.3`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.4`,
        fs:  `cpe:2.3:a:vmware:player:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.5`,
        fs:  `cpe:2.3:a:google:v8:3.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.7`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.9`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.10`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.11`,
        fs:  `cpe:2.3:a:ubuntu_developers:systemd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:10.0.12`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:11.0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:12.0`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:12.0:beta6`,
        fs:  `cpe:2.3:o:ibm:aix:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:13.0`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:p09-0035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:13.0.1`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:14.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:14.0.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:15.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:15.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1db:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:16.0`,
        fs:  `cpe:2.3:a:dolphin-browser:dolphin_browser_mini:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:16.0.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:16.0.2`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.2`,
        fs:  `cpe:2.3:a:isc:bind:9.8.0:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.3`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0.2.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.4`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.5`,
        fs:  `cpe:2.3:o:huawei:honor_6_firmware:h60-l02c00b850:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.6`,
        fs:  `cpe:2.3:a:augeas:augeas:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.7`,
        fs:  `cpe:2.3:a:ca:secure_content_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.8`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.9`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.2.3sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.10`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:17.0.11`,
        fs:  `cpe:2.3:a:x:libxcb:1.1.90.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:18.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:0.9:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:18.0.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:18.0.2`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:19.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.18:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:19.0.1`,
        fs:  `cpe:2.3:a:x.org:libx11:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:19.0.2`,
        fs:  `cpe:2.3:a:gameloft:brothers_in_arms_2_free\&#43;:1.2.0:b:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:20.0`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2.5:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:20.0.1`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:21.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:16.0.0.287:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:22.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:23.0`,
        fs:  `cpe:2.3:h:apple:macbook_air:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:23.0.1`,
        fs:  `cpe:2.3:a:keepass:keepass:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:24.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:24.1`,
        fs:  `cpe:2.3:a:microsoft:ie:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:24.1.1`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:97:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:25.0`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:25.0.1`,
        fs:  `cpe:2.3:a:toshiba:surveillix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:26.0`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:27.0`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:27.0.1`,
        fs:  `cpe:2.3:a:microsoft:virtual_machine_manager:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:28.0`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:29.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:29.0.1`,
        fs:  `cpe:2.3:a:supmua:sup:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:30.0`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:31.0`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:31.1.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.7.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:32.0`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:33.0`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:34.0.5`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:7.6.120.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:35.0.1`,
        fs:  `cpe:2.3:h:ekahau:b4_staff_badge_tag:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:36.0.1`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:36.0.3`,
        fs:  `cpe:2.3:h:cisco:sf300-24pp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:36.0.4`,
        fs:  `cpe:2.3:h:siemens:scalance_w786-2pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:37.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:37.0.1`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:2012.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:37.0.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:38.0`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:40.0.3`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:7.85.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:41.0`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:41.0.1`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:41.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)dd3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:42.0`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:42.0::~~~~x64~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:43.0`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:43.0.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_express:10.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:43.0.2`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.5.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:43.0.3`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.43.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:43.0.4`,
        fs:  `cpe:2.3:a:apple:xcode:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:44.0.1`,
        fs:  `cpe:2.3:a:vmware:player:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:44.0.2`,
        fs:  `cpe:2.3:h:cisco:nexus_7000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:45.0.1`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-28p-si_ls-3600-28p-si-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:45.0.2`,
        fs:  `cpe:2.3:a:thegr:dl:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:46.0.1`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:47.0.1`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:48.0.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:49.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/i:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:49.0.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:49.0.2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:50.0`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:50.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:50.0.2`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:51.0`,
        fs:  `cpe:2.3:a:hp:business_availability_center:8.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:51.0.1`,
        fs:  `cpe:2.3:a:videowhisper:live_streaming_integration_plugin:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox:52.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.561:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.1`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.3:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.3`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.4`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.6.1.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.5`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.6`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20000825:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.7`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.8`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.9`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.7:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.10`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.11`,
        fs:  `cpe:2.3:a:digia:qt:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:10.0.12`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0`,
        fs:  `cpe:2.3:a:inline_entity_form_project:inline_entity_form:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.2`,
        fs:  `cpe:2.3:a:apple:safari:3.0.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.3`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:0.9.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.4`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:8.0.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.5`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.6`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.7`,
        fs:  `cpe:2.3:a:google:chrome:15.0.873.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.8`,
        fs:  `cpe:2.3:a:misterpark:re\:kyu:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.9`,
        fs:  `cpe:2.3:a:gnu:zebra:0.92a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.10`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:17.0.11`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.0`,
        fs:  `cpe:2.3:a:oracle:industry_applications:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.0.1`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.0.2`,
        fs:  `cpe:2.3:a:ksoffice:office_2010:6.6.0.2477:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.1.0`,
        fs:  `cpe:2.3:a:ibm:netezza_performance_portal:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.1.1`,
        fs:  `cpe:2.3:a:ibm:rational_appscan_source:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.2`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.3`,
        fs:  `cpe:2.3:a:siemens:scalance_xr-300_firmware:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.4`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.5`,
        fs:  `cpe:2.3:a:apple:keynote:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.6`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.7`,
        fs:  `cpe:2.3:a:roxio:backontrack:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:24.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.1`,
        fs:  `cpe:2.3:h:hp:advanced_server_9000:b.04.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.1.0`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.1.1`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.2`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.3.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.4`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.5`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.5.1`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.5.2`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2013:cumulative_update_7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.5.3`,
        fs:  `cpe:2.3:a:bea:aqualogic_service_bus:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.6`,
        fs:  `cpe:2.3:a:improved_user_search_in_backend_project:improved_user_search_in_backend:1.2.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:31.8`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.0`,
        fs:  `cpe:2.3:a:member_approval_plugin_project:member_approval:131109:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.0::~~~~x64~`,
        fs:  `cpe:2.3:a:netscape:communicator:4.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.0.1`,
        fs:  `cpe:2.3:a:apache:commons_fileupload:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.0.1::~~~~x64~`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.0.5`,
        fs:  `cpe:2.3:a:oracle:applications_framework:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.0.5::~~~~x64~`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.1.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.1.0::~~~~x64~`,
        fs:  `cpe:2.3:a:polycom:rss_system_software:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.1.1`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.1.1::~~~~x64~`,
        fs:  `cpe:2.3:a:fonality:trixbox:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.2.0`,
        fs:  `cpe:2.3:o:vmware:esx:3.5:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.2.0::~~~~x64~`,
        fs:  `cpe:2.3:a:ireadercity:demon:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.2.1`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.2.1::~~~~x64~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.3.0`,
        fs:  `cpe:2.3:a:x2engine:x2crm:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.3.0::~~~~x64~`,
        fs:  `cpe:2.3:a:oracle:business_intelligence_publisher:11.1.1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.4.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.4.0::~~~~x64~`,
        fs:  `cpe:2.3:h:hp:3com_baseline_plus_switch:2900g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.5.0`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.5.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.6.0`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.6.1`,
        fs:  `cpe:2.3:h:hp:vpn_firewall_appliance:jg213a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.7.0`,
        fs:  `cpe:2.3:a:novell:groupwise_messenger:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:38.7.1`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:45.0.2`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:45.1.0`,
        fs:  `cpe:2.3:o:asus:rt-ac68u_firmware:3.0.0.4.374_4983:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:45.1.1`,
        fs:  `cpe:2.3:a:ostenta:yawpp:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:45.2.0`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_esr:45.3.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:1.0`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:4.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:4.0:beta1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:4.0:beta2`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(5a\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:4.0:beta3`,
        fs:  `cpe:2.3:a:ibm:security_privileged_identity_manager:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:4.0:beta4`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:5.0`,
        fs:  `cpe:2.3:a:fishshell:fish:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:6.0`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.5-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:6.0.1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:6.0.2`,
        fs:  `cpe:2.3:a:bookjam:cookbible:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:7.0`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:8.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.26.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:9.0`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:10.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)t10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:10.0.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:10.0.2`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:10.0.3`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:firefox_mobile:10.0.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.7.6\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mozilla:firefox_os:-`,
        fs:  `cpe:2.3:a:hp:performance_validation_sdk:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mozilla:firefox_os:2.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mozilla:firefoxos:1.2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mozilla:firefoxos:1.2.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:mozilla:firefoxos:1.3`,
        fs:  `cpe:2.3:a:aloaha:aloahapdfviewer:5.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:gecko:-`,
        fs:  `cpe:2.3:a:gannett:daily_advertiser_print:6.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:-`,
        fs:  `cpe:2.3:a:cognos:windows_common_logon_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.8`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.2.1`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.4.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:-:*:*:*:control:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.27:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.6`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.7`,
        fs:  `cpe:2.3:a:codehaus:xfire:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.8`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.9`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.35`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:0.9.48`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.0.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.1.11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.0.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.1:alpha`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.1:beta`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.2`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.2:alpha`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.2:beta`,
        fs:  `cpe:2.3:a:apple:quicktime_pictureviewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.2.1`,
        fs:  `cpe:2.3:a:buffalotech:wzr-ampg144nh_firmware:1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.3`,
        fs:  `cpe:2.3:a:nec:universal_raid_utility:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.4:alpha`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(1\)se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.4:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.4.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.4.2`,
        fs:  `cpe:2.3:a:svnlabs:html5_mp3_player_with_playlist_free:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.4.4`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.5`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.5:alpha`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.5:rc1`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.5:rc2`,
        fs:  `cpe:2.3:a:uplus:u\&#43;box_2.0:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.5.1`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.6`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.6:alpha`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.6:beta`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7:alpha`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7:beta`,
        fs:  `cpe:2.3:a:apache:storm:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7:rc1`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.12:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7:rc2`,
        fs:  `cpe:2.3:o:redhat:fedora:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7:rc3`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-28p-hpwr-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.8:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.2`,
        fs:  `cpe:2.3:a:relsoftware:web_link_validator:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.3`,
        fs:  `cpe:2.3:a:dotclear:dotclear:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.4`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.5`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp3:datacenter_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.6`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.7`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.8`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.9`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.10`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.0.1:mu_\#5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.11`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.7.12`,
        fs:  `cpe:2.3:a:digia:qt:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.8:alpha1`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.4.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.8:alpha2`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.8:alpha3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:1.8:alpha4`,
        fs:  `cpe:2.3:a:grape_project:grape:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla:5.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_mail:-`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_suite:-`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_suite:1.7.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.08.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_suite:1.7.7`,
        fs:  `cpe:2.3:a:ibm:integration_bus:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_suite:1.7.8`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_suite:1.7.10`,
        fs:  `cpe:2.3:a:posh_project:posh:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_suite:1.7.11`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_suite:1.7.12`,
        fs:  `cpe:2.3:a:gnu:glibc:2.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:mozilla_suite:1.7.13`,
        fs:  `cpe:2.3:a:rakus:maildealer:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.1.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3020_concentrator:4.7.1.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.1.2`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.2.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.3`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.4.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.5.1`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.304:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6.1`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6.2`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6.3`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6.4`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6.5`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.3d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6.7`,
        fs:  `cpe:2.3:a:google:chrome:15.0.867.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.6.8`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.7`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.7.1`,
        fs:  `cpe:2.3:a:ibm:sterling_b2b_integrator:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.7.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.7.3`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:5.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.7.4`,
        fs:  `cpe:2.3:a:feedweb:feedweb:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.7.5`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.7.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8`,
        fs:  `cpe:2.3:a:php-nuke:mermaid_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8.2`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0540:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8.3`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:12.5.2213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8.4`,
        fs:  `cpe:2.3:a:redhat:network_satellite:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8.5`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8.6`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8.7`,
        fs:  `cpe:2.3:a:qlogic:sansurfer_fc_hba_management_agent:1.0.1281.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8.8`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.8.9`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.78.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.9`,
        fs:  `cpe:2.3:a:skype:skype:4.1.0.130:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.9.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.9.2`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.9.3`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_75:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.9.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.9.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.9.6`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.10`,
        fs:  `cpe:2.3:a:redhat:cygwin:1.5.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.10.1`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:5.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.10.2`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.10.3`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.10.4`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.3.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.10.5`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:netscape_portable_runtime:4.10.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.23:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.2`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.2.1`,
        fs:  `cpe:2.3:a:emc:documentum_d2:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.3`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:10.6.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.3.1`,
        fs:  `cpe:2.3:a:nokia:affix:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.3.2`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.4`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1-14:fix06:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.4.1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.4.2`,
        fs:  `cpe:2.3:a:godwin\&#39;s_law_project:godwin\&#39;s_law:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.5`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.6`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.1.8:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.6.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.7`,
        fs:  `cpe:2.3:a:perl:perl:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.7.1`,
        fs:  `cpe:2.3:a:zope:zope:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.7.2`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.7.3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.7.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.7.7`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.8`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.9`,
        fs:  `cpe:2.3:a:mozilla:firefox:25.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.11.2`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.11.3`,
        fs:  `cpe:2.3:a:debian:apt:0.8.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.11.4`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.11.5`,
        fs:  `cpe:2.3:a:sybase:easerver:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12`,
        fs:  `cpe:2.3:a:samsung:smart_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.2`,
        fs:  `cpe:2.3:a:avaya:intuity_audix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.3`,
        fs:  `cpe:2.3:a:f5:big-ip_websafe:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.3.1`,
        fs:  `cpe:2.3:a:sage-mozdev:sage:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.3.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.4`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.5`,
        fs:  `cpe:2.3:a:adcisolutions:node_view_permissions:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.6`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je005a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.7`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.8`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.9`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144nh_firmware:1.47:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.10`,
        fs:  `cpe:2.3:a:intel:proset\/wireless_wifi_api:12.1.2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.12.11`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.14`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.14.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.14.2`,
        fs:  `cpe:2.3:a:justsystems:ichitaro_viewer:19.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.14.3`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.14.4`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.14.5`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0583:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.15`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.4.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.15.1`,
        fs:  `cpe:2.3:a:exim:exim:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.15.2`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.15.3`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.15.3.1`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.15.4`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.15.5`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.16`,
        fs:  `cpe:2.3:a:isc:bind:9.10.3:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.19`,
        fs:  `cpe:2.3:o:cisco:ios:12.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.19.2`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.19.2.0`,
        fs:  `cpe:2.3:a:scientificlinux:luci:0.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.20`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.20.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.20.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0\(3a\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.21`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.21.3`,
        fs:  `cpe:2.3:a:ixiacom:ixia_appinfo:1.0.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.22`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.28.3`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak2:2.0.23.19:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.29.3`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:network_security_services:3.30`,
        fs:  `cpe:2.3:a:brother:mfl-pro_suite:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:nss:3.20.1`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:-`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0`,
        fs:  `cpe:2.3:o:omron:ns_series_system_program_firmware:8.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0:alpha`,
        fs:  `cpe:2.3:a:php-nuke:eboard_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0:beta`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.3`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.1.02011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.4`,
        fs:  `cpe:2.3:a:boeing:drs_annotation_tool:2.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)dc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.6`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.7`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.0.9`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:9.7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1`,
        fs:  `cpe:2.3:a:adobe:dreamweaver_mx:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1::alpha`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.91:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1::beta`,
        fs:  `cpe:2.3:a:oracle:customer_relationship_management_technical_foundation:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1:alpha`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1:beta`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.06.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.2`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.15:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.4`,
        fs:  `cpe:2.3:a:huawei:espace_7910:v200r002c00spc600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.5`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.4:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.6`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.7`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.8`,
        fs:  `cpe:2.3:a:gadgettrak:gadgettrak_mobile_security:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.9`,
        fs:  `cpe:2.3:a:nuance:smart_document_scan_software:1.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.10`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.11`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.12`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.13`,
        fs:  `cpe:2.3:a:samba:samba:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.14`,
        fs:  `cpe:2.3:a:netgear:wg111v2_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.15`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.16`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.17`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.3:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.18`,
        fs:  `cpe:2.3:h:fortinet:fortiadc-1000e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.1.19`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.5.0.8`,
        fs:  `cpe:2.3:a:seagate:seagate_manager_installer:2.1.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.5.0.9`,
        fs:  `cpe:2.3:a:portaputty:portaputty:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:1.5.0.10`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0`,
        fs:  `cpe:2.3:a:vmware:workstation:7.1.4.16648:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0:alpha_1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0:alpha_2`,
        fs:  `cpe:2.3:a:isc:bind:8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0:alpha_3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1sg.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0:beta_1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0:beta_2`,
        fs:  `cpe:2.3:a:microsoft:active_directory_federation_services:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0:rc1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0:rc2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.3`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.4`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.6`,
        fs:  `cpe:2.3:a:ciphertrust:ironmail:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.7`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:gold:datacenter_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.8`,
        fs:  `cpe:2.3:o:xen:xen:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.9`,
        fs:  `cpe:2.3:a:oracle:internet_expenses:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.10`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.11`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.12`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:1.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.13`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.0.14`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1:alpha1`,
        fs:  `cpe:2.3:a:websense:websense_web_security:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1:alpha2`,
        fs:  `cpe:2.3:a:gajim:gajim:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1:alpha3`,
        fs:  `cpe:2.3:a:freereprintables:articlefr:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1:beta1`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1:beta2`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1:beta3`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1:rc1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(2e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.1:rc2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.2`,
        fs:  `cpe:2.3:a:apple:safari:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.2:beta1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.2:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.2:beta3`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.3`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.3:beta1`,
        fs:  `cpe:2.3:h:huawei:eudemon1000e-x:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.3:beta2`,
        fs:  `cpe:2.3:o:conectiva:linux:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.3:beta3`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.3.1`,
        fs:  `cpe:2.3:a:att:communication_manager:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.3.2`,
        fs:  `cpe:2.3:a:perl:perl:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.3.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.371:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.4`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.4:beta1`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.4:beta2`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.4:beta3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.4.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.5`,
        fs:  `cpe:2.3:a:piriform:ccleaner:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.5:beta1`,
        fs:  `cpe:2.3:a:tasofro:touhou-hisouten:1.06:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.5:beta2`,
        fs:  `cpe:2.3:a:google:chrome:16.0.911.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.5:beta3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.5:beta4`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.6`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.6:beta1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.6:beta2`,
        fs:  `cpe:2.3:o:blackberry:blackberry_playbook_os:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.6:beta3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.6:beta4`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.6.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:36.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.7`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.7:beta1`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.7:beta2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.7:beta3`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.7:beta4`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.7:beta5`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0404hd-a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.7.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.7.2`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.8`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.8:beta1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.8:beta2`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.8:beta3`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.5:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.8:beta4`,
        fs:  `cpe:2.3:a:cybozu:cybozu_office:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.8:beta5`,
        fs:  `cpe:2.3:a:justsystems:hanako_police3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.8:beta6`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.9`,
        fs:  `cpe:2.3:a:xnview:xnview:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.9:beta1`,
        fs:  `cpe:2.3:a:sun:cluster:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.9:beta2`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.9:beta3`,
        fs:  `cpe:2.3:a:automatedqa:testcomplete:7.52.678.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.9:beta4`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.9.1`,
        fs:  `cpe:2.3:a:ubi:rayman_legends:1.0.95278:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.10`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.10:beta1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.619:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.10:beta2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:108.2146.2565.38893:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.10:beta3`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.10.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.11`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.11:beta1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.11:beta2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.297:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.11:beta3`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.11:beta4`,
        fs:  `cpe:2.3:h:hp:j9642a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.11:beta5`,
        fs:  `cpe:2.3:a:techsmith:snagit:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.11:beta6`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.12`,
        fs:  `cpe:2.3:a:weddingselections:my_wedding_planner:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.12:beta1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.12:beta2`,
        fs:  `cpe:2.3:a:tibco:activematrix_management_agent:1.0.0:*:*:*:*:windows_communication_foundation:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.12:beta3`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.12:beta4`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.12:beta5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.12:beta6`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.12.1`,
        fs:  `cpe:2.3:a:fujitsu:scansnap_organizer:3.2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13:beta1`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13:beta2`,
        fs:  `cpe:2.3:a:web2py:web2py:1.87.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13:beta3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13:beta4`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13:beta5`,
        fs:  `cpe:2.3:a:spip:spip:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13:beta6`,
        fs:  `cpe:2.3:a:clamav:clamav:0.80_rc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.13.2`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.14`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.14:beta1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.14:beta2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.14:beta3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.14:beta4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:tr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.14:beta5`,
        fs:  `cpe:2.3:a:ibm:data_studio:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15`,
        fs:  `cpe:2.3:o:yamaha:rtx1200:10.01.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15:beta1`,
        fs:  `cpe:2.3:a:gnome:evolution:2.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15:beta2`,
        fs:  `cpe:2.3:a:ibm:gina:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15:beta3`,
        fs:  `cpe:2.3:a:invensys:wonderware_inbatch:8.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15:beta4`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15:beta5`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.06.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15:beta6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15.1`,
        fs:  `cpe:2.3:a:david_king:vino:3.1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.15.2`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.2\(3.100\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.16`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.16:beta1`,
        fs:  `cpe:2.3:a:oracle:jdk:8.0:update_74:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.16:beta2`,
        fs:  `cpe:2.3:a:ark-web:a-form_pc_mobile:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.16:beta3`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.16:beta4`,
        fs:  `cpe:2.3:a:adobe:asset_services_cs4:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.16:beta5`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:5.0.1-h1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.16.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.669.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.16.2`,
        fs:  `cpe:2.3:a:metaclassy:byword:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.17`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.17:beta1`,
        fs:  `cpe:2.3:a:oracle:webcenter_content:12.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.17:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20\)st7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.17:beta3`,
        fs:  `cpe:2.3:o:qnap:qts:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.17:beta4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.17.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.18:beta1`,
        fs:  `cpe:2.3:a:hp:scannercopy:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.18:beta2`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.18:beta3`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.74:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.18:beta4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.19`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.19:beta1`,
        fs:  `cpe:2.3:a:gnu:zlib:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.19:beta2`,
        fs:  `cpe:2.3:a:plone:plone:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.20`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.20:beta1`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.20:beta2`,
        fs:  `cpe:2.3:a:exim:exim:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.20:beta3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.21:beta1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.21:beta2`,
        fs:  `cpe:2.3:o:hp:tru64:5.1a_pk3_bl3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.22:beta1`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.22:beta2`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.22.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.23`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.23:beta1`,
        fs:  `cpe:2.3:a:thegr:dl:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.23:beta2`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.24`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.24:beta1`,
        fs:  `cpe:2.3:h:hp:d7p70a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.25:-`,
        fs:  `cpe:2.3:a:oracle:application_server:9.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.25:beta1`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)n2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.25:beta2`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.25:beta3`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.26:-`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.26:rc1`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.31`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:4.5:sp10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.33.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:seamonkey:2.35`,
        fs:  `cpe:2.3:a:rpm:rpm:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:-`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.1`,
        fs:  `cpe:2.3:a:immunize:immunize_canada:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.2`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.3`,
        fs:  `cpe:2.3:a:oracle:mysql_workbench_ce:5.2.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.4`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.5`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.6`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.7`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.7.1`,
        fs:  `cpe:2.3:a:boopsie:aapld:4.5.110:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.7.2`,
        fs:  `cpe:2.3:a:rob_westgeest:md2pdf:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)ire3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.8`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:0.9`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.1`,
        fs:  `cpe:2.3:a:nicholasthompson:global_redirect:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.3`,
        fs:  `cpe:2.3:a:entrouvert:lasso:1.9.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.4`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.5`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_agent:6.0.0.278:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.5:beta`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.6`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.554:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.0.8`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5:beta2`,
        fs:  `cpe:2.3:a:adobe:flash_player:12.0.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.2`,
        fs:  `cpe:2.3:a:ibm:informix_open_admin_tool:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.4`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.5`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.1.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.6`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.7`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.267:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.9`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.10`,
        fs:  `cpe:2.3:a:google:v8:3.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.11`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.12`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.0.14`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_75:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.1`,
        fs:  `cpe:2.3:a:paul_lesniewsk:autocomplete:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.5.2`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.7.1`,
        fs:  `cpe:2.3:a:citrix:nfuse:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:1.7.3`,
        fs:  `cpe:2.3:a:canon:canoscan_toolbox:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:9.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp3:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.2`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.3`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta48:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.6`,
        fs:  `cpe:2.3:a:bashgaming:bingo_bash_free_bingo_casino:1.31.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.195:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.8`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.17:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.11`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.12`,
        fs:  `cpe:2.3:a:vasco:identikey_authentication_server:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.13`,
        fs:  `cpe:2.3:a:irokez:irokez_cms:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.14`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:7.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.15`,
        fs:  `cpe:2.3:a:web-dorado:web-dorado_spider_video_player:1.4.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.16`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.17`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.18`,
        fs:  `cpe:2.3:a:adam_zaninovich:sounder:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.19`,
        fs:  `cpe:2.3:a:atlassian:jira:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.20`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.21`,
        fs:  `cpe:2.3:a:ca:etrust_iam_suite:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.22`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.0.23`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:2.0.14`,
        fs:  `cpe:2.3:o:freebsd:freebsd:9.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0`,
        fs:  `cpe:2.3:o:d-link:dcs-933l_firmware:1.13.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.1`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.0:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.2`,
        fs:  `cpe:2.3:a:sap:print_and_output_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.3`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.2f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.4`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.6:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.5`,
        fs:  `cpe:2.3:a:nagios:nagios:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.6`,
        fs:  `cpe:2.3:a:apple:apple_tv:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.8`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.9`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.10`,
        fs:  `cpe:2.3:a:gnu:aspell:0.50.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.0.11`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:rc.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.1`,
        fs:  `cpe:2.3:a:onesolutionapps:ajd_bail_bonds:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.2`,
        fs:  `cpe:2.3:a:apple:webkit:418.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.3`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3_3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.5`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.6`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.7`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_standalone_agent:4.0.1.161434:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.8`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.9`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.10`,
        fs:  `cpe:2.3:a:microsoft:outlook:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.11`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.12`,
        fs:  `cpe:2.3:a:pygments:pygments:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.13`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.14`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.15`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.16`,
        fs:  `cpe:2.3:a:gnu:gnats:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:3.1.17`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2010:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:5.0`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:6.0`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.0:e0101h03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:6.0.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:6.0.2`,
        fs:  `cpe:2.3:a:hp:ignite-ux:a.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:7.0`,
        fs:  `cpe:2.3:a:omeka:omeka:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:7.0.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:8.0`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:9.0`,
        fs:  `cpe:2.3:a:phplist:phplist:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:9.0.1`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:10.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:10.0.1`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:10.0.2`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:10.0.3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.02:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:10.0.4`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:a7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:11.0`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:11.0.1`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:12.0`,
        fs:  `cpe:2.3:h:canon:powershot_s200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:12.0.1`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:13.0`,
        fs:  `cpe:2.3:h:hp:8\/20q_fibre_channel_switch_8_port:aq233b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:13.0.1`,
        fs:  `cpe:2.3:a:netscape:navigator:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:14.0`,
        fs:  `cpe:2.3:a:skype:skype:1.3.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:15.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:15.0.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:16.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.0:c1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:16.0.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:16.0.2`,
        fs:  `cpe:2.3:a:jease:jease:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.1`,
        fs:  `cpe:2.3:a:schneems:wicked:0.1.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.2`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf428a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.5`,
        fs:  `cpe:2.3:a:video-lead-form:uk-cookie:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.6`,
        fs:  `cpe:2.3:a:wolfcms:wolf_cms:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.7`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:17.0.9`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.0`,
        fs:  `cpe:2.3:a:citrix:xenapp:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.0.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.1`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(1t\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.1.1`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.2`,
        fs:  `cpe:2.3:a:warrior_beach_retreat_project:warrior_beach_retreat:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.4`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7902g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.5`,
        fs:  `cpe:2.3:a:isc:bind:8.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.6`,
        fs:  `cpe:2.3:a:avg:anti-virus:7.5:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:24.8`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.1.0`,
        fs:  `cpe:2.3:a:debian:tetex-bin:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.1.2`,
        fs:  `cpe:2.3:o:tp-link:tl-wdr4300_\(1.0\)_firmware:141113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.4:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.5`,
        fs:  `cpe:2.3:a:apache:nutch:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.6`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing:10.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:31.8`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:32.0`,
        fs:  `cpe:2.3:h:tek:phaser_network_printer_840:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:38.0`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:38.0.1`,
        fs:  `cpe:2.3:a:echoping_project:echoping:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:38.1`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:38.5.1`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:6.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird:38.6.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:10.0.tc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0`,
        fs:  `cpe:2.3:h:huawei:s5300:v100r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.2`,
        fs:  `cpe:2.3:h:hp:officejet_k:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.3`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.5.146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.4`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.5`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.6`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.7`,
        fs:  `cpe:2.3:a:symantec:web_security:3.01.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.8`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.9`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.10`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent_option:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.11`,
        fs:  `cpe:2.3:a:anixis:password_policy_enforcer:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:10.0.12`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4\(1.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0`,
        fs:  `cpe:2.3:a:citrix:access_management_console_framework:4.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.2`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:11.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.10:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.6`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.7`,
        fs:  `cpe:2.3:a:biscom:faxcom_suite_for_windows_admin:9.6.990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.8`,
        fs:  `cpe:2.3:a:invensys:foxboro_control_software:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.9`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:9.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:thunderbird_esr:17.0.10`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert1:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mozilla:zamboni:-`,
        fs:  `cpe:2.3:a:google:chrome:4.0.301.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mplayer2:mplayer2:-`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mr384_project:mzone_login:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:evolution:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mrcgiguy:guestbook:1.0`,
        fs:  `cpe:2.3:a:collectiveaccess:pawtucket:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mredsoftware:powershell_script-o-matic:1.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mrv:lx-4000t:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mscsoftware:msc_nastran:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mscsoftware:msc_nastran:2005`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.23:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:msevensoftware:msecure:2.15`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:msteam:sharepoint_birthday_reminder:1.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/e:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mtouch_quiz_project:mtouch_quiz:3.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mumble:mumble:1.2.1`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mumble:mumble:1.2.3:rc1`,
        fs:  `cpe:2.3:a:xavier_beaudouin:mod_vhs:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mumble:mumble:1.2.3:rc2`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mumble:mumble:1.2.3:rc3`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mumble:mumble:1.2.4`,
        fs:  `cpe:2.3:a:python:python:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mumble:mumble:1.2.4:beta1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mumble:mumble:1.2.4:rc1`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2610:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mumble:mumble:1.2.5`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.0`,
        fs:  `cpe:2.3:a:open-realty:open-realty:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.2`,
        fs:  `cpe:2.3:a:tripwire:securecheq:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.3`,
        fs:  `cpe:2.3:a:ibm:secureway_directory:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd393a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.5`,
        fs:  `cpe:2.3:a:keepass:keepass:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.6`,
        fs:  `cpe:2.3:a:telos:amhs:12.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.7`,
        fs:  `cpe:2.3:a:hp:customer_participation_program:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.8`,
        fs:  `cpe:2.3:a:google:chrome:14.0.837.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.9`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.10`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.11`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.11.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.12`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.13`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:5.2.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.14`,
        fs:  `cpe:2.3:a:ncircle:suite360_intelligence_hub:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.15`,
        fs:  `cpe:2.3:a:atutor:atutor:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.16`,
        fs:  `cpe:2.3:o:ipcop:ipcop:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.17`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.1.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munin-monitoring:munin:2.0.18`,
        fs:  `cpe:2.3:o:sophos:web_appliance_firmware:3.7.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:munsoft:easy_office_recovery:1.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:musiclab-llc:bearshare:5.2.1.9`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:musulmanin:musulmanin.com:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:sap:netweaver_abap:7.03:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:mutiny:5.0-1.00`,
        fs:  `cpe:2.3:a:jpmorganchase:chase_mobile:-:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:mutiny:5.0-1.10`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:mutiny:5.0-1.11`,
        fs:  `cpe:2.3:a:novell:netmail_xe:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:mutiny:mutiny_appliance:-`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:mutiny_virtual_appliance:-`,
        fs:  `cpe:2.3:a:symantec:network_access_control:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:standard:4.4-1.12`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:standard:4.5-1.03`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:standard:4.5-1.05`,
        fs:  `cpe:2.3:a:telligent:evolution:7.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:standard:4.5-1.07`,
        fs:  `cpe:2.3:a:apache:myfaces_tomahawk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:standard:4.5-1.10`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutiny:standard:4.5-1.12`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5`,
        fs:  `cpe:2.3:a:digium:asterisk:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.1`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.0.1499:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.3`,
        fs:  `cpe:2.3:a:kde:koffice:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.4`,
        fs:  `cpe:2.3:h:hp:j9452a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.5`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.6`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.7`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.8`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.3:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.9`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.10`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.11`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp1:advanced_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.12`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0-rc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.13`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_internet_server:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.14`,
        fs:  `cpe:2.3:a:php:php:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.15`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.16`,
        fs:  `cpe:2.3:a:libssh:libssh:0.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.17`,
        fs:  `cpe:2.3:a:opera:mini:2.0.4719:1690:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.18`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.19`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.20`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.21`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mutt:mutt:1.5.22`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:muvee:autoproducer:4.10.50`,
        fs:  `cpe:2.3:a:yodobashi:yodobashi:1.4.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mvd:surething_cd_labeler:1.0`,
        fs:  `cpe:2.3:o:maygion:ip_camera_firmware:05.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mvd:surething_cd_labeler:2.0`,
        fs:  `cpe:2.3:o:huawei:s7712_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mvd:surething_cd_labeler:3.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mvd:surething_cd_labeler:3.02`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mvd:surething_cd_labeler:4.3.196`,
        fs:  `cpe:2.3:a:ixiacom:aptixia_ixnetwork:5.30.90.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mvd:surething_cd_labeler:5.2.693`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mw6tech:aztec_activex_control:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mw6tech:datamatrix_activex_control:-`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mw6tech:maxicode_activex_control:-`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp4:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myanmar_movies_hd_project:myanmar_movies_hd:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myanmars:myanmar_housing_%3a_mmhome:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myapp:ibis_pau_centre:1::~~~android~~`,
        fs:  `cpe:2.3:a:emc:navisphere_server_utility:28.20.1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myapp:prix_import:1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:2.0.169.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myapp:treves_dance_center:1::~~~android~~`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:ajax_forum_stat:2.0:-:~~~mybb~~`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.00`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.0:beta4`,
        fs:  `cpe:2.3:a:openswan:openswan:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.0:pr1`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.1.4369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.0:pr2`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.0:rc1`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.0:rc2`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.10b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.0:rc3`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.05\/21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.0:rc4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.478:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.0.2`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.01`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:40.0.2214.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.1`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.2`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:9.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.3`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.4`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.5`,
        fs:  `cpe:2.3:a:topgames:top_games_script:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.6`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:cf09:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.7`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.1.8`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(.2.10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.02`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2`,
        fs:  `cpe:2.3:a:pcre:perl-compatible_regular_expression_library:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.1`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.3`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.5`,
        fs:  `cpe:2.3:a:ibm:network_appliance_data_ontap:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.6`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.7`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.9`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_platform:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.10`,
        fs:  `cpe:2.3:a:canon-its:accessguardian:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.11`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.12`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.13`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3b.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.2.14`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.03`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.3:pre-1.0`,
        fs:  `cpe:2.3:o:siemens:spc5000_firmware:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.04`,
        fs:  `cpe:2.3:a:qemu:qemu:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.0`,
        fs:  `cpe:2.3:a:apache:pdfbox:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.1`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.23:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.2`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.3`,
        fs:  `cpe:2.3:o:sun:sunos:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.4`,
        fs:  `cpe:2.3:a:ca:internet_security_suite:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.5`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.5.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.6`,
        fs:  `cpe:2.3:a:bizagi:business_process_management_suite:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.7`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.8`,
        fs:  `cpe:2.3:a:ultravnc:vnc_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.9`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.10`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.11`,
        fs:  `cpe:2.3:a:jam-software:treesize:5.4.4:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.12`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.30:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.13`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.14`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.15`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.4.16`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.5.1`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.5.2`,
        fs:  `cpe:2.3:a:emc:networker:7.4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.29.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.2`,
        fs:  `cpe:2.3:a:winzip:winzip:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.3`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.4`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.5`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.6`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.8`,
        fs:  `cpe:2.3:a:jasper_project:jasper:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.9`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(4b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.10`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.11`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:sp1_alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.12`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.13:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.13`,
        fs:  `cpe:2.3:a:moip_project:moip:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.6.14`,
        fs:  `cpe:2.3:a:python:python:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.8.3`,
        fs:  `cpe:2.3:a:david_king:vino:2.32.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybb:mybb:1.8.7`,
        fs:  `cpe:2.3:a:xcloner:xcloner:2.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mybboard:mybb:1.4.3`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybboard:mybb:1.4.10`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mybroadband:mybroadband_tapatalk:3.9.22::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:cognos_business_intelligence:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.8.7`,
        fs:  `cpe:2.3:a:adobe:extension_manager_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.8.8`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.8.9`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.9.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.9.3`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.9.4`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.20.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.9.5`,
        fs:  `cpe:2.3:a:viewvc:viewvc:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.10`,
        fs:  `cpe:2.3:h:hp:laserjet_m2727_multifunction_printer:cb533a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.11`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myclientbase:myclientbase:0.12`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myfone:myfone_shopping:2.1.01.00.040::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mygamedaytix:game_day_tix:2.4::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.285:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mygoodhotels:booking_discount:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myhabit:myhabit:%407f080041::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myheritage:sequeryobject_activex_control:1.0.2.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mylittleforum:my_little_forum:1.7`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mylittleforum:my_little_forum:2.3.3`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd917a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mymembersfirst:tn_members_1st_fcu-rdc:1.0.28::~~~android~~`,
        fs:  `cpe:2.3:h:huawei:s7800:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mymetro_project:mymetro:2.4.7::~~~android~~`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mymobileday1:my_mobile_day:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myrephp:myre_business_directory:-`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper_live_streaming_integration:4.29.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:myrephp:myre_real_estate_software:2012:q2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p180:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myrephp:myre_realty_manager:-`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myrephp:myre_vacation_rental:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:community_server:5.0.41`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:community_server:5.0.44`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:community_server:5.0.45`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:eventum:1.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:eventum:1.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:eventum:1.2.2`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:eventum:1.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:eventum:1.3.1`,
        fs:  `cpe:2.3:a:apache:ignite:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:eventum:1.4`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:eventum:1.5.4`,
        fs:  `cpe:2.3:a:ilias:ilias:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:eventum:1.5.5`,
        fs:  `cpe:2.3:o:novell:netware:6.5:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00`,
        fs:  `cpe:2.3:a:devsaran:creative:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.08`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.11`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.12`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.14`,
        fs:  `cpe:2.3:a:autodesk:building_systems:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.15`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.16`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.18`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.19`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.23`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.5.00.25`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:006:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:maxdb:7.6.00.22`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:-`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.20`,
        fs:  `cpe:2.3:a:videolan:vlc:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.20.32a`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.1:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.21`,
        fs:  `cpe:2.3:a:mutiny:mutiny:5.0-1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.22`,
        fs:  `cpe:2.3:a:adobe:flash_player:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.22.26`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.6.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.22.27`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.22.28`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.22.29`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p275:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.22.30`,
        fs:  `cpe:2.3:a:awesomewidgets:rasta_weed_widgets_hd:4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.22.32`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.0:alpha`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.1`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.2`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.5`,
        fs:  `cpe:2.3:a:busybox:busybox:1.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.6`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.7`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-232_firmware:t377sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.8`,
        fs:  `cpe:2.3:h:intel:server_board_shg2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.9`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.11`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.12`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5e.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.13`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.14`,
        fs:  `cpe:2.3:a:breezy:breezy:1.2.3:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.15`,
        fs:  `cpe:2.3:a:avigilon:avigilon_control_center:4.12.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.16`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.17`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.18`,
        fs:  `cpe:2.3:h:d-link:dsr-500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.19`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.20:beta`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.21`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.22`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.23`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.24`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.25`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp6:terminal_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.26`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.27`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.28`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.28:gamma`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.29`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.30`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.4.100.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.31`,
        fs:  `cpe:2.3:a:google:chrome:9.0.583.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.32`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_ops_center:12.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.33`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:cch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.34`,
        fs:  `cpe:2.3:a:hp:web_registration:130.0.132.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.35`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.36`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.37`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.38`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.39`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.40`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.41`,
        fs:  `cpe:2.3:a:samba:samba:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.42`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.43`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.457:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.44`,
        fs:  `cpe:2.3:a:gnu:gdb:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.45`,
        fs:  `cpe:2.3:a:skyarc:autotagging:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.46`,
        fs:  `cpe:2.3:a:tryton:trytond:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.47`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_launcher:1.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.48`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.49`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.50`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1662.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.51`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.52`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.53`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.53a`,
        fs:  `cpe:2.3:a:vmware:tools:8.0.2.14744:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.54`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.54a`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.55`,
        fs:  `cpe:2.3:a:x:libxres:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.56`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.57`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp8:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.58`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:3.23.59`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.9p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.0`,
        fs:  `cpe:2.3:o:juniper:screenos:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.1`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.2`,
        fs:  `cpe:2.3:a:vim:vim:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.3`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.4`,
        fs:  `cpe:2.3:a:belarc:advisor:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.5`,
        fs:  `cpe:2.3:a:engardelinux:guardian_digital_webtool:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.5a`,
        fs:  `cpe:2.3:h:cisco:catalyst_2926:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.6`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.7`,
        fs:  `cpe:2.3:a:ubi:uplay_pc:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.7:gamma`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.3.5:-:ipad:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.8`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.8:gamma`,
        fs:  `cpe:2.3:a:altiris:it_analytics_client_management_pack:6.1.1085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.9`,
        fs:  `cpe:2.3:h:asus:rt-ac56s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.9:gamma`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.10`,
        fs:  `cpe:2.3:o:cray:unicos:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.11`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.11:gamma`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p221:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.12`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.13`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.14`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.4mda:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.16`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.17`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.18`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.19`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.20`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.3:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.21`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.16s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.23`,
        fs:  `cpe:2.3:a:samba:samba:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.24`,
        fs:  `cpe:2.3:o:hp:storeonce_backup_system_software:3.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.25`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:0.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.26`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.0.27`,
        fs:  `cpe:2.3:h:ibm:ts3100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1`,
        fs:  `cpe:2.3:a:horde:groupware:5.1.2:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.0:alpha`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.1.1:-:-:-:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.0.0`,
        fs:  `cpe:2.3:a:elipse:scada:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.1`,
        fs:  `cpe:2.3:h:hp:laserjet_m525f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.2:alpha`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.3:beta`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p307:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.4`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.5`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:95:osr2.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.6`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.7`,
        fs:  `cpe:2.3:a:feed_element_mapper_project:feed_element_mapper:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.8`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:9.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.8a`,
        fs:  `cpe:2.3:a:keepass:keepass:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.9`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_optimization_engine:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.10`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.10a`,
        fs:  `cpe:2.3:a:apple:apple_mobile_device_support:3.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.11`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.14.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.12`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.12a`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.13`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:10.0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.13a`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.14`,
        fs:  `cpe:2.3:a:netscape:navigator:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.14a`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.15`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.8.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.15a`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.16`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-rc2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.17`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.18`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:6.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.19`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.20`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.21`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:4.1.22`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0`,
        fs:  `cpe:2.3:a:smarty:smarty:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.0:alpha`,
        fs:  `cpe:2.3:a:anchorcms:anchor_cms:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.0.0`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.1`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.1a`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.3`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.3:beta`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(8.9\)sa6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.3a`,
        fs:  `cpe:2.3:a:symantec:anti-virus_engine:20151.1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(2\)xg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.4a`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_discovery_for_distributed:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.5`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.6`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.7`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.9.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.8`,
        fs:  `cpe:2.3:a:vips:vips:7.22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.9`,
        fs:  `cpe:2.3:a:fujitsu:scansnap_organizer:4.1.11.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.10`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:2008.1:x86_64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.10a`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.11`,
        fs:  `cpe:2.3:a:inclind:custom_pub:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.13`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.14`,
        fs:  `cpe:2.3:a:serv-u:serv-u:11.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.15`,
        fs:  `cpe:2.3:h:cisco:nexus_3132q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.15a`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(11\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.16`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.16a`,
        fs:  `cpe:2.3:a:xymon:xymon:4.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.17`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.17a`,
        fs:  `cpe:2.3:a:rsa:access_manager_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.18`,
        fs:  `cpe:2.3:a:apple:personal_web_sharing:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.19`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.11:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.20`,
        fs:  `cpe:2.3:a:isc:bind:9.1.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.20a`,
        fs:  `cpe:2.3:a:intergraph:job_order_status_tool:1.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.21`,
        fs:  `cpe:2.3:a:hp:employee_expense_management_system:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.22`,
        fs:  `cpe:2.3:a:gnu:glibc:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.24`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.27`,
        fs:  `cpe:2.3:h:snapgear:585:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.28`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)t9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.30`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.30:sp1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.32`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.33`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.34`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.36`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.36:sp1`,
        fs:  `cpe:2.3:a:walk_score_project:walk_score:0.5.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.37`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3c\)2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.38`,
        fs:  `cpe:2.3:a:sun:sdk:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.40`,
        fs:  `cpe:2.3:a:gnu:gdb:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.41`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.42`,
        fs:  `cpe:2.3:a:apple:safari:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.44`,
        fs:  `cpe:2.3:a:microsoft:message_compiler:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.44:sp1`,
        fs:  `cpe:2.3:a:apache:openoffice.org:3.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.45`,
        fs:  `cpe:2.3:a:guitar-pro:guitar_pro:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.46`,
        fs:  `cpe:2.3:a:netscape:netscape_messaging_server_multiplexor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.48`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.50`,
        fs:  `cpe:2.3:h:hp:sn6000_stackable_8gb_12-port_single_power_fibre_channel_switch:bk780b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.51:a`,
        fs:  `cpe:2.3:a:isc:bind:9.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.51:b`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:6.2:sp8:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.52`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.54`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.56`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.56:sp1`,
        fs:  `cpe:2.3:a:iss:internet_scanner:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.58`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.60`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.62`,
        fs:  `cpe:2.3:a:apple:mac_os_runtime_for_java:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.64`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.66`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.66:a`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0074:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.66:sp1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.67`,
        fs:  `cpe:2.3:a:ibm:spectrum_lsf:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.68`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.70`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.72`,
        fs:  `cpe:2.3:a:rowlandsolutions:lent_experience:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.72:sp1`,
        fs:  `cpe:2.3:a:janetter:janetter:3.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.74`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.74:sp1`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.75`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.45.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.76`,
        fs:  `cpe:2.3:a:gluster:glusterfs:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.77`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.78`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.79`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.80`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.81`,
        fs:  `cpe:2.3:a:sun:java_system_portal_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.82`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.82:sp1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.83`,
        fs:  `cpe:2.3:a:php:php:5.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.84`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(6\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.84:sp1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.85`,
        fs:  `cpe:2.3:o:sgi:irix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.86`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.87`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.87:sp1`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.510:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.88`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.89`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.7.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.90`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.91`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.72:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.92`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.93`,
        fs:  `cpe:2.3:a:mozilla:durian_web_application_server:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.94`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.95`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.0.96`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:507:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1`,
        fs:  `cpe:2.3:a:horde:imp:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.4.0.46.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12.05\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.4`,
        fs:  `cpe:2.3:a:process-one:exmpp:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.5a`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yg3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.6`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.7`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.8`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.9`,
        fs:  `cpe:2.3:a:hp:procurve_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.10`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.11`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.12`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.13`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.14`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.15`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.16`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.542:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.17`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.18`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xd4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.19`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:613:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.20`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a3\(2.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.21`,
        fs:  `cpe:2.3:a:french_national_commission_on_informatics_and_liberty:cookieviz:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.22`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.23`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.23:a`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.23_bk`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.23a`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.25`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_entry_client:2.02:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.26`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.0.e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.27`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.28`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.29`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.30`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.31`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.31:sp1`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.32`,
        fs:  `cpe:2.3:a:sun:java_system_access_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.32-bzr`,
        fs:  `cpe:2.3:a:vmware:workstation:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.33`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.34`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.34:sp1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.35`,
        fs:  `cpe:2.3:a:ibm:sterling_secure_proxy:3.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.36`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.37`,
        fs:  `cpe:2.3:a:franklychat:frankly_chat:3.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.37:sp1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sg_3.3.2sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.38`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.39`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.5.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.40`,
        fs:  `cpe:2.3:a:npmjs:node_packaged_modules:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.40:sp1`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.41`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.42`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.43`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.43:sp1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p228:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.44`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2\(0.104\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.45`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.46`,
        fs:  `cpe:2.3:a:microsoft:access:2010:sp2:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.46:sp1`,
        fs:  `cpe:2.3:a:sap:hybris:5.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.47`,
        fs:  `cpe:2.3:a:augeas:augeas:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.48`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.49`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.49:sp1`,
        fs:  `cpe:2.3:a:ibm:disposal_and_governance_management_for_it:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.1.50`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.0`,
        fs:  `cpe:2.3:h:hp:proliant_sl170z_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.1`,
        fs:  `cpe:2.3:a:hp:sitescope:11.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.2`,
        fs:  `cpe:2.3:a:scilab:scilab:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.4`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.5`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.6`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.7`,
        fs:  `cpe:2.3:a:winzip:winzip:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.8`,
        fs:  `cpe:2.3:a:f5:big-iq_device:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:5.5.9`,
        fs:  `cpe:2.3:a:oracle:financial_consolidation_hub:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:6.0.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:6.0.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:6.0.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70f:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:6.0.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql:6.0.4`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_community_server:-`,
        fs:  `cpe:2.3:a:canon:mp_navigator_ex:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_connector%2fodbc:3.51.12`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_connector%2fodbc:3.51.15`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_connector%2fodbc:5.1.6`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_eventum:-`,
        fs:  `cpe:2.3:a:your-text-manager_project:your-text-manager:0.3.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_tools:5.0.1`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_tools:5.0.11`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:9.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_tools:5.0.17`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:mysql_workbench:5.0.30::~~oss~~~`,
        fs:  `cpe:2.3:o:creston:dm-txrx-100-str_firmware:1.2866.00026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql:winmysqladmin:-`,
        fs:  `cpe:2.3:a:intel:2200bg_proset_wireless:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysql-lite-administrator_project:mysql-lite-administrator:-:beta1`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.5:-:server_for_linux\/freebsd:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:-`,
        fs:  `cpe:2.3:a:findingscience:mod_auth_openid:0.2:*:*:*:*:apache:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.21:b6`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.21_b6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.22`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.23:pre`,
        fs:  `cpe:2.3:a:apache:struts:2.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.23_pre-release`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24:rc1.5`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24:rc1.6`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24:rc1.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24:rc1.8`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24:rc1.9`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg247a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24.3`,
        fs:  `cpe:2.3:a:debian:bsmtpd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mysqldumper:mysqldumper:1.24.4`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mystorexpress:tienda_virtual:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mystorexpress:tienda_virtual:2.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mythicsoft:agent_ransack:1.7.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mythicsoft:agent_ransack:2010`,
        fs:  `cpe:2.3:a:google:chrome:3.0.190.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mythicsoft_ltd:filelocator_pro:6.0.1225.1::~~~~x64~`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.core:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:mythinkpal:thinkpal:1.6.3::~~~android~~`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.1.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mytoursapp:revel_in_the_rideau_lakes:1.0.6::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.721.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:myupb:ultimate_php_board:2.2.7`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:myvet2pet:ahrah:219426::~~~android~~`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:mywebsiteadvisor:simple_security:1.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:piriform:ccleaner:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:n-i-agroinformatics:soy_cms:1.4.0:c`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:2.0.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:alpha1`,
        fs:  `cpe:2.3:a:debian:adequate:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:alpha2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:sv:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:alpha3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:alpha4`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:alpha5`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:beta1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:beta2`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:beta3`,
        fs:  `cpe:2.3:a:opera:mini:3.1.7203:1690:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:beta4`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:beta5`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:beta6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:beta7`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:rc1`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:rc2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0:rc3`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0.1`,
        fs:  `cpe:2.3:a:boost:boost:1.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0.2`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0.3`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0.4`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0.5`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.0.6`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.1.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.1.1`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.1.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.186:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.2.0`,
        fs:  `cpe:2.3:o:yahama:rta55i:4.06.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.2.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.222:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.2.3`,
        fs:  `cpe:2.3:a:vmware:vcenter_chargeback_manager:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.3.1`,
        fs:  `cpe:2.3:a:teamquest:view:9.2_pf_20060315:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.4.0`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.4.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.8.0.2257:unknown:online_windows_server_2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.4.2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.4.3`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.4.4`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:3.5.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:4.0.0:beta1`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:4.0.0:beta2`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:4.0.0:beta3`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:4.0.0:beta4`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2000_server:6.3.407:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:4.0.2`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:8.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:4.0.3:rc1`,
        fs:  `cpe:2.3:a:gnu:tar:1.14.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:4.2.1`,
        fs:  `cpe:2.3:h:3com:3cnj220:2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios:4.2.3`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012:rc2`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012:rc3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012:rc4`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(1f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:1.0\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.3`,
        fs:  `cpe:2.3:a:bigware:bigware_shop:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.4`,
        fs:  `cpe:2.3:o:redhat:fedora_core:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.5`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.6`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.7`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.8`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_command_center:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r1.9`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.0`,
        fs:  `cpe:2.3:h:xerox:workcentre:5685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.1`,
        fs:  `cpe:2.3:o:samsung:samsung_mobile:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.2`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.3`,
        fs:  `cpe:2.3:a:fusedpress:buddypress-extended-frienship-request:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.4`,
        fs:  `cpe:2.3:a:hp:proliant_remote_monitor_service:5.20.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.4:b`,
        fs:  `cpe:2.3:o:hp:laserjet_pro_m1214nfh_mfp_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.5`,
        fs:  `cpe:2.3:a:sap:mobile_platform:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.6`,
        fs:  `cpe:2.3:a:yahoo:messenger:6.0.0.1750:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:nagios_xi:2012r2.7`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.3.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.3.1`,
        fs:  `cpe:2.3:a:emc:retrospect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4`,
        fs:  `cpe:2.3:a:boa:boa:0.94.14.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.2`,
        fs:  `cpe:2.3:a:ncircle:ip360:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.4`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.5`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.7`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.8`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.9`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.10`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.11`,
        fs:  `cpe:2.3:a:invensys:intouch:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.12`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.13`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_redundant_controller_firmware:21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.14`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.15`,
        fs:  `cpe:2.3:a:isc:bind:9.6.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.4.16`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:1.5`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:2.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.0.44:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:plugins:2.0.1`,
        fs:  `cpe:2.3:a:dell:online_diagnostics:2.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:1.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p334:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:1.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.5.13\(3717\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:1.5`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:1.6`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:1.7`,
        fs:  `cpe:2.3:a:compaq:trucluster:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:1.8`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:1.9`,
        fs:  `cpe:2.3:h:supermicro:x9drg-hf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.0`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.0b1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.0b2`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.7.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.0b3`,
        fs:  `cpe:2.3:a:microsoft:windows_media_services:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.0b4`,
        fs:  `cpe:2.3:a:openx:openx:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.0b5`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.3`,
        fs:  `cpe:2.3:a:microsoft:publisher:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.4`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.5`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.5.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.5.2`,
        fs:  `cpe:2.3:a:powerdns:authoritative:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.6`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g_firmware:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.7`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.7.1`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.8`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.8.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.8b1`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.60:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.9`,
        fs:  `cpe:2.3:a:google:v8:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.10`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.11`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.12`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p108:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plug_in_executor:2.13`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagios:remote_plugin_executor:2.15`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagiosql:nagiosql:3.2`,
        fs:  `cpe:2.3:a:preemptive_solutions:dotfuscator:5.0.2300.0:*:*:*:community_edition:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nagiosql:nagiosql:3.2:sp2`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.0`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4014:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.2`,
        fs:  `cpe:2.3:a:novell:netware_client:4.91:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.3`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.4`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.5`,
        fs:  `cpe:2.3:a:juniper:network_connect:6.4.0.15779:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.6`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.7`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.2.9`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.3.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:213:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.3.1`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.3.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.3.3`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.4.0`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.95:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.4.1`,
        fs:  `cpe:2.3:a:php:php:5.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.4.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.4.3`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naist.jp:chasen:2.4.4`,
        fs:  `cpe:2.3:a:citrix:provisioning_services:5.6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nakodabhairav:rajendra_suriji:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:-`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.11.21`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.12.2`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.14.2`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.15.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.16.14`,
        fs:  `cpe:2.3:a:microsoft:windows_messenger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.17.4`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_105:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.20.5`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.22.5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.24.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nalin_dahyabhai:vte:0.25.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.1.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.1.2`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:5.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.1.3`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.1.4`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.2.0`,
        fs:  `cpe:2.3:a:emc:retrospect:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.2.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.2.2`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.3.0`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.3.1`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.3.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:0.3.3`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.0.0`,
        fs:  `cpe:2.3:a:luracast:restler:1.5.4:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.0.1`,
        fs:  `cpe:2.3:a:macedonia_hacienda_hotel_project:macedonia_hacienda_hotel:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.0.2`,
        fs:  `cpe:2.3:o:d-link:dcs-6212l_firmware:1.00.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.0.3`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.0.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(8b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.0.4a`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.0.4b`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.0`,
        fs:  `cpe:2.3:a:samba:samba:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.0a`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.642.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.1.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.1.2`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.1.3`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.1.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.13:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.1.5`,
        fs:  `cpe:2.3:a:haxx:curl:7.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.2`,
        fs:  `cpe:2.3:a:citrix:presentation_server_for_windows:4.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.2.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.2.2`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.2.3`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.2.4`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.1.2.5`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.0.1`,
        fs:  `cpe:2.3:a:devsaran:responsive_blog:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.0.2`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.1.100:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.4-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.0.5:beta2`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.051017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta10`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta11`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.11.024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta12`,
        fs:  `cpe:2.3:a:ibm:license_metric_tool:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta13`,
        fs:  `cpe:2.3:a:ip_ban_project:ip_ban:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta5`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta6`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta7`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta8`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.2.1.0:beta9`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.20:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0`,
        fs:  `cpe:2.3:a:x:libdmx:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta1`,
        fs:  `cpe:2.3:h:xerox:workcentre_m45:2.28.11.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta10`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta11`,
        fs:  `cpe:2.3:a:cybozu:cybozu_office:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta12`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta13`,
        fs:  `cpe:2.3:a:teradata:workload_analyzer:13.10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta2`,
        fs:  `cpe:2.3:a:microsoft:access:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta3`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.12.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta5`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta6`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta7`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta8`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.0:beta9`,
        fs:  `cpe:2.3:a:joomla:joomla\!:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p431:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.1:beta1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je091a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.0.2`,
        fs:  `cpe:2.3:a:tenable:nessus:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha1`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha10`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha11`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha2`,
        fs:  `cpe:2.3:a:livetecs:timeline:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha3`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha4`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha5`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha6`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha7`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.09.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha8`,
        fs:  `cpe:2.3:a:boost:boost:1.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.3.1.0:alpha9`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:257:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:alpha1`,
        fs:  `cpe:2.3:o:cisco:staros:16.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:alpha2`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.422:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:alpha3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert13:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:alpha4`,
        fs:  `cpe:2.3:a:gitlist:gitlist:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:alpha5`,
        fs:  `cpe:2.3:o:huawei:s7703_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:alpha6`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:alpha7`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1.2-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:beta1`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:5.2:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:beta2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:beta3`,
        fs:  `cpe:2.3:o:freebsd:freebsd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:beta4`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:beta5`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xg1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:beta6`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:beta7`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:1.4.0.0:beta8`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)ewa1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.2`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.4`,
        fs:  `cpe:2.3:a:exim:exim:4.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:6.7:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:pre1`,
        fs:  `cpe:2.3:a:adcisolutions:node_view_permissions:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:pre2`,
        fs:  `cpe:2.3:o:yamaha:rta52i:4.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:pre3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:rc2`,
        fs:  `cpe:2.3:a:marvell:mrvlusgtracking:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:rc3`,
        fs:  `cpe:2.3:h:cisco:3945e_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:rc4`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:rc5`,
        fs:  `cpe:2.3:a:apache:ofbiz:13.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:rc6`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.6:rc7`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.7`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.7:pre1`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.7:pre2`,
        fs:  `cpe:2.3:h:apple:powerpc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.7:pre3`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.8`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.8:pre1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.0:pre.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)t15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.9:rc1`,
        fs:  `cpe:2.3:a:wisdomsoft:screenhunter:5.1:*:*:*:free:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.10`,
        fs:  `cpe:2.3:a:hp:extended_capabilities:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.10:rc1`,
        fs:  `cpe:2.3:a:snitz_communications:avatar_mod:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.10:rc2`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:fp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.11:pre1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.11:pre2`,
        fs:  `cpe:2.3:a:djangoproject:django:1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.11:pre3`,
        fs:  `cpe:2.3:a:openx:openx_source:2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.11:pre4`,
        fs:  `cpe:2.3:a:altiris:realtime_console_infrastructure_documentation:6.3.1006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.12`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:pre3`,
        fs:  `cpe:2.3:h:hp:j9826a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:pre4`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:pre5`,
        fs:  `cpe:2.3:o:cisco:staros:18.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:pre6`,
        fs:  `cpe:2.3:a:haxx:curl:7.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:pre7`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:pre8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:rc1`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:rc2`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:rc3`,
        fs:  `cpe:2.3:a:apache:http_server:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.13:rc4`,
        fs:  `cpe:2.3:a:google:earth_plug-in:5.2.0.5932:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.14`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:pre1`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:pre2`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.50:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:pre3`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.08e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:pre4`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:rc1`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:rc2`,
        fs:  `cpe:2.3:a:typo3:typo3:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:rc3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.03.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:rc4`,
        fs:  `cpe:2.3:o:cisco:broadband_operating_system:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.15:rc5`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2007:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.16`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.340:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.16:rc2`,
        fs:  `cpe:2.3:a:invensys:wonderware_information_server:4.5:-:portal:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.16:rc3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.17`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.18`,
        fs:  `cpe:2.3:a:ibm:aix_enetwork_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.19`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:namazu:namazu:2.0.20`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.5:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:nana_project:african_radios_live:1.0.6::~~~android~~`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.584:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:announcements:6.x-1.0`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:announcements:6.x-1.0:beta`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:announcements:6.x-1.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:announcements:6.x-1.2`,
        fs:  `cpe:2.3:o:huawei:quidway_s9300_firmware:v200r001c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:announcements:6.x-1.3`,
        fs:  `cpe:2.3:a:lxml:lxml:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:announcements:6.x-1.4`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:announcements:6.x-1.5`,
        fs:  `cpe:2.3:a:cognos:planning_client:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:announcements:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:blackberry:blackberry_enterprise_service:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.0`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.0:beta`,
        fs:  `cpe:2.3:a:nestor_mata_cuthbert:taxonomy_navigator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.0.1984:unknown:online_windows_2000:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.1:rc1`,
        fs:  `cpe:2.3:a:adobe:connect:9.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.1:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.1:rc3`,
        fs:  `cpe:2.3:a:hp:psswcore:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.2`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.3`,
        fs:  `cpe:2.3:a:libav:libav:0.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.4`,
        fs:  `cpe:2.3:a:ibm:leads:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.5`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:realname:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:sitedoc:6.x-1.0`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_l55_controller_firmware:16.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:sitedoc:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:sitedoc:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:sitedoc:6.x-1.0:rc4`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:sitedoc:6.x-1.1`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:sitedoc:6.x-1.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:sitedoc:6.x-1.3`,
        fs:  `cpe:2.3:a:tribiq:tribiq_cms:5.0.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:sitedoc:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)cx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:taxonomy_list:6.x-1.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:taxonomy_list:6.x-1.0-beta1`,
        fs:  `cpe:2.3:a:gnome:glib:2.31.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:taxonomy_list:6.x-1.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:taxonomy_list:6.x-1.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:taxonomy_list:6.x-1.2:dev`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:taxonomy_list:6.x-1.3`,
        fs:  `cpe:2.3:a:sun:one_web_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nancy_wichmann:taxonomy_list:6.x-1.x-dev`,
        fs:  `cpe:2.3:a:wp_consultant_project:wp_consultant:1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:naranjascontocados:naranjas_con_tocados:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:narr8:knights_of_the_void:2.1.7::~~~android~~`,
        fs:  `cpe:2.3:a:ca:message_queuing:1.07_build_220_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:narr8:secret_city_-_motion_comic:2.1.7::~~~android~~`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:narr8:spin_-_motion_comic:2.1.7::~~~android~~`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.5.2:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:nas4free:nas4free:9.1.0.1.798`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.05\/29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nas4free:nas4free:9.1.0.1.804`,
        fs:  `cpe:2.3:a:microsoft:access:95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nas4free:nas4free:9.1.0.1.847`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nasa_universe_wallpapers_xeus_project:nasa_universe_wallpapers_xeus:1::~~~android~~`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashaplaneta:nashaplaneta.su:1.02::~~~android~~`,
        fs:  `cpe:2.3:a:boost:boost:1.65.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:6.0`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.1.1:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.00`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.01`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.02`,
        fs:  `cpe:2.3:a:autodesk:sketchbook_for_enterprise_2014:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.03`,
        fs:  `cpe:2.3:o:cisco:staros:15.0\(912\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.04`,
        fs:  `cpe:2.3:o:conectiva:linux:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.05`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:12.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.06`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.07`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0804hd-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.08`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.09`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.10`,
        fs:  `cpe:2.3:a:3ivx:mpeg-4:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.11`,
        fs:  `cpe:2.3:a:drupal:drupal:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nashtech:easy_php_calendar:7.0.12`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nasioc:nasioc:3.8.0::~~~android~~`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nasir_khan:asaancart:0.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.1`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.2`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.3`,
        fs:  `cpe:2.3:a:perl:perl:5.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.4`,
        fs:  `cpe:2.3:a:combodo:itop:2.0.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.5`,
        fs:  `cpe:2.3:a:packetfence:packetfence:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.6`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.528:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:7.x-1.2:beta1`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:7.x-1.3`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:7.x-1.4`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:8.04:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:7.x-1.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:108.2146.2565.38893:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:7.x-1.6`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:7.x-1.7`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1015:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:7.x-1.8`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:filefield_sources:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:network_appliance_data_ontap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.0`,
        fs:  `cpe:2.3:h:netscout:ngenius_flow_recorder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.0:beta1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.0\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.0:beta2`,
        fs:  `cpe:2.3:a:taskware:wintask:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.0:beta3`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:3.6ebz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.0:beta4`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.18:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.0:beta5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.0:beta6`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:8.5.6-073:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:6.0\(3\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.2`,
        fs:  `cpe:2.3:a:codeasily:grand_flagallery:1.56:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.3`,
        fs:  `cpe:2.3:a:apple:apple_application_support:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.4`,
        fs:  `cpe:2.3:h:adtran:netvanta_7060:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.5`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.7`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.8`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0565:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.9`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.10`,
        fs:  `cpe:2.3:o:cisco:staros:15.0\(938\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.11`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.12`,
        fs:  `cpe:2.3:a:perl:perl:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.13`,
        fs:  `cpe:2.3:a:docker:docker:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.14`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.15`,
        fs:  `cpe:2.3:a:ibm:lotus_connections:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.16`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.17`,
        fs:  `cpe:2.3:a:compaq:insight_manager_xe:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.18`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.6.5.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:6.x-3.x:dev`,
        fs:  `cpe:2.3:o:google:android:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.0:beta3`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.0:beta4`,
        fs:  `cpe:2.3:h:yokogawa:centum_cs_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.0:beta5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.0:beta6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.0:beta7`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.0:beta8`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.3:beta1`,
        fs:  `cpe:2.3:a:x.org:libx11:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.4:beta1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.6`,
        fs:  `cpe:2.3:a:dell:online_diagnostics:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.7`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.8`,
        fs:  `cpe:2.3:a:quest:intrust_repository_viewer:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.9`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6ebz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.10`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.1:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.11`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.12`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.13`,
        fs:  `cpe:2.3:a:gnome:evolution:2.24.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.15`,
        fs:  `cpe:2.3:a:github:gaug.es:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.16`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nathan_haug:webform:7.x-3.x:dev`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.1:*:*:*:base:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naver:line_play:2.3.1.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naver:loctouch:3.4.6:-:~~~android~~`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.4.131.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naver:nhn_japan_naver_line:2.5:-:~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.14s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naver:nhn_japan_naver_line:2.5.5:-:~~~android~~`,
        fs:  `cpe:2.3:a:vmware:vcenter_guided_consolidation:4.0.0.7797:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naver:nhn_japan_naver_line:3.3.4:-:~~~android~~`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naver:nhn_japan_naver_line:3.3.7:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naver:nhn_japan_naver_line:3.4.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:navicat:navicat:10.0::~~premium~~~`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naxsi_project:naxsi:0.46`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naxsi_project:naxsi:0.46-1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:naxtech:cms_afroditi:1.0`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.60.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nba:nba_game_time_2013-2014:4.11::~~~android~~`,
        fs:  `cpe:2.3:a:openstack:swift:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nba:sacramento_kings:6.0.8::~~~android~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd347a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nbcfc:new_beginnings_cfc:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nbe:nbe:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:python:pillow:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncircle:configuration_compliance_manager:-`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.0.1475.18262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncircle:ip360:-`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ncircle:suite360_intelligence_hub:-`,
        fs:  `cpe:2.3:a:mesa3d:mesa:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_secure_client:9.31:-:juniper`,
        fs:  `cpe:2.3:a:ubercart_views_project:uc_views:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_enterprise_client:2.1:-:~~~android~~`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr1604hf-a-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_enterprise_client:2.02:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_enterprise_client:2.37:-:~~~windows_ce~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_enterprise_client:3.23:-:~~~linux_kernel~~`,
        fs:  `cpe:2.3:h:cisco:unity_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_enterprise_client:9.31:-:~~~windows~~`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.0.1:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_entry_client:2.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_entry_client:2.02:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_entry_client:2.35:-:~~~windows_mobile~~`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_entry_client:9.31:-:~~~windows~~`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2638:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncp:vpn_universal_secure_entry_client_premium:2.1:-:~~~android~~`,
        fs:  `cpe:2.3:h:cisco:nexus_7700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncr:bootdiskmon:2.3.0.0`,
        fs:  `cpe:2.3:a:capasystems:performance_guard:6.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncr:bootdiskmon:2.4.0.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncr:ncr_sm3g_cmic_legacy:2.0.0.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncr:pci_configurator:1.2.0.0`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncr:tas:2.0.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncr:wintools_for_windows:2.3.0.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:huawei:honor_4c_firmware:chm-ul00c00b556:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:progress:4gl_compiler:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.2.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.18_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.3.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.3.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:customer_intelligence:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.3.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:avaya:sg200:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.3.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:16.5.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.3.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:2.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.3.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.52.1:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ncrafts:formcraft:1.3.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nec:asl_ux_4800:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:bluefire_ix1035_router:-`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nec:ews-ux_v:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:expresscluster_x:3.3::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:expresscluster_x:3.3::~~~windows~~`,
        fs:  `cpe:2.3:o:huawei:quidway_s9300_firmware:v200r003c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:ix1010:-`,
        fs:  `cpe:2.3:a:apple:quicktime:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:ix1011:-`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:sp4_patch3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:ix1020:-`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:ix1050:-`,
        fs:  `cpe:2.3:a:hp:bufferchm:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:ix2010:-`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:9.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:multiwriter_1700c:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:socks_5:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p284:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:socks_5:1.0r5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:socks_5:1.0r11`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:sockscap:-`,
        fs:  `cpe:2.3:a:suse:kiwi:4.85.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:superscript_4400:-`,
        fs:  `cpe:2.3:a:avast:internet_security:11.1.2262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nec:univerge:-`,
        fs:  `cpe:2.3:h:cisco:nexus_9396tx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:universal_raid_utility:1.40`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(2\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:universal_raid_utility:1.40:rev_680`,
        fs:  `cpe:2.3:a:oracle:http_server:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:universal_raid_utility:2.5`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:universal_raid_utility:2.5:rev_2244`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:universal_raid_utility:2.31`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nec:universal_raid_utility:2.31:rev_1492`,
        fs:  `cpe:2.3:a:scadatec:scadaphone:5.3.11.1230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nec:up-ux_v:-`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.17.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nec:up-ux_v:4.2mp`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nedprod:nedmalloc:1.10:beta1`,
        fs:  `cpe:2.3:a:autodesk:autocad_architecture_2009:5.7.68.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nedprod:nedmalloc:1.10:beta2`,
        fs:  `cpe:2.3:a:sybase:easerver:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:neevia:docuprinter:5.0::~~lt~~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nefarious2_project:nefarious2:-`,
        fs:  `cpe:2.3:a:bean_project:bean:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nefarious2_project:nefarious2:2.0`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:neojoomla:com_neorecruit:1.6.4`,
        fs:  `cpe:2.3:a:opsview:opsview:4.4:-:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:neojoomla:com_neorecruit:2.0.5`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.11-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:neorcha:usek:1.0.8::~~~android~~`,
        fs:  `cpe:2.3:a:kde:kmail:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:neotys:neoload:3.2.3`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nerdico_project:nerdico:1.9::~~~android~~`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:advertising_center:0.0.0.1`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:burnrights:2.99.6.100`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:controlcenter:0.0.0.1`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_332_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:controlcenter:9.0.0.1`,
        fs:  `cpe:2.3:a:adobe:air:15.0.0.293:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:coverdesigner:4.0.5.100`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:coverdesigner_help:4.0.0.0`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:disc_copy_gadget:1.53.0.0`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:disc_copy_gadget_help:2.0.0.0`,
        fs:  `cpe:2.3:a:skype:skype:4.1.0.166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:discspeed:4.99.5.105`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:dolbyfiles:2.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:drivespeed:3.99.5.105`,
        fs:  `cpe:2.3:h:foundrynet:bigiron_8000_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:essentials:7.2.4509`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:essentials:7.2.5017`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:essentials:7.2.7903`,
        fs:  `cpe:2.3:a:google:chrome:5.0.373.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:essentials:7.2.8078`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7a\)ey3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:essentials:7.2.8506`,
        fs:  `cpe:2.3:a:docker:docker:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:essentials:8.3.500`,
        fs:  `cpe:2.3:o:cisco:ios:12.1aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:infotool:5.99.5.105`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:installer:2.0.0.1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.6.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:live:1.0.164.0`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:5.5:u3b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:live_help:1.0.162.0`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.4.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:mediahome:-`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:mediahome:2.5.5.0`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:mediahome_ce:-`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:mediahome_ce:1.3.0.4`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:mediaplayer:-`,
        fs:  `cpe:2.3:a:emc:data_domain_openstorage_plugin:2.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:mediaplayer:1.4.0.35`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:menu_templates_starter_kit:9.0.4.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:movie_templates_starter_kit:9.0.4.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.07.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:nero:-`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:nero:5.5.8.13`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:nero:6.0.0.15`,
        fs:  `cpe:2.3:a:cisco:business_edition_3000_software:8.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:nero:7.2.8637::~~ultra~~~`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:nero:9.0.0.0::~~express~~~`,
        fs:  `cpe:2.3:o:juniper:junos_m:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:nero:9.0.9.100`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:12.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:nero:9.0.9.100::~~express~~~`,
        fs:  `cpe:2.3:a:microsoft:outlook:2010:sp1:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:nero:nero_soundtrax_help:4.0.15.0`,
        fs:  `cpe:2.3:a:infor:enspire_distribution_management_solution:7.3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:neronet:-`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:neronet:1.2.0.2`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:neroxml:1.0.0`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.2:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:photosnap:1.53.2.0`,
        fs:  `cpe:2.3:a:agi:license_manager:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:photosnap_help:1.53.2.0`,
        fs:  `cpe:2.3:a:activetemplates:template:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:recode:3.53.0.0`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:recode_help:3.53.0.0`,
        fs:  `cpe:2.3:o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:rescue_agent:1.99.0.1`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:showtime:4.99.0.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:soundtrax:4.0.18.0`,
        fs:  `cpe:2.3:a:microsoft:excel:97:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:startsmart:9.0.9.100`,
        fs:  `cpe:2.3:a:zarafa:zarafa:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:startsmart_help:9.0.0.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_41:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:vcredistsetup:1.0.0`,
        fs:  `cpe:2.3:h:siemens:scalance_x200-4p_irt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:vision:6.0.0.100`,
        fs:  `cpe:2.3:a:php:php:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:vision:6.0.6.100`,
        fs:  `cpe:2.3:a:bestsoftinc:advance_hotel_booking_system:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:waveeditor:5.0.18.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nero:waveeditor_help:5.0.15.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.23:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nessoft:multiping:2.10.2.19`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nestler:ultimate_christian_radios:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nestor_mata_cuthbert:taxonomy_navigator:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nesvarnik:nesvarnik:1::~~~android~~`,
        fs:  `cpe:2.3:h:3com:3c17702-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.2`,
        fs:  `cpe:2.3:a:winzip:winzip:_9.0_sr-1_\(6224\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.3`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.4`,
        fs:  `cpe:2.3:a:preplogic:exam_70-643:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.5`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.6`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.7`,
        fs:  `cpe:2.3:a:redhat:kdelibs_devel:2.2-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.8`,
        fs:  `cpe:2.3:a:cisco:internet_streamer_content_delivery_system:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.0.9`,
        fs:  `cpe:2.3:a:drecom:reign_of_dragons\:_build-battle:2.4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.1`,
        fs:  `cpe:2.3:a:bzrtp_project:bzrtp:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.1.2`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.3`,
        fs:  `cpe:2.3:a:x:libfs:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.3.0.1`,
        fs:  `cpe:2.3:a:emc:networker:7.5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.4`,
        fs:  `cpe:2.3:a:apache:groovy:1.9.0:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.5`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.6`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.7`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.7.1`,
        fs:  `cpe:2.3:a:swim_team_project:swim_team:1.44.10777:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.7.2`,
        fs:  `cpe:2.3:a:microsoft:forefront_unified_access_gateway:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:net-snmp:net-snmp:5.8`,
        fs:  `cpe:2.3:a:mod_nss_project:mod_nss:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:data_ontap:-`,
        fs:  `cpe:2.3:a:hp:san\/iq:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:data_ontap:6.5.2`,
        fs:  `cpe:2.3:a:ca:unicenter_nsm_wireless_network_management_option:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:data_ontap:7.0.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:data_ontap:7.1`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netapp:data_ontap:8.2.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4sq.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:data_ontap_dsm_for_windows_mpio:3.4.3741.1243`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_marconi_atm:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:netcache:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:oncommand_balance:4.2`,
        fs:  `cpe:2.3:a:php-nuke:emporium_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:snapdrive:6.2.0.5007`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.13:dev1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:snapdrive:6.2.1.5029`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2010.302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:snapdrive:6.3.0.4601`,
        fs:  `cpe:2.3:a:crear.ne.jp:al-mail32:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:system_manager:1.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:system_manager:1.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:virtual_file_mangemer:-`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netapp:windows_host_utilities:5.3.3508.1105`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30097:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netartmedia:car_portal:1.0`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netartmedia:car_portal:2.0`,
        fs:  `cpe:2.3:a:atutor:atutor:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netartmedia:car_portal:3.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:3.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netartmedia:iboutique:4.0`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netartmedia:iboutique.mall:1.2`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netartmedia:real_estate_portal:2.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netartmedia:real_estate_portal:3.0`,
        fs:  `cpe:2.3:a:trendmicro:interscan_messaging_security_suite:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.1`,
        fs:  `cpe:2.3:a:roxio:creator_de:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.11:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.2.1`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:8.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.3`,
        fs:  `cpe:2.3:o:tp-link:lm_firmware:1.6.18p12_sign5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.3.1`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_standalone:4.0.1.161434:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.3.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.4-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.4`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.4.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.5`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.804.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.5.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:3.6`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:4.0`,
        fs:  `cpe:2.3:h:d-link:dap-2690:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:4.1`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:5.0`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:5.5`,
        fs:  `cpe:2.3:a:apps4u\@android:sd_card_manager:20140223:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:5.5.1`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.0`,
        fs:  `cpe:2.3:a:php:f1_maxs_file_uploader:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.0.1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.1`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.5`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:6.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.5.1`,
        fs:  `cpe:2.3:a:adastra:trace_mode_data_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.7`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.7.1`,
        fs:  `cpe:2.3:a:apport_project:apport:2.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.8`,
        fs:  `cpe:2.3:h:hp:jg514a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.9`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:6.9.1`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:7.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbeans:netbeans_ide:7.0.1`,
        fs:  `cpe:2.3:a:altiris:application_metering_documentation:6.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbsd:ftpd:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbsd:ftpd:1.5`,
        fs:  `cpe:2.3:a:hp:array_diagnostic_utility:8.26.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbsd:ftpd:1.5.1`,
        fs:  `cpe:2.3:a:tilman_hausherr:xenu_link_sleuth:1.0g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbsd:ftpd:1.5.2`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbsd:ftpd:1.5.3`,
        fs:  `cpe:2.3:a:grape_project:grape:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbsd:ftpd:1.6`,
        fs:  `cpe:2.3:a:gimp:gimp:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.0`,
        fs:  `cpe:2.3:a:blackberry:enterprise_server:12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.1`,
        fs:  `cpe:2.3:a:kajona:kajona:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.2`,
        fs:  `cpe:2.3:o:cisco:vpn_3020_concentrator:4.7.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.2.1`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp4:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.3`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.3.1`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.3.2`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.3.3`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.4`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.4.1`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:6.14.12.5981:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.4.2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.4.3`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.5`,
        fs:  `cpe:2.3:a:opensis:opensis:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.5.1`,
        fs:  `cpe:2.3:a:redhat:open_iscsi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.5.2`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.9:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.5.3`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r75.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.6`,
        fs:  `cpe:2.3:a:rack_project:rack:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.6:beta`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.5:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.6.1`,
        fs:  `cpe:2.3:a:emc:file_management_appliance_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:1.6.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:2.0`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:2.0.1`,
        fs:  `cpe:2.3:a:lumension:patchlink:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:2.0.2`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:2.0.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:2.0.4`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:2.1`,
        fs:  `cpe:2.3:a:perl:perl:2.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:2.1.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.178:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:3.0`,
        fs:  `cpe:2.3:a:oracle:vm_server:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:3.0.1`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:3.0.2`,
        fs:  `cpe:2.3:a:pcre:pcre:8.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:3.1`,
        fs:  `cpe:2.3:a:askapache:firefox_adsense:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:3.99.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:4.0`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:4.0:beta`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:4.0:beta2`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(12\)s4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:5.1.1`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:5.1.2`,
        fs:  `cpe:2.3:a:ibm:lotus_protector_for_mail_security:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:5.1.3`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:5.1.4`,
        fs:  `cpe:2.3:a:mahara:mahara:16.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:5.2`,
        fs:  `cpe:2.3:a:janetter:janetter:3.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:5.2.1`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-282_firmware:t377sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:5.2.2`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.0:beta`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.0.1`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.0.2`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.0.3`,
        fs:  `cpe:2.3:h:hp:3com_switch:ss4_5500g-ei-pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.0.4`,
        fs:  `cpe:2.3:a:dtsearch:dtsearch:7.66.7936:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.0.5`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.0.6`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2005:0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.1`,
        fs:  `cpe:2.3:a:emc:atmos:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.1.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.1.2`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.1.3`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.1.2:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.1.4`,
        fs:  `cpe:2.3:o:cisco:unified_sip_phone_3900_firmware:9.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netbsd:netbsd:6.1.5`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:4.0.138377.779:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netbsd:umapfs:-`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netcreators:irfaq:1.0.1`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.5.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netcreators:irfaq:1.0.2`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netcreators:irfaq:1.1.0`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netcreators:irfaq:1.1.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.125.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netcreators:irfaq:1.1.2`,
        fs:  `cpe:2.3:a:adobe:creative_cloud:3.6.0.248:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netcreators:irfaq:1.1.4`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:netease_cloudalbum:2.0.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:netease_cloudalbum:2.2.0`,
        fs:  `cpe:2.3:a:garmin:communicator_plugin:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:netease_pmail:0.5.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.397:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:netease_pmail:0.5.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:netease_weibohd:1.0.0`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.0.2:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:neteaseweibo:1.2.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.01.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:neteaseweibo:1.2.2`,
        fs:  `cpe:2.3:a:apache:couchdb:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:youdao_dictionary:1.6.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:youdao_dictionary:2.0.1%282%29`,
        fs:  `cpe:2.3:a:boopsie:boopsie_mylibrary:4.5.110:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:netease:youdao_dictionary:3.0.0%281%29`,
        fs:  `cpe:2.3:a:apache:cocoon:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:ipset:6.30`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:ipset:6.31`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:ipset:6.32`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:ipset:6.33`,
        fs:  `cpe:2.3:h:hp:laserjet_m1522n_multifunction_printer:cc372a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:ipset:6.34`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:libmnl:1.0.0`,
        fs:  `cpe:2.3:a:basercms:basercms:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:libmnl:1.0.1`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:libmnl:1.0.2`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:libmnl:1.0.3`,
        fs:  `cpe:2.3:a:perl:perl:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netfilter:libmnl:1.0.4`,
        fs:  `cpe:2.3:a:intel:mlogview:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:d3600:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:d3600_firmware:_1.0.0.49`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:d3600_firmware:1.0.0.49`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:d6000:-`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp3:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:d6000_firmware:1.0.0.49`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:d6220:-`,
        fs:  `cpe:2.3:a:jquery:jquery:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:d6220_firmware:1.0.0.22`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:d6400:-`,
        fs:  `cpe:2.3:h:hp:af601a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:d6400_firmware:1.0.0.56`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:dg834gt:-`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:dg834gt:1.01.28`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.3:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fm114p:-`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fsm726s:-`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fsm726s:2.6.2`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.0.4115.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvg318:-`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvg318:1.0.40`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvs318:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvs318:1.0`,
        fs:  `cpe:2.3:a:samba:samba:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvs318:1.1`,
        fs:  `cpe:2.3:o:cisco:mds_9000:1.3\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvs318:1.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvs318:1.3`,
        fs:  `cpe:2.3:a:splunk:splunk:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvs318:2`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:fvs318:2.4`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:gs108pe:-`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:gs108pe_firmware:1.2.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.0se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:gs716t:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.15:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:gs724t:-`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:ma521_driver:-`,
        fs:  `cpe:2.3:a:mini-stream:rm-mp3_converter:3.1.2.1.2010.03.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:me102:-`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:me102:1.3`,
        fs:  `cpe:2.3:a:opscode:chef:0.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:mr-adsl-dg834:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:netgear_ga311_smart_wizard_utility:1.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:prosafe_firmware:5.0.4.4`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.2.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:prosafe_firmware:5.3.0.17`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:prosafe_firmware:5.4.0.6`,
        fs:  `cpe:2.3:a:ultraseek:ultraseek:5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:prosafe_firmware:5.4.1.10`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:prosafe_firmware:5.4.1.13`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:prosafe_firmware:5.4.1.14`,
        fs:  `cpe:2.3:a:apache:tomcat:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:prosafe_firmware:6.1.0.12`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs510tp:-`,
        fs:  `cpe:2.3:a:hp:service_virtualization:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs724t:v3`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs725ts:-`,
        fs:  `cpe:2.3:a:apache:http_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs728tps:-`,
        fs:  `cpe:2.3:h:hp:cf082a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs728ts:-`,
        fs:  `cpe:2.3:a:mautic:mautic:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs728txs:-`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs748t:v4`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs752tps:-`,
        fs:  `cpe:2.3:a:fitnesse:fitnesse_wiki:20131110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_gs752txs:-`,
        fs:  `cpe:2.3:a:vmware:workstation_player:12.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:prosafe_network_management_software_300:1.5.0.11`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:prosafe_s716t:v2`,
        fs:  `cpe:2.3:a:osisoft:pi_interface:1.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r6250:-`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.10.205.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r6250_firmware:1.0.4.6_10.1.12`,
        fs:  `cpe:2.3:h:nvidia:geforce_930mx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r6400:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r6400_firmware:1.0.1.18`,
        fs:  `cpe:2.3:a:sophos:unified_threat_management_software:9.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r6700:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:566:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r6700_firmware:1.0.1.14`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.core:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r6900:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.11:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r6900_firmware:1.0.1.14`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r7000:-`,
        fs:  `cpe:2.3:h:axis:2400_video_server:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r7000_firmware:1.0.7.2_1.1.93`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r7100lg:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5.2\)xu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r7100lg_firmware:1.0.0.28`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r7300dst:-`,
        fs:  `cpe:2.3:a:tenable:nessus:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r7300dst_firmware:1.0.0.46`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r7900:-`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r7900_firmware:1.0.1.8`,
        fs:  `cpe:2.3:a:adobe:svg_viewer:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:r8000:-`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:r8000_firmware:1.0.3.26`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:raidiator:4.1:-:~-~-~-~readynas~`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:raidiator:4.2.15:-:~-~-~-~readynas~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:raidiator:4.2.20:-:~-~-~-~readynas~`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:raidiator:4.2.23:-:~-~-~-~readynas~`,
        fs:  `cpe:2.3:a:apache:http_server:0.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:raidiator:4.2.24:-:~-~-~-~readynas~`,
        fs:  `cpe:2.3:a:magzter:indian_jeweller:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:readynas_raidiator:-`,
        fs:  `cpe:2.3:a:netscape:navigator:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:readynas_surveillance:1.1.1`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:-:driveshield:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:readynas_surveillance:1.1.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:readynas_surveillance:1.2.0.4`,
        fs:  `cpe:2.3:a:apple:itunes:7.2.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:readynas_surveillance:1.3.2.4`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:readynas_surveillance:1.3.2.14`,
        fs:  `cpe:2.3:a:apache:derby:10.2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:readynas_surveillance:1.4.0`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:readynas_surveillance:1.4.1`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:readynas_surveillance:1.4.2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rm356:-`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.18415:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rp114:-`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:2.0:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rp114:3.26`,
        fs:  `cpe:2.3:a:telerik:asp.net_ajax_radeditor_control:2009.3.1208.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rt311:-`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.5p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rt314:-`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rt314:3.22`,
        fs:  `cpe:2.3:a:osisoft:pi_opc_da_interface:2.3.20.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rt314:3.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rt314:3.25`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:rt338:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:ssl312:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wg111v2:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:wg111v2_driver:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.52:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgear:wg111v2_driver:5.1213.6.316`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wg311v1:-`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.0\(240.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wg602:-`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wg602:1.04.0`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wg602:1.5.67`,
        fs:  `cpe:2.3:h:cisco:ids_4250:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wg602:1.7.14`,
        fs:  `cpe:2.3:o:raritan:px:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v2`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_73:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd374a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v5`,
        fs:  `cpe:2.3:a:apache:ofbiz:12.04.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v6`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v8`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgr614:v9`,
        fs:  `cpe:2.3:a:samsung:scx-4200_driver:2.00.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wgt624:-`,
        fs:  `cpe:2.3:a:google:v8:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wndr4700:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update6:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:wndr4700_firmware:1.0.0.34`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netgear:wnr1000v3:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:netgear:wnr1000v3_firmware:1.0.2.68`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgenius:multilink:6.x-2.0`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgenius:multilink:6.x-2.1`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgenius:multilink:6.x-2.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgenius:multilink:6.x-2.3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgenius:multilink:6.x-2.4`,
        fs:  `cpe:2.3:a:gnu:data_display_debugger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgenius:multilink:6.x-2.5`,
        fs:  `cpe:2.3:a:google:custom_search_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgenius:multilink:6.x-2.6`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netgenius:multilink:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:access_manager:4.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:access_manager:4.0.1`,
        fs:  `cpe:2.3:a:e107:e107:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:analysis_center:2.5.0`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_agent:7.0.10160.0`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_agent:7.0.25020.0`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_agent:7.0.25142.0`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_console:7.0.10160.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_console:7.0.25063.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_console:7.0.41018.0`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.881:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_control_center:7.0.10160.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_control_center:7.0.40179.0`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_control_center:7.0.40428.0`,
        fs:  `cpe:2.3:h:pacom:1000_ccu_gms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_control_center:7.0.40469.0`,
        fs:  `cpe:2.3:a:apple:itunes:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_diagnostic_console:2.1.0.0`,
        fs:  `cpe:2.3:a:microsoft:ie:4.72.3110.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_management_server:7.0.41053.16`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_repository_installation:7.0.10160.0`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.0.2.1744:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_repository_slovenia_qdb:7.0.11248.0`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:appmanager_web_management_server:7.0.41039.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:core_services:5.7.0.390`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.0`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.0:-:~~~windows~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.1`,
        fs:  `cpe:2.3:a:plone:plone:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.1:-:~~~windows~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.2`,
        fs:  `cpe:2.3:a:gnu:automake:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.2:-:~~~windows~~`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.3`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.3:-:~~~windows~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)sl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.4`,
        fs:  `cpe:2.3:a:x:libxi:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.4:-:~~~windows~~`,
        fs:  `cpe:2.3:h:ibm:bladecenter:hs22v:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.5`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.5:-:~~~windows~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.6:-:~~~windows~~`,
        fs:  `cpe:2.3:a:apache:james_server:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.6.7`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.7.0`,
        fs:  `cpe:2.3:h:cisco:asr_1013:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.7.0:-:~~~windows~~`,
        fs:  `cpe:2.3:a:jason_moore:amadou:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.7.1`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.7.1:-:~~~windows~~`,
        fs:  `cpe:2.3:a:google:chrome:11.0.672.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:edirectory:8.8.7.2`,
        fs:  `cpe:2.3:h:dell:powervault_ml6030:23u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:endpoint:5.0.3186`,
        fs:  `cpe:2.3:o:cisco:headend_system_release:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:endpoint:5.1.8149`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.17:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:namespace_server:2.54`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:privileged_user_manager:2.3.0`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_vc220_network_dome_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:privileged_user_manager:2.3.1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.764:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:privileged_user_manager:2.3.1:hf2`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:secure_configuration_manager:5.7.0.390`,
        fs:  `cpe:2.3:h:linksys:befsr11:1.43.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:security_manager:6.0.0.194`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:security_manager:6.5.3.149`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:security_manager:6.5.4.349`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p276:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:security_manager_agent:6.0.0.194`,
        fs:  `cpe:2.3:a:vn-calendar_project:vn-calendar:1.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:security_manager_agent:6.5.3.149`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-52p-pwr-ei_ls-3600-52p-pwr-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:security_manager_log_archive_resource_kit:1.0.0`,
        fs:  `cpe:2.3:o:redhat:fedora_core:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:security_manager_reporting:6.0.0.194`,
        fs:  `cpe:2.3:a:docker:docker:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:security_solutions_for_iseries:8.1`,
        fs:  `cpe:2.3:h:huawei:s3500:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:self_service_password_reset:2.0`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:8.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:self_service_password_reset:3.0`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:self_service_password_reset:3.1`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:self_service_password_reset:3.2`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:self_service_password_reset:3.3`,
        fs:  `cpe:2.3:h:supermicro:x9qr7-tf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:self_service_password_reset:3.3.1`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:sentinel:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:sentinel_agent_manager:-`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:snmp_trap_receiver:1.2.16.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:snmp_trap_receiver:1.3.9.0`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:unix_agent_manager:7.1.0.0`,
        fs:  `cpe:2.3:a:sega:sonic_4_episode_ii_lite:2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:netiq:unix_manager:5.5.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netjapan:tsushima_travel_guide:1.9::~~~android~~`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netkit:netkit:-`,
        fs:  `cpe:2.3:a:digium:asterisk:11.15.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netkit:netkit:0.17`,
        fs:  `cpe:2.3:a:tiket:tiket.com_hotel_\&amp;_flight:1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:netkit-ftp:netkit_ftp:-`,
        fs:  `cpe:2.3:a:wikipop_plugin_project:wikipop:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netkit-ftp:netkit_ftp:0.17`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netkit-ftp:netkit_ftpd:-`,
        fs:  `cpe:2.3:a:microsoft:office:xp:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netmarble:mpang.gp:4.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:apport_project:apport:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netopsystem:fead_optimizer:-`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsarang:xmanager:3.0.127`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsarang:xmanager:3.0.218::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsarang:xmanager:4.0.165::~~enterprise_beta~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3_6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscantools:netscantools:10.31::~~professional~~~`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:certificate_management_system:-`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:certificate_server:-`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:certificate_server:4.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.0:beta0002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:collabra_server:-`,
        fs:  `cpe:2.3:a:apache:libcloud:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:collabra_server:3.5.2`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_5830:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:collabra_server:3.5.4`,
        fs:  `cpe:2.3:a:serf_project:serf:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:commerce_server:-`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:commerce_server:1.12`,
        fs:  `cpe:2.3:a:abb:panel_builder_800:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communications_server:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communications_server:1.1`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.snap:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communications_server:1.12`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:-`,
        fs:  `cpe:2.3:a:digium:asterisk:12.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:2.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:3.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.643.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.0`,
        fs:  `cpe:2.3:h:3com:3c17203-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.01`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.04`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20020803:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.4`,
        fs:  `cpe:2.3:a:dell:idrac6_monolithic:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.5`,
        fs:  `cpe:2.3:a:sap:hybris:5.7.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.05`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.5_beta`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.6`,
        fs:  `cpe:2.3:a:debian:adequate:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.06`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.0.899:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.07`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.7`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.08`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.8`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.14159265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.51`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.61`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_chassis_management_firmware:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.72`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.16:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.73`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.74`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.75`,
        fs:  `cpe:2.3:a:david_king:vino:2.25.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.76`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.41.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.77`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.78`,
        fs:  `cpe:2.3:a:centrify:centrify_suite:2012.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:4.79`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:6.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:6.2.1`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:communicator:7.02`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2008.0225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:directory_server:-`,
        fs:  `cpe:2.3:a:oracle:industry_applications:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:directory_server:3.6`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:directory_server:3.12`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:directory_server:4.1`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:directory_server:4.11`,
        fs:  `cpe:2.3:a:gnu:glibc:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:directory_server:4.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:directory_server:4.13`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:2.0`,
        fs:  `cpe:2.3:a:sysphonic:thetis:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.0`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.0.1`,
        fs:  `cpe:2.3:a:apple:java_1.6:0:05:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.3`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.4`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0804hf-a-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.5`,
        fs:  `cpe:2.3:a:google:chrome:9.0.568.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.5.1`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:3.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:4.0`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:4.1`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:6.0`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:enterprise_server:6.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:fasttrack_server:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:fasttrack_server:2.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_platform_emulator:3.0\(2c\)ts9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:fasttrack_server:2.01`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:fasttrack_server:3.01`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:fasttrack_server:3.01b`,
        fs:  `cpe:2.3:a:cybird:girls_calendar_period\&amp;weight:3.2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:fasttrack_server:4.0.1`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:iplanet_ical:-`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:messaging_server:-`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:messaging_server:3.6`,
        fs:  `cpe:2.3:a:vmware:hyperic_hq:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:messaging_server:3.54`,
        fs:  `cpe:2.3:a:mozilla:firefox:24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:messaging_server:3.55`,
        fs:  `cpe:2.3:a:winpcap:winpcap:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:messaging_server:4.0`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:messaging_server:4.15`,
        fs:  `cpe:2.3:h:ibm:sng:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:messanger:-`,
        fs:  `cpe:2.3:a:ibm:infosphere_guardium:8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:messenging_server:-`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:-`,
        fs:  `cpe:2.3:o:schneider-electric:modicon_m241_firmware:4.0.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:_navigator`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.40.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:2.02`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.01`,
        fs:  `cpe:2.3:a:acdsystems:acdsee:5.0.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.02`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.03`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.04`,
        fs:  `cpe:2.3:a:jenkins:git:0.1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.05`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.5`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.06`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.07`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.7`,
        fs:  `cpe:2.3:a:vips:vips:7.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.08`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.10:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.61`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.75`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:4.77`,
        fs:  `cpe:2.3:a:openid:openid4java:0.9.4.339:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:6.0`,
        fs:  `cpe:2.3:a:alvaro_herrera:pl\/php:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:6.01`,
        fs:  `cpe:2.3:h:cisco:hosting_solution_engine:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:6.1`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.8:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:6.2`,
        fs:  `cpe:2.3:a:hp:data_protector:9.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:6.2.1`,
        fs:  `cpe:2.3:a:ctdb_project:ctdb:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:6.2.2`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:8.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:6.2.3`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:7.0`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:10.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:7.0.2`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:7.1`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050414:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:7.2`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:7.02`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:8.0.3.3`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:8.0.3.4`,
        fs:  `cpe:2.3:a:teradata:administrator:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:8.0.40`,
        fs:  `cpe:2.3:a:roxio:backontrack:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:8.1`,
        fs:  `cpe:2.3:a:monotone:monotone:0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:8.1.2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:8.1.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:navigator:9.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:netscape_messaging_server_multiplexor:-`,
        fs:  `cpe:2.3:a:apache:cocoon:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:news_server:-`,
        fs:  `cpe:2.3:a:logitech:lws_help_main:13.25.1016.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:personalization_engine:-`,
        fs:  `cpe:2.3:a:nagios:nagios:4.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:portable_runtime_api:-`,
        fs:  `cpe:2.3:a:exim:exim:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:professional_services_ftpserver:-`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:proxy_server:-`,
        fs:  `cpe:2.3:a:perl:perl:5.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:proxy_server:2.5`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:proxy_server:3.5.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:publishingxpert:-`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:publishingxpert:2.5`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:smartdownload:-`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscape:smartdownload:1.3`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.8.1-215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:cdm_agent_firmware_maintenance_release:-`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:ngenius_client:4.6.0.0`,
        fs:  `cpe:2.3:a:redaxo:redaxo:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:ngenius_client:4.7.0.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:ngenius_client:4.9.0.0`,
        fs:  `cpe:2.3:a:redhat:openshift:3.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netscout:ngenius_express_appliance:-`,
        fs:  `cpe:2.3:a:hp:virtual_rooms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netscout:ngenius_flow_recorder:-`,
        fs:  `cpe:2.3:a:ssh:secure_shell:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:ngenius_infinistream:4.6.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:ngenius_performance_manager:-`,
        fs:  `cpe:2.3:a:php:php:5.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:ngenius_probes:-`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:netscout:ngenius_probes:-`,
        fs:  `cpe:2.3:a:agnitum:outpost_security_suite:6.7.3.3063.452.0726:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:ngenius_trace_analyzer_integrator:-`,
        fs:  `cpe:2.3:a:aegirproject:hostmaster:6.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:sniffer_analysis:4.6.0.0`,
        fs:  `cpe:2.3:a:spi\/si263b:message_classification:2.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscout:sniffer_analysis:4.7.0`,
        fs:  `cpe:2.3:a:psyced:psyced:20120821:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netscreen:network_and_security_manager:1.0.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netshinesoftware:com_netinvoice:1.2.0:sp1`,
        fs:  `cpe:2.3:a:atvise:webmi2ads:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netshinesoftware:com_netinvoice:2.0.8:-:std`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netshinesoftware:com_netinvoice:2.0.9:-:std`,
        fs:  `cpe:2.3:a:apache:camel:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netshinesoftware:com_netinvoice:2.0.10:-:lite`,
        fs:  `cpe:2.3:a:sap:netweaver:7.0:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netshinesoftware:com_netinvoice:2.3.2`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.1`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.2`,
        fs:  `cpe:2.3:a:mindrot:jbcrypt:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.4`,
        fs:  `cpe:2.3:a:siteminder_federation:r6.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.5`,
        fs:  `cpe:2.3:a:google:chrome:13.0.777.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.6`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.8`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.9`,
        fs:  `cpe:2.3:a:tecorange:simple_e-document:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.10`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.11`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.16.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.12`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.13`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.7.5\(42\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.14`,
        fs:  `cpe:2.3:a:wp_blipbot_project:wp_blipbot:3.0.9:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.15`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:-:*:macintosh:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:2.6.29.16`,
        fs:  `cpe:2.3:a:cisco:unified_ip_ivr:8.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.2`,
        fs:  `cpe:2.3:a:hp:arcsight_logger:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.4`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.16:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.7`,
        fs:  `cpe:2.3:a:nortel:51c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.0.9`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.0`,
        fs:  `cpe:2.3:a:rsa:bsafe_cert-c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.3`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.4`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.5`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.6`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.8`,
        fs:  `cpe:2.3:a:ibm:advanced_settings_utility:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.9`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.10`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.11`,
        fs:  `cpe:2.3:a:sympa:sympa:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:3.1.12`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.0`,
        fs:  `cpe:2.3:a:commvault:continuous_data_replicator_vss_provider:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.1`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.2`,
        fs:  `cpe:2.3:a:spip:spip:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.3`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)yq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.5`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.6`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.7`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.15s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.8`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_console:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.9`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.10`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.5.0.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.0.11`,
        fs:  `cpe:2.3:o:ibm:global_console_manager_32_firmware:1.18.0.22011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.0`,
        fs:  `cpe:2.3:a:hp:praesidium_webproxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.11:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.3`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.0.0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.4`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3060-ac-poe-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.5`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.431:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.7`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.8`,
        fs:  `cpe:2.3:a:page-layout-builder_project:page-layout-builder:1.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.1.9`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.2.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:4.2.2`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.25:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.2`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.3`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.014:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.4`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.5`,
        fs:  `cpe:2.3:a:bamboosolutions:custom_column_license_pack:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.6`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.7`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.8`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.0.9`,
        fs:  `cpe:2.3:a:sun:javamail:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.1.1`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.1.2`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.1.3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.1.4`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.1.5`,
        fs:  `cpe:2.3:h:cisco:spa8000_8-port_ip_telephony_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.1.6`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.2.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.2.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.2.3`,
        fs:  `cpe:2.3:a:logitech:quickcam:11.90.1263:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.2.4`,
        fs:  `cpe:2.3:h:huawei:ar_18-2x:r1712:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netsweeper:netsweeper:5.2.5`,
        fs:  `cpe:2.3:a:cisco:finesse:10.0\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.0`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.1`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.2`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.3`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.4`,
        fs:  `cpe:2.3:a:ibm:lotus_foundations_start:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.5`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.6`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.7`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.6.8`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.7.0`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.9.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.8.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.8.1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.9.0`,
        fs:  `cpe:2.3:a:apache:ambari:2.4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.9.1`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.9.1.1`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:3.9.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.0`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-backup:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.1`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.3`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:10.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.5`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.6`,
        fs:  `cpe:2.3:h:meinberg:ims-lantime_m1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.7`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0:ru6mp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(2\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.9`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.17.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.10`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.11`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.29:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.12`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.13`,
        fs:  `cpe:2.3:a:citrix:access_management_console_web_interface:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.14`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.15`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.16`,
        fs:  `cpe:2.3:a:cisco:accesspath:ts-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.17`,
        fs:  `cpe:2.3:h:hp:2200dtn_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.18`,
        fs:  `cpe:2.3:a:axis:media_control_embedded_installer:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.19`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.20`,
        fs:  `cpe:2.3:a:tincan:phplist:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.21`,
        fs:  `cpe:2.3:a:oracle:jdk:1.4.2_40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.22`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.23`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.25`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.1:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.26`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.27`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.28`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.29`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.30`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.39.5101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.31`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.32`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.33`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.34`,
        fs:  `cpe:2.3:a:illinois:ncsa_mosaic:2.7:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.35`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.36`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:11.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.0.37`,
        fs:  `cpe:2.3:a:plone:plone:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.352:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netty_project:netty:4.1.1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:neturf:ecommerce_shopping_cart:-`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:2.1`,
        fs:  `cpe:2.3:a:libssh2:libssh2:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:2.1.1`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds3400:1726:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:2.1.2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:2.1.3`,
        fs:  `cpe:2.3:o:oracle:opensolaris:snv_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:2.1.4`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:2.1.5`,
        fs:  `cpe:2.3:h:f5:big-ip_3600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:2.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:2.21`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.0`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.0.1`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.1.528992:*:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.0.2`,
        fs:  `cpe:2.3:a:keepass:keepass:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.0.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.387:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.0.4`,
        fs:  `cpe:2.3:o:lacie:lac9000464u_firmware:2.3.0.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.0.4.1`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.0b`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.11:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.0b3`,
        fs:  `cpe:2.3:a:synology:ds_photo\&#43;:3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.1`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnipcx:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netweblogic:login_with_ajax:3.1.1`,
        fs:  `cpe:2.3:a:apple:xcode:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:1.1h`,
        fs:  `cpe:2.3:a:isc:bind:9.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.0c`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.0d`,
        fs:  `cpe:2.3:a:samba:samba:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.0e`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.4:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.0f`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.2k1`,
        fs:  `cpe:2.3:o:google:chrome_os:8.0.552.342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.2k3`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.2m1`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3a1`,
        fs:  `cpe:2.3:h:xerox:phaser_6180mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3a2`,
        fs:  `cpe:2.3:a:zope:zope:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3a6`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3a7`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.2:sp01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3a8`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3a9`,
        fs:  `cpe:2.3:a:fourkitchens:ed_readmore:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3a10`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.55:rc01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3a12`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.68:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:netwin:surgeftp:2.3b1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwitness:netwitness_administrator:8.6`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwitness:netwitness_investigator:8.6`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:netwitness:netwitness_live_manager:1.0.0`,
        fs:  `cpe:2.3:a:broadcom:asf_management_applications:10.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:network-weathermap:.network_weathermap:0.97:a`,
        fs:  `cpe:2.3:a:blynk:deltin_suites:3.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:network-weathermap:.network_weathermap:0.97:b`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:network-weathermap:.network_weathermap:0.97:c`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:network_vision:intravue:2.3.0a11`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:networkautomation:automate:6.1.1.0`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ecc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:networknotepad:network_notepad:4.6.6`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:neumann:neumann_student_activities:216607::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:new-year-firework_project:new-year-firework:1.1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.27:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:new_atlanta:bluedragon:7.1.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.45.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newisys:service_processor_software_components:1.0.0`,
        fs:  `cpe:2.3:a:checkpoint:ng-ai:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.2.0`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.3.0`,
        fs:  `cpe:2.3:a:apple:cups:1.1.20:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.3.1`,
        fs:  `cpe:2.3:a:jan_bednarik:cooluri:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.3.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.3.2.1`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.3.3`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.3.4`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1004.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.3.4.1`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma610xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.3.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.4.0`,
        fs:  `cpe:2.3:o:cisco:nx-os_1000v_switch:4.0\(4\)sv1\(1\):*:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.4.0.1`,
        fs:  `cpe:2.3:a:david_king:vino:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.4.1`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.4.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.336.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.4.2.1`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.5.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.5.0.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.5.1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.5.1.14`,
        fs:  `cpe:2.3:h:supermicro:x9drt-h6ibqf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.5.2`,
        fs:  `cpe:2.3:a:arcsight:arcsight_console:5.0.1.2:sp1_patch_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newrelic:ruby_agent:3.5.2.17`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.627:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_pack_project:news_pack:0.1.0::~~~typo3~~`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_project:news:3.0.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:macromedia:jrun:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_project:news:3.0.1::~~~typo3~~`,
        fs:  `cpe:2.3:h:hp:jc612a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_project:news:3.1.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:mcafee:privacy_service:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_project:news:3.2.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_project:news:3.2.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:emc:networker:7.6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_project:news:3.4.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_project:news:3.5.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:reviewboard:djblets:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_project:news:3.5.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_revolution_-_bahrain_project:news_revolution_-_bahrain:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:isc:bind:9.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:news_search_project:news_search:0.1.0`,
        fs:  `cpe:2.3:a:google:earth:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsignature:addressfield_tokens:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsignature:addressfield_tokens:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:qemu:qemu:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsignature:addressfield_tokens:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsignature:addressfield_tokens:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:umn:mapserver:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsignature:addressfield_tokens:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:avery:design_pro:5.2.1201:*:*:*:limited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsoftinc:presto%21_bizcard:4.0:::en`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsoftinc:presto%21_bizcard:5.20.51:::en`,
        fs:  `cpe:2.3:a:gnu:make:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsoftinc:presto%21_pagemanager:7.15.14e`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsoftinc:presto%21_pagemanager:7.15.16`,
        fs:  `cpe:2.3:a:combodo:itop:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsoftinc:presto%21_pagemanager:7.16.20`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newsoftinc:presto%21_pagemanager:7.16.30`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:newstatpress_project:newstatpress:0.9.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nex-forms_lite_project:nex-forms_lite:2.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:hpssupply:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha1`,
        fs:  `cpe:2.3:a:tor_browser_the_short_guide_project:tor_browser_the_short_guide:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha10`,
        fs:  `cpe:2.3:a:adobe:dreamweaver:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha11`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha12`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha13`,
        fs:  `cpe:2.3:a:apache:poi:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha14`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha15`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha16`,
        fs:  `cpe:2.3:a:microsoft:pocket_internet_explorer:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha2`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1513-1_pn_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha3`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:624:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha7`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha8`,
        fs:  `cpe:2.3:o:google:android:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:alpha9`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:beta1`,
        fs:  `cpe:2.3:a:apple:safari:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:beta2`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:beta3`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.16.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:beta4`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:13-12-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:rc1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.582:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:rc2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h:10.80:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:rc3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:rc4`,
        fs:  `cpe:2.3:a:ca:configuration_automation_server:12.5.8.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:rc5`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:rc6`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0:rc7`,
        fs:  `cpe:2.3:a:quest:toad_data_modeler:3.6.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0.1:test1`,
        fs:  `cpe:2.3:a:vmware:workstation:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0.1:test2`,
        fs:  `cpe:2.3:a:apache:poi:2.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.0.1:test3`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:beta1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je027a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:beta2`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_connect:r73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:beta3`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:6700:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:beta4`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:beta5`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.5.54375.427:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:money:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:rc3`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:rc4`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.04t-2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.0:rc5`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:2.1.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:3.0:beta1`,
        fs:  `cpe:2.3:a:sympa:sympa:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:3.0:beta2`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd656a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:3.0:beta3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:3.0:beta4`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:3.0:beta5`,
        fs:  `cpe:2.3:a:phplist:phplist:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:3.0:beta6`,
        fs:  `cpe:2.3:a:apache:groovy:2.2.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:3.0:beta7`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextapp:echo:3.0:beta8`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextbbs:nextbbs:0.6`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.6.1-gpl-022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextcloud:nextcloud_server:9.0.51`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextdc:onedc:1.7:-:~-~-~iphone_os~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextdc:onedc:1.51:-:~-~-~iphone_os~~`,
        fs:  `cpe:2.3:a:microsoft:interix:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextendweb:nextend_facebook_connect:1.5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:unicenter_service_level_management:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nexters:throne_rush:2.3.10::~~~android~~`,
        fs:  `cpe:2.3:a:icekirin:di_long_weibo:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextgenupdate:nextgenupdate:3.1.6::~~~android~~`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextit:activeagent:4.0`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nextit:activeagent:4.2`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nfsen:nfsen:-`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nfsen:nfsen:1.2.3`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ngemc:my_ngemc_account:1.153.0034::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.276:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nghttp2:nghttp2:1.5.0`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.0`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:6.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.1`,
        fs:  `cpe:2.3:a:microsoft:visual_foxpro:9.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.2`,
        fs:  `cpe:2.3:o:hp:hp-ux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.222.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.4`,
        fs:  `cpe:2.3:o:redhat:linux:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.5`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.6`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.7`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta62:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.8`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.9`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.10`,
        fs:  `cpe:2.3:h:fortinet:fortianalyzer-2000b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.11`,
        fs:  `cpe:2.3:o:ibm:vios:1.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.12`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.13`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.14`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.0.15`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.04.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.0`,
        fs:  `cpe:2.3:a:citrix:common_commands:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.1`,
        fs:  `cpe:2.3:a:pygments:pygments:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.2`,
        fs:  `cpe:2.3:a:perl:perl:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.3`,
        fs:  `cpe:2.3:a:apple:webkit:420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.5`,
        fs:  `cpe:2.3:a:mcafee:groupshield_for_exchange:7.0.716.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.6`,
        fs:  `cpe:2.3:o:tp-link:tl-wrd741nd_\(5.0\)_firmware:141217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.7`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.8`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp3:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.9`,
        fs:  `cpe:2.3:a:corel:paint_shop_photo_album:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.10`,
        fs:  `cpe:2.3:a:podofo_project:podofo:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.11`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.12`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.13`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.14`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.15`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.16`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.17`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.18`,
        fs:  `cpe:2.3:a:perl:perl:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.1.19`,
        fs:  `cpe:2.3:a:google:chrome:12.0.728.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.2.0`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.0`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.1`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.3`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.4`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.5`,
        fs:  `cpe:2.3:a:google:search_appliance_software:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.6`,
        fs:  `cpe:2.3:a:sgi:mipspro_compilers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.7`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.8`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.9`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.10`,
        fs:  `cpe:2.3:a:apple:mac_os_x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.11`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.12`,
        fs:  `cpe:2.3:a:darold:squidclamav:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.13`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.14`,
        fs:  `cpe:2.3:a:microsoft:windows_media_format_runtime:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.15`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.3.16`,
        fs:  `cpe:2.3:a:google:chrome:17.0.929.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.4.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.4.1`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.4.2`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.4.3`,
        fs:  `cpe:2.3:a:vmware:player:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.0`,
        fs:  `cpe:2.3:a:radius_extension_project:radius:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.1`,
        fs:  `cpe:2.3:a:djangoproject:django:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.2`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.3`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.5`,
        fs:  `cpe:2.3:a:teradata:manager:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.6`,
        fs:  `cpe:2.3:a:simplehrm:simplehrm:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.7`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.8`,
        fs:  `cpe:2.3:o:cisco:spa500_series_ip_phone_firmware:7.5.7\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.9`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.10`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.11`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports:12.3.1.684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.5.12`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.6.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p449:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.6.1`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.809:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.6.2`,
        fs:  `cpe:2.3:a:sasync:sasync:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.8.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.0`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.1`,
        fs:  `cpe:2.3:a:gnu:emacs:22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.361:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.3`,
        fs:  `cpe:2.3:o:hp:hp-ux_series_700:10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.5`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.4:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.6`,
        fs:  `cpe:2.3:a:nodejs:node.js:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.7`,
        fs:  `cpe:2.3:a:digia:qt:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.8`,
        fs:  `cpe:2.3:h:zyxel:p-660h-t3:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.9.9`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.10.0`,
        fs:  `cpe:2.3:a:citrix:online_plug-in:12.0.0.6410:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.10.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nginx:nginx:1.11.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:diadem:-`,
        fs:  `cpe:2.3:a:htc:vivid_software:3.26.502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:diadem:2012`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:labview:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:labview:2012`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:labwindows:-`,
        fs:  `cpe:2.3:a:invensys:dasabcip:4.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:labwindows:8.5`,
        fs:  `cpe:2.3:a:brocade:san_health_diagnostics_capture:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:labwindows:9.0`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:labwindows:2009`,
        fs:  `cpe:2.3:a:sun:jdk:1.2.2:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:labwindows:2010`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.5.1:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:labwindows:2012`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:lookout:6.5`,
        fs:  `cpe:2.3:a:google:chrome:6.0.466.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:lookout:6.6`,
        fs:  `cpe:2.3:a:vmware:vcloud_director:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:lookout:6.7`,
        fs:  `cpe:2.3:a:libgd:libgd:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:measurementstudio:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:497:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:measurementstudio:2013`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.5.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:teststand:-`,
        fs:  `cpe:2.3:a:apache:mod_python:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ni:teststand:2012`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nibbleblog:nibbleblog:4.0.1`,
        fs:  `cpe:2.3:a:fogproject:fog:0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nice:recording_express:6.3.5`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nice:recording_express:6.5.7`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:6.x-1.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.95:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:6.x-1.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:tenc4.1.1-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:6.x-1.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:6.x-1.3:alpha1`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:6.x-1.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:6.x-1.5`,
        fs:  `cpe:2.3:a:samba:samba:3.0.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:6.x-1.x-dev`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:7.x-1.3`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:7.x-1.3:alpha1`,
        fs:  `cpe:2.3:a:nvidia:control_panel:276.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:7.x-1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:7.x-1.5`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro:232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicholasthompson:global_redirect:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:hp:scanjet_8200_firmware:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.3`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.4-1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.4-57`,
        fs:  `cpe:2.3:a:indusoft:web_studio:7.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.5-13`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(2\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.5-19`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.5-37`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:0.9.5:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.5-48`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.5-60`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.5-66`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.5-89`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.6-113`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.6-121`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.6-150`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.6-169`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.9.6-212`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p421:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.2`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.4`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.5`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.7`,
        fs:  `cpe:2.3:a:condor_project:condor:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.8`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.31:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.9`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.10`,
        fs:  `cpe:2.3:a:hp:operations_agent:11.03.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.11`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.12`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.10.13`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.21.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.2`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.3`,
        fs:  `cpe:2.3:a:google:sketchup:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.4`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.11.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.5`,
        fs:  `cpe:2.3:h:sun:fire_x4100_server:sw_1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.6`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.883:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.7`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.8`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.9`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.3.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.20.10`,
        fs:  `cpe:2.3:a:apple:cups:1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.2`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.3`,
        fs:  `cpe:2.3:a:google:v8:3.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.4`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.5`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.7`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.8`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.30.9`,
        fs:  `cpe:2.3:a:sap:netweaver:7.0:ehp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.40.3`,
        fs:  `cpe:2.3:o:huawei:s9303_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.40.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p280:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.40.5`,
        fs:  `cpe:2.3:a:c-3.co.jp:webcalenderc3:0.31:s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.40.6`,
        fs:  `cpe:2.3:a:novell:nsure_audit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.40.7`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.40.8`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:20.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.50.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p310:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.50.3`,
        fs:  `cpe:2.3:a:sgi:nqsdaemon:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.50.5`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.50.6`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.50.7`,
        fs:  `cpe:2.3:a:gnu:automake:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.50.8`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.60.0`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.60.1`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.60.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.60.3`,
        fs:  `cpe:2.3:a:ivanjaros:feed_block:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.60.4`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.60.5`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.60.6`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.6.0.19140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nick_copeland:bristol:0.60.7`,
        fs:  `cpe:2.3:a:addsoft:storebot:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicolas_cannasse:ocaml_xml-light_library:r233`,
        fs:  `cpe:2.3:a:prosody:prosody:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicolas_cannasse:ocaml_xml-light_library:r234`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicolas_tormo:phppaleo:4.8b155`,
        fs:  `cpe:2.3:h:hp:proliant_dl2x170h_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nicolas_tormo:phppaleo:4.8b180`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nigel_horne:mod_spambot:0.47`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.6`,
        fs:  `cpe:2.3:a:wayne_allen:postie:1.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.6.1`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.7`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.7.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.8`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.9.1`,
        fs:  `cpe:2.3:o:yahama:rta52i:4.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.9.2`,
        fs:  `cpe:2.3:a:cisco:unity_connection:10.5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.9.3`,
        fs:  `cpe:2.3:a:brocade:san_health_diagnostics_capture:3.1.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.10`,
        fs:  `cpe:2.3:a:debian:apt:0.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.10.1`,
        fs:  `cpe:2.3:a:extplorer:extplorer:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nih:libzip:0.11.2`,
        fs:  `cpe:2.3:a:apple:webobjects:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-1.x:dev`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-15_iw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-2.1`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-2.2`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-2.4`,
        fs:  `cpe:2.3:a:atmail:atmail:6.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-2.5`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-2.x:dev`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-3.3`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.20.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-3.4`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:5.x-3.x:dev`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.717.2343.40629:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-2.0`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.0.471780:*:*:*:netware:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-2.1`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:t28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-2.2`,
        fs:  `cpe:2.3:a:squareup:okhttp3:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-3.0`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-3.0:1`,
        fs:  `cpe:2.3:a:typemoon:fate\/stay_night:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-3.1`,
        fs:  `cpe:2.3:h:huawei:eudemon_usg5300:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-3.2`,
        fs:  `cpe:2.3:o:huawei:p8_firmware:gra-ul10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-3.3`,
        fs:  `cpe:2.3:a:nagios:nagios:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-4.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-4.0:rc1`,
        fs:  `cpe:2.3:h:f5:big-ip_5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-4.0:rc3`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-4.0:rc4`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-4.0:rc5`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-4.0:rc6`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:6.x-4.x:dev`,
        fs:  `cpe:2.3:o:windriver:bsdos:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:7.x-4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:7.x-4.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:distributed_transaction_coordinator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:7.x-4.0:rc2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:7.x-4.0:rc3`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibb_auth:7.x-4.x:dev`,
        fs:  `cpe:2.3:a:roxio:cineplayer:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibboleth_authentication:6.x-4.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibboleth_authentication:6.x-4.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:2.5.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibboleth_authentication:6.x-4.2rc1::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibboleth_authentication:7.x-4.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibboleth_authentication:7.x-4.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.9:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:niif:shibboleth_authentication:7.x-4.2:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nijskens_raf:admintools:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.47.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikhilk:web_development_helper:0.8.5.1`,
        fs:  `cpe:2.3:a:roxio:burn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.0`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.0:rc1`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.0:rc2`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.2`,
        fs:  `cpe:2.3:a:ati:skins:2008.0225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.4`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.6`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.06.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.7`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikias_bassen:usbmuxd:1.0.8`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.0.2`,
        fs:  `cpe:2.3:a:apache:axis:-:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.0.3`,
        fs:  `cpe:2.3:a:job_manager:job_manager:0.7.22:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.0.4`,
        fs:  `cpe:2.3:a:ibm:actuate_encyclopedia_for_ibm_maximo:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.0.5`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:6.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.0.6`,
        fs:  `cpe:2.3:a:s-peek:s-peek_credit_rating_report:2.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.0.7`,
        fs:  `cpe:2.3:a:python:python:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.0.8`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.0.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.1.1`,
        fs:  `cpe:2.3:a:sap:netweaver_business_warehouse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.1.3`,
        fs:  `cpe:2.3:a:apple:apple_tv:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms:1.1.4`,
        fs:  `cpe:2.3:h:dlink:dcs-5300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.0.2:-`,
        fs:  `cpe:2.3:a:gentoo:portage:2.0.51.22:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.0.3:-`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.0.4:-`,
        fs:  `cpe:2.3:a:microsoft:exchange_instant_messenger:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.0.5:-`,
        fs:  `cpe:2.3:a:symantec:netbackup_opscenter:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.0.6:-`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.0.7:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.0.8:-`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.0.9:-`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.4.2:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.1.0:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)bc2i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.1.1:-`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1063.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.1.2:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.2:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.1.3:-`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nikola_posa:webfoliocms1.1.4:-`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ninjaforge:com_ninjaxplorer:1.0.4`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.30:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ninjaforge:com_ninjaxplorer:1.0.5`,
        fs:  `cpe:2.3:a:intermesh:group-office:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ninjaforge:com_ninjaxplorer:1.0.6`,
        fs:  `cpe:2.3:a:ca:threat_manager:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ninjaforge:com_ninjaxplorer:1.0.7`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(26\)p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ninjaforms:ninja_forms:2.8.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:php:php:5.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ninjaforms:ninja_forms:2.8.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows_rt_8.1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ninjaforms:ninja_forms:2.9.42::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ninjakiwi:sas%3a_zombie_assault_3:2.56::~~~android~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.2:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nintex:workflow:2010`,
        fs:  `cpe:2.3:a:redhat:docbook_stylesheets:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nirsoft:smartsniff:1.71`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:0.10`,
        fs:  `cpe:2.3:h:cisco:catalyst_2948g-l3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.00`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:15.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.01`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.1.0`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.2.0`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.2.3`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.3.0`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.3.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.1.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.3.4`,
        fs:  `cpe:2.3:a:microsoft:outlook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.3.5`,
        fs:  `cpe:2.3:a:clamav:clamav:0.75.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.4.0`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.01:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.5.0`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.3\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_news_clipper:2.5.2`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_teachers_schedule_board:1.10`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_teachers_schedule_board:2.00`,
        fs:  `cpe:2.3:a:microsoft:orca:4.5.6001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_teachers_schedule_board:2.10`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_teachers_schedule_board:2.20`,
        fs:  `cpe:2.3:a:vmware:server:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_teachers_schedule_board:2.21`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:2.0.0:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:nishishi:fumy_teachers_schedule_board:2.22`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nist:hipaa_security_rule_toolkit:1.0.0.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nisuta:ns-wir150ne:-`,
        fs:  `cpe:2.3:h:nvidia:nvs_510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nisuta:ns-wir150ne_firmware:5.07.41`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p136:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nisuta:ns-wir300n:-`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nisuta:ns-wir300n_firmware:5.07.36_nis01`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nitropdf:nitro_pdf:6.2.0.44::~~professional~~~`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_internet_server:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nitropdf:nitro_pdf:6.2.1.10::~~professional~~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nliteos:nlite:1.4.9.1`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:0.50`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:0.60`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:0.65`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:0.66`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:0.70`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.0.0`,
        fs:  `cpe:2.3:a:debian:adequate:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.1.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.2.0`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.2.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.2.2`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.3`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.1.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.4.0`,
        fs:  `cpe:2.3:a:gencat:artacces:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.4.1`,
        fs:  `cpe:2.3:a:apple:safari:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.5.1`,
        fs:  `cpe:2.3:a:gnu:gdb:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.0`,
        fs:  `cpe:2.3:a:digium:asterisk:12.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.3`,
        fs:  `cpe:2.3:o:brocade:fabric_os:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.4`,
        fs:  `cpe:2.3:a:perl:perl:5.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.5`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.6`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.8`,
        fs:  `cpe:2.3:a:cmu:cyrus-sasl:1.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.9`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.10:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.10`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:ldns:1.6.11`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.8-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.2`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.3`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.077:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.4`,
        fs:  `cpe:2.3:a:anecms:anecms:2e2c583:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.5`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.21:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.6`,
        fs:  `cpe:2.3:a:janrain:php-openid:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.7`,
        fs:  `cpe:2.3:o:lorextechnology:edge_lh310_firmware:7-35-28-1b26e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.0.8`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.1.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.1.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.1`,
        fs:  `cpe:2.3:a:libav:libav:0.7:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.3`,
        fs:  `cpe:2.3:h:cisco:spa_512g_1-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.4`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.5`,
        fs:  `cpe:2.3:o:hp:thinpro:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.6`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.7`,
        fs:  `cpe:2.3:h:cisco:unity_express:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.8`,
        fs:  `cpe:2.3:o:huawei:s9303_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.9`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.14:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:nsd:3.2.10`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nlnetlabs:unbound:1.5.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nmap:nmap:5.51`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nmedia:member_conversation:1.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nmedia:member_conversation:1.2`,
        fs:  `cpe:2.3:a:php:php:5.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nmedia:member_conversation:1.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nmh:nmh:-`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.8.0:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nmh:nmh:1.0.2`,
        fs:  `cpe:2.3:a:citrix:xenapp_feature_pack_enabler:4.5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nng:naviextras_toolbox_prerequesities:1.0.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:no-margin-for-errors:prettyphoto:3.1.4`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:no-margin-for-errors:prettyphoto:3.1.5`,
        fs:  `cpe:2.3:a:surdoc:surdoc_-_100gb\&#43;_free_storage:1.3.4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:no_magic_inc.:magicdraw_floating_license_server:16.0.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:x5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:abc_lounge_webradio:3.3.10::~~~android~~`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:abram_radio_groove%21:3.2.3::~~~android~~`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:amnesia_groove:3.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:nortel:callpilot_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:asylum%21:3.3.10::~~~android~~`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:fabuestereo_88.1_fm:3.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:house365_radio:3.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:jazz_lovers_radio:3.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:menalto:gallery:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:joint_radio_blues:3.2.3::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:master_mix:3.3.5::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:musica_de_barrios_sonideros:3.3.10::~~~android~~`,
        fs:  `cpe:2.3:o:eucalyptus:eustore:emi_3868652036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:radios_del_ecuador:3.2.4::~~~android~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nobexrc:talk_radio_europe:3.3.10::~~~android~~`,
        fs:  `cpe:2.3:a:apache:hbase:0.92.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_access_product_project:node_access_product:7.x-1.0:rc4:~~~drupal~~`,
        fs:  `cpe:2.3:h:siemens:scalance_x308-2m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc1`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:beta5:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc2`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.8:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc4`,
        fs:  `cpe:2.3:a:google:v8:4.2.77.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc6`,
        fs:  `cpe:2.3:a:vmware:fusion:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:roxio:photoshow:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_invite_project:node_invite:6.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:5.x-1.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.10:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:5.x-1.1-1`,
        fs:  `cpe:2.3:a:mozilla:firefox:15.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:5.x-1.1-2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:5.x-1.1-3`,
        fs:  `cpe:2.3:o:raritan:px:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:5.x-1.4`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:5.x-1.x:dev`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:6.x-1.0`,
        fs:  `cpe:2.3:a:autodesk:raster_design:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:6.x-1.1`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:6.x-1.2`,
        fs:  `cpe:2.3:a:yikyakapp:yik_yak:2.0.002:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:6.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:vmware:gsx_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:6.x-2.0:alpha2`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:6.x-2.0:beta1`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:6.x-2.0:beta2`,
        fs:  `cpe:2.3:h:asus:rt-n65u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_limit_number_project:node_limitnumber:6.x-2.x:dev`,
        fs:  `cpe:2.3:o:juniper:junos:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:node_template_project:node_template:-::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodeauthor_project:nodeauthor:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:maximo_industry_solutions:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.3.3`,
        fs:  `cpe:2.3:a:gnu:emacs:22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.7.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.0`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sxj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.2`,
        fs:  `cpe:2.3:a:opentype_sanitiser_project:opentype_sanitiser:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.3`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.4`,
        fs:  `cpe:2.3:a:microsoft:remote_desktop_connection:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.5`,
        fs:  `cpe:2.3:a:mikejolley:download_monitor:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.6`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.0.45:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.7`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.2.0:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.8`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.9`,
        fs:  `cpe:2.3:o:cisco:ios:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.10`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.11`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.12`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.13`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.14`,
        fs:  `cpe:2.3:a:apache:struts:2.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.15`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.16`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.16-isaacs-manual`,
        fs:  `cpe:2.3:a:crunchify:all-in-on-webmaster:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.17`,
        fs:  `cpe:2.3:a:tibco:spotfire_professional:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.18`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.19`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.20`,
        fs:  `cpe:2.3:a:wayne_allen:postie:1.5.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.21`,
        fs:  `cpe:2.3:a:isc:bind:4.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.22`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.2\(2\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.23`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.24`,
        fs:  `cpe:2.3:a:xnview:xnview:1.91.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.25`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.26`,
        fs:  `cpe:2.3:a:novell:imanager:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.27`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.28`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.29`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.30`,
        fs:  `cpe:2.3:o:cisco:spa_500_series_ip_phone_firmware:7.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.31`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.32`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-6:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.33`,
        fs:  `cpe:2.3:a:zope:zope:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.34`,
        fs:  `cpe:2.3:a:hp:solution_center_and_imaging_support_tools:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.35`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:5100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.36`,
        fs:  `cpe:2.3:a:roxio:creator:10.3.206:*:*:*:enterprise_edition_gold:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.37`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.38`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.2:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.39`,
        fs:  `cpe:2.3:a:x.org:x11:6.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.40`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.12:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.41`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.42`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.43`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.44`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.45`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.10.46`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.6`,
        fs:  `cpe:2.3:a:openssl:openssl:1.1.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.7`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.8`,
        fs:  `cpe:2.3:o:cisco:vpn_3020_concentrator:4.7.2.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.9`,
        fs:  `cpe:2.3:a:project-redcap:redcap:4.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.10`,
        fs:  `cpe:2.3:a:qemu:qemu:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.11`,
        fs:  `cpe:2.3:h:xerox:workcentre_m35:4.84.16.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.12`,
        fs:  `cpe:2.3:a:namazu:namazu:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.13`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.14`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.009.20079:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.15`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.50:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.11.16`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.0`,
        fs:  `cpe:2.3:h:mcdata:sphereon_4500_fabric_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.1`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.3.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.2`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.3`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.4`,
        fs:  `cpe:2.3:a:avactis:avactis_shopping_cart:1.9.0:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.5`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.6`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.7`,
        fs:  `cpe:2.3:a:vips:vips:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.8`,
        fs:  `cpe:2.3:a:spice_project:spice:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.9`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.10`,
        fs:  `cpe:2.3:a:hp:precisionscan_pro:3.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.11`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.12`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.13`,
        fs:  `cpe:2.3:a:google:chrome:13.0.780.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.14`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:0.12.15`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:1.0.4`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.5:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:1.6.2`,
        fs:  `cpe:2.3:a:apache:maven:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:1.8.4`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.0.0`,
        fs:  `cpe:2.3:a:redhat:wu_ftpd:2.6.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.1.0`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.1.1`,
        fs:  `cpe:2.3:a:cisco:ons_15216_optical_add_drop_multiplexer_software:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.1.2`,
        fs:  `cpe:2.3:a:novell:groupwise_messenger:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.2.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.2.1`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.2.2`,
        fs:  `cpe:2.3:a:iss:blackice_agent:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.2.3`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.2.4`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.2.5`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.2.6`,
        fs:  `cpe:2.3:a:drupal:drupal:7.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.4.2`,
        fs:  `cpe:2.3:a:pmb_services:pmb:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.4.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.4.4`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_management_console:10.0.13762:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.4.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.4.6`,
        fs:  `cpe:2.3:a:intel:proset_wireless:14.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.4.7`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.5.0`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.6.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.6.1`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.6.2`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.7.0`,
        fs:  `cpe:2.3:o:google:android:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.7.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_fasttrack:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.7.2`,
        fs:  `cpe:2.3:a:corosync:corosync:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.7.3`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.8.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.8.1`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.8.2`,
        fs:  `cpe:2.3:a:combodo:itop:2.0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.8.3`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:4.8.4`,
        fs:  `cpe:2.3:a:git-scm:git:0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.0.0`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.1.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.1.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.2.0`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.3.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.4.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.4.1`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2014:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.5.0`,
        fs:  `cpe:2.3:a:cisco:mediasense:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.10.0`,
        fs:  `cpe:2.3:a:microsoft:telnet_client:5.1.2600.2180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.10.1`,
        fs:  `cpe:2.3:a:apple:apple_tv:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.11.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.11.1`,
        fs:  `cpe:2.3:a:exim:exim:4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:5.12.0`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.0.0`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.1.0`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:8.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.2.0`,
        fs:  `cpe:2.3:a:cybozu:mailwise:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.2.1`,
        fs:  `cpe:2.3:a:telos:amhs:12.9.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.2.2`,
        fs:  `cpe:2.3:a:sybase:sql_anywhere_documentation:10.0.1.3415:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.3.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.3.1`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.6:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.4.0`,
        fs:  `cpe:2.3:a:apache:cxf:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.5.0`,
        fs:  `cpe:2.3:a:cacti:superlinks:1.4-2:*:*:*:*:cacti:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.6.0`,
        fs:  `cpe:2.3:o:opensuse_project:opensuse:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.7.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.8.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.8.1`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.9.0`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.9.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.9.2`,
        fs:  `cpe:2.3:a:keymetricsoft:foldersizes:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.9.3`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:gm45_gs45_pm45_sinit_21.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.9.4`,
        fs:  `cpe:2.3:a:apache:poi:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.9.5`,
        fs:  `cpe:2.3:a:faz:faz.net:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.10.0`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.10.1`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.10.2`,
        fs:  `cpe:2.3:h:nortel:survivable_remote_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.10.3`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.11.0`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.11.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.11.2`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.11.3`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:9.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:6.11.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.0.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.1.0`,
        fs:  `cpe:2.3:a:open_source_development_team:sthttpd:2.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.2.0`,
        fs:  `cpe:2.3:o:juniper:ive_os:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.2.1`,
        fs:  `cpe:2.3:a:filemaker:filemaker_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.3.0`,
        fs:  `cpe:2.3:h:intel:express_8100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.4.0`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(1\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.6.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.7.0`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.7.1`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.7.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.7.3`,
        fs:  `cpe:2.3:a:sharelatex:sharelatex:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.7.4`,
        fs:  `cpe:2.3:a:tumbleweed:mailgate_email_firewall:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.8.0`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.9.0`,
        fs:  `cpe:2.3:a:datadynamics:activereports:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.10.0`,
        fs:  `cpe:2.3:a:teradata:fastload:12.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:7.10.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.0.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.1.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.1.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.1.2`,
        fs:  `cpe:2.3:a:mcafee:dlp_agent:9.1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.1.3`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3.4:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.1.4`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.0:rc1:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.2.0`,
        fs:  `cpe:2.3:a:iss:blackice_agent_server:3.6ebz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.2.1`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf802a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.3.0`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.4.0`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.10:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.6.0`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.7.0`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.7.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.8.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.8.1`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.9.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.9.1`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.9.2`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.2:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:8.9.3`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:9.0.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:9.1.0`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:9.2.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:9.2.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:node.js:9.3.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.6.16`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.6.17`,
        fs:  `cpe:2.3:a:ca:unicenter_service_fulfillment:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.1`,
        fs:  `cpe:2.3:a:oracle:openjdk:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.2`,
        fs:  `cpe:2.3:a:hp:jc085a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.3`,
        fs:  `cpe:2.3:a:google:v8:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.4`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf804a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.5`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.6`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.0.0.456:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.7`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:0.1.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.7.8`,
        fs:  `cpe:2.3:a:apps2you:cedar_kiosk:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.0`,
        fs:  `cpe:2.3:a:instaroid_-_instagram_viewer_project:instaroid_-_instagram_viewer:1.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.2`,
        fs:  `cpe:2.3:a:hp:centralview_subscription_fraud_prevention:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.3`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.6.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.4`,
        fs:  `cpe:2.3:a:amtelco:misecuremessages:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.5`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.6`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.7`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.8`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.4.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.9`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_for_windows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.10`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.11`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.11.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.12`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.13`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.14`,
        fs:  `cpe:2.3:o:netbsd:netbsd:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.15`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.4:*:linux_ibm_zos:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.16`,
        fs:  `cpe:2.3:a:gnu:automake:1.4:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.17`,
        fs:  `cpe:2.3:a:facebook:news_revolution_-_bahrain:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.18`,
        fs:  `cpe:2.3:a:shopware:shopware:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.19`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.5.0.489:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.20`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.9.00:*:*:*:*:aix:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.21`,
        fs:  `cpe:2.3:a:idevspot:autohost:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.22`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.23`,
        fs:  `cpe:2.3:a:siemens:simotion_scout:4.3:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.24`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.25`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.26`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.8.27`,
        fs:  `cpe:2.3:a:gajim:gajim:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.0`,
        fs:  `cpe:2.3:a:become:becomebot:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.1`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.0.1810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.2`,
        fs:  `cpe:2.3:a:digium:asterisk:12.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.3`,
        fs:  `cpe:2.3:a:microsoft:service_bus:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.4`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.5t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.6`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.7`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.8`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.9`,
        fs:  `cpe:2.3:a:vmware:server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.10`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.11`,
        fs:  `cpe:2.3:h:lexmark:cx825dte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.12`,
        fs:  `cpe:2.3:a:bundler:bundler:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.13`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.14`,
        fs:  `cpe:2.3:a:ipswitch:imail:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.16`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.17`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.18`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.19`,
        fs:  `cpe:2.3:a:social_stats_project:social_stats:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.20`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre.10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.21`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.22`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.23`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.24`,
        fs:  `cpe:2.3:a:google:chrome:17.0.924.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.25`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.26`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.461:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.27`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.16-64.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.28`,
        fs:  `cpe:2.3:a:netscout:sniffer_analysis:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodejs:nodejs:0.10.29`,
        fs:  `cpe:2.3:a:php:php:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:4.7-1.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:4.7-1.1`,
        fs:  `cpe:2.3:a:google:chrome:15.0.860.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:4.7-1.2`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:7.0.5730:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:4.7-1.x:dev`,
        fs:  `cpe:2.3:a:iss:blackice_agent:3.1eal:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.2`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.3`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.4`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.5`,
        fs:  `cpe:2.3:a:aol:aolserver:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.7`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.8`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110803:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.8:rc1`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.9`,
        fs:  `cpe:2.3:a:microsoft:onenote:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.10`,
        fs:  `cpe:2.3:h:avaya:definity_one_media_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.11`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.12`,
        fs:  `cpe:2.3:h:cisco:ips_4270:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.13`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:5.x-1.x:dev`,
        fs:  `cpe:2.3:a:roads365:www.roads365.com:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp2:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.3`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.3:alpha1`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.3:alpha2`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.2.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.3:beta3`,
        fs:  `cpe:2.3:h:cisco:nexus_3048:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.3:beta4`,
        fs:  `cpe:2.3:a:php:php:5.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.3:beta5`,
        fs:  `cpe:2.3:a:fortinet:forticlient_lite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.4`,
        fs:  `cpe:2.3:a:bea:tuxedo:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.5`,
        fs:  `cpe:2.3:a:apple:itunes:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.6`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1041:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.7`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.8`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.9`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.10`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p359:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta1`,
        fs:  `cpe:2.3:h:hp:0235a0a7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta3`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta4`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta5`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta6`,
        fs:  `cpe:2.3:a:websitesrus:accessories_me_php_affiliate_script:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta7`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta8`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:beta9`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.12:rc1`,
        fs:  `cpe:2.3:a:gtk:gtk\&#43;:3.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.13`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.13:rc1`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_bell:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.13:rc2`,
        fs:  `cpe:2.3:a:digia:qt:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.14:beta1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.14:beta2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2011.728.1722.29300:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nodewords_project:nodewords:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:3210:-`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nokia:6210_handset:-`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:6310i:-`,
        fs:  `cpe:2.3:a:apple:safari:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:7610:-`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:9500:-`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2_1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:2.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:2.0.1`,
        fs:  `cpe:2.3:h:polycom:soundpoint_ip_650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:2.0.2`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.2.173:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:2.1`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.11-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:2.1.1`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:2.1.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:2.3.0`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:3.0`,
        fs:  `cpe:2.3:a:gnu:zlib:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:3.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:affix:3.2.0`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:electronic_documentation:-`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:ggsn:-`,
        fs:  `cpe:2.3:a:threedify:threedify_designer:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:groupwise_mobile_server:-`,
        fs:  `cpe:2.3:a:ibm:eclipse_help_system:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:intellisync_mobile_suite:-`,
        fs:  `cpe:2.3:a:polycom:rmx_system_software:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:intellisync_wireless_email_express:-`,
        fs:  `cpe:2.3:a:microsoft:asp.net_signalr:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nokia:ip440_firewall_vpn_appliance:-`,
        fs:  `cpe:2.3:a:apple:itunes:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nokia:ipso:-`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nokia:ipso:3.7`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_sametime:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nokia:n70:-`,
        fs:  `cpe:2.3:a:apache:flex:4.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nokia:n95:-`,
        fs:  `cpe:2.3:o:novell:netware:6.5:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nokia:n95:12.0.0.013`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nokia:n95:12.0.013`,
        fs:  `cpe:2.3:a:adobe:jabber:5.2.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:pc_suite:7.1.180.64`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.0.0.3:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:0.9.1:beta`,
        fs:  `cpe:2.3:h:ampedwireless:r10000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:0.9.2:rc1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.0.0`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.1.0`,
        fs:  `cpe:2.3:a:microsoft:expression_design:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.1.0:rc1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.2.0`,
        fs:  `cpe:2.3:h:linksys:wrt54gc:1.00.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.2.90`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.3.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.3.0:beta`,
        fs:  `cpe:2.3:a:apple:xcode:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.3.0:rc1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:1.3.1`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:2.0.0`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.71\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:2.0.0:alpha`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:2.0.0:beta`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:2.0.0:rc1`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qt_creator:2.0.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:qtdemobrowser:-`,
        fs:  `cpe:2.3:a:agilefleet:fleetcommander_kiosk:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:sgsn_dx200:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nokia:symbian_os:-`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia:symbian_s60_browser:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nokia_maps_%26_places_project:nokia_maps_%26_places:1.6.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nomachine:5.3.9`,
        fs:  `cpe:2.3:a:ibm:soliddb:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:1.5.0:beta2`,
        fs:  `cpe:2.3:a:monotone:monotone:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:1.5.0:beta3`,
        fs:  `cpe:2.3:a:cisco:jabber:10.6\(2\):*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:2.0.0-1`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:2.1.0-1`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.0.0-1`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.0.0-2`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.0.0-3`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.009.20077:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.0.0-4`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.0.0-5`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.1.0-1`,
        fs:  `cpe:2.3:h:f5:viprion_performance_blade_200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.2.0-1`,
        fs:  `cpe:2.3:o:sun:sunos:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.3.0-1`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.3.0-2`,
        fs:  `cpe:2.3:a:hp:product_assistant:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.4.0-1`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.13:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.4.0-2`,
        fs:  `cpe:2.3:o:cisco:catos:4.3\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.4.0-3`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.5.0-1`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nomachine:nx_web_companion:3.5.0-2`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nonghyup:smart:3.0.5::~~~android~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.25.622:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nonghyup:smart_calculator:2.0::~~~android~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p370:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nonghyup:smart_card:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nonghyup:smart_nhibzbanking:2.1::~~~android~~`,
        fs:  `cpe:2.3:o:yamaha:rta54i:4.03.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.0.0`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.0.1`,
        fs:  `cpe:2.3:a:gnu:gzip:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.2.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.2.1`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_for_oracle_administration:10.1.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.2.2`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.4.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.4.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.4.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.07.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.4.3`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.4.4`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.4.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.19:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.4.6`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.6.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.6.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.6.2`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:9.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.6.3`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.6.4`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.8.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.8.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.8.2`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.10.0`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.10.1`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.10.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.10.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.10.4`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.10.5`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.12.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.12.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.12.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.12.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(3\)n2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.12.4`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.12.5`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:1.12.6`,
        fs:  `cpe:2.3:a:canonical:telepathy-idle:0.1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:2.0.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:2.0.1`,
        fs:  `cpe:2.3:h:hp:0235a20v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:2.0.2`,
        fs:  `cpe:2.3:h:apple:airport_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:2.2.0`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:2.4.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nongnu:oath_toolkit:2.4.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:noodlecake:super_stickman_golf:2.2::~~~android~~`,
        fs:  `cpe:2.3:a:hp:creativeprojects_plsbusinessflyers:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.22`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1682.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.23`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.11.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.24`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:alpha4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.25`,
        fs:  `cpe:2.3:a:sap:trex:7.10:revision_63:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.26`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.27`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.28`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.29`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.30`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.31`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.32`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.33`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.34`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.35`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.1:preview1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.36`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(2\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.37`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.38`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.39`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.3.40`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.9.9p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.4.0`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.4.1`,
        fs:  `cpe:2.3:a:tenable:web_ui:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xm4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.4.3`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.4.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.4.5`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.0`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.1`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:17.2.0.59184:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.4`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.5`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:7.x-1.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.6`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.7`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.5:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.8`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.9`,
        fs:  `cpe:2.3:h:ibm:power_5:9111-285:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.10`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.11`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.12`,
        fs:  `cpe:2.3:a:david_king:vino:2.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.13`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.4.0:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.14`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.15`,
        fs:  `cpe:2.3:a:webform_invitation_project:webform_invitation:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.16`,
        fs:  `cpe:2.3:a:huge-it:huge-it_catalog:1.0.7:*:*:*:*:joomla:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.17`,
        fs:  `cpe:2.3:h:htc:evo_3d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.18`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.359:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.19`,
        fs:  `cpe:2.3:a:vmware:vcloud_director:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.20`,
        fs:  `cpe:2.3:a:emc:rsa_identity_management_and_governance:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.21`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.22`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.2.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.23`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.25`,
        fs:  `cpe:2.3:a:knowledgetree:knowledgetree:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.26`,
        fs:  `cpe:2.3:a:tag1consulting:support_timer:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.27`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.28`,
        fs:  `cpe:2.3:a:roxio:creator_de:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.29`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.30`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.31`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.32`,
        fs:  `cpe:2.3:a:ca:etrust_security_command_center:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.33`,
        fs:  `cpe:2.3:a:microsoft:excel:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.34`,
        fs:  `cpe:2.3:a:apache:cxf:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.35`,
        fs:  `cpe:2.3:a:htc:hero_software:2.32.651.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.36`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.37`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.38`,
        fs:  `cpe:2.3:a:cisco:socialminer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.39`,
        fs:  `cpe:2.3:h:fortinet:fortianalyzer-1000d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.40`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.2014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.41`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a4\(2.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.42`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.43`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.44`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.45`,
        fs:  `cpe:2.3:a:viewvc:viewvc:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.46`,
        fs:  `cpe:2.3:a:mozilla:firefox:49.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.47`,
        fs:  `cpe:2.3:a:yahoo:widgets:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.48`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.49`,
        fs:  `cpe:2.3:o:huawei:s7706_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.50`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.51`,
        fs:  `cpe:2.3:a:x:libxxf86vm:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.52`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.15:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.53`,
        fs:  `cpe:2.3:h:juniper:fips_secure_access_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.54`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.6.8\(4222\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.55`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.56`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.57`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.5.58`,
        fs:  `cpe:2.3:a:microsoft:system_center_operations_manager:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.6.0`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:9.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.6.2`,
        fs:  `cpe:2.3:a:tincan:phplist:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.6.3`,
        fs:  `cpe:2.3:a:cubecart:cubecart:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.6.4`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.6.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.8.1`,
        fs:  `cpe:2.3:a:vmware:workstation:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.8.1.1`,
        fs:  `cpe:2.3:a:rack_project:rack:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.8.1.1-1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.8.1.1-2`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.8.2`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.8.2.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nordugrid:nordugrid-arc:0.8.2.2`,
        fs:  `cpe:2.3:o:iodata:hdl2-a_firmware:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:norman:norman_antivirus_%26_antispyware:6.06.12`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:norman:security_suite:8.0::pro`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:norman:security_suite:10.0`,
        fs:  `cpe:2.3:a:macromedia:shockwave_flash_plugin:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:norman:security_suite:10.1`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:11c:-`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:51c:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2011.707.2315.39839:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:61c:-`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:7220_wlan_access_point:-`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0epk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:7250_wlan_access_point:-`,
        fs:  `cpe:2.3:a:moodle:moodle:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:802.11_wireless_ip_gateway:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:81c:-`,
        fs:  `cpe:2.3:a:oracle:oracle_database_express_edition:10.2.1015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:alteon_2424_application_switch:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p197:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:alteon_acedirector:-`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:alteon_acedirector:9.0`,
        fs:  `cpe:2.3:a:phpkit:phpkit:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:business_communications_manager:-`,
        fs:  `cpe:2.3:a:cisco:firepower_threat_defense:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:callpilot:-`,
        fs:  `cpe:2.3:o:yamaha:rt56v:4.07.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:callpilot_server:-`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:centrex_ip_client_manager:-`,
        fs:  `cpe:2.3:a:shopware:shopware:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:centrex_ip_element_manager:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:communications_server:-`,
        fs:  `cpe:2.3:a:embedthis:goahead:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:contact_center:-`,
        fs:  `cpe:2.3:a:gnu:readline:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:contivity:-`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:contivity:1.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:cs1000e:-`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:cs1000m:-`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:cs1000s:-`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:cvx_1800_multi-service_access_switch:-`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ethernet_routing_switch_1612:-`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ethernet_routing_switch_1624:-`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ethernet_routing_switch_1648:-`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:helmsman:4.2.1`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:3.60.0128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:helmsman:4.4.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_audio_conference_phone_2033:-`,
        fs:  `cpe:2.3:a:ipswitch:imail:8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_phone_1110:-`,
        fs:  `cpe:2.3:a:google:chrome:4.0.264.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_phone_1120e:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_phone_1140e:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_phone_1150e:-`,
        fs:  `cpe:2.3:a:ntop:ntopng:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_phone_2001:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20101112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_phone_2002:-`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_phone_2004:-`,
        fs:  `cpe:2.3:h:supermicro:x9qr7-tf-jbod:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ip_phone_2007:-`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:ip_softphone_2050:-`,
        fs:  `cpe:2.3:a:novell:edirectory:85.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:media_communication_server_5100:3.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:media_communication_server_5200:3.0`,
        fs:  `cpe:2.3:a:snort:snort:2.7_beta1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:media_processing_server:-`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:meridian_mail:-`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:meridian_option_11c:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.0.584:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:meridian_option_51c:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:meridian_option_61c:-`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:meridian_option_81c:-`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_l32e_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:meridian_option_core_card:-`,
        fs:  `cpe:2.3:a:redhat:mcstrans:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:meridian_sl100:-`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:mobile_voice_client_2050:-`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:multimedia_communication_server_5100:-`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:multimedia_communication_server_5100:3.0.13`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:multimedia_communication_server_5200:-`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:nautica_marlin:-`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:net_direct_client:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je107a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:net_direct_client:6.0.4`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:optical_metro:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:optical_metro_5000:-`,
        fs:  `cpe:2.3:a:trendmicro:internet_security:2010:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:optical_metro_5100:-`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:optical_metro_5200:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.9:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:optivity_net_architect:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.619:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:optivity_telephony_manager:-`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:passport_8000:-`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:pc_client_soft_phone_sip:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg374a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:periphonics:-`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:preside_site_manager:1.0.0.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1680.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:sip_softphone:-`,
        fs:  `cpe:2.3:a:zend:zendopenid:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:ssl_vpn:-`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:ssl_vpn_module_1000:-`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:succession_communication_server_1000:-`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.7f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:succession_communication_server_2000:-`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:survivable_remote_gateway:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:survivable_remote_gateway:1.0`,
        fs:  `cpe:2.3:a:apple:apple_tv:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:switched_firewall_5000:-`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:switched_firewall_5100:-`,
        fs:  `cpe:2.3:a:ni:labwindows:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:switched_firewall_6000:-`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:symposium_agent:-`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.2.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:symposium_call_center_server:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:symposium_express_call_center:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:symposium_network_control_center:-`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.4.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:symposium_tapi_service_provider:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:symposium_web_centre_portal:-`,
        fs:  `cpe:2.3:a:oracle:hyperion_sqr_server_for_oracle:8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nortel:symposium_web_client:-`,
        fs:  `cpe:2.3:a:ibm:java:6.0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:universal_signaling_point:-`,
        fs:  `cpe:2.3:h:huawei:ar160:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_gateway_3050:-`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_gateway_3070:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_1010:-`,
        fs:  `cpe:2.3:a:justsystems:atok_smile:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_1050:-`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:313.00:-:*:*:sunos:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_1100:-`,
        fs:  `cpe:2.3:a:bonitasoft:bonita_bpm_portal:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_1700:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_1740:-`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12:beta16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_1750:-`,
        fs:  `cpe:2.3:a:apple:remote_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_2700:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_5000:-`,
        fs:  `cpe:2.3:a:google:chrome:14.0.819.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_600:-`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.43.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:vpn_router_portfolio:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:wlan_access_point_2220:-`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.0:build110510:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:wlan_access_point_2221:-`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:wlan_access_point_2225:-`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:wlan_handset_2210:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.102.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:wlan_handset_2211:-`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:wlan_handset_2212:-`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-09-25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:wlan_handset_6120:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:hu:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nortel:wlan_handset_6140:-`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:8.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:northropgrumman:ecgs:3.3.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:northropgrumman:fileversion:3.3.0`,
        fs:  `cpe:2.3:a:isc:dhcp_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:northropgrumman:mailroom:3.3.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nos:nos_alive:5.1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nosltd:getplus_for_adobe:1.5.2.35`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:not_yet_commons_ssl_project:not_yet_commons_ssl:0.3.14`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:not_yet_commons_ssl_project:not_yet_commons_ssl:0.3.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.5`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.6.2`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.0.3.1464:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.6.8`,
        fs:  `cpe:2.3:a:libav:libav:0.8:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.7`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.8.2`,
        fs:  `cpe:2.3:a:apache:wicket:6.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.8.4`,
        fs:  `cpe:2.3:a:atlassian:jira:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.8.5`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.153.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.8.6`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.8.7`,
        fs:  `cpe:2.3:a:ibm:db2:9.5:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.9`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.9.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.9.3`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.9.4`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.9.5`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.531:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notepad_plus_plus:notepad%2b%2b:5.9.6.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:notredame:notredame_seguradora:1.2::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nova921:nova_92.1_fm:1::~~~android~~`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.13:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:novaboard:novaboard:1.0.6`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novaboard:novaboard:1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.604.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novaboard:novaboard:1.1.1`,
        fs:  `cpe:2.3:o:ibm:aix:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novaboard:novaboard:1.1.2`,
        fs:  `cpe:2.3:a:google:v8:3.23.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novaboard:novaboard:1.1.3`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novaboard:novaboard:1.1.4`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novaces:concerto_web:5.8`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:5.5.062.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novarm:diptrace:2.1`,
        fs:  `cpe:2.3:h:hp:serialusb_thermal_receipt_printer_bm476aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:novatech:orion5_dnp_master:1.27.38`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:novatech:orion5_dnp_slave:1.23.10`,
        fs:  `cpe:2.3:a:cisco:business_edition_5000_software:8.6\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:novatech:orion5r_dnp_master:1.27.38`,
        fs:  `cpe:2.3:a:webmin:usermin:1.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:novatech:orion5r_dnp_slave:1.23.10`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:9.0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:novatech:orionlx_dnp_master:1.27.38`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:novatech:orionlx_dnp_slave:1.23.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novatel:installvc90support:1.1.0`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:6.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:access_manager:-`,
        fs:  `cpe:2.3:a:emc:retrospect:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:access_manager:3`,
        fs:  `cpe:2.3:a:conky:conky:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:access_manager_identity_server:-`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.1:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:access_manager_identity_server:3`,
        fs:  `cpe:2.3:o:cisco:catos:7.6\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:bordermanager:-`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.abstractions:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:bordermanager:3.0`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:bordermanager:3.5`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:bordermanager:3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.1m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:bordermanager:3.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ya7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.13:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:2.0:sp2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:2.0:sp3`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:2012.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:3.1`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.8`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.9`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.83:sp3`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.5f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.91`,
        fs:  `cpe:2.3:a:samba:samba:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.91:sp1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.91:sp2`,
        fs:  `cpe:2.3:a:redhat:daredevil_skk:11.6.0-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.91:sp3`,
        fs:  `cpe:2.3:a:canon:captureperfect:3.0.8209.309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.91:sp4`,
        fs:  `cpe:2.3:o:scientificlinux:scientificlinux:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client:4.91:sp5`,
        fs:  `cpe:2.3:h:hp:0235a297:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client_firewall:-`,
        fs:  `cpe:2.3:a:autodesk:dwg_trueview:17.1.65.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:client_login_extension_%28cle%29:-`,
        fs:  `cpe:2.3:a:websvn:websvn:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:data_synchronizer:1.0.0`,
        fs:  `cpe:2.3:h:lexmark:cx725dhe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:data_synchronizer:1.1.0`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:data_synchronizer:1.1.1`,
        fs:  `cpe:2.3:a:hp:operations_manager:9.21:*:*:*:*:solaris:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:-`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:beta_6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.0`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.5`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-28c-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.5.12a`,
        fs:  `cpe:2.3:h:hp:laserjet_4100_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.5.27`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.6.2`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.1:sp1`,
        fs:  `cpe:2.3:a:apple:itunes:4.2.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp1:windows`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.317:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp2:windows`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.04:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp3:windows`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp4:windows`,
        fs:  `cpe:2.3:a:microsoft:iis:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp5:windows`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp6:windows`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp7:windows`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp8:windows`,
        fs:  `cpe:2.3:a:redaxo:redaxo:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3:sp9:windows`,
        fs:  `cpe:2.3:a:citrix:provisioning_services:5.6:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.7.3.8`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.8`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.8:sp2:windows`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.8:sp8`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:8.8.1`,
        fs:  `cpe:2.3:a:git-scm:git:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:85.20`,
        fs:  `cpe:2.3:a:ibm:flex_system_manager:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:85.24`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:edirectory:85.30`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.5:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:emframe:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:emframe:1.2.1`,
        fs:  `cpe:2.3:a:gemalto:pc-ccid:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:extend_director:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:extend_director:4.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.33:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:file_reporter:1.0.2`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:filr:1.2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:filr:1.2:security_update_2`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.2.13p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:filr:2.0:security_update_1`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r39:*:*:*:*:chrome_os:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:-`,
        fs:  `cpe:2.3:h:emerson:gxt4-2000rt120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:5.2`,
        fs:  `cpe:2.3:a:digium:asterisk:13.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:5.5`,
        fs:  `cpe:2.3:a:isc:bind:9.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:5.57e`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.0.1:sp1`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5:sp1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.2\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5:sp2`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5:sp3`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5:sp4`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5:sp5`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.18.309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5:sp6`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5.2`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5.3`,
        fs:  `cpe:2.3:a:basercms:basercms:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5.6`,
        fs:  `cpe:2.3:a:wave:wave_infrastructure_installer:7.1.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:6.5.7`,
        fs:  `cpe:2.3:a:last.fm_rotation_plugin_project:lastfm-rotation_plugin:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.0`,
        fs:  `cpe:2.3:a:citrix:delivery_services_console_legacy_tools:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.0.3:hp4`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.0.3:hp5`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.0.4`,
        fs:  `cpe:2.3:a:libraw:libraw:0.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.0.4:ftf`,
        fs:  `cpe:2.3:a:dadabik:dadabik:2.1b:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.01`,
        fs:  `cpe:2.3:a:isc:bind:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.01:ir1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.02`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.02:hp1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.466.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.02:hp1a`,
        fs:  `cpe:2.3:a:acquia:commons:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.02:hp2`,
        fs:  `cpe:2.3:a:rrdtool_project:rrdtool:1.4.7:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.02:hp2r1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.03`,
        fs:  `cpe:2.3:a:drupal:drupal:6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.03:hp`,
        fs:  `cpe:2.3:a:pocketmags:skin\&amp;ink_magazine:\@7f08017a:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.03:hp2`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.03:hp3`,
        fs:  `cpe:2.3:a:perl:perl:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:7.03:hp3%2bftf`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.0`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.00:hp1`,
        fs:  `cpe:2.3:o:microsoft:windows_98:beta:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.00:hp2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.00:hp3`,
        fs:  `cpe:2.3:a:file_project:file:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.01`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.06.4324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.01:hp`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.02`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.02:hp1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.02:hp2`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.02:hp3`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.03`,
        fs:  `cpe:2.3:a:tenable:nessus:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.03:hp1`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.03:hp2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:8.03:hp3`,
        fs:  `cpe:2.3:o:huawei:s6300ei_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:2012`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:2012:sp1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:2012:sp1_hp1`,
        fs:  `cpe:2.3:a:cdotech:edcl_server_monitoring:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:2012:sp2`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:2012:sp3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.97.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:2014`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.17:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise:2014:sp1`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_enhancement_pack:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppetlabs-rabbitmq:4.0.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_messenger:-`,
        fs:  `cpe:2.3:a:mislav_marohnic:will_paginate:3.0.4:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_messenger:1.0.6`,
        fs:  `cpe:2.3:a:emc:documentum_eroom:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_messenger:2.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_messenger:2.0.2`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_webaccess:-`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_webaccess:5.5`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_webaccess:6.5`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:groupwise_webaccess:7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:gtk%23_for_.net:2.12.10`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:http_server:-`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:ichain:-`,
        fs:  `cpe:2.3:a:ipswitch:moveit_dmz:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:ichain:2.1`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:ichain:2.2`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:ichain:2.3`,
        fs:  `cpe:2.3:o:cisco:vpn_5000_concentrator_series_software:6.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:identity_manager:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:identity_manager:3.0.1`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:identity_manager:3.5`,
        fs:  `cpe:2.3:a:sun:grid_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:identity_manager:3.5.1`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:identity_manager:4.0.2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.06:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:-`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:1.5`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.0.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.5`,
        fs:  `cpe:2.3:a:arcanadev:sql_server_for_adtempus:1.00.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7`,
        fs:  `cpe:2.3:a:adobe:livecycle_form_manager:7.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7:refresh6`,
        fs:  `cpe:2.3:a:corel:wordperfect:13.0.0.565:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7:sp4`,
        fs:  `cpe:2.3:a:diafan:diafan.cms:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7:sp4_patch1`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.769.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7:sp4_patch2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7:sp4_patch3`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d210:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7:sp4_patch4`,
        fs:  `cpe:2.3:a:solarwinds:orion_ip_address_manager:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7:sp5`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7:sp6`,
        fs:  `cpe:2.3:h:ibm:integrated_management_module_ii:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7.1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7.3`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7.3:ftf2`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7.3:ftf4`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:7.0.2.38b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7.3:sp3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7.4`,
        fs:  `cpe:2.3:a:microsoft:frontpage:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imanager:2.7.5`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imonitor:-`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:imonitor:2.4`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:9.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:internet_messaging_system:-`,
        fs:  `cpe:2.3:h:dell:latitude_d830:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:internet_messaging_system:2.6`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:internet_messaging_system:3.0`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:-`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:4.26`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:4.27`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:4.28`,
        fs:  `cpe:2.3:h:d-link:dcs-2136l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:4.30`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:4.32`,
        fs:  `cpe:2.3:a:macromedia:flashpaper:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:4.34`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:4.36`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:4.38`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2010:14.0.903.64:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.04`,
        fs:  `cpe:2.3:a:apache:roller:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.12`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.20b`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.0:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.30`,
        fs:  `cpe:2.3:a:condor_project:condor:7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.32`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.06.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.40`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.42`,
        fs:  `cpe:2.3:a:apache:subversion:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.44`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.50`,
        fs:  `cpe:2.3:a:microsoft:orca:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.52`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.56`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.60`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.64`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.68`,
        fs:  `cpe:2.3:a:horde:groupware:5.1.4:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.72`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.413:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.74`,
        fs:  `cpe:2.3:a:thoughtworks-studios:mingle:3.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.78`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.01.246:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.82`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.86`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.90:-:~~~windows_7~~`,
        fs:  `cpe:2.3:a:namazu:namazu:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.90:-:~~~windows_8~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.90:-:~~~windows_vista~~`,
        fs:  `cpe:2.3:a:opsview:opsview:4.4:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:iprint:5.90:-:~~~windows_xp~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:kanaka:2.7:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:kanaka:2.7.1:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p209:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:kanaka:2.8:-:~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.11:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:leap:42.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.1.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:leap:42.1`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:libzypp:11.2`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:libzypp:11.3`,
        fs:  `cpe:2.3:a:apache:wink:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:libzypp:11.4`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:libzypp:12.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:libzypp:12.2`,
        fs:  `cpe:2.3:a:git-scm:git:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:libzypp:12.3`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:libzypp:12.15.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:linux_desktop:-`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:linux_desktop:9`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management:11.0:*:*:*:collaborative:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:mobility_pack:1.1`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:mobility_pack:1.1.1`,
        fs:  `cpe:2.3:a:aol:aim:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:mobility_pack:1.1.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p225:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:modular_authentication_service:-`,
        fs:  `cpe:2.3:a:netscape:navigator:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:modular_authentication_service:3.1.2`,
        fs:  `cpe:2.3:a:gnome:tomboy:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:-`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.0.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.0.3a`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.0.3b`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.5`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.5.2`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.5.2a`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:4.0.2:002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.5.2b`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.5.2c`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.5.2c1`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp5:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.5.2d`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.5.2e`,
        fs:  `cpe:2.3:a:sun:jre:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.10`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.02.4115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.10a`,
        fs:  `cpe:2.3:a:opera:opera_browser:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.10b`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.10c`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.10d`,
        fs:  `cpe:2.3:h:hp:sn6000_stackable_8gb_24-port_dual_power_fibre_channel_switch:aw576a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.10e`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.10f`,
        fs:  `cpe:2.3:a:sybase:powerdesigner_repository_proxy_:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.10h`,
        fs:  `cpe:2.3:a:realvnc:realvnc:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.52`,
        fs:  `cpe:2.3:a:macromedia:flash:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.52a`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.52b`,
        fs:  `cpe:2.3:a:ipswitch:imail_server:8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.52c`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.52c1`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.52d`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail:3.52e`,
        fs:  `cpe:2.3:a:yahoo:yui:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail_xe:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update2:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netmail_xe:3.1`,
        fs:  `cpe:2.3:o:cisco:headend_system_release:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:3.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:3.12`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.25:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:4.0`,
        fs:  `cpe:2.3:a:hexagon:erdas_er_viewer:13.00.0001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:4.01`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:4.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:4.11`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:5.0`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware:5.1`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:5.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)ja1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:5.1:sp4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:5.1:sp6`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware:6.0`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.0`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_design_premium:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5`,
        fs:  `cpe:2.3:a:oracle:clinical:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5:sp1`,
        fs:  `cpe:2.3:a:google:v8:3.30.33.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5:sp2`,
        fs:  `cpe:2.3:a:apache:struts:2.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5:sp3`,
        fs:  `cpe:2.3:a:canon:imagerunner_6870:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5:sp4`,
        fs:  `cpe:2.3:o:cisco:catos:2.4\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5:sp5`,
        fs:  `cpe:2.3:a:ibm:systems_director:6.3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5:sp6`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5:sp7`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:netware:6.5:sp8`,
        fs:  `cpe:2.3:a:digium:asterisk:c.1.8.1:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:-`,
        fs:  `cpe:2.3:h:cisco:nexus_2248tp_e_fex_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:4.80`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:4.81`,
        fs:  `cpe:2.3:a:google:chrome:4.0.223.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:4.82`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:4.83`,
        fs:  `cpe:2.3:h:perle:iolan\&#43;_serial_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:4.91`,
        fs:  `cpe:2.3:a:opnet:modeler:16.1.0.10834:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:4.91:sp1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:4.91:sp2`,
        fs:  `cpe:2.3:a:ibm:aix_parallel_systems_support_programs:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_client:4.91:sp4`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_enterprise_web_server:-`,
        fs:  `cpe:2.3:a:php:php:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_ftp_server:-`,
        fs:  `cpe:2.3:a:horde:groupware:1.0.7:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_ftp_server:5.06.05`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:11.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:netware_ftp_server:5.07`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)s8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:nsure_audit:-`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:nsure_audit:1.0.1`,
        fs:  `cpe:2.3:h:huawei:te50:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:open_enterprise:9::server`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:-`,
        fs:  `cpe:2.3:a:aphpkb:aphpkb:0.95.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:1`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1.3:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:1.x`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2007:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:2`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:2.0.1:sp1`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:2.0.2:sp2`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:2.0.3:sp3`,
        fs:  `cpe:2.3:a:webmin:usermin:1.230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:9.0`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:11.0:sp1:~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:adobe:flash:8.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:open_enterprise_server:11.0:sp2:~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.49.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:-`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:10.2`,
        fs:  `cpe:2.3:a:freebsd:libarchive:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:10.3`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:11.0`,
        fs:  `cpe:2.3:a:netgenius:multilink:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:11.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:11.2`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:11.3`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:11.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:12.1`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_9.0_firmware:9.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:12.2`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:12.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.18a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:13.1`,
        fs:  `cpe:2.3:a:boost:boost:1.44.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:opensuse:13.2`,
        fs:  `cpe:2.3:a:gnome:evolution:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.6.2:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.5`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.7`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.7.0`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.7.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.7.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.7.4`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.7.5`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.3.1:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.7.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.7.7`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.9.90`,
        fs:  `cpe:2.3:a:digium:asterisk:10.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.9.91`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:1.9.92`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.0`,
        fs:  `cpe:2.3:a:hp:openview_agent_extension_for_configuration_and_discovery:2.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.1`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:11.17.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.5`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.6`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:6.0:u1b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.7`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.8`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.11.444:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.16`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.103`,
        fs:  `cpe:2.3:a:jenkins:git:0.8.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.104`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.0.106`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_icons_for_huawei:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1`,
        fs:  `cpe:2.3:a:percipientstudios:imagen:2.5.7:-:*:*:*:umbraco_cms:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.2`,
        fs:  `cpe:2.3:a:adobe:photodeluxe:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.3`,
        fs:  `cpe:2.3:a:google:talk_plugin:2.1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.4`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.5`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.5.1`,
        fs:  `cpe:2.3:a:libssh:libssh:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_build_service:2.1.7`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2016:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_swamp:-`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:opensuse_swamp_workflow_administration_management:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:securelogin:-`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-28c-ei-dc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:securelogin:6:sp1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:sentinel_log_manager:1.0.0.4`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:sentinel_log_manager:1.0.0.5`,
        fs:  `cpe:2.3:o:siemens:scalance_x-200_series_firmware:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:sentinel_log_manager:1.1.0.0`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:sentinel_log_manager:1.1.0.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:sentinel_log_manager:1.1.0.2`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:sentinel_log_manager:1.2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1305.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:sentinel_log_manager:1.2.0.1`,
        fs:  `cpe:2.3:a:symantec:workspace_streaming:6.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:sentinel_log_manager:1.2.0.2`,
        fs:  `cpe:2.3:a:exim:exim:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:service_desk:7.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:small_business_suite:-`,
        fs:  `cpe:2.3:h:hp:cf081a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:small_business_suite:5.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:3.6.7.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:small_business_suite:6.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_audit_log_keeper:0.2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.271:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_audit_log_keeper:0.2.1-0.4.6.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_cloud:1.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_lifecycle_management_server:1.0`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_lifecycle_management_server:1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_lifecycle_management_server:1.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.11:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_lifecycle_management_server:1.3`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_lifecycle_management_server:1.3.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p148:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:1.0::desktop`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:9::server`,
        fs:  `cpe:2.3:a:canonical:lxcfs:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:9.3::pro`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:10::desktop`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)fy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:10::server`,
        fs:  `cpe:2.3:a:ibm:thinkvantage_tpm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:10.0`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:10.1`,
        fs:  `cpe:2.3:a:hp:scan:140.0.167.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:11::desktop`,
        fs:  `cpe:2.3:h:dell:precision_m2400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:11::server`,
        fs:  `cpe:2.3:a:ca:etrust_intrusion_detection:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:11:sp1:desktop`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux:11:sp1:server`,
        fs:  `cpe:2.3:a:hp:hppscanto:0.105.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_desktop:11.0:sp2`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ebh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_desktop:11.0:sp3`,
        fs:  `cpe:2.3:h:huawei:s9300:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_desktop:12.0`,
        fs:  `cpe:2.3:a:isc:kea:1.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_module_for_legacy_software:12`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_server:11.0:sp2:~~~vmware~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.51:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_server:11.0:sp2:~~ltss~~~`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_server:11.0:sp3`,
        fs:  `cpe:2.3:a:ibm:monitoring_server_\(ms\)_and_shared_libraries_\(ax\):6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_server:11.0:sp3:~~ltss~~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(36\)cc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_server:12.0`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:6.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_server:12.0:sp1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)s8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_software_development_kit:11.0:sp4`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_linux_enterprise_software_development_kit:12.0:sp1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_linux_software_development_kit:11.0:sp2:enterprise`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_linux_software_development_kit:11.0:sp3:enterprise`,
        fs:  `cpe:2.3:a:login_widget_with_shortcode_project:login_widget_with_shortcode:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_manager:2.1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_manager_proxy:2.1`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:suse_openstack_cloud:5`,
        fs:  `cpe:2.3:a:openstack:oslo:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:suse_package_hub_for_suse_linux_enterprise:12`,
        fs:  `cpe:2.3:a:fastcgi:fcgi:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:unixware:-`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:novell:unixware:1.1`,
        fs:  `cpe:2.3:a:debian:iceape:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:web_search:-`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:web_server:-`,
        fs:  `cpe:2.3:a:samba:samba:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:web_server:1.0`,
        fs:  `cpe:2.3:a:successsecrets:successsecrets_project:1.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:web_server_examples_toolkit:-`,
        fs:  `cpe:2.3:h:buffalotech:wzr2-g300n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks:-`,
        fs:  `cpe:2.3:h:softbank:mobile_wi-fi_router:102z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks:6.2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks:6.2:sr1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks:6.5`,
        fs:  `cpe:2.3:h:cabletron:2h252-25r:5.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks:7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks:7:sp1`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.0.p-3531-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_asset_management:-`,
        fs:  `cpe:2.3:a:commvault:galaxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_asset_management:7:sp1`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_asset_management:7.5`,
        fs:  `cpe:2.3:a:roxio:creator_copy:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:10.0`,
        fs:  `cpe:2.3:a:boost:boost:1.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:10.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:10.2`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_windows:6.1.2004.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:10.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:10.3.1`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:10.3.2`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:10.3.3`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_61:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11:sp1`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11.2.3`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.18.4844:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11.3.0`,
        fs:  `cpe:2.3:a:optimizepress:optimizepress:1.61:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11.3.1`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11.3.2`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11.4.0`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_configuration_management:11.4.1`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_desktop_management:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_desktop_management:6.5`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_desktops:-`,
        fs:  `cpe:2.3:a:safenet-inc:luna_jsp_for_luna_sa:4.4.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_desktops:3.2:sp2`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_desktops:4.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_desktops:4.0.1`,
        fs:  `cpe:2.3:a:blueeleph_project:blueeleph:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_endpoint_security_management:-`,
        fs:  `cpe:2.3:a:mautic:mautic:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_endpoint_security_management:3.5`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_endpoint_security_management:3.5.0.20`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_lights_out:2_1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_endpoint_security_management:3.5.0.82`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_handheld_management:7`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:266:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_handheld_management:7:sp1`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_patch_management_server:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_patch_management_server:6.0.0.52`,
        fs:  `cpe:2.3:a:gnu:emacs:23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_patch_management_server:6.3.2.700`,
        fs:  `cpe:2.3:a:roxio:creator_tools:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_remote_management:-`,
        fs:  `cpe:2.3:o:dlink:dir865l_firmware:1.00b24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_server_management:-`,
        fs:  `cpe:2.3:h:axis:2401_video_server:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_server_management:6.5`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_servers:-`,
        fs:  `cpe:2.3:a:microsoft:visio_viewer:2010:sp1:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_servers:3.0.2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:novell:zenworks_servers:3.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nowbrowser:now_browser_%28material%29:2.8.1::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:drools:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nowsms:now_sms_%26_mms_gateway:2013.09.26`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nowsms:now_sms_%26_mms_gateway:2013.11.11`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nowsms:now_sms_%26_mms_gateway:2013.11.15`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:npds:revolution:13.0`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:npmjs:node_packaged_modules:1.3.2`,
        fs:  `cpe:2.3:h:cabletron:2h252-25r:5.04.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:npmjs:node_packaged_modules:1.3.3`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nq:antivirus_free:7.2.16.02::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nq:easy_finder_%26_anti-theft:2.0.10.08::~~~android~~`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nq:nq_mobile_security_%26_antivirus:7.2.16.00::~~~android~~`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nq:vault-hide_sms_pics_%26_videos:5.0.14.22::~~~android~~`,
        fs:  `cpe:2.3:a:transifex:transifex:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nrgglobal:clevereye:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nsclient:nsclient%2b%2b:0.3.8.76::~~~~x64~`,
        fs:  `cpe:2.3:a:google:v8:3.23.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nsoftware:unitronics_uniopc:1.3.8`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nsoftware:unitronics_uniopc:2.0.0`,
        fs:  `cpe:2.3:h:supermicro:h8dgt-hibqf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nteloswireless:my_ntelos:1.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nticorp:cd-maker:6.7.0.28::~~gold~~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntop:ntop:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntop:ntop:3.3.10`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntop:ntopng:1.1`,
        fs:  `cpe:2.3:a:citrix:web_interface:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntop:ntopng:1.2.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntop:ntopng:1.2.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_55:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntop:ntopng:2.0.151021`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.72`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.73`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050915:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.90`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-455_firmware:t470sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.91`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.92`,
        fs:  `cpe:2.3:a:quagga:quagga:0.96.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.93`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.3\(3.109\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.94`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.95`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.96`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p312:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.97`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:15.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.98`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.0.99`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p228:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.1.0`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.761:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.1.2`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.2`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.2:p1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.2:p2`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.2:p3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.2:p4`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4`,
        fs:  `cpe:2.3:a:x:libxxf86vm:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4mda12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p1`,
        fs:  `cpe:2.3:a:sheepsystems:bookdog:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p3`,
        fs:  `cpe:2.3:a:ibm:interact:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p4`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p5`,
        fs:  `cpe:2.3:a:macromedia:flash_player:6.0.47.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p6`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p7`,
        fs:  `cpe:2.3:a:hp:insight_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p7_rc1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1011:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p7_rc2`,
        fs:  `cpe:2.3:a:emc:captiva_capture:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p7_rc3`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.1:update_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p7_rc4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p7_rc5`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p7_rc6`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p7_rc7`,
        fs:  `cpe:2.3:a:microsoft:cabarc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.4:p8`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p124`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.637:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p125`,
        fs:  `cpe:2.3:a:breezy:breezy:-:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p126`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(7\)e0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p127`,
        fs:  `cpe:2.3:h:htc:desire_hd:gri40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p128`,
        fs:  `cpe:2.3:h:netgear:gs108pe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p129`,
        fs:  `cpe:2.3:a:roxio:central_data:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p130`,
        fs:  `cpe:2.3:a:microsoft:iis:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p131`,
        fs:  `cpe:2.3:a:ibm:db2_connect:11.1.0.0:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p132`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p133`,
        fs:  `cpe:2.3:a:htc:evo_view_4g_software:2.23.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p134`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p277:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p135`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p136`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p137`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p138`,
        fs:  `cpe:2.3:a:vmware:tools:8.0.1.12458:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p139`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p140`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p141`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p1_beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p142`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:102p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p143`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p144`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p145`,
        fs:  `cpe:2.3:a:trendmicro:hijackthis:1.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p146`,
        fs:  `cpe:2.3:a:suse:suse_cvsup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p147`,
        fs:  `cpe:2.3:h:cisco:asr_1002_fixed_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p148`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p149`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:6.14.12.5849:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p150`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p151`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p152`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p153`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p154`,
        fs:  `cpe:2.3:a:telos:xacta_detect_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p155`,
        fs:  `cpe:2.3:a:microsoft:photodraw_2000:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p156`,
        fs:  `cpe:2.3:a:kana:knowledge_editor:7.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p157`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p158`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p159`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p160`,
        fs:  `cpe:2.3:h:ibm:ds4500:1742:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p161`,
        fs:  `cpe:2.3:a:samba:samba:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p162`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_technology_for_corba:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p163`,
        fs:  `cpe:2.3:a:abbyy:finereader:9.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p164`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p165`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p166`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:*:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p167`,
        fs:  `cpe:2.3:h:buffalotech:whr-hp-ampg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p168`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p169`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p170`,
        fs:  `cpe:2.3:a:digium:asterisk:13.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p171`,
        fs:  `cpe:2.3:h:cisco:cgr_1240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p172`,
        fs:  `cpe:2.3:a:trend_micro:interscan_web_security_virtual_appliance:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p173`,
        fs:  `cpe:2.3:o:cru-inc:ditto_forensic_fieldstation_firmware:2013jun30a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p174`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p175`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p176`,
        fs:  `cpe:2.3:h:linksys:befsru31:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p177`,
        fs:  `cpe:2.3:h:cisco:6400_nrp_2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p178`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p179`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p180`,
        fs:  `cpe:2.3:a:altiris:task_management_pack:6.0.1504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p181`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p182`,
        fs:  `cpe:2.3:h:huawei:espace_7910:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p183`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p184`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p185`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p186`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p187`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p188`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p189`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p190`,
        fs:  `cpe:2.3:a:hp:marketresearch:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p191`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p192`,
        fs:  `cpe:2.3:a:emc:vipr_srm:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p193`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p194`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert1_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p195`,
        fs:  `cpe:2.3:a:sympa:sympa:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p196`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.tc5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p197`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p198`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.26:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p199`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p200`,
        fs:  `cpe:2.3:a:twilio_project:twilio:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p201`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p202`,
        fs:  `cpe:2.3:a:atutor:atutor:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p203`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p204`,
        fs:  `cpe:2.3:a:plone:plone:4.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p205`,
        fs:  `cpe:2.3:h:apple:imac:mb325xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p206`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p207`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p208`,
        fs:  `cpe:2.3:a:ibm:qradar_risk_manager:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p209`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p210`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:11.1.0.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p211`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p212`,
        fs:  `cpe:2.3:a:python:python:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p213`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p214`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4n\)e2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p215`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.4:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p216`,
        fs:  `cpe:2.3:a:webroot:security_-_free:3.6.0.6610:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p217`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p218`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p219`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p220`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p221`,
        fs:  `cpe:2.3:a:iconics:genesis32:9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p222`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p223`,
        fs:  `cpe:2.3:a:git-scm:git:2.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p224`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:108.2146.2565.38893:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p225`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments_data_protection_for_vmware:4.1.3:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p226`,
        fs:  `cpe:2.3:a:studio.gd:gd_infinite_scroll:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p227`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.18:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p228`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p229`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p230`,
        fs:  `cpe:2.3:h:cisco:catalyst_3750-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p231_rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p232_rc1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:beta.10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p233_rc1`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p234_rc1`,
        fs:  `cpe:2.3:a:sun:chilisoft:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p235_rc1`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.838.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p236_rc1`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p237_rc1`,
        fs:  `cpe:2.3:a:bump_project:bump:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p238_rc1`,
        fs:  `cpe:2.3:a:orcacle:retail_point-of-service:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p239_rc1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p240_rc1`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p241_rc1`,
        fs:  `cpe:2.3:a:mcafee:security_center:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p242_rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.35.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p243_rc1`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p244_rc1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(.3.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p245_rc1`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p246_rc1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p247_rc1`,
        fs:  `cpe:2.3:a:symantec:license_inventory_agent:4.2.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p248_rc1`,
        fs:  `cpe:2.3:a:tobias_bathge:wp-table_reloaded:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p249_rc1`,
        fs:  `cpe:2.3:a:gnome:glib:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.5:p250_rc1`,
        fs:  `cpe:2.3:a:aol:aim:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p1_rc1`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p1_rc2`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p1_rc3`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p1_rc4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p1_rc5`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.24:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p1_rc6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p2`,
        fs:  `cpe:2.3:a:redhat:cairo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p2_rc1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p2_rc2`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p2_rc3`,
        fs:  `cpe:2.3:a:samba:samba:3.0.21:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p2_rc4`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f2-s3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p2_rc5`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p2_rc6`,
        fs:  `cpe:2.3:a:google:chrome:6.0.423.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p2_rc7`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_beta1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc1`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp3:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc10`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc11`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc12`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc2`,
        fs:  `cpe:2.3:a:citrix:management_console_for_citrix_presentation_server:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc3`,
        fs:  `cpe:2.3:a:lucent:radius:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc4`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc5`,
        fs:  `cpe:2.3:a:debian:adequate:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc6`,
        fs:  `cpe:2.3:a:microsoft:access:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc7`,
        fs:  `cpe:2.3:a:gnu:readline:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc8`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p3_rc9`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.447.6.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p4_beta1`,
        fs:  `cpe:2.3:h:hp:j8693a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p4_beta2`,
        fs:  `cpe:2.3:a:digia:qt:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p4_rc1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p4_rc2`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p5`,
        fs:  `cpe:2.3:a:pocketmags:classic_car_buyer:\@7f08017a:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p5_rc1`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p5_rc2`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.6:p5_rc3`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p0`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p1`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultracompare:6.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p10`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p100`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p101`,
        fs:  `cpe:2.3:a:flickatrade:flick_a_trade:3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p102`,
        fs:  `cpe:2.3:a:microsoft:internet_explorer:5.01:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p103`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p104`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p105`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p106`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p107`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p108`,
        fs:  `cpe:2.3:a:emc:networker:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p109`,
        fs:  `cpe:2.3:a:ibm:quickfile:1.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p110`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p111`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p112`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p113`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p114`,
        fs:  `cpe:2.3:a:mcafee:webshield:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p115`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:313.30:-:*:*:esx:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p116`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p117`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p118`,
        fs:  `cpe:2.3:a:apple:remote_desktop:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p119`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p12`,
        fs:  `cpe:2.3:a:php-nuke:ev:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p120`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.5:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p121`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p122`,
        fs:  `cpe:2.3:a:sun:solaris_isp_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p123`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.3.4-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p124`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p125`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1078.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p126`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p127`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.02:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p128`,
        fs:  `cpe:2.3:a:netscape:fasttrack_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p129`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p13`,
        fs:  `cpe:2.3:a:parentlink:west_bend_school_district:4.0.500:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p130`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p131`,
        fs:  `cpe:2.3:a:ogaki_kyoritsu_bank:smartphone_passbook:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p132`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p133`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p134`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p135`,
        fs:  `cpe:2.3:a:opscode:chef:0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p136`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p137`,
        fs:  `cpe:2.3:a:google:chrome:9.0.570.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p138`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p139`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p14`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p140`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p141`,
        fs:  `cpe:2.3:a:microsoft:psgetsid:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p142`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p143`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p144`,
        fs:  `cpe:2.3:a:google:chrome:4.0.263.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p145`,
        fs:  `cpe:2.3:a:wikiwig_project:wikiwig:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p146`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_server:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p147`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.1.0:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p148`,
        fs:  `cpe:2.3:o:cisco:wrvs4400n_firmware:2.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p149`,
        fs:  `cpe:2.3:a:attachmate:oracle_provider:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p15`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p150`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p151`,
        fs:  `cpe:2.3:o:google:android:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p152`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p153`,
        fs:  `cpe:2.3:a:ingen-studios:conquest_of_fantasia:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p154`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p164:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p155`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p156`,
        fs:  `cpe:2.3:h:hp:pa-risc:_nil_:_nil_:64bit:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p157`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.52.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p158`,
        fs:  `cpe:2.3:a:microsoft:ie:4.71.1008.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p159`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p16`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p160`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p161`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.25:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p162`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p163`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p164`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p165`,
        fs:  `cpe:2.3:a:mysql:eventum:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p166`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(6a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p17`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p170`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.3:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p171`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p172`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p173`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p174`,
        fs:  `cpe:2.3:a:nitropdf:nitro_pdf:6.2.1.10:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p175`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.181:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p176`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p177`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p178`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p179`,
        fs:  `cpe:2.3:h:linksys:befsr81:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p18`,
        fs:  `cpe:2.3:a:vmware:vcenter_operations:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p180`,
        fs:  `cpe:2.3:a:aol:internet_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p181`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p182`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p183`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p184`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p185`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p186`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p187`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p188`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p189`,
        fs:  `cpe:2.3:a:nvidia:install_application:2.265.39.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p19`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p190`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p191`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p192`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p193`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p194`,
        fs:  `cpe:2.3:o:cisco:content_services_switch_11500:7.20_\(03.09\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p195`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p196`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.00:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p197`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.2.073.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p198`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p144:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p199`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p2`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p20`,
        fs:  `cpe:2.3:a:busybox:busybox:0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p200`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p201`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.2.0-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p202`,
        fs:  `cpe:2.3:a:isc:bind:9.7.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p203`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p204`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.03:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p205`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p206`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p207`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0-p2-w2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p208`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p209`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p21`,
        fs:  `cpe:2.3:a:ibm:campaign:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p210`,
        fs:  `cpe:2.3:a:logitech:quickcam:11.80.1065:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p211`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p212`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p213`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p214`,
        fs:  `cpe:2.3:a:oracle:internet_directory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p215`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p216`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p217`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:gold:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p218`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p219`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p22`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p220`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p221`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p222`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p223`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(6d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p224`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p225`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p226`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.6h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p227`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.594:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p228`,
        fs:  `cpe:2.3:a:symantec:client_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p229`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p23`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p230`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p231`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p232`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.1.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p233`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p234`,
        fs:  `cpe:2.3:a:apache:ofbiz:12.04.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p235`,
        fs:  `cpe:2.3:a:serena:sourcebridge:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p236`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p237`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p238`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p239`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p24`,
        fs:  `cpe:2.3:a:ad-manager_project:ad-manager:1.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p240`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p241`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p242`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p243`,
        fs:  `cpe:2.3:a:emc:rsa_data_protection_manager_software_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p244`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p245`,
        fs:  `cpe:2.3:a:apache:poi:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p246`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5\)su1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p247`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p248`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p249`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p25`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p250`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.3:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p251`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.08.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p252`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p253`,
        fs:  `cpe:2.3:a:teradata:bteq:12.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p254`,
        fs:  `cpe:2.3:a:emc:documentum_capital_projects:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p255`,
        fs:  `cpe:2.3:a:corel:quattro_pro_x6:16.0.0.388:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p256`,
        fs:  `cpe:2.3:a:compaq:armada_insight_manager:4.20j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p257`,
        fs:  `cpe:2.3:a:safeway:safeway:4.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p258`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p259`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.9.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p26`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p260`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p261`,
        fs:  `cpe:2.3:a:id:id-software:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p262`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p263`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p264`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p265`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p266`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p267`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:17.012.20095:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p268`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2:alpha0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p269`,
        fs:  `cpe:2.3:a:techsmith:snagit:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p27`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p270`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p271`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p272`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p273`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p274`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p275`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p276`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p277`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p278`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p279`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p28`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p280`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p281`,
        fs:  `cpe:2.3:a:hp:hpsockd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p282`,
        fs:  `cpe:2.3:h:hp:jg834a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p283`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p284`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p285`,
        fs:  `cpe:2.3:h:ibm:system_storage_dcs3700_storage_subsystem:1818:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p286`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p287`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30096:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p288`,
        fs:  `cpe:2.3:a:gnu:automake:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p289`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:6.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p29`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p290`,
        fs:  `cpe:2.3:a:adobe:livecycle_designer_es2:9.0.0.20091029.1.612548:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p291`,
        fs:  `cpe:2.3:o:cisco:ios:12.3jx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p292`,
        fs:  `cpe:2.3:a:clamav:clamav:0.86.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p293`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p294`,
        fs:  `cpe:2.3:a:apple:safari:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p295`,
        fs:  `cpe:2.3:a:skype:skype:4.1.0.179:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p296`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.2:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p297`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.5.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p298`,
        fs:  `cpe:2.3:o:ibm:aix:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p299`,
        fs:  `cpe:2.3:a:plogger:plogger:1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p3`,
        fs:  `cpe:2.3:a:synology:diskstation_manager:4.3-3810:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p30`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p300`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.133:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p301`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p302`,
        fs:  `cpe:2.3:a:zebra_technologies:setup_utilities:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p303`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p304`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p305`,
        fs:  `cpe:2.3:a:icsharpcode:sharpdevelop:3.2.6466:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p306`,
        fs:  `cpe:2.3:a:microsoft:word:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p307`,
        fs:  `cpe:2.3:a:lucent:vitalnet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p308`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p309`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp3:x32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p31`,
        fs:  `cpe:2.3:a:sun:iplanet_directory_server:5.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p310`,
        fs:  `cpe:2.3:a:canonical:update-manager:1\:0.134.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p311`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p312`,
        fs:  `cpe:2.3:o:schrack:technik_microcontrol_firmware:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p313`,
        fs:  `cpe:2.3:a:sun:ray_server_software:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p314`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p315`,
        fs:  `cpe:2.3:a:ben10_omniverse_walkthrough_project:ben10_omniverse_walkthrough:0.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p316`,
        fs:  `cpe:2.3:a:wpsymposium:wp_symposium:13.04:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p317`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p318`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p319`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.1:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p32`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p320`,
        fs:  `cpe:2.3:a:microsoft:office_web_apps:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p321`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:54.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p322`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p323`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p324`,
        fs:  `cpe:2.3:a:oneorzero:action_and_information_management_system:2.6.0:-:members:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p325`,
        fs:  `cpe:2.3:o:raritan:px:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p326`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p327`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p328`,
        fs:  `cpe:2.3:a:apache:opennlp:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p329`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_web_server:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p33`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p330`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p331`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p332`,
        fs:  `cpe:2.3:o:juniper:junos:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p333`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p334`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p335`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p336`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_6911:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p337`,
        fs:  `cpe:2.3:a:microsoft:visual_c\#:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p338`,
        fs:  `cpe:2.3:a:apache:httpclient:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p339`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p34`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p340`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.28.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p341`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p342`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p343`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.268:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p344`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p345`,
        fs:  `cpe:2.3:a:apache:camel:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p346`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p347`,
        fs:  `cpe:2.3:a:php:php:7.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p348`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.2.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p349`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)n1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p35`,
        fs:  `cpe:2.3:a:jason_moore:amadou:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p350`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p351`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p352`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p353`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.26a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p354`,
        fs:  `cpe:2.3:a:pheonixcontact-software:multiprog:5.0:*:*:*:pro\&#43;:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p355`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p356`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p357`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p358`,
        fs:  `cpe:2.3:a:leon_weber:pyxtrlock:0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p359`,
        fs:  `cpe:2.3:a:hp:san\/iq:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p36`,
        fs:  `cpe:2.3:a:docebo:docebolms:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p360`,
        fs:  `cpe:2.3:a:ibm:db2:9.7:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p361`,
        fs:  `cpe:2.3:a:typemoon:fate\/stay_night_\&#43;_hollow_ataraxia_set:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p362`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p363`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1684.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p364`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.0.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p365`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p366`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p367`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p368`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p369`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p37`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.04.545:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p370`,
        fs:  `cpe:2.3:a:f5:vpn_client_for_windows:55.2.60918.1441:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p371`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p372`,
        fs:  `cpe:2.3:a:symantec:network_access_control:11.0.6100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p373`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p374`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.06.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p375`,
        fs:  `cpe:2.3:a:sun:jre:1.4.1:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p376`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p377`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.999:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p378`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:8.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p379`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p38`,
        fs:  `cpe:2.3:a:belarc:belmanage\/belsecure_2010:8.1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p380`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p381`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:15.0.0.302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p382`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p383`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p384`,
        fs:  `cpe:2.3:a:oracle:commerce_platform:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p385`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p386`,
        fs:  `cpe:2.3:a:gnu:libtasn1:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p387`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p388`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p389`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p39`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p390`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p391`,
        fs:  `cpe:2.3:h:aterm:wf800hp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p392`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_configuration_manager:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p393`,
        fs:  `cpe:2.3:h:buffalotech:whr-1166dhp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p394`,
        fs:  `cpe:2.3:a:opsview:opsview:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p395`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p396`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p397`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p398`,
        fs:  `cpe:2.3:a:vmware:player:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p399`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p4`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p40`,
        fs:  `cpe:2.3:a:netcreators:irfaq:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p400`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p401`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p402`,
        fs:  `cpe:2.3:a:nokia:symbian_s60_browser:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p403`,
        fs:  `cpe:2.3:a:samba:samba:1.9.17:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p404`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p405`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p406`,
        fs:  `cpe:2.3:a:openttd:openttd:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p407`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p408`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p409`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p41`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p410`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.1:*:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p411`,
        fs:  `cpe:2.3:a:certmagic:cissp-testengine-certmagic-part1:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p412`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p413`,
        fs:  `cpe:2.3:a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.7:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p414`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p415`,
        fs:  `cpe:2.3:a:imember360:imember360:3.9.004:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p416`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p417`,
        fs:  `cpe:2.3:h:meinberg:lantime_m300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p418`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p419`,
        fs:  `cpe:2.3:h:hp:nonstop_himalaya_s76:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p42`,
        fs:  `cpe:2.3:a:tenable:nessus:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p420`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p421`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p422`,
        fs:  `cpe:2.3:a:keepass:keepass:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p423`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p424`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p425`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p426`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p427`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p428`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.9.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p429`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1689.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p43`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p430`,
        fs:  `cpe:2.3:a:clamav:clamav:0.96.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p431`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p432`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.5.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p433`,
        fs:  `cpe:2.3:o:xen:xen:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p434`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p435`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p436`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p437`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:5.5:u2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p438`,
        fs:  `cpe:2.3:a:crunchify:all-in-on-webmaster:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p439`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:10.3.186.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p44`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p440`,
        fs:  `cpe:2.3:a:magzter:magzter_-magazine_\&amp;_book_store:3.31:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p441`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p442`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.0:e0101h04:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p443`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p444`,
        fs:  `cpe:2.3:a:google:v8:3.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p445`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p446`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p447`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p448`,
        fs:  `cpe:2.3:o:huawei:s2350ei_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p449`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p45`,
        fs:  `cpe:2.3:h:axis:storpoint_cd\&#43;:6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p450`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p451`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.194:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p452`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20\)sp1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p453`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option_server:08-00\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p454`,
        fs:  `cpe:2.3:a:oracle:http_server:9.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p455`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p456`,
        fs:  `cpe:2.3:a:apache:subversion:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p457`,
        fs:  `cpe:2.3:a:symantec:security_check_virus_detection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p458`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p459`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p46`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p460`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p461`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p462`,
        fs:  `cpe:2.3:a:vmware:horizon_view:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p463`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p464`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p465`,
        fs:  `cpe:2.3:a:teradata:index_wizard:13.10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p466`,
        fs:  `cpe:2.3:a:bitrock:bitrock_installbuilder_enterprise:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p467`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p468`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p469`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p47`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc474a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p470`,
        fs:  `cpe:2.3:a:microsoft:access:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p471`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p472`,
        fs:  `cpe:2.3:o:yamaha:rtw65b:5.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p473`,
        fs:  `cpe:2.3:a:apple:cups:1.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p474`,
        fs:  `cpe:2.3:a:compaq:system_healthcheck:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p475`,
        fs:  `cpe:2.3:a:tenable:nessus:6.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p476`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p477`,
        fs:  `cpe:2.3:a:google:chrome:7.0.524.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p478`,
        fs:  `cpe:2.3:a:astaro:security_gateway_software:8.305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p479`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p48`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p480`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.2.3:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p481`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p482`,
        fs:  `cpe:2.3:a:divx:codec:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p483`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p484_rc1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.791.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p485_rc1`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p486_rc1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p49`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p5`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p50`,
        fs:  `cpe:2.3:a:josh_roesslein:tweepy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p51`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p52`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p53`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p54`,
        fs:  `cpe:2.3:a:microsoft:asp.net:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p55`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p56`,
        fs:  `cpe:2.3:a:apport_project:apport:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p57`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p58`,
        fs:  `cpe:2.3:a:divx:mkv_splitter:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p59`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p6`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.3:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p60`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p61`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p62`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p63`,
        fs:  `cpe:2.3:a:microsoft:pslist:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p64`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p65`,
        fs:  `cpe:2.3:a:justsystems:just_smile:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p66`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p67`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p68`,
        fs:  `cpe:2.3:a:ibm:sterling_integrator:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p69`,
        fs:  `cpe:2.3:a:hp:photo_and_imaging_gallery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p7`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p70`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p2_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p71`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p72`,
        fs:  `cpe:2.3:a:microsoft:pocket_ie:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p73`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p74`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p75`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sy1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p76`,
        fs:  `cpe:2.3:a:john_morrissey:mod_ldap_userdir:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p77`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p78`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p79`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p8`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je022a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p80`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p81`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p82`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p83`,
        fs:  `cpe:2.3:a:snort:snort:2.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p84`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p85`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p86`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.11:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p87`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p88`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p89`,
        fs:  `cpe:2.3:a:solarwinds:san_monitor_for_emc_clariion:1.0.0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p9`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p90`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p91`,
        fs:  `cpe:2.3:a:adobe:photoshop:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p92`,
        fs:  `cpe:2.3:a:devsaran:responsive:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p93`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p94`,
        fs:  `cpe:2.3:a:nas4free:nas4free:9.1.0.1.798:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p95`,
        fs:  `cpe:2.3:a:robotstats:robotstats:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p96`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p97`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.35:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p98`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7:p99`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:eca:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.7p444`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8`,
        fs:  `cpe:2.3:a:f-secure:secure_messaging_secure_gateway:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.29.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p1_beta1`,
        fs:  `cpe:2.3:a:tincan:phplist:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p1_beta2`,
        fs:  `cpe:2.3:a:adobe:flash_player:23.0.0.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p1_beta3`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p1_beta4`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p1_beta5`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p1_rc1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p1_rc2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.604:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p2_rc1`,
        fs:  `cpe:2.3:a:php:php:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p2_rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p2_rc3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p3`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/ru2_firmware:2.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p3_rc1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p3_rc2`,
        fs:  `cpe:2.3:a:google:chrome:41.0.2272.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p3_rc3`,
        fs:  `cpe:2.3:a:serf_project:serf:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p4`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p6`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p7`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.2.8:p9`,
        fs:  `cpe:2.3:a:umn:mapserver:4.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.2`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.3`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12c\)e7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.5`,
        fs:  `cpe:2.3:a:woodforest:woodforest_mobile_banking:3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.6`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.7`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.8`,
        fs:  `cpe:2.3:h:cisco:intrusion_prevention_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.9`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.10`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.11`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.05:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.12`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.13`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.14`,
        fs:  `cpe:2.3:a:longwaveconsulting:ubercart_securetrading_payment_method_module:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.15`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.07:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.16`,
        fs:  `cpe:2.3:a:gnu:libtasn1:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.17`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.18`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.19`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.20`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.21`,
        fs:  `cpe:2.3:a:google:chrome:13.0.771.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.22`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.23`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.24`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2010.910.2122.36517:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.25`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.26`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.27`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.28`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.29`,
        fs:  `cpe:2.3:a:cisco:webns:7.20.03.09s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.30`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.30.020.1180:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.31`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.32`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:*:x64-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.33`,
        fs:  `cpe:2.3:a:php:php:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.34`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.35`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.36`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.6:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.37`,
        fs:  `cpe:2.3:a:magzter:epc_world:3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.38`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.02:pl6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.39`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.40`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.41`,
        fs:  `cpe:2.3:a:vdgsecurity:vdg_sense:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.42`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.43`,
        fs:  `cpe:2.3:a:sympa:sympa:3.0b.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.44`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.45`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:4.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.46`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.47`,
        fs:  `cpe:2.3:h:buffalotech:wzr-g144n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.48`,
        fs:  `cpe:2.3:o:openvas:greenbone_security_assistant:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.49`,
        fs:  `cpe:2.3:a:microsoft:outlook:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.50`,
        fs:  `cpe:2.3:a:hp:webinspect:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.51`,
        fs:  `cpe:2.3:a:hp:openview_performance_extended_capability_technology:4.59.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.52`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.53`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpx\/epx2203:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.54`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.55`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.56`,
        fs:  `cpe:2.3:a:sun:storedge_enterprise_backup_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.57`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.58`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.257:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.59`,
        fs:  `cpe:2.3:o:cisco:ip_phone_8800_series_firmware:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.60`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.61`,
        fs:  `cpe:2.3:a:yokogawa:b\/m9000_vp_software:7.03.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.62`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.63`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.64`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:2.1\(1.37\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.65`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.66`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.67`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.68`,
        fs:  `cpe:2.3:a:novell:groupwise:7.03:hp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.69`,
        fs:  `cpe:2.3:a:digia:qt:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.70`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf012:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.71`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.72`,
        fs:  `cpe:2.3:a:mozilla:firefox:42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.73`,
        fs:  `cpe:2.3:a:attachmate:reflection_x:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.74`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.75`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.76`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-05-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.77`,
        fs:  `cpe:2.3:a:yahoo:yui:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.78`,
        fs:  `cpe:2.3:a:openstack:keystone:2014.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.79`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1276.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.80`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.81`,
        fs:  `cpe:2.3:a:php-fusion:team_impact_ti_blog_system_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.82`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.222:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.83`,
        fs:  `cpe:2.3:a:symantec:livereg:2.4.2.2295:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.84`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.85`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.86`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg510-10:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.87`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.88`,
        fs:  `cpe:2.3:a:riken:xoonips:3.48:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.89`,
        fs:  `cpe:2.3:a:onelouder:friendcaster_chat:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.90`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner:16.0.0.10215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.91`,
        fs:  `cpe:2.3:a:smarty:smarty:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.92`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:4.3.93`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_advanced_pdf_editor:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p91`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p92`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p93`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.14-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p94`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p95`,
        fs:  `cpe:2.3:o:yahama:rtw65b:5.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p96`,
        fs:  `cpe:2.3:a:qemu:qemu:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p97`,
        fs:  `cpe:2.3:a:isc:bind:8.2.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p98`,
        fs:  `cpe:2.3:a:adobe:extendscript_toolkit_cs4:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntp:ntp:p99`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntt:050_plus:4.2.0::~~~android~~`,
        fs:  `cpe:2.3:h:dell:kace_k1200s_systems_management_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntt:050_plus:4.2.1::~~~android~~`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.54:bbet54l:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntt:050_plus:4.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:network_satellite_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntt:webarena_service_formmail:2.2.0`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdata:terasoluna_server_framework_for_java_web:2.0.0.1`,
        fs:  `cpe:2.3:h:antlabs:inngate_ig_3.02_e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdata:terasoluna_server_framework_for_java_web:2.0.0.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdata:terasoluna_server_framework_for_java_web:2.0.1.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.63a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdata:terasoluna_server_framework_for_java_web:2.0.2.0`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cpn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdata:terasoluna_server_framework_for_java_web:2.0.5.1`,
        fs:  `cpe:2.3:a:radius_extension_project:radius:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdata:terasoluna_server_framework_for_java_web:2.0.5.2`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdata:terasoluna_server_framework_for_java_web:2.0.5.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2009.0113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdata:web_analytics_service:-`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:overseas_usage:2.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_vx_clinical_assistant:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:overseas_usage:2.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:2546`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:2631`,
        fs:  `cpe:2.3:a:ibm:http_server:8.5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:3000`,
        fs:  `cpe:2.3:a:avaya:aura_application_server_5300:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:3100`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:3200`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:3300`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:3400`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4000`,
        fs:  `cpe:2.3:a:intel:network_connections:12.4.38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4200`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4300`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4400`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30306:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4500`,
        fs:  `cpe:2.3:h:cisco:catalyst_2926gl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4600`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4700`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4800`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:4900`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:5000`,
        fs:  `cpe:2.3:o:cisco:ios:15.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:5100`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_appliance:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:5200`,
        fs:  `cpe:2.3:a:cisco:business_edition_5000_software:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:5300`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:5400`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:5500`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:5550`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.10.2\(42\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:5900::~~~android~~`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:6000::~~~android~~`,
        fs:  `cpe:2.3:h:rockwellautomation:1756-enbt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:6200::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:6300::~~~android~~`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:6620::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nttdocomo:spmode_mail_android:6700::~~~android~~`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntwind:winsnap:3.1.4`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ntwind:winsnap:3.5.4`,
        fs:  `cpe:2.3:a:gnu:bash:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:caere_scan_manager:5.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:dragon_naturallyspeaking:8.10.0.285`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:dragon_naturallyspeaking:9.0.100`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:dragon_naturallyspeaking:11.0.200`,
        fs:  `cpe:2.3:a:citrix:sharefile_mobile:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:dragon_sdk:10.10.0.431::~~server~~~`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.1:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:image_retriever:5.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.2.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:-`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_server:5.x\/6.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:2.0.0::~~se~~~`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2000:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:2.0.4::~~se~~~`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall_1:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:4.0::~~se~~~`,
        fs:  `cpe:2.3:h:buffalotech:whr-hp-g54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:10.0::~~pro~~~`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:11.0.1::~~se~~~`,
        fs:  `cpe:2.3:a:apache:qpid:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:12::pro`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:15.1.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:15.2.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:16.1.0`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.0:beta_5.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:17::pro`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage:18::pro`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:omnipage_web:1.0::~~personal~~~`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a1:8.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:openspeech_recognizer:3.0.9`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:11:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:7.2`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:9.2.814`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.08b51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:9.2.827`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:10.2.0`,
        fs:  `cpe:2.3:h:hp:0235a321:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:10.3.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:10.4.0`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.2.3:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:10.4.1000`,
        fs:  `cpe:2.3:a:google:chrome:9.0.572.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:11.0.0::~~pro~~~`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:11.1.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport:11.2.0`,
        fs:  `cpe:2.3:a:hp:hppscanto:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:paperport_image_printer:1.0.0`,
        fs:  `cpe:2.3:a:vmware:capacityiq:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:pdf_converter:1.0.0`,
        fs:  `cpe:2.3:a:hp:e\/a_agent_simplified_chinese_localization:8.60.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:pdf_create:4.1.9`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:pdf_printer:1.0.0`,
        fs:  `cpe:2.3:a:3ivx:mpeg-4:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:pdf_reader:6.0`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:pdf_reader:7.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:pdf_reader:8.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:pdf_reader_plus:7.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:realspeak:12.0.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:smart_document_scan_software:1.20.0`,
        fs:  `cpe:2.3:h:hp:apache-based_web_server:2.0.43.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:smart_document_scan_software:2.0.0`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:smart_document_scan_software:2.60.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.01.024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:smart_document_scan_software:2.70.0`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuance:visual_c%2b%2b_runtime_for_dragon_naturallyspeaking:10.0.200.184`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nucleustechnologies:kernel_for_ost_to_pst:10.10.1::~~evaluation~~~`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:nullsoft_install_system:2.30`,
        fs:  `cpe:2.3:a:justsystems:atok:17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:nullsoft_install_system:2.46`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:0.20a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p206:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:0.92`,
        fs:  `cpe:2.3:a:drupal:drupal:7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:1.006`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:1.90`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p160:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:2.0`,
        fs:  `cpe:2.3:a:oracle:server_manager:3.1.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:2.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:2.9`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:2.10`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:2.91`,
        fs:  `cpe:2.3:a:emc:rsa_identity_management_and_governance:6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:2.92`,
        fs:  `cpe:2.3:a:esri:arcgis:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:2.95`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.32.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.0`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.01`,
        fs:  `cpe:2.3:a:gnome:glib:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.1:-:surround`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.02`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.2`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.03`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.0.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.3`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.04`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.05`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.06`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.07`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.1.7.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.08c`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.18:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.08d`,
        fs:  `cpe:2.3:a:intel:msso:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.08e`,
        fs:  `cpe:2.3:a:david_alkire:drag_\&amp;_drop_gallery:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.09`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.11`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.12`,
        fs:  `cpe:2.3:a:apple:itunes:10.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.13`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.22`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.23`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.3:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.24`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2013:cumulative_update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.31`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.32`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.33`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.34`,
        fs:  `cpe:2.3:a:bir.gov.ph:alphalist_data_entry_and_validation:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.35`,
        fs:  `cpe:2.3:a:haxx:curl:7.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.36`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.51`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.51:beta`,
        fs:  `cpe:2.3:a:siteminder_federation:12.0:-:standalone:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.52`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bbet64b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.53`,
        fs:  `cpe:2.3:a:apple:safari:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.54`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.54:beta`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.55`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.55:beta`,
        fs:  `cpe:2.3:a:firaxis:sid_meiers_civilization_iv_warlords:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.56`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.6:*:*:*:expressway:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.57`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.58`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.59:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.61`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.63`,
        fs:  `cpe:2.3:a:redwood:cronacle_process_server:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.091`,
        fs:  `cpe:2.3:o:huawei:s5300si_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.093`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.094`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc2420:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.111`,
        fs:  `cpe:2.3:a:almasiapps:healing_bookstore:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.112`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.61.020.2822:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.531`,
        fs:  `cpe:2.3:a:sitepark:information_enterprise_server:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.541`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.551`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.552`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.572`,
        fs:  `cpe:2.3:h:huawei:p8:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.581`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.623`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nullsoft:winamp:5.666`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nunit.org:nunit:2.4.8`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuphoto:nusquare:1.0.78::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuuo:crystal:2.2.1`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuuo:crystal:3.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuuo:crystal:3.1.0`,
        fs:  `cpe:2.3:a:alan_kennington:mod_bwshare:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nuuo:crystal:3.2.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.395:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.1.0`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.0.1065:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.3.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.3.2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.4.0`,
        fs:  `cpe:2.3:a:adobe:camera_raw:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.5.2`,
        fs:  `cpe:2.3:a:apache:struts:2.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.6.0`,
        fs:  `cpe:2.3:a:symantec:intruder_alert:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.6.1`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.6.2`,
        fs:  `cpe:2.3:o:ge:multilink_ml2400_firmware:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.6.4`,
        fs:  `cpe:2.3:h:cisco:spa_501g_8-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.7.0`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.7.1`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.7.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.7.5`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:1.7.6`,
        fs:  `cpe:2.3:a:redhat:daredevil_skk:11.6.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:2.0.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:2.2.1`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrmini_2:3.0.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.4\(1\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.0.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.0.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.1.0.117`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.7.b-1.0.2.1-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.1.1`,
        fs:  `cpe:2.3:a:vim:vim:8.0.0055:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.1.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.3.0`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:1.75`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.0.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.1.5`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:rc3:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.3.1.20`,
        fs:  `cpe:2.3:a:samba:samba:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.3.7.9`,
        fs:  `cpe:2.3:a:emc:documentum_taskspace:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.3.7.10`,
        fs:  `cpe:2.3:a:debian:apt:0.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:2.3.9.6`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:nuuo:nvrsolo:3.0.0`,
        fs:  `cpe:2.3:a:process-one:ejabberd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:260.99`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:266.58`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:266.87`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:268.44`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:275.33`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd395a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:275.65`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:5.x-0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:275.89`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:276.14`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.4.110.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:control_panel:276.28`,
        fs:  `cpe:2.3:h:bluecoat:proxysg:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:1.6`,
        fs:  `cpe:2.3:a:roxio:creator:3.8.0:*:*:*:business:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:2.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.308.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:6.14.11.9716`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:6.14.11.9728`,
        fs:  `cpe:2.3:a:nortel:contact_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:6.14.11.9745`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:6.14.12.5849`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:6.14.12.5896`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:6.14.12.5922`,
        fs:  `cpe:2.3:a:emc:navisphere_service_taskbar:29.2.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:6.14.12.5981`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.8:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_control_panel:6.14.12.6883`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_driver:307.00:-:~~~windows~~`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_driver:307.78:-:~~~windows~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_driver:310.00:-:~~~windows~~`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:5.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:display_driver:311.00:-:~~~windows~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_910m:-`,
        fs:  `cpe:2.3:a:skype:skype:4.2.0.141:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_920m:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_920mx:-`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_930m:-`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:3.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_930mx:-`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_940m:-`,
        fs:  `cpe:2.3:h:nortel:7220_wlan_access_point:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_940mx:-`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_945m:-`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:geforce_experience:gfe_2.11.3.5`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.3\(1.200\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:geforce_experience:gfe_3.1.0.00`,
        fs:  `cpe:2.3:a:xerox:freeflow_print_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gt_710:-`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gt_730:-`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp3505:cb442a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gtx_1050:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gtx_1060:-`,
        fs:  `cpe:2.3:a:artifex:mupdf:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gtx_1070:-`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gtx_1080:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gtx_950m:-`,
        fs:  `cpe:2.3:a:tincan:phplist:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gtx_960m:-`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:geforce_gtx_965m:-`,
        fs:  `cpe:2.3:a:tilman_hausherr:xenu_link_sleuth:1.2d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:-`,
        fs:  `cpe:2.3:a:lenovo:shareit:3.5.98_ww:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:195.22:-:~~esx~~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:195.22:-:~~freebsd~~~`,
        fs:  `cpe:2.3:a:exim:exim:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:195.22:-:~~linux_kernel~~~`,
        fs:  `cpe:2.3:a:apache:myfaces_tomahawk:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:195.22:-:~~sunos~~~`,
        fs:  `cpe:2.3:a:gnu:tar:1.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.00:-:~~esx~~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.554.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.00:-:~~freebsd~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.00:-:~~linux_kernel~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.00:-:~~sunos~~~`,
        fs:  `cpe:2.3:a:roxio:activation_module:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.00:-:~~unix~~~`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:14.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.00:-:~~windows~~~`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.79`,
        fs:  `cpe:2.3:a:typo3:typo3:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.88:-:~~esx~~~`,
        fs:  `cpe:2.3:a:quest:toad_for_data_analysts:2.5.0.913:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.88:-:~~freebsd~~~`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.88:-:~~linux_kernel~~~`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.88:-:~~sunos~~~`,
        fs:  `cpe:2.3:a:nokia:qt_creator:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:304.123`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.00:-:~~esx~~~`,
        fs:  `cpe:2.3:a:piriform:ccleaner:5.00.5050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.00:-:~~freebsd~~~`,
        fs:  `cpe:2.3:h:hp:j9576a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.00:-:~~linux_kernel~~~`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.00:-:~~sunos~~~`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.00:-:~~windows~~~`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.44:-:~~esx~~~`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.44:-:~~freebsd~~~`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.44:-:~~linux_kernel~~~`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:310.44:-:~~sunos~~~`,
        fs:  `cpe:2.3:h:huawei:s9312e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:313.00:-:~~esx~~~`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:313.00:-:~~freebsd~~~`,
        fs:  `cpe:2.3:a:divx:converter:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:313.00:-:~~linux_kernel~~~`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:313.00:-:~~sunos~~~`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:313.30:-:~~esx~~~`,
        fs:  `cpe:2.3:a:pocketmags:classic_arms_\&amp;_militaria:\@7f080193:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:313.30:-:~~freebsd~~~`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:313.30:-:~~linux_kernel~~~`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:313.30:-:~~sunos~~~`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:319.00:-:~~unix~~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.595.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:319.00:-:~~windows~~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:325.00:-:~~windows~~~`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:331.00:-:~~unix~~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.12:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:331.00:-:~~windows~~~`,
        fs:  `cpe:2.3:o:hp:tru64:4.0f_pk7_bl18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:331.104`,
        fs:  `cpe:2.3:a:citadel:ux:6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:334.16`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(55\)se9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:337.19`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:340.52`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:340.65`,
        fs:  `cpe:2.3:h:hp:jd676a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:341.98`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.3\(2\)n1\(0.296\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:343.22`,
        fs:  `cpe:2.3:a:spumko_project:hapi_server_framework:2.0.0:-:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:346.59`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.23:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:349.12`,
        fs:  `cpe:2.3:h:cisco:7920_wireless_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:352.0`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:361.91`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:365.19`,
        fs:  `cpe:2.3:a:levelfourdevelopment:wp-easycart:2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:368.81`,
        fs:  `cpe:2.3:a:apache:struts:2.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:373.06`,
        fs:  `cpe:2.3:a:apache:subversion:0.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r21.2::~~~linux_kernel~tegra~`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7911g:8.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r39::~~~chrome_os~~`,
        fs:  `cpe:2.3:a:intuit:quicken:20.1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r304.125::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.2:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r331.00::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:oracle:reports:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r331.112::~~~linux_kernel~~`,
        fs:  `cpe:2.3:h:apple:imac:ma876xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r340.00::~~~linux_kernel~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xa1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r340.65::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r343.00::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r343.36::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r346.00::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver:r346.22::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver_r304:309.07`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver_r340:341.43`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver_r343:345.19`,
        fs:  `cpe:2.3:a:dulwich_project:dulwich:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:gpu_driver_r346:347.51`,
        fs:  `cpe:2.3:a:ca:etrust_admin:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:install_application:2.0.12.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:install_application:2.0.14.0`,
        fs:  `cpe:2.3:h:lexmark:c935dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:install_application:2.265.36.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:install_application:2.265.39.0`,
        fs:  `cpe:2.3:a:ark-web:a-form_pc:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:install_application:2.265.41.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:install_application:2.275.78.0`,
        fs:  `cpe:2.3:a:symantec:web_security:3.01.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:install_application:2.275.80.0`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:install_application:2.275.82.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview:135.36`,
        fs:  `cpe:2.3:o:huawei:agile_controller-campus:v100r001c00spc315:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview:135.50`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview:135.60`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview:135.70`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.1.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview:135.85`,
        fs:  `cpe:2.3:a:xoops:xoops:2.5.7:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview:136.2`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.0`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.1362`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:9.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.12152`,
        fs:  `cpe:2.3:a:microsoft:ie:4.70.1158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.12154`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.13065`,
        fs:  `cpe:2.3:a:hp:mercury_sitescope:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.13527`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.13530`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.13560`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.13570`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:nview_desktop_manager:6.14.10.13585`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:nvs_310:-`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:nvs_315:-`,
        fs:  `cpe:2.3:a:intel:proset_wireless:13.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:nvs_510:-`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:7.0.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:nvs_810:-`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:physx_system_software:9.9.814`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:physx_system_software:9.10.514`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:physx_system_software:260.99`,
        fs:  `cpe:2.3:h:ibm:storwize_v5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:pvsonydll:1.0.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.0\(2.46\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_k1200:-`,
        fs:  `cpe:2.3:a:yuriy_v_semenikhin:yvs_image_gallery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_k420:-`,
        fs:  `cpe:2.3:a:equis:metastock:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_k620:-`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m1000m:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m2000:-`,
        fs:  `cpe:2.3:a:apple:safari:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m2000m:-`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m3000m:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xg5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m4000:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)n1\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m4000m:-`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m5000:-`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m5000m:-`,
        fs:  `cpe:2.3:a:apache:wicket:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m500m:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m5500:-`,
        fs:  `cpe:2.3:a:rpm:rpm:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m6000:-`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_m600m:-`,
        fs:  `cpe:2.3:a:hp:array_diagnostics_utility:9.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_p5000:-`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:quadro_p6000:-`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:nvidia:titan_x:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nvidia:wmi:275.89`,
        fs:  `cpe:2.3:a:ca:siteminder:12.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nwtc:nwtc_mobile:1.4.17::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nyc:liver_health_-_hepatitis_c:2.0.0::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nytimes:times_reader:2.54`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:nzhondas:nzhondas.com:3.6.14::~~~android~~`,
        fs:  `cpe:2.3:a:hp:7500_7600_7700_help1:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.1`,
        fs:  `cpe:2.3:a:afterlogic:mailsuite_pro:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.2`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.2.5`,
        fs:  `cpe:2.3:a:klassens_project:klassens:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.3`,
        fs:  `cpe:2.3:a:emulex:common_san_management:31.1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.3.5`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.3.6`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.398.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.4.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0.4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.4.6`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.4.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.4.8`,
        fs:  `cpe:2.3:a:phpjabbers:appointment_scheduler:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.4.9`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.4.3830.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.4.9.1`,
        fs:  `cpe:2.3:a:perl:perl:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.5.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.5.5`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.6`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.6.1`,
        fs:  `cpe:2.3:a:python:python:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.6.2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.6.3`,
        fs:  `cpe:2.3:a:wpgetready:nextcellent_gallery:1.9.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.6.4`,
        fs:  `cpe:2.3:a:gajim:gajim:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.6.5`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.7`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.92:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.7.5`,
        fs:  `cpe:2.3:a:tumbleweed:validation_authority:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:0.7.6`,
        fs:  `cpe:2.3:a:microsoft:windows_2000_terminal_services:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:1.0`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:1.1`,
        fs:  `cpe:2.3:a:python:python:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o-dyn:collabtive:1.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:o2micro:oz776_scr_cardbus_v1.1.3.6:1.1.3.6`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oar_project:oar:2.5.6`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oberthur:id-one_cosmo:5.2`,
        fs:  `cpe:2.3:a:apache:subversion:1.10.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oberthur:id-one_cosmo:5.2:a`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oberthur:id-one_cosmo:64`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.0`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.0.1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.0.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.0.3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.0.4`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_at\&amp;t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.3`,
        fs:  `cpe:2.3:a:autodesk:map_3d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.3.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.3.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(16\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.3.3`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.3.4`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.4`,
        fs:  `cpe:2.3:a:cisco:connected_grid_network_management_system:3.0\(0.35\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.4.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.4.2`,
        fs:  `cpe:2.3:a:symantec:enterprise_firewall:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.5`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.5.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.2.0.2070:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.5.2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.5.3`,
        fs:  `cpe:2.3:a:apache:knox:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objective_development:little_snitch:3.6.1`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:objectraku:raku_symbol_server:3.0.2008`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.0`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.1`,
        fs:  `cpe:2.3:o:huawei:s5310hi_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.2`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.3`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.4`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.5`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.6`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.7`,
        fs:  `cpe:2.3:a:zhwnl:ecalendar2:4.5.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.8`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.9`,
        fs:  `cpe:2.3:o:d-link:dcs-931l_firmware:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.10`,
        fs:  `cpe:2.3:a:gnu:gdb:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.11`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.12`,
        fs:  `cpe:2.3:a:ca:business_protection_suite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.13`,
        fs:  `cpe:2.3:a:rpm:rpm:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.14`,
        fs:  `cpe:2.3:a:microsoft:access:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.15`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.16`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.17`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.18`,
        fs:  `cpe:2.3:h:huawei:svn3000:v100r002c02spc802b041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.19`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.40.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.2.20`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.2`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.3`,
        fs:  `cpe:2.3:a:citrix:presentation_server_client:10.200.2650:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.4`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.5`,
        fs:  `cpe:2.3:a:php:php:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.6`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.7`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.8`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_85:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.9`,
        fs:  `cpe:2.3:a:apple:cups:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.10`,
        fs:  `cpe:2.3:a:php:php:5.4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.11`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.12`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.13`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2002:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.14`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.15`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.16`,
        fs:  `cpe:2.3:a:ntt:050_plus:4.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.17`,
        fs:  `cpe:2.3:o:opensuse:opensuse:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.18`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_hp_procurve:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.19`,
        fs:  `cpe:2.3:a:cybozu:office:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.3.20`,
        fs:  `cpe:2.3:a:google:v8:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0:rc11`,
        fs:  `cpe:2.3:a:gnome:evolution:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0:rc13`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0:rc14`,
        fs:  `cpe:2.3:a:solarwinds:log_forwarder_for_windows:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0:rc15`,
        fs:  `cpe:2.3:a:apache:struts:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0:rc16`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0:rc6`,
        fs:  `cpe:2.3:a:att:communication_manager:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0:rc7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0:rc9`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:obm:open_business_management:2.4.0.1`,
        fs:  `cpe:2.3:a:isc:bind:9.9.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocaml:ocaml:4.02.3`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oce:windows_printer_driver:1.19`,
        fs:  `cpe:2.3:o:cisco:ios:3.6.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oceanavenue:ocean_avenue_mobile_pro:2::~~~android~~`,
        fs:  `cpe:2.3:a:isc:bind:9.5.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.0.1`,
        fs:  `cpe:2.3:a:bib2html_project:bib2html:0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.0.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.0.3`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.0.4`,
        fs:  `cpe:2.3:a:citrix:access_gateway:4.5:hf1:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.0.5`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-51:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.46.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.2`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.3`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:hpc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.4`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.5`,
        fs:  `cpe:2.3:a:microsoft:ie:7.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.6`,
        fs:  `cpe:2.3:a:s9y:serendipity:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.8`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1025:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.9`,
        fs:  `cpe:2.3:a:amazon:kindle:4.5.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.10`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:4.3.0:cp04:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.11`,
        fs:  `cpe:2.3:a:koha:koha:3.16.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.12`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.217.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.1.13`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.2:beta1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.9\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.2:beta2`,
        fs:  `cpe:2.3:a:displaylink:displaylink_core_software:6.0.33743.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.2:rc1`,
        fs:  `cpe:2.3:a:tigertext:tigertext:3.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.2:rc2`,
        fs:  `cpe:2.3:h:cisco:unity_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.2:rc3`,
        fs:  `cpe:2.3:a:recipes-writer_project:recipes-writer:1.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.2.1`,
        fs:  `cpe:2.3:o:huawei:nip6300_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.2.2`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.3`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.3:rc1`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.25:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.3:rc2`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.3:rc3`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp6015:q3932a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.3.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:4.3.2`,
        fs:  `cpe:2.3:a:oracle:project_contracts:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:5.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:5.0:rc1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.3:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:5.0.1`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:5.0.2`,
        fs:  `cpe:2.3:a:apple:remote_desktop:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:5.0.2:beta1`,
        fs:  `cpe:2.3:h:xerox:workcentre:m128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:5.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:5.1:beta1`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0:beta1`,
        fs:  `cpe:2.3:a:sun:one_directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0:rc1`,
        fs:  `cpe:2.3:a:x:libxinerama:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0:rc3`,
        fs:  `cpe:2.3:a:hp:productcontextnpi:70.0.231.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0.1`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0.2`,
        fs:  `cpe:2.3:h:supermicro:x9drd-7ln4f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.0.3`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:3.2.1:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.1.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p346:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:6.2:rc1`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.0.1`,
        fs:  `cpe:2.3:a:zpanelcp:zpanel:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.1:beta1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.1.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.13:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.1.2`,
        fs:  `cpe:2.3:a:skype:skype:4.2.0.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.1.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.617:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.1.4`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0584:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.1.5`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:7.1.6`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocportal:ocportal:9.0.16`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ocshield:datagard_vpn_%2b_av:%407f050013::~~~android~~`,
        fs:  `cpe:2.3:a:rewardingyourself:rewardingyourself:-:*:*:*:*:andriod:*:*`,
    },
     
    {
        uri: `cpe:/a:ocsinventory-ng:ocsinventory_ng:-`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.45`,
        fs:  `cpe:2.3:h:linksys:wrt54gl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.46`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.47`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.48`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.49`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.50`,
        fs:  `cpe:2.3:a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.51`,
        fs:  `cpe:2.3:a:samba:samba:3.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.52`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.53`,
        fs:  `cpe:2.3:a:ibm:security_privileged_identity_manager:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.54`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.55`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.56`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.57`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.58`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.59`,
        fs:  `cpe:2.3:a:rzip_project:rzip:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.60`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.61`,
        fs:  `cpe:2.3:a:imember360:imember360:3.4.015:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.62`,
        fs:  `cpe:2.3:a:google:chrome:14.0.785.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.63`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.64`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.65`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.66`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.4:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.67`,
        fs:  `cpe:2.3:a:osinet:classified_ads:7.x-3.1:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.68`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p175:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.69`,
        fs:  `cpe:2.3:a:busybox:busybox:1.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.70`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.71`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.72`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.73`,
        fs:  `cpe:2.3:h:3com:3cnj220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.74`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.75`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2011.728.1723.29300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.76`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.77`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:a4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.78`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.79`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.80`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.8:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.81`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.82`,
        fs:  `cpe:2.3:a:symantec:liveupdate:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.83`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.84`,
        fs:  `cpe:2.3:a:ecos:embperl:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.85`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.86`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.622:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.87`,
        fs:  `cpe:2.3:a:apache:hadoop:2.0.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.88`,
        fs:  `cpe:2.3:a:adobe:after_effects:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.89`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.90`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.91`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1512c-1_pn_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.92`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.93`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.94`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.95`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.37:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.96`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.97`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.3sq:3.3.1sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.98`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp2:x32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.99`,
        fs:  `cpe:2.3:a:ibm:tivoli_configuration_manager:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.100`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup_agent:-:*:oracle:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.101`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.102`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.103`,
        fs:  `cpe:2.3:a:csounds:csound:5.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.104`,
        fs:  `cpe:2.3:a:isc:bind:9.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.105`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_console:8.0.6.622:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.106`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.107`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd326a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.108`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.109`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.110`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1057.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.111`,
        fs:  `cpe:2.3:a:altiris:connector_for_wise:6.1.138:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.112`,
        fs:  `cpe:2.3:a:apache:archiva:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.113`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.114`,
        fs:  `cpe:2.3:a:opscode:chef:0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.115`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.116`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.117`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.118`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.119`,
        fs:  `cpe:2.3:a:perl:perl:5.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.120`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.121`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.122`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.123`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.124`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.1:*:*:*:lombardi:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.125`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.126`,
        fs:  `cpe:2.3:a:unrtf_project:unrtf:0.21.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.127`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p162:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.128`,
        fs:  `cpe:2.3:a:aol:aim:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.129`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd330a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.130`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(3a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.131`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(2\)n2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.132`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.133`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.134`,
        fs:  `cpe:2.3:o:cisco:conference_connection:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.135`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.136`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.137`,
        fs:  `cpe:2.3:a:ca:arcserve_backup_client_agent_for_windows:12.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.138`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3203a:a.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.139`,
        fs:  `cpe:2.3:a:microsoft:windows_media_rights_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.140`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_mobile:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.141`,
        fs:  `cpe:2.3:a:dell:dw_wlan_card_utility:5.60.48.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.142`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.143`,
        fs:  `cpe:2.3:a:apache:sling_auth_core_component:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.144`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.145`,
        fs:  `cpe:2.3:a:impliedbydesign:navigate:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.146`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.3:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.147`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4500_series_software:4.5\(1.45\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.148`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.13:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.149`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.150`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.151`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.152`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.153`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.154`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp1:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.155`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.156`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.157`,
        fs:  `cpe:2.3:a:busybox:busybox:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.158`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.159`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.47.5133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.160`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.161`,
        fs:  `cpe:2.3:a:apache:derby:10.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.162`,
        fs:  `cpe:2.3:a:adobe:fireworks_mx:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.163`,
        fs:  `cpe:2.3:a:opera:opera_browser:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.164`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.165`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.166`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.167`,
        fs:  `cpe:2.3:a:intel:pro_alerting_agent:12.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.168`,
        fs:  `cpe:2.3:a:iversemedia:archie_comics:1.07:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.169`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.170`,
        fs:  `cpe:2.3:a:citrix:xenserver:6.2.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.171`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.172`,
        fs:  `cpe:2.3:a:kwoksys:information_server:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.173`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.174`,
        fs:  `cpe:2.3:a:oracle:knowledge_management:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.175`,
        fs:  `cpe:2.3:a:isc:bind:9.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.176`,
        fs:  `cpe:2.3:a:keyinternet:invex:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.178`,
        fs:  `cpe:2.3:a:canon:imagerunner_8500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.179`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.180`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.181`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.182`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.183`,
        fs:  `cpe:2.3:a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.5.1:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.184`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.185`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.186`,
        fs:  `cpe:2.3:a:ca:cleverpath_olap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.187`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.191`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.192`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.199`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.205`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.187:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.206`,
        fs:  `cpe:2.3:a:cisco:emergency_responder:10.5\(1.10000.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.209`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.210`,
        fs:  `cpe:2.3:h:cisco:asa_5500:7.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.211`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.214`,
        fs:  `cpe:2.3:h:hp:color_laserjet_m775dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.215`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:11.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.216`,
        fs:  `cpe:2.3:a:pcre:perl_compatible_regular_expression_library:8.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.217`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.218`,
        fs:  `cpe:2.3:a:horde:imp:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.220`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.221`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.222`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.224`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.225`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.226`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.227`,
        fs:  `cpe:2.3:a:1800contacts:1800contacts_app:2.7.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.228`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6:\(2\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.229`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.236`,
        fs:  `cpe:2.3:a:citrix:broadcast_server:6.1:*:cisco:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.239`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:5.2:2003q4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.245`,
        fs:  `cpe:2.3:a:vmware:tools:8.3.2.1593:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.246`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.247`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.249`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.250`,
        fs:  `cpe:2.3:a:cisco:webex_advanced_recording_format_player:t27ld:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.252`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.258`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.260`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.266`,
        fs:  `cpe:2.3:a:aol:browser:1.7:-:standalone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.267`,
        fs:  `cpe:2.3:h:hp:jg861a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.268`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.269`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.270`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.271`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:ccd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.272`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.273`,
        fs:  `cpe:2.3:a:vmware:workstation:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.274`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.275`,
        fs:  `cpe:2.3:a:microsoft:ftp_service:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.276`,
        fs:  `cpe:2.3:a:zoodles:kid_mode\:_free_games_\&#43;_lock:4.9.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.277`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.278`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.279`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.280`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.283`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.284`,
        fs:  `cpe:2.3:a:sixdead:brain_lab_-_brain_age_games_iq:2.37:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.287`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.289`,
        fs:  `cpe:2.3:h:hp:0235a20k:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.290`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_enterprise_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.291`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc654a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.292`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.293`,
        fs:  `cpe:2.3:a:netscape:publishingxpert:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.295`,
        fs:  `cpe:2.3:a:carbonblack:carbon_black:4.1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.296`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.297`,
        fs:  `cpe:2.3:h:polycom:soundpoint_ip_601:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.298`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.299`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.300`,
        fs:  `cpe:2.3:a:mark_theunissen:views_lang_switch:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.301`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p34:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.304`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:1.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.305`,
        fs:  `cpe:2.3:a:saltstack:salt:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.309`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.310`,
        fs:  `cpe:2.3:a:apple:numbers:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.313`,
        fs:  `cpe:2.3:a:gnu:grep:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.316`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.317`,
        fs:  `cpe:2.3:a:hp:business_availability_center:7.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.318`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.319`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.21:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.320`,
        fs:  `cpe:2.3:h:hp:jg209a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.321`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.322`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.323`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.769:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.324`,
        fs:  `cpe:2.3:a:ibm:platform_symphony:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.325`,
        fs:  `cpe:2.3:a:isc:bind:9.8.3:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.326`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.327`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.328`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.329`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.330`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.331`,
        fs:  `cpe:2.3:a:h-dvisa:harley-davidson_visa:1.18:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.332`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.31.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.333`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.334`,
        fs:  `cpe:2.3:a:nvidia:nview:135.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.335`,
        fs:  `cpe:2.3:a:flood-it_project:flood-it:4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.336`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.337`,
        fs:  `cpe:2.3:a:sap:netweaver:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.338`,
        fs:  `cpe:2.3:a:adobe:freehand_mx:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.339`,
        fs:  `cpe:2.3:a:opsview:opsview:4.2:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.340`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.341`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.342`,
        fs:  `cpe:2.3:a:eviware:soapui:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.343`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.344`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.345`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.346`,
        fs:  `cpe:2.3:h:dell:precision_t1600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.347`,
        fs:  `cpe:2.3:a:lester_chan:wp-downloadmanager:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.348`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.349`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.350`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.351`,
        fs:  `cpe:2.3:a:drupal-id:counter_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.352`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.353`,
        fs:  `cpe:2.3:a:tibco:spotfire_deployment_kit:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.354`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.355`,
        fs:  `cpe:2.3:a:wtradersactivity_project:wtradersactivity:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.356`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp2:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.357`,
        fs:  `cpe:2.3:a:gnu:queue:1.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.358`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:10.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.359`,
        fs:  `cpe:2.3:a:google:earth:4.2.205.5730:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.360`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.361`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.362`,
        fs:  `cpe:2.3:a:gentoo:mldonkey_ebuild:2.9.0:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.363`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp2a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.364`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.365`,
        fs:  `cpe:2.3:a:hp:icc_profiles:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.366`,
        fs:  `cpe:2.3:a:atlassian:jira:2.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.367`,
        fs:  `cpe:2.3:o:google:android:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.368`,
        fs:  `cpe:2.3:a:google:chrome:7.0.548.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.369`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.370`,
        fs:  `cpe:2.3:h:huawei:5710hi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.371`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.372`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg210-10:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.373`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(3b\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.374`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.375`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.376`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.377`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.378`,
        fs:  `cpe:2.3:h:hp:t610:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.379`,
        fs:  `cpe:2.3:a:apple:webobjects:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.380`,
        fs:  `cpe:2.3:h:sun:fire_x4600_server:sw_1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.381`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.382`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.12:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.383`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.384`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.385`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.386`,
        fs:  `cpe:2.3:a:haxx:curl:7.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.387`,
        fs:  `cpe:2.3:a:devsaran:fresh:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.388`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.389`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.009:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.390`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.391`,
        fs:  `cpe:2.3:a:gsitecrawler:gsitecrawler:v1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.392`,
        fs:  `cpe:2.3:a:ibm:websphere_business_modeler_basic:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.393`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.394`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.395`,
        fs:  `cpe:2.3:a:cisco:vpn_client:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.396`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_software_development_kit:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.397`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.398`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.399`,
        fs:  `cpe:2.3:a:invensys:wonderware_inbatch:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.400`,
        fs:  `cpe:2.3:o:cisco:rvs4000_firmware:2.0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.401`,
        fs:  `cpe:2.3:h:cisco:5500_series_adaptive_security_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.402`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.403`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.12:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.404`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.405`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.406`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.407`,
        fs:  `cpe:2.3:a:gnu:automake:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.408`,
        fs:  `cpe:2.3:a:apache:coyote_http_connector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.409`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.410`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.411`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.412`,
        fs:  `cpe:2.3:a:artiphp:artiphp_cms:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.413`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.414`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.00:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.415`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.416`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:3.0\(2d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.417`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.418`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.419`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.420`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.421`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.422`,
        fs:  `cpe:2.3:a:apple:webkit:412.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.423`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.424`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.425`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.3:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.426`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.427`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.010:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octobercms:october_cms:1.0.428`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.11-197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.1`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:1.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.2`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.88.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.4`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.5`,
        fs:  `cpe:2.3:a:ssh:secure_shell:1.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.6`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u2\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.7`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.5.1857:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.8`,
        fs:  `cpe:2.3:a:ca:unicenter_remote_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.9`,
        fs:  `cpe:2.3:a:haxx:curl:7.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.10`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.11`,
        fs:  `cpe:2.3:a:skyarc:multifileuploader:0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.12`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.13`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.2-77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.14`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.15`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.16`,
        fs:  `cpe:2.3:a:google:v8:3.24.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.17`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.00.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.18`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.19`,
        fs:  `cpe:2.3:a:apache:subversion:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.20`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.21`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.22`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.287:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.23`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.12154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.24`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.25`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:r6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.0.26`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.0`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.0:beta0001`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:10.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.0:beta0002`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.53:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.3`,
        fs:  `cpe:2.3:a:ekiga:ekiga:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.4`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.5`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.6`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.7`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.12`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.1.13`,
        fs:  `cpe:2.3:h:belden:hirschmann_l2p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.0`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.1.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.0:beta0001`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.1`,
        fs:  `cpe:2.3:a:atmail:atmail:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.2`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:x06ht:ii:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.3`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:6.9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.4`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.01b50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.6`,
        fs:  `cpe:2.3:a:autodesk:dwg_trueview:18.2.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.7`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.8`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.9`,
        fs:  `cpe:2.3:a:hp:mercury_sitescope:8.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.10`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.11`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.15`,
        fs:  `cpe:2.3:a:xcloner:xcloner:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.16`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.1:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.17`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.260:update26:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.19`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.20`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.21`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.22`,
        fs:  `cpe:2.3:a:google:chrome:5.0.306.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.23`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.2.24`,
        fs:  `cpe:2.3:a:bea:aqualogic_service_bus:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.0:beta0001`,
        fs:  `cpe:2.3:a:boson:exam_environment:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.0:beta0002`,
        fs:  `cpe:2.3:h:cisco:sg300-28mp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.1`,
        fs:  `cpe:2.3:a:ibm:java:6.0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.9:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.4`,
        fs:  `cpe:2.3:o:alliedtelesis:at-rg634a_firmware:3.3\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.5`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.6`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.8`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.9`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.10`,
        fs:  `cpe:2.3:a:oracle:secure_enterprise_search:10.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.11`,
        fs:  `cpe:2.3:a:microsoft:excel:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.12`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.14`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.15`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.16`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.17`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.18`,
        fs:  `cpe:2.3:o:microsoft:windows_10:1511:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.19`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.7.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.20`,
        fs:  `cpe:2.3:a:adobe:connect:9.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.21`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.22`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.24`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.25`,
        fs:  `cpe:2.3:a:web2py:web2py:1.77.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.26`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.3.27`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.0`,
        fs:  `cpe:2.3:a:atlassian:jira:2.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.0:beta0001`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.886:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.0:beta0002`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.3`,
        fs:  `cpe:2.3:a:pgp:freeware:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.4`,
        fs:  `cpe:2.3:a:deltek:open_plan_professional:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.5`,
        fs:  `cpe:2.3:a:hp:product_assistant:82.0.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.6`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.7`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.2p5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.8`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.9`,
        fs:  `cpe:2.3:o:cisco:ios_xr:6.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.10`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.11`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.12`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.13`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.14`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp1:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.4.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.5.1`,
        fs:  `cpe:2.3:a:vmware:server:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.0mra:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.5.4`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.5.5`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.5.6`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.5.7`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-52c-pwr-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.5.8`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.5.9`,
        fs:  `cpe:2.3:a:apple:quictime:7.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.6.0`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.6.1`,
        fs:  `cpe:2.3:a:emc:documentum_digital_asset_manager:6.5:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.6.2`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.0`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.1`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.3`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_deployment:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.4`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:11.0.0.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.7`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:637:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.8`,
        fs:  `cpe:2.3:a:apple:itunes:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.9`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.10`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.11`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.12`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.13`,
        fs:  `cpe:2.3:a:xnview:xnview:1.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.14`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.15`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.16`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.17`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.7.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.0`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.1`,
        fs:  `cpe:2.3:a:icinga:icinga:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.2`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.3`,
        fs:  `cpe:2.3:h:ibm:system_x3950_x5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.4`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.5`,
        fs:  `cpe:2.3:a:jenkins:git:1.4.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.7`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.8`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.8.9`,
        fs:  `cpe:2.3:a:samba:samba:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.9.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.10.0`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.10.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.0`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.897:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.3`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.4`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.4.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.5`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:s3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.6`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.7`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.9`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.10`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.11`,
        fs:  `cpe:2.3:a:zoneo-soft:phptraffica:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.12`,
        fs:  `cpe:2.3:a:buffalotech:wer-ag54_firmware:1.12:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.13`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.14`,
        fs:  `cpe:2.3:h:hp:5850_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.15`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.16`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.17`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.11.18`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:6.14.12.5896:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.0`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.1`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.2`,
        fs:  `cpe:2.3:o:f5:tmos:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.3`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.4`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.5`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.6`,
        fs:  `cpe:2.3:a:oracle:xml_developers_kit:12.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.7`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.12.9`,
        fs:  `cpe:2.3:o:huawei:gem-703l_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.0`,
        fs:  `cpe:2.3:a:qemu:qemu:2.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.1`,
        fs:  `cpe:2.3:a:novell:emframe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.2`,
        fs:  `cpe:2.3:a:huawei:campus_series_switch_software:v200r005c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.5`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.6`,
        fs:  `cpe:2.3:a:beijerelectronics:beijer_adp:6.5.0-180_r1967:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.9`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.70.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.13.10`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:4.2.\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.14.1`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.14.15`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.14.159`,
        fs:  `cpe:2.3:a:busybox:busybox:1.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.14.1592`,
        fs:  `cpe:2.3:a:ibm:java:5.0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.14.15926`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.21:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.1`,
        fs:  `cpe:2.3:a:rocomotion:p_link_compact:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.2`,
        fs:  `cpe:2.3:h:cru-inc:ditto_forensic_fieldstation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.3`,
        fs:  `cpe:2.3:a:pantech:uml290:1.5.39.512:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.4`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a1:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.5`,
        fs:  `cpe:2.3:a:f5:big-ip_websafe:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.6`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.07.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.7`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.15.8`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.16.0`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.16.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3y\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.16.2`,
        fs:  `cpe:2.3:h:hp:scanjet_8200c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.16.3`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.65.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.16.4`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:x64-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.16.5`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.16.6`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15:exp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.16.7`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.17.0`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.17.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.17.2`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.8:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:octopus:octopus_deploy:3.17.3`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:offertaviaggi:firenze_map:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:kent-web:clip_board:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:offertaviaggi:venezia_map:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:poi:3.8:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:og_tabs_project:og_tabs:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ogaki_kyoritsu_bank:smartphone_passbook:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6ecg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ohwada:xf-section:1.12a`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oi:minha_oi:1.15.0::~~~android~~`,
        fs:  `cpe:2.3:a:autodesk:sketchbook_express:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:okacloud:domain_name_search_%26_web_host:0.64.13398.55733::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:2:ur1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:okb.co.jp:smartphone_passbook:1.00::~~~android~~`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:okb.co.jp:smartphone_passbook:1.00::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.189:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:okcupid:okcupid_dating:3.4.6::~~~android~~`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:okidata:3037e_network_printer:-`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:okidata:c5400_network_printer:-`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:okidata:c9500_network_printer:-`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ol-commerce_project:ol-commerce:2.1.1`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:olaschool:ola_school:1.2.7.132::~~~android~~`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:olat:olat:7.8.0.1`,
        fs:  `cpe:2.3:a:search_api_autocomplete_project:search_api_autocomplete:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.0`,
        fs:  `cpe:2.3:a:php:php:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.1`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.2`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.3`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.4`,
        fs:  `cpe:2.3:a:emc:retrospect_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.5`,
        fs:  `cpe:2.3:a:castor_project:castor:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.6`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.7`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:google:chrome:6.0.422.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.1`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.2`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.5`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.5f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.6`,
        fs:  `cpe:2.3:a:apple:safari:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.7`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.329:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.9`,
        fs:  `cpe:2.3:a:intel:geomedia_webmap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oleg_kovalchuk:cctags:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oleggo_livestream_project:oleggo_livestream:0.2.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:libexpat:expat:1.95.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oleumtech:sensor_wireless_i%2fo_module:-`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp4:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oleumtech:wio_dh2_wireless_gateway:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:olivetoast:documents_pro_file_viewer:1.11:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:olivetoast:documents_pro_file_viewer:1.11.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oman_news_project:oman_news:1::~~~android~~`,
        fs:  `cpe:2.3:a:apple:quicktime:6.1.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.0`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.1`,
        fs:  `cpe:2.3:a:macromedia:breeze:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.2`,
        fs:  `cpe:2.3:a:websitepanel:websitepanel:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.2.1`,
        fs:  `cpe:2.3:a:gnu:coreutils:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.3`,
        fs:  `cpe:2.3:a:apache:wss4j:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.3.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_replication_server:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.3.2`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.4`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:9.5.0-235:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.4.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.4.2`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.5`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.5.1`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.5.2`,
        fs:  `cpe:2.3:o:alcatel:aos:6.1.3.965:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:1.5.3`,
        fs:  `cpe:2.3:a:apple:safari:3.1.0b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.0.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.0.2`,
        fs:  `cpe:2.3:o:hp:700_series_firmware:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.0.3`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.0.4`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.1`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.1.1`,
        fs:  `cpe:2.3:a:microsoft:windows_2000_resource_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.1.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.1.3`,
        fs:  `cpe:2.3:a:google:v8:3.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.1.4`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.2`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.2.1`,
        fs:  `cpe:2.3:a:otrs:otrs:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omeka:omeka:2.2.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omfg_mobile_project:omfg_mobile:1.1.26:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:2015.006.30060:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omnigroup:omniweb:5.1:563.34`,
        fs:  `cpe:2.3:a:lttng:ust:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omnikey.aaitg:omnikey_cardman:-`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:5.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omnikey.aaitg:omnikey_cardman_4040:-`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:omnistaretools:omnistar_recruiting:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:omron:ns_series_system_program_firmware:8.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:omron:ns_series_system_program_firmware:8.68`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:0.9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:omron:ns_series_system_program_firmware:8.69`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:omron:ns_series_system_program_firmware:8.70`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a5:3.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:omron:ns10_hmi_terminal:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p437:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:omron:ns12_hmi_terminal:-`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:omron:ns15_hmi_terminal:-`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:omron:ns5_hmi_terminal:-`,
        fs:  `cpe:2.3:a:nuance:paperport:11.0.0:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/h:omron:ns8_hmi_terminal:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:one_you_fitness_project:one_you_fitness:1.399::~~~android~~`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onefile:onefile_ignite:1.19::~~~android~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onelouder:friendcaster_chat:2.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:catos:8.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oneorzero:action_and_information_management_system:2.6.0:-:members`,
        fs:  `cpe:2.3:o:siemens:scalance_w700_series_firmware:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oneorzero:action_and_information_management_system:2.7.0`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oneorzero:action_and_information_management_system:2.7.0:-:trial`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oneorzero:action_and_information_management_system:2.8.0:build231211:trial`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.3.176757.1236:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oneplus:oxygenos:4.0.3`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_appliance:7.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onesolutionapps:aaaa_discount_bail:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:ip_interactive_voice_response:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onesolutionapps:ajd_bail_bonds:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onesolutionapps:aloha_bail_bonds:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:mcafee:groupshield_for_exchange:7.0.716.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onesolutionapps:bail_bonds:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onesolutionapps:bust_out_bail:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:hp:bufferchm:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onesolutionapps:reds_anytime_bail:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:onesolutionapps:woodward_bail:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.15.99.904:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:online-solutions:online_solutions_security_suite:1.5.14905.0`,
        fs:  `cpe:2.3:a:microsoft:ie:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ontariosystems:artiva_architect:3.2:mr5`,
        fs:  `cpe:2.3:a:rpm:rpm:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ontariosystems:artiva_healthcare:5.2:mr5`,
        fs:  `cpe:2.3:a:pearlsw:echo_workstation:7.79.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ontariosystems:artiva_rm:3.1:mr7`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ontariosystems:artiva_workstation:1.3.0`,
        fs:  `cpe:2.3:a:gnu:grep:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ontariosystems:artiva_workstation:1.3.9`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ooorl_project:ooorl:-:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:monitor:5.3.5`,
        fs:  `cpe:2.3:a:crear.ne.jp:al-mail32:1.13:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:monitor:5.4.0`,
        fs:  `cpe:2.3:a:zemanta:related_posts:2.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:monitor:5.4.2`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:monitor:5.5.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:monitor:5.5.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.320.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:monitor:5.5.3`,
        fs:  `cpe:2.3:a:bilyoner:bilyoner:2.3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:monitor:6.3.0`,
        fs:  `cpe:2.3:a:openbsd:openbsd:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:monitor:6.3.1`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:system-op5config:2.0.2`,
        fs:  `cpe:2.3:a:quest:sql_optimizer_for_oracle:8.0.0.1551:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:system-op5config:2.0.3`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:system-portal:1.6.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_client:06-50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:op5:system-portal:1.6.2`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1\(3\)sr5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opac_project:opac:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.05.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opalvoip:portable_tool_library:2.10.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opalvoip:portable_tool_library:2.10.2`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opalvoip:portable_tool_library:2.10.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opalvoip:portable_tool_library:2.10.9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opalvoip:portable_tool_library:2.10.10`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opcsystems:opc_systems.net:8.00.0023`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.5c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opcsystems:opcsystems.net:-`,
        fs:  `cpe:2.3:a:stripshow_plugin_project:stripshow:2.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:opcsystems:opcsystems.net:4.0`,
        fs:  `cpe:2.3:a:invensys:dassidirect:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opcsystems:opcsystems.net:5.0`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-classifieds:open_classifieds:1.7.0.2`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-emr:openemr:3.1.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-emr:openemr:3.2.0`,
        fs:  `cpe:2.3:a:php:php:5.4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-emr:openemr:4.0.0`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-emr:openemr:4.1.0`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-emr:openemr:4.1.1`,
        fs:  `cpe:2.3:a:gajim:gajim:0.12.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-realty:open-realty:2.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-realty:open-realty:2.3.4`,
        fs:  `cpe:2.3:o:yamaha:rtw65b:5.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-realty:open-realty:2.5.8`,
        fs:  `cpe:2.3:h:nokia:n95:12.0.0.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:6.20.7`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:6.22.0`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:6.22.1`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:7.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ixg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:7.0.2`,
        fs:  `cpe:2.3:a:wolfcms:wolf_cms:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:7.2.0`,
        fs:  `cpe:2.3:a:spider_contacts_project:spider_contacts:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:7.2.1`,
        fs:  `cpe:2.3:h:avaya:s8100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:7.2.2`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:7.4.0`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:7.4.1`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_foundation:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_appsuite:7.4.2`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_server:6.20.7`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_server:6.22.0`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_server:6.22.1`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_server:7.0.1`,
        fs:  `cpe:2.3:a:webtrends:scheduler_agent:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_server:7.0.2`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:open-xchange_server:7.2.0`,
        fs:  `cpe:2.3:a:cisco:jabber:9.0\(.3\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:open-xchange:ox_guard:2.0.0:rev6`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open_atrium_project:open_atrium:7.x-2.21::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:personal_assistant:1.3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open_explorer_beta_project:open_explorer_beta:0.253::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.2.0:alpha-4:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:open_graph_importer_project:open_graph_importer:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:h:supermicro:x9qri-f\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open_graph_protocol_project:open_graph_protocol:1.0.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open_source_development_team:sthttpd:2.26`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3200a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open_source_development_team:sthttpd:2.26.1`,
        fs:  `cpe:2.3:a:tizen:tizen:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open_source_development_team:sthttpd:2.26.2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open_source_development_team:sthttpd:2.26.3`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:open_source_development_team:sthttpd:2.26.4`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.0`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.0.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.0.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.0.3`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.0.4`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.0.4a`,
        fs:  `cpe:2.3:o:freenas:freenas:0.686.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.1`,
        fs:  `cpe:2.3:a:samba:rsync:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.1.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.1.1`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.1.1a`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp1:tablet_pc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.2`,
        fs:  `cpe:2.3:a:google:chrome:7.0.539.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.2a`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.2b`,
        fs:  `cpe:2.3:a:kokuyo:camiapp:1.21.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.3`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.4`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.5`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server_supplementary:6.4.z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.6`,
        fs:  `cpe:2.3:a:apache:struts:2.0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.7`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.8`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.9`,
        fs:  `cpe:2.3:a:microsoft:windows_mail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.10`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.11`,
        fs:  `cpe:2.3:a:lingotek:lingotek:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.2.13`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.3`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.3.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.3.2`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.3.5`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.3.70`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd918a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.3.74`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.3.77`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.3.81`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4`,
        fs:  `cpe:2.3:a:google:chrome:7.0.531.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.0`,
        fs:  `cpe:2.3:a:mysql:community_server:5.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.3`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.4`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.5`,
        fs:  `cpe:2.3:h:hp:0235a38m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.6`,
        fs:  `cpe:2.3:a:homepage_decorator_perlmailer_project:homepage_decorator_perlmailer:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.7`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.7_pre1`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.7_pre2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.7_pre3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.7_pre4`,
        fs:  `cpe:2.3:a:aximediasoft:slide_show_creator:4.4.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.7_pre5`,
        fs:  `cpe:2.3:h:huawei:eudemon100e:v200r007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.8`,
        fs:  `cpe:2.3:a:huawei:s9700_firmware:v200r003c00spc500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.8_pre1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.42a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.8_pre2`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.8_pre3`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.9`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.10`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.11`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.12`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.14`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.14.1`,
        fs:  `cpe:2.3:o:cisco:wap4410n_firmware:2.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.4.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.10`,
        fs:  `cpe:2.3:a:altiris:connector_solution_data_integration_component:6.5.1149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.11`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.1_b20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.12`,
        fs:  `cpe:2.3:a:owncloud:owncloud:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.21:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.14`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.15`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.154.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.16`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.17`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.18`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.19`,
        fs:  `cpe:2.3:a:peel:peel_shopping:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.20`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.21`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.22`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.23`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.24`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.25`,
        fs:  `cpe:2.3:a:apple:preview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.26`,
        fs:  `cpe:2.3:a:microsoft:debug_interface_access_software_development_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.27`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.28`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.29`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.30`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.31`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.32`,
        fs:  `cpe:2.3:h:hp:color_laserjet_m775z:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.33`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.34`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.35`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.36`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.37`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.38`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.39`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.1.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.50`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.51`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.03b36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.52`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.419.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.53`,
        fs:  `cpe:2.3:a:expressjs:express:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.54`,
        fs:  `cpe:2.3:a:directwebremoting:direct_web_remoting:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.55`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.56`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.57`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_3com:2.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.58`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.59`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.60`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.61`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.62`,
        fs:  `cpe:2.3:a:apprain:apprain:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.63`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.64`,
        fs:  `cpe:2.3:a:google:chrome:5.0.372.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.65`,
        fs:  `cpe:2.3:a:ibm:rational_automation_framework:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.66`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.03.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.67`,
        fs:  `cpe:2.3:a:apple:safari:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.68`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.69`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.70`,
        fs:  `cpe:2.3:a:livezilla:livezilla:3.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.71`,
        fs:  `cpe:2.3:a:winzip:winzip:15.0.9302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.72`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04s:sp10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.73`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.74`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.75`,
        fs:  `cpe:2.3:a:checkpoint:secure_platform_ng:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.76`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.77`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.5.78`,
        fs:  `cpe:2.3:a:apache:camel:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.1`,
        fs:  `cpe:2.3:o:sun:solaris:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.2`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp1:x86-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.2.1`,
        fs:  `cpe:2.3:a:docker:docker:0.10.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.3`,
        fs:  `cpe:2.3:a:emc:networker_module_for_microsoft_applications:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p243_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.5.1`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.5.2`,
        fs:  `cpe:2.3:o:cisco:unified_ip_conference_station_7935:3.2\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.6`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.7`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.8`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.9`,
        fs:  `cpe:2.3:a:sympa:sympa:4.2b.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.10`,
        fs:  `cpe:2.3:a:sun:java_plug-in:1.4.2_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.11`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.12`,
        fs:  `cpe:2.3:a:php:php:5.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sv3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.14.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.15`,
        fs:  `cpe:2.3:h:wdc:my_net_n900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.6.16`,
        fs:  `cpe:2.3:a:google:chrome:11.0.684.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.2`,
        fs:  `cpe:2.3:a:microsoft:word:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.3`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.819:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.4`,
        fs:  `cpe:2.3:a:ibm:filenet_content_manager:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.8`,
        fs:  `cpe:2.3:a:djangoproject:django:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.10`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.11`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.12`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.13`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd335a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.14`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.15`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.16`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg301a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.17`,
        fs:  `cpe:2.3:a:xen:xen:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.18`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.19`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:7.2.0.722:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.20`,
        fs:  `cpe:2.3:a:dymo:dymo_label:8.2.2.996:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.21`,
        fs:  `cpe:2.3:a:mysql:winmysqladmin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.22`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.23`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.24`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.25`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.26`,
        fs:  `cpe:2.3:a:php:php:5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.27`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.28`,
        fs:  `cpe:2.3:a:yassl:cyassl:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.29`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.30`,
        fs:  `cpe:2.3:a:debian:adequate:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openafs:openafs:1.7.31`,
        fs:  `cpe:2.3:a:imgpals:img_pals_photo_host:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbravo:openbravo_erp:2.40`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbravo:openbravo_erp:2.50`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.0\(2\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbravo:openbravo_erp:3.0`,
        fs:  `cpe:2.3:a:bannersky:bsk_pdf_manager:1.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:ftpd:-`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update4:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:ftpd:5.51`,
        fs:  `cpe:2.3:a:perl:perl:5.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:ftpd:5.60`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:libressl:2.1.1`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openbsd:-`,
        fs:  `cpe:2.3:h:huawei:secospace_usg6300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:-`,
        fs:  `cpe:2.3:a:python:pillow:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.0`,
        fs:  `cpe:2.3:a:php:php:5.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.2`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.3`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.4`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.3:6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.6`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.7`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.8`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openbsd:2.9`,
        fs:  `cpe:2.3:a:plone:plone:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:2.9`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openbsd:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.0`,
        fs:  `cpe:2.3:a:microsoft:windows_2000_terminal_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openbsd:3.1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.1`,
        fs:  `cpe:2.3:a:sap:fi_manager_self-service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openbsd:3.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.3`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.4`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.5`,
        fs:  `cpe:2.3:a:oracle:global_order_promising:12.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.6`,
        fs:  `cpe:2.3:a:apple:quicktime:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.7`,
        fs:  `cpe:2.3:a:invensys:wonderware_inbatch:9.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.8`,
        fs:  `cpe:2.3:a:mybboard:mybb:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:3.9`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.0`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openbsd:4.1`,
        fs:  `cpe:2.3:a:symantec:client_firewall:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.1`,
        fs:  `cpe:2.3:a:oracle:jsp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openbsd:4.2`,
        fs:  `cpe:2.3:o:juniper:junos:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.2`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1yc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xb11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.6`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.7`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.8`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.24:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openbsd:openbsd:4.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:opensmtpd:5.3.1`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_unix_and_openvms:14.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:opensmtpd:5.3.2`,
        fs:  `cpe:2.3:a:devsaran:company:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:opensmtpd:5.3.3`,
        fs:  `cpe:2.3:a:cybernetikz:easy_social_icons:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:opensmtpd:5.4.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:opensmtpd:5.4.2`,
        fs:  `cpe:2.3:a:google:chrome:15.0.859.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.3.92.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.2.1`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.2.2`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_portal_server:2001:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.2.3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.2.27`,
        fs:  `cpe:2.3:a:djinnworks:stickman_ski_racer:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.3`,
        fs:  `cpe:2.3:h:seowonintech:swc-9100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc5:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.5.7`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1048.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:1.5.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.1`,
        fs:  `cpe:2.3:h:hp:j9573a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.1.1`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.3`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.3.1`,
        fs:  `cpe:2.3:a:novell:iprint:4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.5.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.5.2`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.9`,
        fs:  `cpe:2.3:a:anixis:password_policy_client:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.9.9`,
        fs:  `cpe:2.3:h:cisco:sg500-52p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.9.9p2`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.9p1`,
        fs:  `cpe:2.3:a:php:com_extensions:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:2.9p2`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.0`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_agent:10.0.12703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.0.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp4:datacenter_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.0.1p1`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.0.2`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.0.2p1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.0p1`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.1`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.1p1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.2`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.2.2`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.2.2p1`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.2.3p1`,
        fs:  `cpe:2.3:a:trustix:antivirus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.3`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:18.0.l059219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.3p1`,
        fs:  `cpe:2.3:a:fishshell:fish:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.4`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.4p1`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.5`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.5p1`,
        fs:  `cpe:2.3:a:jenkins-ci:build_failure_analyzer:1.5.1:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.6`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.6.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.6.1p1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.6.1p2`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.7`,
        fs:  `cpe:2.3:a:shavlik:netchk_configure:4.1.0.209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.7.1`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.7.1p1`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.7.1p2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.8`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.8.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.14.0:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.8.1p1`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.9`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.9.1`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.0.3:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:3.9.1p1`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.0`,
        fs:  `cpe:2.3:a:opnet:ace_analyst:15.0.0.8652:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.0p1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.1`,
        fs:  `cpe:2.3:a:mobileappsuite:grandma\&#39;s_grotto:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.1p1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.7.2\(4937\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.2`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.2p1`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_os_deployment:7.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.3`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.3p1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tcu4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.3p2`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.0.0:rc522:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ya:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.4p1`,
        fs:  `cpe:2.3:a:perl:perl:5.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.5`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.6`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.7`,
        fs:  `cpe:2.3:o:novell:netware:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.7p1`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.8`,
        fs:  `cpe:2.3:a:maianscriptworld:maian_weblog:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:4.9`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:-:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.8.5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.0:p1`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.1:p1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.806.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.2`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.2:p1`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.3`,
        fs:  `cpe:2.3:a:rsa:access_manager_server:6.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.3:p1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.4`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.4:p1`,
        fs:  `cpe:2.3:a:macromedia:contribute:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.5`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.5:p1`,
        fs:  `cpe:2.3:a:vips:vips:7.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.6`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.6:p1`,
        fs:  `cpe:2.3:a:9bis:kitty:0.66.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.7`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_lights_out_2:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.7:p1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.8`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.8:p1`,
        fs:  `cpe:2.3:o:toshibacommerce:4690_point_of_sale_operating_system:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.8p2`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.9`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:5.9:p1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.285.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.0:p1`,
        fs:  `cpe:2.3:a:tenable:nessus:6.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.1`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.1:p1`,
        fs:  `cpe:2.3:a:xymon:xymon:4.2:rc20060712:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.2`,
        fs:  `cpe:2.3:a:gojbm:coe_message_processor:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.2:p1`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds3524:1746:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.2:p2`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.3`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.3:p1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.4`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.4:p1`,
        fs:  `cpe:2.3:a:git-scm:git:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.5`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.50:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.5:p1`,
        fs:  `cpe:2.3:a:standards_based_linux_instrumentation_project:standards-based_linux_common_information_model_client:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.6`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.6:p1`,
        fs:  `cpe:2.3:a:altiris:discovery_for_rim:6.1.1091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.7`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.7:p1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.8`,
        fs:  `cpe:2.3:a:ca:inoculateit:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.8:p1`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.9`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:6.9:p1`,
        fs:  `cpe:2.3:a:openstack:neutron:2014.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:7.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1281.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:7.0:p1`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4500_series_software:4.3\(2.18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:7.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:7.1:p1`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:7.2:p2`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.0:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:7.3`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:6.40.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openbsd:openssh:7.3:p1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opencart:opencart:2.1.0.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openchrome:openchrome:0.3.2`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openconstructor_project:openconstructor:3.12.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendaylight:opendaylight:1.0`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendental:opendental:16.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.2:-`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.2:a`,
        fs:  `cpe:2.3:a:veritas:license_utilities:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.2:b`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1\(3\)n1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.3:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:575:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.3:a`,
        fs:  `cpe:2.3:h:dell:poweredge_2950:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.5`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.6`,
        fs:  `cpe:2.3:a:avexim:noticias_bebes_beybies:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.7:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.7:beta`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.6.8`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.7`,
        fs:  `cpe:2.3:o:juniper:screenos:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.7.1`,
        fs:  `cpe:2.3:a:tm_software:tempo:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.7.2`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opendocman:opendocman:1.2.7.3`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:openelec:openelec:-`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.1\(1\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openelectrical:open_electrical_webser:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.04.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.2.5`,
        fs:  `cpe:2.3:h:cisco:nexus_6001:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:28.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.3.1`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.72:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.3.2`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.4`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:gold:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.4.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.822:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.4.2`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.1:*:free:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.5`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.5.1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:enterprise_distribution:1.5.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:ibacm:1.0.5`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:ibacm:1.0.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:ibacm:1.0.7`,
        fs:  `cpe:2.3:h:xerox:document_centre_432:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:ibutils:1.2-11.2`,
        fs:  `cpe:2.3:o:cisco:dpq3925_8x4_docsis_3.0_wireless_residential_gateway_with_embedded_digital_voice_adapter:r1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:ibutils:1.5.7`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:ibutils:1.5.7-2`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfabrics:librdmacm:1.0.16`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openfiler:openfiler:2.99`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openid:openid4java:0.9.2`,
        fs:  `cpe:2.3:a:ncr:pci_configurator:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openid:openid4java:0.9.3`,
        fs:  `cpe:2.3:a:microsoft:office_web_components:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openid:openid4java:0.9.4.339`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openid:openid4java:0.9.5.593`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20030313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openidm_project:openidm:4.0.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openidm_project:openidm:4.5.0`,
        fs:  `cpe:2.3:a:apache:synapse:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3:beta_2`,
        fs:  `cpe:2.3:a:pass4sure:questions_and_answers_for_ec-council_ec0-0:3.0:*:*:*:demo:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3:beta_3`,
        fs:  `cpe:2.3:a:apache:hadoop:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3:rc_1`,
        fs:  `cpe:2.3:a:csc:ssoserviceclient:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3.1`,
        fs:  `cpe:2.3:a:rovicorp:sonic_update_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3.2`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3.3`,
        fs:  `cpe:2.3:a:ecava:integraxor:3.5.3900.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3.4`,
        fs:  `cpe:2.3:a:adobe:golive:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3.5`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.3.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4`,
        fs:  `cpe:2.3:a:henner_zeller:henplus:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4:beta_1`,
        fs:  `cpe:2.3:a:aftab:tickfa:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4:beta_2`,
        fs:  `cpe:2.3:a:php:php:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4:beta_3`,
        fs:  `cpe:2.3:a:facebook:zhang_zhijun_taiwan_visit_2014-06-25:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4:rc_1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4.1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4.2`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0536:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4.4`,
        fs:  `cpe:2.3:h:cabletron:6h252-17:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4.5`,
        fs:  `cpe:2.3:a:gnu:bash:1.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4.6`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:1.4.7`,
        fs:  `cpe:2.3:a:codiad:codiad:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:2.0:beta_1`,
        fs:  `cpe:2.3:h:cisco:sg500xg-8f8t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:2.0:beta_2`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:2.0:rc_1`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openinfosecfoundation:suricata:2.0.7`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:1.3`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.8.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:1.4`,
        fs:  `cpe:2.3:a:apache:geronimo:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:1.5`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:1.5.1`,
        fs:  `cpe:2.3:a:hp:image_zone:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:1.5.2`,
        fs:  `cpe:2.3:a:otrs:faq:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:2.0.0`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:2.1.0`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:2.1.1`,
        fs:  `cpe:2.3:a:mozilla:camino:0.8:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openjpeg:openjpeg:2.1.2`,
        fs:  `cpe:2.3:a:oracle:agile_product_lifecycle_management_framework:9.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openkm:openkm:5.1.7`,
        fs:  `cpe:2.3:a:openstack:swift:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openkm:openkm:5.1.8`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openkm:openkm:6.4.18`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs5:12.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:-`,
        fs:  `cpe:2.3:h:intel:c204_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.7`,
        fs:  `cpe:2.3:a:marvell:mrvlusgtracking:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.8`,
        fs:  `cpe:2.3:a:kde:ark:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.9`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.10`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.11`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.12`,
        fs:  `cpe:2.3:a:openstack:swift:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.13`,
        fs:  `cpe:2.3:a:microsoft:excel:-:-:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.14`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.15`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.16`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.17`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.18`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.19`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.20`,
        fs:  `cpe:2.3:a:wasen:mod_simplefileupload:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.21`,
        fs:  `cpe:2.3:a:skype:skype:2.6.0.103:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.22`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.23`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.24`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.25`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.26`,
        fs:  `cpe:2.3:a:piriform:ccleaner:5.01.5075:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.27`,
        fs:  `cpe:2.3:a:freeradius:freeradius:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.28`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.29`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.30`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.31`,
        fs:  `cpe:2.3:a:vmware:vcenter_update_manager:4.0.0.5332:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.32`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.33`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.34`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.35`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.36`,
        fs:  `cpe:2.3:a:avaya:computer_telephony:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.37`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc6:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.38`,
        fs:  `cpe:2.3:a:apache:mod_python:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.39`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openldap:openldap:2.4.40`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5054-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openmrs:openmrs:2.1::~~standalone~~~`,
        fs:  `cpe:2.3:a:gnu:tramp:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:-`,
        fs:  `cpe:2.3:a:ca:unicenter_management_microsoft_exchange:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.0`,
        fs:  `cpe:2.3:a:f5:arx:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-24p-si_ls-5100-24p-si-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.3`,
        fs:  `cpe:2.3:a:mcafee:agent:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf431a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.5`,
        fs:  `cpe:2.3:a:gnome:glib:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.6`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.1se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.7`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.8`,
        fs:  `cpe:2.3:a:boost:boost:1.63.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.90`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.91`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.92`,
        fs:  `cpe:2.3:a:oracle:integration_services_server:11.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.9.93`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.0`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.1`,
        fs:  `cpe:2.3:a:nero:mediaplayer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.2`,
        fs:  `cpe:2.3:a:winscp:winscp:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.3`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.4`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.011:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.7`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.8`,
        fs:  `cpe:2.3:a:ca:unicenter_tng:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.9`,
        fs:  `cpe:2.3:a:janetter:janetter:3.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.10`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.11`,
        fs:  `cpe:2.3:a:adobe:reader:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.12`,
        fs:  `cpe:2.3:a:avaya:basic_call_management_system_reporting_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.13`,
        fs:  `cpe:2.3:o:cisco:catos:5.4\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.10.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)cz3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.0`,
        fs:  `cpe:2.3:a:harfbuzz_project:harfbuzz:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8b\)e18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.3`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.90`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-rc5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.91`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.0\(2\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.92`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.93`,
        fs:  `cpe:2.3:a:askia:askiaweb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.11.94`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.1.1:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.0`,
        fs:  `cpe:2.3:a:synology:download_station:3.5-2970:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.2`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.3`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.4`,
        fs:  `cpe:2.3:a:ultimus:ultimus_client:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.5`,
        fs:  `cpe:2.3:a:ddsn:cm3_acora_content_management_system:6.0.6\/1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.6`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.7`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opennms:opennms:1.12.8`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openntpd:openntpd:6.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:-`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server_client_components_sdk:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:1.0`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.4:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:1.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:1.1.0`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:1.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:1.2.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:1.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.766.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:1.3.3`,
        fs:  `cpe:2.3:o:debian:debian_linux:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:1.3.5`,
        fs:  `cpe:2.3:h:alliedtelesis:at-rg634a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:2.0`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:2.1`,
        fs:  `cpe:2.3:a:apache:camel:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:2.2`,
        fs:  `cpe:2.3:a:netscape:smartdownload:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openpkg:openpkg:2.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openproject:openproject:6.1.5`,
        fs:  `cpe:2.3:h:cisco:rv180_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openproject:openproject:7.0.0`,
        fs:  `cpe:2.3:a:winscp:winscp:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openproject:openproject:7.0.1`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openproject:openproject:7.0.2`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:4.5`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:gold:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:4.6`,
        fs:  `cpe:2.3:a:apple:quicktime:7.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:4.7`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:4.8`,
        fs:  `cpe:2.3:h:oracle:netra_sparc_t4-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:4.8.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:4.9`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:5.0`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:5.1`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:5.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensis:opensis:5.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.8.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensolution:quick.cms:2.4`,
        fs:  `cpe:2.3:a:oracle:openjdk:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensolution:quick.cms:4.0`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensolution:quick.cms.lite:0.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensolution:quick.cms.lite:0.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensolution:quick.cms.lite:2.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensolution:quick.cms.lite:2.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.1:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensolution:quick_cart:6.0`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensolution:quick_cms:5.0`,
        fs:  `cpe:2.3:a:oracle:advanced_collections:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensourceclassifieds:opensourceclassifieds:-`,
        fs:  `cpe:2.3:a:apache:solr:4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssh:openssh:-`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.11:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:openssh:openssh:4.6`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:fips_object_module:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.1c`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.2b`,
        fs:  `cpe:2.3:o:schneider-electric:tburjr900_firmware:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.3`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.3a`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(11a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.4`,
        fs:  `cpe:2.3:a:haxx:curl:7.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.5`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.5:beta1`,
        fs:  `cpe:2.3:a:osticket:osticket:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.5:beta2`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.5a`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.5a:beta1`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.5a:beta2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6:beta1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6:beta2`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6:beta3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.652.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6a`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6a:beta1`,
        fs:  `cpe:2.3:a:web2py:web2py:1.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6a:beta2`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6a:beta3`,
        fs:  `cpe:2.3:a:netapp:data_ontap:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6b`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:14.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6c`,
        fs:  `cpe:2.3:a:vmware:vrealize_operations:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6d`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6e`,
        fs:  `cpe:2.3:a:hp:array_diagnostic_utility:8.0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6f`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6g`,
        fs:  `cpe:2.3:a:mongodb:mongodb:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6h`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6i`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.8:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6j`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6k`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:6.0.188.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6l`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.6m`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.3.5:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7`,
        fs:  `cpe:2.3:a:ca:message_queuing:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7:beta1`,
        fs:  `cpe:2.3:a:hp:mercury_sitescope:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7:beta2`,
        fs:  `cpe:2.3:a:websense:triton_web_security_gateway_anywhere:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7:beta3`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7:beta4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7:beta5`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7:beta6`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7a`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7b`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7c`,
        fs:  `cpe:2.3:o:netgear:r7000_firmware:1.0.7.2_1.1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7d`,
        fs:  `cpe:2.3:a:apache:struts:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7e`,
        fs:  `cpe:2.3:h:lucent:cajun_p333_network_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7f`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7g`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.69a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7h`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7i`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1028:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7j`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7k`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_technology_for_bpmn:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7l`,
        fs:  `cpe:2.3:a:emurasoft:emftp:-:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.7m`,
        fs:  `cpe:2.3:a:altiris:barcode_solution:6.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8a`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p456:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8b`,
        fs:  `cpe:2.3:a:citrix:access_management_console_diagnostics:4.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8c`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8d`,
        fs:  `cpe:2.3:a:haxx:curl:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8e`,
        fs:  `cpe:2.3:a:sun:java_web_console:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8f`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-51:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8g`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8h`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8i`,
        fs:  `cpe:2.3:a:emberjs:ember.js:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8j`,
        fs:  `cpe:2.3:a:polycom:cma_system_software:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8k`,
        fs:  `cpe:2.3:a:vips:vips:7.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8l`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8m`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8m:beta1`,
        fs:  `cpe:2.3:a:microsoft:psexec:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8n`,
        fs:  `cpe:2.3:a:apprain:apprain:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8o`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8p`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8q`,
        fs:  `cpe:2.3:a:globeranger:dod_passive_rfid_solution_base:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8r`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg210-5:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8s`,
        fs:  `cpe:2.3:a:easytimestudio:easy_file_manager:1.1:-:-:*:-:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8t`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8u`,
        fs:  `cpe:2.3:a:ibm:vios:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8v`,
        fs:  `cpe:2.3:o:barraguard:barracuda_link_balancer_series_firmware:1.3.2.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8w`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.63:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8x`,
        fs:  `cpe:2.3:a:apache:camel:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8y`,
        fs:  `cpe:2.3:a:sympa:sympa:3.0a.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8z`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8za`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8zb`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8zc`,
        fs:  `cpe:2.3:a:web2py:web2py:1.94.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8zd`,
        fs:  `cpe:2.3:a:keepass:keepass:0.97:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8ze`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8zf`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8zg`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:0.9.8zh`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0:beta1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0:beta2`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0:beta3`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-52p-pwr-si_ls-3600-52p-pwr-si-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0:beta4`,
        fs:  `cpe:2.3:a:schneems:wicked:0.6.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0:beta5`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20060710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0a`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)e5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0b`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0c`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0d`,
        fs:  `cpe:2.3:o:d-link:dir-601_firmware:1.02na:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0e`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0f`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0g`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0h`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.06.555:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0i`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0j`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.836:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0k`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0l`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0m`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0n`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0o`,
        fs:  `cpe:2.3:a:merethis:centreon:2.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0p`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.4:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0q`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0r`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.0s`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1:beta1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1:beta2`,
        fs:  `cpe:2.3:a:ati:avivo_codecs:10.0.0.40103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1:beta3`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1a`,
        fs:  `cpe:2.3:a:rob_loach:sharethis:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1b`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1c`,
        fs:  `cpe:2.3:a:microsoft:picture_it:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1d`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.15:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1e`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1f`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1g`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.15:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1h`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_agent:5.2.0.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1i`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:beta4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1j`,
        fs:  `cpe:2.3:a:apache:activemq:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1k`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.0.9.2743:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1l`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1m`,
        fs:  `cpe:2.3:h:ibm:proventia_network_ips_gx5108:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1n`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1o`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1p`,
        fs:  `cpe:2.3:o:suse:suse_linux:7.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1q`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1r`,
        fs:  `cpe:2.3:a:w1.fi:wpa_supplicant:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1s`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1t`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.1u`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2`,
        fs:  `cpe:2.3:a:search_api_autocomplete_project:search_api_autocomplete:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2:beta1`,
        fs:  `cpe:2.3:a:apache:poi:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2:beta2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2:beta3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2a`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix_5570_controller_firmware:17.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2b`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2c`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2d`,
        fs:  `cpe:2.3:a:sap:hybris:5.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2e`,
        fs:  `cpe:2.3:a:dell:dataengine:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2f`,
        fs:  `cpe:2.3:a:tinytap:hundred_thousands_kid_book:1.6.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2g`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2h`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2i`,
        fs:  `cpe:2.3:a:ibm:java:7.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2j`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2k`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2l`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30174:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.0.2m`,
        fs:  `cpe:2.3:a:justsystems:shuriken:2008:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.1.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:37.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.1.0a`,
        fs:  `cpe:2.3:h:cisco:asr_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.1.0b`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.1.0c`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg300a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.1.0d`,
        fs:  `cpe:2.3:a:square:okhttp:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.1.0e`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.260:update26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.1.0f`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.pi_ia_host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openssl:openssl:1.1.0g`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:ceilometer:2013.1`,
        fs:  `cpe:2.3:a:apache:apr-util:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:ceilometer:2013.2`,
        fs:  `cpe:2.3:a:cisco:asa_5500-x_series_ips_ssp_software:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:cinder:2013.1.1`,
        fs:  `cpe:2.3:a:adobe:indesign:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:cinder:2013.1.2`,
        fs:  `cpe:2.3:h:rockwellautomation:guardlogix_5570_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:-`,
        fs:  `cpe:2.3:a:libssh:libssh:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:12.0.0`,
        fs:  `cpe:2.3:o:cisco:vpn_5000_concentrator_series_software:6.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2012.2`,
        fs:  `cpe:2.3:h:hp:laserjet_m725z:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2013.1`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2013.1.1`,
        fs:  `cpe:2.3:a:web2py:web2py:1.90.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2013.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(15\)g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2013.1.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2013.2`,
        fs:  `cpe:2.3:a:google:chrome:7.0.506.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2013.2.1`,
        fs:  `cpe:2.3:a:facebook:best_beginning:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2013.2.2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2013.2.3`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2014.2.1`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2014.2.2`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:compute:2015.1.2`,
        fs:  `cpe:2.3:h:cisco:wrvs4400n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:devstack:-`,
        fs:  `cpe:2.3:a:vmware:ace:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:diablo:2011.3`,
        fs:  `cpe:2.3:h:sony:snc_dh280:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:essex:2012.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:folsom:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:folsom:2012.2`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:folsom:2012.2.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:folsom:2012.2.2`,
        fs:  `cpe:2.3:a:adobe:flash_mx:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:folsom:2012.2.3`,
        fs:  `cpe:2.3:h:intel:express_520t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:folsom:2012.2.4`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:glance:2015.1.1`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:grizzly:2013.1`,
        fs:  `cpe:2.3:a:boxautomation:c2box:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:grizzly:2013.1.1`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:grizzly:2013.1.2`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.7.0.1860:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:grizzly:2013.1.3`,
        fs:  `cpe:2.3:a:wpdatatables:wpdatatables:1.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:grizzly:2013.1.4`,
        fs:  `cpe:2.3:h:alcatel:speed_touch_adsl_modem:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:havana:2013.2.1`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.06.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:havana:havana-1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p238_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:havana:havana-2`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:6.0.0:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:havana:havana-3`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.03.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:heat:5.0.0`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:heat:2013.2`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:heat:2013.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:heat:2013.2.2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:heat:2013.2.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:heat:2014.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:heat:2015.2`,
        fs:  `cpe:2.3:a:abbyy:finereader_sprint:5.0.0.22227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2012.1`,
        fs:  `cpe:2.3:a:vips:vips:7.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2012.2`,
        fs:  `cpe:2.3:a:typoheads:formhandler:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2013.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00-09:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2013.2`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2013.2.1`,
        fs:  `cpe:2.3:a:softonic:english_toolbar:5.7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2013.2.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2013.2.3`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.13585:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2013.2.4`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2014.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2014.1.1`,
        fs:  `cpe:2.3:a:google:v8:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2014.1.2`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2014.2.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2014.2.1`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2014.2.2`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.xc7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:2014.2.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:folsom-1`,
        fs:  `cpe:2.3:a:emc:networker:7.4:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:folsom-3`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:juno-1`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:juno-2`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:horizon:juno-3`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:icehouse:-`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:icehouse:2014.1.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:-`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2013.2`,
        fs:  `cpe:2.3:a:process-one:exmpp:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2013.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2013.2.2`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:7.1.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2013.2.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2013.2.4`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.1.1`,
        fs:  `cpe:2.3:h:choice-wireless:wixfmr-111:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.1.2`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.1.3`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:11.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.1.4`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.2`,
        fs:  `cpe:2.3:a:vips:vips:7.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.2:rc1`,
        fs:  `cpe:2.3:o:ibm:vios:2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.2:rc2`,
        fs:  `cpe:2.3:a:spip:spip:2.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.2:rc3`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.2.1`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:2014.2.2`,
        fs:  `cpe:2.3:a:netapp:data_ontap:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:juno-1`,
        fs:  `cpe:2.3:a:apache:struts:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:juno-2`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.6.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:image_registry_and_delivery_service_%28glance%29:juno-3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.17.1as:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:juno:2014.2`,
        fs:  `cpe:2.3:a:google:chrome:16.0.888.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:juno:2014.2.2`,
        fs:  `cpe:2.3:a:emc:navisphere_agent:26.9.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:juno:2014.2.3`,
        fs:  `cpe:2.3:o:ibm:os_400:v5r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:8.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.0.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:8.0.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:13.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.1.1`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.1.2`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.1.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.2.1`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.2.2`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.2.3`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2012.2.4`,
        fs:  `cpe:2.3:o:huawei:s5700_firmware:v200r008c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013`,
        fs:  `cpe:2.3:a:oracle:10g_enterprise_manager_database_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.1`,
        fs:  `cpe:2.3:a:square:okhttp:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.1.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.1.2`,
        fs:  `cpe:2.3:a:ibm:rational_service_tester:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.1.3`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.2\(1\)sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.1.4`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.2.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.18:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.2.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.2.3`,
        fs:  `cpe:2.3:a:cisco:rv042_dual_wan_vpn_router_firmware:4.0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2013.2.4`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.0:preview2.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2014.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2014.1.2`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2014.1.2.1`,
        fs:  `cpe:2.3:a:vmware:vm-support:0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2014.1.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2014.2.0`,
        fs:  `cpe:2.3:a:breezy:breezy:1.2.14:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2014.2.1`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2014.2.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:38.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2014.2.3`,
        fs:  `cpe:2.3:h:hp:3com_baseline_plus_switch:2900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:2015.1.2`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:juno-1`,
        fs:  `cpe:2.3:a:ultraseek:ultraseek:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:juno-2`,
        fs:  `cpe:2.3:a:ca:single_sign-on:r12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone:juno-3`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:keystone_essex:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:kilo:2015.1.0`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:11:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2012.2`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2012.2.1`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2012.2.2`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2012.2.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2012.2.4`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.1`,
        fs:  `cpe:2.3:a:apache:struts:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.1.1`,
        fs:  `cpe:2.3:a:google:android_browser:4.2.1:-:-:-:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.1.3`,
        fs:  `cpe:2.3:a:altiris:agent_for_mac_documentation:6.2.1124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.1.4`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.1.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.2`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.2.1`,
        fs:  `cpe:2.3:a:bareftp:bareftp:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.2.2`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.2.3`,
        fs:  `cpe:2.3:a:oracle:http_server:1.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2013.2.4`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2014.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2014.1.1`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2014.1.2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2014.2.3`,
        fs:  `cpe:2.3:o:cisco:mds_9000_nx-os:4.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2015.1.0`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.3.296:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:2015.1.1`,
        fs:  `cpe:2.3:a:icinga:icinga:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:juno-1`,
        fs:  `cpe:2.3:a:squishy_birds_project:squishy_birds:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:juno-2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:juno-3`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:juno1`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:juno2`,
        fs:  `cpe:2.3:a:vmware:workstation:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:neutron:juno3`,
        fs:  `cpe:2.3:a:acme:thttpd:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:oslo:-`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(4k\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:oslo:2013`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:oslo:2013.2`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:8.2.4:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2009.211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.2`,
        fs:  `cpe:2.3:a:perl:perl:5.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.3`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.3.4:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.4`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:3.0:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.5`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.6`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.7`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.8`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.1.9`,
        fs:  `cpe:2.3:h:xerox:workcentre_245:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.2`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.2.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.2.2`,
        fs:  `cpe:2.3:o:microsoft:windows_8:-:-:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.3`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.4`,
        fs:  `cpe:2.3:h:intel:express_550t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.4.1`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:pycadf:0.5.0`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:0.2.2`,
        fs:  `cpe:2.3:a:genertel:genertel:2.6.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:0.2.3`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:0.2.4`,
        fs:  `cpe:2.3:h:hp:jg665a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:0.3.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:0.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(9\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:0.3.2`,
        fs:  `cpe:2.3:o:microsoft:windows_2000_terminal_services:-:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:0.4.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:1.5.0`,
        fs:  `cpe:2.3:a:generaldynamics:pc_updater:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:1.5.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:1.5.2`,
        fs:  `cpe:2.3:a:wp_smiley_project:wp_smiley:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:1.5.3`,
        fs:  `cpe:2.3:a:redhat:jboss_web_framework_kit:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:1.6.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:1.6.1`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall_1:4.1.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:1.7.0`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:2.0.0`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:2.1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:2.2.0`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:2.3.0`,
        fs:  `cpe:2.3:a:hitachi:jp1\/it_desktop_management-manager:10-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:2.3.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.9.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python-keystoneclient:2.3.2`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.8:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.4.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.4.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.4.2`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.5.0`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.3:alpha14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.5.1`,
        fs:  `cpe:2.3:a:apache:axis:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.6.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.49.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.7.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.8.0`,
        fs:  `cpe:2.3:a:iconics:bizviz:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.9.0`,
        fs:  `cpe:2.3:a:enterasys:netsight_inventory_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.10.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:python_glanceclient:0.11.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.0.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.0.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.800.186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.0.2`,
        fs:  `cpe:2.3:a:avactis:avactis_shopping_cart:1.8.0:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.1.0:rc1`,
        fs:  `cpe:2.3:h:htc:desire_s:gri40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.1.0:rc2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.4:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.2.0`,
        fs:  `cpe:2.3:a:corel:painter_ipm:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.2.0:gamma1`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.2.0:rc1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.512:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.3.0`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.3.0:gamma1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.3.0:rc1`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.1`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.2`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.4`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.5`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.6`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.7`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.4.8`,
        fs:  `cpe:2.3:a:adobe:update_manager:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.5.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.6.0`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.7.0`,
        fs:  `cpe:2.3:h:hp:cf067a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.7.2`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.7.4`,
        fs:  `cpe:2.3:o:sun:solaris:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.7.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.7.6`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.8.0`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.8.0:rc1`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.8.0:rc2`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-02-\/g:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.9.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p441:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.9.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.9.2`,
        fs:  `cpe:2.3:a:php:php:7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.10.0`,
        fs:  `cpe:2.3:a:otrs:otrs:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.11.0`,
        fs:  `cpe:2.3:a:telligent:evolution:7.1.12.36162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.12.0`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.2.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.13.0`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:10.00.00.3646:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.13.1`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.13.1:rc1`,
        fs:  `cpe:2.3:a:sap:production_planning_and_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:1.13.1:rc2`,
        fs:  `cpe:2.3:h:hp:laserjet_9055:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:2.1.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:2.2.2`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:2.4.0`,
        fs:  `cpe:2.3:a:gnome:evolution:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift:2.5.0`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:swift3:1.8`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:telemetry_%28ceilometer%29:2013.2`,
        fs:  `cpe:2.3:a:secunia:csi_agent:6.0.0.15017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:telemetry_%28ceilometer%29:2013.2.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.2.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:telemetry_%28ceilometer%29:2014.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:telemetry_%28ceilometer%29:2014.1.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openstack:tripleo_heat_templates:-`,
        fs:  `cpe:2.3:a:skype:skype:3.6.0.127:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:evergreen:11.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:leap:42.0`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:leap:42.1`,
        fs:  `cpe:2.3:a:gnome:evolution:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:leap:42.2`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:leap:42.3`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.0.4990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:10.2`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:10.3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:11.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19\)e6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:11.1`,
        fs:  `cpe:2.3:a:microsoft:ie:8.0.6001:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:11.2`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:11.3`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:11.4`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:12.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:12.2`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:12.3`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_6901:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:13.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:opensuse:13.2`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.00:-:*:*:esx:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse:suse_linux_enterprise_server:11.0:sp3`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:leap:42.2`,
        fs:  `cpe:2.3:a:apport_project:apport:2.20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:opensuse:11.3`,
        fs:  `cpe:2.3:a:corel:videostudio_pro:x7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:opensuse:12.1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:opensuse:13.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:opensuse:13.2`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:suse_linux_enterprise_desktop:11.0:sp3`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.1.2.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:suse_linux_enterprise_server:11.0:sp3`,
        fs:  `cpe:2.3:a:apple:apple_tv:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:suse_linux_enterprise_server:11.0:sp3:~~~vmware~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:opensuse_project:suse_linux_enterprise_software_development_kit:11.0:sp3`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_31:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.3.0`,
        fs:  `cpe:2.3:a:contentlion:contentlion_alpha:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.3.1`,
        fs:  `cpe:2.3:a:google:v8:3.24.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-2330c_firmware:t450sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.1`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:7.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.2`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.3`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.5`,
        fs:  `cpe:2.3:o:huawei:mate_7_firmware:mt7-tl10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.6`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.7`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.8`,
        fs:  `cpe:2.3:a:microsoft:internet_information_services:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.10`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.2:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.11`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.4.13`,
        fs:  `cpe:2.3:a:radius_extension_project:radius:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.0:sbs4`,
        fs:  `cpe:2.3:a:storagetek:library_console:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.0:sbs5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.01`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.02`,
        fs:  `cpe:2.3:a:microsoft:sql_server_reporting_services:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.03`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.04`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.05`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.06`,
        fs:  `cpe:2.3:h:xerox:workcentre_m45:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.07`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.08`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf846a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.09`,
        fs:  `cpe:2.3:o:cisco:mds_9000_san-os:1.3\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.10`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.11`,
        fs:  `cpe:2.3:h:ibm:proventia_network_ips_gx5008:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.12`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_222_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.13`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.14`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.15`,
        fs:  `cpe:2.3:a:ca:anti-virus:2007:8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.16`,
        fs:  `cpe:2.3:a:lincolnloop:authorize.net_echeck_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.17`,
        fs:  `cpe:2.3:a:emc:navisphere_command_line_interface:26.9.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.5.18`,
        fs:  `cpe:2.3:a:bookformobile:simple_car_care_tip_and_advice:1.03:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.01`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.02`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.03`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.04`,
        fs:  `cpe:2.3:o:redhat:enterprise_virtualization_manager:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.05`,
        fs:  `cpe:2.3:a:hornbill:supportworks_itsm:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.06`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.07`,
        fs:  `cpe:2.3:a:ibm:api_management:3.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.08`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:19.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.09`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:4.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.10`,
        fs:  `cpe:2.3:a:devicelock:devicelock:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.11`,
        fs:  `cpe:2.3:a:sybase:easerver:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.12`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.13`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.14`,
        fs:  `cpe:2.3:a:symantec:liveupdate:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.15`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.16`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.6.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.17`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.18`,
        fs:  `cpe:2.3:a:kristof_de_jaeger:bundle_copy:7.x-1.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.19`,
        fs:  `cpe:2.3:a:redhat:undertow:1.1.0:cr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.20`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.21`,
        fs:  `cpe:2.3:a:ca:arcserve_client_agent:-:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.22`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.23`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.24`,
        fs:  `cpe:2.3:a:ipswitch:imail:8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.25`,
        fs:  `cpe:2.3:a:hp:document_viewer:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.26`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0596:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.27`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.28`,
        fs:  `cpe:2.3:a:zend:zendservice_amazon:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.30`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.31`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.6-121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.32`,
        fs:  `cpe:2.3:a:apache:struts:1.1:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.33`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.34`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.35`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.36`,
        fs:  `cpe:2.3:a:watchguard:xcs:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.37`,
        fs:  `cpe:2.3:a:microsoft:asp.net_signalr:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.38`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.39`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.4s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openswan:openswan:2.6.40`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.37:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:webwork:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1668.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.0.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p172:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.0.1`,
        fs:  `cpe:2.3:a:avaya:octelaccess_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.0.2`,
        fs:  `cpe:2.3:a:qbnz:geshi:1.0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.0.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.0.5`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.1.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.1.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opensymphony:xwork:2.2.1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:administration_client:10.1.0.271`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:archive_administration_utilities:9.6.1`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:connectivity_secure_shell:2008`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.40.020.1968:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:deployment_wizard:13.0.0.0`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a3\(1.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:desktop_viewer:8.30`,
        fs:  `cpe:2.3:a:google:chrome:12.0.723.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:desktop_viewer_3d%2b:8.30`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:2.5.0.997:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:desktop_viewer_lm:8.30`,
        fs:  `cpe:2.3:a:winscp:winscp:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:enterprise_library_archive_server:5.5`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:enterprise_library_classifications_professional:4.2.0.464`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:enterprise_library_content_archiving:2.1.0.271`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:enterprise_library_enterprise_server:9.7.1.313`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:enterprise_library_enterprise_server_patches_for_els:10.1.0.269`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:enterprise_library_records_management:4.2.0.487`,
        fs:  `cpe:2.3:h:netgear:r8000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:enterprise_library_security_clearance:4.2.0.466`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:enterprise_library_service_module:1.1.0.272`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:exceed_ondemand:8.0`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:livelink_imaging:9.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:livelink_remote_search:1.2.0.448`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:livelink_webdav:3.5.0`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentext:opentext%2fixos_ecm_for_sap_netweaver:-`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.3.6`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.4.0`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.4.0.1`,
        fs:  `cpe:2.3:a:cisco:accesspath:ls-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.4.5`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1287.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.4.6`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.4.7`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.4.8`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.061:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.5.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.5.1`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.5.2`,
        fs:  `cpe:2.3:a:webassist:powerstore:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.5.3`,
        fs:  `cpe:2.3:a:apple:cups:1.1.20:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.6.0`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.6.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.53.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.6.2`,
        fs:  `cpe:2.3:a:ibm:rational_service_tester:8.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.6.3`,
        fs:  `cpe:2.3:a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.7.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.7.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_human_capital_management:8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.7.2`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.7.3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.15:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.7.4`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:0.7.5`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.0:beta1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:17.011.30065:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.0:beta2`,
        fs:  `cpe:2.3:o:starnet:x_win32:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.0:beta3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.0:beta4`,
        fs:  `cpe:2.3:a:google:chrome:13.0.752.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.0:rc1`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.0:rc2`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.0:rc3`,
        fs:  `cpe:2.3:a:microsoft:content_management_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.1:rc1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.1:rc2`,
        fs:  `cpe:2.3:a:vips:vips:7.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.2:rc1`,
        fs:  `cpe:2.3:a:acrosoftware:cutepdf_writer:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.3`,
        fs:  `cpe:2.3:a:opnet:modeler:15.0.0.8631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.3:rc1`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.4:rc1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.5`,
        fs:  `cpe:2.3:o:debian:debian_linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.5:rc1`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.0.5:rc2`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.1\(1\)_es1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.1.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.1.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.1.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.1.5`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.2.0`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.2.1`,
        fs:  `cpe:2.3:a:apache:poi:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.2.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.2.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.3.2`,
        fs:  `cpe:2.3:a:plantronics:persono_suite:1.1.23884.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openttd:openttd:1.3.3`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opentype_sanitiser_project:opentype_sanitiser:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvas:greenbone_security_assistant:6.0.0`,
        fs:  `cpe:2.3:a:lksctp:stream_control_transmission_protocol:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvas:greenbone_security_assistant:6.0.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvas:greenbone_security_assistant:6.0.2`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvas:greenbone_security_assistant:6.0.3`,
        fs:  `cpe:2.3:h:cisco:call_manager:5.1.1.3000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvas:greenbone_security_assistant:6.0.4`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.6:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvas:greenbone_security_assistant:6.0.5`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvas:greenbone_security_assistant:6.0.6`,
        fs:  `cpe:2.3:a:isc:bind:9.10.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvas:greenbone_security_assistant:6.0.7`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.2:rc1`,
        fs:  `cpe:2.3:a:google:v8:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.2.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.2.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.2.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.3:beta1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1018:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.3:rc1`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:7.0:e02020p03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.3.0`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.3.1`,
        fs:  `cpe:2.3:a:qualcomm:eudora_worldmail:9.0.333.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_administrator:1.3.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.5.0`,
        fs:  `cpe:2.3:a:google:v8:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.6.0`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:11.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.6.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.7.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.8.1`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.26:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.359.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.2`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_the_web_2008:10.2.534:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.3`,
        fs:  `cpe:2.3:h:apple:macbook_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.5`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.6`,
        fs:  `cpe:2.3:a:getgosoft:getgo_download_manager:4.9.0.1982:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.7`,
        fs:  `cpe:2.3:a:tumbleweed:desktop_validator:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:0.9.8`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0:beta2`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0:beta3`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mda13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0:beta4`,
        fs:  `cpe:2.3:a:synology:download_station:3.4-2557:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0:beta5`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0:beta6`,
        fs:  `cpe:2.3:a:oracle:advanced_collections:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0:beta7`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.0:rc1`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.1`,
        fs:  `cpe:2.3:a:intuit:quickbooks:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.2`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.3`,
        fs:  `cpe:2.3:o:cisco:nx-os_1000v_switch:4.0\(4\)sv1\(3\):*:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:1.0.4`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0:beta1`,
        fs:  `cpe:2.3:h:xerox:workcentre_m165:6.47.33.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0:beta2`,
        fs:  `cpe:2.3:a:ati:catalyst_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0:beta3`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0:rc1`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0:rc2`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0:rc3`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0:rc4`,
        fs:  `cpe:2.3:a:symantec:livestate_agent_for_windows:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0.0`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0.1`,
        fs:  `cpe:2.3:a:pip-installer:pip:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0.2`,
        fs:  `cpe:2.3:a:savysoda:wifi_free_hd:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0.3`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0.4`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0.5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0_rev_b:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:2.0.6`,
        fs:  `cpe:2.3:a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:beta1`,
        fs:  `cpe:2.3:a:keyword_strategy_internal_links_project:keyword_strategy_internal_links:2.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:beta2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.3:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:beta3`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:beta4`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.6.0.597:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:beta5`,
        fs:  `cpe:2.3:a:adobe:linguistics_cs3:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:beta6`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:beta7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:beta8`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0:rc1`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0.1`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linuxsoft:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0.2`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:43.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0.5`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.5.502.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:3.0.7`,
        fs:  `cpe:2.3:a:cookpad:android_activities:1.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0:beta1`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0:beta2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0:beta3`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.4.3880.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0:beta4`,
        fs:  `cpe:2.3:h:siemens:ozw672:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0:beta5`,
        fs:  `cpe:2.3:h:cisco:2504_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0.0`,
        fs:  `cpe:2.3:a:microsoft:word:98:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0.3`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0.5`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:4.0.6`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_database_control:10.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta10`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta11`,
        fs:  `cpe:2.3:a:adobe:flash_player:21.0.0.97:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta12`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp1:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta13`,
        fs:  `cpe:2.3:a:umn:mapserver:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta2`,
        fs:  `cpe:2.3:a:mw6tech:maxicode_activex_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta3`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta4`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.02.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta5`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.5.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta6`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta7`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta8`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.0:beta9`,
        fs:  `cpe:2.3:a:vmware:virtualcenter:2.0:unknown:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.1`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.3`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.4`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.5`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.3:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.7`,
        fs:  `cpe:2.3:a:atutor:atutor:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.8`,
        fs:  `cpe:2.3:a:ibm:high_availability_cluster_multiprocessing:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:5.0.9`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.:*:pro:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0:beta1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0:beta2`,
        fs:  `cpe:2.3:a:bluecoat:proxysg_va-15:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0:beta3`,
        fs:  `cpe:2.3:a:pixman:pixman:0.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0:beta4`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0:beta5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0:beta6`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.1`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.2`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.3`,
        fs:  `cpe:2.3:a:radscan:network_audio_system:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.4`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.5`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.6`,
        fs:  `cpe:2.3:a:ibm:websphere_caching_proxy_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.7`,
        fs:  `cpe:2.3:h:hp:elitedesk_705_g2_mt_sff:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.8`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.6:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.9`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.10`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.0.11`,
        fs:  `cpe:2.3:a:iomega:iomegaware:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.1:beta1`,
        fs:  `cpe:2.3:h:intel:active_management_technology:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.1:beta2`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.1.0.2019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:6.1:beta3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:7.0.0`,
        fs:  `cpe:2.3:a:serf_project:serf:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:7.0.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_manager:7.0.2`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.0:beta1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.0:beta2`,
        fs:  `cpe:2.3:a:datadirect:datadirect_connect_odbc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.0:beta3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.0:beta4`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:10.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.0:beta4.1`,
        fs:  `cpe:2.3:a:csounds:csound:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.0:beta6`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.0:rc1`,
        fs:  `cpe:2.3:a:otrs:faq:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.1`,
        fs:  `cpe:2.3:o:cisco:staros:16.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.0.2`,
        fs:  `cpe:2.3:a:ca:inoculan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.1.0`,
        fs:  `cpe:2.3:h:alliedtelesis:img616lh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.1.0:rc1`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.1.0:rc2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.1.0:rc3`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.1.1`,
        fs:  `cpe:2.3:o:google:android:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2:beta1`,
        fs:  `cpe:2.3:h:sprint:airave:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2:beta2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2:rc1`,
        fs:  `cpe:2.3:h:huawei:s3700:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2.0`,
        fs:  `cpe:2.3:a:redhat:jboss_bpm_suite:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2.1`,
        fs:  `cpe:2.3:a:mozilla:camino:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2.2`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2.3`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xd1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.2.5`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.3.0:rev36620:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.3:beta1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:4.3.0:cp05:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.3:beta2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.3:rc1`,
        fs:  `cpe:2.3:a:hp:update:4.0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.3.1`,
        fs:  `cpe:2.3:a:erlang-solutions:mongooseim:1.3.1:rev2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.4:beta1`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.4:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xnd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.4:rc1`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.4.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.4.1`,
        fs:  `cpe:2.3:a:cisco:security_agent_management_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:3.4.2`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta1`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta2`,
        fs:  `cpe:2.3:a:combodo:itop:1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta3`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.6:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta5`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta6`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta7`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta8`,
        fs:  `cpe:2.3:a:curtis_galloway:libexif:0.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0:beta9`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0.0`,
        fs:  `cpe:2.3:a:siemens:wincc:7.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0.2`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0.3`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0.4`,
        fs:  `cpe:2.3:a:hp:oracle_for_openview:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0.5`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0.6`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:4.0.7`,
        fs:  `cpe:2.3:a:microsoft:works:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0:beta1`,
        fs:  `cpe:2.3:a:opnet:ace_analyst_documentation:15.0.0.8623:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0:beta2`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0:beta3`,
        fs:  `cpe:2.3:a:novell:groupwise:7.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0:beta4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0:beta5`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.542:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0:beta6`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd1.m2xx0_firmware:1.24.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.1`,
        fs:  `cpe:2.3:a:skype:skype:1.4.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.3`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg210-5:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.4`,
        fs:  `cpe:2.3:a:sas:deployment_tester:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.5`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.6`,
        fs:  `cpe:2.3:a:adobe:contribute:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.7`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.0.8`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.1:beta1`,
        fs:  `cpe:2.3:a:google:v8:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.1:beta2`,
        fs:  `cpe:2.3:a:ibm:sterling_connect:4.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.1:beta3`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-2500c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.1.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openvas:openvas_scanner:5.1.1`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:-`,
        fs:  `cpe:2.3:a:ca:etrust_admin:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.2.0`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.2.1`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.9:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.3.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.3.1`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.6c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.3.2`,
        fs:  `cpe:2.3:a:apple:webobjects:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.4.0`,
        fs:  `cpe:2.3:a:aperturemobilemedia:aperture_mobile_media:1.404:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.4.1`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.4.2`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.4.3`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.5.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:1.71:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:1.6.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.15:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.1.0`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.1.28.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.51:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.2.0`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.3.0`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.3.12`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.3.13`,
        fs:  `cpe:2.3:a:microsoft:word:2013:-:-:*:-:rt:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.4.0`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.4.0:alpha2`,
        fs:  `cpe:2.3:a:opentext:desktop_viewer:8.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.4.0:beta1`,
        fs:  `cpe:2.3:a:microsoft:psshutdown:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.4.0:beta2`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.4.0:rc1`,
        fs:  `cpe:2.3:a:juniper:smartpass:8.0:mr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.4.0:rc2`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn:2.4.1`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn_access_server:1.5.6`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_for_mac:6.2.1054:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn_access_server:1.8.4`,
        fs:  `cpe:2.3:a:apple:xcode:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvpn:openvpn_access_server:1.8.5`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-52c-pwr-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.0.1`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.1.0`,
        fs:  `cpe:2.3:a:bea:aqualogic_.net_portlet_toolkit:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.1.1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.2.0`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.2.1`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.2.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.3.0`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.4.0`,
        fs:  `cpe:2.3:a:docker:docker:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.4.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_business_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.4.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.5.0`,
        fs:  `cpe:2.3:a:oracle:cadview-3d:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.6.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openvswitch:openvswitch:1.7.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvz:vzkernel:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.935.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:openvz:vzkernel:2.6.32`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0`,
        fs:  `cpe:2.3:a:siemens:comos:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0.1`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0.4`,
        fs:  `cpe:2.3:a:adobe:premiere_pro_cs3:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0.5`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.9:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0.6`,
        fs:  `cpe:2.3:a:atheme:atheme:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0.7`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.1:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.0.8`,
        fs:  `cpe:2.3:a:gnu:libc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.1.0:rc1`,
        fs:  `cpe:2.3:a:mauro_lorenzutti:wfqbe:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.1.0:rc2`,
        fs:  `cpe:2.3:a:gnu:automake:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.1.0:rc3`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.1.0:rc4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.1.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.0`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.0:rc1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd357a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.0:rc2`,
        fs:  `cpe:2.3:a:docker:docker:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.0:rc3`,
        fs:  `cpe:2.3:a:openstack:keystone:2014.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.1:rc1`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.2`,
        fs:  `cpe:2.3:a:microsoft:data_protection_manager:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.3`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.2.4`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.3.0`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.3.0:rc1`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r346.00:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.3.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.4.0`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.4.0:rc1`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.4.0:rc2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.4.0:rc3`,
        fs:  `cpe:2.3:a:horde:imp:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.4.0:rc4`,
        fs:  `cpe:2.3:a:samba:samba:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.4.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.51.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.0`,
        fs:  `cpe:2.3:a:jenkins:git:3.3.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.0:rc1`,
        fs:  `cpe:2.3:a:busybox:busybox:0.60.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.0:rc2`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.0:rc3`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_t3:-:*:custom:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.1`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.1.1.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_1q:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.3`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr2116c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.4`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openwebanalytics:open_web_analytics:1.5.5`,
        fs:  `cpe:2.3:a:ibm:qradar_vulnerability_manager:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4.4`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4.5`,
        fs:  `cpe:2.3:a:prolific:ez-dub_finder:0.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4.6`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4.7`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4.8`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4.9`,
        fs:  `cpe:2.3:a:apple:quicktime:7.65.17.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4.10`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta36:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.4.11`,
        fs:  `cpe:2.3:a:opnet:sp_guru_network_planner:16.0.0.10353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.6.0`,
        fs:  `cpe:2.3:a:paypal:website_payments_standard_module:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.6.1`,
        fs:  `cpe:2.3:o:hp:mpe_ix:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.6.2`,
        fs:  `cpe:2.3:a:google:chrome:12.0.739.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.6.3`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.6.4`,
        fs:  `cpe:2.3:o:opensuse:opensuse:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.6.5`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.7.29`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.2`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.93.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.4`,
        fs:  `cpe:2.3:a:ibm:updatexpress_system_packs_installer:9.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.5`,
        fs:  `cpe:2.3:a:hp:readme:70.0.231.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.7`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.1.0:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.8`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.3.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.9`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.115.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.10`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx:2.8.11`,
        fs:  `cpe:2.3:o:omron:ns_series_system_program_firmware:8.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx_source:2.8.10`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:openx:openx_source:2.8.11`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:brew_browser:6.0:sp1`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:mini:2.0.4719:1690`,
        fs:  `cpe:2.3:a:tabtale:abc_song:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:mini:3.1.7196:1690`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:mini:3.1.7203:1690`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:mini:3.1.8295:1690`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.15:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:1.00`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:2.00`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:2.10`,
        fs:  `cpe:2.3:a:erlang:crypto:2.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:2.10:beta1`,
        fs:  `cpe:2.3:a:ca:api_gateway:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:2.10:beta2`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:2.10:beta3`,
        fs:  `cpe:2.3:a:hp:centralview_revenue_leakage_control:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:2.12`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.0.380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.00`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.00:beta`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.10`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.21`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.50`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.11s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.51`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p1_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.60`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.61`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.62`,
        fs:  `cpe:2.3:h:hp:officejet_9100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:3.62:beta`,
        fs:  `cpe:2.3:a:andreas_krennmair:tpp:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:4.00`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.18.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:4.00:beta2`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:4.00:beta3`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:4.00:beta4`,
        fs:  `cpe:2.3:a:mapsmarker:leaflet_maps_marker_plugin:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:4.00:beta5`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:4.00:beta6`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:6.01.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:4.01`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:4.02`,
        fs:  `cpe:2.3:a:qemu:qemu:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p82:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.0:beta2`,
        fs:  `cpe:2.3:a:powerdns:authoritative:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.0:beta3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.0:beta4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.7-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.0:beta5`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.0:beta6`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.0:beta7`,
        fs:  `cpe:2.3:a:ibm:secureway_firewall:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.0:beta8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.02`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.10`,
        fs:  `cpe:2.3:h:cisco:dpc3212:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.11`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:5.12`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ebz:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.0:beta2`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.0:beta3`,
        fs:  `cpe:2.3:a:goahead:goahead_webserver:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.0:tp1`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.0:tp2`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.0:tp3`,
        fs:  `cpe:2.3:a:nancy_wichmann:taxonomy_list:6.x-1.0-beta1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.1`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.01`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update2:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.1:beta1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.02`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.12.0.knots20160226:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.03`,
        fs:  `cpe:2.3:a:novell:groupwise:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.04`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.05`,
        fs:  `cpe:2.3:a:accunetix:web_vulnerability_scanner:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.06`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.11`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:6.12`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.0:beta1`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.0:beta1_v2`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.0:beta2`,
        fs:  `cpe:2.3:a:elokence:akinator_the_genie_free:2.46:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.01`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.02`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6ccf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.03`,
        fs:  `cpe:2.3:a:google:checkout-php:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.10`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.10:beta1`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.11`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.11:beta2`,
        fs:  `cpe:2.3:h:nortel:vpn_router_1100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.20`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.20:beta7`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.21`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.22`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.23`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.50`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.50:beta1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.51`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.52`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.53`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:12.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.54`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.54:update1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.5.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.54:update2`,
        fs:  `cpe:2.3:a:php:php:7.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:7.60`,
        fs:  `cpe:2.3:a:cisco:webns:7.20_\(03.09\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.00`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.0:beta1`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.0:beta2`,
        fs:  `cpe:2.3:a:altova:xmlspy_2012:-:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.0:beta3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.01`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.02`,
        fs:  `cpe:2.3:a:hp:select_identity:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.50`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.51`,
        fs:  `cpe:2.3:a:apple:cups:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.52`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.53`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:8.54`,
        fs:  `cpe:2.3:a:wellintech:kingview:6.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.00`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.0`,
        fs:  `cpe:2.3:a:gnu:findutils:4.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.0:beta1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.0:beta2`,
        fs:  `cpe:2.3:a:ibm:rational_testmanager:2.1.1063:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.01`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.02`,
        fs:  `cpe:2.3:h:huawei:s3300hi:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.10`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_rich_text_editor:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.12`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.20`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.20:beta1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.21`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.22`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.23`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.24`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.25`,
        fs:  `cpe:2.3:a:arcanadev:arcana_scheduler:2.3.0202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.26`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.27`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.5:-:sbs:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.50`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.50:beta1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.1.3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.50:beta2`,
        fs:  `cpe:2.3:a:ca:common_services:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.51`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.52`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.60`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.60:beta1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.61`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.62`,
        fs:  `cpe:2.3:a:sap:sap_kernel:7.40:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.63`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:9.64`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4500_series_software:4.2\(1.43\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.00`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.00:alpha`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.00:beta1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.00:beta2`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.00:beta3`,
        fs:  `cpe:2.3:a:cisco:ios:15.2\(2\)eb1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.01`,
        fs:  `cpe:2.3:a:atecea:atecea:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.10`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.10:beta1`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.11`,
        fs:  `cpe:2.3:a:php:php:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.20:alpha`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.50`,
        fs:  `cpe:2.3:a:google:v8:3.22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.50:beta1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.03b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.50:beta2`,
        fs:  `cpe:2.3:a:splunk:splunk:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.51`,
        fs:  `cpe:2.3:a:ibm:connections_portlets:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.52`,
        fs:  `cpe:2.3:h:cisco:catalyst_4912g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.52:beta1`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.52:beta2`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.53`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.53:b`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.52.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.53:beta1`,
        fs:  `cpe:2.3:a:silberfish:sfimageresize:1.3.1:*:*:*:personal:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.54`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.60`,
        fs:  `cpe:2.3:a:microsoft:lync:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.60:alpha`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.60:beta1`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.61`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.62`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:10.63`,
        fs:  `cpe:2.3:h:hp:arcsight_connector_appliance:c1400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.00`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.57.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.00:beta`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p192:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.01`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.10`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_apppack:5.1.1000.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.10:beta`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:5.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.11`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.50`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.50:beta`,
        fs:  `cpe:2.3:a:ibm:messagesight_jms_client:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.51`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.52`,
        fs:  `cpe:2.3:a:gnu:libtasn1:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.52.1100`,
        fs:  `cpe:2.3:h:supermicro:x9drh-7f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.60`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.60:beta`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.61`,
        fs:  `cpe:2.3:a:google:chrome:6.0.401.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.62`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution_assurance:10.6\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.64`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(16.1\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.65`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.07.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.66`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:11.67`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.00`,
        fs:  `cpe:2.3:a:php:php:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.00:beta`,
        fs:  `cpe:2.3:a:adobe:anchor_service_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.01`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:2.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.02`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.10`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.17.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.10:beta`,
        fs:  `cpe:2.3:h:cisco:mds_9200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.11`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder:5.2.0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.12`,
        fs:  `cpe:2.3:a:xnview:xnview:1.80.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.13`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.14`,
        fs:  `cpe:2.3:h:nortel:wlan_access_point_2220:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:12.15`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:15.00:next`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:16.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:17.00`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:18.00`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_browser:19.00`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_mini:7.4:-:~~~android~~`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_mini:7.5:-:~~~android~~`,
        fs:  `cpe:2.3:h:hp:jf430b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_mini:7.5.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:sysinternals_pstools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_mobile:12.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opera:opera_mobile:12.1:-:~~~android~~`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:ace_analyst:15.0.0.8631::~~standard~~~`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0a7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:ace_analyst:15.0.0.8652::~~plus~~~`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:ace_analyst:15.0.0.8652::~~standard~~~`,
        fs:  `cpe:2.3:o:cisco:asa_with_firepower_services:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:ace_analyst:16.0.0.8934`,
        fs:  `cpe:2.3:a:plone:plone:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:ace_analyst_documentation:15.0.0.8623::~~plus~~~`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:ace_analyst_documentation:15.0.0.8623::~~standard~~~`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:development_kit_module:16.0.0.10106`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:development_kit_module_documentation:16.0.0.10106`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:it_guru:15.0.0.8631`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:12.0.1.1737:-:-:*:-:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:it_guru:15.0.0.8652`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.1:rp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:it_guru:16.0.0.10215`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:it_guru:16.0.0.10353`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:it_guru_documentation:15.0.0.8622`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:it_guru_documentation:16.0.0.10106`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:50.1.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:license_server:15.0.0.8631`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:license_server:16.0.0.8934`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:license_server:16.0.0.10106`,
        fs:  `cpe:2.3:a:emc:task_space:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:license_server:16.0.0.10215`,
        fs:  `cpe:2.3:a:apache:traffic_server:4.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:license_server:16.0.0.10353`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:license_server:16.1.0.10834`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7e_3.7.3e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:license_server:17.0.0.10655`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:license_server:17.0.0.910588`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:model_library:15.0.0.0`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_real-time_information_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:model_library:16.0`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-8024:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:model_library:16.1.0.0`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:modeler:15.0.0.8631`,
        fs:  `cpe:2.3:a:sun:ray_windows_connector:2.0:*:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:modeler:16.0.0.10261`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:modeler:16.0.0.10353`,
        fs:  `cpe:2.3:a:digium:asterisk:12.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:modeler:16.1.0.10834`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:modeler_documentation:16.1.0.10830`,
        fs:  `cpe:2.3:o:cisco:aironet_access_point_software:7.4_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_network_planner:15.0.0.8631`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_network_planner:16.0.0.10106`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:-:pulse:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_network_planner:16.0.0.10215`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_network_planner:16.0.0.10353`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_network_planner_documentation:15.0.0.8622`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_network_planner_documentation:16.0.0.10106`,
        fs:  `cpe:2.3:a:emc:centera:4.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_network_planner_documentation:16.0.0.10353`,
        fs:  `cpe:2.3:a:apple:cups:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner:15.0.0.8631`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner:16.0.0.10215`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner:16.0.0.10353`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner:17.0.0.10655:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner:17.0.0.10655`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.8:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner_documentation:15.0.0.8168`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner_documentation:16.0.0.10107`,
        fs:  `cpe:2.3:a:huge-it:huge-it_catalog:1.0.7:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner_documentation:16.0.0.10215`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.12f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner_documentation:16.0.0.10355`,
        fs:  `cpe:2.3:h:cisco:sg500-52mp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opnet:sp_guru_transport_planner_documentation:17.0.0.10655`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.5.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.5.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.5.4`,
        fs:  `cpe:2.3:a:freereprintables:articlefr:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.5.6`,
        fs:  `cpe:2.3:a:omeka:omeka:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.6.0`,
        fs:  `cpe:2.3:a:slavasoft:hashcalc:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.6.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.366.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.7.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.7.4`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.7.6`,
        fs:  `cpe:2.3:a:syncsort:backup_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.7.8`,
        fs:  `cpe:2.3:a:centreon:centreon:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.7.10`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.7.12`,
        fs:  `cpe:2.3:a:jinfra:guess_the_movie:2.982:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.7.14`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.8.2`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.8.4`,
        fs:  `cpe:2.3:a:vmware:esx_server:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.8.6`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.8.8`,
        fs:  `cpe:2.3:a:john_nunemaker:crack:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.8.10`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.8.12`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.017.20053:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.8.14`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.8.16`,
        fs:  `cpe:2.3:a:google:chrome:11.0.659.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.0`,
        fs:  `cpe:2.3:a:symantec:csapi:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.2`,
        fs:  `cpe:2.3:h:hp:cf236a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.4`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.8`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs3_template_projects_\&amp;_footage:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.10`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.12`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20161005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.14`,
        fs:  `cpe:2.3:a:boost:boost:1.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.16`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.9.18`,
        fs:  `cpe:2.3:a:preprojects:pre_printing_press:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.10.0`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.10.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.10.4`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.10.6`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.10.8`,
        fs:  `cpe:2.3:a:playscape:bouncy_bill_world-cup:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.10.10`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opscode:chef:0.10.12`,
        fs:  `cpe:2.3:a:arellia:arellia_file_inventory_report_pack_language_pack:6.1.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:2.7`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:2.8`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:2.10`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:2.12`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:2.14`,
        fs:  `cpe:2.3:a:apple:cups:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.0:-:~~community~~~`,
        fs:  `cpe:2.3:a:no-margin-for-errors:prettyphoto:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.1:-:~~community~~~`,
        fs:  `cpe:2.3:a:spip:spip:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.2:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:combodo:itop:1.2.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.4:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:sybase:easerver:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.6:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.8:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1030.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.10:-:~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.12:-:~~enterprise~~~`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:3.14:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:brother:mfl-pro_suite:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.0:-:~~enterprise~~~`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:3.0.0.4.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.0:-:~~pro~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.1:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:netgenius:multilink:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.1:-:~~pro~~~`,
        fs:  `cpe:2.3:a:vmware:remote_console:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.2:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.2:-:~~pro~~~`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.3:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.04.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.3:-:~~pro~~~`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.4:-:~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.4:-:~~pro~~~`,
        fs:  `cpe:2.3:a:vmware:workstation_pro:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.4.0`,
        fs:  `cpe:2.3:a:apport_project:apport:2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.4.1`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.6.2`,
        fs:  `cpe:2.3:a:apache:apache-ssl:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opsview:opsview:4.6.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:optimalpayments:neteller_direct_payment_api:4.1.6`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:optimizepress:optimizepress:1.60:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:optimizepress:optimizepress:1.61:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.1.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:option:driver_installer:2.3.0.797`,
        fs:  `cpe:2.3:a:atutor:acontent:1.2:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:optipng:optipng:0.6.4`,
        fs:  `cpe:2.3:a:alipay_project:alipay:3.6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:optipng:optipng:0.7.5`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:optipng_project:optipng:0.6.4`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.6.0:*:ja:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:optipng_project:optipng:0.7.5`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opus-codec:opus:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opus-codec:opus:1.0.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.00:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:opus-codec:opus:1.0.2`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:10g_enterprise_manager_database_control:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:10g_enterprise_manager_grid_control:-`,
        fs:  `cpe:2.3:a:moodle:moodle:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:10g_reports_server:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:advanced_collections:11.5.10.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:advanced_collections:12.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:advanced_collections:12.1.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:advanced_collections:12.1.3`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_engineering_data_management:6.1.2.2`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_engineering_data_management:6.1.3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_engineering_data_management:6.2.0.0`,
        fs:  `cpe:2.3:a:apple:itunes:12.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_product_lifecycle_management:9.3.1.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_product_lifecycle_management:9.3.1.2`,
        fs:  `cpe:2.3:a:mobile4social:exposed_filter_data:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_product_lifecycle_management:9.3.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_product_lifecycle_management:9.3.3`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_product_lifecycle_management_framework:9.3.1.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd334a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_product_lifecycle_management_framework:9.3.1.2`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_product_lifecycle_management_framework:9.3.2`,
        fs:  `cpe:2.3:a:adobe:color_common_setrgb:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:agile_product_lifecycle_management_framework:9.3.3`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:apex:-`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:apex:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xk1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:apex:2.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:apex:2.2`,
        fs:  `cpe:2.3:o:redhat:linux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:apex:2.2.0.00.32`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:apex:3.0.0.00.20`,
        fs:  `cpe:2.3:a:schneems:wicked:0.3.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:api_gateway:11.1.2.3.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:api_gateway:11.1.2.4.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.2\(1f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_management:12.1::~~~e-business_suite~~`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_management:12.2::~~~e-business_suite~~`,
        fs:  `cpe:2.3:a:google:chrome:48.0.2564.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_management_pack:12.1::~~~e-business_suite~~`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_management_pack:12.2::~~~e-business_suite~~`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:1.0.10d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_object_library:11.5.10.2`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_object_library:12.1.3`,
        fs:  `cpe:2.3:a:csilvers:gperftools:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_object_library:12.2.3`,
        fs:  `cpe:2.3:h:cisco:as5200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_object_library:12.2.4`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_object_library:12.2.5`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:-`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.14:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.4.1:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0.2.0`,
        fs:  `cpe:2.3:a:h2o_project:h2o:1.7.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0.2.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0.2.1s`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0.2.2`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0.2.2:r1`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0.2.2:r2`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.4\(3.42\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:1.0.2.2.2`,
        fs:  `cpe:2.3:a:3com:3cserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:3.0.7`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:4.0`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:4.0.8`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.2919.6307:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:4.0.8.2`,
        fs:  `cpe:2.3:h:zyxel:nbg-418n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:7.0.4.4`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:8.1.7`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.11s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0`,
        fs:  `cpe:2.3:a:apple:quicktime:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.2:r2`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.2.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.2.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.2.1`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.2.0_b26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.2.2`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.2.3`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.3`,
        fs:  `cpe:2.3:a:montala:resourcespace:4.0.2429:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.3.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.4`,
        fs:  `cpe:2.3:a:hp:laserjet_toolbox:1.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.4.0`,
        fs:  `cpe:2.3:a:hp:mercury_loadrunner_agent:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.4.1`,
        fs:  `cpe:2.3:a:zenprise:zenprise_device_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.4.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.0.4.3`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.2.0.6`,
        fs:  `cpe:2.3:o:ibm:aix:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:9.2.0.7`,
        fs:  `cpe:2.3:o:oracle:solaris:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.0.3`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.0.3.1`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_7900_series_firmware:9.9_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.0.4`,
        fs:  `cpe:2.3:a:teradata:fastload:13.10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.0`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.0.0`,
        fs:  `cpe:2.3:a:apple:terminal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.0.0:r2`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.0.1`,
        fs:  `cpe:2.3:a:netiq:analysis_center:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.0.1:r2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.0.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp1:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.0.2:r2`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.1`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.1.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.1.0`,
        fs:  `cpe:2.3:a:tincan:phplist:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.2`,
        fs:  `cpe:2.3:a:webcreate:webforum:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.2.0`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2.3`,
        fs:  `cpe:2.3:o:redhat:fedora_core:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.2_.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.642.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.3.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.3.0.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.3.1`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.3.1.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.3.2.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.3.3`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.3.3.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.4.0`,
        fs:  `cpe:2.3:a:usebb:usebb:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.4.0.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:rc.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.4.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.1.4.1.0`,
        fs:  `cpe:2.3:a:microsoft:directx_media:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:10.2.0.0`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server:11i`,
        fs:  `cpe:2.3:a:brlcad:brlcad:7.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_10g:10.1.2.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_discussion_forum_portlet:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_portal:-`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_portal:3.0.9.8.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2009.925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_portal:9.0.2`,
        fs:  `cpe:2.3:a:redhat:ddskk-xemacs:11.6.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_portal:9.0.2.3`,
        fs:  `cpe:2.3:a:vmware:virtual_infrastructure_client:2.0.2.50618:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_portal:9.0.2.3a`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.15.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_portal:9.0.2.3b`,
        fs:  `cpe:2.3:a:atlassolutions:accipiter_direct_server:6.0.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:-`,
        fs:  `cpe:2.3:a:hp:process_resource_manager:c.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:2.0.0.0`,
        fs:  `cpe:2.3:a:rim:blackberry_desktop_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:2.0.0.1`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:2.0.0.2`,
        fs:  `cpe:2.3:a:emulex:fibre_channel_hbanyware:2.1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:2.0.0.3`,
        fs:  `cpe:2.3:h:huawei:5310hi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:9.0.0.4.0`,
        fs:  `cpe:2.3:a:citrix:xenapp_migration:6.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:9.0.2.0.0`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.7:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:9.0.2.2.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1068.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:9.0.2.3.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:9.0.3.1.0`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:9.0.4.0.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:9.0.4.1.0`,
        fs:  `cpe:2.3:o:carlosgavazzi:eos-box_photovoltaic_monitoring_system_firmware:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:10.1.2.0.0`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d45.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:10.1.2.0.2`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_server_web_cache:10.1.2.2.0`,
        fs:  `cpe:2.3:a:python:python:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_testing_suite:12.4.0.2`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_testing_suite:12.5.0.1`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_testing_suite:12.5.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16.06\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:application_testing_suite:12.5.0.3`,
        fs:  `cpe:2.3:h:dell:powerconnect_5324:1.0.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications:-`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications:10.7`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20130211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications:11.0`,
        fs:  `cpe:2.3:a:emc:eroom:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_framework:11.5.10.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_framework:12.1`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_framework:12.1.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_framework:12.2`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_framework:12.2.3`,
        fs:  `cpe:2.3:a:microsoft:word:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_framework:12.2.4`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_framework:12.2.5`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_manager:12.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:applications_technology_stack:11.5.10.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:approvals_management:11.5.10.2`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:balanced_scorecard:11.5.10.2`,
        fs:  `cpe:2.3:a:solventus:com_jgen:0.9.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:balanced_scorecard:12.1`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:business_intelligence:11.1.1.7.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:business_intelligence:11.1.1.9.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:business_intelligence:11.2.1.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:business_intelligence:12.2.1.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adobe:fireworks_cs4:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:business_intelligence_publisher:11.1.1.7.0`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_team_services:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:business_intelligence_publisher:11.1.1.9.0`,
        fs:  `cpe:2.3:a:cisco:security_agent:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:business_intelligence_publisher:12.2.1.0.0`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:cadview-3d:11.5.10.2`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:cadview-3d:12.1.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:cadview-3d:12.1.2`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:8.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:cadview-3d:12.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:clinical:-`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.5:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:clinical:4.5.0`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:clinical:4.5.1`,
        fs:  `cpe:2.3:a:juniper:junos_space:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:-`,
        fs:  `cpe:2.3:a:php:xhprof:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:9.0.4.2`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:9.0.4.2:r2`,
        fs:  `cpe:2.3:a:hp:proliant_remote_monitor_service:5.11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:10.1.1`,
        fs:  `cpe:2.3:a:nuance:paperport:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:10.1.1:r1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:10.1.2`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.21.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:10.1.2:r1`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.175:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:10.1.2.0`,
        fs:  `cpe:2.3:a:chat_room_project:chat_room:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite:10.1.2.1`,
        fs:  `cpe:2.3:a:debian:debmake:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:collaboration_suite_10g:10.1.2`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:8.0:r3:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_guided_search_and_experience_manager:3.0`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_guided_search_and_experience_manager:3.1.0`,
        fs:  `cpe:2.3:a:symantec:vrtsmh:5.0.433:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_guided_search_and_experience_manager:3.1.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_guided_search_and_experience_manager:3.1.2`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_guided_search_and_experience_manager:11.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_guided_search_and_experience_manager:11.1`,
        fs:  `cpe:2.3:a:pgp:universal_server:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_platform:3.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sed:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_platform:3.1.1`,
        fs:  `cpe:2.3:a:hp:process_resource_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_platform:3.1.2`,
        fs:  `cpe:2.3:a:s9y:serendipity:2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_platform:9.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_platform:10.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_platform:10.2`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_platform:11.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.6.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:commerce_platform:11.1`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:common_applications:11.5.10.2`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:common_applications:12.1.1`,
        fs:  `cpe:2.3:a:ferretcms_project:ferretcms:1.0.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:common_applications:12.1.2`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:common_applications:12.1.3`,
        fs:  `cpe:2.3:a:igniterealtime:openfire:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:common_applications_calendar:12.1.1`,
        fs:  `cpe:2.3:a:emc:documentum_web_publisher:6.5:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:common_applications_calendar:12.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:common_applications_calendar:12.1.3`,
        fs:  `cpe:2.3:h:hp:service_center_server:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_converged_application_server_service_controller:6.1`,
        fs:  `cpe:2.3:a:nih:libzip:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_eagle_local_number_portability_application_processor:10.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_online_mediation_controller:6.1`,
        fs:  `cpe:2.3:o:ibm:i:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_operations_monitor:3.3.92.0.0`,
        fs:  `cpe:2.3:a:abb:robotstudio:5.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_service_broker:6.0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.1-73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_service_broker:6.0::~~engineered_system~~~`,
        fs:  `cpe:2.3:a:intel:proset_wireless:13.2.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_service_broker:6.1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.0:pre9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_unified:7.0`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:5.05.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:communications_user_data_repository:10.0.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:complex_maintenance_repair_and_overhaul:12.1.1`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:complex_maintenance_repair_and_overhaul:12.1.2`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:complex_maintenance_repair_and_overhaul:12.1.3`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:configurator:-`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:configurator:11.5.6.16.52`,
        fs:  `cpe:2.3:a:gnu:gv:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:configurator:11.5.6.16.53`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:configurator:11.5.7.17.31`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:configurator:11.5.10.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:configurator:12.1`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:configurator:12.2`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:connector%2fj:5.1.40`,
        fs:  `cpe:2.3:a:siemens:scalance_x308-2m_firmware:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:corporate_time_outlook_connector:-`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:corporate_time_outlook_connector:3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.42:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:corporate_time_outlook_connector:3.1.1`,
        fs:  `cpe:2.3:a:adobe:director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:corporate_time_outlook_connector:3.1.2`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:corporate_time_outlook_connector:3.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_intelligence:11.5.10.2`,
        fs:  `cpe:2.3:a:ca:directory:r12:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_intelligence:12.1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf009:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_intelligence:12.1.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_intelligence:12.1.3`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_intelligence:12.2.3`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_intelligence:12.2.4`,
        fs:  `cpe:2.3:a:paretologic:regcure:1.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_intelligence:12.2.5`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_interaction_history:12.1.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_interaction_history:12.1.2`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_interaction_history:12.1.3`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_interaction_history:12.2.3`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_interaction_history:12.2.4`,
        fs:  `cpe:2.3:a:avaya:secure_access_link_gateway:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_interaction_history:12.2.5`,
        fs:  `cpe:2.3:a:f5:linerate:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_relationship_management_technical_foundation:11.5.10.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_relationship_management_technical_foundation:12.1.3`,
        fs:  `cpe:2.3:a:siemens:comos:10.1.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_relationship_management_technical_foundation:12.2.3`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_relationship_management_technical_foundation:12.2.4`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:customer_relationship_management_technical_foundation:12.2.5`,
        fs:  `cpe:2.3:a:al_jazeera_project:al_jazeera:6.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:-`,
        fs:  `cpe:2.3:a:myanmars:myanmar_housing_\:_mmhome:1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:9.2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.55:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:9.2.0.2`,
        fs:  `cpe:2.3:a:apache:http_server:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:9.2.0.4`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:10.1`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x2270:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:10.1.0.2`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.3.8:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:10.1.0.3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:10.1.0.4`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:10.2`,
        fs:  `cpe:2.3:a:moodle:moodle:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:10.2.0.1`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.2\(2\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:10.2.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:11.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:11.1.0.6.20`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:data_provider_.net:11.1.0.7.20`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database:11.2.0.4`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database:12.1.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database:12.1.0.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.302.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_assistant:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_assistant:1.0`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_lite:10.3.0.3`,
        fs:  `cpe:2.3:a:nancy_wichmann:sitedoc:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_mobile%2flite_server:10.3.0.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_mobile%2flite_server:11.1.0.0`,
        fs:  `cpe:2.3:a:spip:spip:3.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:1.0.2.2`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:1.0.2.2:r1`,
        fs:  `cpe:2.3:a:sympa:sympa:3.1b.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:4.0.8`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.13.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:4.0.8:r2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:4.2.0`,
        fs:  `cpe:2.3:a:jetico:bcwipe:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:4.2.3`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7.0.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7.0.64`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7.1.3`,
        fs:  `cpe:2.3:a:muvee:autoproducer:4.10.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7.1.4`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7.1.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.11.1:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7.3`,
        fs:  `cpe:2.3:a:apple:xcode:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7.3.3`,
        fs:  `cpe:2.3:a:xymon:xymon:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:7.3.4`,
        fs:  `cpe:2.3:a:cipherdyne:fwknop:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0.1`,
        fs:  `cpe:2.3:a:sgminer_project:sgminer:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0.2`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0.3`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0.4`,
        fs:  `cpe:2.3:a:hp:enterprise:47.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0.5.1`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0.6`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.5:beta2:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.0.6.3`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2xo:3.2.1xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.1.5`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:2006:-:premium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.1.6`,
        fs:  `cpe:2.3:a:orcacle:webcenter_sites:11.1.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.1.7`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.1.7:r1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.1.7.0.0`,
        fs:  `cpe:2.3:a:location_module_project:location:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.1.7.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.5.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:8.1.7.4:r3`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9`,
        fs:  `cpe:2.3:a:sun:sunvts:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.0.1`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.5.3.4870:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.0.1.4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:0.2.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.0.1.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:el:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.0.2.4`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.0.2.4:r2`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.470:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0008_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.1`,
        fs:  `cpe:2.3:a:ibm:cognos_tm1:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.2`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.5.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.3`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.4`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.5`,
        fs:  `cpe:2.3:a:samsung:scx-4200_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.6`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.6:r2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.7`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.18.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.7:r2`,
        fs:  `cpe:2.3:a:xymon:xymon:4.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.8`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.8:r2`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.8dv`,
        fs:  `cpe:2.3:a:ibm:spss_analytical_decision_management:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.0.8dv:r2`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.1`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.4:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:9.2.2`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.10.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1`,
        fs:  `cpe:2.3:a:symantec:ghost_console_and_standard_tools:110.2.1573:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.2`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.3:r1`,
        fs:  `cpe:2.3:a:go-nitty-gritty:right_to_the_nitty_gritty:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)bz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.4`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.4:r1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)xk3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.4.2`,
        fs:  `cpe:2.3:a:hp:status:100.0.272.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.4.2:r1`,
        fs:  `cpe:2.3:a:oracle:mysql_installer:1.0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.5`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.2.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.1.0.5:r1`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2`,
        fs:  `cpe:2.3:a:cisco:content_distribution_manager_4650:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(4d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.1`,
        fs:  `cpe:2.3:a:gnu:automake:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.1:r2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.2`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.2\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.2:r2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20140530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.3:r2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.4`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.4.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.0.5`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.1`,
        fs:  `cpe:2.3:a:apache:james:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:10.2.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.1.0.6`,
        fs:  `cpe:2.3:h:d-link:dap-2553:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.1.0.6.0::enterprise`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.1.0.6.0:enterprise`,
        fs:  `cpe:2.3:a:naxsi_project:naxsi:0.46-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.1.0.7`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.1.0.7.0::enterprise`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.1.0.7.0:enterprise`,
        fs:  `cpe:2.3:a:bestwebsoft:captcha:4.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.2.0.1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.2.0.1.0::enterprise`,
        fs:  `cpe:2.3:h:cisco:ios:12.1ay:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.2.0.1.0:enterprise`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.2.0.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.2.0.3`,
        fs:  `cpe:2.3:a:emc:networker:8.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11.2.0.4`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:11g`,
        fs:  `cpe:2.3:a:ibm:db2_purescale_feature_9.8:-:-:-:*:-:db2_enterprise_edition:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:12.1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server:12.1.0.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.3_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server_lite:-`,
        fs:  `cpe:2.3:a:exim:exim:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server_lite:5.0`,
        fs:  `cpe:2.3:h:enterasys:vh-2402s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server_lite:5.0.1`,
        fs:  `cpe:2.3:a:microsoft:excel:2013:sp1:*:*:rt:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server_lite:5.0.1.0.0`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server_lite:5.0.2`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server_lite:5.0.2.0.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:database_server_lite:5.0.2.9.0`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:-`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:9.0.2.1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:9.0.4`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:9.0.4.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:9.0.4.2`,
        fs:  `cpe:2.3:h:polycom:soundpoint_ip_301:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:9.0.4.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:10.1.2`,
        fs:  `cpe:2.3:a:gnome:evolution:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:10.1.2.0.2`,
        fs:  `cpe:2.3:a:cognos:series_7:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_suite:10.1.2.2`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_tools_for_visual_studio_.net_help:10.2.20`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_tools_for_visual_studio_help:11.1.620`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:developer_tools_for_visual_studio_help:11.1.720`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:diagnostics:-`,
        fs:  `cpe:2.3:o:ibm:flashsystem_v9000_firmware:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:diagnostics:2.0`,
        fs:  `cpe:2.3:a:plainblack:webgui:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:diagnostics:2.1`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:diagnostics:2.2`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:diagnostics:2.3`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_lan_management_solution:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_intelligence:11.5.10.2`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.0.0:rc1:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_intelligence:12.1.1`,
        fs:  `cpe:2.3:h:supermicro:x9scm-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_intelligence:12.1.2`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.1.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_intelligence:12.1.3`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:-`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:4.3`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:6.2.3`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:6.2.4`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:10.2`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:10.7`,
        fs:  `cpe:2.3:h:lexmark:cx860de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.0`,
        fs:  `cpe:2.3:a:cisco:trust_agent:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.1`,
        fs:  `cpe:2.3:a:huawei:campus_series_switch_software:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.2`,
        fs:  `cpe:2.3:a:weeverapps:mcmaster_marauders:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.3`,
        fs:  `cpe:2.3:a:isc:bind:9.1.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.4`,
        fs:  `cpe:2.3:a:hp:secure_web_server_for_tru64:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5`,
        fs:  `cpe:2.3:a:tm_software:tempo:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5:cu2`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.1`,
        fs:  `cpe:2.3:a:drupal:drupal:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.3`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit-32:10.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.4`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.5`,
        fs:  `cpe:2.3:a:adobe:dynamiclink_support:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.6`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.7`,
        fs:  `cpe:2.3:a:compaq:smartstart:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.8`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.569:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.9`,
        fs:  `cpe:2.3:a:sun:grid_engine:5.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.10`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p373:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.10.1`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.5.10.2`,
        fs:  `cpe:2.3:a:a-pdf:restrictions_remover:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.6`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11.8`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:11i`,
        fs:  `cpe:2.3:a:webform_multiple_file_upload_project:webform_multiple_file_upload:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-02-\/g:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.0.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.0.1`,
        fs:  `cpe:2.3:a:juniper:junos_internet_software:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.0.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.0.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.0.4`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.1.1`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator_instrumentation_service:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.1.2`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.1.3`,
        fs:  `cpe:2.3:a:hp:insight_contol:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.2`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.4.5.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.2.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.52:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.2.3`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.2.4`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite:12.2.5`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5816:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite_11i:11.5.10:cu2`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite_application_management_pack:121020`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:e-business_suite_application_management_pack:121030`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:email_center:12.1.1`,
        fs:  `cpe:2.3:h:intel:active_management_technology:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:email_center:12.1.2`,
        fs:  `cpe:2.3:a:process-one:ejabberd:1.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:email_center:12.1.3`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:endeca_server:7.3.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sxf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:endeca_server:7.4.0.0`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:endeca_server:7.5.0.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:endeca_server:7.6.0.0`,
        fs:  `cpe:2.3:h:apple:imac:m9845xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_governance_risk_and_compliance_manager:7.7.2.0`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_governance_risk_and_compliance_manager:7.8.0.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:-`,
        fs:  `cpe:2.3:h:yokogawa:prosafe-rs_\(chs2200\:_soe_opc_interface_package\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9`,
        fs:  `cpe:2.3:h:supermicro:x9db3-tpf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9.0.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.08.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9.0.1.0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9.0.1.5`,
        fs:  `cpe:2.3:a:apache:httpclient:4.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9.0.4.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9.0.4.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9.2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:3.6.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9.2.0.7`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:9.2.0.8`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:10.1.0.3`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:10.1.0.4`,
        fs:  `cpe:2.3:a:google:chrome:17.0.949.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:10.1.0.5`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:10.1.0.6`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:10.2.0.1`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.10m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:10.2.0.5`,
        fs:  `cpe:2.3:a:microsoft:visio:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:10g`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:11.1.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:11.2.0.4`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:12.1.0.4`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager:12.1.0.5`,
        fs:  `cpe:2.3:a:microsoft:sna_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_application_server_control:-`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_application_server_control:9.0.4.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_application_server_control:9.0.4.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_base_platform:11.1.0.1`,
        fs:  `cpe:2.3:h:ibm:system_x3250_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_base_platform:11.2.0.4`,
        fs:  `cpe:2.3:a:webmin:usermin:1.240:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_base_platform:12.1.0.4`,
        fs:  `cpe:2.3:a:symantec:norton_internet_security_2010:17.5.0.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_base_platform:12.1.0.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_database_control:-`,
        fs:  `cpe:2.3:a:vmware:capacityiq:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_database_control:10.1.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0:alpha_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_database_control:10.2.0.3`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_database_control:10.2.0.4`,
        fs:  `cpe:2.3:h:cisco:sg500-28p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_database_control:10.2.0.5`,
        fs:  `cpe:2.3:a:lxml:lxml:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_database_control:11.1.0.7`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_database_control:11.2.0.2`,
        fs:  `cpe:2.3:h:netgear:rm356:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_database_control:11.2.0.3`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.7\(1.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:6.5`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r13b02-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:10`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:10.1.0.0.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:10.1.0.0.3`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:10.1.0.2`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:10.1.0.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:10.1.0.4`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:10.2.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:10.2.0.5`,
        fs:  `cpe:2.3:a:little_games:africa_memory:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:11.1`,
        fs:  `cpe:2.3:a:condor_project:condor:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:11.1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(10\)w5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:11.1.3`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.1.0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:11.2.0.4`,
        fs:  `cpe:2.3:a:ibm:disposal_and_governance_management_for_it:6.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:12.1.0.1`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:12.1.0.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:12.1.0.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2:update28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:12.1.0.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:12.1.0.5`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control:12.1.4`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_grid_control_10g:10.2.0.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_ops_center:12.1.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_ops_center:12.1.4`,
        fs:  `cpe:2.3:h:lexmark:cs720dte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_ops_center:12.2.0`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_ops_center:12.2.1`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_ops_center:12.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)ew4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.1`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.2`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.3`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.4`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.6`,
        fs:  `cpe:2.3:a:piwik:piwik:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.7`,
        fs:  `cpe:2.3:a:restaurantbiller:restaurant_biller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.22.13`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-16p-pwr-ei_ls-5100-16p-pwr-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.47.11`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.48.06`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.12:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.94`,
        fs:  `cpe:2.3:a:synology:ds_file:4.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.95`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.95.f1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.95.j1`,
        fs:  `cpe:2.3:a:paperthin:commonspot_content_server:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.95.p1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.31.272:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.96`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.96.11`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:enterpriseone:8.96.d1`,
        fs:  `cpe:2.3:a:debian:apt:0.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:es1-24:-`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_5600_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:es1-24_firmware:1.3.1.12`,
        fs:  `cpe:2.3:a:ibm:rational_automation_framework:3.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:essbase_server:11.1.2.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:essbase_server:11.1.2.2`,
        fs:  `cpe:2.3:a:python:python:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:exalogic_infrastructure:1.0`,
        fs:  `cpe:2.3:a:adobe:presenter:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:exalogic_infrastructure:2.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:exchange:-`,
        fs:  `cpe:2.3:a:pizzahut:pizza_hut_japan_official_order_application:1.1.0:a:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:field_service:12.1.1`,
        fs:  `cpe:2.3:o:cisco:catos:7.4\(0.2\)clr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:field_service:12.1.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:field_service:12.1.3`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_enterprise_client:2.37:-:*:*:*:windows_ce:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:field_service:12.2.3`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:field_service:12.2.4`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:field_service:12.2.5`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_consolidation_hub:11.5.10.2`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_consolidation_hub:12.1.1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_consolidation_hub:12.1.2`,
        fs:  `cpe:2.3:o:freenas:freenas:0.69.1:-:i386:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_consolidation_hub:12.1.3`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm:6.1.744.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:6.0.0.0.0`,
        fs:  `cpe:2.3:a:ppc64-diag_project:ppc64-diag:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:6.1.0.0.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:6.1.0.2.2`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:6.1.1.0.0`,
        fs:  `cpe:2.3:a:curtis_galloway:exif:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:8.0.0.0.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:pre7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:8.0.0.1.0`,
        fs:  `cpe:2.3:a:novell:iprint:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:8.0.1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1658.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:8.0.2.0.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:8.0.3.0.0`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:8.0.4.0.0`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_asset_liability_management:8.0.5.0.0`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:2.8.0`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:3.1.0`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:4.1.0`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:5.0.2`,
        fs:  `cpe:2.3:a:stillbreathing:bannerman:0.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:5.0.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:5.1.0`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:5.2.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:5.3.0`,
        fs:  `cpe:2.3:a:redhat:resteasy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:5.3.1`,
        fs:  `cpe:2.3:a:ca:ehealth_livehealth:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:5.3.3`,
        fs:  `cpe:2.3:a:playscape:playscape:9.3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:5.3.4`,
        fs:  `cpe:2.3:a:symantec:livestate_recovery:6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:6.0.1`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:6.2.0`,
        fs:  `cpe:2.3:a:winzip:winzip:8.1:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:10.0.0`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:10.0.2`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:10.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.19:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:10.2.0`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.10.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:10.2.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:10.3.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:10.5.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:11.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:11.2.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:11.4.0`,
        fs:  `cpe:2.3:h:apple:imac:mc021xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:12.0.0`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:financial_services_software:12.0.1`,
        fs:  `cpe:2.3:a:monotone:monotone:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:flexcube_direct_banking:12.0.2`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.27a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:flexcube_direct_banking:12.0.3`,
        fs:  `cpe:2.3:a:fusionforge:fusionforge:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:-`,
        fs:  `cpe:2.3:a:qemu:qemu:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:3.0`,
        fs:  `cpe:2.3:a:avaya:aura_application_server_5300:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:4.5`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:4.5.10.22`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.17.0:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:6.0`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:6.0.8.25`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass_guest:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:6i`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:9i`,
        fs:  `cpe:2.3:a:isc:bind:9.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms:10g`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:forms_builder:9.0.4`,
        fs:  `cpe:2.3:a:ibm:java:6.0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:formsbuilder:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8b\)ex4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:fujitsu_m10_firmware:2290`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:9.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:rc1:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.3`,
        fs:  `cpe:2.3:a:skype:skype:3.8.0.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.4`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.642:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.6`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.485:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.8`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.9`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_applications:11.1.10`,
        fs:  `cpe:2.3:a:endonesia:endonesia:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:2.1.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:2.2.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:3.0-04`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.1.0.273:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:3.0.1`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:10.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:3.1.2`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:3.0a5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:4.0`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:6.0`,
        fs:  `cpe:2.3:a:microsoft:word_rt:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:6.1`,
        fs:  `cpe:2.3:a:kwoksys:information_server:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:6.2`,
        fs:  `cpe:2.3:a:altiris:monitor_packs_for_servers:6.0.2066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:6.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:6.5.1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.0`,
        fs:  `cpe:2.3:a:joakim_nygard:webgrind:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.0.1`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b1:pk4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.0.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.0.3`,
        fs:  `cpe:2.3:o:qnap:qts:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.4.0`,
        fs:  `cpe:2.3:a:microsoft:web_applications:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.5`,
        fs:  `cpe:2.3:a:kbs:weblygo:4.04:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.5.1.1`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.5.2`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.19:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.6.1`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:7.6.2`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.0:update2_patch5`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.3.2.0`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.3.5.0`,
        fs:  `cpe:2.3:a:adobe:stock_photos_cs2:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.3.7.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.4`,
        fs:  `cpe:2.3:a:savysoda:wifi_free_hd:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.4.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.0.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.5.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.5.1`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.13.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:8.5.2`,
        fs:  `cpe:2.3:a:microsoft:ie:5.50.4308.2900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:9.2.4`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.0.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1`,
        fs:  `cpe:2.3:a:apache:camel:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.2.3`,
        fs:  `cpe:2.3:o:freebsd:freebsd:0.4_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.3.1`,
        fs:  `cpe:2.3:a:kingsoft:writer_2007:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.3.3.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.336:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.3.4.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.3.4.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.389:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.3.5`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.3.5.1`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.3.6.0`,
        fs:  `cpe:2.3:a:digium:asterisk:13.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.1.4.3`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.3.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.03.020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.3.3.0`,
        fs:  `cpe:2.3:a:citrix:xenapp_server_role_manager:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.3.4`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.3.5`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:10.3.6`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.5.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1`,
        fs:  `cpe:2.3:a:securecomputing:securityreporter:4.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.1.0`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1\(4.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.2.0`,
        fs:  `cpe:2.3:h:huawei:svn5300:v100r001c01b019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.3.0`,
        fs:  `cpe:2.3:h:dell:powerconnect_5324:1.0.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.4.0`,
        fs:  `cpe:2.3:a:microsoft:jet:4.0:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.5`,
        fs:  `cpe:2.3:a:git-scm:git:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.5.0`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.6.0`,
        fs:  `cpe:2.3:a:microsoft:word:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.6.1`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.6.2`,
        fs:  `cpe:2.3:a:microsoft:project_server:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.7`,
        fs:  `cpe:2.3:a:citrix:access_management_console_web_interface:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.7.0`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.8`,
        fs:  `cpe:2.3:a:webmin:usermin:1.420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.8.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.5\(2.12901.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.1.9`,
        fs:  `cpe:2.3:a:avactis:avactis_shopping_cart:1.8.1:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.2.0`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.2.1`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:4.0.2:007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.2.1.0`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.24-25.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.2.2`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.2.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.2.3`,
        fs:  `cpe:2.3:a:nero:nero:5.5.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.2.3.0`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x50:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:11.1.2.4.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:12.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.41:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:12.1.2`,
        fs:  `cpe:2.3:a:autodesk:architectural_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:12.1.2.0`,
        fs:  `cpe:2.3:a:dell:solution_center:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:12.1.2.0.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:12.1.3`,
        fs:  `cpe:2.3:o:juniper:junos:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:12.1.3.0`,
        fs:  `cpe:2.3:a:opsview:opsview:3.10:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:12.2.1`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:27.7.2`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:27.7.3`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:28.2.2`,
        fs:  `cpe:2.3:a:gajennings:this:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:28.2.3`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:fusion_middleware:28.2.4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:general_ledger:11.5.10.2`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:1.0`,
        fs:  `cpe:2.3:a:compaq:insight_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:1.0:ur1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:1.0:ur1_po1`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:2:ur1`,
        fs:  `cpe:2.3:a:python-requests:requests:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:2:ur2`,
        fs:  `cpe:2.3:a:cisco:webns:7.40.2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:2.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:2.1`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.08057:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:2.1.1`,
        fs:  `cpe:2.3:h:hp:jg362a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:3.0`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:3.0.1`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:3.1`,
        fs:  `cpe:2.3:a:joomla-cbe:com_cbe:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:3.1.1`,
        fs:  `cpe:2.3:a:psi-plus:psi:0.15.5145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:3.1.2`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:glassfish_server:3_prelude`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:global_order_promising:12.1.1`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:7.10.020.3176:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:global_order_promising:12.1.2`,
        fs:  `cpe:2.3:a:samba:samba:4.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:global_order_promising:12.1.3`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:global_order_promising:12.2.3`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:global_order_promising:12.2.4`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.21:b6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:global_order_promising:12.2.5`,
        fs:  `cpe:2.3:a:hp:software_security_core:6.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:global_order_promising:12.2.6`,
        fs:  `cpe:2.3:a:microsoft:psservice:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:global_order_promising:12.2.7`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:50.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:goldengate:11.2`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:goldengate:12.1.2`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:health_sciences_applications:8.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:html_db:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:html_db:1.3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:html_db:1.3.6`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:-`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:1.0`,
        fs:  `cpe:2.3:a:spip:spip:2.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:1.0.2.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:1.0.2.1`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3b.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:1.0.2.2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1063.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:8.1.7`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.0.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.0.1.5`,
        fs:  `cpe:2.3:h:huawei:ne40e\/80e:v600r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.0.2`,
        fs:  `cpe:2.3:a:x:libxvmc:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.0.2.3`,
        fs:  `cpe:2.3:o:moxa:miineport_e1_7080_firmware:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.0.3.1`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.0.4.0.0`,
        fs:  `cpe:2.3:a:openstack:heat:2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.0.4.1.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.1`,
        fs:  `cpe:2.3:a:google:v8:3.22.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.2.0`,
        fs:  `cpe:2.3:a:ibm:cognos_express:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.2.0.7`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:9.2.0.8`,
        fs:  `cpe:2.3:h:juniper:router_m5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:10.1.0.5`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization_manager:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:10.1.2.0.0`,
        fs:  `cpe:2.3:a:nero:burnrights:2.99.6.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:10.1.2.0.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:10.1.2.2.0`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:http_server:12.1.2.0`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:5.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:human_capital_management:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.3:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:human_capital_management:8.9`,
        fs:  `cpe:2.3:a:netbsd:ftpd:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:human_capital_management:9.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:human_capital_management_configuration_workbench:12.1.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:human_capital_management_configuration_workbench:12.1.2`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:human_capital_management_configuration_workbench:12.1.3`,
        fs:  `cpe:2.3:o:suse:yast2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:human_resources:11.5.10.2`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion:11.1.2.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion:11.1.2.2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_mail_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion:11.1.2.3`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_financial_management:11.1.1.4`,
        fs:  `cpe:2.3:a:winzip:winzip:12.0.8252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_financial_management:11.1.2.1.104`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_interactive_reporting:11.1.2.1`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_interactive_reporting:11.1.2.2`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_production_reporting_server:11.1.2.1`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_production_reporting_server:11.1.2.2`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_sqr_server_for_oracle:8.3.2`,
        fs:  `cpe:2.3:a:novell:suse_cloud:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_strategic_finance:11.1.2.1.0`,
        fs:  `cpe:2.3:a:apple:apple_tv:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:hyperion_strategic_finance:12.0`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.2:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:identity_analytics:11.1.1.5`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp2:datacenter_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:identity_federation:11.1.1.7`,
        fs:  `cpe:2.3:h:apple:imac:mc019xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:identity_federation:11.1.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:identity_management_10g:-`,
        fs:  `cpe:2.3:a:esri:arcpad:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:identity_management_10g:10.1.4.0.1`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:identity_manager:11.1.2.1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:ilearning:5.2.1`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:ilearning:6.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_configuration_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:ilearning:6.1`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:1.3`,
        fs:  `cpe:2.3:a:shopware:shopware:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:1.4`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:1.4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3`,
        fs:  `cpe:2.3:h:securecomputing:snapgear_sg580:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3a`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3b`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3c`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3d`,
        fs:  `cpe:2.3:h:cisco:multiservice_platform_2650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3e`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3f`,
        fs:  `cpe:2.3:a:sap:netweaver_abap:7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3g`,
        fs:  `cpe:2.3:a:avaya:ip_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3h`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3i`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3j`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:3.0.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.5:sp3k`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp0`,
        fs:  `cpe:2.3:a:cisco:webex_training_manager_for_firefox_or_chrome:5.26.2802:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp0a`,
        fs:  `cpe:2.3:a:google:chrome:6.0.415.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp0b`,
        fs:  `cpe:2.3:o:cisco:ethernet_subscriber_solution_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp0c`,
        fs:  `cpe:2.3:a:digia:qt:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp1`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp1a`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp1b`,
        fs:  `cpe:2.3:o:cisco:catos:4.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp1c`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp2`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp2a`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp2b`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6:sp2c`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6.0`,
        fs:  `cpe:2.3:a:cabextract:cabextract:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6.3`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:4.6.6`,
        fs:  `cpe:2.3:h:intel:server_platform_spsh4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.0:sp0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.0:sp0a`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.4:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.0:sp1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.0:sp1a`,
        fs:  `cpe:2.3:a:digium:asterisk:13.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.0:sp1b`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.0.3`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.0.4`,
        fs:  `cpe:2.3:o:cisco:rv215w_wireless-n_vpn_router_firmware:1.2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.5:sp0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.5:sp0b`,
        fs:  `cpe:2.3:a:apache:cassandra:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:5.5.1`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:6.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:7.7`,
        fs:  `cpe:2.3:a:listener-interactive:kfai_community_radio:2.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:7.8`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:8.0.0.0`,
        fs:  `cpe:2.3:h:cisco:router_2600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:8.1.1.0`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:8.2.2.0`,
        fs:  `cpe:2.3:a:emc:documentum_wdk:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:10.2.0`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup_agent:-:*:sql:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:10.3.0`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.10:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:10.3.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:10.4.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd378a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:10.4.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:10.4.2`,
        fs:  `cpe:2.3:h:f5:firepass_4100:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:11.0`,
        fs:  `cpe:2.3:a:en2grate:eta_mobile:1.6.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:12.0`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance:a5\(2.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:12.0:in`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:12.1`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:13.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:13.1`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:13.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:13.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:industry_applications:13.4`,
        fs:  `cpe:2.3:a:s3graphics:s3_graphics_utilities:3.3201.25d40-1013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:integrated_lights_out_manager_firmware:3.2.3`,
        fs:  `cpe:2.3:a:sixnet:udr:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:integration_services_server:11.1.2.1`,
        fs:  `cpe:2.3:h:lexmark:e34x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:integration_services_server:11.1.2.2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_blending:11.5.10.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p149:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_blending:12.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_blending:12.1.2`,
        fs:  `cpe:2.3:a:opera:opera_mobile:12.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_blending:12.1.3`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_blending:12.2.3`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_blending:12.2.4`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.98a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_blending:12.2.5`,
        fs:  `cpe:2.3:h:supermicro:x7spt-df-d525\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_center_intelligence:11.5.10.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_center_intelligence:12.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_center_intelligence:12.1.2`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:interaction_center_intelligence:12.1.3`,
        fs:  `cpe:2.3:a:ca:unicenter_software_delivery:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_directory:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_directory:2.0.6`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_directory:2.1.1`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_directory:2.1.1.1`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.19m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_directory:3.0.1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_expenses:11.5.10.2`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.6:pl2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_expenses:12.1.1`,
        fs:  `cpe:2.3:a:spip:spip:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_expenses:12.1.2`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:17.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_expenses:12.1.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_expenses:12.2.3`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_expenses:12.2.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:beta.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:internet_expenses:12.2.5`,
        fs:  `cpe:2.3:a:plupload:plupload:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:iplanet_web_proxy_server:4.0`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.1.1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:iplanet_web_server:7.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:iprocurement:11.5.10.2`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:ireceivables:11.5.10.2`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jai:1.1.2`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_microsoft_audit_collection_services:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jai:1.1.2:01`,
        fs:  `cpe:2.3:a:sun:n1_grid_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jai:1.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jai:1.1.3::windows`,
        fs:  `cpe:2.3:a:microsoft:office_infopath:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jai:1.1.3:alpha`,
        fs:  `cpe:2.3:a:feiron:feiron:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jai:1.1.3:beta`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.5:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jai:1.1.4`,
        fs:  `cpe:2.3:h:polycom:viewstation_mp:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:java_db:10.6.2.1`,
        fs:  `cpe:2.3:o:yamaha:rta55i:4.06.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:java_dynamic_management_kit:5.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)m2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:1.2`,
        fs:  `cpe:2.3:a:netease:youdao_dictionary:3.0.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:1.2.2`,
        fs:  `cpe:2.3:a:keepass:keepass:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:1.2.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:1.3.0`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:1.3.1`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.6380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.0.2`,
        fs:  `cpe:2.3:a:rpm:rpm:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.0.3`,
        fs:  `cpe:2.3:a:vandyke:vshell:3.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.1`,
        fs:  `cpe:2.3:a:yahoo:messenger:11.0.0.1751:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.3`,
        fs:  `cpe:2.3:a:novell:iprint:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.4`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.5`,
        fs:  `cpe:2.3:o:freebsd:freebsd:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.7`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.21`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.14.1:beta:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.40`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.45`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr1604hf-al-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.51`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:javafx:2.2.76`,
        fs:  `cpe:2.3:a:apptalk_project:apptalk:1.4.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jd_edwards_enterpriseone_tools:9.1`,
        fs:  `cpe:2.3:a:microsoft:ie:5.01:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jd_edwards_enterpriseone_tools:9.1.5`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jd_edwards_enterpriseone_tools:9.2`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.6:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jd_edwards_products:8.98`,
        fs:  `cpe:2.3:a:letshare:world_cup_2014_brazil_-_xem_tv:2.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jd_edwards_products:9.1`,
        fs:  `cpe:2.3:a:rackspace:openstack_windows_guest_agent:1.2.6.1:-:-:*:-:xen_server:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jd_edwards_products:9.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(26\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jd_edwards_products:24.0`,
        fs:  `cpe:2.3:a:adobe:creative_suite:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdeveloper:-`,
        fs:  `cpe:2.3:a:mikejolley:download_monitor:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdeveloper:9.0.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdeveloper:9.0.5`,
        fs:  `cpe:2.3:a:drupal:drupal:7.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdeveloper:10.1.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdeveloper:10.1.2.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdeveloper:10.1.2.3`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.4.2_38`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.4.2_40`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_36`,
        fs:  `cpe:2.3:h:dell:poweredge_server_6650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_38`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_39`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.276:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_40`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_41`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(1\)n2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_45`,
        fs:  `cpe:2.3:a:findingscience:mod_auth_openid:0.1:*:*:*:*:apache:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_51`,
        fs:  `cpe:2.3:a:gitlist:gitlist:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_55`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_61`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_65`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1\(.1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_75`,
        fs:  `cpe:2.3:a:emerson:deltav_workstation:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.5.0:update_81`,
        fs:  `cpe:2.3:a:hp:storevirtual_vsa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_105`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_113`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_115`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:5.0.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_22`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_23`,
        fs:  `cpe:2.3:a:apple:quicktime:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_24`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_25`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_26`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_27`,
        fs:  `cpe:2.3:a:clamav:clamav:0.96:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_29`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.6.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_30`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:11.0.1.764:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_31`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_32`,
        fs:  `cpe:2.3:h:sun:cobalt_raq_3i:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_33`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.40a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_34`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p333:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_35`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_37`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_38`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:06-70-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_39`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_41`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_43`,
        fs:  `cpe:2.3:a:gnu:glibc:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_45`,
        fs:  `cpe:2.3:a:vmware:workstation:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_51`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_60`,
        fs:  `cpe:2.3:a:webyog:sqlyog:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_65`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:5.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_71`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_75`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_85`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.6.0:update_91`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.0:rc10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0`,
        fs:  `cpe:2.3:a:tigertext:tigertext:3.1.405:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_101`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)yz2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_141`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_40`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_45`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_3f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_51`,
        fs:  `cpe:2.3:a:merant:merant_tracker:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_60`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_71`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_72`,
        fs:  `cpe:2.3:a:mcafee:neotrace_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_76`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.16a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_91`,
        fs:  `cpe:2.3:a:symantec:sygate_network_access_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_97`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update_99`,
        fs:  `cpe:2.3:a:hp:software_xercesa_xml_parser:2.7.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update1`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update10`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update11`,
        fs:  `cpe:2.3:h:schneider-electric:bmxp3420302:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update13`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update15`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update17`,
        fs:  `cpe:2.3:a:rick_mead:media_library_categories:1.1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update2`,
        fs:  `cpe:2.3:a:authoring_html:6.x-1.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update21`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update25`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update3`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update4`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update5`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update6`,
        fs:  `cpe:2.3:a:juniper:network_connect:6.0.0.12875:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update7`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.7.0:update9`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_131`,
        fs:  `cpe:2.3:a:qemu:qemu:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_25`,
        fs:  `cpe:2.3:a:yahoo:messenger:3.0.1:beta-35554:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_40`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_5`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_6`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(11c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_65`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_66`,
        fs:  `cpe:2.3:a:wdc:fat32_formatter:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_73`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_74`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.4\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_77`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_91`,
        fs:  `cpe:2.3:a:perl:perl:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:1.8.0:update_92`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:6.0:update_141`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:7.0:update_131`,
        fs:  `cpe:2.3:a:microsoft:forefront_endpoint_protection_2010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:7.0:update_97`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2013:sp1:*:*:rt:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:8.0:update_121`,
        fs:  `cpe:2.3:h:dell:latitude_d530:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:8.0:update_73`,
        fs:  `cpe:2.3:h:perle:iolan_scs32:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jdk:8.0:update_74`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:-`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.5`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.7`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r14b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.7.11`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.7.15.1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.7.18`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.151.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.7.27`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.8`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.8.3`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.8.7`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.8.10`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.8.13`,
        fs:  `cpe:2.3:a:webbynode:webbynode:1.0.5.3:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.8.14`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.8.16`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.1.8.25`,
        fs:  `cpe:2.3:a:x:libfs:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.6`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-60:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.9`,
        fs:  `cpe:2.3:a:ibm:security_guardium:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.17`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.18`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5b\)su6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.21`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.22`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.25`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.0_management_engine:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.26`,
        fs:  `cpe:2.3:a:playscape:jewels_\&amp;_diamonds:1.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.28`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ira:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.29`,
        fs:  `cpe:2.3:a:symmetricom:symmtime:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jinitiator:1.3.1.30`,
        fs:  `cpe:2.3:o:huawei:5310ei_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.4.2_38`,
        fs:  `cpe:2.3:a:gnu:grep:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.4.2_40`,
        fs:  `cpe:2.3:a:lenovo:rescue_and_recovery:4.21.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_36`,
        fs:  `cpe:2.3:a:google:v8:3.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_38`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_39`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_40`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_41`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_45`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_51`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_55`,
        fs:  `cpe:2.3:a:microsoft:iis:6.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_61`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_65`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_75`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.5.0:update_81`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_105`,
        fs:  `cpe:2.3:a:isc:bind:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_113`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:8.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_115`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp1:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_19`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_22`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_23`,
        fs:  `cpe:2.3:a:hp:toolbox:82.0.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_24`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_25`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_26`,
        fs:  `cpe:2.3:h:sun:fire_x4200_server:sw_1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_27`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_29`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_30`,
        fs:  `cpe:2.3:a:microsoft:word:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_31`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_32`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_33`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-4.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_34`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_35`,
        fs:  `cpe:2.3:a:capasystems:performance_guard:6.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_37`,
        fs:  `cpe:2.3:o:radiothermostat:ct80_firmware:1.4.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_38`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_39`,
        fs:  `cpe:2.3:a:apache:struts:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_41`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_43`,
        fs:  `cpe:2.3:a:mit:kerberos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_45`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r15.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_51`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_60`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_65`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p39:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_71`,
        fs:  `cpe:2.3:o:oracle:linux:5:10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_75`,
        fs:  `cpe:2.3:a:foundstone:foundstone_ssldigger:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_85`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p361:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.6.0:update_91`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_m575f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_101`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_141`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_40`,
        fs:  `cpe:2.3:a:isc:bind:9.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_45`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_51`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.23:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_60`,
        fs:  `cpe:2.3:a:php:php:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_71`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_72`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_76`,
        fs:  `cpe:2.3:a:google:chrome:12.0.744.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_91`,
        fs:  `cpe:2.3:a:welcart:welcart:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_97`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_agent:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update_99`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update1`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update10`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update11`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.02:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update13`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update15`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.5.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update17`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update2`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update21`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update25`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update3`,
        fs:  `cpe:2.3:a:apache:poi:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update4`,
        fs:  `cpe:2.3:o:opensuse_project:opensuse:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update5`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update6`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update7`,
        fs:  `cpe:2.3:a:ibm:forms_experience_builder:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.7.0:update9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_131`,
        fs:  `cpe:2.3:o:juniper:unified_access_control_software:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_25`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_40`,
        fs:  `cpe:2.3:a:ffftp:ffftp:1.98:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_5`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.2:-:-:*:documentum:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_6`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_65`,
        fs:  `cpe:2.3:a:zend:zendto:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_66`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.8.3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_73`,
        fs:  `cpe:2.3:a:7-zip:7zip:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_74`,
        fs:  `cpe:2.3:a:shellinabox_project:shellinabox:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_77`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_91`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:1.8.0:update_92`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:6.0:update_141`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:7.0:update_131`,
        fs:  `cpe:2.3:a:oracle:common_applications_calendar:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:7.0:update_97`,
        fs:  `cpe:2.3:a:google:chrome:6.0.474.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:8.0:update_121`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:8.0:update_73`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jre:8.0:update_74`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.1h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.7.1`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3200a:a.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.7.2`,
        fs:  `cpe:2.3:a:x:x.org-xserver:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.7.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je109a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.7.4`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.7.5`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.7.6`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.7.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p444:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.8.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.458.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.8.2`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r27.8.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.0.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.0.1`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.0.2`,
        fs:  `cpe:2.3:h:kyocera:xw320k:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.1.0`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.6.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.1.3`,
        fs:  `cpe:2.3:a:magzter:honeybee_mag:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.1.4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.8:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.1.5`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.2.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.2.3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp1:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.2.4`,
        fs:  `cpe:2.3:a:apache:mod_perl:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.2.5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.2.6`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.2.7`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.2.8`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.2.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.366:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.3.1`,
        fs:  `cpe:2.3:a:ibm:sterling_connect:4.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.3.2`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.3.4`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.3.5`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.3.8`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.3.10`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jrockit:r28.3.13`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jserver:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jserver:8.1.7.2.0`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jsp:-`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:jsp:1.1.1`,
        fs:  `cpe:2.3:a:microsoft:visual_c\&#43;\&#43;:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:knowledge_management:12.1.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta39:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:knowledge_management:12.1.2`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:knowledge_management:12.1.3`,
        fs:  `cpe:2.3:h:cisco:5500_series_adaptive_security_appliance:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:knowledge_management:12.2.3`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:knowledge_management:12.2.4`,
        fs:  `cpe:2.3:a:symantec:product_authentication_service_client:4.3.34.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:knowledge_management:12.2.5`,
        fs:  `cpe:2.3:a:symantec:norton_personal_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:learning_management:11.5.10.2`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:life_sciences_data_hub:2.1`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.0.0.10021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:5:10`,
        fs:  `cpe:2.3:a:koha:koha:3.14.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:5:11`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:5.9`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:6:5`,
        fs:  `cpe:2.3:a:alentum:weblog_expert:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:6:6`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:6:7`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:6.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.87:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:6.4`,
        fs:  `cpe:2.3:a:bzip:bzip2:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:7:0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:7:1`,
        fs:  `cpe:2.3:a:divx:divx_codec:6.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:7:2`,
        fs:  `cpe:2.3:a:wokamoto:wp-cron_dashboard:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:7.0`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:7.2`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_internet_server:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:linux:7.3`,
        fs:  `cpe:2.3:a:spice_project:spice:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:listener:-`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.3:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:listener:7.3.4`,
        fs:  `cpe:2.3:a:openttd:openttd:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:listener:8.0.6`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:3.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:listener:8.1.6`,
        fs:  `cpe:2.3:a:haxx:curl:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:logging_utilities:6.1.3.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:marketing:11.5.10.2`,
        fs:  `cpe:2.3:a:vmware:player:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:marketing:12.1.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:marketing:12.1.2`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:marketing:12.1.3`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:marketing:12.2.3`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:marketing:12.2.4`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:marketing:12.2.5`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_arspos:1.5`,
        fs:  `cpe:2.3:a:easy_video_downloader_project:easy_video_downloader:4.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_c2:9.89.0.0`,
        fs:  `cpe:2.3:o:d-link:dap-2553_firmware:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_cwdirect:12.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_cwdirect:13.0`,
        fs:  `cpe:2.3:h:cisco:c200_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_cwdirect:14.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_cwdirect:15.0`,
        fs:  `cpe:2.3:a:ibm:soliddb:4.5.178:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_cwdirect:16.0`,
        fs:  `cpe:2.3:h:nec:multiwriter_1700c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_cwdirect:17.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_cwdirect:17.018.0`,
        fs:  `cpe:2.3:o:microsoft:windows:server_2008:unknown:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:micros_cwdirect:18.0`,
        fs:  `cpe:2.3:a:collabnet:automatic_update:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mobile_application_server:12.1`,
        fs:  `cpe:2.3:a:hp:storage_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mobile_application_server:12.2`,
        fs:  `cpe:2.3:a:vmware:vcenter_server_appliance:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.1`,
        fs:  `cpe:2.3:h:f5:big-ip_6800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.1_02`,
        fs:  `cpe:2.3:a:netiq:security_manager_log_archive_resource_kit:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:3.2.0.0303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_01`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_02`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_03`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_04`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.3.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_05`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_06`,
        fs:  `cpe:2.3:a:openbsd:openssh:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_07`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_08`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_09`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_10`,
        fs:  `cpe:2.3:a:sun:jre:6.0.270:update27:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_11`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_12`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.11:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_13`,
        fs:  `cpe:2.3:a:onesolutionapps:bust_out_bail:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_14`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.60310.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:1.2_15`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sv2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.0.0`,
        fs:  `cpe:2.3:a:ibm:soliddb:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.0.1`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.0.2`,
        fs:  `cpe:2.3:a:oracle:application_management_pack:12.1:*:*:*:*:e-business_suite:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.0.3`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:36.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.2`,
        fs:  `cpe:2.3:a:atlassian:jira:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.3`,
        fs:  `cpe:2.3:o:schrack:technik_microcontrol_firmware:1.7.0\(937\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.4`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jax:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.5`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.6`,
        fs:  `cpe:2.3:a:apache:poi:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.7`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.8`,
        fs:  `cpe:2.3:a:cisco:router_web_setup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.9`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a4\(2.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.10`,
        fs:  `cpe:2.3:a:vmware:license_server:2.5.0.64247:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.11`,
        fs:  `cpe:2.3:a:cherokee-project:cherokee:1.2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.12`,
        fs:  `cpe:2.3:a:mod_nss_project:mod_nss:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.13`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.14`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.3.1:interim:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.15`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.16`,
        fs:  `cpe:2.3:a:red-gate:sql_response:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.17`,
        fs:  `cpe:2.3:a:sony:vaio_manual_cybersupport:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.18`,
        fs:  `cpe:2.3:a:altiris:notification_server:6.0.6074:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.19`,
        fs:  `cpe:2.3:a:symantec:backup_exec:2012:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.20`,
        fs:  `cpe:2.3:a:digia:qt:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.21`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.22`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.23`,
        fs:  `cpe:2.3:a:epiqo:email:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.24`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.25`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.26`,
        fs:  `cpe:2.3:o:a10networks:advanced_core_operating_system:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.27`,
        fs:  `cpe:2.3:a:novell:client:2.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.28`,
        fs:  `cpe:2.3:a:djangoproject:django:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.1.29`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.2.0`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.2.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.2.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.2.3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.4.2:*:*:*:*:*:*:permissive`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.2.4`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-backup:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.2.5`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.2.6`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mojarra:2.2.7`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:1.5.1`,
        fs:  `cpe:2.3:a:hp:software_update:3.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.51`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.52`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.22:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.52:sp1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p464:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.53`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.54`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.55`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.2.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.56`,
        fs:  `cpe:2.3:a:tm_software:tempo:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.57`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.58`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.59`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf238a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.60`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.61`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.62`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.63`,
        fs:  `cpe:2.3:h:cisco:spa_504g_4-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.64`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.65`,
        fs:  `cpe:2.3:h:securecomputing:sidewinder_g2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.66`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.67`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.68`,
        fs:  `cpe:2.3:o:fortinet:fortianalyzer_firmware:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.69`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.70`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4.4014:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.71`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(5\)n1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.72`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.11:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.1.73`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_tools:8.46.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.0`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.2`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.3`,
        fs:  `cpe:2.3:h:lexmark:w840:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.4`,
        fs:  `cpe:2.3:a:sysaid:sysaid_admin_tools:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.5`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.6`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.6:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.7`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.8`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.9`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.10`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.11`,
        fs:  `cpe:2.3:a:apple:keynote:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.12`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.13`,
        fs:  `cpe:2.3:a:gnu:grep:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.14`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.15`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p230:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.16`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.20:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.17`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.18`,
        fs:  `cpe:2.3:a:innominate:mguard_industrial_rs:hw-105000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.19`,
        fs:  `cpe:2.3:a:nagios:nagios:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.20`,
        fs:  `cpe:2.3:a:oracle:common_applications:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.21`,
        fs:  `cpe:2.3:h:yokogawa:exaopc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.22`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.23`,
        fs:  `cpe:2.3:a:filemaker:filemaker_server:10.0.1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.24`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.25`,
        fs:  `cpe:2.3:o:cisco:ios:12.0sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.25:a`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.26`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.27`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.28`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.29`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.30`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.2.0:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.31`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.32`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:11:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.33`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:1.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.34`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.35`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.36`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.37`,
        fs:  `cpe:2.3:a:exim:exim:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.38`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.39`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.40`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.41`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.42`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.43`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.44`,
        fs:  `cpe:2.3:a:digia:qt:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.45`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.46`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.47`,
        fs:  `cpe:2.3:a:kozos:easyctf:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.48`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.49`,
        fs:  `cpe:2.3:a:boost:boost:1.33.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.50`,
        fs:  `cpe:2.3:a:monotone:monotone:0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.51`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.6:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.52`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.53`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.54`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a7\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.55`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.56`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1279.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.57`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.6.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.58`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.59`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.5.60`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.0`,
        fs:  `cpe:2.3:a:raphael_zschorsch:rzautocomplete:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.1`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.5`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.6`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5503:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.7`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.8`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.9`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.10`,
        fs:  `cpe:2.3:a:freso:languageicons:6.x-2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.11`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.12`,
        fs:  `cpe:2.3:a:sincerely:ink_cards:2.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.13`,
        fs:  `cpe:2.3:a:codemasters:dirt:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.641:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.16`,
        fs:  `cpe:2.3:a:skype:skype:0.97.0.40:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.17`,
        fs:  `cpe:2.3:a:python:python:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.18`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:12.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.19`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.20`,
        fs:  `cpe:2.3:a:gameinfo:best_racing\/moto_games_ranking:2.2.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.21`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.22`,
        fs:  `cpe:2.3:a:hp:bpd_scan_carrier:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.23`,
        fs:  `cpe:2.3:a:avonesoft:iphone\/itouch\/ipod_to_computer_transfer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.24`,
        fs:  `cpe:2.3:a:clamav:clamav:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.25`,
        fs:  `cpe:2.3:a:google:chrome:10.0.612.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.26`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.27`,
        fs:  `cpe:2.3:a:nice:recording_express:6.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.28`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.29`,
        fs:  `cpe:2.3:a:nero:live_help:1.0.162.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.30`,
        fs:  `cpe:2.3:a:symantec:netbackup:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.31`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.32`,
        fs:  `cpe:2.3:a:gnu:glibc:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.33`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.34`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.35`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:13.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.36`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.37`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.38`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.39`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.40`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.6.285.7.10`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:17.0.0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.2`,
        fs:  `cpe:2.3:a:frontrange:devicewall_dynamic_activity_monitor:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.3`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.4`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.5`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.6`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf182a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.7`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd354a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.9`,
        fs:  `cpe:2.3:a:sympa:sympa:5.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.10`,
        fs:  `cpe:2.3:a:altiris:software_delivery_solution_agent:6.1.1016.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.11`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.12`,
        fs:  `cpe:2.3:h:cisco:881_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.13`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.14`,
        fs:  `cpe:2.3:a:cisco:cisco_policy_suite:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.15`,
        fs:  `cpe:2.3:o:cisco:catos:7.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.16`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.17`,
        fs:  `cpe:2.3:a:xnview:xnview:1.82.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.18`,
        fs:  `cpe:2.3:a:litronic:fortezza:51.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.19`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.20`,
        fs:  `cpe:2.3:a:apache:santuario_xml_security_for_java:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.21`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:5.7.22`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.2.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:6.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql:8.0`,
        fs:  `cpe:2.3:a:zoneo-soft:phptraffica:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fc:6.1.2`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:-`,
        fs:  `cpe:2.3:a:ffftp:ffftp:1.98:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:0.6`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-4.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:0.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.289:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:0.8`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:0.9`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:0.9d`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.14s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.1`,
        fs:  `cpe:2.3:h:cisco:886_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.1b`,
        fs:  `cpe:2.3:a:apache:solr:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.1f`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.1g`,
        fs:  `cpe:2.3:o:cisco:headend_digital_broadband_delivery_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.1h`,
        fs:  `cpe:2.3:a:shopware:shopware:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.1i`,
        fs:  `cpe:2.3:a:yokogawa:centum_vp:r5.02.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.2a`,
        fs:  `cpe:2.3:a:hp:fax:100.0.187.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:1.2b`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.1`,
        fs:  `cpe:2.3:a:web2py:web2py:1.87.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.3`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.5`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.06b43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.6`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.8`,
        fs:  `cpe:2.3:a:escucha_eldiario_project:escucha_eldiario:1.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.9`,
        fs:  `cpe:2.3:a:arg0:encfs:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.10`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.11`,
        fs:  `cpe:2.3:a:mesa3d:mesa:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.12`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.13`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:2.0.14`,
        fs:  `cpe:2.3:o:yahama:rtx2000:7.01.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.53.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.1`,
        fs:  `cpe:2.3:o:debian:debian_linux:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.2`,
        fs:  `cpe:2.3:a:debian:mime-support:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.200:update20:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.4`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.5`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.6`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.7`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.8`,
        fs:  `cpe:2.3:a:ntwind:winsnap:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.9`,
        fs:  `cpe:2.3:a:samba:samba:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.10`,
        fs:  `cpe:2.3:a:digium:asterisk:13.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.11`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.12`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.13`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.15`,
        fs:  `cpe:2.3:o:cisco:mds_9000_san-os:1.3\(3.33\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.16`,
        fs:  `cpe:2.3:o:netbsd:netbsd:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.0.17`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.0`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.2`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.3`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.4`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.5`,
        fs:  `cpe:2.3:h:google:mini_search_appliance:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.6`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.7`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.8`,
        fs:  `cpe:2.3:a:apache:ambari:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.9`,
        fs:  `cpe:2.3:a:vmware:springsource_spring_security:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.10`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.11`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.12`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.13`,
        fs:  `cpe:2.3:a:google:chrome:10.0.623.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.14`,
        fs:  `cpe:2.3:o:google:android:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:3.1.15`,
        fs:  `cpe:2.3:a:piwik:piwik_mobile_2:2.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.0`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.2`,
        fs:  `cpe:2.3:h:huawei:s9303:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.3`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.4`,
        fs:  `cpe:2.3:a:sheado:furdiburb:1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.6`,
        fs:  `cpe:2.3:a:citrix:access_gateway:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.7`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.0.8`,
        fs:  `cpe:2.3:o:cisco:catos:7.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.0`,
        fs:  `cpe:2.3:a:typo3:neos:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.3`,
        fs:  `cpe:2.3:a:apache:cxf:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.4`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(16.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.7`,
        fs:  `cpe:2.3:a:emc:networker:7.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(44\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.9`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.10`,
        fs:  `cpe:2.3:a:microsoft:ie:5.0.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.11`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.12`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.13`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.9:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.14`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.15`,
        fs:  `cpe:2.3:a:debian:debian-goodies:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.16`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds3300:1726:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.17`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.18`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.19`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.20`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.3.2:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.21`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.38.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.22`,
        fs:  `cpe:2.3:a:oracle:sun_role_manager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.23`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.24`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.25`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.26`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.27`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.28`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:182:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.29`,
        fs:  `cpe:2.3:a:symantec:veritas_jre_redistribution:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.30`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf239a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.31`,
        fs:  `cpe:2.3:a:tincan:phplist:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.32`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2\(.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.33`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.34`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.35`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(12e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.36`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.37`,
        fs:  `cpe:2.3:a:acmailer:acmailer:3.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.38`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.39`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.40`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.41`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.42`,
        fs:  `cpe:2.3:a:boost:boost:1.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.43`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.44`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.05:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.45`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fj:5.1.46`,
        fs:  `cpe:2.3:a:kryo:iodine:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:10.3.0:rc3:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.2`,
        fs:  `cpe:2.3:a:vmware:player:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch_3500yl:k.11.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.4`,
        fs:  `cpe:2.3:a:shopware:shopware:5.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.5`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.6`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r005c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.7`,
        fs:  `cpe:2.3:a:vitamin_plugin_project:vitamin:1.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.8`,
        fs:  `cpe:2.3:a:sun:hotjava_browser:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.9`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.10`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:1.0.11`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.0`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p153:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.2`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.3`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.4`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20100621:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.6`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.18.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)se4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.9`,
        fs:  `cpe:2.3:a:f5:linerate:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.0.10`,
        fs:  `cpe:2.3:o:alcatel:aos:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.2`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.3`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0.220:update22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.4`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.5`,
        fs:  `cpe:2.3:a:autodesk:autocad_architecture_2012_language_pack:18.2.51.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.6`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.7`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.1.8`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.0`,
        fs:  `cpe:2.3:a:plone:plone:5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.3`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gw_3241:2.0\(1.51\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.5`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.00.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.6`,
        fs:  `cpe:2.3:a:symantec:client_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.7`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:5.2.8`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.0`,
        fs:  `cpe:2.3:h:zte:zxdsl_831:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.1`,
        fs:  `cpe:2.3:a:python:pillow:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.2`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)yw3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.4`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.0.878:online_windows_2000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.6`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.7:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.7`,
        fs:  `cpe:2.3:h:cisco:ie-4000-8gt8gp4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.0.8`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.1.0`,
        fs:  `cpe:2.3:a:libav:libav:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.1.1`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.1.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.1.3`,
        fs:  `cpe:2.3:a:hp:fax:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.1.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.1.5`,
        fs:  `cpe:2.3:a:ibm:leads:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.1.6`,
        fs:  `cpe:2.3:a:alienwp:hatch:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.1.7`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.2.0`,
        fs:  `cpe:2.3:a:microsoft:windows_essentials:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.2.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.2.2`,
        fs:  `cpe:2.3:a:google:chrome:6.0.490.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.2.3`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.2.4`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.2.5`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.6:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.2.6`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.1`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.2`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.3`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.4`,
        fs:  `cpe:2.3:h:hp:0235a393:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.5`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.04:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.6`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.7`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.0.10.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.8`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.3.9`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.16344:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.4.0`,
        fs:  `cpe:2.3:o:gentoo:linux:2.2.28:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.4.1`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.4.2`,
        fs:  `cpe:2.3:a:redhat:rsync:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.4.3`,
        fs:  `cpe:2.3:h:huawei:quidway_s6700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.4.4`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.4.5`,
        fs:  `cpe:2.3:h:hp:officejet_g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.4.6`,
        fs:  `cpe:2.3:a:oracle:warehouse_builder:10.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.5.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.5.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.5.3`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.5.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.15.99.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.5.5`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.5.6`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.5.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)xi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.6.1`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.6.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.403:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.6.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.6.4`,
        fs:  `cpe:2.3:a:microsoft:lync:2010:*:attendee:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.6.5`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.6.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(9d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.6.7`,
        fs:  `cpe:2.3:a:python:python:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.0`,
        fs:  `cpe:2.3:a:graphon:go-global_ux:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.0:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.2`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.3`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.4`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.5`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.7`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.8`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.7.9`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.0`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.1`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.0.0:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.2`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.3`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.411:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.31:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.6`,
        fs:  `cpe:2.3:a:python:python:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.7`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_access_control_list_manager:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.8.8`,
        fs:  `cpe:2.3:a:emc:networker:8.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.609.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.2`,
        fs:  `cpe:2.3:o:d-link:dir-505l_shareport_mobile_companion_firmware:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.4`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.5`,
        fs:  `cpe:2.3:o:novell:opensuse:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.6`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.3.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.7`,
        fs:  `cpe:2.3:a:visualcertexam:visual_certexam_suite:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.8`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.9`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.10`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.9.11`,
        fs:  `cpe:2.3:a:avsmedia:audio_tools:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.10.0`,
        fs:  `cpe:2.3:a:soprano:fonecta_verify:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.10.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.10.2`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.10.3`,
        fs:  `cpe:2.3:a:apache:httpasyncclient:4.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.10.4`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:8.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.10.5`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fnet:6.10.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector%2fodbc:5.1.8`,
        fs:  `cpe:2.3:a:antoine_beaupre:hostmaster:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector_c:1.1.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector_j:5.1.15.0`,
        fs:  `cpe:2.3:a:horde:imp:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector_net:6.3.6`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector_net:6.3.7`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.12m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_connector_net:6.4.4`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.1:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_documents:5.5.11`,
        fs:  `cpe:2.3:a:digium:asterisk:10.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_documents:5.5.17`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1046:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_enterprise_monitor:3.0.25`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_enterprise_monitor:3.1.2`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_examples_and_samples:5.5.11`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:gold:srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_examples_and_samples:5.5.15`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_installer:1.0.11.0`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_installer:1.0.17.0`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x51:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_installer:1.0.18.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_workbench:6.3.8`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.4:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_workbench_ce:5.2.26`,
        fs:  `cpe:2.3:o:cisco:ios:11.0\(22a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_workbench_ce:5.2.31`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19\)fc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_workbench_ce:5.2.33`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_workbench_ce:5.2.34.2`,
        fs:  `cpe:2.3:a:webmin:usermin:1.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:mysql_workbench_ce:5.2.35`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1055.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:netra_sparc_t3-1:-`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:netra_sparc_t3-1b:-`,
        fs:  `cpe:2.3:a:namazu:namazu:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:netra_sparc_t4-1:-`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase_lt:2.1.1063:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:netra_sparc_t4-2:-`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:netra_sparc_t4-2b:-`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:odac_documentation_for_visual_studio_2010:11.2.2`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:odac_documentation_for_visual_studio_2010:11.2.12`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:r2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:olap:11.2.0.4`,
        fs:  `cpe:2.3:a:cisco:catalyst_5xxx_supervisor_software:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:olap:12.1.0.1`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:olap:12.1.0.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je165a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:openjdk:1.6.0`,
        fs:  `cpe:2.3:a:isc:bind:8.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:openjdk:1.7.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:openjdk:1.8.0`,
        fs:  `cpe:2.3:a:mintboard:mintboard:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:opensolaris:snv_01`,
        fs:  `cpe:2.3:a:xnview:xnview:1.92.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:opensolaris:snv_98`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:opensolaris:snv_134`,
        fs:  `cpe:2.3:a:gnu:gcc:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:opensso:3.0-0.7`,
        fs:  `cpe:2.3:a:samba:samba:2.2.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:opensso:7.1`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:opensso:8.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:opensso_enterprise:8.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1..5.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:opmn_daemon:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:opus_10g_ethernet_switch_family:1.2.2.13`,
        fs:  `cpe:2.3:h:hp:cf118a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:opus_10g_ethernet_switch_family:1.2.2.15`,
        fs:  `cpe:2.3:h:belkin:n150_f9k1009:v1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:opus_10g_ethernet_switch_family:1.3.1.13`,
        fs:  `cpe:2.3:a:horde:imp:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:opus_10g_ethernet_switch_family:2.0.0.6`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1.4:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_and_sun_systems_product_suite:3.2`,
        fs:  `cpe:2.3:a:sgpsys:gems:1.0.3181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_and_sun_systems_product_suite:3.3`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_and_sun_systems_product_suite:4.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_and_sun_systems_product_suite:4.1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_berkeley_db:11.2.5.0.32`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_berkeley_db:11.2.5.1.29`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.b0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_berkeley_db:11.2.5.2.42`,
        fs:  `cpe:2.3:a:debian:apt:0.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_berkeley_db:11.2.5.3.28`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a5\(2.1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_berkeley_db:12.1.6.0.35`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1m:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_berkeley_db:12.1.6.1.26`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc3000\/epc3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_berkeley_db:12.1.6.2.23`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_communications_unified_communications_suite_connector_for_microsoft_outlook:7.3.116.990`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_data_provider_for_.net_help:10.1.10`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_data_provider_for_.net_help:10.2.0`,
        fs:  `cpe:2.3:a:ca:unicenter_jasmine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_data_provider_for_.net_help:10.2.20`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_data_provider_for_.net_help:10.2.50`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_data_provider_for_.net_help:11.1.620`,
        fs:  `cpe:2.3:a:condor_project:condor:7.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_data_provider_for_.net_help:11.1.720`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_data_provider_for_.net_help:11.2.10`,
        fs:  `cpe:2.3:a:exim:exim:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oracle_database_express_edition:10.2.1015`,
        fs:  `cpe:2.3:a:php:php:5.6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:oss_support_tools:8.11.16.3.8`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:outside_in_technology:8.5.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:outside_in_technology:8.5.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:outside_in_technology:8.5.2`,
        fs:  `cpe:2.3:a:splunk:splunk:6.5.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:payroll:12.1.1`,
        fs:  `cpe:2.3:h:linksys:psus4_printserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:payroll:12.1.2`,
        fs:  `cpe:2.3:a:microsoft:office_infopath:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:payroll:12.1.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:payroll:12.2.3`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:payroll:12.2.4`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:payroll:12.2.5`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:payroll:12.2.6`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.1`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.4:bundle16`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.8:bundle10`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5c\)e12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.8:bundle11`,
        fs:  `cpe:2.3:a:symantec:brightmail_antispam:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.8:bundle13`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.0\(2.49\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.8:ga`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.9`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.9:bundle11`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_appliance:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.9:bundle13`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.13:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.9:bundle26`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.9:bundle3`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.9:bundle4`,
        fs:  `cpe:2.3:a:analogx:proxy:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.9:ga`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(3\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.9.18`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.40:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.22`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.22.11:ga`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.22.13`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.22.14`,
        fs:  `cpe:2.3:a:webmin:usermin:1.490:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.22.15`,
        fs:  `cpe:2.3:o:cisco:catos:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.22.17`,
        fs:  `cpe:2.3:h:huawei:cx600:v600r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.44`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.01.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.45`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.45.17`,
        fs:  `cpe:2.3:a:xfree86:xfree86:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.46`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.46:ga`,
        fs:  `cpe:2.3:h:ibm:storwize_v7000_unified:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.46.02`,
        fs:  `cpe:2.3:a:indus-systems:idrawings_setup:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.46.03`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.274:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.46.12`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.46.15`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.47:ga`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.47.04`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:2.1.002:patch02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.47.09`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.47.11`,
        fs:  `cpe:2.3:a:imember360:imember360:3.4.014:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.47.12`,
        fs:  `cpe:2.3:a:intel:mlogview:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.47.13`,
        fs:  `cpe:2.3:a:realmd_project:realmd:15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.47.14`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.48:ga`,
        fs:  `cpe:2.3:a:ibm:rational_asset_analyzer:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.48.03`,
        fs:  `cpe:2.3:a:sun:java_dynamic_management_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.48.06`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.48.08`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.48.10`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.48.13`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)ja10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.49.02`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.49.05`,
        fs:  `cpe:2.3:a:google:chrome:14.0.787.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.49.14`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.97.2.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.97.2.5`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:8.98.0.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.826:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:9.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:9.0:bundle3`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:9.0:bundle7`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.1.8.20:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:9.0.8`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.0:cf05:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise:9.1:bundle4`,
        fs:  `cpe:2.3:a:oracle:http_server:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_customer_relationship_management:-`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_customer_relationship_management:8.9`,
        fs:  `cpe:2.3:a:phpyabs:phpyabs:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_customer_relationship_management:8.81`,
        fs:  `cpe:2.3:a:rack_project:rack:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_customer_relationship_management:9.0`,
        fs:  `cpe:2.3:a:plone:plone:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_human_capital_management:-`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_human_capital_management:8.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_human_capital_management:9.0`,
        fs:  `cpe:2.3:a:cisco:nac_agent:4.8.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_human_capital_management_eperformance:9.2`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_human_capital_management_global_payroll:9.1::~~switzerland~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p140:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_human_capital_management_global_payroll:9.2::~~switzerland~~~`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_human_capital_management_human_resources:9.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_human_capital_management_human_resources:9.2`,
        fs:  `cpe:2.3:a:mvd:surething_cd_labeler:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:-`,
        fs:  `cpe:2.3:a:roxio:drag-to-disc:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8.22`,
        fs:  `cpe:2.3:a:dell:system_e-support_tool:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8.47`,
        fs:  `cpe:2.3:a:inclind:custom_pub:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8.48`,
        fs:  `cpe:2.3:a:horde:imp:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8.49`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8.52`,
        fs:  `cpe:2.3:a:ibm:leads:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8.53`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.325:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8.54`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:8.55`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_peopletools:54`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.4`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.4:bundle15`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.8`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(3b\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.8:bundle10`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8a\)ew1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.9:bundle2`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.22.14`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.47.12`,
        fs:  `cpe:2.3:a:microfocus:rumba:9.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_portal:8.48.08`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_tools:-`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_tools:8.46:ga`,
        fs:  `cpe:2.3:a:vmware:tools:10.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_tools:8.46.12`,
        fs:  `cpe:2.3:a:msteam:sharepoint_birthday_reminder:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_tools:8.47:ga`,
        fs:  `cpe:2.3:a:atutor:atutor:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_enterprise_tools:8.47.04`,
        fs:  `cpe:2.3:a:infoblox:netmri:6.0.2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_products:8.50`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_products:8.51`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_products:8.52`,
        fs:  `cpe:2.3:o:ibm:integrated_management_module_ii_firmware:4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_products:8.53`,
        fs:  `cpe:2.3:a:google:v8:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_products:9.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_products:9.1`,
        fs:  `cpe:2.3:a:teradata:.net_data_provider:13.10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_products:9.2`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_supply_chain_management_eprocurement:9.1`,
        fs:  `cpe:2.3:o:sitecom:wl-153_router_firmware:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_supply_chain_management_eprocurement:9.2`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_supply_chain_management_order_management:9.1`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_supply_chain_management_order_management:9.2`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_371:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_supply_chain_management_purchasing:9.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:peoplesoft_supply_chain_management_purchasing:9.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:pharmaceutical:-`,
        fs:  `cpe:2.3:h:juniper:mag6611_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:pharmaceutical:4.5.0`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:pharmaceutical:4.5.1`,
        fs:  `cpe:2.3:a:webmin:webmin:1.820:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:pharmaceutical:4.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ste:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:power_distribution_unit:-`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_portfolio_management:8.0.8456`,
        fs:  `cpe:2.3:a:xen:xen:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:6.2.1`,
        fs:  `cpe:2.3:a:hp:smart_web_printing:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:6.21.3.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:7.0`,
        fs:  `cpe:2.3:a:citrix:xenclient_xt:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:7.0.1.0`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:8.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:8.0.6`,
        fs:  `cpe:2.3:a:osisoft:pi_interface:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:8.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.48.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:8.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:8.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:primavera_products_suite:8.5`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:rc4:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:project_contracts:12.1.1`,
        fs:  `cpe:2.3:a:codehaus:redback:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:project_contracts:12.1.2`,
        fs:  `cpe:2.3:a:ca:unicenter_web_services_distributed_management:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:project_contracts:12.1.3`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:providers_for_asp.net_help:11.1.620`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:providers_for_asp.net_help:11.1.720`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.10.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:quality:11.5.10.2`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:report_manager:11.5.10.2`,
        fs:  `cpe:2.3:a:zencast:zencast:1.02.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:report_manager:12.1.3`,
        fs:  `cpe:2.3:a:ibm:iss_internet_scanner_software:7.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:report_manager:12.2.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:report_manager:12.2.4`,
        fs:  `cpe:2.3:h:cisco:storage_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:reports:-`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:reports:6.0`,
        fs:  `cpe:2.3:o:breakingpointsystems:breakingpoint_storm_appliance_ctm:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:reports:6.0.8`,
        fs:  `cpe:2.3:a:samba:samba:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:reports:6.0.8.19`,
        fs:  `cpe:2.3:h:selinc:sel-3505:r119-v0-z001001-d20120720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:reports:6i`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:reports:9.0.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:reports:9i`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:reports:10g`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p194:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:12.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:12.0in`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:13.0`,
        fs:  `cpe:2.3:h:enterasys:2e42-27r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:13.1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:13.2`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:13.3`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:13.4`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:14.0`,
        fs:  `cpe:2.3:a:daum_communications:daumgame_activex_control:1.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications:14.1`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:6.1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:3.2.1`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:3.4.2`,
        fs:  `cpe:2.3:h:sensaphone:ims-4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:3.5.0`,
        fs:  `cpe:2.3:a:microsoft:word:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:4.0.1`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.2.074.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:4.5.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:4.8.0`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:5.0.3`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.0:tp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:5.5.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.10sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:6.0.6`,
        fs:  `cpe:2.3:a:emc:networker:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_applications_xstore:6.5.2`,
        fs:  `cpe:2.3:a:winzip:winzip:9.0:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:3.5`,
        fs:  `cpe:2.3:a:hp:digital_sending_software:4.91.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:4.0`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:4.5`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:4.7`,
        fs:  `cpe:2.3:a:hp:photosmart_essential:1.12.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:5.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.09.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:5.1`,
        fs:  `cpe:2.3:o:huawei:s7703_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:5.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:6.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:6.1`,
        fs:  `cpe:2.3:o:asus:rt-n10e_firmware:2.0.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:15.0`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_open_commerce_platform_cloud_service:16.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_order_broker_cloud_service:4.0`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.2:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_order_broker_cloud_service:4.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_order_management_system_cloud_service:3.5`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_order_management_system_cloud_service:4.5`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_1f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_order_management_system_cloud_service:4.7`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_order_management_system_cloud_service:5.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_order_management_system_cloud_service:15.0`,
        fs:  `cpe:2.3:a:novell:groupwise:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:6.0.0`,
        fs:  `cpe:2.3:a:kde:koffice:1.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:6.0.10`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:6.0.11`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:6.5.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:6.5.4`,
        fs:  `cpe:2.3:a:oracle:endeca_server:7.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:6.5.10`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.14:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:6.5.11`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.0.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.0.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.0.2`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1p:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.0.3`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.0.4`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:7.4.6.790:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.0.5`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.0.6`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.1.0`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.1.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.2:*:lombardi:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.1.3`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.1.4`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.1.5`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.10:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:7.1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:13.4`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:14.0`,
        fs:  `cpe:2.3:a:ibm:monitoring_server_\(ms\)_and_shared_libraries_\(ax\):6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:14.1`,
        fs:  `cpe:2.3:a:openstack:compute:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:15.0.0`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.3.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:15.0.1`,
        fs:  `cpe:2.3:a:alstom:e-terracontrol:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:16.0.0`,
        fs:  `cpe:2.3:a:virtools:virtools_3d_life_player:4.0.0.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:16.0.0.1`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:16.0.1`,
        fs:  `cpe:2.3:o:arris:vap2500_firmware:08.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_point-of-service:16.0.2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_service_backbone:14.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_service_backbone:14.1`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_service_backbone:15.0`,
        fs:  `cpe:2.3:a:atmail:atmail:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_xstore_point_of_service:5.0`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:433:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_xstore_point_of_service:5.5`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_xstore_point_of_service:6.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_xstore_point_of_service:6.5`,
        fs:  `cpe:2.3:a:adobe:flex_builder_plug-in:3.0.2.214193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_xstore_point_of_service:7.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:retail_xstore_point_of_service:7.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:right_now_service_cloud:8.2.3.10.1`,
        fs:  `cpe:2.3:a:sybase:replication_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:right_now_service_cloud:8.4.7.2`,
        fs:  `cpe:2.3:a:oracle:outside_in_technology:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_backup:10.1.0.1`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_backup:10.1.0.3`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_backup:10.2.0.2`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_backup:10.3.0.3`,
        fs:  `cpe:2.3:h:cisco:guard_ddos_mitigation_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_enterprise_search:-`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_enterprise_search:10.1.6`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_enterprise_search:10.1.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_enterprise_search:10g`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_global_desktop:4.63`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_global_desktop:4.71`,
        fs:  `cpe:2.3:a:lame_project:lame:3.99.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:secure_global_desktop:5.2`,
        fs:  `cpe:2.3:a:citrix:delivery_services_console_diagnostics:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:self-service_human_resources:11.5.10.2`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:server_manager:-`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.1:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:server_manager:3.1.7.0.0`,
        fs:  `cpe:2.3:a:ivanjaros:feed_block:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:service_bus:12.1.3.0.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:service_bus:12.2.1.0.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:service_bus:12.2.1.1.0`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:service_bus:12.2.1.2.0`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:service_contracts:11.5.10.2`,
        fs:  `cpe:2.3:o:f5:tmos:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:service_contracts:12.1.1`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.1.8.780:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:service_contracts:12.1.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:service_contracts:12.1.3`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_core-common_components:8.1.1`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_core-common_components:8.2.2`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_crm:8.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_crm:8.2.2`,
        fs:  `cpe:2.3:h:cisco:telepresence_mcu_4505:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_e-billing:7.1`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_suite:7.7.2.12`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_suite:7.8.2`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_suite:7.8.2.14`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_suite:8.0.0.10`,
        fs:  `cpe:2.3:a:alfresco:alfresco:5.0.a:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_suite:8.1.1.3`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_ui_framework:8.1.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.31.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:siebel_ui_framework:8.2.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:solaris:-::~~~~sparc~`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.008:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:solaris:10`,
        fs:  `cpe:2.3:a:hp:bastille:b.02.00.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:solaris:11`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5609:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:solaris:11.2`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.21:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:solaris:11.3`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:solaris_cluster:3.3`,
        fs:  `cpe:2.3:a:cmsdevelopment:business_card_web_builder:2.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:solaris_cluster:4.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:solaris_cluster:4.2`,
        fs:  `cpe:2.3:a:canon:mp_navigator_ex:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sparc-opl_service_processor:1121`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sparc_t3-1:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sparc_t3-1b:-`,
        fs:  `cpe:2.3:a:horde:imp:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sparc_t3-2:-`,
        fs:  `cpe:2.3:a:ca:api_gateway:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sparc_t3-3:-`,
        fs:  `cpe:2.3:a:axis:ip_utility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sparc_t3-4:-`,
        fs:  `cpe:2.3:a:python:python:3.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sparc_t4-1:-`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sparc_t4-1b:-`,
        fs:  `cpe:2.3:a:winpcap:winpcap:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sparc_t4-4:-`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sql_trace_analyzer:12.1.10`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.9.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_blade_x6250:-`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.43.p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_blade_x6270:-`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_blade_x6270_m2:-`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.13.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_blade_x6275:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_blade_x6275_m2:-`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_blade_x6440_m2:-`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.0xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_blade_x6450:-`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.3:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x2270:-`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x2270_m2:-`,
        fs:  `cpe:2.3:a:php:php:5.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x4170:-`,
        fs:  `cpe:2.3:a:justsystems:hanako:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x4170_m2:-`,
        fs:  `cpe:2.3:o:huawei:5700hi_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x4270:-`,
        fs:  `cpe:2.3:a:iij:seil\/b1_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x4270_m2:-`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x4275:-`,
        fs:  `cpe:2.3:a:microsoft:ampx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x4470:-`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x4470_m2:-`,
        fs:  `cpe:2.3:a:ibm:informix_extended_parallel_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:oracle:sun_fire_x4540:-`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.2.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_java_system_access_manager_policy_agent:2.2`,
        fs:  `cpe:2.3:a:avaya:ip_soft_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_middleware_products:3.0.1`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_middleware_products:3.1.2`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:1.0`,
        fs:  `cpe:2.3:a:sun:jre:6.0.100:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:2.1.1`,
        fs:  `cpe:2.3:a:actividentity:corestreet_desktop_validation_client:3.1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:3.0.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:3.1`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix_5570_controller_firmware:21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:3.2`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:3.3`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.7.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:3.6.1`,
        fs:  `cpe:2.3:a:goahead:goahead_webserver:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:4.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)e8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:5.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:6.0`,
        fs:  `cpe:2.3:a:digium:asterisk:13.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:6.1`,
        fs:  `cpe:2.3:a:koha:koha:3.16.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:6.2`,
        fs:  `cpe:2.3:a:divx:codec:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:6.3`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:6.3.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:6.9.0`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2014:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:7.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:7.0:2005q4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:7.1`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:8.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:8.1`,
        fs:  `cpe:2.3:a:plone:plone:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite:10.0`,
        fs:  `cpe:2.3:a:flowerfire:sawmill:6.5.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_products_suite_java_system_web_server:6.1`,
        fs:  `cpe:2.3:a:fotoschilenas:recetas_de_tragos:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:sun_products_suite_sysfw:8.2.0.a`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_ray_software:11.1`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:07-00-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_role_manager:4.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_role_manager:5.0`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sun_storage_common_array_manager:6.9.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:sunos:5.11.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:5.2.2`,
        fs:  `cpe:2.3:h:netgear:wgr614:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:5.5.05`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:5.5.06`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.0.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.0.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xq1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.0.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.0.0.4`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.0.0.6.3`,
        fs:  `cpe:2.3:a:roxio:creator_data:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.199:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.0.1.14`,
        fs:  `cpe:2.3:a:plone:plone:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.0.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.1.0`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.1.3`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.2.0`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_8961:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.2.2`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.1.3.0`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.2.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.3.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)ja1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.3.2`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.3.3`,
        fs:  `cpe:2.3:a:firebird:firebird:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.3.4`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)ey:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:6.3.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:7.2.0.3`,
        fs:  `cpe:2.3:a:sun:java_system_calendar_server:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:9.3.0.2`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:9.3.1`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention:7.0.800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:9.3.1.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch_1600m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:9.3.1.2`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:57.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:9.3.2`,
        fs:  `cpe:2.3:h:huawei:s8500:r1632:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:9.3.3`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.08:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:9.3.4`,
        fs:  `cpe:2.3:a:microsoft:report_viewer:2005:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:11.5.10`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:12.0.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30243:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:12.1.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:18.009.20044:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:12.2.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:12.2.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:12.2.2`,
        fs:  `cpe:2.3:a:microsoft:visual_basics:6.0:*:*:*:rt:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite:20.1.1`,
        fs:  `cpe:2.3:a:oracle:service_bus:12.1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite_sql-server:7.3.0`,
        fs:  `cpe:2.3:a:fujitsu:scansnap_manager:v4.2l14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite_sql-server:7.3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite_sql-server:12.2.0`,
        fs:  `cpe:2.3:a:microsoft:icm_color_management_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite_sql-server:12.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite_sql-server:12.2.2`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:supply_chain_products_suite_sql-server:12.2.3`,
        fs:  `cpe:2.3:a:cisco:cloud_network_automation_provisioner:1.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:6.0`,
        fs:  `cpe:2.3:a:alberto_trujillo_gonzalez:protest:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:6.1`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:6.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4500_series_software:4.2\(1.50\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:6.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.94.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:6.4`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:6.5`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:6.6`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:6.7`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:7.0`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:7.1`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:7.2`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:7.3`,
        fs:  `cpe:2.3:a:mesa3d:mesa:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:7.4`,
        fs:  `cpe:2.3:a:intel:network_connections:15.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:8.0`,
        fs:  `cpe:2.3:a:hp:quick_launch_button:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:sysfw:8.0.3:b`,
        fs:  `cpe:2.3:a:citrix:access_management_console_web_interface:5.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:traffic_director:11.1.1.7.0`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:traffic_director:11.1.1.9.0`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:transportation_management:6.1`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:transportation_management:6.2`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:tuxedo:12.1.1.0`,
        fs:  `cpe:2.3:a:cisco:catalyst_5xxx_supervisor_software:2.1.502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:universal_work_queue:11.5.10.2`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:universal_work_queue:12.1.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:universal_work_queue:12.1.2`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:universal_work_queue:12.1.3`,
        fs:  `cpe:2.3:a:fonality:hud_web:1.4.1:*:*:*:*:fonality:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:3.2`,
        fs:  `cpe:2.3:h:siemens:simatic_s7_cpu_1215c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:4.0`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:4.1`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:4.6`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:4.7`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:4.63`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:4.71`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpq3925:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:5.0`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:5.1`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization:5.2`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.60.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization_secure_global_desktop:4.63`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization_secure_global_desktop:4.71`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.404:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization_secure_global_desktop:5.0`,
        fs:  `cpe:2.3:a:apache:poi:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:virtualization_secure_global_desktop:5.10`,
        fs:  `cpe:2.3:a:diychatroom:diychatroom:3.4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:vm_server:3.1::~~~~sparc~`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:oracle:vm_server:3.2::~~~~sparc~`,
        fs:  `cpe:2.3:h:hp:proliant_ml150_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_server:3.3`,
        fs:  `cpe:2.3:a:zcms_project:zcms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:1.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:1.6.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:1.6.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:1.6.4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:1.6.6`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.65:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)sz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.0.4`,
        fs:  `cpe:2.3:a:samba:samba:2.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.0.6`,
        fs:  `cpe:2.3:a:ibm:connections:1.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.0.8`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.0.10`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_cisco:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.0.12`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.1`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.1.0`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.65:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.1.2`,
        fs:  `cpe:2.3:a:spice_project:spice:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.1.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.334:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.2`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:5.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.2.2`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.51:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:2.2.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0`,
        fs:  `cpe:2.3:a:iconics:bizviz:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0.0`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_microsoft_exchange_server:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0.2`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction_identity_service_for_ldap:2.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0.4`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0.6`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.65:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0.8`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0.10`,
        fs:  `cpe:2.3:a:innominate:mguard_smart:hw-101050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0.12`,
        fs:  `cpe:2.3:a:ibm:security_appscan:6.0.1.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.0.14`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.1`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.1.0`,
        fs:  `cpe:2.3:a:microsoft:report_viewer:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.1.2`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.1.4`,
        fs:  `cpe:2.3:a:digia:qt:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.1.6`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.1.8`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2`,
        fs:  `cpe:2.3:a:gnu:enscript:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.0`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.2`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_java_sdk:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.4`,
        fs:  `cpe:2.3:a:daumcorp:daum_cloud:1.6.18:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.6`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.8`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.10`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.12`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system:7.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.14`,
        fs:  `cpe:2.3:a:wolfcms:wolf_cms:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.16`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.18`,
        fs:  `cpe:2.3:a:apple:quicktime:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.20`,
        fs:  `cpe:2.3:o:fedoraproject:fedora_core:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.22`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:3.2.24`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.424.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0`,
        fs:  `cpe:2.3:a:sap:netweaver:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.0`,
        fs:  `cpe:2.3:a:djangoproject:django:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.06:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.4`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.6`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.8`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.10`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.12`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.14`,
        fs:  `cpe:2.3:h:supermicro:x9dbu-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.16`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.18`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.20`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.22`,
        fs:  `cpe:2.3:a:apache:hive:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.24`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p85:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.26`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.31`,
        fs:  `cpe:2.3:a:rapid7:nexpose:6.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.34`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.0.36`,
        fs:  `cpe:2.3:a:sunil_nanda:blue_wrench_video_widget:1.0.5:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.0`,
        fs:  `cpe:2.3:a:gnome:libsocialweb:0.25.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.2`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.4`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.6`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.8`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:7.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.10`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.12`,
        fs:  `cpe:2.3:a:mcafee:rogue_system_detection_server:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.14`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.16`,
        fs:  `cpe:2.3:a:ca:brightstor_san_manager:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.18`,
        fs:  `cpe:2.3:a:cisco:webex_meeting_center_for_firefox_or_chrome:8.29.3000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.20`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.22`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.24`,
        fs:  `cpe:2.3:a:ontariosystems:artiva_workstation:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.26`,
        fs:  `cpe:2.3:a:shopware:shopware:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.28`,
        fs:  `cpe:2.3:o:cisco:staros:16.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.30`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.32`,
        fs:  `cpe:2.3:a:oracle:reports:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.34`,
        fs:  `cpe:2.3:a:globeranger:dod_passive_rfid_solution_event_notification:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.39`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1064.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.42`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.1.44`,
        fs:  `cpe:2.3:a:david_king:vino:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.0`,
        fs:  `cpe:2.3:a:hotlingo:hotlingo:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.2`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.6`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.05\/31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.8`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.10`,
        fs:  `cpe:2.3:a:rack_project:rack:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.12`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.14`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.16`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.18`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.968:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.20`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.22`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.24`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.4:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.26`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-02-\/e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.31`,
        fs:  `cpe:2.3:o:moxa:oncell_gateway_firmware:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.34`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.2.36`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp3:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.2`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.4`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3100-26c-si_ls-s3100-26c-si-dc-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.6`,
        fs:  `cpe:2.3:a:peoplepc:peoplepal:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.8`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.12`,
        fs:  `cpe:2.3:h:fortinet:fortigate-600c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.14`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.18`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.29`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.13:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.34`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.35`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.05.550:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:4.3.36`,
        fs:  `cpe:2.3:a:sgi:mipspro_compilers:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.10`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.12`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.13`,
        fs:  `cpe:2.3:a:cherokee-project:cherokee:1.2.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.14`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.16`,
        fs:  `cpe:2.3:a:autodesk:inventor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.18`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(1\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.20`,
        fs:  `cpe:2.3:a:tivoli_storage_productivity_center:5.1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.24`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.26`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.32`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.0.36`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.1.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.1.2`,
        fs:  `cpe:2.3:a:justsystems:shuriken:2010:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.1.4`,
        fs:  `cpe:2.3:a:b-e-soft:artweaver_free:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.1.6`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:5.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.1.8`,
        fs:  `cpe:2.3:a:suse:studio_onsite:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.1.10`,
        fs:  `cpe:2.3:a:macromedia:shockwave_flash:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.1.14`,
        fs:  `cpe:2.3:a:tm_software:tempo:7.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:vm_virtualbox:5.1.18`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.2:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:warehouse_builder:10.2.0.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-09-30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:warehouse_builder:10.2.0.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:warehouse_builder:10.2.0.5`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:warehouse_builder:11.1.0.6.0`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:warehouse_builder:11.2.0.1.0`,
        fs:  `cpe:2.3:a:websense:triton_web_security_gateway_anywhere:7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:web_cache:11.1.1.7.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:web_cache:11.1.1.9.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:web_listener:-`,
        fs:  `cpe:2.3:a:tobias_bathge:wp-table_reloaded:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_analytics:10.3.0.0`,
        fs:  `cpe:2.3:a:tuleap:tuleap:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_content:11.1.1.7`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_content:11.1.1.9`,
        fs:  `cpe:2.3:a:henner_zeller:henplus:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_content:12.2.1.0`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_content:12.2.1.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_content:12.2.1.2`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.02:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_interaction:10.3.0.0`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:5.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_interaction_identity_service_for_ldap:10.3.0.0`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_sites:7.6.2`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_sites:11.1.1.8.0`,
        fs:  `cpe:2.3:h:foundrynet:edgeiron_eif48g_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:webcenter_sites:12.2.1`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:8.0`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:8.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:8.1:sp1`,
        fs:  `cpe:2.3:a:curitel:pc_card_software:2.0.8.406:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:8.1:sp2`,
        fs:  `cpe:2.3:a:sympa:sympa:3.1b.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:8.1:sp3`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:8.1:sp4`,
        fs:  `cpe:2.3:a:augeas:augeas:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:8.1:sp5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.477:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:9.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:9.2:ga`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:10.3`,
        fs:  `cpe:2.3:a:php:php:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:10.3.2`,
        fs:  `cpe:2.3:h:3com:tippingpoint_600e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_portal:10.3.6`,
        fs:  `cpe:2.3:a:adobe:dreamweaver:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:9.0.0.0.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:9.1.0.0.0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:9.2.0.0.0`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.11.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.0.0.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.1.0.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.2`,
        fs:  `cpe:2.3:a:newisys:service_processor_software_components:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.2.0.0`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_server:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.3`,
        fs:  `cpe:2.3:a:php-fusion:freshlinks_module:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.3.0.0`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.0.1490:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.6`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(1\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.6.0`,
        fs:  `cpe:2.3:a:e107:e107:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:10.3.6.0.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.1.2`,
        fs:  `cpe:2.3:a:mysql:mysql_community_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.1.2.0`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.1.2.0.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.95.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.1.3.0`,
        fs:  `cpe:2.3:a:docker:docker:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.1.3.0.0`,
        fs:  `cpe:2.3:a:avatar_uploader_project:avatar_uploader:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.2.1`,
        fs:  `cpe:2.3:a:exim:exim:4.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.2.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.2.1.0.0`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.2.1.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.2.1.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.2.1.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.2.1.2.0`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_server:12.2.1.3.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:weblogic_workshop:8.1:sp5`,
        fs:  `cpe:2.3:h:huawei:s3300:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:workflow:-`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:workflow:11.5.1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:workflow:11.5.9.5`,
        fs:  `cpe:2.3:a:david_king:vino:2.7.4.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:workspace_manager:-`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:workspace_manager:11.2.0.4`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:xml_developers_kit:11.2.0.4`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:xml_developers_kit:12.1.0.1`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:xml_developers_kit:12.1.0.2`,
        fs:  `cpe:2.3:a:isc:bind:8.2.2:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:xml_publisher_reporting_tools_for_word:5.7.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:7.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:xvm_virtualbox:-`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0588:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oracle:xvm_virtualbox:3.0.4`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.41.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.1`,
        fs:  `cpe:2.3:a:parallels:h-sphere:3.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.1:alpha4`,
        fs:  `cpe:2.3:a:bandh:b\&amp;h_photo_video_pro_audio:2.5.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.2.0.2`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.2.0.3`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.2.1`,
        fs:  `cpe:2.3:a:emc:avamar:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.2.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.2.2.1`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:1.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.2.2.2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.3`,
        fs:  `cpe:2.3:a:oracle:opensso:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.3:alpha14`,
        fs:  `cpe:2.3:a:novell:suse_lifecycle_management_server:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.3.0`,
        fs:  `cpe:2.3:h:y-cam:yck003:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.4`,
        fs:  `cpe:2.3:o:cisco:ios:15.0xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.4.0`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.4.1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.4.2`,
        fs:  `cpe:2.3:a:commvault:windows_file_system_idataagent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.5`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.5.0`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.0`,
        fs:  `cpe:2.3:h:huawei:s5720hi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p472:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_4503:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.2`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.6`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.7`,
        fs:  `cpe:2.3:a:keepass:keepass:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.8`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.8.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.9`,
        fs:  `cpe:2.3:a:altiris:endpoint_security_solution_documentation:6.0.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.10`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1\(.1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.11`,
        fs:  `cpe:2.3:a:cognos:planning_client_framework:8.4.6025.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.11.2`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.11.3`,
        fs:  `cpe:2.3:a:tincan:phplist:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.12`,
        fs:  `cpe:2.3:a:spip:spip:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.6.12.1`,
        fs:  `cpe:2.3:a:apache:subversion:0.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.7`,
        fs:  `cpe:2.3:a:ssh:daemon:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:2.7.1:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangehrm:orangehrm:3.1.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orangelampsoftware:killprocess:2.44`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orbitscripts:orbit_open_ad_server:1.1.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orbitscripts:orbit_open_ad_server:1.1.1`,
        fs:  `cpe:2.3:a:trend_micro:interscan_web_security_suite:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orcacle:retail_point-of-service:13.4`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.11.2:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orcacle:retail_point-of-service:14.0`,
        fs:  `cpe:2.3:a:hp:destinations:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orcacle:retail_point-of-service:14.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orcacle:webcenter_sites:7.6.2`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orcacle:webcenter_sites:11.1.1.8.0`,
        fs:  `cpe:2.3:a:tdah:t-day_webmail:3.2.0-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:0.1`,
        fs:  `cpe:2.3:a:microsoft:ie:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:0.5`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:0.8`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:0.9`,
        fs:  `cpe:2.3:a:nsoftware:unitronics_uniopc:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.0`,
        fs:  `cpe:2.3:a:netfilter:libmnl:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.0.20`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.1`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.1.30`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.2`,
        fs:  `cpe:2.3:a:xnview:xnview:1.90.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.2.41`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.3`,
        fs:  `cpe:2.3:a:roxio:toast:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.3.9`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.3.10`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.4`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.5`,
        fs:  `cpe:2.3:a:mcafee:cloud_identity_manager:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.5.1`,
        fs:  `cpe:2.3:h:enterasys:roamabout_ap2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.6`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.7.3`,
        fs:  `cpe:2.3:a:hp:openview_storage_data_protector:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.8`,
        fs:  `cpe:2.3:a:digium:asterisk:12.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.8.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.8.2`,
        fs:  `cpe:2.3:o:tp-link:tl-wr841n_\(10.0\)_firmware:150104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.9`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.41`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orchardproject:orchard:1.42`,
        fs:  `cpe:2.3:a:dolphin-browser:dolphin_browser_hd:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orderingapps:buckhorn_grill:2.8::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.8:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orderingapps:sweatshop:2.96::~~~android~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.1.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:rsa:bsafe_crypto-c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:beta4:~~~drupal~~`,
        fs:  `cpe:2.3:a:miway:miway_insurance_ltd:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:rc3:~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:database_server_lite:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.0:rc4:~~~drupal~~`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:5900:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.11.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:oxwall:oxwall:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organic_groups_project:organic_groups:7.x-2.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:kde:kde-workspace:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organizer_project:organizer:0.4b::~~~wordpress~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organizer_project:organizer:0.5b::~~~wordpress~~`,
        fs:  `cpe:2.3:a:acidcat:acidcat_cms:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organizer_project:organizer:0.6.1b::~~~wordpress~~`,
        fs:  `cpe:2.3:a:augeas:augeas:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organizer_project:organizer:1.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:freebsd:freebsd:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organizer_project:organizer:1.0b::~~~wordpress~~`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organizer_project:organizer:1.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organizer_project:organizer:1.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:lxml:lxml:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:organizer_project:organizer:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orientdb:orientdb:2.0.14::~~community~~~`,
        fs:  `cpe:2.3:a:boost:boost:1.33.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:orientdb:orientdb:2.1.0::~~community~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osclass:osclass:3.4.2`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscmax:oscmax:2.5.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:online_merchant:2.3.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:192:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:online_merchant:2.3.1`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:online_merchant:2.3.2`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:online_merchant:2.3.3`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:online_merchant:2.3.3.4`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:1.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:1.5.1`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.25:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:1.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:1.12`,
        fs:  `cpe:2.3:h:hp:digital_sender_8100c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:1.13`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.1`,
        fs:  `cpe:2.3:a:ipswitch:moveit_mobile:1.2.0.962:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2:rc_2a`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2_cvs`,
        fs:  `cpe:2.3:a:sagecrm:sagecrm:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2_ms1`,
        fs:  `cpe:2.3:a:microsoft:office_proofing_tools:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2_ms2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2_ms2_2006-08-17`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2_ms3`,
        fs:  `cpe:2.3:a:scriptlogic:secure_copy:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r1`,
        fs:  `cpe:2.3:a:bib2html_project:bib2html:0.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r2`,
        fs:  `cpe:2.3:a:cisco:ip_contact_center_hosted:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r3`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r4`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r5`,
        fs:  `cpe:2.3:a:intel:active_management_technology_setup_and_configuration_service:3.0.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r6a`,
        fs:  `cpe:2.3:a:objectraku:raku_symbol_server:3.0.2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r8`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.1.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:2.2ms1j-r9`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:3.0.2`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.18:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:3.0a3`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oscommerce:oscommerce:3.0a5`,
        fs:  `cpe:2.3:o:ge:multilink_ml800_firmware:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osehra:vista:-`,
        fs:  `cpe:2.3:a:mitsubishicars:mitsubishi_road_assist:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:osinet:classified_ads:6.x-3.1:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osinet:classified_ads:7.x-3.1:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:0.2`,
        fs:  `cpe:2.3:a:infusionsoft_project:infusionsoft:1.5.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.0`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.1.2`,
        fs:  `cpe:2.3:a:persits:aspupload:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.2`,
        fs:  `cpe:2.3:a:apple:safari:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.3`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.0.1927:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.4`,
        fs:  `cpe:2.3:a:schneider-electric:opc_factory_server:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.5`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.5.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p183:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.5.2`,
        fs:  `cpe:2.3:a:docker:docker:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.6.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.6.3`,
        fs:  `cpe:2.3:a:citrix:metaframe_password_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.6.4`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.6.5`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.7`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:1.7.1`,
        fs:  `cpe:2.3:a:sabreairlinesolutions:crew_planning:2010.2.12.20008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.0`,
        fs:  `cpe:2.3:a:juniper:networks_mobility_system_software:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.2`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.903:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.3`,
        fs:  `cpe:2.3:o:cisco:voip_phone_cp-7910:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.3.1`,
        fs:  `cpe:2.3:a:sendcard:sendcard:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.4`,
        fs:  `cpe:2.3:a:redhat:cloudforms_cloud_engine:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.5`,
        fs:  `cpe:2.3:a:ricardo_villalba:smplayer:0.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:2.7.5`,
        fs:  `cpe:2.3:a:tibco:enterprise_administrator:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.0`,
        fs:  `cpe:2.3:a:citrix:presentation_server_presentation_server_reports:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.1`,
        fs:  `cpe:2.3:a:tag1consulting:support_timer:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.2.1`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.3`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.5`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.6`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.7.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.8.1`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:3.9.4`,
        fs:  `cpe:2.3:a:xymon:xymon:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:4.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:4.1.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:5.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:5.5.2`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cpie:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:5.6`,
        fs:  `cpe:2.3:a:roxio:creator:5.0.0:*:*:*:starter:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:5.7`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix:5.8`,
        fs:  `cpe:2.3:a:python:python:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osirix-viewer:osirix_md:2.7`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_interface:1.0.1.3`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:7.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_interface:1.0.2.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_interface:1.0.3.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_interface:1.0.4.88`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpw941:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_interface:1.0.5.101`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_interface:3.1.2`,
        fs:  `cpe:2.3:a:schneems:wicked:0.6.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_interface:3.1.2.54`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_opc_da_interface:2.3.16.16`,
        fs:  `cpe:2.3:a:apache:solr:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_opc_da_interface:2.3.17.18`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osisoft:pi_opc_da_interface:2.3.20.9`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oskarshamnsliv_project:oskarshamnsliv:6::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ossec:ossec:2.8.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ostenta:yawpp:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:wget:1.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ostenta:yawpp:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ostenta:yawpp:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ostenta:yawpp:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.756.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.2.7`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.3.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.6:rc1`,
        fs:  `cpe:2.3:a:pantech:uml290:1.5.26.1201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.6:rc2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.1.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.6:rc3`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.6:rc4`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.06b43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.6:rc5`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.6.0`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.0`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.0:rc1`,
        fs:  `cpe:2.3:a:hp:storeonce_4210_iscsi_backup_system:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.0:rc2`,
        fs:  `cpe:2.3:a:libav:libav:0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.0.1`,
        fs:  `cpe:2.3:h:d-link:di-524up:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.0.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.8:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.0.3`,
        fs:  `cpe:2.3:a:rim:blackberry_desktop_software:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.0.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.1`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:10.00.tc4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.1:developer_preview`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.1.2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.1:rc1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.1.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.22:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.1.2`,
        fs:  `cpe:2.3:h:xerox:workcentre_5655:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.8.4`,
        fs:  `cpe:2.3:o:bluecoat:sgos:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.9.0`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.9.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.9.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.9.4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:osticket:osticket:1.9.5`,
        fs:  `cpe:2.3:a:jquery:jquery_ui:1.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:0.1`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:0.2`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:0.3`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:11:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:0.4`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:0.5`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:0.6`,
        fs:  `cpe:2.3:a:postfix:postfix:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:0.7`,
        fs:  `cpe:2.3:a:google:chrome:4.0.245.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:0.8`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg9000-20:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:1.0.0`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:1.0.1`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:epj:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:1.0.2`,
        fs:  `cpe:2.3:a:techsmith:snagit:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:1.0.3`,
        fs:  `cpe:2.3:h:hp:procurve_router:jc148a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:1.0.4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:1.0.5`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:1.0.6`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oswald_buddenhagen:isync:1.1.0`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.0.2`,
        fs:  `cpe:2.3:a:gnu:grep:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.0.3`,
        fs:  `cpe:2.3:a:commvault:sql_server_idataagent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.0.4`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.7:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.0.5`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.2.2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.0.6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.0.7`,
        fs:  `cpe:2.3:a:sendmail:managed_mta:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.0.8`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:5400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.1.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.1.2`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.1.3`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_91:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.1.4`,
        fs:  `cpe:2.3:a:emulex:hbanyware:4.00a32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.2.0`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.2.1`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.2.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.2.3`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.3.0`,
        fs:  `cpe:2.3:a:netscout:ngenius_client:4.9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.3.1`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.3.2`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.3.3`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_9951_firmware:9.4\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:2.3.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:4.0.0`,
        fs:  `cpe:2.3:a:ibm:qradar_vulnerability_manager:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:4.0.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:4.0.2`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:4.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:5.0.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:5.0.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:5.0.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.30:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:faq:5.0.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:0.5:beta1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd355a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:0.5:beta2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:0.5:beta3`,
        fs:  `cpe:2.3:a:john_nunemaker:crack:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:0.5:beta4`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:0.5:beta5`,
        fs:  `cpe:2.3:a:blair_williams:pretty_link_lite:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:0.5:beta6`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:0.5:beta7`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:0.5:beta8`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.0:rc1`,
        fs:  `cpe:2.3:a:rpm:rpm:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.0:rc2`,
        fs:  `cpe:2.3:a:cybozu:office:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.0:rc3`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.0.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.0.1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool_application_service_monitors:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.1:rc1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.1.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:3.5.3e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.1.0:rc2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.1.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.1.2`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.1.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.1.4`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.2.0:beta1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:12.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.2.0:beta2`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.2.0:beta3`,
        fs:  `cpe:2.3:a:vmware:view:4.0.0:u2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.2.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.2.2`,
        fs:  `cpe:2.3:a:hp:ldap-ux_integration:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.2.3`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.2.4`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.3.0:beta1`,
        fs:  `cpe:2.3:a:verity:k2_dashboard:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.3.0:beta2`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.3.0:beta3`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.3.0:beta4`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:gold:advanced_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.3.1`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_xgs_firmware:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.3.2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:1.3.3`,
        fs:  `cpe:2.3:a:exsoul-browser:exsoul_web_browser:3.3.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.0:beta1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.0:beta2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.0:rc.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.0:beta4`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.0:beta5`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.0:beta6`,
        fs:  `cpe:2.3:h:hp:storevirtual_4130:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.2`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer_with_flow_analytics_module:9.5.0:-:pay:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.3`,
        fs:  `cpe:2.3:a:schneider-electric:vijeo_citect:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.4`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.93.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.0.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p236_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.0:beta1`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.0:beta2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p211:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.1`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:6.29.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.2`,
        fs:  `cpe:2.3:o:cisco:catos:6.4\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.4`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.6`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.7`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.11.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.1.9`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.0:beta1`,
        fs:  `cpe:2.3:o:cisco:vpn_5000_concentrator_series_software:6.0.21.0001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.0:beta2`,
        fs:  `cpe:2.3:a:digium:asterisk:13.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.0:beta3`,
        fs:  `cpe:2.3:o:ibm:i5os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.0:beta4`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.0:rc1`,
        fs:  `cpe:2.3:a:mumble:mumble:1.2.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.1`,
        fs:  `cpe:2.3:a:php.s3.to:tree_bbs:2003\/06\/17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.2`,
        fs:  `cpe:2.3:a:be-graph:bezip:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.3`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.4`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.5`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.6`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.7`,
        fs:  `cpe:2.3:o:cisco:staros:19.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.8`,
        fs:  `cpe:2.3:a:doug_poulin:ommand_school_student_management_system:1.06.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.2.9`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.0:beta1`,
        fs:  `cpe:2.3:a:merethis:centreon:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.0:beta2`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.0:beta3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.0:beta4`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.0:rc1`,
        fs:  `cpe:2.3:a:mcafee:epo_deep_command:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.2`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.90.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.3`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:13.0.0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.4`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.5`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.3.6`,
        fs:  `cpe:2.3:h:hp:0235a320:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.0:beta1`,
        fs:  `cpe:2.3:a:google:v8:3.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.0:beta2`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.10b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.0:beta3`,
        fs:  `cpe:2.3:a:certificationkits:ip_subnet_calculator:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.0:beta4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.0:beta5`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.0:beta6`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.2`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.11:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.4`,
        fs:  `cpe:2.3:a:google:chrome:17.0.948.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.5`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.6`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0566:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.7`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.8`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.9`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.10`,
        fs:  `cpe:2.3:a:frontrange:goldmine:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.11`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.12`,
        fs:  `cpe:2.3:a:teamquest:it_service_analyzer\/reporter:10.2.533:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.13`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.14`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:2.4.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zh3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.0:beta1`,
        fs:  `cpe:2.3:o:juniper:junos:14.2:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.0:beta2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.0:beta3`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.51:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.0:beta4`,
        fs:  `cpe:2.3:a:digium:asterisk:11.13.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.0:beta5`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.0:beta6`,
        fs:  `cpe:2.3:o:netapp:data_ontap:8.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.0:beta7`,
        fs:  `cpe:2.3:a:epson:event_manager:2.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.1`,
        fs:  `cpe:2.3:a:bea:weblogic_platform:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.2`,
        fs:  `cpe:2.3:a:scilab:scilab:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.3`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.5`,
        fs:  `cpe:2.3:h:hospira:lifecare_pca3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.7`,
        fs:  `cpe:2.3:a:ultraseek:ultraseek:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.8`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.11-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.10`,
        fs:  `cpe:2.3:a:polycom:rmx_system_software:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.12`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.13`,
        fs:  `cpe:2.3:a:wp-business_directory_project:wp-business_directory:1.0.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.14`,
        fs:  `cpe:2.3:a:tim_robbins:libmagic:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.15`,
        fs:  `cpe:2.3:a:adobe:flash_player:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.16`,
        fs:  `cpe:2.3:a:rpm:rpm:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.0.17`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.2`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.15:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.4`,
        fs:  `cpe:2.3:a:rpm:rpm:4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.5`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.6`,
        fs:  `cpe:2.3:a:pass4sure:pass4sure_for_isaca_cism:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.7`,
        fs:  `cpe:2.3:a:teradata:administrator:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.8`,
        fs:  `cpe:2.3:o:ibm:global_console_manager_32_firmware:1.20.0.23447:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.9`,
        fs:  `cpe:2.3:a:ibm:websphere_eclipse_platform:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.10`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.11`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.13`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.14`,
        fs:  `cpe:2.3:a:cisco:finesse:10.5\(1\)_su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.15`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.1.00028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.16`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.17`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-35-\/f:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.18`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.26.2:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.19`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.20`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.1.21`,
        fs:  `cpe:2.3:a:oracle:application_management_pack:12.2:*:*:*:*:e-business_suite:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.0`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1516-3_pn\/dp_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.0:beta1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:6.7:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.0:beta2`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.0:beta3`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:0.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.0:beta4`,
        fs:  `cpe:2.3:o:apple:a_ux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.0:beta5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.0:rc1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.1`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:8.5.6-113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.2`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)s14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.4`,
        fs:  `cpe:2.3:h:silex:sx-2000wg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.5`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.6`,
        fs:  `cpe:2.3:o:netgear:r6700_firmware:1.0.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.7`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.8`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.9`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.10`,
        fs:  `cpe:2.3:a:feeds_project:feeds:7.x-2.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.11`,
        fs:  `cpe:2.3:a:cisco:agent_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.12`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.13`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_optimization_engine:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.14`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:3.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.15`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.2.16`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.0`,
        fs:  `cpe:2.3:a:xnview:xnview:1.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.0:beta1`,
        fs:  `cpe:2.3:a:atlassian:jira:2.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.0:beta2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.0:beta3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.0:beta4`,
        fs:  `cpe:2.3:o:compaq:tru64:4.0g_pk3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.0:beta5`,
        fs:  `cpe:2.3:a:ibm:packaging_utility:1.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.0:rc1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.4`,
        fs:  `cpe:2.3:a:gnu:coreutils:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.5`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs:3.3.6`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.1`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.2`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.3`,
        fs:  `cpe:2.3:a:digia:qt:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:12.0.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.5`,
        fs:  `cpe:2.3:a:pgp:desktop_for_mac:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.6`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1061:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.7`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.8`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.9`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.10`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.11`,
        fs:  `cpe:2.3:a:websitepanel:websitepanel:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.12`,
        fs:  `cpe:2.3:a:google:chrome:11.0.658.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.13`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.14`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.15`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.2.16`,
        fs:  `cpe:2.3:h:hp:jetdirect_680n_eio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.0`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:10.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.3`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.4`,
        fs:  `cpe:2.3:a:busybox:busybox:1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.5`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:6.0:u1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.6`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.7`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.9`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:3.3.10`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:4.0.0`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:10.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:4.0.1`,
        fs:  `cpe:2.3:a:plex:plex_media_server:0.9.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_help_desk:4.0.2`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:2.1.0`,
        fs:  `cpe:2.3:a:mono-project:libgdiplus:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:2.1.1`,
        fs:  `cpe:2.3:a:themepunch:slider_revolution:4.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:2.1.2`,
        fs:  `cpe:2.3:o:cisco:catos:5.1\(1a\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:2.1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:2.1.4`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:2.1.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.0.0`,
        fs:  `cpe:2.3:a:solarwinds:toolset:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.0.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.0.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.0.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.0.4`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:3.0.11171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.0.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.0.6`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.1.0`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.1.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.1.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.1.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.1.4`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.1.5`,
        fs:  `cpe:2.3:a:avaya:ip_soft_phone:5.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:otrs:otrs_itsm:3.1.6`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ourtoolbar:productivity_toolbar:3.1`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:overdrive:overdrive_media_console:2.1.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.0.0_0001`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.1.0`,
        fs:  `cpe:2.3:a:hp:openview_performance_extended_capability_technology:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.2.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.2.0-4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.2.1`,
        fs:  `cpe:2.3:a:newsignature:addressfield_tokens:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.2.1-1`,
        fs:  `cpe:2.3:a:openstack:swift:1.3.0:gamma1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.2.2`,
        fs:  `cpe:2.3:a:oracle:industry_applications:13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3:beta1`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3:rc1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3:rc2`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.0`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:6.0.132.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.0.1`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.1`,
        fs:  `cpe:2.3:a:dlink:dwl-3200ap_firmware:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.1:beta1`,
        fs:  `cpe:2.3:a:apache:camel:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.1:rc1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.2:beta1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.2:rc`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.2:rc1`,
        fs:  `cpe:2.3:a:hp:creativeprojects:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.3`,
        fs:  `cpe:2.3:a:genixcms:genixcms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.3:beta1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.3:rc1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.4`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.4:beta1`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.4:rc1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.5`,
        fs:  `cpe:2.3:a:xfree86:xfree86:3.3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.3.5:rc1`,
        fs:  `cpe:2.3:a:adobe:shockwave:8.5.1.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.0`,
        fs:  `cpe:2.3:a:compaq:intelligent_cluster_administrator:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.0:beta1`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.0:beta2`,
        fs:  `cpe:2.3:h:nortel:ssl_vpn_module_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.0:beta3`,
        fs:  `cpe:2.3:h:ceragon:fiberair_ip-10g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.0:rc`,
        fs:  `cpe:2.3:a:buffalotech:wer-ag54_firmware:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.0:rc1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.0:rc2`,
        fs:  `cpe:2.3:a:ca:license_software:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.0:rc3`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.0.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10\)ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.1:rc1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.2`,
        fs:  `cpe:2.3:a:datadynamics:activereports:2.5.0.1314:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.2:rc1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.3`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.3:rc1`,
        fs:  `cpe:2.3:o:kddi:home_spot_cube_firmware:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.4`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.4.4:rc1`,
        fs:  `cpe:2.3:a:intel:server_configuration_wizard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:alpha1`,
        fs:  `cpe:2.3:h:hp:laserjet_9050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:alpha1.1`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:alpha2`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:beta1`,
        fs:  `cpe:2.3:a:augeas:augeas:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:beta2`,
        fs:  `cpe:2.3:a:id:id-software:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:rc1`,
        fs:  `cpe:2.3:a:mozilla:firefox:28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:rc1.1`,
        fs:  `cpe:2.3:h:cisco:ons_15600_sdh_multiservice_provisioning_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:rc2`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:rc3`,
        fs:  `cpe:2.3:a:docker:docker:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:rc3.1`,
        fs:  `cpe:2.3:a:adobe:formflow_filler:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0:rc4`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.0.1:rc5`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.1`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:10.00.00.4019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.1:rc1`,
        fs:  `cpe:2.3:a:debian:qpopper:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.1.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.345:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.2:rc1`,
        fs:  `cpe:2.3:a:quagga:quagga:0.97.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.2:rc2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1012.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.2:rc3`,
        fs:  `cpe:2.3:a:all_video_gallery_plugin_project:all_video_gallery_plugin:1.2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.2:rc4`,
        fs:  `cpe:2.3:a:oracle:endeca_server:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.2.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.3:rc1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.764.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.3.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.4`,
        fs:  `cpe:2.3:a:snort:snort:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.4.1`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.4.2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.5`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.6.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.6.2`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.7`,
        fs:  `cpe:2.3:a:blogengine:e2:2.4:2845:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.7.1`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.5.8`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:alpha1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:alpha1.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_import_export_manager:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:alpha1.2`,
        fs:  `cpe:2.3:a:gnu:emacs:21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:alpha2`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:alpha3`,
        fs:  `cpe:2.3:a:apache:openjpa:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:beta1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:beta1.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:beta2`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:beta3`,
        fs:  `cpe:2.3:a:nttdata:terasoluna_server_framework_for_java_web:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:beta4`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:beta5`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:beta6`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:beta7`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_server:7.2.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:qa1`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:qa2`,
        fs:  `cpe:2.3:a:git-scm:git:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:qa3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0:qa4`,
        fs:  `cpe:2.3:a:corel:paintshop_pro_x5:16.0.0.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0-1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0.1`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0.1-2`,
        fs:  `cpe:2.3:a:oracle:apex:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0.2`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.0.3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.1`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.1.1`,
        fs:  `cpe:2.3:a:openstack:keystone:2014.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.1.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.1.3`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.2`,
        fs:  `cpe:2.3:a:apple:bonjour:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.2.2`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/r_firmware:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.2.3`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.2.4`,
        fs:  `cpe:2.3:h:seil:x1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.2.5`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1021.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.2.6`,
        fs:  `cpe:2.3:a:google:chrome:12.0.708.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.529:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.3.2`,
        fs:  `cpe:2.3:a:piwik:piwik:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.3.3`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.3.4`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.4`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.4.1`,
        fs:  `cpe:2.3:a:checkpoint:check_point_integrity_client:5.1.556.166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.5`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.5.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.5.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.5.3`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.6`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.6.1`,
        fs:  `cpe:2.3:a:faq-frequenty_asked_questions_project:faq-frequently_asked_questions:1.2.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.6.2`,
        fs:  `cpe:2.3:a:redhat:openshift:2.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.7`,
        fs:  `cpe:2.3:a:samba:samba:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.7.1`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.7.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.7.3`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.7.4`,
        fs:  `cpe:2.3:a:ibm:db2:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.7.5`,
        fs:  `cpe:2.3:a:sendmail:advanced_message_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.8`,
        fs:  `cpe:2.3:h:cisco:887va-w_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.8.1`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.9`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.582:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.9.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.9.2`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.10`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.10.1`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.10.2`,
        fs:  `cpe:2.3:a:hitachi:replication_manager:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.11`,
        fs:  `cpe:2.3:a:google:chrome:6.0.484.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.11.1`,
        fs:  `cpe:2.3:a:opnet:license_server:16.0.0.10215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.11.2`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.11.3`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.12`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:3.6.12.1`,
        fs:  `cpe:2.3:a:bastian_kleineidam:linkchecker:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4-0.7.2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0`,
        fs:  `cpe:2.3:a:google:update_helper:1.3.21.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0:alpha1`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0:beta1`,
        fs:  `cpe:2.3:a:mysql:mysql_workbench:5.0.30:*:*:*:oss:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0.1`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0.2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0.3`,
        fs:  `cpe:2.3:a:apple:safari:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0.4`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0.5`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.0.6`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.1`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.19.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.1.1`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.2.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.2.2`,
        fs:  `cpe:2.3:a:ibm:netfinity_remote_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.2.3`,
        fs:  `cpe:2.3:h:rockwellautomation:1768-eweb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.2.4`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.2.5`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.66.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.2.6`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.2.7`,
        fs:  `cpe:2.3:a:citrix:xenapp_server_configuration_tool:1.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.4`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(1\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.4.1`,
        fs:  `cpe:2.3:a:rsa:cleartrust_servers:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.4.2`,
        fs:  `cpe:2.3:h:intel:express_550t:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.4.3`,
        fs:  `cpe:2.3:a:cdotech:cdo_dal_components:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.4.4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.5`,
        fs:  `cpe:2.3:h:cisco:spa962_6-line_ip_phone_with_2-port_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.5.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(4\)sv1\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.5.2`,
        fs:  `cpe:2.3:h:avaya:ag250:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.5.3`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.1.4.13:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.5.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.5.5`,
        fs:  `cpe:2.3:a:roxio:creator_audio:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.6`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.6.1`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.6.2`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.6.3`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.7`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.7.1`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.7.2`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:2.1.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.7.3`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.7.4`,
        fs:  `cpe:2.3:a:web2py:web2py:1.82.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.0.7.5`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.0`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.0:beta1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.2:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.0:beta2`,
        fs:  `cpe:2.3:h:siemens:ccid1445-dn18:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.0.1`,
        fs:  `cpe:2.3:a:apache:roller:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.0.2`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04:sp17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.0.3`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.0.4`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:pre7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1.2`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1.3`,
        fs:  `cpe:2.3:a:inmatrix:zoom_player:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1.5`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1.6`,
        fs:  `cpe:2.3:a:oracle:internet_expenses:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1.7`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.1.8`,
        fs:  `cpe:2.3:a:hp:openview_nnm_lcore_dependencies:7.53.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.2`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.2.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.2.2`,
        fs:  `cpe:2.3:o:juniper:junos:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.2.3`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.3`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.3.1`,
        fs:  `cpe:2.3:a:google:android_api:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.3.2`,
        fs:  `cpe:2.3:h:huawei:ne40e:v600r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.3.3`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.17.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.3.4`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.3.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.4`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.4.1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.4.2`,
        fs:  `cpe:2.3:a:buffalotech:wzr2-g300n_firmware:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.5`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.5.1`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.5.2`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.6`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.6.1`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.6.2`,
        fs:  `cpe:2.3:a:apache:http_server:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.7`,
        fs:  `cpe:2.3:a:apache:openjpa:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.7.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.7.2`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.7.3`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.7.4`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.7.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_configuration_manager_for_atm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.1.7.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.2.0:beta1`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ovirt:ovirt:4.2.0:test1`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.1.1.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ovislink:airlive_od-2025hd:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ovislink:airlive_od-2060hd:-`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ovislink:airlive_poe100hd:-`,
        fs:  `cpe:2.3:h:huawei:campus_s7700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ovislink:airlive_poe200hd:-`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ovislink:airlive_poe250hd:-`,
        fs:  `cpe:2.3:o:cisco:content_services_switch_11500:7.30_\(00.08\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ovislink:airlive_poe2600hd:-`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ovislink:airlive_wl2600cam:-`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:3.0.0`,
        fs:  `cpe:2.3:a:google:sketchup:8.0:maintenance_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:3.0.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:3.0.2`,
        fs:  `cpe:2.3:a:citrix:xenapp_plugin_for_streamed_apps:5.0.0.5357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:3.0.3`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:3.4.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.0`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.2`,
        fs:  `cpe:2.3:o:xen:xen:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.3`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_portal_server:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.6`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.7`,
        fs:  `cpe:2.3:a:torchsoft:malware_defender:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.8`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.10`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.11`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.12`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.13`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.14`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.15`,
        fs:  `cpe:2.3:h:avaya:cajun_p880:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.0.16`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a3\(2.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.0`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.5.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.2`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.3`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.4`,
        fs:  `cpe:2.3:h:3com:3crwe754g72-a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.6`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.7`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.8`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.6.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.9`,
        fs:  `cpe:2.3:a:sun:iplanet_directory_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.10`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.40a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.11`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.12`,
        fs:  `cpe:2.3:a:ca:etrust_security_suite:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:4.5.13`,
        fs:  `cpe:2.3:a:apache:cxf:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.0`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.1`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.316:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.3`,
        fs:  `cpe:2.3:a:teamviewer:teamviewer:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.4`,
        fs:  `cpe:2.3:a:djangoproject:django:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.5`,
        fs:  `cpe:2.3:h:hp:officejet_pro_8500:cb023a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.7`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.8`,
        fs:  `cpe:2.3:a:dest-unreach:socat:2.0.0:b6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.9`,
        fs:  `cpe:2.3:a:adobe:photoshop:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.10`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.11`,
        fs:  `cpe:2.3:o:tp-link:tl-wdr3600_\(1.0\)_firmware:141022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.12`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.13`,
        fs:  `cpe:2.3:a:pgp:personal_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.14`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.14:a`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.16`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:5.0.17`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:2.0.1:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:6.0.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1006:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:6.0.1`,
        fs:  `cpe:2.3:a:ca:unicenter_network_and_systems_management:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:6.0.2`,
        fs:  `cpe:2.3:a:gnu:gpgme:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:6.0.3`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:6.0.4`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:6.0.5`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:7.0.0`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:7.0.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:7.0.2`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.0.0:beta_update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:7.0.11`,
        fs:  `cpe:2.3:a:hp:software_update:2.0.37.20031205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.0.0`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.0.2`,
        fs:  `cpe:2.3:a:open_graph_protocol_project:open_graph_protocol:1.0.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.0.3`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.0.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.0.5`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.0.6`,
        fs:  `cpe:2.3:a:phplist:phplist:2.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.0.8`,
        fs:  `cpe:2.3:a:redhat:tcpdump:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.0.9`,
        fs:  `cpe:2.3:a:microsoft:frontpage_server_extensions:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.1.0`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.10.8:*:*:*:rim:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.1.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.1.3`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.1.4`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.2.0`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb766xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:8.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud:9.0.3`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud_client:1.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:owncloud:owncloud_desktop:2.2.2`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.0.8.4990:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ows:scald:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:1.0.1.7f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ows:scald:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ows:scald:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:webmin:usermin:1.160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ows:scald:6.x-1.0:beta3`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.6.8.638:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ows:scald:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ows:scald:7.x-1.0`,
        fs:  `cpe:2.3:a:hp:network_automation:9.22.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ows:scald:7.x-1.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.0`,
        fs:  `cpe:2.3:a:adobe:extension_manager_cs4:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.0::community`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.0::enterprise`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.0::professional`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.12:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.1`,
        fs:  `cpe:2.3:a:public_download_count_project:public_download_count:7.x-1.x-dev:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.1::community`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.1::enterprise`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.1::professional`,
        fs:  `cpe:2.3:a:x:libxt:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.2`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.2:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.2::community`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.2::enterprise`,
        fs:  `cpe:2.3:o:advantech:vesp211-232_firmware:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.2::professional`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.3`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:5.0:*:pocket_pc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.3::community`,
        fs:  `cpe:2.3:a:wordpress_spreadsheet_project:wordpress_spreadsheet:0.62:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.3::enterprise`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.3::professional`,
        fs:  `cpe:2.3:a:ups:worldship_system:14.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.4`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.4::community`,
        fs:  `cpe:2.3:a:horde:groupware:1.1.4:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.4::enterprise`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)ys:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.4::professional`,
        fs:  `cpe:2.3:a:david_king:vino:2.21.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.5`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.5::community`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.5::enterprise`,
        fs:  `cpe:2.3:a:cisco:webns:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.5::professional`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.4:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.6`,
        fs:  `cpe:2.3:h:ibm:e10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.6::community`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.6::enterprise`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.6::professional`,
        fs:  `cpe:2.3:a:samba:samba:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.7`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.7::community`,
        fs:  `cpe:2.3:a:wave:preboot_manager:2.4.0.244:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.7::enterprise`,
        fs:  `cpe:2.3:a:hp:fax_cda:70.0.231.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.7::professional`,
        fs:  `cpe:2.3:a:buffalotech:wzr-ampg144nh_firmware:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.8::community`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.8::enterprise`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.6.8::professional`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.0:-:community`,
        fs:  `cpe:2.3:a:hp:select_identity:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.0:-:professional`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.1:-:community`,
        fs:  `cpe:2.3:a:citrix:secure_gateway:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.1:-:professional`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns550rx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.2:-:community`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.3.2:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.2:-:professional`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.00.245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.3:-:community`,
        fs:  `cpe:2.3:h:juniper:idp250:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.3:-:professional`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.4:-:community`,
        fs:  `cpe:2.3:a:acronis:snapapi:3.1.329:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.4:-:professional`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.5:-:community`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_hp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.5:-:professional`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.6:-:community`,
        fs:  `cpe:2.3:a:adobe:acrobat:17.011.30065:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.6:-:professional`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.7:-:community`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.7:-:professional`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.8::community`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.8::professional`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0404hd-u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.8:-:community`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.8:-:professional`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2\(.50\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.9::community`,
        fs:  `cpe:2.3:o:advantech:eki-1361_series_firmware:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.9::professional`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.10::community`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.4.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.10::professional`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.11::community`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.7.11::professional`,
        fs:  `cpe:2.3:h:ibm:system_storage_virtualization_engine_ts7700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.0::community`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.0::professional`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.1::community`,
        fs:  `cpe:2.3:a:somcloud:somnote_-_journal\/memo:2.1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.1::professional`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.2::community`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.2::professional`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.3::community`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.3::professional`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.4::community`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.4::professional`,
        fs:  `cpe:2.3:a:buzztouch:emt-paramedic_lite:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.5::community`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:4.8.5::professional`,
        fs:  `cpe:2.3:a:powie:pgb:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.0::enterprise`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.0:-:enterprise`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.1::enterprise`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.2::enterprise`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.92.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.2:-:enterprise`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.3::enterprise`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.3:-:enterprise`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.4::enterprise`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.08057:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.4:-:enterprise`,
        fs:  `cpe:2.3:a:apache:subversion:0.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.5::enterprise`,
        fs:  `cpe:2.3:h:cisco:asr_9000_rsp440_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.5:-:enterprise`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:r12.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.6::enterprise`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.6:-:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.7::enterprise`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.7:-:enterprise`,
        fs:  `cpe:2.3:a:barebones:textwrangler:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.8::enterprise`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.8:-:enterprise`,
        fs:  `cpe:2.3:a:blaine_lang:maestro:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.9::enterprise`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.9:-:enterprise`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.10::enterprise`,
        fs:  `cpe:2.3:o:hp:openvms:7.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.0.11::enterprise`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2008:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.1.0::enterprise`,
        fs:  `cpe:2.3:a:isc:bind:9.6.1:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.1.0:-:enterprise`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.1.1::enterprise`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.5.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.1.2::enterprise`,
        fs:  `cpe:2.3:a:civicrm:civicrm_private_report:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.1.3::enterprise`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.1.4::enterprise`,
        fs:  `cpe:2.3:h:polycom:hdx_9002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxid-esales:eshop:5.1.5::enterprise`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxide_project:oxide:-`,
        fs:  `cpe:2.3:a:saltstack:salt_2015:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxide_project:oxide:1.5.5`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxide_project:oxide:1.6.0`,
        fs:  `cpe:2.3:a:icinga:icinga:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxide_project:oxide:1.6.4`,
        fs:  `cpe:2.3:a:amberdms:amberdms_billing_system:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxil:simplified-content:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.3.05s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxwall:oxwall:1.1.1`,
        fs:  `cpe:2.3:a:sharethis:sharethis:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxwall:oxwall:1.3.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_network_storage_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxwall:oxwall:1.5.0`,
        fs:  `cpe:2.3:a:mutiny:standard:4.5-1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:oxwall:oxwall:1.7.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pacificmags:better_homes_and_gardens_aus:%407f0801b2::~~~android~~`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packagekit_project:packagekit:0.8.1`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packagekit_project:packagekit:0.8.2`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packagekit_project:packagekit:0.8.3`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packagekit_project:packagekit:0.8.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packagekit_project:packagekit:0.8.5`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.8:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packagekit_project:packagekit:0.8.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packagekit_project:packagekit:0.8.7`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packetfence:packetfence:3.2.0`,
        fs:  `cpe:2.3:a:rsa:access_manager_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packetfence:packetfence:3.3.0`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:6.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packetfence:packetfence:3.3.2`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_marconi_lan:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packetfence:packetfence:3.4.1`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packetfence:packetfence:3.5.1`,
        fs:  `cpe:2.3:a:xangati:xangati_xnr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packetfence:packetfence:3.6.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:packettrap:pt360_tool_suite:2.2.5459`,
        fs:  `cpe:2.3:a:digium:asterisk:11.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:pacom:1000_ccu_gms:-`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:pacom:rtu_gms:-`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.0.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:page-layout-builder_project:page-layout-builder:1.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:catos:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pageplanetsoftware:mgi_server:2.1.13`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:1.3.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pageplanetsoftware:mgi_server:2.2.0`,
        fs:  `cpe:2.3:a:perl:perl:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pagetriage_project:pagetriage:-::~~~mediawiki~~`,
        fs:  `cpe:2.3:o:xen:xen:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paidmembershipspro:paid_memberships_pro:1.7.14.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pakan_ken_tube_project:pakan_ken_tube:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:16.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:4.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:4.0.3`,
        fs:  `cpe:2.3:a:ibm:vios:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:4.0.5`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:4.0.6`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:4.0.7`,
        fs:  `cpe:2.3:a:kunena:kunena:5.0.4:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:5.0`,
        fs:  `cpe:2.3:a:intel:mzconfig:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:6.0`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:6.0.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:7.0`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.31.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:7.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:9.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.34:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:9.0.1`,
        fs:  `cpe:2.3:a:microsoft:office:2004:*:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:9.1`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_controller_firmware:21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:9.2`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:20.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:11.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:11.0.1`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:12.0`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bpeo64g:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:12.1`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:12.2`,
        fs:  `cpe:2.3:a:apache:tomcat:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:12.2.1`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:12.3`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:12.3:r2`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.0`,
        fs:  `cpe:2.3:a:bluestacks:bluestacks:2.1.3.5650:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-51:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.1.1`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.2`,
        fs:  `cpe:2.3:a:adobe:contribute:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.2.1`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.0.4:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.3`,
        fs:  `cpe:2.3:a:ni:diadem:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.3.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.8.0.2257:online_windows_server_2003_x64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.3.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.805:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.4`,
        fs:  `cpe:2.3:a:isode:m-link:15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palemoon:pale_moon:15.4.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.4:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.1`,
        fs:  `cpe:2.3:a:emc:avamar:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.3`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.3.1`,
        fs:  `cpe:2.3:a:drupal:drupal:6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.4.1`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.5`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.5.1`,
        fs:  `cpe:2.3:o:huawei:s12708_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.6`,
        fs:  `cpe:2.3:a:openafs:openafs:1.1.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.6.1`,
        fs:  `cpe:2.3:h:y-cam:ycbl03:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.6.2`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.7`,
        fs:  `cpe:2.3:a:redhat:libreport:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.7.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.7.2`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.8`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.8.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.8.3`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.9`,
        fs:  `cpe:2.3:o:yahama:rtx1200:10.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.9.1`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62r:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.9.2`,
        fs:  `cpe:2.3:h:netgear:r7100lg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.9.3`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.9.4`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.9.5`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.9.6`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.79:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.10`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.10.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.10.2`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.1.0.12319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.10.3`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.10.4`,
        fs:  `cpe:2.3:a:kieranoshea:calendar:1.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11`,
        fs:  `cpe:2.3:a:7andi-fs.co:denny\&#39;s:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.3`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.4`,
        fs:  `cpe:2.3:a:simple_subscription_project:simple_subscription:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.5`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.6`,
        fs:  `cpe:2.3:a:clamav:clamav:0.81:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.7`,
        fs:  `cpe:2.3:a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.8`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.9`,
        fs:  `cpe:2.3:a:microsoft:excel:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palletsprojects:werkzeug:0.11.10`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palm:blazer:3.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palm:blazer:4.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palm:blazer:4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palm:blazer:4.3`,
        fs:  `cpe:2.3:h:symantec:gateway_security_400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palm:blazer:4.5`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palo_alto_networks:traps:3.1.2.1546`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paloaltonetworks:globalprotect:1.1.6`,
        fs:  `cpe:2.3:a:perl:perl:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paloaltonetworks:globalprotect:1.1.7`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2010:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paloaltonetworks:netconnect:-`,
        fs:  `cpe:2.3:a:oracle:solaris_cluster:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:3.1.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:3.1.10`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:3.1.11`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:3.1.12`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p391:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.0`,
        fs:  `cpe:2.3:o:netgear:prosafe_firmware:5.4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.333:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.2`,
        fs:  `cpe:2.3:a:core-apps:rims_2014_annual_conference:6.0.7.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.3`,
        fs:  `cpe:2.3:a:php:php:5.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.4`,
        fs:  `cpe:2.3:o:huawei:honor_4c_firmware:chm-tl00c01b556:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.5`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp6:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.6`,
        fs:  `cpe:2.3:h:hp:elitebook_745_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.7`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.12.2:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.8`,
        fs:  `cpe:2.3:a:realtek:realtek_ac\&#39;97_audio:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.10`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.05.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.11`,
        fs:  `cpe:2.3:a:mama:mama.cn:1.02:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.12`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.124.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.0.13`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.1`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.2`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.15:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.4`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.5`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.6`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.7`,
        fs:  `cpe:2.3:h:linksys:befsx41:1.43.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.8`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.8-h3`,
        fs:  `cpe:2.3:o:hp:hp-ux:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.9`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.10`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.11`,
        fs:  `cpe:2.3:a:gnu:fileutils:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.12`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:4.1.13`,
        fs:  `cpe:2.3:a:ibm:data_protection:6.3.1:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.0`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:7.0.220.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.0-h1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.2`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.3`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2000:sp4:analysis_services:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.4`,
        fs:  `cpe:2.3:a:apple:itunes:8.0.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.5`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.14`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.15`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.11.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.0.17`,
        fs:  `cpe:2.3:a:hp:openview_emanate_snmp_agent:14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.1`,
        fs:  `cpe:2.3:a:facebook:radio_de_la_cato:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.2`,
        fs:  `cpe:2.3:h:hp:laserjet_5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.3`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.4`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.5cdf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.5`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.6`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.01:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.7`,
        fs:  `cpe:2.3:a:csounds:csound:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.8`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.9`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:5.1.10`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.07.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.10.186:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.3`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.4`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.5`,
        fs:  `cpe:2.3:a:apache:camel:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.6`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.7`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.8`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.9`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.10`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.11`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.0.12`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:13.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.0`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.3`,
        fs:  `cpe:2.3:a:microsoft:outlook:98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.4`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs4_template_projects_\&amp;_footage:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.22:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.6`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.7`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.0.p-1.0.6.0.32-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.8`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.9`,
        fs:  `cpe:2.3:a:trillian:trillian:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.10`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.12`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.13`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.0as:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:6.1.15`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4p\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.0.4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.0.5-h2`,
        fs:  `cpe:2.3:a:businessobjects:xcelsius:12.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.0.8`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.6.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.0.9`,
        fs:  `cpe:2.3:a:bittorrent:utorrent:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.0.11`,
        fs:  `cpe:2.3:o:juniper:junos_j:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.0.12`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.0`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4.2:patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.1`,
        fs:  `cpe:2.3:a:wp_rss_poster_plugin_project:wp-rss-poster:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.3`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.4`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.4-h2`,
        fs:  `cpe:2.3:a:vmware:player:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.6`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.7`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:paloaltonetworks:pan-os:7.1.8`,
        fs:  `cpe:2.3:h:rockwellautomation:controllogix_5560_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:palosanto:elastix:2.5.0`,
        fs:  `cpe:2.3:a:apple:xcode:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:panalogic:serial_talk:1.6.8.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:panasonic:network_camera_recorder:-`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:panasonic:network_camera_recorder:4.04r02`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:panasonic:network_camera_view:3.0`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:panasonic:network_camera_view:4.0`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:panasonic:workio_digital_multifunction_copier:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:panasonic:workio_dp-3520:-`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:panasonic:workio_dp-3560:-`,
        fs:  `cpe:2.3:a:buffalotech:whr-g54s_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pandasecurity:panda_av_pro_2014:13.01.01`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pandasecurity:panda_global_protection_2014:7.01.01`,
        fs:  `cpe:2.3:o:dlink:dsl-2740b_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pandasecurity:panda_gold_protection:7.01.01`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pandasecurity:panda_internet_security_2014:19.01.01`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:panduit:design_tool_for_visio:5.0.0`,
        fs:  `cpe:2.3:h:panasonic:workio_dp-3520:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:panduit:easy-mark:3.6.60`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:panopoly_magic_project:panopoly_magic:7.x-1.16::~~~drupal~~`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pansi:pansi_sms:1.97`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pansi:pansi_sms:2.01`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.01:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pansi:pansi_sms:2.1`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pansi:pansi_sms:2.04`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pansi:pansi_sms:2.05`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pansi:pansi_sms:2.06`,
        fs:  `cpe:2.3:a:hp:centralview_revenue_leakage_control:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pansi:pansi_sms:2.07`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_card_software:2.0.a11.430`,
        fs:  `cpe:2.3:a:sap:hybris:5.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_card_software:2.0.a20.1215`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:16.10.0.1036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_card_software:2.2.3738.1006`,
        fs:  `cpe:2.3:a:ibm:maximo_for_utilities:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_card_software:2.2.6200.701`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_usb_modem_software:1.2.3619.926`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.419:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_usb_modem_software:1.2.4151.1109`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.8.5:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_usb_modem_software:1.2.7000.720`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_usb_modem_software:3.0.4.823`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:pc_usb_modem_software:3.2.4074.1103`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:uml290:1.5.24.1102`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:uml290:1.5.26.1201`,
        fs:  `cpe:2.3:a:merethis:centreon:2.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:uml290:1.5.33.429`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:uml290:1.5.39.512`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:uml290_end_user_upgrade:16.0.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.14:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pantech:umw190_end_user_upgrade:8.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9.0as:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.6.0`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.6.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.6.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:10.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.6.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.6.4`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.8.0`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.4.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.8.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.8.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.73:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.9.0`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.2:*:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paolo_bacchilega:file_roller:3.9.3`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:12.0`,
        fs:  `cpe:2.3:a:symantec:security_check:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:12.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.23:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:12.2`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:12.3`,
        fs:  `cpe:2.3:a:red-gate:sql_backup:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:12.4`,
        fs:  `cpe:2.3:a:namazu:namazu:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:12.5`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:13.0`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:13.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:13.2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.176.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:13.3`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:13.4`,
        fs:  `cpe:2.3:a:php.s3.to:php-i-board:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:13.5`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:14.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_mf:14.1`,
        fs:  `cpe:2.3:o:juniper:junos:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:12.0`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.7.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:12.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:12.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p484_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:12.3`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:12.4`,
        fs:  `cpe:2.3:a:moodle:moodle:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:12.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(.3.8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:13.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:13.1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:13.2`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:13.3`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:13.4`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:13.5`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:14.0`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papercut:papercut_ng:14.1`,
        fs:  `cpe:2.3:a:rackspace:openstack_windows_guest_agent:1.2.6.0:-:-:*:-:xen_server:*:*`,
    },
     
    {
        uri: `cpe:/a:paperthin:commonspot_content_server:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paperthin:commonspot_content_server:7.0.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta63:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paperthin:commonspot_content_server:7.0.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paperthin:commonspot_content_server:8.0.0`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paperthin:commonspot_content_server:8.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paperthin:commonspot_content_server:8.0.2`,
        fs:  `cpe:2.3:a:ibm:maximo_service_desk:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paperthin:commonspot_content_server:8.0.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paperton:allt_om_brollop:1.53::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paperton:dive_the_world:1.53::~~~android~~`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:papoo:cms_papoo_light:6.0.0`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paragon-software:alignment_tool:3.0`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:h-sphere:3.3:p1`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:7.0`,
        fs:  `cpe:2.3:a:bedita:bedita:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:7.6.1`,
        fs:  `cpe:2.3:o:cray:unicos:9.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:8.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:8.1`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:8.2`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:8.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:8.4`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:8.6`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:9.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:9.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:9.3`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:9.5`,
        fs:  `cpe:2.3:a:adobe:photoshop:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:9.5.4`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.0.0.701:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.0.1:mu_%2310`,
        fs:  `cpe:2.3:a:barebones:textwrangler:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.0.1:mu_%2311`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.0.1:mu_%232`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:8.5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.0.1:mu_%233`,
        fs:  `cpe:2.3:a:danielkorte:nodeaccesskeys:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.0.1:mu_%235`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.0.1:mu_%237`,
        fs:  `cpe:2.3:a:mcmguides:pdg_gold_for_ncos_2009:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2310`,
        fs:  `cpe:2.3:h:cisco:catalyst_2900:xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2311`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2312`,
        fs:  `cpe:2.3:o:cisco:ios:12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2313`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2315`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2316`,
        fs:  `cpe:2.3:a:riken:xoonips:3.47:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2317`,
        fs:  `cpe:2.3:a:monotone:monotone:0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2318`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.5125:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2319`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.1.1:mu_%2320`,
        fs:  `cpe:2.3:a:quest:qexplain:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:build1011110331.18`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:build20110407.20`,
        fs:  `cpe:2.3:a:hp:http_server:5.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%231`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%2310`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%2311`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%2312`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.350:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%232`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%233`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%234`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%235`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%237`,
        fs:  `cpe:2.3:a:perl:perl:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%238`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.2.0:mu_%239`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.3.1:build1013110726.09`,
        fs:  `cpe:2.3:a:citrix:presentation_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.3.1:mu_%232`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.3.1:mu_%233`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.1.14:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.3.1:mu_%234`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:10.4.4:build20111103.18`,
        fs:  `cpe:2.3:a:rarlab:winrar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parallels:parallels_plesk_panel:11.0.9`,
        fs:  `cpe:2.3:a:irssi:irssi:0.8.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paramore_project:paramore:2.3.4::~~~android~~`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paratrooper-newrelic_project:paratrooper-newrelic:1.0.1:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:bladeenc:bladeenc:0.94.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parentlink:bloom_township_206:4.0.500::~~~android~~`,
        fs:  `cpe:2.3:a:altiris:wise_toolkit:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parentlink:west_bend_school_district:4.0.500::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paretologic:regcure:1.5.1.3`,
        fs:  `cpe:2.3:a:phorum:phorum:5.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pargovernment:gv:950.0.0.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-03-02:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parsagostar:parsaweb:-`,
        fs:  `cpe:2.3:a:netkit:netkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parsagostar:parsaweb_cms:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:parsi-font_project:parsi-font:4.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.8.4:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:partytrack_library_project:partytrack_library:-::~~~android~~`,
        fs:  `cpe:2.3:a:hp:sitescope_patch:11.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:pass4sure_for_comptia_n10-004:3.10::~~demo~~~`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.7:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:pass4sure_for_comptia_sy0-201:3.10`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:pass4sure_for_comptia_sy0-201:7.6`,
        fs:  `cpe:2.3:a:sun:jre:1.1.8:update8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:pass4sure_for_isaca_cism:3.0`,
        fs:  `cpe:2.3:a:landesk:landesk_management_suite:9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:questions_and_answers_for_cisco_640-802:7.13.13049::~~demo~~~`,
        fs:  `cpe:2.3:h:dell:precision_t3600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:questions_and_answers_for_cisco_640-816:3.0::~~demo~~~`,
        fs:  `cpe:2.3:a:haxx:curl:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:questions_and_answers_for_cisco_640-816:5.0.13021`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:questions_and_answers_for_comptia_sy0-201:7.7.12912`,
        fs:  `cpe:2.3:a:superwebmailer:superwebmailer:5.60.0.01190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:questions_and_answers_for_comptia_sy0-301:4.0.13061::~~demo~~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:questions_and_answers_for_comptia_sy0-301:5.7.13201`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:questions_and_answers_for_ec-council_2-50:3.0::~~demo~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pass4sure:questions_and_answers_for_ec-council_ec0-0:3.0::~~demo~~~`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.1.3.1513:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:passion4profession:8_minutes_abs_workout:2.0.9::~~~android~~`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:passion4profession:chest_workout:2.0.8::~~~android~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password-solutions:office_password_recovery:1.0::~~professional~~~`,
        fs:  `cpe:2.3:a:symantec:vrtssmweb:1.2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:webmin:usermin:1.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:netdynamics:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.7q16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:docker:docker:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:sendy:sendy:1.1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:v8:3.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:6.x-1.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:h:sierrawireless:pinpoint_xt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:redhat:rsync:2.4.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome_frame:16.0.912.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:justsystems:atok:2007:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:password_policy_project:password_policy:7.x-1.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:path_breadcrumbs_project:path_breadcrumbs:7.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:path_breadcrumbs_project:path_breadcrumbs:7.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:path_breadcrumbs_project:path_breadcrumbs:7.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-0.x:dev`,
        fs:  `cpe:2.3:a:adobe:adobe_reader:11.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-1.0`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd_dx:8.3.5424:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-1.2`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-1.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-1.35`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-1.36`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-1.x:dev`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-2.0`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-2.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-2.2`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:5.x-2.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-1.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-1.2`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-1.3`,
        fs:  `cpe:2.3:a:microsoft:publisher:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-1.35`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p177:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-1.36`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.13:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:cisco:jabber:9.1\(.2\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-2.0`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux_corporate_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-2.1`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-2.2`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-2.3`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r7:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-2.4`,
        fs:  `cpe:2.3:h:cisco:ip_phone_7960:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-3.0`,
        fs:  `cpe:2.3:a:free_pageplus_activation_project:free_pageplus_activation:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-3.1`,
        fs:  `cpe:2.3:a:rubyonrails:jquery-ujs:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-3.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-3.3`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:1.8.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-3.4`,
        fs:  `cpe:2.3:a:plogger:plogger:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patrick_przybilla:addtoany:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patterns:patterns:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.4.4:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:patterson_dental:eaglesoft:17.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_lesniewsk:autocomplete:1.0`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_lesniewsk:autocomplete:1.1`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.2:rc2:*:*:drupal:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_lesniewsk:autocomplete:1.2`,
        fs:  `cpe:2.3:a:roxio:central_core:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_lesniewsk:autocomplete:1.3`,
        fs:  `cpe:2.3:o:cisco:catos:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_lesniewsk:autocomplete:2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_lesniewsk:autocomplete:2.1`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.5`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.6`,
        fs:  `cpe:2.3:a:adobe:connect:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.7`,
        fs:  `cpe:2.3:a:emc:networker:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.8:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.8:p1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.09.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.8:p2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.1.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.8:p3`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.9:ga11`,
        fs:  `cpe:2.3:a:redmine:redmine:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.9:ga12`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.10:ga3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.10:ga4`,
        fs:  `cpe:2.3:h:lucent:access_point_service_router_600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.10:ga5`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update7_b03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.11:beta2`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.11:beta4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.11:ga6`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.12:beta6`,
        fs:  `cpe:2.3:h:hp:procurve_switch_8000m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.12:ga10`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.12:ga11`,
        fs:  `cpe:2.3:a:mcafee:dlp_management_tools:9.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.12:ga12`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:341.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.12:ga13`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.12:ga7`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.13:ga6`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.13:ga7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.14:ga11`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_service:3.3.929:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.14:ga6`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.21:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.14:ga7`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_mattes:x3270:3.3.14:ga9`,
        fs:  `cpe:2.3:o:freebsd:freebsd:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paul_perkins:tail_for_win32:4.2.6`,
        fs:  `cpe:2.3:a:apple:quicktime:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paulalexanderformayor:paul_alexander_campaign:4.5.8::~~~android~~`,
        fs:  `cpe:2.3:a:synck_graphica:mailform_pro_cgi:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pavel_zolnikov:command_prompt_explorer_bar:1.1.0`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.68:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pawel_jakub_dawidek:geli:4`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pawel_jakub_dawidek:geli:7`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pawel_jakub_dawidek:geli:8`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.54.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pax_project:pax:1%3a20140703`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pay_per_media_player_project:pay_per_media_player:1.24:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:payment_for_webform_project:payment_for_webform:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:payment_for_webform_project:payment_for_webform:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:payment_for_webform_project:payment_for_webform:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:payment_for_webform_project:payment_for_webform:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:payment_for_webform_project:payment_for_webform:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:payment_for_webform_project:payment_for_webform:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paymentsplus:payments_plus:2.1.5`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paymentsplus:payments_plus:2.10`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.63:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:paymentsplus:payments_plus:2.20`,
        fs:  `cpe:2.3:a:bea:aqualogic_interaction:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paymentsplus:payments_plus:2.25`,
        fs:  `cpe:2.3:a:dell:system_manager:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paymentsplus:payments_plus:2.30`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paymentsplus:payments_plus:3.00`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paymentsplus:payments_plus:3.10`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paymentsplus:payments_plus:3.20`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:payoneer_sign_up_project:payoneer_sign_up:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)mc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:instant_payment_notification:-`,
        fs:  `cpe:2.3:o:debian:debian_linux:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:mass_pay:-`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:merchant-sdk-php:3.9.1`,
        fs:  `cpe:2.3:a:david_king:vino:3.5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:merchant_sdk:-`,
        fs:  `cpe:2.3:a:yahoo:messenger:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:payments_pro:-`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:payments_standard:-`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:payments_standard:20120427`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:transactional_information_soap:-`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:paypal:website_payments_standard_module:1.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pbboard:pbboard:2.1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pbboard:pbboard:3.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pbm212030_project:pbm212030:-`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcman%27s_ftp_server_project:pcman%27s_ftp_server:2.0.7`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.00`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:10.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.01`,
        fs:  `cpe:2.3:a:microsoft:forefront_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.02`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.373:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.10`,
        fs:  `cpe:2.3:a:citrix:xenapp_plugin_for_streamed_apps:1.2.5357:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.11`,
        fs:  `cpe:2.3:o:sun:sunos:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.12`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.13`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.20`,
        fs:  `cpe:2.3:a:google:drive:1.0.2891.6813:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.21`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.30`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.31`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.32`,
        fs:  `cpe:2.3:a:adobe:pdf_library_sdk:9.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.33`,
        fs:  `cpe:2.3:a:perl:perl:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.34`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.35`,
        fs:  `cpe:2.3:a:emc:navisphere_agent:29.6.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.36`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.37`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2007.0.0.2:-:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.38`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.40`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre:8.41`,
        fs:  `cpe:2.3:a:siemens:simatic_pcs7:7.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre2:10.23`,
        fs:  `cpe:2.3:a:roxio:easy_cd_\&amp;_dvd_creator:6.1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:pcre2:10.30`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:perl-compatible_regular_expression_library:7.0`,
        fs:  `cpe:2.3:h:linksys:befw11s4:1.4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:perl-compatible_regular_expression_library:7.1`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:perl-compatible_regular_expression_library:7.2`,
        fs:  `cpe:2.3:a:microsoft:backoffice:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:perl-compatible_regular_expression_library:7.3`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.5:u3b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:perl_compatible_regular_expression_library:8.36`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:perl_compatible_regular_expression_library:8.37`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.3:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pcre:perl_compatible_regular_expression_library:8.38`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pctools:pctools_firewall:6.0.0.88:-:plus`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:3.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pctools:threatfire:4.7.0.17`,
        fs:  `cpe:2.3:a:autodesk:architectural_desktop:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pd-admin:pd-admin:4.16`,
        fs:  `cpe:2.3:o:d-link:dap-1350_firmware:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pdfforge:pdfcreator:0.9.3`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pdfforge:pdfcreator:0.9.5`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.11:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pdfforge:pdfcreator:0.9.6`,
        fs:  `cpe:2.3:h:hp:j9264a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pdfforge:pdfcreator:0.9.8`,
        fs:  `cpe:2.3:a:wellintech:kinghistorian:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pdfforge:pdfcreator:1.2.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pdfforge:pdfcreator_toolbar:3.0.0.0`,
        fs:  `cpe:2.3:h:cisco:spa8800_ip_telephony_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pdflib:pdflib:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pdlk:hardest_game_collection:1.5.0::~~~android~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pearlsw:echo:9.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pearlsw:echo_workstation:7.79.9`,
        fs:  `cpe:2.3:a:planetofthevapes:planet_of_the_vapes_forum:3.7.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pearson:esis_enterprise_student_information_system:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pearson:esis_enterprise_student_information_system:3.3.0.13`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x4275:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pecio-cms:pecio_cms:1.1.5`,
        fs:  `cpe:2.3:a:plone:plone:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pecio-cms:pecio_cms:2.0`,
        fs:  `cpe:2.3:a:adobe:illustrator:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pecio-cms:pecio_cms:2.0.1`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.1.0-104.rhel5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pecio-cms:pecio_cms:2.0.5`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedestal:securityexpressions:3.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_guardium:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_cambra:commerce_extra_panes:7.x-1.0`,
        fs:  `cpe:2.3:a:php:xhprof:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_cambra:commerce_extra_panes:7.x-1.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_cambra:commerce_extra_panes:7.x-1.x:dev`,
        fs:  `cpe:2.3:h:tropos:3320_indoor_mesh_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.0.1:-`,
        fs:  `cpe:2.3:a:winzip:self-extractor:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.0.2`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.0.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.1`,
        fs:  `cpe:2.3:h:cisco:aironet_3600p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.2`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.3`,
        fs:  `cpe:2.3:a:process-one:ejabberd:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.4`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.5.1`,
        fs:  `cpe:2.3:a:webpromoexperts:webpromoexperts:1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.6`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-03-02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.7`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a4:2.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.7.1`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.7.2`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.5:-:windows-nt:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.8`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.9`,
        fs:  `cpe:2.3:a:ca:etrust_intrusion_detection:1.4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:0.9.1`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_castro:gnome-subtitles:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_villavicencio_garrido:hipo:0.6`,
        fs:  `cpe:2.3:a:lingotek:lingotek:6.x-1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_villavicencio_garrido:hipo:0.6.1`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.50.020.1299:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pedro_villavicencio_garrido:hipo:0.6.99`,
        fs:  `cpe:2.3:o:nokia:ipso:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:2.8`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_firmware:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:2.9`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:5.5`,
        fs:  `cpe:2.3:a:hp:radia_notify_daemon:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:5.6`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:5.7`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma463xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:6.0`,
        fs:  `cpe:2.3:a:isc:bind:9.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:6.1`,
        fs:  `cpe:2.3:a:cisco:media_experience_engine:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:6.2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peel:peel_shopping:6.3`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peernet:file_conversion_center:4.0.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1p\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peernet:file_conversion_center:4.0.8`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pegasus_airlines_project:pegasus_airlines:0.84.13503.96707::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:zlib:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:penguinchefshop_project:penguinchefshop:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:logitech:lws_youtube_plugin:13.30.1346.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pennytalk:pennytalk_mobile:2.0.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.2.3:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pentalogix:viewmate:11.2.3`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.taghelpers:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:peoplepc:peoplepal:3.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.7.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peoplepc:peoplepal:6.1`,
        fs:  `cpe:2.3:a:php:php:5.4.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peoplepc:peoplepal:6.2`,
        fs:  `cpe:2.3:a:symantec:mail_security_for_microsoft_exchange:6.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perblue:parallel_kingdom_mmo:%407f070019::~~~android~~`,
        fs:  `cpe:2.3:a:netiq:self_service_password_reset:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percipientstudios:imagen:2.5.1:-:~~~umbraco_cms~~`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percipientstudios:imagen:2.5.2:-:~~~umbraco_cms~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:7:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percipientstudios:imagen:2.5.3:-:~~~umbraco_cms~~`,
        fs:  `cpe:2.3:a:epson:copy_utility:3.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percipientstudios:imagen:2.5.4:-:~~~umbraco_cms~~`,
        fs:  `cpe:2.3:h:axis:2400_video_server:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percipientstudios:imagen:2.5.5:-:~~~umbraco_cms~~`,
        fs:  `cpe:2.3:a:sun:jre:6.0.250:update25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percipientstudios:imagen:2.5.6:-:~~~umbraco_cms~~`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percipientstudios:imagen:2.5.7:-:~~~umbraco_cms~~`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percipientstudios:imagen:2.9.0:-:~~~umbraco_cms~~`,
        fs:  `cpe:2.3:a:microsoft:excel_2013_rt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.5.50-38.0`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.10.020.1616:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.5-60.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_4840g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.6-60.1`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.10-60.2`,
        fs:  `cpe:2.3:a:apache:jackrabbit:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.11-60.3`,
        fs:  `cpe:2.3:a:montala:resourcespace:3.6.2022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.12-60.4`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.13-60.5`,
        fs:  `cpe:2.3:a:digium:asterisk:14.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.13-60.6`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.13-61.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.14-62.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.15-63.0`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.16-64.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(7a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.16-64.1`,
        fs:  `cpe:2.3:a:ibm:algo_one:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.16-64.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.17-65.0`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.17-66.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.19-67.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.20-68.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.21-69.0`,
        fs:  `cpe:2.3:a:vips:vips:7.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.21-70.0`,
        fs:  `cpe:2.3:a:vmware:workstation:12.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.21-70.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.22-71.0`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.22-72.0`,
        fs:  `cpe:2.3:a:oracle:http_server:12.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.23-72.1`,
        fs:  `cpe:2.3:a:gentoo:media-libs_jpeg:6b:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.24-72.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.25-73.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.25-73.1`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:7.80.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.26-74.0`,
        fs:  `cpe:2.3:a:apache:httpclient:4.1:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.27-75.0`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.27-76.0`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.28-76.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.29-76.2`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.30-76.3`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.6.31-77.0`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.7.10-1`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.7.10-2`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.7.10-3`,
        fs:  `cpe:2.3:o:cisco:mds_9000:2.0\(0.86\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.7.11-4`,
        fs:  `cpe:2.3:a:ibm:daeja_viewone:4.1.5.1:*:*:*:virtual:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.7.12-5`,
        fs:  `cpe:2.3:a:ninjaforge:com_ninjaxplorer:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:percona_server:5.7.13-6`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.0:alpha1`,
        fs:  `cpe:2.3:a:justsystems:just_smile:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.0:beta1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.0:rc1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.3`,
        fs:  `cpe:2.3:a:perl:perl:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.4`,
        fs:  `cpe:2.3:a:php:pear:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yk1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.1.6`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.3.5`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.18:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.4.0:rc1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.4.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.4.2`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.4.3`,
        fs:  `cpe:2.3:a:adobe:fonts_all:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtrabackup:2.4.4`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.14-25.1`,
        fs:  `cpe:2.3:a:apache:solr:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.15-25.2`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.15-25.3`,
        fs:  `cpe:2.3:a:filenice:filenice:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.15-25.4`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.15-25.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.19-25.6`,
        fs:  `cpe:2.3:a:gnu:gpgme:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.20-25.7`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.21-25.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.22-25.8`,
        fs:  `cpe:2.3:a:cisco:jabber:9.1\(.4\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.24-25.11`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.25-25.12`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.26-25.12`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.27-25.13`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.28-25.14`,
        fs:  `cpe:2.3:o:yahama:rtw65b:5.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.29-25.15`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.30-25.16`,
        fs:  `cpe:2.3:a:redhat:libpng:1.2.2-16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.6.30-25.16.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:percona:xtradb_cluster:5.7.11-4:beta-25.14.2`,
        fs:  `cpe:2.3:a:gnu:libtool:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peribit:sequence_reduction_system_software:-`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:pathtools:3.61`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.10:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:-`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.1`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:1.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.2`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.4`,
        fs:  `cpe:2.3:a:php:pear:1.3b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.5`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.52`,
        fs:  `cpe:2.3:a:apple:quicktime:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.61`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.5.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.62`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp3:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.63`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.64`,
        fs:  `cpe:2.3:a:novell:opensuse_swamp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.65`,
        fs:  `cpe:2.3:a:softartisans:fileup:5.3.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.66`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.67`,
        fs:  `cpe:2.3:a:cisco:wan_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.68`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.69`,
        fs:  `cpe:2.3:a:commvault:commserve:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.70`,
        fs:  `cpe:2.3:a:apple:itunes:4.0.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.71`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.7.0:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.72`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.73`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.516:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.80`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.81`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.82`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.10:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.83`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.84`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.85`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.86`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)m1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.87`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.88`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:2.2.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.89`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.90`,
        fs:  `cpe:2.3:a:google:chrome:11.0.667.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.91`,
        fs:  `cpe:2.3:a:oracle:http_server:1.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.92`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.93`,
        fs:  `cpe:2.3:a:ibm:db2:10.5:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.94`,
        fs:  `cpe:2.3:h:buffalotech:whr-g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.95`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.96`,
        fs:  `cpe:2.3:a:pedro_villavicencio_garrido:hipo:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.97`,
        fs:  `cpe:2.3:a:microsoft:outlook:2002:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.98`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:0.99`,
        fs:  `cpe:2.3:a:fujitsu:cardminder:v3.2l10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.00`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.01`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.20`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.21`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x4270:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.22`,
        fs:  `cpe:2.3:a:bluecoat:winproxy:6.0:r1c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.31`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71-\/f:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.32`,
        fs:  `cpe:2.3:a:oracle:field_service:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.40`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.41`,
        fs:  `cpe:2.3:a:apple:itunes:12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.42`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb3x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.43`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.44`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.40.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.45`,
        fs:  `cpe:2.3:h:supermicro:x9dax-if-hft:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.46`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.47`,
        fs:  `cpe:2.3:a:coleman_watts:webform_civicrm:7.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.48`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:1.49`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.0.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.1.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.1.1`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.1.2`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.1.3`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_explorer:7.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.2.0`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x48:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.2.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.2.2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.3.0`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.4.0`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.5.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.5.1`,
        fs:  `cpe:2.3:a:canonical:reportbug:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.6.0`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.6.1`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.6.2`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.6.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.6.4`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.6.5`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.6.6`,
        fs:  `cpe:2.3:a:google:chrome:17.0.959.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.7.0`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.7.1`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.7.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.0`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.1`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.21.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.2`,
        fs:  `cpe:2.3:a:oracle:xml_publisher_reporting_tools_for_word:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.3`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.1.04011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.4`,
        fs:  `cpe:2.3:a:apple:apple_tv:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.5`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.6`,
        fs:  `cpe:2.3:h:cisco:unity_server:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.7`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.8.8`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.9.0`,
        fs:  `cpe:2.3:a:livetecs:timeline:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.9.1`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.9.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.10.0`,
        fs:  `cpe:2.3:a:tibco:enterprise_administrator_sdk:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.10.1`,
        fs:  `cpe:2.3:a:microsoft:office:2011:*:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.10.2`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.10.3`,
        fs:  `cpe:2.3:h:f5:big-ip_access_policy_manager:11.1.0:*:*:*:*:*:*:standalone`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.10.4`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.10.5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.10.6`,
        fs:  `cpe:2.3:a:libav:libav:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.10.7`,
        fs:  `cpe:2.3:a:ca:anti_virus_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.0`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.1`,
        fs:  `cpe:2.3:h:huawei:s9703:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.2`,
        fs:  `cpe:2.3:a:apache:axis:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.3`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.4`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.5`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.6`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.7`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.11.8`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.12.0`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.13.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.3:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.14.0`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:3.0:unknown:unknown:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.14.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p199:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.15.0`,
        fs:  `cpe:2.3:a:netscape:communicator:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.15.1`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.16.0`,
        fs:  `cpe:2.3:a:quagga:quagga:0.98.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.16.1`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.0.56.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.17.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.187:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.17.1`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.17.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.18.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:2.18.1`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.6.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6s_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.6.1`,
        fs:  `cpe:2.3:o:oracle:solaris:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.0`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.1`,
        fs:  `cpe:2.3:o:google:android:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.2`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.3`,
        fs:  `cpe:2.3:h:huawei:quidway_service_process_unit_board_s9700:v200r001c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.4`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.5`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.6`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.7`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.8`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.12:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.9`,
        fs:  `cpe:2.3:h:cisco:ie-5000-16s12p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.8.10`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(1\)sv1\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.9.2`,
        fs:  `cpe:2.3:a:vips:vips:7.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.10`,
        fs:  `cpe:2.3:a:symantec:ghost_console_and_standard_tools:115.1.2266:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.10.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.10.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.10.0:rc2`,
        fs:  `cpe:2.3:a:monotone:monotone:0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.10.1`,
        fs:  `cpe:2.3:a:spip:spip:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.10.1:rc1`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.3.2:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.10.1:rc2`,
        fs:  `cpe:2.3:h:apple:airport_card:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.11.0`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.11.1`,
        fs:  `cpe:2.3:o:hp:tru64:5.1_pk3_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.11.2`,
        fs:  `cpe:2.3:a:google:chrome:11.0.670.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.11.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.11.4`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.11.5`,
        fs:  `cpe:2.3:a:gnu:gnash:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.0:rc0`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.0:rc1`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.0:rc2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.24:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.0:rc3`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.0:rc4`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.0:rc5`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.1`,
        fs:  `cpe:2.3:h:huawei:ngfw_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.1:rc1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.1:rc2`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.2:rc1`,
        fs:  `cpe:2.3:h:hp:laserjet_3700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1675.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.3:rc1`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.3:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.12.3:rc3`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.0`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.1`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd7.d4xxd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.2`,
        fs:  `cpe:2.3:a:iconics:genesis32:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.3`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_9.0_firmware:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.4`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.5`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.7`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_manager:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.8`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.9`,
        fs:  `cpe:2.3:a:x.org:libx11:1.1.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.10`,
        fs:  `cpe:2.3:a:e2fsprogs_project:e2fsprogs:1.43.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.13.11`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.14.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.14.0:rc1`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:020:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.14.0:rc2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.14.0:rc3`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.14.1`,
        fs:  `cpe:2.3:a:microsoft:html_help_workshop:4.03.0002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.14.2`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.14.3`,
        fs:  `cpe:2.3:a:vmware:player:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.16.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.16.1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.16.2`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.17.7`,
        fs:  `cpe:2.3:a:imember360:imember360:3.9.002:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.18.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.20.1`,
        fs:  `cpe:2.3:a:php:php:5.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.22`,
        fs:  `cpe:2.3:a:nuance:omnipage:2.0.4:*:*:*:se:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perl:perl:5.23.9`,
        fs:  `cpe:2.3:a:amx:resource_management_suite:3.3.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:perle:833_remote_access_server:-`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:perle:cs9000_console_servers:-`,
        fs:  `cpe:2.3:a:vmware:vrealize_operations:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:perle:iolan%2b_serial_servers:-`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.3.1:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/h:perle:iolan_scs32:-`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:perle:jetstream_serial_servers:-`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:7:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:perle:lanstream_serial_servers:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je066a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perlexpress:perl_express:2.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.06:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perlmonks:module%3a%3asignature:0.70::~~~perl~~`,
        fs:  `cpe:2.3:a:mcafee:antispyware_enterprise_module:8.7.0.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perlmonks:module%3a%3asignature:0.71::~~~perl~~`,
        fs:  `cpe:2.3:a:portrait:sdk:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perlmonks:module%3a%3asignature:0.72::~~~perl~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.40.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perlmonks:module%3a%3asignature:0.73::~~~perl~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:permadi:mahjong_galaxy_space_lite:2.5::~~~android~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:perrla:perrla:7.1.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(4\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:persian_car_cms_project:persian_car_cms:1.0`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.0.5:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:persits:aspupload:-`,
        fs:  `cpe:2.3:a:wp_easy_post_types_project:wp_easy_post_types:1.4.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:persits:aspupload:1.4.0.2`,
        fs:  `cpe:2.3:a:apache:james:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:persits:aspupload:2.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:persits:xupload:-`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:persits:xupload:2.1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:persits:xupload:2.1.1`,
        fs:  `cpe:2.3:a:samba:samba:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:persits:xupload:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:persits:xupload:3.0.0.4`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pervasive:data_integrator:9.0.3.30`,
        fs:  `cpe:2.3:a:musiclab-llc:bearshare:5.2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pervasive:data_integrator_connectors:9.0.3.30`,
        fs:  `cpe:2.3:h:hp:jc611a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pervasive:data_integrator_documentation:9.0.3.30`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pervasive:data_integrator_engine:9.0.3.30`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pervasive:data_integrator_integration_server:9.0.3.30`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peta:peta:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:peter_kovacs:timesheet_next_gen:1.5.2`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:petition_project:petition:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:petition_project:petition:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:petition_project:petition:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:openstack:oslo:2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pexip:pexip_infinity:7.0`,
        fs:  `cpe:2.3:a:microsoft:media_player:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pfsense:pfsense:2.1.3`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:9.2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pfsense:pfsense:2.1.4`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.00.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pfsense:pfsense:2.2`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.3:beta_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pfsense:pfsense:2.2.1`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pfsense:snort_package:3.0.12`,
        fs:  `cpe:2.3:a:symantec:encryption_desktop:10.3.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pfsense:snort_package:3.0.13`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pfsense:suricata_package:1.0.5`,
        fs:  `cpe:2.3:o:mandriva:multi_network_firewall:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pfsense:suricata_package:1.0.6`,
        fs:  `cpe:2.3:a:bmc:patrol_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:certificate_server:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:certificate_server:2.5`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:certificate_server:2.5.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:corporate_desktop:-`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:corporate_desktop:7.1`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:corporate_desktop:7.1.1`,
        fs:  `cpe:2.3:a:telerik:analytics_monitor_library:3.2.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:corporate_desktop:9.5`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_mac:10.0.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_mac:10.0.1`,
        fs:  `cpe:2.3:a:siemens:homecontrol_for_room_automation:2.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_mac:10.0.2`,
        fs:  `cpe:2.3:a:apple:quicktime:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_mac:10.0.3`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_mac:10.0.3:sp1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.20.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_mac:10.1.0`,
        fs:  `cpe:2.3:a:opscode:chef:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_windows:10.0.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_windows:10.0.1`,
        fs:  `cpe:2.3:a:monotone:monotone:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_windows:10.0.2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_windows:10.0.3`,
        fs:  `cpe:2.3:a:ibm:director:5.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_windows:10.0.3:sp1`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_for_windows:10.1.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_security:-`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:desktop_security:7.0.4`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:e-business_server:-`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:e-business_server:6.5.8`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:e-business_server:7.0.4`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:e-business_server:7.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_architect:07-50-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:pgp:e-ppliance_1000:-`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:e-ppliance_300:-`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:pgp:e-ppliance_300:1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.14a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:pgp:e-ppliance_300:1.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:pgp:e-ppliance_300:2.0`,
        fs:  `cpe:2.3:o:google:android:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:freeware:-`,
        fs:  `cpe:2.3:a:microsoft:excel:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:freeware:7.0.3`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:keyserver:-`,
        fs:  `cpe:2.3:a:vandyke:securecrt:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:keyserver:7.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:keyserver:7.0.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:openpgp:-`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:personal_privacy:-`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:personal_privacy:6.5.3`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:personal_security:-`,
        fs:  `cpe:2.3:a:fuse_project:fuse:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:personal_security:7.0.3`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:universal_server:2.6.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.2_a:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:universal_server:2.6.2`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:universal_server:2.6.3`,
        fs:  `cpe:2.3:a:oracle:database_server:11.1.0.6.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:universal_server:2.7.2`,
        fs:  `cpe:2.3:a:kamailio:kamailio:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:universal_server:2.8.3`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:universal_server:2.9.1`,
        fs:  `cpe:2.3:a:sharetronix:sharetronix:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:universal_server:2.9.9`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgp:universal_server:2.10.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pgpdump_project:pgpdump:0.29`,
        fs:  `cpe:2.3:a:google:chrome:6.0.424.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pharmaguideline:pharmaguideline:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pharscape:hsolink:1.0.118`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.408:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pharscape:hsolink:1.0.118-2`,
        fs:  `cpe:2.3:a:ibm:application_support_facility:3.4.0:-:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:pheonixcontact-software:multiprog:5.0`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pheonixcontact-software:multiprog:5.0::~~express~~~`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pheonixcontact-software:multiprog:5.0::~~pro%2b~~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:pheonixcontact-software:proconos_eclr:-`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf019:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:pheonixcontact-software:proconos_eclr:-::~~single_chip~~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:pheonixcontact-software:proconos_eclr:-::~~softplc~~~`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:pheonixcontact-software:proconos_eclr:-::~~visual_studio~~~`,
        fs:  `cpe:2.3:a:altova:diffdog_2008:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phil_schwartz:denyhosts:2.6`,
        fs:  `cpe:2.3:a:ca:etrust_audit_client:1.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:1.0`,
        fs:  `cpe:2.3:a:rpm:rpm:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:1.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.0`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.12:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.11`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.21`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.51`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.52`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.53`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.54`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.60`,
        fs:  `cpe:2.3:a:ibm:security_qradar_incident_forensics:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.62`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.70`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:13.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.71`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.72`,
        fs:  `cpe:2.3:a:adobe:common_file_installer:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.73`,
        fs:  `cpe:2.3:a:altiris:migration_portal:1.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.74`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.80`,
        fs:  `cpe:2.3:a:redhat:jboss_wildfly_application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.81`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.82`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.83`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:2.84`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.00`,
        fs:  `cpe:2.3:a:emc:replication_manager:5.2:*:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.01`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.02`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.03`,
        fs:  `cpe:2.3:a:mollify:mollify:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.10:beta`,
        fs:  `cpe:2.3:a:cisco:qos_policy_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.20`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.22`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.23`,
        fs:  `cpe:2.3:o:hp:vvos:11.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.26`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-15_a_w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.27`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.28`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.29`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.31`,
        fs:  `cpe:2.3:a:ibm:db2:9.5:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.33`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.34`,
        fs:  `cpe:2.3:a:sgi:mailx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.35`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpq2202:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.50`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:3.51`,
        fs:  `cpe:2.3:a:hp:ignite-ux:b.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:4.00`,
        fs:  `cpe:2.3:a:wp_unique_article_header_image_project:wp_unique_article_header_image:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:philippe_jounin:tftpd32:4.50`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:philips:xper_flex_cardio:-`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:4.3.1.0218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philips:xper_information_management_physiomonitoring_5:-`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:philips:xper_information_management_vascular_monitoring_5:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2mc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:philips:xperconnect:1.5.4.053`,
        fs:  `cpe:2.3:a:siemens:comos:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phillip_lougher:squashfs:1.3:r3`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phillip_lougher:squashfs:2.2:r2`,
        fs:  `cpe:2.3:a:apache:camel:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phillip_lougher:squashfs:3.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phillip_lougher:squashfs:3.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.4.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phillip_lougher:squashfs:4.0`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phillip_lougher:squashfs:4.1`,
        fs:  `cpe:2.3:a:projectforge:projectforge:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phillip_lougher:squashfs:4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xv5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phimviethoa:chien_binh_bakugan_2_longtieng:2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phm:phm_registry_editor:0.70`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.0\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phoenixcpm:phoenix_project_manager:2.1.0.8`,
        fs:  `cpe:2.3:a:roderick_braun:ya_googlesearch:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phome:empirecms:6.6`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:8.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:-`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.0.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.1`,
        fs:  `cpe:2.3:a:mollify:mollify:1.6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.1.1`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.6.0.446:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.1.1:a`,
        fs:  `cpe:2.3:a:novell:groupwise:8.03:hp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.1.1:pre`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_team_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.1.1:rc2`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.1.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.3:a`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.3:b`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.4`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.5`,
        fs:  `cpe:2.3:a:adobe:drive_cs4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.6`,
        fs:  `cpe:2.3:a:atlassian:jira:2.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.7`,
        fs:  `cpe:2.3:a:ibm:db2:10.5:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.8`,
        fs:  `cpe:2.3:o:windriver:bsdos:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.2.11`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.3.1`,
        fs:  `cpe:2.3:a:biscom:faxcom_suite_for_windows:9.4.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.3.1:a`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.3.2`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp4:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.3.2:a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.3.2:b3`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing:10.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.383:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.3`,
        fs:  `cpe:2.3:a:extendsim:extendsim:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.4`,
        fs:  `cpe:2.3:h:lucent:ascend_pipeline_router:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.5`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.6`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.7`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.8`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:3.4.8:a`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:4.3.7`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.0:alpha`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.1:alpha`,
        fs:  `cpe:2.3:a:logitech:audio_echo_cancellation_component:10.0.1439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.2:alpha`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.3:beta`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.4:a_beta`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.4:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sra:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.5:beta`,
        fs:  `cpe:2.3:o:cisco:mds_9000_san-os:3.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.6:beta`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.7:a_beta`,
        fs:  `cpe:2.3:a:x:libxfixes:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.7:beta`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.8:rc`,
        fs:  `cpe:2.3:h:netgear:mr-adsl-dg834:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.9`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.10`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.11`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.12`,
        fs:  `cpe:2.3:a:welcart:e-commerce:1.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.13`,
        fs:  `cpe:2.3:a:imember360:imember360:3.9.000:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.13:a`,
        fs:  `cpe:2.3:a:cloudera:cloudera_service_and_configuration_manager:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.14`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.14:a`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.26:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.15`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.15:a`,
        fs:  `cpe:2.3:a:apache:libcloud:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.16`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.17`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.17:a`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.18`,
        fs:  `cpe:2.3:a:apple:keynote:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.19`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.0.20`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.1.13`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.1.14`,
        fs:  `cpe:2.3:a:bakbone:netvault:8.2.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.1.17`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:2.0\(0.169\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.1.18`,
        fs:  `cpe:2.3:a:yodl_project:yodl:3.06.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.1.20`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.3:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.1.21`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.1.25`,
        fs:  `cpe:2.3:a:citrix:presentation_server_for_windows:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.1`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.2:beta`,
        fs:  `cpe:2.3:a:spip:spip:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.3:rc1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.0.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.4:rc2`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.5`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.8`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.9`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.10`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.10:rc1`,
        fs:  `cpe:2.3:a:krisonav:krisonav:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.11`,
        fs:  `cpe:2.3:a:tibco:spotfire_desktop:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.12`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:2008.3:sp9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.12:a`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.13`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.14`,
        fs:  `cpe:2.3:a:apache:solr:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.15`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.15:a`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:2.0.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.16`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phorum:phorum:5.2.18`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photocati_media:photocrati:-::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photocati_media:photocrati:4.07::~~~wordpress~~`,
        fs:  `cpe:2.3:a:yaml-fuer-drupal:linkchecker:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.29`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.32`,
        fs:  `cpe:2.3:a:monotone:monotone:0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.33`,
        fs:  `cpe:2.3:a:gnu:sharutils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.34`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.35`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.12-1.8:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.36`,
        fs:  `cpe:2.3:a:netty_project:netty:3.9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.37`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.38`,
        fs:  `cpe:2.3:a:microsoft:host_integration_server:2004:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.39`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30119:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.39:pl1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.39:pl2`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.39:pl3`,
        fs:  `cpe:2.3:o:asus:rt-n10e_firmware:2.0.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.40`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(9\)ex3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.41`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.9sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.42`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.43`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.44`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.9p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.45`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.46`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.49`,
        fs:  `cpe:2.3:a:ibm:secureway_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.50`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.52`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc4:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.53`,
        fs:  `cpe:2.3:a:batavi:batavi:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.54`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.55`,
        fs:  `cpe:2.3:a:corosync:corosync:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.56`,
        fs:  `cpe:2.3:a:evan_dandrea:usb-creator:0.2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.57`,
        fs:  `cpe:2.3:a:dameware:remote_support:10.0.0.372:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.58`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.58:pl1`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.59`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.60`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:0.61`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.11`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.12`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.13`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.20`,
        fs:  `cpe:2.3:h:sony:playstation_3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.21`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.22`,
        fs:  `cpe:2.3:a:vmware:movie_decoder:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.23`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.31`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.32`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.33`,
        fs:  `cpe:2.3:a:e107:e107:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.40`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.41`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.42`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.43`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.44`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.45`,
        fs:  `cpe:2.3:a:suse:linux_enterprise_server_8_on_ibm_zseries_s390:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.47`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.48`,
        fs:  `cpe:2.3:a:debian:ldapscripts:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.49`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.50`,
        fs:  `cpe:2.3:a:tinc-vpn:tinc:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.51`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:1.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.52`,
        fs:  `cpe:2.3:a:automattic:genericons:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.53`,
        fs:  `cpe:2.3:a:symantec:vrtsaa:5.0.442:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.54`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.03b43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.55`,
        fs:  `cpe:2.3:o:hp:arcsight_connector_appliance_firmware:6.0.0.60023.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.56`,
        fs:  `cpe:2.3:h:hp:z240_sff_workstation_n51:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.57`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.58`,
        fs:  `cpe:2.3:a:gnu:emacs:20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.59`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.09.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.60`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.61`,
        fs:  `cpe:2.3:a:apache:solr:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.62`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.63`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.6p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.64`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.65`,
        fs:  `cpe:2.3:a:brian_akers:mod_layout:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.66`,
        fs:  `cpe:2.3:a:adobe:update_manager:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.67`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.70`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.71`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.2.5:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.72`,
        fs:  `cpe:2.3:a:allnurses:allnurses:3.4.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.73`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.74`,
        fs:  `cpe:2.3:a:rocomotion:pm_up_bbs:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.75`,
        fs:  `cpe:2.3:a:grabapp:eponyms:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.76`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.77`,
        fs:  `cpe:2.3:a:f5:big-iq_cloud:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.78`,
        fs:  `cpe:2.3:o:juniper:ive_os:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.79`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.80`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.81`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.82`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.83`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.84`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.85`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:1.90`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sru:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.00`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.10`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.11`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.12`,
        fs:  `cpe:2.3:a:brio:folder_size_for_windows:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.14`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.15`,
        fs:  `cpe:2.3:a:horde:imp:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.16`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:08.0.01h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.17`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.18`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.50`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.51`,
        fs:  `cpe:2.3:a:jenkins:git:3.4.0:alpha-4:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.52`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.53`,
        fs:  `cpe:2.3:a:opnet:license_server:17.0.0.910588:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.54`,
        fs:  `cpe:2.3:a:ca:etrust_intrusion_detection:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.55`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.56`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.7:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.70`,
        fs:  `cpe:2.3:a:ibm:iss_proventia_server_ips_for_windows:1.0.914.1780:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.71`,
        fs:  `cpe:2.3:a:netscape:navigator:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photogallerycreator:flash-album-gallery:2.72`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:photosmash_project:photosmash:1.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:photoxhibit_project:photoxhibit:2.1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:animated_smiley_generator:-`,
        fs:  `cpe:2.3:a:ibm:inventory_scout:2.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:ar_memberscript:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:blog_cms:-`,
        fs:  `cpe:2.3:o:radiothermostat:ct50_firmware:1.4.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:blog_cms:4.1.3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:bloq:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:bloq:0.5.4`,
        fs:  `cpe:2.3:a:measureup:microsoft_press_training_kit_exam_prep_suite_70-642:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:com_extensions:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:comoblog:-`,
        fs:  `cpe:2.3:a:oracle:webcenter_content:11.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:comoblog:1.1`,
        fs:  `cpe:2.3:a:daiki_ueno:libfep:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:cvs:-`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:directory_listing_script:-`,
        fs:  `cpe:2.3:a:gnu:emacs:20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:dirlist:-`,
        fs:  `cpe:2.3:a:jenkins:git:0.7.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:php:easymoblog:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:errordocs:-`,
        fs:  `cpe:2.3:a:websquare:job_web_system:1.0.6:*:*:*:high_income:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:f1_maxs_file_uploader:-`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:10.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:go-pear.php:-`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.29.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:mysql_banner_exchange:-`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:php:mysql_extension:-`,
        fs:  `cpe:2.3:h:cisco:ons_15327_sonet_multiservice_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:-`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.1.08005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:0.9`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:0.10`,
        fs:  `cpe:2.3:a:qemu:qemu:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:0.11`,
        fs:  `cpe:2.3:a:x:libxfont:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:0.90`,
        fs:  `cpe:2.3:a:zend:zendto:4.08-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p301:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.0b1`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.0b2`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.0b3`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.4.0.2710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.1`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.161:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.2.1`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.70.020.1453:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.2b1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.2b2`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.2b3`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.2b4`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:17.011.30068:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.2b5`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3.1`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(4f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3.4`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.03.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3.5`,
        fs:  `cpe:2.3:a:php:pear:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3.6`,
        fs:  `cpe:2.3:a:php:php:5.4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3b1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.19:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3b2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3b3`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.6.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3b5`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.3:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.3b6`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.6:beta:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.7.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0:rc1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ga:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a1`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a2`,
        fs:  `cpe:2.3:o:yahama:rt200i:3.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a3`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_runtime:12.0.0.840:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a4`,
        fs:  `cpe:2.3:a:libav:libav:0.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a5`,
        fs:  `cpe:2.3:a:catalyst:file_transfer:6.0.6030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a6`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a7`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a8`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1_pk6_bl20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a9`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a10`,
        fs:  `cpe:2.3:a:fortinet:forticlient_ssl_vpn:4.0.2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a11`,
        fs:  `cpe:2.3:a:xnview:xnview:1.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.0a12`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.1`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pear:1.4.2`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:pecl_phpdoc:-`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:phorum:-`,
        fs:  `cpe:2.3:a:vmware:tools:9.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:phorum:3.2.11`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.4.4004:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:-`,
        fs:  `cpe:2.3:o:sun:solaris:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:1.0`,
        fs:  `cpe:2.3:a:stackideas:komento:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:2.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:2.0b10`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.1`,
        fs:  `cpe:2.3:a:fmac:fmac_\:_federation_culinaire:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.2`,
        fs:  `cpe:2.3:a:lingotek:lingotek:6.x-1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-71-\/g:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.5`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.4.5:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.6`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.7`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.8`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.9`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.10`,
        fs:  `cpe:2.3:a:f5:big-ip:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.11`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.12`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.0:build110502:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.13`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.14`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.15`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.16`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.17`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:3.0.18`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0:beta_4_patch1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0:beta1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0:beta2`,
        fs:  `cpe:2.3:a:vmware:tools:9.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0:beta3`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0:beta4`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0.0`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0.1`,
        fs:  `cpe:2.3:a:netgenius:multilink:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0.2`,
        fs:  `cpe:2.3:a:serf_project:serf:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0.4`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.9.1:*:*:*:*:*:*:development_snapshot`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0.5`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0.6`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.0.7`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.1.0`,
        fs:  `cpe:2.3:a:isc:dnsco_bind:9.9.4:s1b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.1.1`,
        fs:  `cpe:2.3:a:mysql:maxdb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.1.3`,
        fs:  `cpe:2.3:a:lucent:radius:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.2`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.2.0`,
        fs:  `cpe:2.3:a:sigmatel:c-major_audio:5.10.5102.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.2.1`,
        fs:  `cpe:2.3:a:conky:conky:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.2.2`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.2.3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.2.4`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.0`,
        fs:  `cpe:2.3:a:adcisolutions:node_view_permissions:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.1`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.3`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.5`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.6`,
        fs:  `cpe:2.3:h:fortinet:fortigate-1000d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.7`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.8`,
        fs:  `cpe:2.3:a:ca:unicenter_jasmine:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.9`,
        fs:  `cpe:2.3:a:microsoft:ie:4.70.1300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.10`,
        fs:  `cpe:2.3:a:emc:networker_module_for_microsoft_applications:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.3.11`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.0`,
        fs:  `cpe:2.3:a:live_tv_browser_project:live_tv_browser:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.2`,
        fs:  `cpe:2.3:o:hp:thinpro:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.3`,
        fs:  `cpe:2.3:a:docebo:docebolms:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.4`,
        fs:  `cpe:2.3:a:cisco:finesse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.5`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.6`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1082.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.7`,
        fs:  `cpe:2.3:a:schneider-electric:scada_expert_clearscada:2013:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.8`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:4.4.9`,
        fs:  `cpe:2.3:a:perl:perl:2.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.0`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.0:beta1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.0.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.0:beta2`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.0:beta3`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.0:beta4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.24:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.0:rc1`,
        fs:  `cpe:2.3:a:david_king:vino:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.0:rc2`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.0:rc3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.1`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.2`,
        fs:  `cpe:2.3:a:hp:fax:140.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.3`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.4`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.0.5`,
        fs:  `cpe:2.3:a:boost:boost:1.49.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.1.0`,
        fs:  `cpe:2.3:a:hp:software_update:3.0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.1.1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.1.2`,
        fs:  `cpe:2.3:a:apple:icloud:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.1.3`,
        fs:  `cpe:2.3:o:hp:tru64:5.1a:pk6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.1.4`,
        fs:  `cpe:2.3:a:pimcore:pimcore:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.1.5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.1.6`,
        fs:  `cpe:2.3:a:hp:mercury_quality_center:8.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.0`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.2`,
        fs:  `cpe:2.3:a:feedweb:feedweb:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.3`,
        fs:  `cpe:2.3:a:google:chrome:9.0.574.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.4`,
        fs:  `cpe:2.3:a:toshiba:chec:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.5`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.6`,
        fs:  `cpe:2.3:a:x:libxfont:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.7`,
        fs:  `cpe:2.3:a:microsoft:personal_web_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.8`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.9`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.10`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.11`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_113:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.12`,
        fs:  `cpe:2.3:h:hp:j8992a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.13`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.14`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.15`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.16`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.2.17`,
        fs:  `cpe:2.3:a:broadcom:management_programs:7.70.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.0`,
        fs:  `cpe:2.3:a:digium:asterisk:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.1`,
        fs:  `cpe:2.3:a:isc:bind:9.7.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.3`,
        fs:  `cpe:2.3:h:hp:j8699a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.4`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.10:build110523:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.5`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd944a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.6`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.3.2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.7`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.8`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta51:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.9`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.10`,
        fs:  `cpe:2.3:o:alcatel:aos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.11`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.12`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144n_firmware:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.13`,
        fs:  `cpe:2.3:a:hp:eva_3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.14`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.15`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.16`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.17`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.18`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.19`,
        fs:  `cpe:2.3:h:3com:3c6012-902:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.20`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.21`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(20\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.22`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.23`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.24`,
        fs:  `cpe:2.3:a:redhat:openstack:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.25`,
        fs:  `cpe:2.3:o:microsoft:windows-9x:98:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.26`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.27`,
        fs:  `cpe:2.3:a:sysax:multi_server:5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.3.28`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.3_build_34685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.0`,
        fs:  `cpe:2.3:a:cisco:finesse:8.5\(4\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.2`,
        fs:  `cpe:2.3:a:google:v8:3.24.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.3`,
        fs:  `cpe:2.3:a:todo_filter_project:todo_filter:7.x-1.x-dev:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.4`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-00-\/a:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.6`,
        fs:  `cpe:2.3:a:ibm:db2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.7`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.8`,
        fs:  `cpe:2.3:a:xnview:xnview:1.25:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.9`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1:update20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.10`,
        fs:  `cpe:2.3:a:microsoft:office_web_components:xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.11`,
        fs:  `cpe:2.3:a:david_king:vino:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.12`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.12:rc1`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.12:rc2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.13`,
        fs:  `cpe:2.3:a:ca:desktop_management_suite:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.13:rc1`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.14`,
        fs:  `cpe:2.3:o:apple:a_ux:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.14:rc1`,
        fs:  `cpe:2.3:a:connections_project:connections:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.15:rc1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.16:rc1`,
        fs:  `cpe:2.3:h:siemens:scalance_x-200rna:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.17`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.18`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.19`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ew:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.20`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.21`,
        fs:  `cpe:2.3:a:zarafa:zarafa:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.22`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.6:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.23`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_client:7.2.106_:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.24`,
        fs:  `cpe:2.3:a:mandrakesoft:mandrake_single_network_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.25`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.26`,
        fs:  `cpe:2.3:a:digium:asterisk:11.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.27`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p480:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.28`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.29`,
        fs:  `cpe:2.3:o:sun:solaris:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.30`,
        fs:  `cpe:2.3:a:capnproto:capnproto:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.34`,
        fs:  `cpe:2.3:a:ibm:api_management:4.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.35`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.37`,
        fs:  `cpe:2.3:a:opscode:chef:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.38`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.12.4:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.39`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.41`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.42`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.43`,
        fs:  `cpe:2.3:a:ibm:security_guardium_database_activity_monitor:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.44`,
        fs:  `cpe:2.3:a:oracle:email_center:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.4.45`,
        fs:  `cpe:2.3:a:vmware:view_client:4.6.0.366101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:alpha1`,
        fs:  `cpe:2.3:a:keepass:keepass:0.97:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:alpha2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:alpha3`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:alpha4`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.9:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:alpha5`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:alpha6`,
        fs:  `cpe:2.3:a:google:chrome:12.0.733.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:beta1`,
        fs:  `cpe:2.3:a:neojoomla:com_neorecruit:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:beta2`,
        fs:  `cpe:2.3:a:hp:creativeprojects_panorama1config:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:beta3`,
        fs:  `cpe:2.3:a:xymon:xymon:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:beta4`,
        fs:  `cpe:2.3:a:apache:activemq:5.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:rc1`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.0:rc2`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.2`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.14:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.3`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.4`,
        fs:  `cpe:2.3:a:apple:webkit:85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.5`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.6`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.7`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.8`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.9`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:6.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.10`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_22.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.11`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.12`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.13`,
        fs:  `cpe:2.3:a:microsoft:asp.net_signalr:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.14`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7906g:8.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.18`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.19`,
        fs:  `cpe:2.3:a:zope:zope:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.20`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.21`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.22`,
        fs:  `cpe:2.3:o:honeywell:excel_web_xl_1000c500_300_i\/o:2.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.23`,
        fs:  `cpe:2.3:a:avaya:message_networking:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.24`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.25`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.26`,
        fs:  `cpe:2.3:h:huawei:ma5200g:v300r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.27`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:12.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.28`,
        fs:  `cpe:2.3:o:huawei:s3300_firmware:v100r006c00spc800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.29`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5610:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.30`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.31`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.32`,
        fs:  `cpe:2.3:a:ibm:sterling_b2b_integrator:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.33`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.34`,
        fs:  `cpe:2.3:a:acme:thttpd:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.35`,
        fs:  `cpe:2.3:a:microsoft:word:98:sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.36`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.5.37`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:alpha1`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:319.00:-:*:*:unix:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:alpha2`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:alpha3`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.0.5:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:alpha4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:alpha5`,
        fs:  `cpe:2.3:a:oracle:marketing:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:beta1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:beta2`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:beta3`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.0:beta4`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.1`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.2`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.52:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.4`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.5`,
        fs:  `cpe:2.3:a:rack_project:rack:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.6`,
        fs:  `cpe:2.3:a:datawatch:monarch_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.7`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.8`,
        fs:  `cpe:2.3:a:embedthis:appweb:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.10`,
        fs:  `cpe:2.3:a:haxx:curl:7.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)e5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.14`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.15`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.16`,
        fs:  `cpe:2.3:a:tenable:nessus:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.17`,
        fs:  `cpe:2.3:a:oracle:interaction_center_intelligence:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.18`,
        fs:  `cpe:2.3:a:x2engine:x2crm:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.19`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.20`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.21`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.22`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2009:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.23`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.25`,
        fs:  `cpe:2.3:a:webasyst:shop-script:5.2.2.30933:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.26`,
        fs:  `cpe:2.3:a:cabextract:cabextract:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.27`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.28`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.29`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.0.1:-:-:en-us:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:5.6.30`,
        fs:  `cpe:2.3:a:xfree86:xfree86:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:6.0`,
        fs:  `cpe:2.3:a:osticket:osticket:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.0`,
        fs:  `cpe:2.3:a:redhat:stronghold:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.1`,
        fs:  `cpe:2.3:a:cisco:internet_streamer_content_delivery_system:2.6.3.b50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.2`,
        fs:  `cpe:2.3:a:techsmith:snagit:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.4`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.64:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.6`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:7.80.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.7`,
        fs:  `cpe:2.3:a:ti:ti_inst:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.8`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.9`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.10`,
        fs:  `cpe:2.3:o:juniper:junos:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.11`,
        fs:  `cpe:2.3:a:vim:vim:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.12`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p2_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.13`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.14`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.15`,
        fs:  `cpe:2.3:a:dell:md_storage_software:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.16`,
        fs:  `cpe:2.3:h:cisco:catalyst_6000_ws-svc-nam-2:2.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.17`,
        fs:  `cpe:2.3:a:lxml:lxml:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.18`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.19`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.0.20`,
        fs:  `cpe:2.3:a:adobe:indesign:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.1.0`,
        fs:  `cpe:2.3:a:tibco:enterprise_administrator:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.1.1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.1.2`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.1.3`,
        fs:  `cpe:2.3:h:samsung:chromebox_3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.1.4`,
        fs:  `cpe:2.3:a:adobe:color_common_settings:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.1.5`,
        fs:  `cpe:2.3:a:usr:digital_line_detect:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php:7.1.6`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php_fi:-`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php_script_index:-`,
        fs:  `cpe:2.3:a:hummingbird:cyberdocs:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:php123_top_sites:-`,
        fs:  `cpe:2.3:a:ca:unicenter_tng:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:phpbookingcalendar:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:phpsquidpass:-`,
        fs:  `cpe:2.3:a:isc:bind:9.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:xhprof:0.9.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.437:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:xhprof:0.9.1`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-backup:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:xhprof:0.9.2`,
        fs:  `cpe:2.3:a:openstack:swift:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:xhprof:0.9.3`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php:xhprof:0.9.4`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_provisioning:10.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.1`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.2`,
        fs:  `cpe:2.3:a:hp:openview_cross_platform_component:3.10.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.4`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.5`,
        fs:  `cpe:2.3:a:siteminder_federation:12.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.7`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.8`,
        fs:  `cpe:2.3:o:avtech:avn801_dvr_firmware:1017-1003-1009-1003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.9`,
        fs:  `cpe:2.3:o:freebsd:freebsd:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.9.1`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.44:-:*:*:linux_kernel:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-calendar:php-calendar:0.10`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:expanded_calendar_module:-`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1040:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:expanded_calendar_module:2.01`,
        fs:  `cpe:2.3:a:intel:lan_adapters_snmp_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:freshlinks_module:1.0:rc1`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:-`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:4.01`,
        fs:  `cpe:2.3:a:mautic:mautic:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:6.01.9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:6.01.10`,
        fs:  `cpe:2.3:a:quassel-irc:quassel:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:6.01.15`,
        fs:  `cpe:2.3:a:yahoo:messenger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:7.00.1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.6p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:7.02.01`,
        fs:  `cpe:2.3:a:digium:asterisk:12.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:7.02.02`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(26\)sv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:7.02.03`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_105:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:7.02.04`,
        fs:  `cpe:2.3:a:intel:network_connections:14.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:7.02.05`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:7.02.06`,
        fs:  `cpe:2.3:a:symantec:liveupdate:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:php-fusion:7.02.07`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:recepies_module:1.1`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_management_center_for_ips_sensors:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:team_impact_ti_blog_system_module:-`,
        fs:  `cpe:2.3:a:differencegames:hidden_object_-_alice_free:1.0.17:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:team_impact_ti_blog_system_module:_nil_`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-fusion:world_of_warcraft_tracker_infusion_module:2.0`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:advanced_classified_module:-`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:autohtml_module:-`,
        fs:  `cpe:2.3:a:zed_shaw:mongrel:0.3.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:downloads_module:8.0`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:downloadsplus_module:-`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:eboard_module:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(4\)m2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:emporium_module:-`,
        fs:  `cpe:2.3:a:dell:openmanage_cd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:ev:-`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:iframe_module:-`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:inp:-`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:mermaid_module:-`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:mobile_entertainment_module:-`,
        fs:  `cpe:2.3:a:netscape:professional_services_ftpserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:myheadlines:-`,
        fs:  `cpe:2.3:a:microsoft:word:2002:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:news_module:-`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:php-nuke:-`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:platinum:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:pool_module:-`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:19.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:satel_lite:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-nuke:sections_module:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(3\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-proxima:php-proxima:-`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-proxima:php-proxima:6.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php-sqrl_project:php-sqrl:-`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php.s3.to:php-i-board:1.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.5:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php.s3.to:php-i-board:1.1`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php.s3.to:php-i-board:1.2`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php.s3.to:tree_bbs:2002%2f09%2f23`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php.s3.to:tree_bbs:2003%2f06%2f17`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:alpha5:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:php.s3.to:tree_bbs:2003%2f07%2f07`,
        fs:  `cpe:2.3:a:skype:skype:1.3.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php.s3.to:tree_bbs:2004%2f11%2f23`,
        fs:  `cpe:2.3:o:huawei:honor_4c_firmware:chm-tl00hc00_b535:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php.s3.to:tree_bbs:2009%2f06%2f22`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00-10:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php_font_lib_project:php_font_lib:0.3`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php_ireport_project:php_ireport:1.0`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php_kobo:photo_gallery_cms_free:1.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:php_kobo:photo_gallery_cms_free:1.0.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpace:samswhois:1.1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpace:samswhois:1.4.2.3`,
        fs:  `cpe:2.3:a:microsoft:visio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.2.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.2.2`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.2.3`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.2.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.3.0`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.3.1`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.3.1:fix01`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.3.1:fix02`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.3.2`,
        fs:  `cpe:2.3:h:intel:server_board_sc5400ra:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1-14`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.19.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1-14:fix01`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1-14:fix02`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1-14:fix03`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1-14:fix05`,
        fs:  `cpe:2.3:a:autodesk:design_review_2008:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1-14:fix06`,
        fs:  `cpe:2.3:a:digium:asterisk:13.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1.14`,
        fs:  `cpe:2.3:a:opsview:opsview:4.2:-:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1.15`,
        fs:  `cpe:2.3:a:ca:network_discovery_gateway:2.0.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpalbum:phpalbum:0.4.1.16`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phparena:panews:2.0b4`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpbb:phpbb:3.0.12`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpblogger:php-blogger:-`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpblogger:php-blogger:2.2.5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpblogger:php-blogger:2.2.7`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpbridges_dev_team:phpbridges:-`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_universal_restore:10.0.13762:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.1.1`,
        fs:  `cpe:2.3:a:searchblox:searchblox:6.2:build_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.1.2`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_anti-spyware:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.2.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.2.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.3.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.3.2`,
        fs:  `cpe:2.3:a:percipientstudios:imagen:2.5.2:-:*:*:*:umbraco_cms:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.4.1`,
        fs:  `cpe:2.3:a:intel:network_connections:13.2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.4.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.248.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.4.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.10.027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.4.4`,
        fs:  `cpe:2.3:a:emc:networker:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.4.5`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.5.1`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_server:3.6:ece:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.5.2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.0.1198:online_windows_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.5.3`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.6.1`,
        fs:  `cpe:2.3:o:novell:netware:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.6.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.1`,
        fs:  `cpe:2.3:a:usebb:usebb:0.6:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.2`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.3`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.4`,
        fs:  `cpe:2.3:a:teradata:data_connector:13.10.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.20:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.6`,
        fs:  `cpe:2.3:a:nex-forms_lite_project:nex-forms_lite:2.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.8`,
        fs:  `cpe:2.3:a:apache:subversion:0.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.7.9`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.8.1`,
        fs:  `cpe:2.3:h:seagate:blackarmor_nas_220:st320005lsa10g-rk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.8.2`,
        fs:  `cpe:2.3:a:teradata:performance_monitor:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.8.3`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-352:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.8.4`,
        fs:  `cpe:2.3:a:boa:boa:0.94.14.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.8.5`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1.0sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.2`,
        fs:  `cpe:2.3:a:anonymous_posting_project:anonymous_posting:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.3`,
        fs:  `cpe:2.3:o:apple:iphone_os:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p129:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.5`,
        fs:  `cpe:2.3:a:citrix:xenclient_xt:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.6`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.88:-:*:*:esx:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.7`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:0.9.9`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:1.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:1.0.1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:1.0.2`,
        fs:  `cpe:2.3:a:perl:perl:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:1.0.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.0:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcheckz:phpcheckz:1.1.0`,
        fs:  `cpe:2.3:a:cmu:isilk:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpcms:guesbook_module:-::~~~phpcms~~`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpdocx:phpdocx:-`,
        fs:  `cpe:2.3:h:ibm:iseries_as_400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpenter:php_enter:-`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.11:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpexcel_project:phpexcel:1.7.9`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpexcel_project:phpexcel:1.8.0`,
        fs:  `cpe:2.3:a:phpmoneybooks:phpmoneybooks:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpfox:phpfox:3.6.0`,
        fs:  `cpe:2.3:a:actividentity:activcard_gold_for_cac_feature_pack:3.01.1076.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpfox:phpfox:3.7.3`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.2:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpfox:phpfox:3.7.4`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpfox:phpfox:3.7.5`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpipam:phpipam:1.1.010`,
        fs:  `cpe:2.3:a:localsense:localsense:1.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:phpipam:phpipam:1.2`,
        fs:  `cpe:2.3:h:xerox:copycentre_c65:1.001.02.0715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpjabbers:appointment_scheduler:2.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpjabbers:event_booking_calendar:2.0`,
        fs:  `cpe:2.3:a:tamrielma:skyrim_map:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:phpjabbers:vacation_rental_script:-`,
        fs:  `cpe:2.3:a:cisco:ids_sensor_software:4.0\(1\)e0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpkit:phpkit:1.6.6`,
        fs:  `cpe:2.3:a:google:v8:3.12.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.6.5`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.7.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.7.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.8.2`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.8.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.8.12`,
        fs:  `cpe:2.3:a:cisco:secure_acs_for_windows_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.1`,
        fs:  `cpe:2.3:a:samba:samba:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.2`,
        fs:  `cpe:2.3:a:google:chrome:0.2.149.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.3`,
        fs:  `cpe:2.3:a:webmin:usermin:1.370:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.4`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0054:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.12.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.7`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.8`,
        fs:  `cpe:2.3:a:microsoft:ie:5.50.4030.2400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.9`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.10`,
        fs:  `cpe:2.3:a:cisco:finesse:9.1\(1\)_su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.11`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.12`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.13`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.263:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.14`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.59:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.15`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.16`,
        fs:  `cpe:2.3:h:marconi:esr-5000_enterprise_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.17`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.18`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.395:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.19`,
        fs:  `cpe:2.3:a:redhat:kernel_doc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.10.20`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.07.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.11.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.11.3`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.11.6`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.009.20077:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.11.7`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.11.8`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.244:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.11.9`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:2000:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.11.10`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:2.11.11`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:3.0.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.3:ea9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:3.0.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:3.0.2`,
        fs:  `cpe:2.3:a:divx:divx_web_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:3.0.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:3.0.4`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:3.0.5`,
        fs:  `cpe:2.3:a:xscreensaver_project:xscreensaver:5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist:phplist:3.0.6`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phplist_integration_project:phplist_integration:6.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.15:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmailer_project:phpmailer:5.2.13`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.15.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.10::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.11::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.11.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.12::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.13::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.14::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.15::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.16::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.17::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.18::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:hp:webproxy:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.19::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.20::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.21::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:nuuo:crystal:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.22::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:openttd:openttd:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.23::~~~keepintouch~~`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d33:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.24::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.25::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.2.2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.26::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.7:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.27::~~~keepintouch~~`,
        fs:  `cpe:2.3:o:cisco:catos:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.28::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.29::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:hulihanapplications:diamondlist:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.30::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.31::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:progress:webspeed:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.32::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.33::~~~keepintouch~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.34::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.35::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.36::~~~keepintouch~~`,
        fs:  `cpe:2.3:h:motorola:razr_hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.37::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.38::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.39::~~~keepintouch~~`,
        fs:  `cpe:2.3:o:google:android:2.2:rev1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.40::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.41::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:ibm:db2:10.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.42::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.405.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmanufaktur:kitform:0.43::~~~keepintouch~~`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmemcachedadmin_project:phpmemcachedadmin:1.2.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmoneybooks:phpmoneybooks:1.0.2`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmoneybooks:phpmoneybooks:1.0.4`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router_firmware:1.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.0`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.2`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.5`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.6`,
        fs:  `cpe:2.3:a:hp:photo_and_imaging_software:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.6:a`,
        fs:  `cpe:2.3:a:apache:mod_perl:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.7`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.0.8`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.1`,
        fs:  `cpe:2.3:h:lanier:pcl6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2`,
        fs:  `cpe:2.3:a:vmware:workstation:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.1`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.3`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.4`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:sr_4.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.5`,
        fs:  `cpe:2.3:a:lightscribe:lightscribe:1.4.84.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.6`,
        fs:  `cpe:2.3:a:emulex:common_san_management:30.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.540:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.8`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.9`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.9.1`,
        fs:  `cpe:2.3:a:openstack:keystone:2014.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.9.2`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.9.3`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.9.4:b`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.9.4:c`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.527:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.2.9.5`,
        fs:  `cpe:2.3:a:plone:plone:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:1.3:alpha`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.0`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.1.0`,
        fs:  `cpe:2.3:a:mahasna_batik_project:mahasna_batik:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.1.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.1.2`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.2.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.2.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.2.2`,
        fs:  `cpe:2.3:h:ibm:security_access_manager_appliance:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.3.0`,
        fs:  `cpe:2.3:a:smarttech:smart_board_software:9.1.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.4.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.5.0`,
        fs:  `cpe:2.3:a:trapster:trapster:4.3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.5.1`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.08b77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.5.2`,
        fs:  `cpe:2.3:a:unicreditgroup:unicredit_investors:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.6.0`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.7.0`,
        fs:  `cpe:2.3:a:mobiledeluxe:big_win_slots_-_slot_machines:1.11.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.7.1`,
        fs:  `cpe:2.3:a:gnu:readline:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.7.12.11.7.1`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.8.0`,
        fs:  `cpe:2.3:a:apache:hadoop:0.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.9.0`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.9.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.9.2`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.9.1:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.9.3`,
        fs:  `cpe:2.3:a:python-requests:requests:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.9.4`,
        fs:  `cpe:2.3:a:python:python:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.9.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.9.6`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.10.0`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:2.11.10.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.0.0`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf241a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.0.0:alpha`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.0.0:beta`,
        fs:  `cpe:2.3:a:tridium:niagra_ax_framework:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.0.0:rc1`,
        fs:  `cpe:2.3:a:solarwinds:tftp_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.0.1`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.0.1:rc1`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.0.1.1`,
        fs:  `cpe:2.3:a:kishore_asokan:kish_guest_posting_plugin:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.0`,
        fs:  `cpe:2.3:a:altiris:power_management_agent:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.0:beta1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p216:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.1`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.1:rc1`,
        fs:  `cpe:2.3:a:goforandroid:go_message_widget:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.2`,
        fs:  `cpe:2.3:a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.4.1:2:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.2:rc1`,
        fs:  `cpe:2.3:a:hp:digital_sending_software:4.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.3`,
        fs:  `cpe:2.3:o:yahama:rta55i:4.06.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.3:rc1`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.3.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.3.2`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:1.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.4`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.4:rc2`,
        fs:  `cpe:2.3:a:symantec:im_manager:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.5`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd336a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.1.5:rc1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.2.0`,
        fs:  `cpe:2.3:a:sympa:sympa:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.2.0:beta1`,
        fs:  `cpe:2.3:a:intel:processor_id_utility:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.2.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(2\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.2.1`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.2.1:rc1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.2.2`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:r55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.2.2:rc1`,
        fs:  `cpe:2.3:o:juniper:junos:15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.1.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.2.0`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.3.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.5.0.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.4.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20091218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.5.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.5.1`,
        fs:  `cpe:2.3:a:libssh:libssh:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.6`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.7`,
        fs:  `cpe:2.3:a:oracle:customer_relationship_management_technical_foundation:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.8`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.8.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.9.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.9.1`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.9.2`,
        fs:  `cpe:2.3:h:polycom:viewstation_fx_vs4000:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.3.10.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.0.0`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.1.0`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.2.0`,
        fs:  `cpe:2.3:a:piriform:defraggler:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.3.0`,
        fs:  `cpe:2.3:a:vantagelinguistics:answerworks_runtime:10.0.101:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.3.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.3:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.3.2`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.4.0`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.04n-2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.5.0`,
        fs:  `cpe:2.3:h:ibm:xiv_storage_system_gen3:2812-114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.6.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.5sq:3.5.2sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.7.0`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.7.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.8.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.9.0`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.10.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.10.1`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.10.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.4.11`,
        fs:  `cpe:2.3:a:sap:crystal_reports_for_visual_studio:12.51.0.240:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.1.0`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.2.0`,
        fs:  `cpe:2.3:a:cisco:service_portal:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.2.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.507:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.2.2`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.3.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:13.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.4`,
        fs:  `cpe:2.3:a:quick_edit_project:quick_edit:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.5`,
        fs:  `cpe:2.3:h:netgear:wg111v2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.6`,
        fs:  `cpe:2.3:a:perl:perl:5.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.7`,
        fs:  `cpe:2.3:a:roxio:creator_tools:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.7:rc1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p339:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.8`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:3.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.8:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.8.1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:3.5.8.2`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.0`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.0:rc2`,
        fs:  `cpe:2.3:a:php:php:7.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.0:rc3`,
        fs:  `cpe:2.3:a:digium:asterisk:11.4.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.1`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.2`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.3`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.2:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.4.1`,
        fs:  `cpe:2.3:a:digium:asterisk:13.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)eu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.5`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.03b36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.6`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.8`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.9`,
        fs:  `cpe:2.3:a:esri:arcgis_for_server:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10`,
        fs:  `cpe:2.3:a:x:libxvmc:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.2`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_7971g:8.0\(4\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.3`,
        fs:  `cpe:2.3:a:netkit-ftp:netkit_ftp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd338a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.5`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.6`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.3502.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.8`,
        fs:  `cpe:2.3:a:yahoo:yui:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.9`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:b.02.02.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.10`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.11`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_firmware:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.12`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.13`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.11:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.14`,
        fs:  `cpe:2.3:a:gwmicro:window-eyes:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.15`,
        fs:  `cpe:2.3:a:perl:perl:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.16`,
        fs:  `cpe:2.3:a:wysigot:wysigot:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.17`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.0.10.18`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.1`,
        fs:  `cpe:2.3:a:file_project:file:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.5`,
        fs:  `cpe:2.3:a:opsview:opsview:3.14:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.6`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.7`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.8`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.9`,
        fs:  `cpe:2.3:a:pgp:universal_server:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.10`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.11`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_management_server:11.0.17318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.12`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.13`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.14`,
        fs:  `cpe:2.3:a:veritas:netbackup:4.5.0:mp4:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.14.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.14.3`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.1.14.6`,
        fs:  `cpe:2.3:h:cisco:cache_engine_550:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/o:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.1`,
        fs:  `cpe:2.3:a:phpdocx:phpdocx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.2`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.3`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.5`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.7.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)xk2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.9.1`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:12.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.10.1`,
        fs:  `cpe:2.3:a:curtis_galloway:exif:0.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.11`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.13.1`,
        fs:  `cpe:2.3:a:yahoo:messenger:9.0.0.1912:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.2.13.2`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:313.30:-:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.3`,
        fs:  `cpe:2.3:a:hp:button_manager:1.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.4`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-02-23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.5`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.6`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.7`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.8`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.9`,
        fs:  `cpe:2.3:a:hp:event_monitoring_service:a.04.20.23.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.10`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp4:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.11`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.20m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.12`,
        fs:  `cpe:2.3:h:huawei:vcn500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.3.13`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.0`,
        fs:  `cpe:2.3:a:conky:conky:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.1`,
        fs:  `cpe:2.3:a:iconics:bizviz:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.1.1`,
        fs:  `cpe:2.3:a:oracle:database_server:11.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.2`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.3`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.4`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.6`,
        fs:  `cpe:2.3:a:hp:trayapp:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.6.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.7`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.9`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.10`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.11`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.13.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.12`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.13`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.13.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.14.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.1`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.0:beta:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:th:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.3`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.4`,
        fs:  `cpe:2.3:a:samba:samba:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.5`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.6`,
        fs:  `cpe:2.3:a:sun:jre:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.7`,
        fs:  `cpe:2.3:o:yahama:rta55i:4.06.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.8`,
        fs:  `cpe:2.3:a:freedomscientific:jaws:8.0.2173.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.4.15.9`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.3:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.0`,
        fs:  `cpe:2.3:h:foundrynet:fes_4802_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.0:beta1`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.0:beta2`,
        fs:  `cpe:2.3:a:ubcd4win:ubcd4win:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.0:rc1`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_internet_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.0.1`,
        fs:  `cpe:2.3:a:sun:cluster:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.0.2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.1`,
        fs:  `cpe:2.3:a:apache:solr:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.2`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.3`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.3.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.4`,
        fs:  `cpe:2.3:a:datawatch:monarch:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.4.1`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.5.5`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.598.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.0:alpha1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.262.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.0:rc2`,
        fs:  `cpe:2.3:a:wp_ultimate_email_marketer_project:wp_ultimate_email_marketer:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.1`,
        fs:  `cpe:2.3:a:labtech_software:labtech:55.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.2`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.14.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.3`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyadmin:phpmyadmin:4.6.5`,
        fs:  `cpe:2.3:h:cisco:catalyst_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.0`,
        fs:  `cpe:2.3:a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.0.1a`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.1.0`,
        fs:  `cpe:2.3:o:siemens:scalance_x200irt_firmware:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.1.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.1.2`,
        fs:  `cpe:2.3:h:brickom:ob-100ae:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.1.3`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.1.4`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.1.4a`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.1.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p254:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.2.0`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.2.1`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.2.2`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-50-\/c:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.2.3`,
        fs:  `cpe:2.3:o:raritan:px:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.2.4`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.2.5`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.2.5a`,
        fs:  `cpe:2.3:a:activestate:komodo_edit:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.2.5b`,
        fs:  `cpe:2.3:a:serf_project:serf:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:54.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.1`,
        fs:  `cpe:2.3:a:cisco:unified_ccx_historical_reports:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.2`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.4`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak_classic:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.6`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.7`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.8`,
        fs:  `cpe:2.3:a:clamav:clamav:0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.9`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.9:pl1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.349:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.10`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.11`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.13`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.3.14`,
        fs:  `cpe:2.3:a:raritan:power_iq:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4`,
        fs:  `cpe:2.3:a:adobe:setup:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4:alpha1`,
        fs:  `cpe:2.3:a:nextit:activeagent:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4:alpha2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.0`,
        fs:  `cpe:2.3:a:ibm:smartcloud_provisioning:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.0a`,
        fs:  `cpe:2.3:a:redhat:libtirpc:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.2`,
        fs:  `cpe:2.3:a:nedprod:nedmalloc:1.10:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.4`,
        fs:  `cpe:2.3:a:arraynetworks:ssl_vpn_client:840264:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.5`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.6`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.7`,
        fs:  `cpe:2.3:o:windriver:vxworks:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.8`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.9`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:2008.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.10`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.4.11`,
        fs:  `cpe:2.3:a:optipng:optipng:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:6.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:alpha1`,
        fs:  `cpe:2.3:o:debian:debian_linux:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:alpha2`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_internet_server:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:beta1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:beta2`,
        fs:  `cpe:2.3:a:suse:suse_linux_school_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:beta3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:rc1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:rc2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:rc3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:rc4`,
        fs:  `cpe:2.3:a:omeka:omeka:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5:rc5`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.0`,
        fs:  `cpe:2.3:a:basercms:basercms:3.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_management_framework:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.3`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.4`,
        fs:  `cpe:2.3:a:sonicwall:aventail_access_manager:10.52.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.5`,
        fs:  `cpe:2.3:o:cisco:headend_system_release:i4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.6`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.7`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.8`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.5.9`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.0`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2-p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.1`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.2`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:8.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.4`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.5`,
        fs:  `cpe:2.3:a:emc:powerpath:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.6`,
        fs:  `cpe:2.3:a:taxonomy_accordion_project:taxonomy_accordion:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.7`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.9`,
        fs:  `cpe:2.3:h:cisco:7300_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.10`,
        fs:  `cpe:2.3:a:ibm:sametime:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.11`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:1.6.12`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.0`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.1`,
        fs:  `cpe:2.3:o:siemens:scalance_x-200_series_firmware:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.2`,
        fs:  `cpe:2.3:a:hp:care_pack_products:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.5`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.6`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5580_firmware:v28.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.7`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.8`,
        fs:  `cpe:2.3:a:apple:xcode:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.9`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r5_p1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.10`,
        fs:  `cpe:2.3:o:cisco:ios:11.2p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.11`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2009:13.0.844.64:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.12`,
        fs:  `cpe:2.3:a:devicelock:devicelock:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.13`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.14`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.14-25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.15`,
        fs:  `cpe:2.3:a:emc:navisphere_command_line_interface:28.0.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.16`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.10.1002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.0.17`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.5.0`,
        fs:  `cpe:2.3:h:lexmark:x86x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.5.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.5.2`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.5.3`,
        fs:  `cpe:2.3:h:dell:latitude_e5520:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.5.4`,
        fs:  `cpe:2.3:a:piwik:piwik:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.5.5`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration:9.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.5.6`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.5.7`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.0`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.25-73.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.1`,
        fs:  `cpe:2.3:a:hp:hppiofiles:1.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.2`,
        fs:  `cpe:2.3:a:ibm:security_qradar_incident_forensics:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1\(2.48\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.4`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.5`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.6`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.7`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)ya2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.9`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.10`,
        fs:  `cpe:2.3:o:raritan:px:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.11`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.1:rev33197:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.12`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.13`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.14`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.15`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.16`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.17`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.6.18`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yf4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.0`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.2`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.2.148.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.3`,
        fs:  `cpe:2.3:h:cisco:airespace_4000_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.4`,
        fs:  `cpe:2.3:a:emc:networker:7.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.6`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.7`,
        fs:  `cpe:2.3:a:atlassian:jira:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.8`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.7.9`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.8.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.535:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.8.1`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.8:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.8.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.8.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.8.4`,
        fs:  `cpe:2.3:a:opnet:sp_guru_network_planner_documentation:15.0.0.8622:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.8.5`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmyfaq:phpmyfaq:2.9.6`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpmysite:phpmysite:-`,
        fs:  `cpe:2.3:h:hp:color_laserjet_m575dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:myheadlines:4.3.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:5.6`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.2:mp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:6.5`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.0`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.2`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.4`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.5`,
        fs:  `cpe:2.3:a:hp:alm_synchronizer:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.6`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.7`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.20.175:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.8`,
        fs:  `cpe:2.3:a:vmware:remote_console_plug-in:2.5.0.122581:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:7.9`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:8.0`,
        fs:  `cpe:2.3:a:ibm:iss_internet_scanner:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:8.0.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(3a\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:php-nuke:8.3`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.0.1`,
        fs:  `cpe:2.3:h:lenovo:thinkserver_rd550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8a\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.2`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.3`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.3.1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.4`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.5`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a3:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:5.6`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:7.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:6.0`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:58.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:6.5`,
        fs:  `cpe:2.3:a:roxio:creator:10.3:*:*:*:business:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:6.6`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:6.7`,
        fs:  `cpe:2.3:a:gnu:gdb:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:6.8`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_apppack:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:6.9`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-50-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.2\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.1`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.2`,
        fs:  `cpe:2.3:h:hp:laserjet_m9040_mpf:cc394a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.3`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.344:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.4`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.5`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-backup:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.6`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.7`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.8`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:7.9`,
        fs:  `cpe:2.3:a:microsoft:windows-nt:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:8.0`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:phpnuke:8.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:submit_news_module:-`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpnuke:web_links_module:-`,
        fs:  `cpe:2.3:a:novell:iprint:4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phponlinechat:phponlinechat:3.0`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phppgadmin_project:phppgadmin:5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phppgadmin_project:phppgadmin:5.0.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.d0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phppgadmin_project:phppgadmin:5.0.2`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.8.777:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phppgadmin_project:phppgadmin:5.0.3`,
        fs:  `cpe:2.3:h:lorextechnology:edge\&#43;:lh320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phppgadmin_project:phppgadmin:5.0.4`,
        fs:  `cpe:2.3:a:luracast:restler:1.1.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:phpscriptlerim:php_scriptlerim_who%27s_who:-`,
        fs:  `cpe:2.3:a:oracle:micros_cwdirect:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpspot:php_bbs:-`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpspot:php_bbs_ce:-`,
        fs:  `cpe:2.3:h:dell:idrac7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpspot:php_bbs_css:-`,
        fs:  `cpe:2.3:a:apache:spamassassin:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpspot:php_bbs_image_capture:-`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpspot:php_bbs_rss_builder:-`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.50.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpspot:webshot:-`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpthumb_project:phpthumb:1.7.11`,
        fs:  `cpe:2.3:h:apple:imac:ma199xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phptroubleticket:php_trouble_ticket:2.2`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.0`,
        fs:  `cpe:2.3:a:python:python:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.1`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.2`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg250a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.4`,
        fs:  `cpe:2.3:h:f5:big-ip_3410:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.5`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.6`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.7`,
        fs:  `cpe:2.3:a:pluxml:pluxml:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.10`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.11`,
        fs:  `cpe:2.3:a:gnome:glib:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpunit_project:phpunit:3.3.12`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpvibe:phpvibe:4.20`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpvms:phpvms:2.1.934`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpwebscripts:easy_banner_free:2009.05.18`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpwiki_project:phpwiki:1.5.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpyabs:phpyabs:0.0.1`,
        fs:  `cpe:2.3:a:hp:software_jre:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpyabs:phpyabs:0.1.1`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phpyabs:phpyabs:0.1.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:juvia:-`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_endpoint_manager:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.1`,
        fs:  `cpe:2.3:a:livezilla:livezilla:4.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.2`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.3`,
        fs:  `cpe:2.3:a:path_breadcrumbs_project:path_breadcrumbs:7.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.4`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.5`,
        fs:  `cpe:2.3:o:sun:sunos:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.6`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.7`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.8`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.9`,
        fs:  `cpe:2.3:h:polycom:hdx_4500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.10`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.11`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.12`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.13`,
        fs:  `cpe:2.3:a:digia:qt:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.14`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.15`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.17`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.18`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.19`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:qa1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:3.0.20`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:4.0.1`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:4.0.2`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:4.0.3`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:4.0.4`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b_pk2_bl22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:4.0.5`,
        fs:  `cpe:2.3:a:videowhisper:live_streaming_integration_plugin:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:4.0.6`,
        fs:  `cpe:2.3:a:apple:quicktime:6.2.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusion:passenger:4.0.36`,
        fs:  `cpe:2.3:a:openttd:openttd:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:4.0.59`,
        fs:  `cpe:2.3:a:netscape:navigator:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.0`,
        fs:  `cpe:2.3:a:pivotal_software:redis:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.0:beta1`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.0:beta2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.0:beta3`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.0:rc1`,
        fs:  `cpe:2.3:h:axis:panorama_ptz_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.0:rc2`,
        fs:  `cpe:2.3:a:schneider-electric:micom_s1_studio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.2`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.3`,
        fs:  `cpe:2.3:a:haxx:curl:7.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.4`,
        fs:  `cpe:2.3:a:microsoft:iis:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.5`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.6`,
        fs:  `cpe:2.3:a:umich:libgssglue:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.8`,
        fs:  `cpe:2.3:a:gnome:glib:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.9`,
        fs:  `cpe:2.3:a:samba:samba:3.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.10`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.11`,
        fs:  `cpe:2.3:o:novell:netware:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.13`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.14`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.0:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.15`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.16`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.17`,
        fs:  `cpe:2.3:a:ibm:rational_appscan_source:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.18`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.19`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.20`,
        fs:  `cpe:2.3:h:hp:proliant_sl160z_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:phusionpassenger:phusion_passenger:5.0.21`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:physics_chemistry_biology_quiz_project:physics_chemistry_biology_quiz:1.8::~~~android~~`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:physicsforums:physics_forums:3.9.22::~~~android~~`,
        fs:  `cpe:2.3:a:hp:sitescope:11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pi-soft:spoonftp:1.0.0.12`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:picketlink:picketlink:2.7.0:cr3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pico:picopublisher:2.0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:picsart:picsart_-_photo_studio:4.5.5::~~~android~~`,
        fs:  `cpe:2.3:o:siemens:scalance_x-200_series_firmware:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pictobrowser_project:pictobrowser:0.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:1.0`,
        fs:  `cpe:2.3:a:isc:bind:9.2.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.0.0`,
        fs:  `cpe:2.3:a:php:php:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.0.1`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.0.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.1.0`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.1.1`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_standalone:5.0.0.470252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.2.0`,
        fs:  `cpe:2.3:h:schneider_electric:sage_2300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.2.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.2.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.3.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.3.1`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.4.0`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.4.1`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_agent:4.1.1.6534:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.4.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.4.3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.2`,
        fs:  `cpe:2.3:a:apache:poi:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.3`,
        fs:  `cpe:2.3:a:werner_baumann:davfs2:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:fi:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.5`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.6`,
        fs:  `cpe:2.3:a:zend:zendto:4.05-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.7`,
        fs:  `cpe:2.3:a:google:chrome:11.0.699.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.8`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.4p5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.5.9`,
        fs:  `cpe:2.3:a:rsa:authentication_manager:7.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.6.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.9.0.1380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.6.1`,
        fs:  `cpe:2.3:a:apache:roller:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.6.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.6.3`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.6.4`,
        fs:  `cpe:2.3:a:polycom:cma_system_software:6.0.1:system_patch_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.6.5`,
        fs:  `cpe:2.3:a:novell:bordermanager:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.6.6`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:4.6\(2\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.1`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.2`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.4`,
        fs:  `cpe:2.3:a:mybb:mybb:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p90:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.6`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:7.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.7`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.8`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.9`,
        fs:  `cpe:2.3:o:sagem:f\@st_2604_firmware:253180972b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.10`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.7.11`,
        fs:  `cpe:2.3:a:emc:task_space:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.8.0`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.1.629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.9.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:libpurple:2.10.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:-`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.0.0`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.0.1`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5a\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.1.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(4e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.1.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.2.0`,
        fs:  `cpe:2.3:a:david_king:vino:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.2.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.2.2`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:09:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.3.0`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.3.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.4.0`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.4.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.605.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.4.2`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.4.3`,
        fs:  `cpe:2.3:a:zeenshare_project:zeenshare:1.0.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.0`,
        fs:  `cpe:2.3:o:huawei:s5310hi_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.1`,
        fs:  `cpe:2.3:o:hp:apollo_domain_os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.2`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.3.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.4`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.5`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(20\)aa4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.6`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.7`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.8`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:2.0.2:rev28693:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.5.9`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.6.0`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.05.07s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.6.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.6.2`,
        fs:  `cpe:2.3:a:vmware:tools:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.6.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.7.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.6.5`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.6.6`,
        fs:  `cpe:2.3:a:fotoschilenas:akne_ernahrung:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.1`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.3`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.4`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.5`,
        fs:  `cpe:2.3:a:divx:codec:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.6`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.7`,
        fs:  `cpe:2.3:a:apple:safari:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.8`,
        fs:  `cpe:2.3:a:thinkshout:mandrill:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.9`,
        fs:  `cpe:2.3:a:ibm:ecolab:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.10`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.7.11`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.8.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.9.0`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.0`,
        fs:  `cpe:2.3:h:hp:laserjet_m4345_mfp:cb425a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.1`,
        fs:  `cpe:2.3:h:cisco:email_security_appliance:9.1.0-032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.2`,
        fs:  `cpe:2.3:a:citrix:secure_gateway:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.3`,
        fs:  `cpe:2.3:a:francisco_cifuentes:vote_for_tt_news:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.4`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.208:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.6`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.7`,
        fs:  `cpe:2.3:a:fiddler2:fiddler2:2.3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.8`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:3.9.4:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:pidgin:pidgin:2.10.9`,
        fs:  `cpe:2.3:a:omeka:omeka:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pimcore:pimcore:1.4.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pimcore:pimcore:1.4.9`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pimcore:pimcore:1.5.0`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pimcore:pimcore:2.1.0`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pimcore:pimcore:2.2.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.21.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pimpstore:aprende_a_meditar:1::~~~android~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pimpstore:esercizi_per_le_donne:1::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:xml_core_services:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pineapp:mail-secure:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.21:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pineapp:mail-secure:3.69`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pineapp:mail-secure:3.70`,
        fs:  `cpe:2.3:a:yahoo:yui:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pineapp:mail-secure_5099sk:-`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pingidentity:pingfederate:6.10.1`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:discapi:2.10.57`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.008:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:instant_dvd_recorder:1.60.110`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4:rc_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:instant_dvd_recorder:2.0.88`,
        fs:  `cpe:2.3:a:novell:iprint:5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:instant_dvd_recorder:2.6.0.118`,
        fs:  `cpe:2.3:a:unisys:sma_sam_and_supporting_services:4.25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:rapid:1.0.2`,
        fs:  `cpe:2.3:o:tp-link:tl-wr841n_firmware:3.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:studio:10.5`,
        fs:  `cpe:2.3:a:samba:samba:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:studio:11.0`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:studio:11.0.0.0`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:07-01\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:studio:11.0.13::~~ultimate~~~`,
        fs:  `cpe:2.3:a:siemens:simatic_s7_cfc:8.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:studio:12.1.3.6605`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:pinnaclesys:studio:14.0.0.7255`,
        fs:  `cpe:2.3:a:google:chrome:10.0.640.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pinssible:phonegram_-_instagram_download:1.9.5::~~~android~~`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pintsized:synx_addictive_puzzle_game:1::~~~android~~`,
        fs:  `cpe:2.3:a:mahara:mahara:16.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pip-installer:pip:1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pip-installer:pip:1.0.1`,
        fs:  `cpe:2.3:h:hp:3com_switch:5500g-ei_sfp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pip-installer:pip:1.0.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pip-installer:pip:1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pip-installer:pip:1.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pip-installer:pip:1.2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:10.0.0:beta1:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pippin_williamson:font_uploader:1.2.4`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:2.27`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1009:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:2.31`,
        fs:  `cpe:2.3:h:cabletron:6h302-48:5.06.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:2.33`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:2.34`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:2.36`,
        fs:  `cpe:2.3:a:levelteninteractive:content_analysis:6.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.1`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.0\(2a\)es40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.4`,
        fs:  `cpe:2.3:a:nextapp:echo:3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.5`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.6`,
        fs:  `cpe:2.3:h:juniper:mag4610_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.10`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.11`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.26.1888`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.3.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.27.1900`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:001p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:3.28.1913`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.00.4064`,
        fs:  `cpe:2.3:a:citrix:password_manager_plugin:4.6.270.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.01.4093`,
        fs:  `cpe:2.3:a:canonical:php5:5.3.5-1ubuntu7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.02.4115`,
        fs:  `cpe:2.3:a:janetter:janetter:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.03.4151`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.04.4197`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.05.4250`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.06.4324`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.07.4369`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.08.4428`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.09.4471`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.10.4570`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.11.4619`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.12.4657`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.2:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.13.4693`,
        fs:  `cpe:2.3:a:kde:plasma-workspace:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.14.4707`,
        fs:  `cpe:2.3:a:sendcard:sendcard:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.15.4725`,
        fs:  `cpe:2.3:a:wordpress:plugin_newsletter_plugin:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.16.4763`,
        fs:  `cpe:2.3:h:cisco:nexus_3548:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.17.4808`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.18.4844`,
        fs:  `cpe:2.3:a:cisco:customer_response_solutions_patch_install:1.1.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:4.19.4867`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.0:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:5.00.5050`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:5.01.5075`,
        fs:  `cpe:2.3:a:cisco:okena_stormwatch:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:ccleaner:5.02.5101`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r9:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:defraggler:1.20`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:piriform:recuva:1.41`,
        fs:  `cpe:2.3:a:kodak:image_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry:241`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1010:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry:242.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.5.2:devel:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.17`,
        fs:  `cpe:2.3:h:cisco:unified_ip_conference_station_7937g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.18`,
        fs:  `cpe:2.3:a:php:pear:1.2b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.19`,
        fs:  `cpe:2.3:a:hp:autonomy_ultraseek:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.20`,
        fs:  `cpe:2.3:a:emc:networker:8.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.21`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.3:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.22`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.23`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.25`,
        fs:  `cpe:2.3:a:idera:uptime_infrastructure_monitor:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.26`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.27`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.28`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.29`,
        fs:  `cpe:2.3:a:bundler:bundler:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.30`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.31`,
        fs:  `cpe:2.3:a:cisco:unity_connection:10.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.32`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.34`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.35`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.36`,
        fs:  `cpe:2.3:a:ibm:bootable_media_creator:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.37`,
        fs:  `cpe:2.3:a:symantec:client_security:1.0.1_build_8.01.434:mr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.38`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.15.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.6.39`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.12`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.13`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.14`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.15`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.16`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.17`,
        fs:  `cpe:2.3:a:isc:inn:1.4unoff3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.18`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.19`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.0:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.7.20`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.29:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_elastic_runtime:1.8.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.2`,
        fs:  `cpe:2.3:a:nvidia:control_panel:276.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.4`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.5`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.7`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.8`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.9`,
        fs:  `cpe:2.3:a:apache:log4j:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.10`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.11`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.7.12`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_ops_manager:1.8.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.3.0`,
        fs:  `cpe:2.3:a:f5:big-ip_enterprise_manager:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.3.1`,
        fs:  `cpe:2.3:a:nvidia:control_panel:268.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.4.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.5.1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.6.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.545:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.7.0.2`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.7.0.3`,
        fs:  `cpe:2.3:h:nortel:ip_audio_conference_phone_2033:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.7.1`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.7.2`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.7.3`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:2.7.4.6`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.0.0`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:7.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.2.1:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.1.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.2.0`,
        fs:  `cpe:2.3:a:altiris:it_analytics:6.1.1050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.2.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p7_rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.3.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.3.0.1`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.4.0`,
        fs:  `cpe:2.3:a:ansys:mechanical:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.4.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.05.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)sx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa:3.7.0`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.5.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa_bosh:12.3`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa_bosh:15.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:cloud_foundry_uaa_bosh:16.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.0::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.20.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.1::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:vmware:player:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.2::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.3::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.4::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.5::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.6::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1063:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.7::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.8::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.9::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.10::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:horde:groupware:1.0.3:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.11::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.569.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.12::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.6:*:free:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.13::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:oracle:application_server:4.0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.14::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:ngemc:my_ngemc_account:1.153.0034:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.15::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.17::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:arcanadev:adtempus:3.00.0601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.5.18::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:cisco:remote_access_plugins_for_adaptive_security_appliance:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.0::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.1::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.2::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.3::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:python:python:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.4::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.5::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:digium:asterisk:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.6::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:webtrends:marketing_lab:8.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.7::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.8::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.9::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:gnome:gdk-pixbuf:2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.6.10::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.1:ea9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.7.0::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.7.2::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.7.3::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:mikiurl_wordpress_eklentisi_project:mikiurl_wordpress_eklentisi:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.7.4::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp1:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.7.5::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.431.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:1.7.6::~~~pivotal_cloud_foundry~~`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.1.0`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.1.1`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.2.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.3.1`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.4.0`,
        fs:  `cpe:2.3:h:hp:psc_2500_photosmart_all-in-one:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.4.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.5.0`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:10.04:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.5.1`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.6.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.6.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.7.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.7.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.8.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.8.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.8.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.8.3`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.8.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.8.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.8.6`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7960:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:2.8.7`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.0.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.0.1`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.0.2`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.0.3`,
        fs:  `cpe:2.3:a:ibm:lotus_symphony:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.1.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.09.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.1.1`,
        fs:  `cpe:2.3:o:huawei:te60_firmware:v100r001c10b022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.1.2`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:14.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.1.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.1.4`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.40.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.1.5`,
        fs:  `cpe:2.3:a:redhat:freeipa:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.2.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5b\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.2.1`,
        fs:  `cpe:2.3:h:hp:laserjet_p2055x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.2.2`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.5.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.2.3`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.2.4`,
        fs:  `cpe:2.3:h:hp:jf803a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.3.0`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.3.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.3.2`,
        fs:  `cpe:2.3:a:qemu:qemu:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)sn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.3.4`,
        fs:  `cpe:2.3:h:fortinet:fortigate-3040b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.3.5`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.3m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.4.0`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.4.1`,
        fs:  `cpe:2.3:h:cisco:content_services_switch_11506:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.4.2`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.4.3`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.4.4`,
        fs:  `cpe:2.3:a:emc:networker:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.5.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.5.2`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.2.05015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.5.3`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.5.4`,
        fs:  `cpe:2.3:a:livetecs:timeline:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.5.5`,
        fs:  `cpe:2.3:a:gnu:libtool:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.5.6`,
        fs:  `cpe:2.3:a:ibm:http_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.5.7`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.6.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.229:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.6.1`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.6.2`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.6.3`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:10.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.6.4`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:3.6.5`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq:4.1`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:rabbitmq_management:3.4.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:redis:2.8.0`,
        fs:  `cpe:2.3:a:schoolmation:schoolmation:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:redis:3.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:redis:3.0.1`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:redis:3.2.0`,
        fs:  `cpe:2.3:a:3com:3c16116-us:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:redis:3.2.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.268:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:redis:3.2.2`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:redis:3.2.3`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.0.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.0.1`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.0.2`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.0.3`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.0.4`,
        fs:  `cpe:2.3:a:enterasys:netsight_console:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.0.5`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.0.6`,
        fs:  `cpe:2.3:a:apache:ranger:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.0.7`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_client_set:06-70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.1.0`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.1.0:rc1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.1.0:rc2`,
        fs:  `cpe:2.3:a:samba:samba:4.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.1.1`,
        fs:  `cpe:2.3:h:supermicro:x9dr7-ln4f-jbod:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.1.2`,
        fs:  `cpe:2.3:o:cisco:rv110w_firmware:1.2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.1.3`,
        fs:  `cpe:2.3:h:unisys:libra_6300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.1.4`,
        fs:  `cpe:2.3:a:nero:waveeditor_help:5.0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.0`,
        fs:  `cpe:2.3:h:nortel:wlan_handset_2210:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.0:rc1`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.0:rc2`,
        fs:  `cpe:2.3:a:frandroid:forum_frandroid_beta:3.4.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.0:rc2-a`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.1`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.2`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.3`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.4`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.6`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.7`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.3sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.8`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.9`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.10`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.11`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.12`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.13`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.14`,
        fs:  `cpe:2.3:h:siemens:scalance_x202-2irt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.15`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.16`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.17`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:3.2.18`,
        fs:  `cpe:2.3:a:kishore_asokan:kish_guest_posting_plugin:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.0`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.0:rc1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.0:rc2`,
        fs:  `cpe:2.3:h:ibm:flex_system_manager_node_7955:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.1`,
        fs:  `cpe:2.3:a:canonical:software-properties:0.81.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.2`,
        fs:  `cpe:2.3:a:sap:netweaver:7.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(12a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.4`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0a3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.5`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.6`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.8`,
        fs:  `cpe:2.3:a:emc:unisphere:1.1:-:*:*:*:vmax:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.0.9`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_rich_text_editor:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.19:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.2`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_99:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.3`,
        fs:  `cpe:2.3:a:zenoss:zenoss:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.5`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.6`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.7`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.7.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.8`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.1.9`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.1`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.2`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.3`,
        fs:  `cpe:2.3:a:monotone:monotone:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.4`,
        fs:  `cpe:2.3:a:spip:spip:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.5`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.6.1871.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.1.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.8`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.2.9`,
        fs:  `cpe:2.3:h:cisco:sg500-52:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.3.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.4\(19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.3.1`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.3.2`,
        fs:  `cpe:2.3:a:synology:cloud_station:3.0-3111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.3.3`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_framework:4.3.4`,
        fs:  `cpe:2.3:a:sqlsentry:sql_sentry:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.1`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:unstable1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.2`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.3`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.8:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.4`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.5`,
        fs:  `cpe:2.3:a:microsoft:word_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.6`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.7`,
        fs:  `cpe:2.3:a:ows:scald:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.8`,
        fs:  `cpe:2.3:a:gajim:gajim:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.9`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:3.2.10`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:4.1.0`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:4.1.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:4.1.2`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:4.1.3`,
        fs:  `cpe:2.3:o:hp:ignite-ux:c.7.2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotal_software:spring_security:4.2.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.1.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.1.1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.1.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70-\/g:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.2.0`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.2.0:b1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.2.0:b2`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.2.0:rc`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.2.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.2.2`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.2.3`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.0.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.2.5`,
        fs:  `cpe:2.3:a:hp:destinations:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.3.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.3.2`,
        fs:  `cpe:2.3:a:hp:bpd_hpsu:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.3.3`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.3.5`,
        fs:  `cpe:2.3:a:freerdp_project:freerdp:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.3.6`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.3.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.3.8`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:4.0:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pivotx:pivotx:2.3.9`,
        fs:  `cpe:2.3:a:emc:symmetrix_8530:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.0.0:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.0.1`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.0.2`,
        fs:  `cpe:2.3:a:hp:loadrunner:9.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.1.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.2.0`,
        fs:  `cpe:2.3:h:nvidia:quadro_k1200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.2.1`,
        fs:  `cpe:2.3:o:microsoft:windows_10:1703:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.3.0`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r75.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.3.1`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb604xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.3.2`,
        fs:  `cpe:2.3:a:joe_haskins:og_manager_change:7.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.3.3`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.3.4`,
        fs:  `cpe:2.3:a:smartcatdesign:wp_contruction_mode:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.4.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.4.1`,
        fs:  `cpe:2.3:a:surveytracker:surveytracker:5.5:*:*:*:desktop:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.5.0`,
        fs:  `cpe:2.3:a:ati:catalyst_driver:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.5.1`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.5.2`,
        fs:  `cpe:2.3:a:ca:unicenter_software_delivery:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.6.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.6.1`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.7.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.7.1`,
        fs:  `cpe:2.3:a:merant:dimensions:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.7.2`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:1.7.3`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:5.5:u2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.0`,
        fs:  `cpe:2.3:a:safer_networking:filealyzer:1.6.0.4:*:beta:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg256a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.3`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.4`,
        fs:  `cpe:2.3:a:adobe:illustrator:16.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.5`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.6`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.5.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.7`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.8`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.9`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.0.10`,
        fs:  `cpe:2.3:a:php:php:5.4.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.1.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.1.1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.1.2`,
        fs:  `cpe:2.3:a:serf_project:serf:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.1.3`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.1.4`,
        fs:  `cpe:2.3:a:gnome:evolution:2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.1.5`,
        fs:  `cpe:2.3:h:tp-link:archer_c8_\(1.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.1.6`,
        fs:  `cpe:2.3:a:isc:inn:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.2.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.2.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.2.2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.2.3`,
        fs:  `cpe:2.3:a:google:chrome:14.0.803.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.2.4`,
        fs:  `cpe:2.3:a:schneider-electric:somachine:3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.2.5`,
        fs:  `cpe:2.3:o:d-link:dcs-5029l_firmware:1.12.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.3.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.3.1`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.3.2`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.3.4`,
        fs:  `cpe:2.3:a:dotclear:dotclear:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.3.5`,
        fs:  `cpe:2.3:a:microsoft:word:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.4.0`,
        fs:  `cpe:2.3:a:php:php:5.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.4.1`,
        fs:  `cpe:2.3:h:xerox:copycentre_c75:1.001.02.073:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.4.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.4.3`,
        fs:  `cpe:2.3:a:microsoft:telnet_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.4.4`,
        fs:  `cpe:2.3:a:node_access_user_reference_project:nodeaccess_userreference_module:6.x-3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.4.5`,
        fs:  `cpe:2.3:a:tom_wilkason:snackamp:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.4.6`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.4.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p219:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.5.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.5.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.6.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.6.1`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.6.2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.1.1219:online_windows_server_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.6.3`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.7:build120405:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.6.4`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.7.0:beta1`,
        fs:  `cpe:2.3:a:intel:network_connections:14.7.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.7.0:beta2`,
        fs:  `cpe:2.3:a:plone:plone:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.7.0:rc1`,
        fs:  `cpe:2.3:o:seil:bpv_4_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.7.0:rc2`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.7.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.7.2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.7.3`,
        fs:  `cpe:2.3:a:php:php:5.4.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwigo:piwigo:2.8.3`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1`,
        fs:  `cpe:2.3:a:profile2_privacy_project:profile2_privacy:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.1`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.4`,
        fs:  `cpe:2.3:a:novell:iprint:5.90:-:*:*:*:windows_7:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.5`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.6`,
        fs:  `cpe:2.3:h:hp:4_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.8`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.1.10`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.1`,
        fs:  `cpe:2.3:a:veritas:backup_exec_remote_agent:10.0.5484:sp1:windows_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.2`,
        fs:  `cpe:2.3:a:altiris:out_of_band_management_solution:6.2.1035:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gw_3241:2.1\(1.43\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.5`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.6`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.04.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.8`,
        fs:  `cpe:2.3:a:blaine_lang:filedepot:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.9`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.10`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.11`,
        fs:  `cpe:2.3:a:tnef_project:tnef:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.12`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(3\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.13`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.14`,
        fs:  `cpe:2.3:a:apache:solr:4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.16`,
        fs:  `cpe:2.3:a:deskshare:auto_ftp_manager:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.17`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.18`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:5.5:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.19`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:2.0.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.20`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.22`,
        fs:  `cpe:2.3:a:location_module_project:location:6.x-3.0:test3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.23`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.24`,
        fs:  `cpe:2.3:a:openstack:keystone:2014.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.25`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.26`,
        fs:  `cpe:2.3:a:dell:quickset:7.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.27`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.28`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.29`,
        fs:  `cpe:2.3:o:iij:seil\%2fturbo_firmware:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.30`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.31`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.32`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(10\)da4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.33`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.34`,
        fs:  `cpe:2.3:a:ixonos:checksum_tool:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.35`,
        fs:  `cpe:2.3:a:microsoft:malware_protection_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.36`,
        fs:  `cpe:2.3:a:luracast:restler:0.6.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.2.37`,
        fs:  `cpe:2.3:a:horde:imp:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4:rc1`,
        fs:  `cpe:2.3:a:icoasoft:potrace:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4:rc2`,
        fs:  `cpe:2.3:a:novell:netware_enterprise_web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4:rc3`,
        fs:  `cpe:2.3:o:hp:secure_os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4.1`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.2.6-5.sles10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4.1:rc1`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4.2`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.09.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4.3`,
        fs:  `cpe:2.3:a:ca:introscope_workstation:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4.4`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:398:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.4.5`,
        fs:  `cpe:2.3:a:blueman_project:blueman:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.5`,
        fs:  `cpe:2.3:a:citrix:hdx_mediastream_for_flash_server:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.5.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.5.2`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.5.3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20101129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.5.4`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.5.5`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.46.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.6`,
        fs:  `cpe:2.3:a:samba:samba:3.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.6.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.6.2`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.0.5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.6.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_express:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.6.3:rc1`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.6.3:rc2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc099a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.6.4`,
        fs:  `cpe:2.3:h:cisco:catalyst_6500_ws-x6380-nam:2.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.7`,
        fs:  `cpe:2.3:a:mysql:mysql:3.22.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.8`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.9`,
        fs:  `cpe:2.3:h:google:glass:xe6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:0.9.9`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.1`,
        fs:  `cpe:2.3:a:vmware:vrealize_operations:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.1.1`,
        fs:  `cpe:2.3:a:netapp:virtual_file_mangemer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.2`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.2.1`,
        fs:  `cpe:2.3:a:aol:aim:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.4`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine_clearswift:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.5`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ixb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.6`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.5\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.7`,
        fs:  `cpe:2.3:a:ross_burton:libsocialweb:0.25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.7.1`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.8`,
        fs:  `cpe:2.3:a:google:v8:3.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.8.1`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.8.2`,
        fs:  `cpe:2.3:h:hp:jg820a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.8.3`,
        fs:  `cpe:2.3:a:teklynx:label_matrix:8.60.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.8.4`,
        fs:  `cpe:2.3:a:gnu:cpio:2.5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.9.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.9.2`,
        fs:  `cpe:2.3:o:suse:suse_linux:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.10`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.10.1`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.11`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:1.11.1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.030_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik:2.14.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p325:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:piwik:piwik_mobile_2:2.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:nortel:pc_client_soft_phone_sip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixabay_images_project:pixabay_images:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sun:java_system_identity_manager:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.9.6`,
        fs:  `cpe:2.3:h:htc:droid_incredible:frf91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.10.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp1:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.12.0`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.14.0`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.03.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.16.0`,
        fs:  `cpe:2.3:a:debian:apt:0.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.16.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.23.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.16.4`,
        fs:  `cpe:2.3:h:cisco:spa_508g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.18.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.18.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3ys:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.18.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.20.0`,
        fs:  `cpe:2.3:a:google:v8:3.22.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.20.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.07:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.22.0`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.22.2`,
        fs:  `cpe:2.3:a:globeranger:dla_central_reporting_client:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.24.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.24.2`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administration_utility:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.24.4`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.26.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p445:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.26.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p304:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.28.0`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.6020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.28.2`,
        fs:  `cpe:2.3:a:omeka:omeka:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.30.0`,
        fs:  `cpe:2.3:o:cisco:staros:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.30.2`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixman:pixman:0.32.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixologic:zbrush:3.53`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixologic:zbrush:4.0`,
        fs:  `cpe:2.3:a:citrix:hdx_mediastream_for_flash_server:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pixologic:zbrush:4.2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1060.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzahut:pizza_hut:2.0.5::~~~android~~`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.55:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzahut:pizza_hut_japan_official_order_application:1.1.0:a:~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzahut:pizza_hut_japan_official_order_application:1.1.1:a:~~~android~~`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.3\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.0.2`,
        fs:  `cpe:2.3:a:mybb:mybb:1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.0.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.337:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.0.4`,
        fs:  `cpe:2.3:o:d-link:dsr-250_firmware:1.08b39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.1.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.1.1`,
        fs:  `cpe:2.3:a:sabreairlinesolutions:crew_management:2010.2.12.20008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.2.1`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.2.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.2.3`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)ya1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.3.1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.003:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.3.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.3.3`,
        fs:  `cpe:2.3:o:raritan:px:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pizzashack:rssh:2.3.4`,
        fs:  `cpe:2.3:a:gnu:bash:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pjtech:goverlan:2000_v3.3`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pkware:pkzip:-`,
        fs:  `cpe:2.3:a:kde:koffice:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pkware:pkzip:2.70`,
        fs:  `cpe:2.3:a:web2py:web2py:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pkware:pkzip:4.00`,
        fs:  `cpe:2.3:a:viewvc:viewvc:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pkware:pkzip:12.50.0014`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pkware:pkzip_for_windows:9.0.10`,
        fs:  `cpe:2.3:a:hp:color_laserjet_2500_toolbox:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pkware:pkzip_server_for_windows:12.10.8`,
        fs:  `cpe:2.3:a:schneider-electric:modbuscommdtm_sl:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:5.x-3.3`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:5.x-3.5`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:6.x-3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:6.x-3.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:3.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:6.x-3.6`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.6:epj:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:6.x-3.7`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.18.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:6.x-4.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:6.x-4.1`,
        fs:  `cpe:2.3:a:google:search_appliance_software:7.0.14.g.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plaatsoft:addressbook:6.x-4.2`,
        fs:  `cpe:2.3:a:cp_multi_view_event_calendar_project:cp_multi_view_event_calendar:1.0.1:*:*:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plainblack:webgui:6.8.8`,
        fs:  `cpe:2.3:h:hp:color_laserjet_4730_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plainblack:webgui:7.0.6`,
        fs:  `cpe:2.3:a:apache:wss4j:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plainblack:webgui:7.3.17`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plainblack:webgui:7.10.29`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:planetofthevapes:planet_of_the_vapes_forum:3.7.9::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:planex:brl-04cw:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:planex:brl-04r:-`,
        fs:  `cpe:2.3:h:softbank:windows_mobile_smartphone:x01sc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:planex:brl-04ur:-`,
        fs:  `cpe:2.3:a:apache:camel:2.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plantronics:persono_suite:1.1.23884.1`,
        fs:  `cpe:2.3:a:ssh:secure_shell:1.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:1.5.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:1.5.1`,
        fs:  `cpe:2.3:a:novell:edirectory:8.8:sp2:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:1.5.2`,
        fs:  `cpe:2.3:a:gnu:libtool-ltdl:1.5.22-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:1.5.3`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.2:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:1.5.4`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.0.0`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.0.1`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.0.2`,
        fs:  `cpe:2.3:a:hp:sitescope:11.30.521:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.0.3`,
        fs:  `cpe:2.3:a:mollify:mollify:0.9.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.0.4`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.0.5`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:1.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.1.2`,
        fs:  `cpe:2.3:a:eeye:retina:5.11.15.2157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.1.3`,
        fs:  `cpe:2.3:a:john_geo:blogs_manager:1.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.2.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(2d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.2.1`,
        fs:  `cpe:2.3:a:oracle:agile_product_lifecycle_management_framework:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.2.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plataformatec:devise:2.2.3`,
        fs:  `cpe:2.3:a:xcloner:xcloner:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:platform:lsadmin:-`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd945a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platform:lsadmin:5.1`,
        fs:  `cpe:2.3:a:f5:big-ip:4.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.414.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.2`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.3`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultracompare:6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.5`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.6`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(3\)x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.7`,
        fs:  `cpe:2.3:a:apache:hadoop:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.8`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.2.9`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3`,
        fs:  `cpe:2.3:a:adobe:after_effects:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3.1`,
        fs:  `cpe:2.3:a:directfb:directfb:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3.2`,
        fs:  `cpe:2.3:a:services_project:services:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3.4`,
        fs:  `cpe:2.3:a:bigfix:discovery_platform:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3.5`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3.6`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3.7`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:platinum_seo_project:platinum_seo_plugin:1.3.8`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playcomo:little_dragons:1.0.256::~~~android~~`,
        fs:  `cpe:2.3:a:pixman:pixman:0.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playrix:township:1.5.1::~~~android~~`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:bouncy_bill_monster_smasher_ed:1.0.3::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.7:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:bouncy_bill_seasons:1.3.9::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:virtualization:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:bouncy_bill_world-cup:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.822:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:jewels_%26_diamonds:1.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:lucent:vitalevent:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:ninja_chicken:1.7.6::~~~android~~`,
        fs:  `cpe:2.3:a:phusion:passenger:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:ninja_chicken_adventure_island_:1.1.1::~~~android~~`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.04:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:ninja_chicken_ooga_booga:1.4.2::~~~android~~`,
        fs:  `cpe:2.3:a:sap:enhancement_package:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:pets_fun_house:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playscape:playscape:9.3.3::~~~android~~`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:playstudio:brisbane_%26_queensland_alert:2::~~~android~~`,
        fs:  `cpe:2.3:a:elxis:elxis_cms:2006.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plex:plex_media_server:0.9.9.2`,
        fs:  `cpe:2.3:a:ubercart:ubercart:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.0\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.0:rc1`,
        fs:  `cpe:2.3:a:microsoft:bing:4.2.1:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.0:rc2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.0:rc3`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.0:rc4`,
        fs:  `cpe:2.3:a:token_insert_entity_project:token_insert_entity:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.0:rc5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.2`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:11.0\(0.98000.225\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.0.4`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.1.0`,
        fs:  `cpe:2.3:a:adobe:robohelp_server:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.1.3`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.1.4`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.1.5`,
        fs:  `cpe:2.3:a:apple:itunes:10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:1.2.0`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.0.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:2.0.1`,
        fs:  `cpe:2.3:a:hp:integrated_lights_out:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:2.0.2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:9.5`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:9.9`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:9.9.0`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:alpha5:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:9.9.0:beta`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:9.9.5`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pligg:pligg_cms:9.9.5:beta`,
        fs:  `cpe:2.3:a:samba:samba:3.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plogger:plogger:-`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plogger:plogger:-:beta2`,
        fs:  `cpe:2.3:a:gnu:screen:3.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plogger:plogger:1.0:beta3`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plogger:plogger:1.0:rc1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:6.0.196.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plogger:plogger:2.0`,
        fs:  `cpe:2.3:a:cisco:security_agent:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plogger:plogger:2.1:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xa5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plogger:plogger:3.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plohni:advanced_comment_system:1.0`,
        fs:  `cpe:2.3:a:actuate:iserver:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(9\)s8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:1.0.1`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:1.0.2`,
        fs:  `cpe:2.3:a:asp-dev:xm_diary:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:1.0.3`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:17.012.20093:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:1.0.4`,
        fs:  `cpe:2.3:a:python:python:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:1.0.5`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:1.0.6`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.7.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.0`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.0.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.0.3`,
        fs:  `cpe:2.3:a:cisco:digital_media_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.0.4`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.0.5`,
        fs:  `cpe:2.3:a:symantec:sygate_management_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.1.1`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.1.2`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.1.3`,
        fs:  `cpe:2.3:h:cisco:catalyst_5509:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.1.4`,
        fs:  `cpe:2.3:a:process-one:ejabberd:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.5`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.5.1`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.5.2`,
        fs:  `cpe:2.3:a:cisco:catalyst_5xxx_supervisor_software:2.1.501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.5.3`,
        fs:  `cpe:2.3:h:iodata:ts-wlcam_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.5.4`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:2.5.5`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.0`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.0.1`,
        fs:  `cpe:2.3:a:redhat:kdelibs_sound_devel:2.2-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.0.2`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.0.3`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass_pro:6.3.0:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.0.4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.01:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.0.5`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.0.6`,
        fs:  `cpe:2.3:a:emc:networker:7.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.1.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.1.2`,
        fs:  `cpe:2.3:a:ansys:ls-dyna:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.1.3`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.181:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.1.4`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_t3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.1.5.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.1.6`,
        fs:  `cpe:2.3:a:rocomotion:pm_bbs:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.1.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13.03\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.2.1`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.2.2`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:10.00.tc2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.2.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.3`,
        fs:  `cpe:2.3:a:openfiler:openfiler:2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.3.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.3.2`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.3.3`,
        fs:  `cpe:2.3:h:netgear:r6400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.3.4`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.3.5`,
        fs:  `cpe:2.3:a:pydio:pydio:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:3.3.6`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.1`,
        fs:  `cpe:2.3:a:wpgetready:nextcellent_gallery:1.9.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.2`,
        fs:  `cpe:2.3:a:hummingbird:collaboration:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.4`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.5`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.6.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.7`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.8`,
        fs:  `cpe:2.3:a:ibm:spss_statistics:19.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.9`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.0.10`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.1.1`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.1\(2.48\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.1.2`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.1.3`,
        fs:  `cpe:2.3:o:iij:seil\%2fneu_2fe_plus_firmware:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.1.4`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.1.5`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.1.6`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.2`,
        fs:  `cpe:2.3:a:hp:hppfaxutility:2.101.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.2.1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.2.3`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_patch_management_solution:6.2.3647:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.2.4`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6.8:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.2.5`,
        fs:  `cpe:2.3:a:dmv.ca.gov:ca_dmv:2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.2.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.6:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.2.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.6:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.1`,
        fs:  `cpe:2.3:a:python:python:3.3.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.2`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.3`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.4`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.5`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.6`,
        fs:  `cpe:2.3:a:google:chrome:12.0.740.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.7`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r4:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.8`,
        fs:  `cpe:2.3:a:php.s3.to:tree_bbs:2009\/06\/22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.9`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.5.195786.1383:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.10`,
        fs:  `cpe:2.3:a:avaya:interaction_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.11`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.12`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.14`,
        fs:  `cpe:2.3:a:aol:aolserver:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:4.3.15`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.1.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0:rc1`,
        fs:  `cpe:2.3:h:huawei:p2-6011:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0:rc2`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0:rc3`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.1`,
        fs:  `cpe:2.3:a:altiris:agent_for_mac:6.2.1302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.2`,
        fs:  `cpe:2.3:a:hitachi:compute_systems_manager:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.4`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.5`,
        fs:  `cpe:2.3:a:siemens:spcanywhere:1.4:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.6`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.7`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.5d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.8`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.0.9`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.1:a1`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.2:rp2:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.1:a2`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.01:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.1:b2`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.1:b3`,
        fs:  `cpe:2.3:a:eviware:soapui:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.1:b4`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite_sql-server:12.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plone:plone:5.1:rc1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.21:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plotsoft:pdfill_pdf_editor:8.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plotsoft:pdfill_pdf_editor:9.0`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluck-cms:pluck:4.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluck-cms:pluck:4.5.1`,
        fs:  `cpe:2.3:a:novell:iprint:5.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluck-cms:pluck:4.5.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluck-cms:pluck:4.5.3`,
        fs:  `cpe:2.3:a:google:earth:4.0.2091:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluck-cms:pluck:4.6.1`,
        fs:  `cpe:2.3:a:c-icap_project:c-icap:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluck-cms:pluck:4.6.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluck-cms:pluck:4.7`,
        fs:  `cpe:2.3:a:atheme:atheme:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:internet_directory:2.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openstack:neutron:2012.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:mercurycom:mr804:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.15.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p451:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.2\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:docker:docker:0.11.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:userv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_wireless_security:5.5.080.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sun:grid_engine:6.0:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:helios:textpad:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hrblock:taxcut_delaware_2008:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:2.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.17a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers:2.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_bootable_media_builder:11.0.17217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.56c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:acquia:commons:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.21:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nero:mediahome:2.5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.5.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.2.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:friends_of_symfony_project:fosuserbundle:1.2.0:-:-:*:-:symfony:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:2.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s7503e-s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:a.01.09.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rim:blackberry_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:janetter:janetter:1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.00:-:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.83.p-1.0.4.2-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp1:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:13.0.750.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pctools:pctools_firewall:6.0.0.88:-:plus:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:3.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ad-minister_project:ad-minister:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x:libxfont:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:4.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2009.312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:4.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.4:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:4.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tony_freixas:ubercart_product_keys:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tryton:trytond:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:arcsight_command_center:6.8.0.1896.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:navisphere_off-array_management_server:29.6.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:reviewboard:reviewboard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:citrix:gotoassist_corporate:9.1.0.615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.6.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.35.385:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.6.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.422:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:magento:magento:1.14.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.7.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cmscout:cmscout:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.7.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:5.7.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.3.300.271:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mcafee:protectionpilot:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:finder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.3\(2f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:6.0.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.12.1.knots20160629:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:7.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:7.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:camera_raw:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ows:scald:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:8.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:koha:koha:3.16.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:xp7_global_link_manager_software:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bluecoat:winproxy:6.1:r1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kinsey:infor-lawson:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:h:asus:rt-n16:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:xnview:xnview:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:xerox:document_centre_332:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:buffalotech:wer-amg54_firmware:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.03b23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libpng:libpng:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netiq:appmanager_repository_slovenia_qdb:7.0.11248.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plugin-organizer_project:plugin-organizer:9.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.1:2003sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.0.2`,
        fs:  `cpe:2.3:a:emc:celerra_cifs_management:4.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.0.3`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.0.4`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.0.5`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.0.6`,
        fs:  `cpe:2.3:a:winscp:winscp:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.1.3`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.2`,
        fs:  `cpe:2.3:a:samba:samba:3.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.2.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.2.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.2.3`,
        fs:  `cpe:2.3:a:omeka:omeka:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plume-cms:plume_cms:1.2.4`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plumtree:logging_utilities:6.0.0.0`,
        fs:  `cpe:2.3:a:php:php:5.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plumtree:plumtree_foundation:6.0.1.218452`,
        fs:  `cpe:2.3:a:google:chrome:16.0.898.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plupload:plupload:2.1.8`,
        fs:  `cpe:2.3:a:microsoft:commercial_internet_system:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluxml:pluxml:0.3.1`,
        fs:  `cpe:2.3:a:ultraplayer:ultraplayer_media_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluxml:pluxml:5.1.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pluxml:pluxml:5.1.6`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:plxtech:remotecomms_external_disk_access:1.25.3`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmail:mercury_mail_server:-`,
        fs:  `cpe:2.3:a:mcafee:virusscan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmail:mercury_mail_transport_system:-`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmail:mercury_mail_transport_system:4.51`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmail:pegasus:-`,
        fs:  `cpe:2.3:a:otrs:faq:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmail:pegasus:4.01`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:04-01:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmb_services:pmb:4.1.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.0`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.1`,
        fs:  `cpe:2.3:a:libraw:libraw:0.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.2`,
        fs:  `cpe:2.3:a:vitei:qlock:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.3`,
        fs:  `cpe:2.3:a:mit:kerberos:5_1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.4`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.5`,
        fs:  `cpe:2.3:a:novell:nsure_audit:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.6`,
        fs:  `cpe:2.3:a:miethner-scripting:dz_erotik_auktionshaus_v4rgo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.7`,
        fs:  `cpe:2.3:a:crumbs_project:crumbs:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.8`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.9`,
        fs:  `cpe:2.3:a:ca:unicenter_service_desk_knowledge_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.10`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.0.1-40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.11`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.12`,
        fs:  `cpe:2.3:a:openntpd:openntpd:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.0.13`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.00:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.0`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.26.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.2`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:a.01.09.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.3`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.4`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.5`,
        fs:  `cpe:2.3:a:thycotic:secret_server:8.8.000000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.6`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_cluster-storage:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.7`,
        fs:  `cpe:2.3:a:novell:groupwise:7.03:hp:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.8`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.9`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.10`,
        fs:  `cpe:2.3:a:allplayer:allplayer:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.11`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.12`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.8:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.13`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.5.1.8210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.14`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p462:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.15`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.16`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.17`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.18`,
        fs:  `cpe:2.3:a:sgi:infosearch:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.19`,
        fs:  `cpe:2.3:a:adobe:camera_raw:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.20`,
        fs:  `cpe:2.3:a:pondol-formmail_project:pondol-formmail:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.21`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.22`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.4.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.23`,
        fs:  `cpe:2.3:o:cisco:catos:5.1\(1\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.24`,
        fs:  `cpe:2.3:a:adobe:connect:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.25`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.26`,
        fs:  `cpe:2.3:a:ibm:sterling_integrator:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.1.27`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:267:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0`,
        fs:  `cpe:2.3:h:d-link:dap-1320:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2jk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta10`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta11`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta12`,
        fs:  `cpe:2.3:a:adobe:flash_player:16.0.0.296:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta13`,
        fs:  `cpe:2.3:a:acrosoftware:cutepdf_writer:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta14`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta15`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta16`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta17`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta18`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta19`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.834:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta20`,
        fs:  `cpe:2.3:a:airdroid:airdroid:1.0.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta21`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.17.4710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta22`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta23`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta24`,
        fs:  `cpe:2.3:a:apache:axis2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta25`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta26`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p370:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta27`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.4.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta28`,
        fs:  `cpe:2.3:o:cisco:catos:5.3\(6a\)csx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta29`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta3`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta30`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta31`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta32`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta33`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta34`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta35`,
        fs:  `cpe:2.3:h:fortinet:fortigate-80c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta36`,
        fs:  `cpe:2.3:h:dlink:dsl-2640b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta37`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows_ccf_client:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta38`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta39`,
        fs:  `cpe:2.3:a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta4`,
        fs:  `cpe:2.3:a:magix:samplitude_producer:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta40`,
        fs:  `cpe:2.3:a:debian:ppxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta41`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.2:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta42`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_74:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta43`,
        fs:  `cpe:2.3:a:oracle:database_server:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta44`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta45`,
        fs:  `cpe:2.3:a:vmware:esx_server:2.5.3:patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta46`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta47`,
        fs:  `cpe:2.3:a:netscape:communicator:4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta48`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.19:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta49`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta5`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta50`,
        fs:  `cpe:2.3:a:google:chrome:5.0.369.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta51`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_xgs_firmware:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta52`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta53`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:6.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta54`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta55`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta56`,
        fs:  `cpe:2.3:a:nginx:nginx:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta57`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta58`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta59`,
        fs:  `cpe:2.3:o:ibm:os_400:v4r2m0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta6`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta60`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta61`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta62`,
        fs:  `cpe:2.3:a:mikejolley:download_monitor:3.3.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta63`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.2:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta64`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta65`,
        fs:  `cpe:2.3:a:beyondgrep:ack:2.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta66`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p283:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta67`,
        fs:  `cpe:2.3:a:microsoft:ie:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta68`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta7`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta8`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)sl6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.0:beta9`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.1`,
        fs:  `cpe:2.3:a:symantec:veritas_commandcentral:5.2.473.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.2`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.3`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.4`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.5`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.6`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-00-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.7`,
        fs:  `cpe:2.3:a:activision:call_of_duty_elite:2.0.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.8`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.9`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.10`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.100.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.11`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.1sg:3.1.1sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.12`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.13`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.14`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a3:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.15`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.16`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.17`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.18`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.19`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.20`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3xo.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.21`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.22`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.23`,
        fs:  `cpe:2.3:a:david_king:vino:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.24`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.8.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.25`,
        fs:  `cpe:2.3:h:hp:advanced_server_9000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.26`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.12:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.27`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.10:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.28`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.29`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.8:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.30`,
        fs:  `cpe:2.3:a:wave:wave_support_software:5.10.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.32`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.33`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.34`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pmwiki:pmwiki:2.2.35`,
        fs:  `cpe:2.3:a:mutiny:standard:4.5-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pngquant:pngquant:2.7.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:27.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnmsoft:sequence_kinetics:7.5`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.0`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.2`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:11.1.0.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.3`,
        fs:  `cpe:2.3:a:apache:ignite:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.4`,
        fs:  `cpe:2.3:a:novell:sentinel_log_manager:1.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.5`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.6`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.7`,
        fs:  `cpe:2.3:a:adobe:photoshop_album:3.0:-:starter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.10`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.11`,
        fs:  `cpe:2.3:a:google:v8:3.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.12`,
        fs:  `cpe:2.3:a:nec:expresscluster_x:3.3:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.13`,
        fs:  `cpe:2.3:a:omeka:omeka:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.14`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.15`,
        fs:  `cpe:2.3:a:blaine_lang:filedepot:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.16`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.9\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.17`,
        fs:  `cpe:2.3:h:honeywell:falcon_xlweb_xlwebexe:2.02.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.18`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.19`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.20`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.21`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.6.749:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pnp4nagios:pnp4nagios:0.6.22`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.592:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocket_cam_photo_editor_project:pocket_cam_photo_editor:3.0::~~~android~~`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketknife_bravo_super_project:pocketknife_bravo_super:0.54.13345.33028::~~~android~~`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:adt_aesthetic_dentistry_today:%407f080181::~~~android~~`,
        fs:  `cpe:2.3:h:siemens:scalance_s613:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:american_waterfowler:%407f0801aa::~~~android~~`,
        fs:  `cpe:2.3:a:mcafee:dlp_agent:9.0.0.416:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:classic_arms_%26_militaria:%407f080193::~~~android~~`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:classic_car_buyer:%407f08017a::~~~android~~`,
        fs:  `cpe:2.3:a:kuran\&#39;in_bilimsel_mucizeleri_project:kuran\&#39;in_bilimsel_mucizeleri:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:classic_racer:%407f0801aa::~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp2:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:craft_stamper_magazine:%407f080183::~~~android~~`,
        fs:  `cpe:2.3:a:webtrends:system_database:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:football_espana_magazine:%407f0801aa::~~~android~~`,
        fs:  `cpe:2.3:a:opera:mini:3.1.8295:1690:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:front:%407f08017a::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:business_edition_5000_software:8.6\(2a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:fusion_flowers_-_weddings:%407f0801aa::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:gambling_insider_magazine:%407f0801aa::~~~android~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:inside_crochet:%407f08017a::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:model_laboratory:%407f080193::~~~android~~`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc7:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:nra_journal:%407f080181::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:old_bike_mart:%407f08017e::~~~android~~`,
        fs:  `cpe:2.3:a:techsmith:snagit:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:outdoor_design_and_living:%407f080181::~~~android~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:pc_advisor:%407f08017a::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:pony_magazine:%407f080193::~~~android~~`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:skin%26ink_magazine:%407f08017a::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:superbike_magazine:%407f08017a::~~~android~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:taster_magazine:%407f080183::~~~android~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:terrorizer_magazine:%407f08017a::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocketmags:wasps_official_programmes:%407f080130::~~~android~~`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.0:-`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.0:rc1`,
        fs:  `cpe:2.3:a:ctdb_project:ctdb:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.1.1`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.2.1`,
        fs:  `cpe:2.3:a:apache:hive:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.3`,
        fs:  `cpe:2.3:a:apple:apple_tv:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.3.1`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.4`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.4.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.5`,
        fs:  `cpe:2.3:a:adobe:coldfusion:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.5.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.5.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.5.3`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:3.0:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.5.4`,
        fs:  `cpe:2.3:a:apache:activemq:5.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.5.5`,
        fs:  `cpe:2.3:h:brocade:silkworm_4900_fibre_channel_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.6`,
        fs:  `cpe:2.3:h:qnap:ss-839:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.7`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.7.1`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.7.2`,
        fs:  `cpe:2.3:a:apache:struts:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoo:jinja2:2.8`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoproject:poco_c%2b%2b_libraries:1.4.5`,
        fs:  `cpe:2.3:o:cisco:cg-os:cg4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoproject:poco_c%2b%2b_libraries:1.4.6:-`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoproject:poco_c%2b%2b_libraries:1.4.6:p1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoproject:poco_c%2b%2b_libraries:1.4.6:p2`,
        fs:  `cpe:2.3:a:sympa:sympa:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoproject:poco_c%2b%2b_libraries:1.4.6:p3`,
        fs:  `cpe:2.3:a:quagga:quagga:0.98.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pocoproject:poco_c%2b%2b_libraries:1.4.6:p4`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:podofo_project:podofo:0.9.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:podofo_project:podofo:0.9.5`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:podsfoundation:pods:2.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pointinside:point_inside_shopping_%26_travel:3.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pokecreator:pokecreator_lite:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:apache:camel:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:poker_puzzle_project:poker_puzzle:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:emberjs:ember.js:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarnavy:polarcom:1.6.55`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.10.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.10.1`,
        fs:  `cpe:2.3:a:gimp:gimp:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.11.0`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.11.1`,
        fs:  `cpe:2.3:o:cisco:vpn_5000_concentrator_series_software:6.0.21.0002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.12.0`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.12.1`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.13.1`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.3:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.14.0`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.14.2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.14.3`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.99:pre1`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.99:pre3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.99:pre4`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp3:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:0.99:pre5`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.0.0`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.0:rc0`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.6en:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.0:rc1`,
        fs:  `cpe:2.3:a:isc:bind:9.1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.1`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.3`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.0.8:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.4`,
        fs:  `cpe:2.3:o:dell:idrac7_firmware:1.37.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.5`,
        fs:  `cpe:2.3:a:barebones:textwrangler:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.6`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.7`,
        fs:  `cpe:2.3:a:anywhere_anytime_yoga_workout_project:anywhere_anytime_yoga_workout:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.1.8`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.0`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.1`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-30-\/f:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.3`,
        fs:  `cpe:2.3:a:algosec:firewall_analyzer:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.4`,
        fs:  `cpe:2.3:a:ibm:security_guardium_database_activity_monitor:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.317:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.6`,
        fs:  `cpe:2.3:a:incredimail:incredimail:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.7`,
        fs:  `cpe:2.3:a:kent-web:joyful_note:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.8`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.9`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.10`,
        fs:  `cpe:2.3:a:samba:samba:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.2.11`,
        fs:  `cpe:2.3:a:roxio:creator_de:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.12:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.0:alpha1`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.4:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.0:rc0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.447.2.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.2`,
        fs:  `cpe:2.3:a:pecio-cms:pecio_cms:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.3`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:8.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.4`,
        fs:  `cpe:2.3:a:keepass:password_safe:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.5`,
        fs:  `cpe:2.3:a:ibm:qradar_risk_manager:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.6`,
        fs:  `cpe:2.3:a:gajim:gajim:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polarssl:polarssl:1.3.8`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.2p6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polkit_project:polkit:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p119:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:poll_chart_block_project:poll_chart_block:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.19.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:poll_chart_block_project:poll_chart_block:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:turck:bl20_programmable_gateway_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polldaddy_polls_%26_ratings_plugin_project:polldaddy_polls_%26_ratings:2.0.24::~~~wordpress~~`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polldaddy_polls_%26_ratings_plugin_project:polldaddy_polls_%26_ratings:2.0.25::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:v8:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:cma_system_software:5.2.0j`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.3.0.3650:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:cma_system_software:5.2.1j`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:cma_system_software:5.5.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:cma_system_software:6.0`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:cma_system_software:6.0.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:cma_system_software:6.0.1:system_patch_2`,
        fs:  `cpe:2.3:a:osticket:osticket:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:converged_management_application_4000:-`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.66:e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:converged_management_application_5000:-`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:datastore:5.22.109.0`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:distributed_media_application_7000:-`,
        fs:  `cpe:2.3:a:geodesicsolutions:geocore_max:7.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:dma_system_software:2.1.0j`,
        fs:  `cpe:2.3:a:firejail_project:firejail:0.9.38.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:dma_system_software:2.1.1j`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:dma_system_software:4.0`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:dma_system_software:4.0.2`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:global_management_system:7.0.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_4002:-`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_4500:-`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_6000:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.398:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_7001:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_7002:-`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(3\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_8002:-`,
        fs:  `cpe:2.3:a:hp:network:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_8004:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.27:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_8006:-`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_9002:-`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_9004:-`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:hdx_9006:-`,
        fs:  `cpe:2.3:a:distributive:datadrill:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:2.0.5_j`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:2.5.0.7`,
        fs:  `cpe:2.3:h:cisco:4400_wireless_lan_controller:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:2.5.0.7_g`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_server:11.0:sp2:*:*:ltss:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:2.6.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:2.6.1.3`,
        fs:  `cpe:2.3:a:x:x.org_x11:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:2.7.0_j`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:2.7.1_j`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:3.0.0`,
        fs:  `cpe:2.3:h:axis:700_network_document_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:3.0.0.1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:3.0.0.2`,
        fs:  `cpe:2.3:a:x:x.org_x11:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:3.0.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:3.0.2`,
        fs:  `cpe:2.3:a:dave_thomas:rdoc:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:3.0.3`,
        fs:  `cpe:2.3:a:actualtests:cisco_640-802_demo_in_exam_engine_format:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:3.0.3.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:hdx_system_software:3.0.4`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.1:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:mgc-100:-`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:mgc-25:-`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:mgc-50:-`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:mgc-50:7.00.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(8\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:mgc_manager:7.5`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:pathnavigator:7.0.3.204`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_products:8.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:realpresence_capture_station_software:5.5`,
        fs:  `cpe:2.3:a:john_morrissey:mod_ldap_userdir:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:realpresence_media_manager_software:5.0`,
        fs:  `cpe:2.3:a:teradata:system_emulation_tool:13.10.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:realpresence_media_manager_software:5.1`,
        fs:  `cpe:2.3:o:honeywell:midas_black_firmware:2.13b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:realpresence_presenterpro_software:6.1.5.61`,
        fs:  `cpe:2.3:a:codiad:codiad:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:recording_and_streaming_server_4000:-`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:16.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:rmx_1500:-`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:rmx_2000:-`,
        fs:  `cpe:2.3:a:google:talk_plugin:1.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:rmx_4000:-`,
        fs:  `cpe:2.3:a:apache:tomcat:3.2.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rmx_system_software:4.5.0.f`,
        fs:  `cpe:2.3:a:gnu:glibc:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rmx_system_software:5.1.0.g`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rmx_system_software:7.2.2`,
        fs:  `cpe:2.3:a:hp:creativeprojects_templates:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rmx_system_software:7.5.0.j`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rmx_system_software:7.5.1.j`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.21:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rmx_system_software:7.6`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rmx_system_software:7.6.1`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:6.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rss_system_software:5.0`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rss_system_software:6.0`,
        fs:  `cpe:2.3:a:apple:itunes:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rss_system_software:6.4`,
        fs:  `cpe:2.3:a:suse:linux_enterprise_debuginfo:11:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rss_system_software:6.9j`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:rss_system_software:7.0`,
        fs:  `cpe:2.3:o:conectiva:linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:s4gw_system_software:5.7.2.0.g`,
        fs:  `cpe:2.3:a:acquia:commons:6.x-2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:serial_gateway_s4gw:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:soundpoint_ip_301:-`,
        fs:  `cpe:2.3:o:hot:hotbox_router_firmware:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:soundpoint_ip_301:1.4.1.0040`,
        fs:  `cpe:2.3:a:citrix:metaframe_secure_access_manager:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:soundpoint_ip_601:-`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:soundpoint_ip_601:1.6.3.0067_bootrom_3.0.0`,
        fs:  `cpe:2.3:a:sap:afaria:7.0.6620.2:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:soundpoint_ip_650:-`,
        fs:  `cpe:2.3:a:webmin:usermin:0.929:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polycom:tts:1.0.0.0`,
        fs:  `cpe:2.3:a:google:talk:1.0.0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viavideo:-`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.0.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viavideo:2.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viavideo:3.0`,
        fs:  `cpe:2.3:a:trend_micro:hijackthis:1.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_128:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(17d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_128:6.5.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_128:7.2`,
        fs:  `cpe:2.3:o:redhat:linux:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_512:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_512:6.5.1`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.3.0.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_512:7.2`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_512:7.5.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.65.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_dcp:-`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_dcp:6.5.1`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_dcp:7.2`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_fx_vs_4000:-`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.53.020.2763:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_fx_vs4000:4.1.5`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_h.323:-`,
        fs:  `cpe:2.3:h:dell:latitude_e6520:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_h.323:6.5.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:07-00-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_h.323:7.2`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_mp:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_mp:6.5.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_mp:7.2`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_sp_384:6.5.1`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.1.635:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_sp_384:7.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(2c\)a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_sp_sp384:-`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_v.35:-`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_v.35:6.5.1`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:polycom:viewstation_v.35:7.2`,
        fs:  `cpe:2.3:a:symantec:data_loss_prevention:12.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polylang_plugin_project:polylang:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polylang_plugin_project:polylang:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:polylang_plugin_project:polylang:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pomm-project:pomm:1.1.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pondol-carousel_project:pondol-carousel:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pondol-formmail_project:pondol-formmail:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:bpdsoftware:50.0.165.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.01`,
        fs:  `cpe:2.3:a:symantec:client_firewall:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.02`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.03`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.04`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.05`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.06`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.07`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:ga:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.08`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.407:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.09`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.11`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.12`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.20.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.13`,
        fs:  `cpe:2.3:a:autodesk:dwg_trueview:17.2.56.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.20`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.21`,
        fs:  `cpe:2.3:o:conectiva:linux:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.22`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:archive_decoder:1.23`,
        fs:  `cpe:2.3:h:ibm:bladecenter:hs22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:1.00`,
        fs:  `cpe:2.3:a:bsalsa:embeddedwb:14.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:1.08`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_4l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.00`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.3.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.01`,
        fs:  `cpe:2.3:a:evan_dandrea:usb-creator:0.2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.03`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.04`,
        fs:  `cpe:2.3:a:jffnms:just_for_fun_network_management_system:0.8.4:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.05`,
        fs:  `cpe:2.3:a:flatnux:flatnux:2009-01-27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.06`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.07`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:5.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.08`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.09`,
        fs:  `cpe:2.3:a:google:chrome:10.0.612.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.10`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.11`,
        fs:  `cpe:2.3:a:ibm:java:5.0.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.12`,
        fs:  `cpe:2.3:a:lxml:lxml:2.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.12a`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.12b`,
        fs:  `cpe:2.3:a:gnome:gdk-pixbuf:2.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.13`,
        fs:  `cpe:2.3:a:qemu:qemu:0.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.14`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.15`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.16`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.16a`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.17`,
        fs:  `cpe:2.3:a:hp:performance_center:12.01:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.17a`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.18`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.1\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.19`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.20`,
        fs:  `cpe:2.3:a:microsoft:digital_image_suite:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.21`,
        fs:  `cpe:2.3:a:samba:samba:3.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.22`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1-14:fix01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.23`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.23a`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.24`,
        fs:  `cpe:2.3:o:turck:bl67_programmable_gateway_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.25`,
        fs:  `cpe:2.3:a:citrix:management_console_for_citrix_presentation_server:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.26`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.27`,
        fs:  `cpe:2.3:a:rapidleech:rapidleech:rev36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.27b`,
        fs:  `cpe:2.3:a:ntp:ntp:p95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.28`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.29`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.30`,
        fs:  `cpe:2.3:h:lorextechnology:edge2:lh330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.31`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.32`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.33`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.34`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.34a`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.34b`,
        fs:  `cpe:2.3:a:apple:boot_camp:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.35`,
        fs:  `cpe:2.3:a:mcafee:asset_baseline_monitor:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.35a`,
        fs:  `cpe:2.3:a:apache:struts:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.35b`,
        fs:  `cpe:2.3:a:apache:qpid:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.36`,
        fs:  `cpe:2.3:a:microsoft:word:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.37`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.37a`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.37b`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.38`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.39`,
        fs:  `cpe:2.3:a:forgerock:openam:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.40`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.40a`,
        fs:  `cpe:2.3:a:cisco:cloudcenter_orchestrator:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.41`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.42`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1017.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.42a`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.43`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.44`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.45`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.46`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.47`,
        fs:  `cpe:2.3:a:schneems:wicked:0.2.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.47s`,
        fs:  `cpe:2.3:a:peel:peel_shopping:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.48`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.49`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.49a`,
        fs:  `cpe:2.3:a:smarty:smarty:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.49b`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2008.0717.2343.40629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.50`,
        fs:  `cpe:2.3:a:yahoo:messenger:6.0.0.1643:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.60`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.60a`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.61`,
        fs:  `cpe:2.3:a:rim:blackberry_desktop_software:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.62`,
        fs:  `cpe:2.3:a:rubyonrails:web_console:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.63`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.63a`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_desktop:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.64`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.65`,
        fs:  `cpe:2.3:h:huawei:s5300ei:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.66`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.66a`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.67`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.67a`,
        fs:  `cpe:2.3:a:foxitsoftware:phantompdf:7.0.6.1126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.68`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.69`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.69a`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1k:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.70`,
        fs:  `cpe:2.3:o:freebsd:freebsd:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.71`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.73`,
        fs:  `cpe:2.3:a:grpc:grpc:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.74`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.1.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.74a`,
        fs:  `cpe:2.3:h:hp:jf230a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.74c`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.1:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.75`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.76`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.77`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.77a`,
        fs:  `cpe:2.3:a:ibm:mq_appliance_m2000:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.77b`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.78`,
        fs:  `cpe:2.3:a:xfree86:x11perf:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.79`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.79a`,
        fs:  `cpe:2.3:a:keyword_research_project:keyword_research:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.80`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.81`,
        fs:  `cpe:2.3:a:sourcefabric:campsite:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.82`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.83`,
        fs:  `cpe:2.3:a:samba:samba:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.84`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.0.844:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.85`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.86`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.87`,
        fs:  `cpe:2.3:a:rhq-project:rhq:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.87a`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.88`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.89`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.90`,
        fs:  `cpe:2.3:a:exim:exim:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.91`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.92`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.94`,
        fs:  `cpe:2.3:a:oracle:developer_suite:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.95`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.2:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.96`,
        fs:  `cpe:2.3:h:hp:0235a394:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.97`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.97a`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0-p2-w1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.97b`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.98`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:2.99`,
        fs:  `cpe:2.3:a:emc:documentum_eroom:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.00`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.01`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.01a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.33:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.01b`,
        fs:  `cpe:2.3:a:google:chrome:17.0.939.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.02`,
        fs:  `cpe:2.3:a:ca:business_intelligence:3.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.03`,
        fs:  `cpe:2.3:a:imember360:imember360:3.7.005:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.03a`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.03b`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.04`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.05`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.05a`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.06`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.07`,
        fs:  `cpe:2.3:a:ibm:lotus_foundations_start:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.08`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.09`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.10`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.22:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.11`,
        fs:  `cpe:2.3:a:hp:photosmart_disclabel_paperlabel:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.12`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.13`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.4:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.14`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.14a`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.637:*:*:*:*:linux:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.15:beta`,
        fs:  `cpe:2.3:a:moodle:moodle:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.15:beta2`,
        fs:  `cpe:2.3:h:cisco:ie-4000-8s4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.15:beta3`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.7:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.16`,
        fs:  `cpe:2.3:a:google:v8:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.16a`,
        fs:  `cpe:2.3:a:adobe:acrobat:7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.16b`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.16c`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.17`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.17a`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.17b`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.18`,
        fs:  `cpe:2.3:a:emc:networker:7.6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.18a`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.18b`,
        fs:  `cpe:2.3:a:microsoft:pslist:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.18c`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.0.1495.34684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.19`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.19a`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.20`,
        fs:  `cpe:2.3:a:josh_fradley:burden:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.21`,
        fs:  `cpe:2.3:h:bluecoat:proxysg:5.2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.22`,
        fs:  `cpe:2.3:a:apache:hadoop:0.20.203.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.22a`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.23`,
        fs:  `cpe:2.3:a:adobe:sgm_cs4:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.23a`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.24`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.25`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.26`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.26a`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.27`,
        fs:  `cpe:2.3:a:python:python:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.28`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_edge_75_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.29`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.30`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.301:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.31`,
        fs:  `cpe:2.3:a:f5:big-iq_cloud:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.32`,
        fs:  `cpe:2.3:a:fellowes:mediaface:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.33`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.34`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.35`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.2:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.36`,
        fs:  `cpe:2.3:a:emc:my_documentum_for_microsoft_outlook:6.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.36a`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.36b:beta`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.37`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.01.434:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.38`,
        fs:  `cpe:2.3:a:akiva:webboard:8.0:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.39`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.40`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.41`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.42`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.43`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:p06-0024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.44`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.45`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.46`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.47`,
        fs:  `cpe:2.3:o:vmware:esxi:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.48`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.49`,
        fs:  `cpe:2.3:h:foundrynet:bigiron_4000_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.50`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.51`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:5.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.52`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.53`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.54`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.54a`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.54b`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.55`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.56`,
        fs:  `cpe:2.3:a:bluecoat:proxysg:6.5.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.56b`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.56c`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp3:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.57`,
        fs:  `cpe:2.3:a:construtiva:cis_manager_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.58`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)ea1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.59`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.60`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.61`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.61a`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.62`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.63`,
        fs:  `cpe:2.3:h:microsoft:mn-500_wireless_base_station:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.64`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.65`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.10.329:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.66`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.67`,
        fs:  `cpe:2.3:h:buffalotech:wzr-g144nh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.68`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.69`,
        fs:  `cpe:2.3:a:tasofro:touhou-hisouten:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.70`,
        fs:  `cpe:2.3:a:gnu:glibc:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.71`,
        fs:  `cpe:2.3:a:apptha:contus_video_gallery:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.72`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.73`,
        fs:  `cpe:2.3:a:cisco:rv016_multi-wan_vpn_firmware:4.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.74`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.75`,
        fs:  `cpe:2.3:a:perl:perl:2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.76`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.588:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.77`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.78`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.0:rc3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.79`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.80`,
        fs:  `cpe:2.3:a:dell:openmanage_drac_tools:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.81`,
        fs:  `cpe:2.3:a:danielb:finder:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.82`,
        fs:  `cpe:2.3:a:libexpat:expat:1.95.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.83`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.84`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.85`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.86`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.87`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.88`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.89`,
        fs:  `cpe:2.3:a:aspen:aspen:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.90`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.91`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.92`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:4.2\(1\)_sv1\(4\):-:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.93`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.94`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.95`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.96`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.97`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.98`,
        fs:  `cpe:2.3:a:altiris:package_rule_management:6.1.4085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:3.99`,
        fs:  `cpe:2.3:a:google:chrome:6.0.444.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.00`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:3.1\(2c\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.01`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_61:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.02`,
        fs:  `cpe:2.3:a:google:chrome:17.0.940.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.03`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.04`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.05`,
        fs:  `cpe:2.3:a:apache:wicket:6.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.06`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.07`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r005c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.08`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.12:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.09`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.10`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.11`,
        fs:  `cpe:2.3:a:adobe:csi_cs4:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.12`,
        fs:  `cpe:2.3:a:apache:hadoop:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.13`,
        fs:  `cpe:2.3:a:linux-ha:heartbeat:0.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.14`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.15`,
        fs:  `cpe:2.3:a:oracle:general_ledger:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.16`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_redundant_controller_firmware:20.050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.17`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.18`,
        fs:  `cpe:2.3:a:vmware:workstation:11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.19`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.20`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.21`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.22`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.23`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(7\)da2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.24`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.25`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.26`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.27`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.28`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.29`,
        fs:  `cpe:2.3:a:lenovo:shareit:3.5.88_ww:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.30`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.31`,
        fs:  `cpe:2.3:o:cisco:dpc2203_cable_modem_firmware:r1_customer_image_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.32`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.33`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.cors:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.34`,
        fs:  `cpe:2.3:a:nmedia:member_conversation:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.35`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.36`,
        fs:  `cpe:2.3:a:candy_blast_project:candy_blast:1.1.001:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.37`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.38`,
        fs:  `cpe:2.3:a:david_king:vino:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.39`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.40`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.28-76.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.41`,
        fs:  `cpe:2.3:h:dell:sonicwall_umaem5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.42`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.43`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.44`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.45`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1052.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.46`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.47`,
        fs:  `cpe:2.3:a:samba:samba:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.48`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.49`,
        fs:  `cpe:2.3:h:siemens:sinamics_g180:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.51`,
        fs:  `cpe:2.3:h:cisco:ips_4255:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.52`,
        fs:  `cpe:2.3:a:nfsen:nfsen:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.53`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.595:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.54`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.55`,
        fs:  `cpe:2.3:h:siemens:scalance_xr-300eec:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.56`,
        fs:  `cpe:2.3:a:python:python:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.57`,
        fs:  `cpe:2.3:a:debian:guilt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.58`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.1\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.59`,
        fs:  `cpe:2.3:a:cisco:business_edition_5000_software:8.6\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.60`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-03-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.61`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.62`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:-:core:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.63`,
        fs:  `cpe:2.3:a:apache:synapse:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.64`,
        fs:  `cpe:2.3:a:sensiolabs:twig:1.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.65`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p296:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.66`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.67`,
        fs:  `cpe:2.3:a:microsoft:clip_art:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.68`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.69`,
        fs:  `cpe:2.3:a:audacity:audacity:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.70`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.71`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.72`,
        fs:  `cpe:2.3:a:cisco:unified_ccx:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.73`,
        fs:  `cpe:2.3:a:curtis_galloway:libexif:0.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.74`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.75`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.76`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.77`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.78`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.79`,
        fs:  `cpe:2.3:a:opscode:chef:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.80`,
        fs:  `cpe:2.3:a:apache:mod_perl:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.81`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd352a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.82`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.90`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.91`,
        fs:  `cpe:2.3:a:pfsense:pfsense:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.92`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.93`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.94`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.95`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.96`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.97`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.98`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.15:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.99`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:4.99.2`,
        fs:  `cpe:2.3:a:veritas:netbackup:5.0.0:mp2:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.01`,
        fs:  `cpe:2.3:a:oracle:xml_developers_kit:12.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.02`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.03`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.04`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.05`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.06`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.07`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.6.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.08`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.09`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.10`,
        fs:  `cpe:2.3:o:fortinet:fortiadc_firmware:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.11`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.12`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.333:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.13`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.14`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.15`,
        fs:  `cpe:2.3:a:apache:syncope:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.16`,
        fs:  `cpe:2.3:o:cisco:catos:3.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.17`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.20`,
        fs:  `cpe:2.3:a:microsoft:publisher_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.21`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.22`,
        fs:  `cpe:2.3:h:cisco:catalyst_7600_ws-svc-nam-1:2.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.23`,
        fs:  `cpe:2.3:a:hp:pstaplugin:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.24`,
        fs:  `cpe:2.3:a:citrix:access_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.25`,
        fs:  `cpe:2.3:h:cisco:catalyst_3750g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.26`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.27`,
        fs:  `cpe:2.3:a:jobranco_project:jobranco:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.28`,
        fs:  `cpe:2.3:a:ibm:rational_license_server:7.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.29`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.96:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.30`,
        fs:  `cpe:2.3:a:sun:i-runbook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.31`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.32`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.33`,
        fs:  `cpe:2.3:a:paloaltonetworks:netconnect:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.34`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.35`,
        fs:  `cpe:2.3:a:microsoft:access:2010:sp1:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.36`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_viewer:12.2.209.1094:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.37`,
        fs:  `cpe:2.3:a:shopware:shopware:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.40`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.41`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.42`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.43`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.44`,
        fs:  `cpe:2.3:a:tibbo:aggregate:5.21.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.45`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.46`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.47`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.50`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.0.9:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.51`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.3:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.52`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.53`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-00:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.54`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.2.5:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.55`,
        fs:  `cpe:2.3:a:apache:libcloud:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.56`,
        fs:  `cpe:2.3:h:dell:precision_m6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.57`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.58`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.59`,
        fs:  `cpe:2.3:a:isc:bind:9.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.60`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.61`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.62`,
        fs:  `cpe:2.3:a:google:chrome:10.0.632.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ponsoftware:explzh:5.63`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pootlepress:pootle_button:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:qemu:qemu:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pootlepress:pootle_button:1.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pootlepress:pootle_button:1.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pop-hub:iq_test:3.3::~~~android~~`,
        fs:  `cpe:2.3:h:tp-link:tl-wrd741nd_\(5.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:popoinnovation:slotmachine:1.03::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:popuapp:popu_2%3a_get_likes_on_instagram:1.7.5::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:portaplus:porta%2b_ftp_client:4.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:portaputty:portaputty:1.4`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:portfolio_project:portfolio:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:portfolium_project:portfolium:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:portrait:acer_edisplay_management:1.20.11`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:portrait:pivot_software:8.21.13`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a4\(1.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:portrait:sdk:2.5.4`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.0.1`,
        fs:  `cpe:2.3:a:deloitte:eitdr_service:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.1.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.2.0`,
        fs:  `cpe:2.3:a:apache:camel:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.3.0`,
        fs:  `cpe:2.3:a:justsystems:hanako:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.3.2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.50.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.4.2`,
        fs:  `cpe:2.3:a:mahara:mahara:16.04.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.5:-`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.5:beta`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:2.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.5:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)s7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.5:rc`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:1.5.1`,
        fs:  `cpe:2.3:a:libraw:libraw:0.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.0:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.0:beta`,
        fs:  `cpe:2.3:a:hp:centralized_management_console_software:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.0:beta2`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.0:p1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.0:rc`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.1:-`,
        fs:  `cpe:2.3:a:hp:alm_synchronizer:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.1:b`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:5.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.1:p1`,
        fs:  `cpe:2.3:o:cisco:nx-os:8.0\(1\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.1:p2`,
        fs:  `cpe:2.3:a:equis:metastock:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.1:rc`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.2:-`,
        fs:  `cpe:2.3:a:lucent:vitalsuite:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.2:beta`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.2:rc`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.2.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.2.3`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:2.3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.0:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.0:beta`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.0.1`,
        fs:  `cpe:2.3:o:suse:suse_linux:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.0.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.0.3`,
        fs:  `cpe:2.3:a:digia:qt:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.0.4`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.1.0`,
        fs:  `cpe:2.3:a:tinc-vpn:tinc:1.1:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.1.1`,
        fs:  `cpe:2.3:a:netscout:ngenius_infinistream:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.1.2`,
        fs:  `cpe:2.3:a:apache:subversion:0.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.2.1`,
        fs:  `cpe:2.3:a:sap:basis_communication_services:4.6:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:posh_project:posh:3.3.0`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:possesports:posse_softball_director_cms:-`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:post_to_twitter_project:post_to_twitter:0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atmail:atmail:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.0`,
        fs:  `cpe:2.3:a:emc:navisphere_manager:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.1`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0804:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.2`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.966:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.3`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.4`,
        fs:  `cpe:2.3:o:cisco:modular_encoding_platform_d9036_software:02.02.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.5`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.10.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.6`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p172:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.8`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.9`,
        fs:  `cpe:2.3:a:altiris:patch_management_dell_agent:6.2.2623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.10`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.11`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.12`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.13`,
        fs:  `cpe:2.3:a:docker:docker:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.14`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.15`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.16`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.174:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.17`,
        fs:  `cpe:2.3:a:futomi:search_cgi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.18`,
        fs:  `cpe:2.3:o:cisco:ios:12.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.0.19`,
        fs:  `cpe:2.3:a:google:android_api:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.1.0`,
        fs:  `cpe:2.3:a:compaq:insight_manager_xe:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.1.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.1.2`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.1.3`,
        fs:  `cpe:2.3:h:cisco:xr_12416:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.1.4`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.1.5`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.1.6`,
        fs:  `cpe:2.3:o:suse:suse_linux:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.1`,
        fs:  `cpe:2.3:a:snipsnap:snipsnap:1.0b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.2`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.3`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.34:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.5`,
        fs:  `cpe:2.3:h:fortinet:fortigate-5140b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.6`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:5.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.7`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.8`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.9`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:1.0.1288.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.10`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.11`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.1-1:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.2.12`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3`,
        fs:  `cpe:2.3:h:f5:big-ip_1500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.0`,
        fs:  `cpe:2.3:a:jruby:jruby:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.1`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.2`,
        fs:  `cpe:2.3:a:gnu:g\&#43;\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.3`,
        fs:  `cpe:2.3:a:sap:network_interface_router:7.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.4`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.5`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:b.03.00.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.6`,
        fs:  `cpe:2.3:a:schneider-electric:wonderware_system_platform:2014:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.7`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.8`,
        fs:  `cpe:2.3:a:vmware:converter:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.9`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.10`,
        fs:  `cpe:2.3:a:ca:license_software:1.61.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.11`,
        fs:  `cpe:2.3:a:scilab:scilab:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.12`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-7:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.13`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.14`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.15`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.16`,
        fs:  `cpe:2.3:a:zencast:zencast:1.02.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.17`,
        fs:  `cpe:2.3:o:huawei:s9306e_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.18`,
        fs:  `cpe:2.3:a:microsoft:services:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.3.19`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4`,
        fs:  `cpe:2.3:h:juniper:secure_access_6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.0`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.1`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.3`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.4`,
        fs:  `cpe:2.3:a:adobe:widget_browser:2.0.230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.5`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.6`,
        fs:  `cpe:2.3:h:toshibatec:estudio_4511:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.7`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.9`,
        fs:  `cpe:2.3:h:buffalotech:whr-600d_firmware:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.10`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.11`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.12`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.13`,
        fs:  `cpe:2.3:a:bluechip:bc_post2facebook:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.14`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.4.15`,
        fs:  `cpe:2.3:o:vmware:esx:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.2`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.95.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.4`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.5`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.6`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.7`,
        fs:  `cpe:2.3:a:corel:coreldraw_fontnav:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.8`,
        fs:  `cpe:2.3:a:samba:samba:4.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.9`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.10`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:3.3.202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.11`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.12`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1292.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.5.13`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6`,
        fs:  `cpe:2.3:a:gnu:zebra:0.91a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.409.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_performance_manager:5.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.2`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.3`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.4`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.8:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.5`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.6`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.7`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.8`,
        fs:  `cpe:2.3:a:condor_project:condor:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.9`,
        fs:  `cpe:2.3:a:ca:unicenter_service_level_management:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.6.10`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:4.0.0.10021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.7.0`,
        fs:  `cpe:2.3:a:otrs:otrs:0.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.7.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.7.2`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.7.3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.7.4`,
        fs:  `cpe:2.3:a:freedesktop:libdbus:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.8.0`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.8.1`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\)_sr8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.8.2`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix:postfix:2.8.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.2.1.1`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.0:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.3`,
        fs:  `cpe:2.3:a:posh_project:posh:2.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.3.1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.3.2`,
        fs:  `cpe:2.3:h:softbank:disney_mobile_android_smartphone:dm009sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.3.3`,
        fs:  `cpe:2.3:a:novell:netmail:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.3.4`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.3.5`,
        fs:  `cpe:2.3:a:cognos:developer_client:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.3.6`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postfix_admin_project:postfix_admin:2.3.7`,
        fs:  `cpe:2.3:a:symantec:vrtsjre:1.6.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:-`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:6.3`,
        fs:  `cpe:2.3:a:python:python:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:6.4`,
        fs:  `cpe:2.3:o:juniper:junos:12.1:r11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:6.5`,
        fs:  `cpe:2.3:h:dlink:dwl-3200ap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.0`,
        fs:  `cpe:2.3:a:booksbyraven:raven_-_the_culture_lover:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.3`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.1`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.2`,
        fs:  `cpe:2.3:a:juniper:junos_pulse_secure_access_service:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.3`,
        fs:  `cpe:2.3:a:symantec:reporting_server:1.0.197.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.4`,
        fs:  `cpe:2.3:h:cisco:7500_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.5`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf640a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.6`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.7`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.8`,
        fs:  `cpe:2.3:a:adobe:framemaker:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.9`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.10`,
        fs:  `cpe:2.3:a:gnome:glib:2.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.11`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.12`,
        fs:  `cpe:2.3:h:ibm:system_x3850_x5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.13`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.14`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.15`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.16`,
        fs:  `cpe:2.3:a:hp:document_manager:100.0.201.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.17`,
        fs:  `cpe:2.3:a:citrix:access_management_console_report_center:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.18`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.19`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.7:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.20`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.21`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:8.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.22`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.23`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.5.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.24`,
        fs:  `cpe:2.3:h:huawei:s9300:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.25`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.26`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.27`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.28`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.29`,
        fs:  `cpe:2.3:h:cisco:spa_525g2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:7.4.30`,
        fs:  `cpe:2.3:o:ibm:aix:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.1`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.2`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0043:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.3`,
        fs:  `cpe:2.3:a:safenet-inc:luna_sa_client_software:4.4.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.4`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.5`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.6`,
        fs:  `cpe:2.3:a:nodejs:node.js:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.7`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.8`,
        fs:  `cpe:2.3:h:antlabs:inngate_ig_3.01_e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.9`,
        fs:  `cpe:2.3:a:dell:upek_touchchip_fingerprint_reader:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.10`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.11`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.12`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.13`,
        fs:  `cpe:2.3:h:siemens:cfms2025:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.14`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.15`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.16`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.53:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.17`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.18`,
        fs:  `cpe:2.3:o:opensuse:leap:42.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.19`,
        fs:  `cpe:2.3:a:novell:groupwise:8.03:hp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.20`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.21`,
        fs:  `cpe:2.3:a:intermesh:group-office:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.22`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.23`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.24`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.25`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.0.26`,
        fs:  `cpe:2.3:a:i-escorts:i-escorts_agency_script:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.2`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.1.5\(104\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.5`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.6`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.7`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.8`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.9`,
        fs:  `cpe:2.3:a:trendmicro:interscan_web_security_virtual_appliance:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.10`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.11`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.12`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.15.4610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.13`,
        fs:  `cpe:2.3:o:cisco:staros:16.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.14`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.15`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.16`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring_express:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.17`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.18`,
        fs:  `cpe:2.3:a:altova:databasespy_2011:2.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.19`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.20`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.21`,
        fs:  `cpe:2.3:a:hp:hppfonts:0.106.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.1.22`,
        fs:  `cpe:2.3:a:nuance:omnipage:12:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web_software:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.1`,
        fs:  `cpe:2.3:a:drupal:drupal:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.2`,
        fs:  `cpe:2.3:a:oracle:oracle_berkeley_db:12.1.6.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.3`,
        fs:  `cpe:2.3:a:symantec:norton_partitionmagic:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.4`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.5`,
        fs:  `cpe:2.3:a:nec:universal_raid_utility:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(1.11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.7`,
        fs:  `cpe:2.3:a:saltstack:salt:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.8`,
        fs:  `cpe:2.3:a:oracle:report_manager:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.9`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.252:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.10`,
        fs:  `cpe:2.3:a:microsoft:excel_for_mac:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.11`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.12`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.13`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.14`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.15`,
        fs:  `cpe:2.3:a:trillian:trillian:0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.16`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.17`,
        fs:  `cpe:2.3:a:clamav:clamav:0.84:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.2.18`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.1`,
        fs:  `cpe:2.3:a:gnu:tar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.2`,
        fs:  `cpe:2.3:a:intel:mprosafe:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.4`,
        fs:  `cpe:2.3:a:horde:groupware:1.2.5:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.5`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.6`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.7`,
        fs:  `cpe:2.3:a:nuance:omnipage:15.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.8`,
        fs:  `cpe:2.3:o:lenovo:thinkserver_rd350_firmware:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.9`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.10`,
        fs:  `cpe:2.3:a:google:v8:3.12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.11`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.12`,
        fs:  `cpe:2.3:o:cisco:unified_ip_conference_station_7936:3.2\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.13`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.14`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.15`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.16`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.17`,
        fs:  `cpe:2.3:a:cisco:webns:7.1_0.2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.19`,
        fs:  `cpe:2.3:a:3com:3cdaemon:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.20`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.21`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.509.3:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.3.22`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.1`,
        fs:  `cpe:2.3:a:microsoft:commerce_server:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.2`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.3`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.4`,
        fs:  `cpe:2.3:a:allaire:homesite:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.5`,
        fs:  `cpe:2.3:a:ffftp:ffftp:1.98:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.6`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.7`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.11.331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.8`,
        fs:  `cpe:2.3:a:iss:blackice_defender:2.9:cap:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.9`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.10`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.11`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.12`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.13`,
        fs:  `cpe:2.3:a:apple:itunes:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.14`,
        fs:  `cpe:2.3:a:webbynode:webbynode:1.0.5:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.15`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.16`,
        fs:  `cpe:2.3:a:kde:koffice:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.17`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.18`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0582:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.20`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.0.1679:online_windows_2003_x64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.21`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s_3.10.2ts:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:8.4.22`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:07-56-\/g\(\*2\):-:enterprise:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.1`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.2`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.5`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.6`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.154.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.9`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.10`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.11`,
        fs:  `cpe:2.3:a:tincan:phplist:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.12`,
        fs:  `cpe:2.3:a:jason_flatt:basic_webmail:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.13`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.12.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.14`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.15`,
        fs:  `cpe:2.3:o:google:android:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.17`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.18`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.20`,
        fs:  `cpe:2.3:a:ca:etrust_internet_security_suite:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.21`,
        fs:  `cpe:2.3:a:cisco:secure_services_client:4.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.0.23`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp5:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.1`,
        fs:  `cpe:2.3:a:cisco:security_agent:5.2.0.282:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.2`,
        fs:  `cpe:2.3:a:wellintech:kingview:6.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.3`,
        fs:  `cpe:2.3:h:hp:laserjet_4650dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.5`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.6`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-00-\/s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.7`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.8`,
        fs:  `cpe:2.3:a:quest:toad_data_modeler:3.5.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.9`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.10`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.11`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.12`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.2:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.19`,
        fs:  `cpe:2.3:a:winpcap:winpcap:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.20`,
        fs:  `cpe:2.3:o:samsung:samsung_mobile:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.21`,
        fs:  `cpe:2.3:a:borland:license_server:4.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.22`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.23`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.1.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.3`,
        fs:  `cpe:2.3:a:opensolution:quick.cms:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.5`,
        fs:  `cpe:2.3:h:dell:latitude_e5510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.6`,
        fs:  `cpe:2.3:h:avaya:sg5:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.7`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:2008.3:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.14`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.15`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.16`,
        fs:  `cpe:2.3:a:openstack:neutron:2014.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.17`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.19`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.20`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.2.21`,
        fs:  `cpe:2.3:a:ecitic:china_citic_bank_credit_card:3.3.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.2`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.19.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.3`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.10`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.11`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.12`,
        fs:  `cpe:2.3:h:hp:laserjet_m525dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.13`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.14`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.16`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-720:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.3.17`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:10.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4.5`,
        fs:  `cpe:2.3:a:herac:tuxguitar:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4.6`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4.7`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4.8`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.04r3-2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4.9`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:5.1.1700:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4.10`,
        fs:  `cpe:2.3:a:skype:skype:1.0.0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4.11`,
        fs:  `cpe:2.3:a:mozilla:firefox:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.4.12`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0:rc2a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.5`,
        fs:  `cpe:2.3:a:stillbreathing:bannerman:0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.5.2`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.5.3`,
        fs:  `cpe:2.3:o:yahama:rta54i:4.04.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.5.4`,
        fs:  `cpe:2.3:a:businessobjects:webintelligence:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.5.5`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.5.6`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd663a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.5.7`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.6`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.6.1`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql:9.6.2`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:postgresql_jdbc_driver:8.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:5.1\(3d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:postgresql:psqlodbc:8.3.400`,
        fs:  `cpe:2.3:a:cisco:ip_interactive_voice_response:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:postoaktraffic:awam_bluetooth_reader:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:poul-henning_kamp:md5crypt:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:power-tab:power_tab_editor:1.7.0`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerarchiver:powerarchiver:14.00`,
        fs:  `cpe:2.3:a:amanda:amanda:2.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerarchiver:powerarchiver:14.01`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:3.6:ecg:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerarchiver:powerarchiver:14.02`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerarchiver:powerarchiver:14.02.03`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p249_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerarchiver:powerarchiver:14.02.05`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative:3.2`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative:3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative:3.3.1`,
        fs:  `cpe:2.3:o:hospira:lifecare_pcainfusion_firmware:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative:3.3.2`,
        fs:  `cpe:2.3:h:apc:ap9606:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative:3.4.0`,
        fs:  `cpe:2.3:a:ca:erwin_process_modeler:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative:3.4.1`,
        fs:  `cpe:2.3:a:apple:itunes:4.5.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative:3.4.3`,
        fs:  `cpe:2.3:a:sun:nfs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative_server:2.9.22`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative_server:3.0`,
        fs:  `cpe:2.3:a:digitalfruit:mootorratturid_\&amp;_biker.ee:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:authoritative_server:4.0.0`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.1.1-14.rhel5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.5`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.5.1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.5.2`,
        fs:  `cpe:2.3:a:hp:openvms_secure_web_server:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.5.3`,
        fs:  `cpe:2.3:a:teamviewer:teamviewer:4.1.8107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.6.0`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.6.1`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.6.2`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20020823:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.6.3`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerdns:recursor:3.7.1`,
        fs:  `cpe:2.3:h:lexmark:e350:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:poweriso:poweriso:6.8`,
        fs:  `cpe:2.3:o:rockwellautomation:rslogix_emulate_5000_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerpc-utils_project:powerpc-utils:-`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerpc-utils_project:powerpc-utils:1.2.20`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds5100_storage_controller:1818:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerproduction:storyboard_quick:6.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:rc.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerprogrammer:software_update_wizard:4.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powerprogrammer:web_update_wizard:4.0`,
        fs:  `cpe:2.3:a:safenet-inc:luna_jsp_for_luna_sa:4.4.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:powerquest:deploycenter:5.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.1.99i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powersoftware:winarchiver:3.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.0xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powie:pfile:1.02`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powie:pgb:2.12`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:powie:pgb:2.14`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pp-solution:orakel-ball:0.2::~~~android~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppc64-diag_project:ppc64-diag:2.6.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p322:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.1:-`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.2`,
        fs:  `cpe:2.3:a:atlassian:jira:2.6:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.3`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.4`,
        fs:  `cpe:2.3:a:apache:httpclient:4.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.5`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.5.1`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:11.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.6`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_icons_for_avaya:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.6.1`,
        fs:  `cpe:2.3:a:commdevices:distributed_database_manager-odbc:4.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.7`,
        fs:  `cpe:2.3:a:livetecs:timeline:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.7.1`,
        fs:  `cpe:2.3:h:nortel:vpn_router_600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.7.2`,
        fs:  `cpe:2.3:a:covechurch:cove:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.8.0`,
        fs:  `cpe:2.3:o:apple:os_x_server:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.8.1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.8.2`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_30-20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.9`,
        fs:  `cpe:2.3:a:timedmediahandler_project:timedmediahandler:-:*:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.10`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v200r008c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.11`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.11:r1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.11:r2`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.12`,
        fs:  `cpe:2.3:h:hp:laserjet_2500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.13`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.14`,
        fs:  `cpe:2.3:a:lookout:lookout_security_\&amp;_antivirus:8.17:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.15`,
        fs:  `cpe:2.3:a:sympa:sympa:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.16`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.17`,
        fs:  `cpe:2.3:a:otrs:otrs:1.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.18`,
        fs:  `cpe:2.3:a:rtiindia:rti_india:3.8.21:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.18.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-05-\/i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.19`,
        fs:  `cpe:2.3:a:webcreate:webforum:6.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.19.1`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.20`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.21`,
        fs:  `cpe:2.3:a:openttd:openttd:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.21.1`,
        fs:  `cpe:2.3:a:vmware:player:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.22`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.23`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.52:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.23.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.24`,
        fs:  `cpe:2.3:a:emc:connectrix_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.24.1`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.25`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.26`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.27`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.27.1`,
        fs:  `cpe:2.3:a:gnu:screen:3.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.28`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1287.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.29`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.30`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.31.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1024:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.31.2`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.31.3`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.32.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71-\/g:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.32.2`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.33`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.6.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.34`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.35`,
        fs:  `cpe:2.3:h:axis:2120_network_camera:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.35.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.1:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:0.35.2`,
        fs:  `cpe:2.3:a:otrs:otrs:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:1.0`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:1.0.1`,
        fs:  `cpe:2.3:a:websense:websense:6.3.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:1.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.111.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:1.2`,
        fs:  `cpe:2.3:a:apple:cups:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:1.2.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:1.2.2`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:1.3`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ppfeufer:2-click-social-media-buttons:1.4`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d61:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragmasys:fortress_ssh_client_suite:5.0.9.1370`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.5.4`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:5000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.5.9`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.5.12`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.5.13`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.6:build120405:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.5.14`,
        fs:  `cpe:2.3:h:huawei:ar_g3:v200r001c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.6.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.6.2`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:4.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.6.3`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:2.6.4`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs3:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pragyan_cms_project:pragyan_cms:3.0`,
        fs:  `cpe:2.3:a:logitech:lws_video_mask_maker:13.0.1774.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:praninc:facebook_facts:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preemptive_solutions:dotfuscator:5.0.2300.0::~~community_edition~~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preemptive_solutions:dotfuscator:5.0.2500.0::~~community_edition~~~`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preplaysports:mlb_preplay:5.4.2::~~~android~~`,
        fs:  `cpe:2.3:a:phpfox:phpfox:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preplogic:cissp:3.10.0`,
        fs:  `cpe:2.3:a:ffftp:ffftp:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preplogic:exam_70-290:3.10.0`,
        fs:  `cpe:2.3:a:90meter:card_issuance_workstation:1.00.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preplogic:exam_70-643:3.10.0`,
        fs:  `cpe:2.3:a:k5n:webcalendar:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preplogic:exam_70-680:3.10.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preplogic:exam_a%2b_essentials_%28220-701%29:3.10.0`,
        fs:  `cpe:2.3:a:petition_project:petition:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:preplogic:exam_security%2b_%282008%29:3.10.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.628:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preplogic:exam_security%2b_2008:3.10.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preprojects:business_cards_designer:-`,
        fs:  `cpe:2.3:o:ibm:aix:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:preprojects:pre_printing_press:-`,
        fs:  `cpe:2.3:a:websense:enterprise:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:present-technologies:graffit_it:1.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pressit:expressit:2.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_client:06-51-\/k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:ebay_module:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:ebay_module:1.3.5`,
        fs:  `cpe:2.3:a:embedthis:goahead:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.8.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3jec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.8.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.8.3`,
        fs:  `cpe:2.3:a:activestate:activepython:2.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.8.4`,
        fs:  `cpe:2.3:a:hp:service_manager_web_tier:9.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.8.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.8.5.1`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.9`,
        fs:  `cpe:2.3:a:xml-libxml_project:xml-libxml:2.0118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.9.1:rc1`,
        fs:  `cpe:2.3:a:atmail:atmail:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.9.1:rc2`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.9.2`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.9.5`,
        fs:  `cpe:2.3:a:roxio:creator:9.0.574:*:*:*:silver:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.9.6`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:0.9.7`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.0`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.0.0.1`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.19:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.0.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.0.0.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.404.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.0.0.4`,
        fs:  `cpe:2.3:a:oracle:interaction_center_intelligence:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.0.0.5`,
        fs:  `cpe:2.3:a:sun:sunvts:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.1.0.3`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4`,
        fs:  `cpe:2.3:a:isc:bind:9.9.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.1`,
        fs:  `cpe:2.3:a:hp:wbem:a.02.00.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.2`,
        fs:  `cpe:2.3:a:google:chrome:7.0.514.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.3`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.4`,
        fs:  `cpe:2.3:a:estrongs:es_file_explorer:3.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.5`,
        fs:  `cpe:2.3:h:cisco:catalyst_2948-ge-tx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.6`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.5.0.890:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.7`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:2.0.1:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.8`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.9`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update4:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.10`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.11`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.12`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.13`,
        fs:  `cpe:2.3:h:d-link:dsl-2640r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.14`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.10:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.15`,
        fs:  `cpe:2.3:a:moodle:moodle:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.16`,
        fs:  `cpe:2.3:a:novell:groupwise:7.0.4:ftf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.0.17`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.1.0`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.2.4`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.2.5`,
        fs:  `cpe:2.3:a:avg:safeguard:18.1.7.644:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.3.0`,
        fs:  `cpe:2.3:h:t-mobile:mytouch_4g_slide:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.4.0`,
        fs:  `cpe:2.3:a:polycom:rmx_system_software:5.1.0.g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.4.1`,
        fs:  `cpe:2.3:a:att:communication_manager:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.5.1`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.6.1`,
        fs:  `cpe:2.3:a:gnu:gnats:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.6.2`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.2:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.7.0`,
        fs:  `cpe:2.3:a:nokia:qt_creator:0.9.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.7.1`,
        fs:  `cpe:2.3:a:avery:avery_wizard:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.4.7.2`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestashop:prestashop:1.6.0.9`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:presto-changeo:canadapost:-`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.6.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:presto-changeo:canadapost:1.0.1`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestosoft:examdiff:1.8.0.4`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prestosoft:examdiff:1.8.0.7`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prettybook:prettyformmail:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p340:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pricegong:pricegong:2.1.0`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primera:ptpublisher:2.1.6`,
        fs:  `cpe:2.3:o:rockwellautomation:softlogix:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:primera:signature_iv_color_cd_printer:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.961.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:2.2.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.0`,
        fs:  `cpe:2.3:a:michael_vogt:ubuntu-system-service:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.0.1`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.1`,
        fs:  `cpe:2.3:a:cososys:endpoint_protector:4.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.1.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.5r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.3`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.3.1`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.5.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.1:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.4.1`,
        fs:  `cpe:2.3:h:cisco:7100_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.4.2`,
        fs:  `cpe:2.3:a:perl:perl:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.4.3`,
        fs:  `cpe:2.3:a:sonicwall:aventail_opswat_end_point_control:10.1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.4.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.4.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.1`,
        fs:  `cpe:2.3:a:juniper:network_connect:6.4.0.14619:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.2`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.7:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.3`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.4`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/ru2_firmware:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.5`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.6`,
        fs:  `cpe:2.3:a:formsplayer.formsplayer:1.5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.301:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.8`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.9`,
        fs:  `cpe:2.3:a:smackcoders:wp_ultimate_email_marketer_plugin:1.0.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.10`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.11`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.13`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.14`,
        fs:  `cpe:2.3:a:jenkins:git:3.5.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.15`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.16`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.11.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.17`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server_supplementary_eus:6.7z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.18`,
        fs:  `cpe:2.3:a:ibm:connections:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.19`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.20`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.21`,
        fs:  `cpe:2.3:a:videowhisper:videowhisper_live_streaming_integration:4.27.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.22`,
        fs:  `cpe:2.3:a:f5:vpn_client_for_windows:60.2007.1001.2146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.23`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-50-09:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.24`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.25`,
        fs:  `cpe:2.3:a:services_single_sign-on_server_helper_project:services_single_sign-on_server_helper:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.26`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(19\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.27`,
        fs:  `cpe:2.3:h:carlosgavazzi:eos-box_photovoltaic_monitoring_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:3.5.28`,
        fs:  `cpe:2.3:a:vmware:view:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:19.0.m0.61045:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.1`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.3`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.1.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.6`,
        fs:  `cpe:2.3:h:citrix:application_gateway_for_avaya:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.7`,
        fs:  `cpe:2.3:h:dell:precision_m2300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.8`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.9`,
        fs:  `cpe:2.3:a:adobe:dreamweaver:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.10`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.11`,
        fs:  `cpe:2.3:a:gnu:screen:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(27\)sv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.13`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.14`,
        fs:  `cpe:2.3:a:php:pear:1.0b3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.15`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.16`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.17`,
        fs:  `cpe:2.3:h:emerson:avocent_dsr1031:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.18`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_115:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.19`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.60.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.20`,
        fs:  `cpe:2.3:a:php:php_fi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.21`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.15:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.22`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.23`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:4.0.24`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0`,
        fs:  `cpe:2.3:a:emc:networker:7.6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.1`,
        fs:  `cpe:2.3:a:php:pear:1.2b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)xe3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.4`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.5`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.6`,
        fs:  `cpe:2.3:a:hp:secure_web_console:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.7`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_viewer:12.2.211.1241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.8`,
        fs:  `cpe:2.3:h:cisco:nexus_5596up:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.10`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.11`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)ea3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.12`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.13`,
        fs:  `cpe:2.3:h:cisco:4404_wireless_lan_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.14`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.15`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.16`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.17`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.4p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.0.18`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1`,
        fs:  `cpe:2.3:a:apache:sling:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool_system_service_monitors:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.2`,
        fs:  `cpe:2.3:a:sybase:powerbuilder_client_runtime:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.3`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.4`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.5`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg810-5:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.6`,
        fs:  `cpe:2.3:a:apache:solr:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.7`,
        fs:  `cpe:2.3:a:isc:bind:9.8.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.8`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_si7_i\/o_driver:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.9`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.10`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.11`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.12`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.13`,
        fs:  `cpe:2.3:a:jesse_vincent:extension\:\:mobileui:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.15`,
        fs:  `cpe:2.3:a:clamav:clamav:0.96.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.16`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.17`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.18`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_4i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.19`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.20`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.1.21`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.1`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.2`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.13:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.4`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.5`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.6`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.1.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.8`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.9`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.10`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.11`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:64-bit-2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.12`,
        fs:  `cpe:2.3:a:zodiacdm:aboutme-plugin:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.14`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:8.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.15`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.16`,
        fs:  `cpe:2.3:a:rpm:rpm:4.6.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.17`,
        fs:  `cpe:2.3:a:ibm:sametime:7.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.18`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.19`,
        fs:  `cpe:2.3:a:trimble:sketchup:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.20`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-28c-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.21`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.22`,
        fs:  `cpe:2.3:a:novaboard:novaboard:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.2.23`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.626:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.2.06014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.2`,
        fs:  `cpe:2.3:a:tinymce:tinymce:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.405:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:06-71-\/g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.6`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.8`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.9`,
        fs:  `cpe:2.3:a:aas9:zerocms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.10`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_clientless_ssl_vpn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.11`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.3:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.12`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.3.8.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.13`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.14`,
        fs:  `cpe:2.3:a:vmware:player:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.15`,
        fs:  `cpe:2.3:a:quagga:quagga:0.97.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.16`,
        fs:  `cpe:2.3:o:netgear:prosafe_firmware:5.3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:5.3.17`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0`,
        fs:  `cpe:2.3:a:gnu:bash:4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.1`,
        fs:  `cpe:2.3:o:hp:tru64:5.1_pk5_bl19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.0:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.3`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.4`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-3.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.5`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.6`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.7`,
        fs:  `cpe:2.3:a:php:comoblog:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.8`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.9`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.026:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.10`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.11`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.2:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.12`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.13`,
        fs:  `cpe:2.3:a:digium:asterisk:13.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.14`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.15`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.16`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.17`,
        fs:  `cpe:2.3:o:cisco:vpn_5000_concentrator_series_software:6.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.18`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.19`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.20`,
        fs:  `cpe:2.3:a:aol:aolserver:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.21`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:259:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.22`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.23`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.24`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.91:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.25`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.26`,
        fs:  `cpe:2.3:o:cisco:vpn_5000_concentrator_series_software:6.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.27`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.0.28`,
        fs:  `cpe:2.3:a:teamquest:manager:10.1_pf_20080402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1`,
        fs:  `cpe:2.3:a:krisonav:krisonav:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.2`,
        fs:  `cpe:2.3:a:citrix:presentation_server_document_center:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.3`,
        fs:  `cpe:2.3:o:cisco:catos:7.6\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.4`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.5`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.6`,
        fs:  `cpe:2.3:a:shavlik:netchk_configure:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.7`,
        fs:  `cpe:2.3:a:google:chrome:16.0.910.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.8`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.9`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.10`,
        fs:  `cpe:2.3:a:ca:resource_initialization_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.11`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:primetek:primefaces:6.1.12`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:princetoncorporatesolutions:taking_your_company_public:1.28.44.441::~~~android~~`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:priorswood:acorn_comms:3::~~~android~~`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:5.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.602.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:5.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:5.2`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:5.3`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:5.4`,
        fs:  `cpe:2.3:a:meipai:meipai:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:5.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:5.6`,
        fs:  `cpe:2.3:a:redhat:directory_server:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:6.0`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.5:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:6.1`,
        fs:  `cpe:2.3:a:conky:conky:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:6.2`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:6.3`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:6.4`,
        fs:  `cpe:2.3:a:google:chrome:11.0.687.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0`,
        fs:  `cpe:2.3:a:apache:cassandra:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0:-`,
        fs:  `cpe:2.3:a:apache:knox:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0:-:enterprise`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0:-:opsconsole`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0:-:pulse`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0:beta`,
        fs:  `cpe:2.3:a:grape_project:grape:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0:beta:enterprise`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0:beta:opsconsole`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.0:beta:pulse`,
        fs:  `cpe:2.3:h:cisco:catalyst_4507r-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1:-`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1:-:cloud`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1:-:driveshield`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1:-:enterprise`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1:-:opscenter`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1:-:pulse`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.16.6:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1:-:seccenter`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.1:-:syslog`,
        fs:  `cpe:2.3:a:namazu:namazu:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2`,
        fs:  `cpe:2.3:a:samba:samba:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2:-:cloud`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.30:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2:-:driveshield`,
        fs:  `cpe:2.3:a:joachim_noreiko:flag_module:7.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:document_connect_for_application_support_facility:1.0.0.1218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2:-:opscenter`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2.9.312.2222:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2:-:pulse`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:1.3f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2:-:seccenter`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.2:-:syslog`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.6p6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3:-`,
        fs:  `cpe:2.3:a:vips:vips:7.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3:-:cloud`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg251a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3:-:driveshield`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:net.commerce_hosting_server:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3:-:opscenter`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3:-:pulse`,
        fs:  `cpe:2.3:a:mig:migme:4.03.002:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3:-:seccenter`,
        fs:  `cpe:2.3:a:cisco:unified_ccx:6.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prismmicrosys:eventtracker:7.3:-:syslog`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privatemsg_project:privatemsg:7.x-1.0`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privatemsg_project:privatemsg:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privatemsg_project:privatemsg:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.10.11:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privatemsg_project:privatemsg:7.x-1.1`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privatemsg_project:privatemsg:7.x-1.2`,
        fs:  `cpe:2.3:a:cisco:jabber_guest:10.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privatemsg_project:privatemsg:7.x-1.3`,
        fs:  `cpe:2.3:h:ibm:integrated_management_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privatemsg_project:privatemsg:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:rama-palaniappan:calculatorapp:4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:privatemsg_project:privatemsg:7.x-2.x-dev`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privatetunnel:privatetunnel:2.3.8`,
        fs:  `cpe:2.3:a:aol:aolserver:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privawall:privawall_antivirus:5.6`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privoxy:privoxy:3.0.22`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:privoxy:privoxy:3.0.23`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pro_bet_tips_project:pro_bet_tips:0.2::~~~android~~`,
        fs:  `cpe:2.3:a:nuance:dragon_sdk:10.10.0.431:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pro_quoter_plugin_project:pro_quoter:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:0.9`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:0.9.1`,
        fs:  `cpe:2.3:a:yassl:cyassl:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:0.9.8`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:1.0.0`,
        fs:  `cpe:2.3:a:ez:ez_publish:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:1.1.0`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:1.1.1`,
        fs:  `cpe:2.3:a:symantec:enterprise_firewall:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:1.1.1.0`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:1.1.1.1`,
        fs:  `cpe:2.3:a:opus-codec:opus:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:1.1.2`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:1.1.3`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.0.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:1.1.14`,
        fs:  `cpe:2.3:a:oracle:database_server:12.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.0.0`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.0.0:beta1`,
        fs:  `cpe:2.3:a:redhat:jboss_web_framework_kit:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.0.0:rc1`,
        fs:  `cpe:2.3:a:php:php:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.0.1_2`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.882:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.0.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.0.3`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.0.4`,
        fs:  `cpe:2.3:a:vmware:workstation_player:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.0.5`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.0`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.1`,
        fs:  `cpe:2.3:a:openstack:horizon:2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.3`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.4`,
        fs:  `cpe:2.3:a:services_project:services:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.5`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.6`,
        fs:  `cpe:2.3:a:google:v8:3.24.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.7`,
        fs:  `cpe:2.3:a:ubnt:unifi:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.8`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.9`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.10`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.11`,
        fs:  `cpe:2.3:h:axis:2420_video_server:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.12`,
        fs:  `cpe:2.3:a:xnview:xnview:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:2.1.13`,
        fs:  `cpe:2.3:h:huawei:acu:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:3.0.0:alpha1`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:3.0.0:alpha2`,
        fs:  `cpe:2.3:a:fire_equipments_screen_lock_project:fire_equipments_screen_lock:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:ejabberd:3.0.0:alpha3`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:exmpp:0.9.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:exmpp:0.9.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:exmpp:0.9.3`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:exmpp:0.9.4`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:exmpp:0.9.5`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:exmpp:0.9.6`,
        fs:  `cpe:2.3:a:postfix:postfix:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:process-one:exmpp:0.9.7`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prochatrooms:text_chat_rooms:8.2.0`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.3:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:procmail:procmail:3.12`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:procmail:procmail:3.20`,
        fs:  `cpe:2.3:a:sun:jre:1.3.0:update4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:procmail:procmail:3.22`,
        fs:  `cpe:2.3:a:lxml:lxml:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prodad:vitascene:1.0`,
        fs:  `cpe:2.3:a:posh_project:posh:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:productcart:productcart:3.0`,
        fs:  `cpe:2.3:o:ibm:vios:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:productcart:productcart:4.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:productcart:productcart:4.1:sp1`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:profile2_privacy_project:profile2_privacy:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:yahama:rtv700:8.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:profile2_privacy_project:profile2_privacy:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:profile2_privacy_project:profile2_privacy:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:profile2_privacy_project:profile2_privacy:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:profile2_privacy_project:profile2_privacy:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:profile2_privacy_project:profile2_privacy:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yf4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.0:pre10`,
        fs:  `cpe:2.3:a:site2nite:auto_e-manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.0:pre9`,
        fs:  `cpe:2.3:o:hp:openvms:8.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.0:rc1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.22.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.0:rc2`,
        fs:  `cpe:2.3:a:apache:pdfbox:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.0:rc3`,
        fs:  `cpe:2.3:a:citrix:access_management_console_legacy_tools:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.2`,
        fs:  `cpe:2.3:a:emc:isilon_insightiq:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.2:rc1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.2:rc2`,
        fs:  `cpe:2.3:a:conntrack-tools_project:conntrack-tools:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.2:rc3`,
        fs:  `cpe:2.3:a:nancy_wichmann:announcements:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.3`,
        fs:  `cpe:2.3:a:nttdata:terasoluna_server_framework_for_java_web:2.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.4`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_desktop_agent:3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.5`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns2200rx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.5:rc1`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.5:rc2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.5:rc3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.6`,
        fs:  `cpe:2.3:a:indus-systems:idrawings_setup:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.6:rc1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.06:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.6:rc2`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.7`,
        fs:  `cpe:2.3:o:schneider-electric:telvent_sage_3030_firmware:c3413-500-001f0_pb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.7:rc1`,
        fs:  `cpe:2.3:a:horde:imp:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.7:rc2`,
        fs:  `cpe:2.3:a:blackberry:qnx_momentics_tool_suite:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.7:rc3`,
        fs:  `cpe:2.3:a:red-gate:sql_packager:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.8`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.8:rc1`,
        fs:  `cpe:2.3:a:apache:struts:2.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.8:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.9`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.9:rc1`,
        fs:  `cpe:2.3:a:ethereal:ethereal:0.9.13a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.9:rc2`,
        fs:  `cpe:2.3:a:ibm:sterling_connect:4.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.9:rc3`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.0.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.10`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer_with_flow_analytics_module:9.5.2:-:pay:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.10:rc1`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.10:rc2`,
        fs:  `cpe:2.3:a:umn:mapserver:4.6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.2.10:rc3`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2010:14.0.903.32:*:*:*:server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.6\(1.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.0:a`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.2.4:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.0:rc1`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.0:rc2`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.0:rc3`,
        fs:  `cpe:2.3:a:hp:trayapp:110.0.180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.0:rc4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.0:rc5`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.1:rc1`,
        fs:  `cpe:2.3:h:juniper:srx5400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.1:rc2`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.1:rc3`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2`,
        fs:  `cpe:2.3:a:adobe:asset_services:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:a`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:b`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:c`,
        fs:  `cpe:2.3:a:ibm:messagesight_jms_client:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:d`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:e`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:rc1`,
        fs:  `cpe:2.3:o:cisco:catos:7.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:rc2`,
        fs:  `cpe:2.3:a:php:php:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:rc3`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.2:rc4`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)sqd6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.3:a`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.3:b`,
        fs:  `cpe:2.3:o:huawei:mate_8_firmware:nxt-al10c00b197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.3:c`,
        fs:  `cpe:2.3:a:google:chrome:8.0.561.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.3:rc1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.31b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.3:rc2`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.3:rc3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.3:rc4`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.4`,
        fs:  `cpe:2.3:a:tibco:spotfire_analyst:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.4:a`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.4:b`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.4:c`,
        fs:  `cpe:2.3:a:gnu:cpio:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.4:d`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.74:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.4:rc1`,
        fs:  `cpe:2.3:a:flightgear:flightgear:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.4:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ja1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.4:rc3`,
        fs:  `cpe:2.3:a:1024cms:1024_cms:1.4.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.5:a`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.11.459:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.5:rc1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.5:rc2`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.5:rc3`,
        fs:  `cpe:2.3:h:siemens:spc4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:proftpd:proftpd:1.3.6:rc1`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progea:movicon:11.4`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progea:movicon:11.4.1150`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:4gl_compiler:-`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:database:-`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:database:9.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:objectstore:-`,
        fs:  `cpe:2.3:a:uhcu:united_heritage_mobile:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:objectstore:6.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:objectstore:6.1.1`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:objectstore:6.1.2`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:objectstore:6.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7.7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:objectstore:6.2.5`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:openedge:-`,
        fs:  `cpe:2.3:a:cisco:access_registrar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:openedge:9.1e`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:openedge:10.1a`,
        fs:  `cpe:2.3:a:hp:bufferchm:60.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:openedge:10.1b`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(12a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:webspeed:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:webspeed:3.0`,
        fs:  `cpe:2.3:a:sympa:sympa:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:webspeed:3.1a`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:webspeed:3.1d`,
        fs:  `cpe:2.3:a:hp:quality_center_client_side:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:webspeed:3.1e`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:progress:webspeed_messenger:-`,
        fs:  `cpe:2.3:h:extremenetworks:alpine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:project-redcap:redcap:4.14.0`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:project-redcap:redcap:4.14.1`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:project-redcap:redcap:4.14.2`,
        fs:  `cpe:2.3:a:intel:network_connections:15.8.76.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:project-redcap:redcap:4.14.3`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:project-redcap:redcap:4.14.4`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.00.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:3.4.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_ip_gateway:2.0.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:3.4.1`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.1.644:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:3.4.2`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:3.4.3`,
        fs:  `cpe:2.3:h:cisco:callmanager_express:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:3.5.0`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:3.5.1`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:3.5.2`,
        fs:  `cpe:2.3:a:networknotepad:network_notepad:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:3.5.3`,
        fs:  `cpe:2.3:a:hp:scan:12.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:5.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:5.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:5.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4gc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectforge:projectforge:5.3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:100`,
        fs:  `cpe:2.3:a:ca:antispyware_for_the_enterprise:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:102`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:105`,
        fs:  `cpe:2.3:a:componentone:flexgrid:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:110`,
        fs:  `cpe:2.3:a:linecorp:line\@:1.2.1:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:155`,
        fs:  `cpe:2.3:a:adobe:help_viewer:1.1.198:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:156`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:08:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:157`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:161`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:180`,
        fs:  `cpe:2.3:a:icinga:icinga:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:335`,
        fs:  `cpe:2.3:a:gnu:automake:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:375`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:405`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.558:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:412`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:514`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsend:projectsend:561`,
        fs:  `cpe:2.3:a:symantec:norton_security_scan:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projectsprouts:sprout:0.7.246:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.1.0`,
        fs:  `cpe:2.3:o:sun:sunos:4.0.3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.2.0`,
        fs:  `cpe:2.3:a:cisco:subscriber_edge_services_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.3.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.4.0`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s7506e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.5.0`,
        fs:  `cpe:2.3:a:apple:webkit:106.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.6.0`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.6.1`,
        fs:  `cpe:2.3:a:ibm:rational_directory_server:5.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.7.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.8.0`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.8.1`,
        fs:  `cpe:2.3:a:mono:mono:1.1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:0.9.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.0.0`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.0.1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.6:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.1.0`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.2.0`,
        fs:  `cpe:2.3:a:kindsoft:kind_editor:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.2.1`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.3.0`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.3.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.3.1`,
        fs:  `cpe:2.3:h:linksys:befvp41:1.42.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.4.0`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.4.1`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.4.2`,
        fs:  `cpe:2.3:a:craig_barratt:backuppc:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.5.0`,
        fs:  `cpe:2.3:a:citrix:access_essentials:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.5.1`,
        fs:  `cpe:2.3:a:iveo:iveo_viewer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.5.2`,
        fs:  `cpe:2.3:a:boost:boost:1.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.5.3`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(11b\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.5.4`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.5.5`,
        fs:  `cpe:2.3:a:mr384_project:mzone_login:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.6.0`,
        fs:  `cpe:2.3:a:google:chrome:5.0.360.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.6.1`,
        fs:  `cpe:2.3:a:quest:big_brother_system_and_network_monitor_client:1.8.4000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.6.2`,
        fs:  `cpe:2.3:a:ibm:connections:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.7.0`,
        fs:  `cpe:2.3:a:lester_chan:wp-downloadmanager:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.7.1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.7.2`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.8.0`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.8.1`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.05\/33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.8.2`,
        fs:  `cpe:2.3:a:digium:asterisk:c.1.6:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.8.3`,
        fs:  `cpe:2.3:a:debian:bsmtpd:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.9.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1068.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:1.9.1`,
        fs:  `cpe:2.3:a:isc:bind:9.10.4:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.0.1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.1.0`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.1.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.2.0`,
        fs:  `cpe:2.3:a:invensys:daserver_runtime_components:3.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.2.1`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.2.2`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.2.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.3.0`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.2.0:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.4.0`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.4.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.4.2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.4.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.5.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg307a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.5.1`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.5.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.5.3`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s3600-52p-ei_ls-3600-52p-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.6.0`,
        fs:  `cpe:2.3:a:call-cc:chicken:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5.1\)xp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.6.2`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:2.6.3`,
        fs:  `cpe:2.3:a:mit:kerberos:5_1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.0.0`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.0.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.0:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.0.2`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.1.1`,
        fs:  `cpe:2.3:a:inria:ocaml:3.05:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.1.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.1.3`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.1.4`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:p2_w1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.2.0`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.2.1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.2.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.3.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.91.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.3.1`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:6.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.3.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.4.0`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:2003:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.4.1`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.4.2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.4.3`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:3.4.4`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:4.0.0`,
        fs:  `cpe:2.3:a:vmware:ovf_tool:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:4.0.1`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g54_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:projeqtor:projeqtor:4.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:p96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prolific:ez-dub_finder:0.2.0.3`,
        fs:  `cpe:2.3:a:avaya:interactive_response:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.1`,
        fs:  `cpe:2.3:o:huawei:p2-6011_firmware:v100r001c00b042:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.2`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.3`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.5`,
        fs:  `cpe:2.3:a:apache:poi:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.6`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.7`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.8`,
        fs:  `cpe:2.3:h:hp:2500c_pro_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.9`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.10`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3u\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.11`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.1.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.12`,
        fs:  `cpe:2.3:a:d-link:dap-1360_firmware:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.0.13`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server_eus:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.1.0`,
        fs:  `cpe:2.3:a:yahoo:yafuoku\!:4.3.0:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.1.1`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.1.2`,
        fs:  `cpe:2.3:h:softbank:disney_mobile_android_smartphone:dm010sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.1.3`,
        fs:  `cpe:2.3:a:hp:sitescope_monitoring:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotic:promotic:8.1.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:promotionalshop:promotional_items:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:messagesight_jms_client:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.1.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.2.0`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.3.0`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.4.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.4.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.4.2`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.5.0`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.5.1`,
        fs:  `cpe:2.3:a:hp:software_update:3.0.2.991:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.21:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.6.0`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.0.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.6.1`,
        fs:  `cpe:2.3:a:fuseiso_project:fuseiso:20070708:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.6.2`,
        fs:  `cpe:2.3:a:aol:browser:1.6:-:standalone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.7.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_fasttrack:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.8.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)yu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.8.1`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.8.2`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.0`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.1`,
        fs:  `cpe:2.3:a:redmine:redmine:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.2`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.3`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d55:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.5`,
        fs:  `cpe:2.3:h:sun:storagetek_3510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.6`,
        fs:  `cpe:2.3:a:gnu:automake:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.7`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.0.1570:online_windows_2003_x64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosody:prosody:0.9.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosoft-technology:radiolinx_controlscape:6.00`,
        fs:  `cpe:2.3:a:justsystems:hanako:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prosoft-technology:radiolinx_controlscape:6.00.040`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:protected_pages_project:protected_pages:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:digium:asterisk:10.7.0:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:protected_pages_project:protected_pages:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p142:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:protected_pages_project:protected_pages:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:prothemedesign:mimbo_pro:2.3.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:0.02`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:0.2.1`,
        fs:  `cpe:2.3:a:munsoft:easy_office_recovery:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:0.3`,
        fs:  `cpe:2.3:o:hp:palm_webos:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:0.3.1`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.0`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.7-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3`,
        fs:  `cpe:2.3:a:vips:vips:7.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.1`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.2`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4mg_firmware:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.3`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.4`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.6`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.7`,
        fs:  `cpe:2.3:a:php:php:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.8`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.3.9`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:libunity-webapps:2.4.0`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:0.02:-:~~~firefox~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:0.2.1:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:0.3:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:redhat:freeipa:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:0.3.1:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.1:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.580.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.2:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:apache:struts:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.3:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.3.1:-:~~~firefox~~`,
        fs:  `cpe:2.3:h:huawei:ne80e:v600r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.3.2:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.5:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.3.3:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:plone:plone:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.3.4:-:~~~firefox~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.3.5:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:oracle:report_manager:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.4.0:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:analogx:proxy:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ps_project_management_team:unity-firefox-extension:2.4.1:-:~~~firefox~~`,
        fs:  `cpe:2.3:a:adobe:adobe_presenter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psecu:psecu_mobile%2b:2.2::~~~android~~`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psi-plus:psi:0.15.5122`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.17:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psi-plus:psi:0.15.5145`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pswitch:imail:8.22`,
        fs:  `cpe:2.3:a:teeworlds:teeworlds:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psyced:psyced:20081120`,
        fs:  `cpe:2.3:a:picsart:picsart_-_photo_studio:4.5.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:psyced:psyced:20090323`,
        fs:  `cpe:2.3:h:lexmark:c73x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psyced:psyced:20090617`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psyced:psyced:20111122`,
        fs:  `cpe:2.3:h:ruckuswireless:zoneflex_2942:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psyced:psyced:20120821`,
        fs:  `cpe:2.3:a:tntnet:tntnet:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychology_project:psychology:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:16.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.0:beta`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.0.1:beta`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.1:beta`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.2:beta`,
        fs:  `cpe:2.3:a:advantech:advantech_webaccess:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.2.1:beta`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20090417:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.2.2:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.17.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.2.4:beta`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.3`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.3:beta`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.3.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:2.3.3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:3.0.6b`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:psychostats:psychostats:3.2.2b`,
        fs:  `cpe:2.3:a:apple:safari:3.0.2:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ptc:creo_view:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.2\(2g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ptc:isoview:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_download_count_project:public_download_count:7.x-1.x-dev::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:office:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.0`,
        fs:  `cpe:2.3:a:opentext:opentext\/ixos_ecm_for_sap_netweaver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.1.1`,
        fs:  `cpe:2.3:a:cherokee-project:cherokee:1.2.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.1.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.1.3`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.1.4`,
        fs:  `cpe:2.3:a:drupal:drupal:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.1.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.557:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.1.6`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20140603:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:1.1.7`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.1`,
        fs:  `cpe:2.3:a:cononical:ubuntu:14.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.1.0-1`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.1.1`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.1:cf010:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.1.1-1`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.1.1.-2`,
        fs:  `cpe:2.3:a:krisonav:krisonav:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.1.2`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.9:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.1.2-1`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.3.1`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.3.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.3.3-1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:public_knowledge_project:open_conference_systems:2.3.4`,
        fs:  `cpe:2.3:a:verizon:vz_in_home_agent:7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:publicstuff:elk_grove_publicstuff:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.05.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:0.9.23`,
        fs:  `cpe:2.3:a:google:v8:3.22.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:0.99.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:0.99.2`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:0.99.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:1.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:1.1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:1.99.1`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.60.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:1.99.2`,
        fs:  `cpe:2.3:a:duplicator_project:duplicator:0.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:2.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:2.1`,
        fs:  `cpe:2.3:a:lindo:lingo:12.0.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:3.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:4.0`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseaudio:pulseaudio:5.0`,
        fs:  `cpe:2.3:o:ibm:aix:5.3:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.0:-:basic`,
        fs:  `cpe:2.3:o:google:android:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.1:-:basic`,
        fs:  `cpe:2.3:a:sun:jre:6.0.290:update29:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.01:-:basic`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.6.606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2:-:basic`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2.1:-:basic`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2.2:-:basic`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2.3:-:basic`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2.4:-:basic`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2.5:-:basic`,
        fs:  `cpe:2.3:h:schneider-electric:bmxnoe0100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2.6:-:basic`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2.7:-:basic`,
        fs:  `cpe:2.3:a:hp:software_cross_platform_component:6.20.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.2.8:-:basic`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3:-:pro`,
        fs:  `cpe:2.3:o:xen:xen:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.1:-:pro`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.2:-:pro`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.3:-:pro`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.4:-:pro`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.5:-:pro`,
        fs:  `cpe:2.3:a:hp:centralview_roaming_fraud_control:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.6:-:pro`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.6.1:-:pro`,
        fs:  `cpe:2.3:a:horde:gollem:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.7:-:pro`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.3.8:-:pro`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.4:-:pro`,
        fs:  `cpe:2.3:a:isc:bind:9.8.5:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.4.1:-:pro`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.4.2:-:pro`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1034:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.4.3:-:pro`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.4.4:-:pro`,
        fs:  `cpe:2.3:o:bluecoat:cacheos_ca:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.4.5:-:pro`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.17.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.4.5.1:-:pro`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.4.6:-:pro`,
        fs:  `cpe:2.3:a:yahoo:yui:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.15:-:basic`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.16:-:basic`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.17:-:basic`,
        fs:  `cpe:2.3:a:symantec:client_security:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsecms:pulse_cms:1.18:-:basic`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulseinfotech:com_flipwall:1.1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:client:-::~~~android~~`,
        fs:  `cpe:2.3:a:commvault:exchange_database_idataagent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:client:-::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:emc:networker:7.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4`,
        fs:  `cpe:2.3:a:gnu:tar:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r1.0`,
        fs:  `cpe:2.3:a:google:chrome:52.0.2743.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r2.0`,
        fs:  `cpe:2.3:h:cisco:pix_firewall_520:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r3.0`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r4.0`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.829.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r5.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r6.0`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r7.0`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:7.0.164.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r8.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r9.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r9.1`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r9.2`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:16.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r9.3`,
        fs:  `cpe:2.3:a:x:libglx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r10.0`,
        fs:  `cpe:2.3:a:cisco:expressway_software:x8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r11.0`,
        fs:  `cpe:2.3:h:nortel:vpn_router_1700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r11.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r12.0`,
        fs:  `cpe:2.3:o:d-link:dir-905l_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r13.0`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r13.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.447.1.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r13.2`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99.1:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:7.4r13.3`,
        fs:  `cpe:2.3:h:cisco:catalyst_6000_ws-svc-nam-1:2.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p383:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r1.0`,
        fs:  `cpe:2.3:a:promotic:promotic:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r1.1`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.0.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r2.0`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r3.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r3.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r3.2`,
        fs:  `cpe:2.3:a:php:php:2.0b10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r4.0`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r4.1`,
        fs:  `cpe:2.3:a:nortel:61c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r5.0`,
        fs:  `cpe:2.3:a:ca:directory:12.0.4574:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r6.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r7.0`,
        fs:  `cpe:2.3:o:ibm:aix:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r7.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r8.0`,
        fs:  `cpe:2.3:a:mediaplayercodecpack:media_player_codec_pack:3.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r8.1`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r9.0`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.0r10.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.1`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.1r1.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.03.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.1r1.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.1r2.0`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.1r2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:pulse_connect_secure:8.2`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pulsesecure:steel_belted_radius:-`,
        fs:  `cpe:2.3:a:dell:equallogic_host_integration_tools:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.0`,
        fs:  `cpe:2.3:a:spip:spip:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.1`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.1:rc1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.1:rc2`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.1:rc3`,
        fs:  `cpe:2.3:a:redhat:pam_smb:1.1.6-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.1:rc4`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.2`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.2:rc1`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.3:rc1`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(23f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.4:rc1`,
        fs:  `cpe:2.3:a:saltstack:salt:0.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.5`,
        fs:  `cpe:2.3:o:yahama:rtw65i:5.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.5:rc1`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.6`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.6:rc1`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.6:rc2`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.7`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.7:rc1`,
        fs:  `cpe:2.3:a:hp:readme:50.0.206.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.8`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.8:rc1`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.9`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.9:rc1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.10`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.5.146:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.10:rc1`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.a7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.11`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.11:rc1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.12`,
        fs:  `cpe:2.3:a:intel:network_connections:14.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.12:rc1`,
        fs:  `cpe:2.3:a:ioserver:ioserver_opc_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.12:rc2`,
        fs:  `cpe:2.3:a:php:php:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.13`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.13:rc1`,
        fs:  `cpe:2.3:a:hitachi:it_operations_analyzer:02-53-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.14`,
        fs:  `cpe:2.3:a:x:libxi:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.14:rc1`,
        fs:  `cpe:2.3:o:huawei:e355_firmware:21.157.37.01.910:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.15`,
        fs:  `cpe:2.3:a:python:python:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.15:rc1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:2.1:*:aw:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.16`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.20.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.17`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.17:rc1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.316.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.18`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120711:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.6.18:rc1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.0`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.9505:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.0:rc1`,
        fs:  `cpe:2.3:a:nuance:omnipage:11.0.1:*:*:*:se:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.0:rc2`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.1`,
        fs:  `cpe:2.3:a:devsaran:responsive:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.1:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.2`,
        fs:  `cpe:2.3:a:9jacompass:epl_hat_trick:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.2:rc1`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.3`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.3:rc1`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.4`,
        fs:  `cpe:2.3:a:cisco:libsrtp:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.4:rc1`,
        fs:  `cpe:2.3:a:digia:qt:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.5`,
        fs:  `cpe:2.3:a:monotone:monotone:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.5:rc1`,
        fs:  `cpe:2.3:a:intel:network_connections:14.0.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.5:rc2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:1.7.6`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.0:rc1`,
        fs:  `cpe:2.3:a:atlassian:jira:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.0:rc2`,
        fs:  `cpe:2.3:a:docker:docker:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.0:rc3`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.0:rc4`,
        fs:  `cpe:2.3:a:mcafee:cloud_identity_manager:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.314.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.1:rc1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.1:rc2`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.1:rc3`,
        fs:  `cpe:2.3:a:divx:player:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.1:rc4`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.0.2`,
        fs:  `cpe:2.3:a:novell:extend_director:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.1.0`,
        fs:  `cpe:2.3:a:efstechnology:autoform_pdm_archive:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.2.0`,
        fs:  `cpe:2.3:a:osticket:osticket:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.3.0`,
        fs:  `cpe:2.3:o:buffalotech:wex-300_firmware:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:facter:2.4.0`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:hiera:1.3.3`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.5.1`,
        fs:  `cpe:2.3:a:zope:zope:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.7.0`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.0`,
        fs:  `cpe:2.3:a:gnome:gnome-keyring:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.1`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.2`,
        fs:  `cpe:2.3:a:hp:loadrunner:12.02:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.3`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.4`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-05-\/o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.6`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.7`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_appliance:7.2:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:marionette-collective:2.8.8`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:0.25.0`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:1.3.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:0.25.1`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:0.25.2`,
        fs:  `cpe:2.3:a:adobe:xmp_panels_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:0.25.3`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.0:build110512:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:0.25.4`,
        fs:  `cpe:2.3:o:sgi:irix:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:0.25.5`,
        fs:  `cpe:2.3:a:ibm:rational_performance_tester:8.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:0.25.6`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:1.0:-:enterprise`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:1.1:-:enterprise`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:1.2:-:enterprise`,
        fs:  `cpe:2.3:a:vmware:vcenter_update_manager:4.0.0.3971:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:mozilla:camino:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.0.2:-:enterprise`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.0.3:-:enterprise`,
        fs:  `cpe:2.3:a:adaptivelearningsystems:sun_cx-310-200_solaris_10_administrator_\(scsa\)_part_1:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.5.1:-:enterprise`,
        fs:  `cpe:2.3:a:opnet:modeler:16.0.0.10261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.5.2:-:enterprise`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.1`,
        fs:  `cpe:2.3:a:tincan:phplist:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.2`,
        fs:  `cpe:2.3:a:digia:qt:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.3`,
        fs:  `cpe:2.3:a:kishore_asokan:kish_guest_posting_plugin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.4`,
        fs:  `cpe:2.3:a:cisco:ucs_director:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.5`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_regis_graphics_server:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.6`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.7`,
        fs:  `cpe:2.3:h:hp:4m_plus_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.8`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.9`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:1.3.0.20-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.10`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.11`,
        fs:  `cpe:2.3:a:oracle:forms:6i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.12`,
        fs:  `cpe:2.3:o:sun:solaris:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.13`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:18-10-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.14`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.7.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.15`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.6.16`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.1`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)t17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.360:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2008.717.2343.40629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.5`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.7`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.9`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.10`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.11`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.12`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.15:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.13`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.14`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.16`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.17`,
        fs:  `cpe:2.3:a:shopware:shopware:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.18`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.21`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.22`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.23`,
        fs:  `cpe:2.3:a:google:chrome:14.0.827.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.7.26`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.0:-:enterprise`,
        fs:  `cpe:2.3:a:freedomscientific:talking_installer:11.0.756.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.1:-:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.2:-:enterprise`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.3:-:enterprise`,
        fs:  `cpe:2.3:a:ca:etrust_audit_policy_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:perl:perl:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.5::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.6\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.99.904:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2.8.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.0.0`,
        fs:  `cpe:2.3:a:novell:netware_ftp_server:5.06.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.0.0:-:enterprise`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.12.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.0.1`,
        fs:  `cpe:2.3:a:tincan:phplist:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.0.1:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.0.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.1.0:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:7.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.1.1:-:enterprise`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_license_assessment_tool:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(16.5\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.2.0:-:enterprise`,
        fs:  `cpe:2.3:o:huawei:mate_8_firmware:nxt-tl10c00b197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.2.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.2.2`,
        fs:  `cpe:2.3:h:pgp:e-ppliance_300:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.2.3`,
        fs:  `cpe:2.3:a:novell:identity_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.2.4`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.3.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.3.1`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.3.2`,
        fs:  `cpe:2.3:a:ibm:maximo_anywhere:7.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.4.0`,
        fs:  `cpe:2.3:a:adobe:type_support_cs4:9.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.6.1`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.7.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:codeeta:codeeta_coupons:1.0.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:3.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet:2016.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.1p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.0.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.0.3`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:7.0\(2\)_sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.0.4`,
        fs:  `cpe:2.3:a:hp:openview_event_correlation_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.1.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:8.5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.1.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.2.0`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.2.1`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:4.3:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.2.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.2.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.2.4`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:6.06:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_dashboard:1.2.5`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:3.8.0`,
        fs:  `cpe:2.3:a:hp:wbem:a.01.05.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:3.8.1`,
        fs:  `cpe:2.3:o:huawei:ar_firmware:v200r005c20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:3.8.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.223:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:2015.2.0`,
        fs:  `cpe:2.3:a:hp:operations_manager:9.21:*:*:*:*:unix:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:2015.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:2015.2.2`,
        fs:  `cpe:2.3:a:x:libxxf86vm:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:2015.3.3`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:2016.4.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise:2016.5.1`,
        fs:  `cpe:2.3:a:apple:cups:1.4:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:1.2`,
        fs:  `cpe:2.3:a:sun:wbem_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:1.2.0`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:1.2.1`,
        fs:  `cpe:2.3:a:symantec:scan_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:1.2.2`,
        fs:  `cpe:2.3:a:php:php:5.4.12:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:1.2.3`,
        fs:  `cpe:2.3:a:gtk:gtk\&#43;:3.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:1.2.4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1032:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:2.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.26.630:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:2.0.1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:2.0.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_enterprise_users:2.5.0`,
        fs:  `cpe:2.3:a:bareftp:bareftp:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppet_server:0.2.0`,
        fs:  `cpe:2.3:h:huawei:s3300:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppetlabs-rabbitmq:3.0.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppetlabs-rabbitmq:3.1.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:puppetlabs-rabbitmq:4.0.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:riskdashboard:paarfatron:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.1.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.1.1::~~~puppet~~`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.1.2::~~~puppet~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.1.3::~~~puppet~~`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.2.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:apache:struts:2.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.2.1::~~~puppet~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.3.0::~~~puppet~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.3.1::~~~puppet~~`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:sp1_alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.3.2::~~~puppet~~`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.3.3::~~~puppet~~`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.4.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:2.5.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:3.0.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update11_b03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.1.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:opentext:desktop_viewer_lm:8.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.2.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.2.1::~~~puppet~~`,
        fs:  `cpe:2.3:a:facsys:facsys_desktop_client:5.1.406.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.2.2::~~~puppet~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.3.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:emc:documentum_xplore:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.3.1::~~~puppet~~`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.63:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.3.2::~~~puppet~~`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.4.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:og_tabs_project:og_tabs:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:puppetlabs:stdlib:4.5.0::~~~puppet~~`,
        fs:  `cpe:2.3:a:zemanta:search_everything:7.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pureedge:pureedge_viewer:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureedge:pureedge_viewer:1.0.0`,
        fs:  `cpe:2.3:a:web2py:web2py:1.84.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureedge:pureedge_viewer:2.0`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:16.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.90`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.91`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.92`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.93`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.94`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a1\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.95`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.12:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.95:pre1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.95:pre2`,
        fs:  `cpe:2.3:a:altova:xmlspy_2008:2.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.95:pre3`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.95:pre4`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.95.1`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:9.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.95.2`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.06:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.96`,
        fs:  `cpe:2.3:a:icinga:icinga:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.96:pre1`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.87\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.96.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.01:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97:pre1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97:pre2`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l3_controller_firmware:20.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97:pre3`,
        fs:  `cpe:2.3:a:haxx:curl:7.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97:pre4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97:pre5`,
        fs:  `cpe:2.3:a:gapless_player:simzip:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97-final`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:f9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.1`,
        fs:  `cpe:2.3:a:enalean:tuleap:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(5\)ca1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.3`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2-p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.4`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.5`,
        fs:  `cpe:2.3:a:joe_haskins:og_manager_change:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.6`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.7:pre1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.7:pre2`,
        fs:  `cpe:2.3:a:plone:plone:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.97.7:pre3`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg810-10:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98:final`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(13\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98:pre1`,
        fs:  `cpe:2.3:a:viscacha:viscacha:0.8:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98:pre2`,
        fs:  `cpe:2.3:a:kelly_d._redding:kelredd-pruview:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98.2`,
        fs:  `cpe:2.3:h:ibm:power_5:9124-720:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98.2:a`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98.3`,
        fs:  `cpe:2.3:a:luracast:restler:1.7.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98.4`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_desktop:10:sp4:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.61a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98.6`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.98.7`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99:a`,
        fs:  `cpe:2.3:a:swiftkey:swiftkey_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99:b`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99:pre1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.01a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99:pre2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99.1:a`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99.1:b`,
        fs:  `cpe:2.3:a:saltstack:salt:0.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99.2`,
        fs:  `cpe:2.3:h:hp:jf284a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99.2:a`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc691a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99.3`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.15.1:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99.4`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:0.99.9`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.0`,
        fs:  `cpe:2.3:h:iodata:hdl2-a\/e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.1`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.3`,
        fs:  `cpe:2.3:h:f5:big-ip_4100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.4`,
        fs:  `cpe:2.3:a:visionael:visionael_studio:8.1.0.3455:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.5`,
        fs:  `cpe:2.3:a:teradata:sm3g_open:1.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.7`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.8`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.17.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.14.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.11`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.12`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.13:a`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.14`,
        fs:  `cpe:2.3:o:cisco:aironet_access_point_software:8.1\(15.14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.16:a`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62o:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.16:b`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.16:c`,
        fs:  `cpe:2.3:a:libexpat:expat:1.95.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.17`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.17:a`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.4:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.18`,
        fs:  `cpe:2.3:a:drupal:drupal:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.19`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.20`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.21`,
        fs:  `cpe:2.3:a:microsoft:money:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.22`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.24`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.25`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.26`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.27`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.28`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server_solution_engine:5.5.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.29`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.30`,
        fs:  `cpe:2.3:o:compaq:tru64:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.31`,
        fs:  `cpe:2.3:a:hp:sitescope:11.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pureftpd:pure-ftpd:1.0.32`,
        fs:  `cpe:2.3:h:iodata:np-bbrm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:purplebeanie:com_pbbooking:2.4::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pushpinsapp:pushpins_grocery_coupons:1.56::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:livereg:2.3.0.1833:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:puzzles_and_matchup_games_project:educational_puzzles_-_letters:2.0::~~~android~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pwgen_project:pwgen:2.06`,
        fs:  `cpe:2.3:a:hp:storageworks_hp-ux_11.00_11.11_host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pwgrandom_project:pwgrandom:1.11::~~~wordpress~~`,
        fs:  `cpe:2.3:h:huawei:quidway_s5300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pwicorp:privatefirewall:7.0.20.37`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pxz_project:pxz:4.999.99:beta3`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pydio:pydio:5.0.3`,
        fs:  `cpe:2.3:a:apache:commons-compress:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pydio:pydio:6.0.6`,
        fs:  `cpe:2.3:a:kde:koffice:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:1.2.2`,
        fs:  `cpe:2.3:a:siemens:wincc:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:1.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p293:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:1.3.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:1.4`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:1.5`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.1:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:1.6`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:1.6:rc1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:2.0:rc1`,
        fs:  `cpe:2.3:a:oracle:jd_edwards_enterpriseone_tools:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pygments:pygments:2.0.1`,
        fs:  `cpe:2.3:a:playrix:township:1.5.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:pyplate:pyplate:0.08`,
        fs:  `cpe:2.3:a:matthias_hutterer:email:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:1.7.8`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.02b11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.2.2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.833:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.3.0`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.3.1`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.4.0`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.5.0`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:2.6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.5.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.5.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.5.3`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:7.0.3:mr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.6.0`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.6.0:rc1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.6.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.6.2`,
        fs:  `cpe:2.3:h:cisco:spa_508g_8-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.7.0`,
        fs:  `cpe:2.3:a:redhat:redhat_package_manager:4.0.2-71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.8.0`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.8.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.8.2`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.9.0`,
        fs:  `cpe:2.3:a:ajax_timeline_project:ajax_timeline:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.9.0:dev0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.549:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.9.0:dev1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:2.9.0:dev2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:3.0.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:3.0.0:rc1`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:3.1.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pillow:3.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:-`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:0.9.0`,
        fs:  `cpe:2.3:a:inclind:custom_pub:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:0.9.1`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:1.2`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.1:sp12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:1.3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:1.5.2`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:5.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:1.6`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:1.6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.0`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)ea2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.1.1`,
        fs:  `cpe:2.3:a:aol:browser:1.6:-:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.1.2`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.1.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.2.0`,
        fs:  `cpe:2.3:a:tibco:activematrix_policy_manager:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.2.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.2.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.2.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3.1`,
        fs:  `cpe:2.3:h:pgp:e-ppliance_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3.2`,
        fs:  `cpe:2.3:a:microsoft:visual_basic_software_development_kit:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_new:2009.312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3.4`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3.5`,
        fs:  `cpe:2.3:a:sendmail:intelligent_quarantine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3.6`,
        fs:  `cpe:2.3:h:foundrynet:edgeiron_eif4802cf_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.3.7`,
        fs:  `cpe:2.3:a:openttd:openttd:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.4.0`,
        fs:  `cpe:2.3:a:bilingual_magic_ball_relajo_project:bilingual_magic_ball_relajo:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.4.1`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.4.2`,
        fs:  `cpe:2.3:a:file_project:file:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.4.3`,
        fs:  `cpe:2.3:a:ibm:api_management:4.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.4.4`,
        fs:  `cpe:2.3:a:boson:ms-exam_for_comptia_sy0-201:9.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.4.5`,
        fs:  `cpe:2.3:h:juniper:srx3600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.4.6`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5`,
        fs:  `cpe:2.3:a:artifex:ghostscript_fonts:8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p1_rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5.4`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.1.079.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5.5`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5.6`,
        fs:  `cpe:2.3:a:openttd:openttd:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.5.150`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.1`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.19.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.2`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.4`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.1.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3.0sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.7`,
        fs:  `cpe:2.3:a:novell:suse_linux_software_development_kit:11.0:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.8`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_hpux:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.9`,
        fs:  `cpe:2.3:a:iss:blackice_agent_server:3.6ecb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.2150`,
        fs:  `cpe:2.3:a:cisco:finesse:8.5\(2\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.6.6150`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7`,
        fs:  `cpe:2.3:a:google:v8:4.6.85.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.1:rc1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.2:rc1`,
        fs:  `cpe:2.3:h:xerox:workcentre_m45:4.97.20.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.3`,
        fs:  `cpe:2.3:a:kryo:iodine:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.4`,
        fs:  `cpe:2.3:o:suse:yast2-backup:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.5`,
        fs:  `cpe:2.3:a:courion:access_risk_management_suite:8.0:9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.6`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.7`,
        fs:  `cpe:2.3:a:umn:mapserver:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.8`,
        fs:  `cpe:2.3:a:authentec:authentec_fingerprint_sensor:7.10.0.0129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.9`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0804hf-u-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.10`,
        fs:  `cpe:2.3:a:xnview:xnview:1.98.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.11`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.12`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.13`,
        fs:  `cpe:2.3:a:intel:intelligent_platform_management_interface:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.14`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.1150`,
        fs:  `cpe:2.3:a:gnome:glib:2.28.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.1150::~~~~x64~`,
        fs:  `cpe:2.3:a:teradata:statistics_wizard:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:2.7.2150`,
        fs:  `cpe:2.3:a:aimluck:aipo:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.0`,
        fs:  `cpe:2.3:a:vmware:virtualcenter:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.0.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.0.1`,
        fs:  `cpe:2.3:a:thycotic:secret_server:8.6.000009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.1.0`,
        fs:  `cpe:2.3:h:supermicro:x9sri-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.1.1`,
        fs:  `cpe:2.3:a:microsoft:outlook:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.1.2`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2007:-:government:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.1.3`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)t5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.1.5`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.1.2150::~~~~x64~`,
        fs:  `cpe:2.3:a:microsoft:pinyin_ime:2010:*:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2:alpha`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2.0`,
        fs:  `cpe:2.3:a:ibm:maximo_service_desk:7.1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2.2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2.3`,
        fs:  `cpe:2.3:a:x:libxcb:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2.4`,
        fs:  `cpe:2.3:a:arcanadev:adtempus:3.00.0703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2.5`,
        fs:  `cpe:2.3:a:netscape:commerce_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2.6`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.2.2150`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.6.5.635:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3:beta2`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.1`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.1:rc1`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.2`,
        fs:  `cpe:2.3:a:sybase:easerver:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.3`,
        fs:  `cpe:2.3:a:cisco:user_registration_tool:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.3:rc1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.3:rc2`,
        fs:  `cpe:2.3:a:roxio:express_labeler:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p178:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.4:rc1`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.5`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.5:rc1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.5:rc2`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.6`,
        fs:  `cpe:2.3:a:nvidia:nview:135.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.6:rc1`,
        fs:  `cpe:2.3:a:mutiny:standard:4.5-1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.3.7`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.2:1004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4:alpha1`,
        fs:  `cpe:2.3:a:barracudanetworks:yosemite_server_backup:8.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4.2`,
        fs:  `cpe:2.3:o:cisco:rv110w_firmware:1.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4.3`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_desktop:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4.4`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:t27ld:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4.5`,
        fs:  `cpe:2.3:a:adobe:contribute_cs4:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4.6`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.4.7`,
        fs:  `cpe:2.3:a:google:chrome:14.0.830.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.5`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.8.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.5.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.5.1`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.5.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.5.3`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.5.4`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.6`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr3204lf-al:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.6.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.4e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.6.1`,
        fs:  `cpe:2.3:a:markwilson:classify_for_outlook:8.8.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.6.2`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.6.3`,
        fs:  `cpe:2.3:a:sap:erp:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:python:3.6.4`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(1\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:pyxdg:0.25`,
        fs:  `cpe:2.3:h:dell:3100cn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:rply:0.7.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.40`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.41`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.42`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20101231:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.43`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.44`,
        fs:  `cpe:2.3:a:tincan:phplist:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.45`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.46`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.47`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.48`,
        fs:  `cpe:2.3:a:isc:bind:8.2.3_t9b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.6.49`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cp5225:ce710a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python:setuptools:0.7b4`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-gnupg_project:python-gnupg:0.3.5`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-gnupg_project:python-gnupg:0.3.6`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.1.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.2.1`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.1:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.3.0`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.10:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.4.0`,
        fs:  `cpe:2.3:a:fujitsu:interstage_application_server:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.4.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.0\(2a\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.4.2`,
        fs:  `cpe:2.3:h:cisco:secure_access_control_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.4.3`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.5.0`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.5.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.0:pl:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.5.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python-requests:requests:2.5.3`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python_bugzilla_project:python-bugzilla:0.6.0`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:9.1\(2.1000.28\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python_bugzilla_project:python-bugzilla:0.6.1`,
        fs:  `cpe:2.3:o:novell:leap:42.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python_bugzilla_project:python-bugzilla:0.6.2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.3.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python_bugzilla_project:python-bugzilla:0.7.0`,
        fs:  `cpe:2.3:h:supermicro:x8sit-hf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python_bugzilla_project:python-bugzilla:0.8.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python_bugzilla_project:python-bugzilla:0.9.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:python_imaging_project:python_imaging:1.1.7`,
        fs:  `cpe:2.3:a:opnet:license_server:17.0.0.10655:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pythonware:python_imaging_library:1.1.5`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pythonware:python_imaging_library:1.1.6`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pythonware:python_imaging_library:1.1.7`,
        fs:  `cpe:2.3:a:innominate:mguard_pci:hw-102020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pyyaml:libyaml:0.0.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pyyaml:libyaml:0.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pyyaml:libyaml:0.1.2`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pyyaml:libyaml:0.1.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pyyaml:libyaml:0.1.4`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pyyaml:libyaml:0.1.5`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:pyyaml:libyaml:0.1.6`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qbnz:geshi:1.0.8.4`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qbnz:geshi:1.0.8.5`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qbnz:geshi:1.0.8.6`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qbnz:geshi:1.0.8.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qbnz:geshi:1.0.8.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qbnz:geshi:1.0.8.9`,
        fs:  `cpe:2.3:a:citadel:hercules_remediation_client_for_windows:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qbnz:geshi:1.0.8.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qbnz:geshi:1.0.8.11`,
        fs:  `cpe:2.3:a:gnome:evolution:2.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:qeiinc:epaq-9410_substation_gateway:-`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:-`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.1`,
        fs:  `cpe:2.3:a:biscom:faxcom_job_tracking:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.1.1`,
        fs:  `cpe:2.3:a:ibm:java:6.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.1.2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.1.3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.1.4`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.1.5`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.1.6`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.2`,
        fs:  `cpe:2.3:a:avaya:vpnremote:4.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.3`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.0:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.4.1`,
        fs:  `cpe:2.3:o:d-link:dap-2690_firmware:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.4.2`,
        fs:  `cpe:2.3:a:citrix:xenapp_administration:4.7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.4.3`,
        fs:  `cpe:2.3:a:inline:ihtml:2.20:304:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.5.0`,
        fs:  `cpe:2.3:o:yamaha:rt56v:4.07.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.5.1`,
        fs:  `cpe:2.3:a:steema:teechart_for_.net:2010:*:*:*:eval:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.5.2`,
        fs:  `cpe:2.3:a:openstack:swift:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.5.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.5.4`,
        fs:  `cpe:2.3:a:colorbox_node:dennis_blake:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.5.5`,
        fs:  `cpe:2.3:h:tropos:3310_indoor_mesh_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.6.0`,
        fs:  `cpe:2.3:o:redhat:linux:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.6.1`,
        fs:  `cpe:2.3:a:redhat:docbook_utils:0.6.9-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.7.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.7.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.7.2`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.8.0`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.6.0.574:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.8.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.8.2`,
        fs:  `cpe:2.3:h:huawei:s7700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.9.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1304.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.9.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3va:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.9.1-5`,
        fs:  `cpe:2.3:a:adobe:photoshop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.10.0`,
        fs:  `cpe:2.3:a:nvidia:control_panel:266.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.10.1`,
        fs:  `cpe:2.3:a:microsoft:iemobile:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.10.2`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.10.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.10.4`,
        fs:  `cpe:2.3:a:hp:network_automation:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.10.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.10.6`,
        fs:  `cpe:2.3:a:google:desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.11.0`,
        fs:  `cpe:2.3:h:y-cam:ycw002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.11.0:rc0`,
        fs:  `cpe:2.3:a:docker:docker:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.11.0:rc1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.11.0:rc2`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.11.0-rc0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1036.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.11.0-rc1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.11.0-rc2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.11.1`,
        fs:  `cpe:2.3:h:moxa:miineport_e2_4561:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.12.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.95.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.12.0:rc1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.12.0:rc2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.12.1`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.12.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.12.3`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:10.00.tc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.12.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2010.1125.2142.38865:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.12.5`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.13.0`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1511f-1_pn_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.13.0:rc0`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2000_server:6.3.405:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.13.0:rc1`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.14.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.14.0:rc0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.14.0:rc1`,
        fs:  `cpe:2.3:a:altiris:audit_integration_component_documentation:6.2.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.14.0:rc2`,
        fs:  `cpe:2.3:h:hp:jd665a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.14.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)ys_1.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.15.0:rc1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.15.0:rc2`,
        fs:  `cpe:2.3:a:wernerd:zrtpcpp:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.15.1`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:0.15.2`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.0:rc1`,
        fs:  `cpe:2.3:a:3par:inform_management_console:4.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.0:rc2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r11_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.0:rc3`,
        fs:  `cpe:2.3:a:animoca:star_girl:3.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.0:rc4`,
        fs:  `cpe:2.3:a:exim:exim:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.1`,
        fs:  `cpe:2.3:h:hp:vpn_firewall_appliance:jg214a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.1:rc1`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.1:rc2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.1:rc3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.1:rc4`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.4.1`,
        fs:  `cpe:2.3:a:panduit:easy-mark:3.6.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.4.2`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.5.0`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.5.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.5.0:rc2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.5.0:rc3`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.5.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.2.0.207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.5.2`,
        fs:  `cpe:2.3:a:x:libxt:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.5.3`,
        fs:  `cpe:2.3:a:vmware:infrastructure_client:2.5.0.64207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.6.0`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-02-21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.6.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.6.0:rc2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.6.0:rc3`,
        fs:  `cpe:2.3:a:intel:proset:6.5.2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.6.1`,
        fs:  `cpe:2.3:a:dymo:dymo_label:8.2.0.820:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:1.7.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.0.0:-`,
        fs:  `cpe:2.3:a:kde:koffice:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.0.0:rc0`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.0.0:rc1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1\(2.27\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.0.0:rc2`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.0.0:rc3`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.0.2`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(11b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.0:rc0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.0:rc1`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.0:rc2`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.0:rc3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.0:rc5`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.1`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.2`,
        fs:  `cpe:2.3:a:innopage:giga_hobby:1.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.1.3`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.3.0`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.5.0`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qemu:qemu:2.8.1.1`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.20:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qianqin:qtranslate:2.5.34::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:serviceguard:a.11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qianqin:qtranslate:2.5.39::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nagiosql:nagiosql:3.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer:-`,
        fs:  `cpe:2.3:a:x:x_server:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer:1.0.0.0`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-09-22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer:1.0.0.0::~~professional~~~`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer:4.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer_fc_hba_management_agent:1.0.1281.12`,
        fs:  `cpe:2.3:a:adobe:livecycle_data_services:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer_fc_hba_management_agent:1.0.1281.39`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r5-p1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer_fc_hba_manager:1.0.0.0`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer_fc_hba_manager:2.0.30`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer_fc_hba_manager:5.0.1.0`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qlogic:sansurfer_fc_hba_manager:5.0.1.72`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qmania:aloha_guide:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:08-00:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qmania:aloha_guide:1.5::~~~android~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qnap:iartist_lite:1.4.53.1`,
        fs:  `cpe:2.3:a:cdotech:edcl_common_workflow_components:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qnap:qsync:4.2.2.0724::~~~windows~~`,
        fs:  `cpe:2.3:a:apache:libcloud:0.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qnap:qsync:4.2.3.0915::~~~windows~~`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:qts:4.0`,
        fs:  `cpe:2.3:a:sap:basis_communication_services:7.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:qts:4.0.3`,
        fs:  `cpe:2.3:a:telligent:evolution:6.1.19.36103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:qts:4.1.0`,
        fs:  `cpe:2.3:a:opentext:enterprise_library_classifications_professional:4.2.0.464:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:qts:4.1.4`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:qts:4.2.0:rc1`,
        fs:  `cpe:2.3:a:citrix:hdx_wmi_provider:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qnap:signage_station:2.0`,
        fs:  `cpe:2.3:o:huawei:s5300li_firmware:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:qnap:ss-839:-`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:ss-839_firmware:4.0.7`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.35.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:qnap:ts-459u:-`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:ts-459u_firmware:4.0.7`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:qnap:ts-469u:-`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5_iop:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:ts-469u_firmware:4.0.7`,
        fs:  `cpe:2.3:a:urs_wolfer:kwebkitpart:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:qnap:ts-ec1679u-rp:-`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:qnap:ts-ec1679u-rp_firmware:4.0.7`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:qpw.famvanakkeren:quick_post_widget:1.9.1:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qsxgroup:outlook_express_backup_wizard:1.0`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.4:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qsxgroup:outlook_express_backup_wizard:1.1`,
        fs:  `cpe:2.3:a:henk:git_extensions:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qt:qt:5.9.0::~~~android~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qt:qt:5.9.3::~~~android~~`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qtranslate_project:qtranslate:2.5.39`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:-`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.95`,
        fs:  `cpe:2.3:h:dlink:des-3800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.96`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.96.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.96.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_device_manager_idm_launcher:1.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.96.3`,
        fs:  `cpe:2.3:a:haxx:curl:7.19.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.96.4`,
        fs:  `cpe:2.3:a:apache:subversion:0.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.96.5`,
        fs:  `cpe:2.3:a:vmware:server:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.97.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.97.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.97.2`,
        fs:  `cpe:2.3:a:macromedia:jrun:4.0:sp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.97.3`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.33:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.97.4`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.97.5`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.98.0`,
        fs:  `cpe:2.3:a:cherrypy:cherrypy:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.98.1`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.029:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.98.2`,
        fs:  `cpe:2.3:o:yamaha:rtw65i:5.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.98.3`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.98.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_3m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.98.5`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.5:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.98.6`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.2`,
        fs:  `cpe:2.3:o:cisco:spa8800_8-port_ip_telephony_gateway_firmware:6.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.4`,
        fs:  `cpe:2.3:o:juniper:junos:12.2x65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.5`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.6`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.7`,
        fs:  `cpe:2.3:o:ibm:os_400:v5r2m0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.8`,
        fs:  `cpe:2.3:a:gnome:glib:2.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.9`,
        fs:  `cpe:2.3:a:novell:access_manager_identity_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.10`,
        fs:  `cpe:2.3:a:redhat:tcpdump:3.6.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.11`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.12`,
        fs:  `cpe:2.3:a:qemu:qemu:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.13`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.14`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.15`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.16`,
        fs:  `cpe:2.3:a:google:v8:3.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.17`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp12:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.18`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.16m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.19`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.20`,
        fs:  `cpe:2.3:a:ca:secure_content_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.20.1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.21`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.22`,
        fs:  `cpe:2.3:a:opentext:connectivity_secure_shell:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.22.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.22.2`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:7.5.2-hp2-303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.22.3`,
        fs:  `cpe:2.3:h:siemens:scalance_w746-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:0.99.24`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quagga:quagga:1.0.20160315`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualcomm:eudora_worldmail:9.0.333.0`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualcomm:extensible_diagnostic_monitor:03.09.19`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualcomm:gobi_single_installer_package_for_novatel:1.0.11`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualcomm:gobi_single_installer_package_for_zte:1.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p7_rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualcomm:gobi_single_installer_package_for_zte:1.1.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p134:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualcomm:gobi_single_installer_package_for_zte:1.1.40`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:qualcomm:msm8960:-`,
        fs:  `cpe:2.3:a:lucent:vitalevent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualcomm:yagattatalk_messenger:1.00.01.08`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:3.2.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:3.2.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:3.3.0`,
        fs:  `cpe:2.3:a:apache:subversion:0.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:3.3.2`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:3.4.0`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:3.4.3`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sru:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:3.4.11`,
        fs:  `cpe:2.3:a:simple_subscription_project:simple_subscription:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:3.5.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:4.0.8`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:4.1.3`,
        fs:  `cpe:2.3:h:intel:460t_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:4.5`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:5.1.6`,
        fs:  `cpe:2.3:a:debian:apt:0.8.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:5.1.7`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.8.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:5.1.8`,
        fs:  `cpe:2.3:a:logitech:lws_facebook:13.30.1346.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:5.1.9`,
        fs:  `cpe:2.3:a:docker:docker:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualiteam:x-cart:5.1.10`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.07:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardscap:1.2`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.3`,
        fs:  `cpe:2.3:a:businessobjects:webintelligence:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.4`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.5`,
        fs:  `cpe:2.3:a:ca:etrust_pestpatrol:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.6`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.7`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.8`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.9`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.10`,
        fs:  `cpe:2.3:a:huawei:seco_versatile_security_manager:v200r002c00spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.11`,
        fs:  `cpe:2.3:a:textangular:textangular:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.12`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:7.13`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:8.0`,
        fs:  `cpe:2.3:a:drupal:drupal:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualysguardsuite:8.1`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.6:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualyssuite:8.2`,
        fs:  `cpe:2.3:a:hp:compaqhttpserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualyssuite:8.3`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualyssuite:8.4`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualyssuite:8.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:qualys:qualyssuite:8.6`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:adic_management_console:4.4.2`,
        fs:  `cpe:2.3:a:google:chrome:51.0.2704.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:management_console:6.6`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:12.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:quantum:-`,
        fs:  `cpe:2.3:a:php:php:5.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:quantum:scalar_i500:5u`,
        fs:  `cpe:2.3:a:intel:network_connections:15.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:quantum:scalar_i500:14u`,
        fs:  `cpe:2.3:a:3com:tftp_server:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:quantum:scalar_i500:23u`,
        fs:  `cpe:2.3:a:etoshop:classifieds_creator:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i2`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i3`,
        fs:  `cpe:2.3:a:businessobjects:webintelligence:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i3.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i4`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i5`,
        fs:  `cpe:2.3:a:oracle:application_server:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i5.1`,
        fs:  `cpe:2.3:h:linksys:befw11s4:1.37.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i6`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2.7:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i6.1`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-2330c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i7`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i7.0.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i7.0.2`,
        fs:  `cpe:2.3:a:autodesk:sketchbook:6.2.4:*:*:*:copic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:i7.0.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:quantum:scalar_i500_firmware:i8.2.2.1_%28646g.gs002%29`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:quantum:scalar_i500_firmware:i8.2.2_%28645g.gs004%29`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:sp4`,
        fs:  `cpe:2.3:a:teamst:testlink:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:scalar_i500_firmware:sp4.2`,
        fs:  `cpe:2.3:a:google:chrome:12.0.741.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:vision:4.0.4.1`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.4.0:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:quantum:xtalk_management_console:5.5.0`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.55:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:quartz_plugin_project:quartz_plugin:1.01.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:f5:big-ip_2400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel:0.10.0`,
        fs:  `cpe:2.3:a:sourcelink:multitrac:1.04:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel:0.11.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel:0.12.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.1.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel:0.12.3`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.1.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.3.0`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.3.0.1`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.3.0.2`,
        fs:  `cpe:2.3:a:imagecms:imagecms:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.3.0.3`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.3.1`,
        fs:  `cpe:2.3:h:nvidia:geforce_945m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.4.0`,
        fs:  `cpe:2.3:a:isc:bind:9.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.4.1`,
        fs:  `cpe:2.3:a:intuit:quicken:20.1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.4.2`,
        fs:  `cpe:2.3:h:linksys:befsru31:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.4.3`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.5.0`,
        fs:  `cpe:2.3:h:hp:dc7900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.6.1`,
        fs:  `cpe:2.3:a:twiki:twiki:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.6.2`,
        fs:  `cpe:2.3:a:gnu:aspell:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.6.3`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_cms:4.5.8:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.7.0`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.7.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.7.2`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.7.3`,
        fs:  `cpe:2.3:a:emc:task_space:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.7.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.8.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.9.0`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.9.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quassel-irc:quassel_irc:0.10.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:activeroles_management_shell_for_active_directory:1.4.0.2139`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.5:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:activeroles_management_shell_for_active_directory:1.4.0.2139::~~~~x64~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:application_integration_tool:1.0.5`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_monitoring_center_for_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:benchmark_factory_for_databases:5.5.1.379`,
        fs:  `cpe:2.3:a:avast:avast\!_mobile_security:2.0.4304:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:benchmark_factory_for_databases:5.7.1.504`,
        fs:  `cpe:2.3:a:vermontsystems:progress:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:benchmark_factory_for_databases:5.8.1.571`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:benchmark_factory_for_databases:6.0.0.150`,
        fs:  `cpe:2.3:a:gnome:glib:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:benchmark_factory_for_databases:6.1.1.228`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)ewa3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:benchmark_factory_for_databases:6.1.1.228::~~trial~~~`,
        fs:  `cpe:2.3:a:eolsoft:flash_movie_player:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:big_brother_system_and_network_monitor_client:1.8.4000`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:capacity_manager_for_oracle:1.1.2`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:installer_logging:3.0.1`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust:10.1`,
        fs:  `cpe:2.3:a:open_source_development_team:sthttpd:2.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust:10.2.5`,
        fs:  `cpe:2.3:h:hp:d3l08a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust:10.3`,
        fs:  `cpe:2.3:h:moxa:iologic_e2214:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust:10.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust:10.4.0.853`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_administrative_report_pack:10.2.5.1024`,
        fs:  `cpe:2.3:a:oxide_project:oxide:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_agent:10.2.5.1024`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_indexing_tool:10.2.5.1024`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_cisco_pix_firewall_and_checkpoint_firewall:10.2.5.1024`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_hpux:10.2.5.1024`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_microsoft_audit_collection_services:10.2.5.1024`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_microsoft_excel:10.2.5.1024`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_microsoft_exchange_server:10.2.5.1024`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_microsoft_identity_integration_server:10.2.5.1024`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_microsoft_iis:10.2.5.1024`,
        fs:  `cpe:2.3:o:harman:amx_firmware:1.3.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_microsoft_isa_server:10.2.5.1024`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)zb7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_microsoft_sql_server:10.2.5.1024`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_oracle_database:10.2.5.1024`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_redhat_enterprise_linux_and_suse_linux_enterprise_server:10.2.5.1024`,
        fs:  `cpe:2.3:a:web2ldap:web2ldap:1.1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_knowledge_pack_for_sun_solaris:10.2.5.1024`,
        fs:  `cpe:2.3:a:ibm:db2:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_manager:10.2.5.1024`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(26\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_monitoring_console:10.2.5.1024`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg303a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_predefined_objects_for_microsoft_iis:10.2.5.1024`,
        fs:  `cpe:2.3:a:alberto_trujillo_gonzalez:protest:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_excel:10.2.5.1024`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_firewalls:10.2.5.1024`,
        fs:  `cpe:2.3:a:b-e-soft:artweaver_plus:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_hp-ux:10.2.5.1024`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_iis:10.2.5.1024`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.122:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_isas:10.2.5.1024`,
        fs:  `cpe:2.3:o:cisco:ios:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_linux:10.2.5.1024`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_miis:10.2.5.1024`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_ms_sql_server:10.2.5.1024`,
        fs:  `cpe:2.3:a:mobisynapse:moffice-outlook_sync:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_oracle:10.2.5.1024`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_quest_recovery_manager_for_active_directory:10.2.5.1024`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.5.1:-:-:ja-jp:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_solaris:10.2.5.1024`,
        fs:  `cpe:2.3:a:sendy:sendy:1.1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_suse_linux:10.2.5.1024`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_syslog:10.2.5.1024`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_report_pack_for_windows:10.2.5.1024`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_repository_viewer:10.2.5.1024`,
        fs:  `cpe:2.3:a:corel:shell_extension:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_resource_kit:10.2.5.1024`,
        fs:  `cpe:2.3:h:avaya:csu_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:intrust_server:10.2.5.1024`,
        fs:  `cpe:2.3:h:hp:laserjet_5100dtn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_portal:2.5.1.48`,
        fs:  `cpe:2.3:o:yamaha:rt105i:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert:1.0.84`,
        fs:  `cpe:2.3:a:oracle:database_server:1.0.2.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert:10.0.0.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert:10.1.0.188`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_for_oracle_administration:9.1.1`,
        fs:  `cpe:2.3:a:apple:quicktime:7.2.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_for_oracle_administration:10.1.0.188`,
        fs:  `cpe:2.3:a:corel:coreldraw:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_for_plsql:8.5`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_for_plsql:8.6`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_for_plsql:9.0`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_for_plsql:9.1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_for_plsql:9.1.1`,
        fs:  `cpe:2.3:a:citrix:access_management_console_legacy_tools:4.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_for_plsql:10.1.0.188`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:knowledge_xpert_oracle_common:10.1.0.188`,
        fs:  `cpe:2.3:a:winzip:winzip_command_line_support_add-on:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:litespeed_for_sql_server:5.2.0.1240`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:messagestats:6.5.1.1276`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:messagestats_report_pack_for_blackberry:1.0.1.64`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:powergui:2.2.0.1358`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:qexplain:6.0.5`,
        fs:  `cpe:2.3:h:ibm:power_5:9110-510:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:spotlight:6.0.0.1325`,
        fs:  `cpe:2.3:a:adobe:jrun:4.0_build_61650:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:spotlight:7.6.0.1559`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.7:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:spotlight_on_oracle:5.0.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:spotlight_on_oracle:5.0.1`,
        fs:  `cpe:2.3:a:gnu:gimp:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:spotlight_on_oracle:6.1.0.1433`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:spotlight_on_oracle:7.1.0.1481`,
        fs:  `cpe:2.3:a:civitasmedia:logan_banner:1.0010.b0010:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:spotlight_on_oracle:7.6.0.1559`,
        fs:  `cpe:2.3:a:digia:qt:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle:7.3.678`,
        fs:  `cpe:2.3:a:horde:gollem:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle:7.4.1.834`,
        fs:  `cpe:2.3:a:logitech:lws_facebook:13.0.1777.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle:7.4.1.834::~~trial~~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle:7.5.0.1113`,
        fs:  `cpe:2.3:a:google:chrome:6.0.404.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle:7.5.3.1281`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle:8.0.0.1551`,
        fs:  `cpe:2.3:a:git-scm:git:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle:8.0.0.1551::~~trial~~~`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle_common:1.0.0.100`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle_common:2.0.0.100`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle_common:2.5.0.100`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:sql_optimizer_for_oracle_common:3.0.0.101`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_data_modeler:3.1.7`,
        fs:  `cpe:2.3:a:freemind:freemind:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_data_modeler:3.3.5.5`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_data_modeler:3.4.14.6`,
        fs:  `cpe:2.3:a:kk-osk:advance-flow:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_data_modeler:3.4.15.10`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_data_modeler:3.5.10.4`,
        fs:  `cpe:2.3:a:oracle:jre:7.0:update_131:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_data_modeler:3.6.6.7`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_data_analysts:2.5.0.913`,
        fs:  `cpe:2.3:a:avg:secure_search_toolbar:18.1.7.598:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_data_analysts:2.6.1.568`,
        fs:  `cpe:2.3:a:cisco:nac_guest_server_software:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_data_analysts:2.6.2::~~basic~~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:6.0.2\(28\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_data_analysts:2.6.2.580`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_data_analysts:2.7::~~trial~~~`,
        fs:  `cpe:2.3:a:apache:mod_python:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_data_analysts:2.7.0.348`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_data_analysts:2.7.0.348::~~trial~~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:8.5.3`,
        fs:  `cpe:2.3:h:cisco:sf302-08mpp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:8.6`,
        fs:  `cpe:2.3:a:digia:qt:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:9.0.1`,
        fs:  `cpe:2.3:a:hp:software_certificate_management_client:6.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:9.1`,
        fs:  `cpe:2.3:a:openfabrics:ibacm:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:9.5`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r009c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:9.6.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.09:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:9.7.2.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.8-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:10.0`,
        fs:  `cpe:2.3:a:microsoft:project_multilingual_user_interface_pack:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:10.0.0.41`,
        fs:  `cpe:2.3:o:cisco:unified_sip_phone_3900_firmware:8.1\(2\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:10.1.1.8`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.4.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:10.5.1.3`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6ecd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:10.6.0.42`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.37.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:10.6.0.42::~~freeware~~~`,
        fs:  `cpe:2.3:h:axis:207_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:10.6.1.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:11.0.0.116`,
        fs:  `cpe:2.3:o:lorextechnology:edge\&#43;_lh320_firmware:7-35-28-1b26e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_oracle:11.0.0.116::~~freeware~~~`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.27:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_for_sql_server:5.5.0.1073::~~freeware~~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:toad_group_policy_manager:10.0.0.33::~~freeware~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quest:web_parts_for_sharepoint:5.3.0`,
        fs:  `cpe:2.3:a:php:php:5.5.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:questfcu:quest_federal_cu_mobile:1.0.27::~~~android~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:questionmark:questionmark_secure_browser:4.2.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:questionmark:questionmark_secure_browser:5.3.0.4`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1274.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_edit_project:quick_edit:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_edit_project:quick_edit:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:sametime:7.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_page%2fpost_redirect_project:quick_page%2fpost_redirect:5.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0055:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpw730:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.0:rc3:~~~drupal~~`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.0:rc4:~~~drupal~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.94.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.0:rc5:~~~drupal~~`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update2:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:canonical:acpi-support:0.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-2.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:o:advantech:eki-1362_series_firmware:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-3.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-3.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:perl:perl:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-3.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:6.x-3.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:h:enterasys:matrix_n7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta58:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:o:xen:xen:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:a:aimluck:aipo:5.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:openswan:openswan:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:pcre:pcre:8.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.6:beta:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:content_management_server:2001:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quick_tabs_module_project:quicktabs:7.x-3.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.12:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quickheal:antivirus_pro:7.0.0.1`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quickmobile:ncci%27s_annual_issues_symposium:1::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quickzip:quick_zip:4.60.19`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:-:~~~drupal~~`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update6:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:apple:apple_tv:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:alpha4:~~~drupal~~`,
        fs:  `cpe:2.3:h:axis:2130_ptz_network_camera:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:alpha5:~~~drupal~~`,
        fs:  `cpe:2.3:a:plone:plone:4.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:beta4:~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:beta5:~~~drupal~~`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:beta6:~~~drupal~~`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:beta7:~~~drupal~~`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:beta8:~~~drupal~~`,
        fs:  `cpe:2.3:a:redhat:interchange:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:5.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc10:~~~drupal~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc3:~~~drupal~~`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc4:~~~drupal~~`,
        fs:  `cpe:2.3:a:nokia:affix:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc5:~~~drupal~~`,
        fs:  `cpe:2.3:a:phpblogger:php-blogger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc6:~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:45.0.2454.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc7:~~~drupal~~`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc8:~~~drupal~~`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.3.1:mu_\#3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.0:rc9:~~~drupal~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:avast:business_security:11.1.2262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_module_project:quiz:6.x-4.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:thomsonreuters:velocity_analytics_vhayu_analytic_server:6.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quiz_project:quiz:-::~~~mediawiki~~`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quizzler_project:quizzler:7.x-1.15::~~~drupal~~`,
        fs:  `cpe:2.3:h:cisco:c460_m1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quotes_of_travis_barker_project:quotes_of_travis_barker:0.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quotezone:car_insurance_quote_comparison:2.3::~~~android~~`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quranedu:ahmed_bukhatir_nasheeds_tv:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.706.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:quranedu:quran_abu_bakr_ashshatiri_free:1::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:r-company:unzipper:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:h:f5:big-ip_access_policy_manager:11.3.0:*:*:*:*:*:*:standalone`,
    },
     
    {
        uri: `cpe:/a:r-company:unzipper:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:r-company:unzipper:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:netscape:navigator:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rabidhamster:r2%2fextreme:1.51`,
        fs:  `cpe:2.3:a:ibm:license_metric_tool:9.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rabidhamster:r2%2fextreme:1.65`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:0.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:0.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:0.3`,
        fs:  `cpe:2.3:o:siemens:simatic_s7-1500_cpu_firmware:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:0.4`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:0.9`,
        fs:  `cpe:2.3:a:isc:bind:9.7.6:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:0.9.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.0.0`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:2.3\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.0.1`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.1.0`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.1.2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_3u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.1.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.1.4`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.1.5`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.1.6`,
        fs:  `cpe:2.3:a:debian:sympa:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.1.33`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.2.0`,
        fs:  `cpe:2.3:a:liteonit:ez-dub:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sre3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.2.2`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_opmanager:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.2.3`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.2.4`,
        fs:  `cpe:2.3:o:hp:tru64:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.2.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.2.7`,
        fs:  `cpe:2.3:a:newsoftinc:presto\!_bizcard:4.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.0`,
        fs:  `cpe:2.3:a:gnu:gdb:5.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.1`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.2`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds3950_express:1814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.3`,
        fs:  `cpe:2.3:h:zyxel:p-660hw:_t1:v2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.4`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)ze:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.6`,
        fs:  `cpe:2.3:a:kgb_project:kgb:1.0b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.7`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.8`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a3:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.9`,
        fs:  `cpe:2.3:a:red-gate:sql_response:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.3.10`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:16.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.4.0`,
        fs:  `cpe:2.3:a:samba:samba:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.4.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.4.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.4.3`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.4.4`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.4.5`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:refresh6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.5.0`,
        fs:  `cpe:2.3:a:pansi:pansi_sms:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.5.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.5.2`,
        fs:  `cpe:2.3:a:plone:plone:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.5.3`,
        fs:  `cpe:2.3:a:google:android_api:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.6.0`,
        fs:  `cpe:2.3:a:redhat:cloudforms_3.1_management_engine:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rack_project:rack:1.6.1`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rackspace:openstack_windows_guest_agent:1.2.5.0:-:~-~-~xen_server~~`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rackspace:openstack_windows_guest_agent:1.2.6.0:-:~-~-~xen_server~~`,
        fs:  `cpe:2.3:a:microsoft:edge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rackspace:openstack_windows_guest_agent:1.2.6.1:-:~-~-~xen_server~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rackspace:rackspace:2.1.5:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:hp:software_cross_platform_component:6.20.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rad:asm-40:-`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radare:radare2:2.0.0`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radicale:radicale:1.1.1`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radicale:radicale:2.0.0:rc1`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radio_de_la_cato_project:radio_de_la_cato:2.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1yd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radiocms:radiocms:2.2`,
        fs:  `cpe:2.3:o:microsoft:windows_me:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radiohead_fan_project:radiohead_fan:4.6.2::~~~android~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:radiothermostat:ct50:-`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.5:sr_3.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:radiothermostat:ct50_firmware:1.4.64`,
        fs:  `cpe:2.3:o:huawei:s9306_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:radiothermostat:ct80:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:radiothermostat:ct80_firmware:1.4.64`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radius_extension_project:radius:1.1`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radius_extension_project:radius:1.2.1`,
        fs:  `cpe:2.3:a:divx:divx_version_checker:7.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radius_extension_project:radius:1.2.2`,
        fs:  `cpe:2.3:a:redhat:tcpdump:3.6.2-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radius_extension_project:radius:1.2.3`,
        fs:  `cpe:2.3:a:vmware:fusion:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radius_extension_project:radius:1.2.4`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radius_extension_project:radius:1.2.5`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(2\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radius_extension_project:radius:1.2.6`,
        fs:  `cpe:2.3:a:cabextract:cabextract:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radius_extension_project:radius:1.2.7`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radscan:network_audio_system:1.7`,
        fs:  `cpe:2.3:a:netshinesoftware:com_netinvoice:2.0.9:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radscan:network_audio_system:1.8`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radscan:network_audio_system:1.8a`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radscan:network_audio_system:1.9`,
        fs:  `cpe:2.3:a:apache:camel:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radscan:network_audio_system:1.9.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radscan:network_audio_system:1.9.3`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radscan:network_audio_system:1.9.4`,
        fs:  `cpe:2.3:a:canonical:software-properties:0.81.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radvision:l2w-323:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radware:cache_server_directory:-`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass_guest:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:radware:certaint_100:-`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.22:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:radware:fireproof:-`,
        fs:  `cpe:2.3:a:ca:unicenter_service_metric_analysis:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radware:fireproof:2.20.8`,
        fs:  `cpe:2.3:a:dave_airlie:pam_smb:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radware:fireproof:3.21`,
        fs:  `cpe:2.3:a:avsmedia:cover_editor:1.3.1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radware:linkproof:-`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:radware:web_server_directory:-`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rainbow:sentinel_system_driver:5.39.2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raize:codesite_client_tools:3.0`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:10.1`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.35.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:10.2`,
        fs:  `cpe:2.3:a:sympa:sympa:2.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:10.3`,
        fs:  `cpe:2.3:a:keywen:easydl:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:10.4`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:10.5`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:11.0`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.0.1.501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:11.1`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:11.2`,
        fs:  `cpe:2.3:a:sun:java_plug-in:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rakus:maildealer:11.2.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rama-palaniappan:calculatorapp:4::~~~android~~`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ramui:ramui_forum:1.0:beta`,
        fs:  `cpe:2.3:h:huawei:s2300:v100r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:1.10`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:1.11`,
        fs:  `cpe:2.3:a:google:v8:3.22.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:1.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:1.13`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:1.16`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.9-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:2.1`,
        fs:  `cpe:2.3:a:samsung:ml-85p_printer_driver:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:2.3`,
        fs:  `cpe:2.3:o:d-link:dir-826l_wireless_n600_cloud_router_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:2.4`,
        fs:  `cpe:2.3:h:hp:cf238a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:2.5`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:randall_hand:yerase%27s_tnef_stream_reader:2.6`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raoul_proenca:gnew:2013.1`,
        fs:  `cpe:2.3:a:oracle:application_server:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_assenat:libmikmod:3.1.12`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_assenat:libmikmod:3.2.2:beta`,
        fs:  `cpe:2.3:a:openstack:horizon:2012.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_zschorsch:rzautocomplete:0.0.2`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_zschorsch:rzautocomplete:0.0.3`,
        fs:  `cpe:2.3:a:bitcoin:wxbitcoin:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_zschorsch:rzautocomplete:0.0.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_zschorsch:rzautocomplete:0.0.5`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_zschorsch:rzautocomplete:0.0.6`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_zschorsch:rzautocomplete:0.0.7`,
        fs:  `cpe:2.3:a:psyced:psyced:20111122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raphael_zschorsch:rzautocomplete:0.0.8`,
        fs:  `cpe:2.3:h:siemens:spc5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:metasploit:4.13.19`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_server_suite:01-03-\/f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4`,
        fs:  `cpe:2.3:a:ibm:algorithmics:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.416:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.2`,
        fs:  `cpe:2.3:a:python-requests:requests:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.3`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.1.151.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.4`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.5`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.6`,
        fs:  `cpe:2.3:a:xiaowen_huang:yingzhi_python_programming_language:1.9:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.7`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.8`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.9`,
        fs:  `cpe:2.3:h:hp:j8697a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.10`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.4.12`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.5.1`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.5.3`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.5.4`,
        fs:  `cpe:2.3:a:codiad:codiad:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.5.5`,
        fs:  `cpe:2.3:o:microsoft:windows:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.5.6`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.5.7`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:2.0:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:5.5.8`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapid7:nexpose:6.4.12`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapidleech:rapidleech:2.3:rev42_svn_r358`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapidleech:rapidleech:2.3:rev42_svn_r399`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapidleech:rapidleech:2.3:rev43_svn_r397`,
        fs:  `cpe:2.3:h:hp:color_laserjet_2500lse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapidleech:rapidleech:2.3:v42_svn322`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapidleech:rapidleech:rev36`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.3:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rapidmedia:kayak_angler_magazine:3.12.0::~~~android~~`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.3.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:raritan:dpxr20a-16:-`,
        fs:  `cpe:2.3:a:morbtay:jetty:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raritan:power_iq:4.1.0`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:raritan:power_iq:4.2.1`,
        fs:  `cpe:2.3:h:perle:lanstream_serial_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.0`,
        fs:  `cpe:2.3:a:apple:cups:1.1.22:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.0.4`,
        fs:  `cpe:2.3:a:oracle:retail_order_management_system_cloud_service:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.1`,
        fs:  `cpe:2.3:a:soprano:fonecta_verify:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.1.6`,
        fs:  `cpe:2.3:a:seopanel:seo_panel:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.2`,
        fs:  `cpe:2.3:a:apple:cups:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.2.5`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.2.7`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.3.1`,
        fs:  `cpe:2.3:h:cisco:ipvc-3510-mcu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.3.5`,
        fs:  `cpe:2.3:h:axis:2401_video_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.4.1`,
        fs:  `cpe:2.3:a:apple:itunes:8.0.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.5`,
        fs:  `cpe:2.3:h:zhone_technologies:gpon_2520:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.5.4`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.5.7`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.5.8`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:raritan:px:1.5.11`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rarlab:winrar:-`,
        fs:  `cpe:2.3:a:sun:sunvts:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rarlab:winrar:4.1.0`,
        fs:  `cpe:2.3:a:hummingbird:hostexplorer:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rarlab:winrar:4.1.0::~~~~x64~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rarlab:winrar:4.10.2`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:4.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rarlab:winrar:5.30:beta_4:~~~~x64~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rarlab:winrar:5.30:beta_4:~~~~x86~`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:x64-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rastreadordecelulares:rastreador_de_celulares:5.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:ca:etrust_intrusion_detection:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.1.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sve:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.2.1`,
        fs:  `cpe:2.3:a:qualys:qualyssuite:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.2.2`,
        fs:  `cpe:2.3:a:sonarsource:jenkins_plugin:-:-:-:*:-:sonarqube:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.2.3`,
        fs:  `cpe:2.3:a:google:v8:3.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.3.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.3.2`,
        fs:  `cpe:2.3:a:digium:asterisk:10.12.0:rc1:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:108.2146.2565.38893:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.4:rc1`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.4:rc2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.5`,
        fs:  `cpe:2.3:a:ektron:ektron_content_management_system:8.7.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.5.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.5.2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:1.5.3`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300eec_firmware:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.3`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.4`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5b8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.5`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.6`,
        fs:  `cpe:2.3:a:herac:tuxguitar:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.7`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.8`,
        fs:  `cpe:2.3:a:idt:idt_audio:1.0.6159.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.9`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.2:1006:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.10`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.0.11`,
        fs:  `cpe:2.3:a:gnu:zlib:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.0:beta1`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.0:beta2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.1.181.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.1`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.3`,
        fs:  `cpe:2.3:a:redhat:network_satellite:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.4`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.5`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.0:tp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.6`,
        fs:  `cpe:2.3:a:wokamoto:wp-cron_dashboard:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.7`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.1.8`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.0:rc1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.0:rc3`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.1`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.2`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.3`,
        fs:  `cpe:2.3:a:mark_theunissen:views_lang_switch:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.4`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.0.179.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.5`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.6`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.91.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.7`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.7.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:2.2.9`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ratbox:ircd-ratbox:3.0.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rationalplan:moos_project_viewer:2.6.2`,
        fs:  `cpe:2.3:a:quagga:quagga:0.97.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.4`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.5`,
        fs:  `cpe:2.3:a:7-zip:p7zip:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6`,
        fs:  `cpe:2.3:a:hp:san\/iq:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.1`,
        fs:  `cpe:2.3:a:emc:document_sciences_xpression:4.1:sp1:-:*:enterprise:-:-:publish_engine`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.3`,
        fs:  `cpe:2.3:a:xymon:xymon:4.2:alfa:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.4`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.5`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.6`,
        fs:  `cpe:2.3:a:three:my3:\@7f0a0001:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.7`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p2_rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.553:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.10`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.3:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.11`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.12`,
        fs:  `cpe:2.3:a:ibm:db2_content_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.13`,
        fs:  `cpe:2.3:a:apache:http_server:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.14`,
        fs:  `cpe:2.3:a:apple:cups:1.2:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.15`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.1267:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.16`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.17`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.18`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.19`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.20`,
        fs:  `cpe:2.3:a:iss:realsecure:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ray_stode:accountsservice:0.6.21`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rayburn_davis:duplicate_commander:2.1`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:razerzone:razer_comms_-_gaming_messenger:1.3.07::~~~android~~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.827:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.2`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.2:rc`,
        fs:  `cpe:2.3:a:serv-u:serv-u:3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.2:rc2`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.3`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.3:beta`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.3:beta1`,
        fs:  `cpe:2.3:a:winzip:winzip_command_line_support_add-on:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.3:beta2`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.3:rc`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.3:rc2`,
        fs:  `cpe:2.3:h:extremenetworks:msm64:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:0.4`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.:*:free:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:1.0`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:1.0:beta`,
        fs:  `cpe:2.3:a:gnome:glib:2.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:1.0:beta2`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:9.3.62.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:1.0:rc`,
        fs:  `cpe:2.3:a:gnu:glibc:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:1.2`,
        fs:  `cpe:2.3:a:linux-nfs:nfs-utils:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:1.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.27:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:razorcms:razorcms:1.2.2`,
        fs:  `cpe:2.3:a:lsi:mystorage_sas:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rbfcu:rbfcu_mobile:3.1::~~~android~~`,
        fs:  `cpe:2.3:a:gajim:gajim:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:readplease:readplease_plus:2003`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:readydesk:readydesk:9.1`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:readynet_solutions:wrt300n-dd:-`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:readynet_solutions:wrt300n-dd_firmware:1.0.26`,
        fs:  `cpe:2.3:a:forfone:forfone\:_free_calls_\&amp;_messages:1.5.11:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:real:realplayer:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.11.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:real:realplayer:10.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_hydravision_full:2010.0302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:real:realplayer:10.5`,
        fs:  `cpe:2.3:a:bluecatnetworks:adonis_management_console:4.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:real:realplayer:11`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:real:realplayer:11_build_6.0.14.748`,
        fs:  `cpe:2.3:a:simpel-reserveren_project:simpel-reserveren:3.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:real-estate-php-script:real_estate_php_script:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realacademiabellasartessanfernando:real_academia_de_bellas_artes:1::~~~android~~`,
        fs:  `cpe:2.3:a:emerson:aperture_web_services_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realflex:flexview:3.1.85`,
        fs:  `cpe:2.3:a:e2fsprogs_project:e2fsprogs:1.43.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realflex:realwin:1.06`,
        fs:  `cpe:2.3:a:eduserv:openathens_service_provider:2.0:-:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:realflex:realwin:2.0`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62s:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realflex:realwin:2.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5a\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realflex:realwin:2.1.12`,
        fs:  `cpe:2.3:a:apple:java_1.4:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realflex:realwindemo:2.1.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reality66:cart66_lite:1.5.1.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:caucho:resin:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reality66:cart66_lite:1.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:h:siemens:ozw772:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realmd_project:realmd:15.2`,
        fs:  `cpe:2.3:a:apache:activemq:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realarcade_installer:3.0.7`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:-`,
        fs:  `cpe:2.3:o:novell:netware:6.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:2.1.2::enterprise`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.181.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:2.1.3::enterprise`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:2.1.4::enterprise`,
        fs:  `cpe:2.3:h:nisuta:ns-wir150ne:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:4`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:5`,
        fs:  `cpe:2.3:a:st:tpm_software:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:6`,
        fs:  `cpe:2.3:a:citrix:license_configuration_tool:1.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:7`,
        fs:  `cpe:2.3:a:mahara:mahara:1.7.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:8`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:10.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:10.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.0`,
        fs:  `cpe:2.3:a:libgd:libgd:2.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.0.1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.0.2`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.0.2.1744`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.7.1.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.0.2.2315`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.13:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.0.3`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:2.0:-:coldfusion:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.0.5`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11.1.3`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:11_build_6.0.14.748`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.616:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:12.0.0.1444`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:12.0.0.1548`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:12.0.1.1737:-:~-~-~mac_os_x~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:12.0.1.1738::~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:14.0.0`,
        fs:  `cpe:2.3:a:bsd_group:license_server:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:14.0.1`,
        fs:  `cpe:2.3:a:veritas:volume_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:14.0.1.609`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.11.108364.552:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:14.0.2`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security:e80:-:vpn_blade:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:14.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:14.0.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:14.0.5`,
        fs:  `cpe:2.3:a:cazoodle:nutch:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:15.0.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:15.0.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:15.0.4.43`,
        fs:  `cpe:2.3:a:intel:mscfg:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:15.0.5.109`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:15.0.6.14`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:15.02.71`,
        fs:  `cpe:2.3:a:afterlifewitharchie:afterlife_with_archie:2.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:16.0.0`,
        fs:  `cpe:2.3:a:samba:ppp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:16.0.0.282`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:16.0.1.18`,
        fs:  `cpe:2.3:a:samba:samba:1.9.17:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:16.0.2.32`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bbet64c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:16.0.3.51`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:17.0.4.60`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:17.0.8.22`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer:17.0.10.8`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.0.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.0.2`,
        fs:  `cpe:2.3:a:digium:asterisk:11.21.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.0.5`,
        fs:  `cpe:2.3:a:atlassian:jira:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.1`,
        fs:  `cpe:2.3:a:debian:apt-listchanges:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.1.1`,
        fs:  `cpe:2.3:o:t-com:speedport_500v_firmware:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.1.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc611a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.1.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.1.4`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realplayer_sp:1.1.5`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:7.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:realupgrade:1.1.0`,
        fs:  `cpe:2.3:a:zope:zope:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:rhapsody:1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:rhapsody:1.1`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:rhapsody:3.0`,
        fs:  `cpe:2.3:a:gnome:screensaver:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realnetworks:rhapsody:4.0`,
        fs:  `cpe:2.3:a:gajim:gajim:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realtek:realtek_ac%2797_audio:5.18`,
        fs:  `cpe:2.3:a:adobe:connect:9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realtek:realtek_ac%2797_audio:5.33`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_process_systems_with_cimplicity:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realtek:realtek_ac%2797_audio:5.35`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realtek:realtek_sdk:-`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realtimesoft:zenview_manager:3.0.9`,
        fs:  `cpe:2.3:a:pp-solution:orakel-ball:0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:-`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:4.1.3::~~free~~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:5.0.0`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:5.0.1`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:5.0.2`,
        fs:  `cpe:2.3:a:docker:docker:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:5.0.3`,
        fs:  `cpe:2.3:a:happyworm:jplayer:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:5.0.4`,
        fs:  `cpe:2.3:a:symantec:encryption_desktop:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:5.0.5`,
        fs:  `cpe:2.3:h:ibm:x330:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:5.0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:realvnc:realvnc:5.0.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.2.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:0.93.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:0.93.1`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:0.93.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:0.93.3`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-51-\/k:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.2`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.3`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.5`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.5.1`,
        fs:  `cpe:2.3:a:tips_and_tricks_hq:all_in_one_wordpress_security_and_firewall:3.8.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.6`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.6.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reasoncms:reasoncms:4.7`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.03.0530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recipes-writer_project:recipes-writer:1.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recommend_to_a_friend_project:recommend_to_a_friend:2.0.2`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.7:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recoverytoolbox:recovery_toolbox_for_outlook_password:1.1`,
        fs:  `cpe:2.3:a:synck_graphica:download_log_cgi:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recruit:dokodemo_rikunabi_2013:1.0.0`,
        fs:  `cpe:2.3:a:acme:thttpd:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recruit:dokodemo_rikunabi_2013:1.0.1`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.3.1.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.0`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.1`,
        fs:  `cpe:2.3:a:docker:docker:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_host_on-demand:8.0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.3`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.4`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.5`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.6`,
        fs:  `cpe:2.3:a:shavlik:netchk_configure:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.7`,
        fs:  `cpe:2.3:a:xchat:xchat:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.8`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.9`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.10`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_server:3.6:ebz:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.11`,
        fs:  `cpe:2.3:a:oracle:pharmaceutical:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.0.12`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1013.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.0`,
        fs:  `cpe:2.3:a:isc:bind:8.2.2:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.0:c`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.1`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.2`,
        fs:  `cpe:2.3:a:lucent:vitalanalysis:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.4`,
        fs:  `cpe:2.3:h:supermicro:h8sgl-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.5`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.6`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.7`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.8`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.9`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.1.10`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.4.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.2.0`,
        fs:  `cpe:2.3:a:magento:magento:1.14.2.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.2.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.2.2`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.2.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.2.4`,
        fs:  `cpe:2.3:o:huawei:5700hi_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.0`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v200r008c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.0:beta1`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.1`,
        fs:  `cpe:2.3:h:juniper:idp800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.2`,
        fs:  `cpe:2.3:h:nvidia:quadro_m5500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.3`,
        fs:  `cpe:2.3:a:haxx:curl:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.4`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.5`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.6`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.1:ea4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.7`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.9:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.3.9`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.0\(2a\)es62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.1`,
        fs:  `cpe:2.3:a:actividentity:activcard_usb_reader:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.2`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.3:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.3`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.4`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.5`,
        fs:  `cpe:2.3:a:webmin:usermin:1.600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.6`,
        fs:  `cpe:2.3:a:apache:libcloud:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.7`,
        fs:  `cpe:2.3:a:altiris:out_of_band_setup_and_configuration_language_pack:6.2.1012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.8`,
        fs:  `cpe:2.3:a:nortel:centrex_ip_element_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.9`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:10.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.4.10`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.5.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.5.0`,
        fs:  `cpe:2.3:a:microsoft:pocket_ie:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.5.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.5.2`,
        fs:  `cpe:2.3:h:extremenetworks:summit:6.2.2_68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.5.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.6.0`,
        fs:  `cpe:2.3:a:ushahidi:ushahidi_platform:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.6.1`,
        fs:  `cpe:2.3:a:ca:etrust_access_control:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.6.2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.7.0`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.7.1`,
        fs:  `cpe:2.3:a:adobe:flash_cs4:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.7.2`,
        fs:  `cpe:2.3:a:oracle:database_server:9.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.7.3`,
        fs:  `cpe:2.3:a:collectd:collectd:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.7.4`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.7.5`,
        fs:  `cpe:2.3:a:nullsoft:nullsoft_install_system:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.7.6`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.14.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.7.7`,
        fs:  `cpe:2.3:h:yokogawa:aaasuite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.8.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.8.0:rc1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.547:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.8.0:rc3`,
        fs:  `cpe:2.3:a:srvx:srvx:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.8.1`,
        fs:  `cpe:2.3:a:starluxstudios:puppy_slots:3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.9.0`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.9.1`,
        fs:  `cpe:2.3:a:pixman:pixman:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.10.0`,
        fs:  `cpe:2.3:h:moxa:iologic_e2210:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.10.1`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.10.2`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.10.3`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.11.0`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.11.1`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1690.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:recurly:recurly_client_ruby:2.11.2`,
        fs:  `cpe:2.3:a:ektron:ektron_content_management_system:8.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_backup:3.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_backup:4.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_backup:4.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_backup:5.3`,
        fs:  `cpe:2.3:a:siemens:simatic_s7_cfc:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_backup:5.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_backup:6.3`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:5.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:6.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:6.1`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:331.00:-:*:*:windows:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:6.2`,
        fs:  `cpe:2.3:a:hp:openview_client_configuraton_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:7.0`,
        fs:  `cpe:2.3:a:cisco:webex_sales_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:7.1`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:7.2`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:8.0`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_compare:8.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_comparison_sdk:7.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_comparison_sdk:7.1`,
        fs:  `cpe:2.3:a:google:v8:3.24.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_comparison_sdk:8.0`,
        fs:  `cpe:2.3:h:yokogawa:field_wireless_device_opc_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:4.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:5.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:5.3`,
        fs:  `cpe:2.3:a:qmania:aloha_guide:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:5.4`,
        fs:  `cpe:2.3:a:debian:dpkg:1.15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:6.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:6.1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:6.1.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:7.0`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:7.1`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.5.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:8.0`,
        fs:  `cpe:2.3:a:cloudera:hadoop:0.20.1\&#43;169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:8.0.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_compare:8.0.2`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_generator:1.0`,
        fs:  `cpe:2.3:a:horde:imp:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_generator:1.1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_data_generator:1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(11\)st4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_dependency_tracker:2.0`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_dependency_tracker:2.1`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_dependency_tracker:2.4`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_dependency_tracker:2.5`,
        fs:  `cpe:2.3:a:citrix:xenapp_reports:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_doc:1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_doc:1.2`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_doc:1.3.0`,
        fs:  `cpe:2.3:a:rubyonrails:rails:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_doc:2.0`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_multiscript:1.0`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.1:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_multiscript:1.1`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_packager:5.0`,
        fs:  `cpe:2.3:a:axis:media_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_packager:5.1`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_packager:5.2`,
        fs:  `cpe:2.3:a:redhat:dogtag_certificate_system:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_packager:5.3`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(8.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_packager:5.4`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_packager:5.5`,
        fs:  `cpe:2.3:a:ibm:net.data:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_packager:6.0`,
        fs:  `cpe:2.3:a:ca:license_software:1.90.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:2.0`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:3.0`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:3.1`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:3.5`,
        fs:  `cpe:2.3:a:quizzler_project:quizzler:7.x-1.15:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:3.6`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:3.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:3.8`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:3.9`,
        fs:  `cpe:2.3:h:hp:10500\/7500_advanced_vpn_firewall_module:jd249a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:4.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30392:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_prompt:4.0.3`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_refactor:1.0`,
        fs:  `cpe:2.3:a:sun:one_web_server:6.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_refactor:1.1`,
        fs:  `cpe:2.3:a:quest:intrust_resource_kit:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_refactor:1.3`,
        fs:  `cpe:2.3:a:spip:spip:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_response:1.0`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_response:1.1`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:7.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_response:1.2`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.0.6:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:red-gate:sql_response:1.3`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redatoms:redatoms_three:2.5::~~~android~~`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxo:redaxo:2.7.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxo:redaxo:3.0`,
        fs:  `cpe:2.3:a:typo3:typo3:7.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxo:redaxo:3.2`,
        fs:  `cpe:2.3:h:hp:3com_router:5012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxo:redaxo:4.3`,
        fs:  `cpe:2.3:a:vmware:tools:9.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxo:redaxo:4.3.1`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxo:redaxo:4.3.2`,
        fs:  `cpe:2.3:a:imember360:imember360:3.7.008:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxo:redaxo:4.3.3`,
        fs:  `cpe:2.3:h:rockwellautomation:controllogix_l55_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxo:redaxo:4.4`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redaxscript:redaxscript:2.2.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redcarpet_project:redcarpet:3.3.1`,
        fs:  `cpe:2.3:a:apache:poi:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redcloth:redcloth_library:4.2.9::~~~ruby~~`,
        fs:  `cpe:2.3:h:nortel:ip_phone_1110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redgraphic:sapid_cms:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redgraphic:sapid_cms:1.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(14\)st3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redgraphic:sapid_cms:1.2.3:rc2`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redgraphic:sapid_cms:1.2.3:rc3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redgraphic:sapid_cms:1.2.3:rc5`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.3.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redgraphic:sapid_cms:1.2.3:stable`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redgraphic:sapid_cms:1.2.3.02`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redgraphic:sapid_cms:1.2.3.03`,
        fs:  `cpe:2.3:a:martin_lee:multi-lingual_e-commerce_system:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:aeolus_conductor:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:analog_real-time_synthesizer:-`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:analog_real-time_synthesizer:2.1.1-5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.0-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:analog_real-time_synthesizer:2.2-11`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0589:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:application_server:-`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.6`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.807:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.7.1`,
        fs:  `cpe:2.3:a:componentone:flexgrid:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.8`,
        fs:  `cpe:2.3:o:belkin:n150_f9k1009_firmware:1.00.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.8.5`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.2:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.9`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.10`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:0.0.11`,
        fs:  `cpe:2.3:a:sixapart:movable_type:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.2`,
        fs:  `cpe:2.3:a:keepass:keepass:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.3`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.4`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.5`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.6`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p477:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.7-el6`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.7.f12`,
        fs:  `cpe:2.3:a:softbank:wi-fi_spot_configuration_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.8`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.000:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.0.9`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.0`,
        fs:  `cpe:2.3:a:microsoft:lync_basic:2013:-:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.2`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.3`,
        fs:  `cpe:2.3:a:vips:vips:7.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:26.0.0.137:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.5`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.6`,
        fs:  `cpe:2.3:a:digium:asterisk:10.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.7`,
        fs:  `cpe:2.3:a:rakus:maildealer:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.9`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.10`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:6.7:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.11`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.12`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:10.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.13`,
        fs:  `cpe:2.3:a:isc:bind:9.3.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.14`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.15`,
        fs:  `cpe:2.3:a:sgi:fam:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.16`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2:update14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:1.1.17`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.25:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.1`,
        fs:  `cpe:2.3:o:apple:iphone_os:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.3`,
        fs:  `cpe:2.3:a:arcsight:arcsight_console:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.4`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.4.980`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.4.981`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.6`,
        fs:  `cpe:2.3:a:foliovision:foliopress_wysiwyg:2.6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.7`,
        fs:  `cpe:2.3:h:ibm:power_5:9123-710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.8`,
        fs:  `cpe:2.3:a:mozilla:camino:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.9`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.10`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.3.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.11`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.12`,
        fs:  `cpe:2.3:a:commerce_ogone_project:commerce_ogone:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.13`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ew1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.15`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.16`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.17`,
        fs:  `cpe:2.3:a:hp:destinations:82.0.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.18`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.0.1-40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.19`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.0.20`,
        fs:  `cpe:2.3:a:igniterealtime:smack:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:automatic_bug_reporting_tool:2.7.0`,
        fs:  `cpe:2.3:a:apache:activemq_artemis:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:bigmem_kernel:-`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:bigmem_kernel:2.4.20-8`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cairo:-`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cairo:1.4.12`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:ceph:0.94.3`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:certificate_server:-`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.3.3:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_server:-`,
        fs:  `cpe:2.3:a:corel:wordperfect_office:11.0.0.233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:certificate_server:7.1`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20130926:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:certificate_server:7.2`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:sp4_patch4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_server:7.2`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:certificate_server:7.3`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_system:-`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.1:sp14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_system:7.1`,
        fs:  `cpe:2.3:h:cisco:voice_gateway_as5800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_system:7.2`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_system:7.3`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:19.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_system:8`,
        fs:  `cpe:2.3:a:ibm:cloudscape:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_system:8.0`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_system:8.1`,
        fs:  `cpe:2.3:a:ibm:bootable_media_creator:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:certificate_system:8.1.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms:1.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms:1.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:gold:media_center:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms:3.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms:3.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms:4.0`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300eec_firmware:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms:4.1`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc3825:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)xp4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2.1`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2.1.6`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2.2`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2.3`,
        fs:  `cpe:2.3:a:canonical:telepathy-idle:0.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2.3.2`,
        fs:  `cpe:2.3:a:opensolution:quick_cms:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2.4`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2.4.2`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:9.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.0_management_engine:5.2.5.3`,
        fs:  `cpe:2.3:a:lunarcms:lunar_cms:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_3.1_management_engine:5.3`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_cloud_engine:1.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_cloud_engine:1.1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:4.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_cloud_engine:1.1.2`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_management_engine:5.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_management_engine:5.4.4`,
        fs:  `cpe:2.3:a:symantec:system_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cloudforms_management_engine:5.5.0`,
        fs:  `cpe:2.3:a:novell:groupwise:8.03:hp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cluster_suite:-`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0a4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:conga:-`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.2.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:conga:0.10.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cygwin:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)xr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cygwin:1.5.7`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:cygwin:1.5.7-1`,
        fs:  `cpe:2.3:a:samsung:kies:2.3.2.12074:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:daredevil_skk:-`,
        fs:  `cpe:2.3:a:datadynamics:activereports:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:daredevil_skk:11.3.2`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:6.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:daredevil_skk:11.3.5`,
        fs:  `cpe:2.3:a:google:v8:3.23.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:daredevil_skk:11.6.0-6`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:daredevil_skk:11.6.0-8`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:daredevil_skk:11.6.0-10`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:ddskk-xemacs:11.6.0-6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.656:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:ddskk-xemacs:11.6.0-8`,
        fs:  `cpe:2.3:a:jahia:jahia_xcm:6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:ddskk-xemacs:11.6.0-10`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:desktop:-`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:desktop_workstation:5`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:developer_suite:-`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:directory_server:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:directory_server:-`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:directory_server:7.1`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:directory_server:7.1`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:directory_server:8`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:directory_server:8.0`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:directory_server:8.1`,
        fs:  `cpe:2.3:a:e107:e107:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:directory_server:8.2`,
        fs:  `cpe:2.3:h:samsung:galaxy_note_2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:docbook_stylesheets:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:docbook_stylesheets:1.54.13`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:docbook_utils:-`,
        fs:  `cpe:2.3:o:conectiva:linux:prg_graficos:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:docbook_utils:0.6.9-2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:docbook_utils:0.6.13`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:docker:1.5.0-27`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_content_creator:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:dogtag_certificate_system:-`,
        fs:  `cpe:2.3:h:cisco:aironet_1850i:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:dogtag_certificate_system:9.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:dogtag_certificate_system:10.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:drools:6.1.0`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:dtach:0.8`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:9.1.1\(a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:-`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.01.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:2.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:2.1::as`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:5.1.0.1021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:2.1::aw`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:2.1::es`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:2.1::ia64-as`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:2.1::ia64-es`,
        fs:  `cpe:2.3:a:postfix:postfix:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:2.1::ia64-ws`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:2.1::ws`,
        fs:  `cpe:2.3:a:isc:bind:8.2.2:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3`,
        fs:  `cpe:2.3:a:apache:struts:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:ga`,
        fs:  `cpe:2.3:o:d-link:dsr-150_firmware:1.05b35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:ga:as`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:ga:desktop`,
        fs:  `cpe:2.3:a:hp:openview_http_communication:6.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:ga:es`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)eu2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:ga:ws`,
        fs:  `cpe:2.3:a:gimp:gimp:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update1`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2007:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update1:as`,
        fs:  `cpe:2.3:a:apple:quicktime:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update1:desktop`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update1:es`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.20:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update1:ws`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update2`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:7.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update2:as`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update2:desktop`,
        fs:  `cpe:2.3:a:oracle:diagnostics:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update2:es`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_1300_65:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update2:ws`,
        fs:  `cpe:2.3:h:polycom:rmx_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update3:as`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update3:desktop`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update3:es`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update3:ws`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:12.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update4`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update4:as`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update4:desktop`,
        fs:  `cpe:2.3:a:emc:networker:7.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update4:es`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update4:ws`,
        fs:  `cpe:2.3:h:dell:poweredge_r910:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.00:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update5:as`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update5:desktop`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.11.4619:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update5:es`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update5:ws`,
        fs:  `cpe:2.3:h:intel:express_550f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update6`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.3:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update6:as`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.11:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update6:desktop`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update6:es`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:337.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update6:ws`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update7`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update7:as`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update7:desktop`,
        fs:  `cpe:2.3:a:avst:callxpress:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update7:es`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update7:ws`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.0:*:solaris:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update8`,
        fs:  `cpe:2.3:a:teklynx:codesoft:7.10.100:*:*:*:special_edition:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update8:as`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update8:desktop`,
        fs:  `cpe:2.3:a:lxml:lxml:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update8:es`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update8:ws`,
        fs:  `cpe:2.3:a:vmware:vcenter_operations:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update9`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update9:as`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update9:desktop`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20111118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update9:es`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3:update9:ws`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:3.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4`,
        fs:  `cpe:2.3:a:arabportal:arab_portal:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:ga`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:gold:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:ga:as`,
        fs:  `cpe:2.3:a:redhat:jboss_web_framework_kit:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:ga:desktop`,
        fs:  `cpe:2.3:a:ssh:accession:ssh_accession_1.2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:ga:es`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:ga:ws`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update1:as`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update1:desktop`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update1:es`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.186:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update1:ws`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)ex2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update2`,
        fs:  `cpe:2.3:a:enyetech:coca-cola_fm_peru:2.0.41716:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update2:as`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update2:desktop`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update2:es`,
        fs:  `cpe:2.3:a:web2py:web2py:1.91.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update2:ws`,
        fs:  `cpe:2.3:a:cisco:business_edition_5000_software:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update3`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update3:as`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update3:desktop`,
        fs:  `cpe:2.3:a:google:v8:3.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update3:es`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update3:ws`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update4`,
        fs:  `cpe:2.3:a:ipswitch:imail_server:8.2:hotfix2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update4:as`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update4:desktop`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1:update19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update4:es`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:7.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update4:ws`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update5`,
        fs:  `cpe:2.3:a:php:php:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update5:as`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update5:desktop`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update5:es`,
        fs:  `cpe:2.3:a:feedwordpress_project:feedwordpress:2014.0805:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update5:ws`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.5:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update6`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update6:as`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update6:desktop`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update6:es`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4:update6:ws`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:4.5`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5`,
        fs:  `cpe:2.3:a:abbyy:finereader:5.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5::client`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5::client_workstation`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.3.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5::server`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.1.1:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:ga`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:ga:client`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:ga:client_workstation`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:ga:server`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:unknown:server`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:update1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:update1:client`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:update1:client_workstation`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5:update1:server`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5.0`,
        fs:  `cpe:2.3:a:brother:p-touch_editor:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5.1.0`,
        fs:  `cpe:2.3:a:innominate:eagle_mguard:bd-301010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5.1.0:beta`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:5.4::server_x64`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:6`,
        fs:  `cpe:2.3:a:cisco:webex_meetings:8.0_base:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:6.7`,
        fs:  `cpe:2.3:a:autodesk:autocad_architecture_2010_language_pack:18.0.55.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:7.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:7.1`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.032_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:7.2`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:7.3`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux:7.4`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux__optional_productivity_applications:-`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_cluster-storage:5`,
        fs:  `cpe:2.3:o:debian:debian_linux:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_cluster_suite:3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.21923:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_cluster_suite:4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2010.302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_cluster_suite:5`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7940:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop:3.0`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop:4`,
        fs:  `cpe:2.3:a:hp:openview_omniback_ii:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop:4.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.603:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop:4.4`,
        fs:  `cpe:2.3:a:paidmembershipspro:paid_memberships_pro:1.7.14.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop:5:unknown:client`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_human_capital_management_human_resources:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop:5.0`,
        fs:  `cpe:2.3:a:mit:kerberos_ftp_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop:6.0`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop:7.0`,
        fs:  `cpe:2.3:a:yahoo:yui:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop_supplementary:5.0`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_desktop_supplementary:6.0`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_developer_suite:1`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp3:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_developer_suite:1.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2010.211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_developer_suite:2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_developer_suite:2.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_developer_suite:3`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_developer_suite:3.0`,
        fs:  `cpe:2.3:a:batavi:batavi:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_hpc_node:6.0`,
        fs:  `cpe:2.3:a:apache:qpid:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_hpc_node:7.0`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.5\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_hpc_node_eus:7.2`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_load_balancer:6.0`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_linux_load_balancer:6.4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.369.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server:6.0`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.23:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server:7.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server_aus:7.2`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:587:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server_eus:7.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server_supplementary:5.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1286.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server_supplementary:6.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server_supplementary:6.1.z`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server_supplementary:6.4`,
        fs:  `cpe:2.3:a:gnome:evolution:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server_supplementary:6.4.z`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_server_supplementary_eus:6.7z`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_supplementary:5.0`,
        fs:  `cpe:2.3:a:microsoft:visio:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_virtualization:-`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_virtualization:5.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_workstation:6.0`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b1_pk4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_workstation:7.0`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.33:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_linux_workstation_supplementary:6.0`,
        fs:  `cpe:2.3:a:microsoft:word:2002:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(2\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.0.1`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.0.2`,
        fs:  `cpe:2.3:a:nortel:preside_site_manager:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.0.3`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:12.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.1.2`,
        fs:  `cpe:2.3:o:cisco:voip_phone_cp-7910:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.2`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.08.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.2.2`,
        fs:  `cpe:2.3:a:rack_project:rack:1.1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:1.3`,
        fs:  `cpe:2.3:a:ephiphanyheathdata:cardio_server:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:2.0`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:2.1`,
        fs:  `cpe:2.3:a:cisco:business_edition_5000_software:8.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:2.2`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:2.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.4:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:2.4`,
        fs:  `cpe:2.3:a:altiris:application_control_solution_documentation:6.1.1015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_mrg:2.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p189:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization:2.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization:3.0`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization:3.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization:3.4`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_virtualization_manager:2.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization_manager:2.1`,
        fs:  `cpe:2.3:a:gnu:anubis:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization_manager:2.2`,
        fs:  `cpe:2.3:a:sympa:sympa:5.4a.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_virtualization_manager:2.2`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_virtualization_manager:2.2.3`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization_manager:2.2.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_virtualization_manager:2.2.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_virtualization_manager:3.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization_manager:3.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:enterprise_virtualization_manager:3.1`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization_manager:3.1`,
        fs:  `cpe:2.3:a:ibm:net.commerce:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization_manager:3.2`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization_manager:3.4.1`,
        fs:  `cpe:2.3:a:esri:arcgis:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:enterprise_virtualization_manager:3.5.0`,
        fs:  `cpe:2.3:a:bmc:control-m\/agent:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora:-`,
        fs:  `cpe:2.3:a:k5n:webcalendar:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora:7`,
        fs:  `cpe:2.3:a:apache:hadoop:0.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora:8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora:10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora_core:-`,
        fs:  `cpe:2.3:h:hp:3com_router:3018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora_core:1`,
        fs:  `cpe:2.3:a:oskarshamnsliv_project:oskarshamnsliv:6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora_core:2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora_core:3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(18.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora_core:4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora_core:5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19.3\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:fedora_core:6`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.2:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:2.0.0`,
        fs:  `cpe:2.3:a:k7computing:k7sentry.sys:12.8.0.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:2.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:2.1.0`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:2.1.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:2.1.3`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.31.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:2.1.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:2.2.1`,
        fs:  `cpe:2.3:a:atlassian:jira:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:3.0.0`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:3.0.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:3.0.2`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.0.1:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:3.1.1`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:freeipa:3.1.2`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:gdk_pixbuf:-`,
        fs:  `cpe:2.3:a:hp:6300_help:71.0.215.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:gdk_pixbuf:0.18.0-7`,
        fs:  `cpe:2.3:a:trialtracker:trial_tracker:1.1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:gluster_storage:3.1`,
        fs:  `cpe:2.3:a:cisco:email_security_virtual_appliance:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.0`,
        fs:  `cpe:2.3:h:hp:jd673a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.1`,
        fs:  `cpe:2.3:a:apple:itunes:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.2`,
        fs:  `cpe:2.3:a:compaq:insight_manager_xe:2.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd304a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.5`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.6`,
        fs:  `cpe:2.3:a:oracle:marketing:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.7`,
        fs:  `cpe:2.3:a:qemu:qemu:1.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:hawtjni:1.8`,
        fs:  `cpe:2.3:a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea:1.5.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3060_concentrator:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.0.1`,
        fs:  `cpe:2.3:a:google:authenticator:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.0.2`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_2_firmware:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.0.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.0.4`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.13.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.0.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.0.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:6.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.1.1`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.5:sp0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.1.2`,
        fs:  `cpe:2.3:a:microsoft:office_compatibility_pack:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.1.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.1.4`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.1.5`,
        fs:  `cpe:2.3:a:intel:network_connections:13.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.1.6`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.1.7`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.2`,
        fs:  `cpe:2.3:a:rack_project:rack:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.2.1`,
        fs:  `cpe:2.3:a:rsa:keon_registration_authority_web_interface:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.2.2`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea-web:1.3.1`,
        fs:  `cpe:2.3:a:redprairie:reporting_designer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8.1`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1-14:fix03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8.2`,
        fs:  `cpe:2.3:a:jruby:jruby:1.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8.4`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8.5`,
        fs:  `cpe:2.3:a:opensolution:quick.cms.lite:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8.6`,
        fs:  `cpe:2.3:a:spi\/si263b:outlook_security_settings:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8.7`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.8.8`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.9.1`,
        fs:  `cpe:2.3:a:microsoft:orca:4.0.6001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.9.2`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.9.3`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.9.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.356:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.9.5`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5b\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.9.6`,
        fs:  `cpe:2.3:a:ubercart_views_project:uc_views:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.9.7`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea6:1.9.8`,
        fs:  `cpe:2.3:a:perl:perl:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:icedtea7:2.6.6`,
        fs:  `cpe:2.3:a:embedthis:goahead:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:interchange:-`,
        fs:  `cpe:2.3:a:f5:big-ip:9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:interchange:4.8.1`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:interchange:4.8.2`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:interchange:4.8.3`,
        fs:  `cpe:2.3:a:google:chrome:14.0.829.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:interchange:4.8.4`,
        fs:  `cpe:2.3:a:umn:mapserver:5.4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:interchange:4.8.5`,
        fs:  `cpe:2.3:a:rack_project:rack:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_a-mq:6.0.0`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_bpm_suite:6.0.0`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.2:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_bpm_suite:6.0.1`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_bpm_suite:6.3`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_bpm_suite:6.3.2`,
        fs:  `cpe:2.3:h:cisco:unity_express:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_communications_platform:1.2.11`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.17:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_communications_platform:5.1.1`,
        fs:  `cpe:2.3:h:loytec:linx-100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:5.0.0`,
        fs:  `cpe:2.3:a:hp:openview_agent_extension_for_configuration_and_discovery:2.1.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:5.0.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:5.1.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:6.0.0`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2006-03-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:6.1.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:7.0.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:7.0.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:7.0.2`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:7.1.0`,
        fs:  `cpe:2.3:a:ireadercity:sword:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_community_application_server:7.1.1`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_data_virtualization:6.0.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_drools:-`,
        fs:  `cpe:2.3:a:shawn_bradley:php_ticket_system:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:4.2.0`,
        fs:  `cpe:2.3:a:apache:openoffice:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:4.2.0:cp09`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p264:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:4.3.0`,
        fs:  `cpe:2.3:h:hp:elitebook_755_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:4.3.0:cp10`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:5.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:5.0.1`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.47:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:5.1.0`,
        fs:  `cpe:2.3:a:hp:hph_software:70.0.260.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:5.1.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2009.312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:5.1.2`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.2.1.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:5.2.0`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1005.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:5.2.1`,
        fs:  `cpe:2.3:a:corel:fastflick:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:5.2.2`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.7.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.0.0`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.0.1`,
        fs:  `cpe:2.3:h:huawei:s5300li:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.1.0`,
        fs:  `cpe:2.3:a:cisco:webns:8.20.2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.1.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.2.0`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.2.1`,
        fs:  `cpe:2.3:a:lucktastic:lucktastic:1.2.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.2.2`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.2.3`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.2.4`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.3.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.3.1`,
        fs:  `cpe:2.3:h:cisco:ip_phone_7902:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.3.2`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.3.3`,
        fs:  `cpe:2.3:a:altiris:service_control_task_agent:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.0`,
        fs:  `cpe:2.3:a:openx:openx:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.1`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.2`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.3`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.5:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.4`,
        fs:  `cpe:2.3:a:google:chrome:10.0.646.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.5`,
        fs:  `cpe:2.3:a:dotcms:dotcms:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.6`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.7`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.8`,
        fs:  `cpe:2.3:h:ibm:system_x3550_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.9`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd935a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.10`,
        fs:  `cpe:2.3:a:avaya:vpnremote:4.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.11`,
        fs:  `cpe:2.3:a:x:libxcursor:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.12`,
        fs:  `cpe:2.3:a:iojs:io.js:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.13`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.14`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.15`,
        fs:  `cpe:2.3:a:vmware:zimbra_desktop:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.16`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.17`,
        fs:  `cpe:2.3:a:lsi:dell_sas_raid_storage_manager:2.66.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:6.4.18`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.1`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.3`,
        fs:  `cpe:2.3:a:busybox:busybox:0.60.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.4`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.5`,
        fs:  `cpe:2.3:a:libav:libav:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.6`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.7`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:3.0.0.4.354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.8`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.0.9`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_application_platform:7.1.0`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.05.4250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:5.0.0`,
        fs:  `cpe:2.3:a:canon:mp_navigator_ex:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:5.0.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:5.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:5.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:5.2.0`,
        fs:  `cpe:2.3:a:sun:jre:6.0.240:update24:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:5.3.0`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.4:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:5.3.1`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:6.0.0`,
        fs:  `cpe:2.3:a:microsoft:backoffice_resource_kit:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:6.0.1`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_brms_platform:6.0.3`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_data_services_platform:5.1.0`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.30.020.1931:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_data_services_platform:5.2.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_data_services_platform:5.3.0`,
        fs:  `cpe:2.3:a:schneems:wicked:1.0.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:4.3.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:4.3.0:cp03`,
        fs:  `cpe:2.3:a:kde:ark:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:4.3.0:cp04`,
        fs:  `cpe:2.3:h:antlabs:inngate_ig_3.10_e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:4.3.0:cp05`,
        fs:  `cpe:2.3:a:vmware:workstation:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:4.3.0:cp06`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:4.3.0:cp07`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20140201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:5.0.0`,
        fs:  `cpe:2.3:a:goforandroid:go_weibowidget:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:5.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:5.1.0`,
        fs:  `cpe:2.3:a:samba:samba:4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:5.1.1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:5.2.0`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:5.2.1`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:5.2.2`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1w\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:6.0.0`,
        fs:  `cpe:2.3:a:hp:lefthand_virtual_san_appliance_hydra_software:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:6.1.0`,
        fs:  `cpe:2.3:a:jahia:jahia_xcm:6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_portal_platform:6.2.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.0`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:2.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.2`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.2.1`,
        fs:  `cpe:2.3:a:hp:client_automation_satellite:7.80.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.4`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.5`,
        fs:  `cpe:2.3:o:d-link:dsr-150_firmware:1.05b46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.6`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5607:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.7`,
        fs:  `cpe:2.3:a:adobe:document_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.8`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_service_bus:4.9`,
        fs:  `cpe:2.3:a:schneems:wicked:0.1.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.2.0`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.2.0:cp01`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(3\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.2.0:cp02`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.2.0:cp03`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.5:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.2.0:cp04`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.2.0:cp05`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.2.0:tp02`,
        fs:  `cpe:2.3:a:feeds_project:feeds:7.x-2.0:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.3.0`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.3.0:cp01`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.3.0:cp02`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.3.0:cp03`,
        fs:  `cpe:2.3:o:yahama:rt140i:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.3.0:cp04`,
        fs:  `cpe:2.3:a:tibco:spotfire_analyst:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:4.3.0:cp05`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro:8.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:5.0.0`,
        fs:  `cpe:2.3:a:citrix:group_policy_management:1.5.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:5.0.1`,
        fs:  `cpe:2.3:a:yahoo:tumblr:3.4.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:5.0.2`,
        fs:  `cpe:2.3:a:intel:expressway_cloud_access_360:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:5.1.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:5.1.1`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_inventory_pack_for_servers:6.1.1039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:5.2.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:5.3.0`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_soa_platform:5.3.1`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_platform:5.1.0`,
        fs:  `cpe:2.3:a:digia:qt:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_platform:5.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_platform:5.1.2`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_platform:5.2.0`,
        fs:  `cpe:2.3:o:netgear:r7100lg_firmware:1.0.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_server:1.0.0`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_server:1.0.1`,
        fs:  `cpe:2.3:h:iodata:hdl-as:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_server:1.0.2`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_server:2.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:te2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_enterprise_web_server:2.0.1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_fuse:6.0.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_fuse:6.1.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_fuse_esb_enterprise:7.1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_advanced_media_gateway:1.1\(.1.14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_fuse_service_works:6.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:1.0.0`,
        fs:  `cpe:2.3:a:emc:autostart:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.16s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.1.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.2`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.3.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.d2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.4.1`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.91:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:2.4.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:3.0`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:3.0.1`,
        fs:  `cpe:2.3:a:seotoaster:seotoaster:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:3.1`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20130504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:3.1.1`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:3.1.2`,
        fs:  `cpe:2.3:a:hp:hppiofiles:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:3.3.1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_operations_network:3.3.6`,
        fs:  `cpe:2.3:a:apple:quicktime:7.60.92.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_overlord_run_time_governance:1.0::~~~jbossas~~`,
        fs:  `cpe:2.3:a:tinymce:spellchecker_php:2.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_portal:6.2.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_web_framework_kit:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_web_framework_kit:1.1.0`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_web_framework_kit:1.2.0`,
        fs:  `cpe:2.3:a:easaa:easaa_baoneng:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_web_framework_kit:2.0.0`,
        fs:  `cpe:2.3:h:emc:celerra_network_attached_storage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_web_framework_kit:2.1.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_web_framework_kit:2.2.0`,
        fs:  `cpe:2.3:a:roxio:creator_audio:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_web_framework_kit:2.4.0`,
        fs:  `cpe:2.3:h:hp:procurve_router:jc148b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_web_framework_kit:2.5.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_weld:2.2.7`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_weld:3.0.0:alpha1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:3.0.2.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_weld:3.0.0:alpha2`,
        fs:  `cpe:2.3:a:apple:safari:3.0.4:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_wildfly_application_server:-`,
        fs:  `cpe:2.3:a:combodo:itop:1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_wildfly_application_server:2.0.0:cr8`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jboss_wildfly_application_server:10.0.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:jbpm:6.1.0`,
        fs:  `cpe:2.3:a:microsoft:excel:2000:sp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdebase:-`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert1_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdebase:3.0.3-13`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p28:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs:2.1.1-5`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(8\)sa5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs:2.2-11`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.1:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs:3.0.0-10`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs:3.1-10`,
        fs:  `cpe:2.3:a:hitachi:cosminexus\/opentp1_web_web_front-endset:01-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_devel:-`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_devel:2.1.1-5`,
        fs:  `cpe:2.3:a:webmin:usermin:1.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_devel:2.2-11`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.10:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_devel:3.0.0-10`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_devel:3.0.3-8`,
        fs:  `cpe:2.3:a:powerdns:authoritative:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_devel:3.1-10`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_sound:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.010.20059:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_sound:2.1.1-5`,
        fs:  `cpe:2.3:a:djangoproject:django:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_sound:2.2-11`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_sound_devel:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.562:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_sound_devel:2.1.1-5`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kdelibs_sound_devel:2.2-11`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kernel:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.11:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kernel:2.4.20-8`,
        fs:  `cpe:2.3:a:apparound:apparound_blend:4.9.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kernel:2.4.21`,
        fs:  `cpe:2.3:a:ibm:qradar_incident_forensics:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kernel_doc:-`,
        fs:  `cpe:2.3:a:bitdefender:gravityzone:5.1.11.432:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kernel_doc:2.4.20-8`,
        fs:  `cpe:2.3:h:cisco:ie-4000-8gt4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kernel_source:-`,
        fs:  `cpe:2.3:a:condor_project:condor:7.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kernel_source:2.4.20-8`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kie_workbench:6.0.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:9.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kie_workbench:6.0.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.594.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kon2:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:kvm:83`,
        fs:  `cpe:2.3:a:htc:shift_4g_software:2.75.651.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lha:-`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.8.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lha:1.14i-9`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libpng:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libpng:1.2.2-16`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libpng:1.2.2-20`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.0.8`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.0.9`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.0.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.0.14`,
        fs:  `cpe:2.3:a:ztree_project:ztree:3.5.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.0.16`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.429:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.0.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.0.20`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.1`,
        fs:  `cpe:2.3:a:spip:spip:3.1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.3`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.4`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.5`,
        fs:  `cpe:2.3:a:oracle:customer_interaction_history:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.6`,
        fs:  `cpe:2.3:a:thailand_investor_news_project:thailand_investor_news:1.39s:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.8`,
        fs:  `cpe:2.3:a:hp:openview_storage_management_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.9`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.10`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.1.11`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.2.2`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.2.3`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.3.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.15.0.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.5.1`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libreport:2.6.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libtirpc:0.1.8`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1052:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libtirpc:0.1.9`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libtirpc:0.1.10`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libtirpc:0.1.11`,
        fs:  `cpe:2.3:a:apple:xcode:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libtirpc:0.2.0`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libtirpc:0.2.1`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libtirpc:0.2.2`,
        fs:  `cpe:2.3:a:hitachi:serverconductor\/deploymentmanager:06-00:-:-:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libtirpc:0.2.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.1.7.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:-`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.5:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.0.1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.7.003:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.0.2`,
        fs:  `cpe:2.3:a:cartpauj:shortcode-redirect:1.0.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.0.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.0.4`,
        fs:  `cpe:2.3:a:trihedral:vtscada:8.0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.0.5`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.0.6`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.25.5015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.0`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.3`,
        fs:  `cpe:2.3:a:hp:alm-platform_loader:11.0.4504.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.4`,
        fs:  `cpe:2.3:a:alienwp:hatch:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.5`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.7`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.8`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1t\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.1.9`,
        fs:  `cpe:2.3:a:apple:xsan:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.2.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.2.1`,
        fs:  `cpe:2.3:a:ati:skins:2009.0312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.2.2`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.2.3`,
        fs:  `cpe:2.3:a:redhat:rhel_global_file_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.3.0`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.3.1`,
        fs:  `cpe:2.3:a:roxio:express_labeler:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.3.2`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.0910.1309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.3.3`,
        fs:  `cpe:2.3:a:bmc:performance_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.4.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.24.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.4.1`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.4.2`,
        fs:  `cpe:2.3:a:juniper:smartpass:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.4.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.4.4`,
        fs:  `cpe:2.3:a:php-nuke:php-nuke:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.4.5`,
        fs:  `cpe:2.3:a:citrix:receiver:13.0.0.6685:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.4.6`,
        fs:  `cpe:2.3:a:zimbra:zimbra_collaboration_suite:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.5.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.5.1`,
        fs:  `cpe:2.3:a:webform_multiple_file_upload_project:webform_multiple_file_upload:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.6.0`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.7.3:*:*:*:rim:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.6.1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.6.2`,
        fs:  `cpe:2.3:a:atlassian:jira:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.6.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.6.4`,
        fs:  `cpe:2.3:a:ansys:ls-dyna:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.6.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:8:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.7.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p281:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.7.1`,
        fs:  `cpe:2.3:a:sun:seam:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.7.2`,
        fs:  `cpe:2.3:a:microsoft:outlook_multilingual_user_interface_pack:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.7.3`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.7.4`,
        fs:  `cpe:2.3:a:indexisto_project:indexisto:1.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.7.5`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.7.6`,
        fs:  `cpe:2.3:o:sun:sunos:4.1.3u1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.7.7`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.0`,
        fs:  `cpe:2.3:a:canonical:ltsp_display_manager:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.2`,
        fs:  `cpe:2.3:a:sambar:sambar_server:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(7a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.4`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.5`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.237:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.6`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.7`,
        fs:  `cpe:2.3:a:samba:samba:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.8.8`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.10.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.0`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_vx_clinical_assistant:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.5`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:6.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.6`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.6.1`,
        fs:  `cpe:2.3:a:cyberlink:power2go:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.6.2`,
        fs:  `cpe:2.3:a:apache:subversion:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.6.3`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.7`,
        fs:  `cpe:2.3:a:debian:mime-support:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.9`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.10`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0_rev_a:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11.2`,
        fs:  `cpe:2.3:a:searchblox:searchblox:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.23:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11.5`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11.6`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11.7`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.11.8`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-55:-:enterprise:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.12`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.8a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.9.13`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.0`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2`,
        fs:  `cpe:2.3:a:zend:zendto:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2.1`,
        fs:  `cpe:2.3:a:ibm:connections_portlets:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2.2`,
        fs:  `cpe:2.3:a:altiris:patch_management_solution_for_dell_servers_documentation:6.2.2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2.3`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2.4`,
        fs:  `cpe:2.3:a:openbsd:openbsd:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2.5`,
        fs:  `cpe:2.3:a:crunchify:all-in-on-webmaster:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2.6`,
        fs:  `cpe:2.3:a:adobe:air_sdk:17.0.0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2.7`,
        fs:  `cpe:2.3:a:apache:camel:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:0.10.2.8`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.1`,
        fs:  `cpe:2.3:a:netscape:messaging_server:3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.2`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.3`,
        fs:  `cpe:2.3:a:ca:server_protection_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:11.1ia:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.5.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.5.2`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.5.3`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.320:update32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.5.4`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111231:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.5.5`,
        fs:  `cpe:2.3:a:jowangel:legend_of_trance:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.5.6`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.0.6`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.1.1`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.1.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.1.3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.1.4`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.0`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.2`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.3`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.4`,
        fs:  `cpe:2.3:o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.5`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.6`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.7`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.14`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:2.0.3:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.15`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.5r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.16`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.17`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.18`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.19`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:libvirt:1.2.21`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.93.b-1.0.2.1-17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:-`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:1.0`,
        fs:  `cpe:2.3:h:rockwellautomation:ab_micrologix_controller:1200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:1.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:2.0`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.10.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:2.0.34`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:2.1`,
        fs:  `cpe:2.3:a:google:chrome:16.0.903.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:2.4.2`,
        fs:  `cpe:2.3:a:adobe:color_photoshop_specific_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:2.6.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:3.0`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:3.0.3`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.06.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:4.0`,
        fs:  `cpe:2.3:a:symantec:norton_pc_checkup:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:4.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:4.2`,
        fs:  `cpe:2.3:a:qemu:qemu:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:5.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:5.1`,
        fs:  `cpe:2.3:a:apache:spamassassin:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:5.2`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:6.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:6.1`,
        fs:  `cpe:2.3:a:isc:bind:9.8.5:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:6.2`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.2.0:-:advanced_lifecycle:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:6.2e`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:7.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:7`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:7.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:7.0`,
        fs:  `cpe:2.3:a:gentoo:rootkit_hunter:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux:7.1`,
        fs:  `cpe:2.3:o:yamaha:rt140p:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:7.1`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux:7.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:7.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1da:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux:7.3`,
        fs:  `cpe:2.3:a:adobe:color_video_profiles_cs_cs4:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:7.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux:8.0`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:8.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_4650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:9`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux:9.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p303:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux:9.0`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux_advanced_workstation:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:redhat:linux_advanced_workstation:2.1`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux_powertools:-`,
        fs:  `cpe:2.3:a:ibm:cognos_business_intelligence:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux_powertools:6.1`,
        fs:  `cpe:2.3:a:hp:version_control_agent:6.0.0.840:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux_powertools:6.2`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:linux_powertools:7.0`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.06.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:13.4`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:17.11`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:17.12`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:17.15`,
        fs:  `cpe:2.3:a:xnview:xnview:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:17.16`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:18.11`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd238b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:18.14`,
        fs:  `cpe:2.3:a:adobe:acrobat:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:18.15`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-71:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:livecd-tools:19.2`,
        fs:  `cpe:2.3:h:cisco:catalyst_2926gs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lv:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lv:4.49.4-1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lv:4.49.4-3`,
        fs:  `cpe:2.3:a:cisco:personal_assistant:1.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lv:4.49.4-7`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lv:4.49.4-9`,
        fs:  `cpe:2.3:h:siemens:ruggedcom_win7200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.09`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.10`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp8:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.11`,
        fs:  `cpe:2.3:a:vmware:tools:8.0.3.19531:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.12`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(3\)s7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.13`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.14`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.16`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.17`,
        fs:  `cpe:2.3:a:pgp:e-business_server:6.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.18`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.19`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.3.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.20`,
        fs:  `cpe:2.3:a:ibm:rational_requisitepro:7.0.1.1-ifix02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.21`,
        fs:  `cpe:2.3:a:canonical:ltsp_display_manager:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.22`,
        fs:  `cpe:2.3:a:sympa:sympa:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.23`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.24`,
        fs:  `cpe:2.3:a:nytimes:times_reader:2.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.25`,
        fs:  `cpe:2.3:a:cisco:telepresence_isdn_gateway_software:2.1\(1.43\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.26`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.27`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.28`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.286:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.29`,
        fs:  `cpe:2.3:a:netscape:navigator:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.30`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:9.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.31`,
        fs:  `cpe:2.3:a:abbyy:finereader_sprint:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.32`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.533:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.00.33`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.00`,
        fs:  `cpe:2.3:a:compaq:insight_manager_lc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.01`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.02`,
        fs:  `cpe:2.3:a:umn:mapserver:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.03`,
        fs:  `cpe:2.3:a:dlink:des-3800_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.04`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.05`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)xk2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.06`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.07`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:12.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.08`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.09`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.10`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.11`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.102.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.12`,
        fs:  `cpe:2.3:a:hummingbird:exceed:14.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.13`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.14`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.895:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.01.15`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.00`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.01`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.02`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.03`,
        fs:  `cpe:2.3:a:skype:skype:4.2.0.163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.04`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.05`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.06`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.07`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.08`,
        fs:  `cpe:2.3:h:3com:3c13758:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.09`,
        fs:  `cpe:2.3:a:python:python:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.10`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.11`,
        fs:  `cpe:2.3:a:emc:isilon_insightiq:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.12`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.13`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.14`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.15`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.16`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.17`,
        fs:  `cpe:2.3:a:apple:itunes:4.0.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.18`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.19`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.20`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.21`,
        fs:  `cpe:2.3:a:dell:resource_cd:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.22`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.23`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.24`,
        fs:  `cpe:2.3:a:iss:blackice_defender:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.25`,
        fs:  `cpe:2.3:a:adobe:drive_cs4:1.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.26`,
        fs:  `cpe:2.3:a:vmware:vcenter_chargeback_manager:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.27`,
        fs:  `cpe:2.3:a:opennms:opennms:1.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.28`,
        fs:  `cpe:2.3:a:novell:netmail:3.52d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.29`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.30`,
        fs:  `cpe:2.3:h:hp:8\/20q_fibre_channel_switch_16_port:ak242a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.31`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.32`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(60\)ez11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.33`,
        fs:  `cpe:2.3:a:t1lib:t1lib:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.34`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_30-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.35`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.36`,
        fs:  `cpe:2.3:a:google:chrome:7.0.497.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.37`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.38`,
        fs:  `cpe:2.3:a:atutor:atutor:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.39`,
        fs:  `cpe:2.3:a:google:chrome:11.0.657.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.40`,
        fs:  `cpe:2.3:a:vmware:fusion:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.41`,
        fs:  `cpe:2.3:a:gnu:flim:1.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.42`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.43`,
        fs:  `cpe:2.3:a:radscan:network_audio_system:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.44`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.45`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.46`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.47`,
        fs:  `cpe:2.3:o:cisco:nx-os:9.1\(1\)sv1\(3.1.8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.48`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.49`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.50`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.51`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.52`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.53`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.54`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.55`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.56`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)sy1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.57`,
        fs:  `cpe:2.3:h:siemens:ccid1445-dn36:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.58`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.59`,
        fs:  `cpe:2.3:o:cisco:headend_system_release:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.60`,
        fs:  `cpe:2.3:o:ibm:aix:4.2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.61`,
        fs:  `cpe:2.3:a:konqueror:konqueror:3.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.62`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.63`,
        fs:  `cpe:2.3:a:exchangerxml:exchanger_xml_editor:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.64`,
        fs:  `cpe:2.3:a:sixapart:movable_type:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.65`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.66`,
        fs:  `cpe:2.3:a:rapidleech:rapidleech:2.3:rev42_svn_r358:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.67`,
        fs:  `cpe:2.3:a:lightscribe:lightscribe:1.4.136.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.68`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.69`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.70`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:lvm2:2.02.71`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:manageiq_enterprise_virtualization_manager:5.0`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5800-32f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:mcstrans:-`,
        fs:  `cpe:2.3:a:motorola:123scan:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:mcstrans:0.2.3`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:mod_cluster:1.3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_proxy:-`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.1.8:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_proxy:3.7`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_proxy:4.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.42.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_proxy:4.1`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_proxy:4.2`,
        fs:  `cpe:2.3:a:redhat:rhevm-reports:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_proxy:5.0`,
        fs:  `cpe:2.3:o:huawei:s7706_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_proxy:5.3`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_proxy:5.4`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:redhat:network_satelite_server:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:redhat:network_satelite_server:5.0.0`,
        fs:  `cpe:2.3:a:pico:picopublisher:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:-`,
        fs:  `cpe:2.3:a:spip:spip:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:3.7`,
        fs:  `cpe:2.3:a:sophos:disk_encryption:5.50.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:4.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:4.1`,
        fs:  `cpe:2.3:a:ibm:bigfix_remote_control:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:4.2`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:5.0`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:5.2`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.0.l0.59219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:5.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.111.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:5.4`,
        fs:  `cpe:2.3:a:fookes:notetab_light:4.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:5.5`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:5.6`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite:5.7`,
        fs:  `cpe:2.3:a:atlassian:jira:7.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite_server:-`,
        fs:  `cpe:2.3:a:google:chrome:7.0.528.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite_server:3.7`,
        fs:  `cpe:2.3:a:blackberry:blackberry_enterprise_service:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite_server:4.0`,
        fs:  `cpe:2.3:a:rockwellautomation:1763-l16awa_series_a:15.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite_server:4.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je047a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite_server:4.2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:network_satellite_server:5.0`,
        fs:  `cpe:2.3:h:supermicro:x9dri-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:open_iscsi:-`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:open_iscsi:2.0-864`,
        fs:  `cpe:2.3:a:redhat:cloudforms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:0.0.5`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.0:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)xe4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.1:-:enterprise`,
        fs:  `cpe:2.3:a:trimble:sketchup:8.0:maintenance_5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2::enterprise`,
        fs:  `cpe:2.3:a:apache:commons_beanutils:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2.1::enterprise`,
        fs:  `cpe:2.3:h:hp:laserjet_2500c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2.2:-:enterprise`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2.3::enterprise`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2.4::enterprise`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2.5::enterprise`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2.6::enterprise`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7971g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2.7::enterprise`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:1.2.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:isc:bind:9.2.3:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.0::enterprise`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.0.1::enterprise`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.0.2::enterprise`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.0.3::enterprise`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.0.4::enterprise`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.0.5::enterprise`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.0.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:2.1.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:3.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift:3.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift_origin:1.0.5`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift_origin:1.0.5-3`,
        fs:  `cpe:2.3:a:vips:vips:7.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift_origin:1.2.8`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.64.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift_origin:2.1`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.1:a32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openshift_origin:2.1.1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openssl:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd307a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openssl:0.9.6-15`,
        fs:  `cpe:2.3:a:busybox:busybox:1.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openssl:0.9.6b-3`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openssl:0.9.7a-2`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openstack:3.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openstack:4.0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openstack:7.0`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openstack_essex:-`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:openstack_folsom:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:package_manager:-`,
        fs:  `cpe:2.3:o:huawei:s6700_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:packstack:2012.2.3`,
        fs:  `cpe:2.3:a:huawei:seco_versatile_security_manager:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:pam_smb:-`,
        fs:  `cpe:2.3:h:nec:ix1010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:pam_smb:1.1.6-2`,
        fs:  `cpe:2.3:a:samsung:ipolis_device_manager:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:pam_smb:1.1.6-5`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:pam_smb:1.1.6-7`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2012:r2:-:-:*:essentials:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:policycoreutils:2.2.5`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:power_tool:-`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:494:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:pre-execution_environment:0.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:pre_execution_environment_server:-`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:qspice:0.3.0`,
        fs:  `cpe:2.3:a:magzter:halftime_magazine:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:redhat_package_manager:4.0.2-71`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:redhat_package_manager:4.0.2-72`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:redhat_package_manager:4.0.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:redhat_package_manager:4.0.4`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:1.0.0`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.2:3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:1.0.1`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.6:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:1.0.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:1.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:1.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.0.0`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.0.1`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.1.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.2.0`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.2.1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4yd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.2.3`,
        fs:  `cpe:2.3:a:sybase:powerbuilder_virtual_machine:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.0`,
        fs:  `cpe:2.3:a:ibm:installation_manager:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.1`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.4`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.5`,
        fs:  `cpe:2.3:a:adobe:document_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.6`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.7`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.7.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.7.2`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.8`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:2.3.8:sp2`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0:beta1`,
        fs:  `cpe:2.3:a:redhat:network_satellite:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0:beta2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0:beta3`,
        fs:  `cpe:2.3:a:horde:imp:5.0.4-git:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0:beta4`,
        fs:  `cpe:2.3:a:alan_kennington:mod_bwshare:0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0:beta5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0:beta6`,
        fs:  `cpe:2.3:a:pcre:pcre:8.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0:rc1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.6.2\(64\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.1`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.4`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.5`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.6`,
        fs:  `cpe:2.3:a:knowledgetree:knowledgetree:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.7`,
        fs:  `cpe:2.3:h:dell:poweredge_2900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.8`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:resteasy:3.0.9`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:8.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_application_server:-`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_application_server:1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.2.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_application_server:2`,
        fs:  `cpe:2.3:a:hp:openview_performance_agent:4.60.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_application_stack:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.4:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_application_stack:1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.7.5:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_application_stack:2`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_cluster:-`,
        fs:  `cpe:2.3:a:apache:roller:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_cluster:3`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:1.0.0:rev25273:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_cluster:4`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_cluster:5`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_cluster_storage:-`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_cluster_storage:5`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_cluster_suite:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_developer_suite:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.6.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_developer_suite:1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_developer_suite:2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.2:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_developer_suite:2.0`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_developer_suite:2.1`,
        fs:  `cpe:2.3:a:sanriodigital:hello_kitty_cafe:1.4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_developer_suite:3`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_extras:-`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_extras:3`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_extras:4`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_extras:5`,
        fs:  `cpe:2.3:a:wolterskluwer:teammate_audit_management_software_suite:8.0:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_extras:5::client`,
        fs:  `cpe:2.3:a:mclewin:wishlist:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_extras:5::server`,
        fs:  `cpe:2.3:h:iij:seil_turbo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_global_file_system:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:0.9:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_global_file_system:3`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_global_file_system:4`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_global_file_system:6.0`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_global_file_system:6.1`,
        fs:  `cpe:2.3:a:plone:plone:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_productivity:-`,
        fs:  `cpe:2.3:a:mymetro_project:mymetro:2.4.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_productivity:5`,
        fs:  `cpe:2.3:a:gnu:readline:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_stronghold:4.0`,
        fs:  `cpe:2.3:a:realnetworks:rhapsody:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_virtualization:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_virtualization:5`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_virtualization:5::client`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_virtualization:5::server`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhel_virtualization:5.0`,
        fs:  `cpe:2.3:a:time_tracker_project:time_tracker:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhevm-reports:3.0`,
        fs:  `cpe:2.3:a:runtime:driveimage_xml:2.22:*:*:*:private:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhevm-reports:3.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhevm-reports:3.2`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhevm-reports:3.3`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.60.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhevm-reports:3.3.3`,
        fs:  `cpe:2.3:a:novell:libzypp:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhmask:-`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.367:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhmask:1.0-9`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70-\/f:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhncfg:5.10.27`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhncfg:5.10.27-8`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhx_enterprise_db:5.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rhx_enterprisedb_advanced_server:7.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.1.2`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.1.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.778.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.1.4`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.1.5`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.1.6`,
        fs:  `cpe:2.3:a:splunk:splunk:6.4.2:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.2.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.2.0:sr1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.2.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.2.2`,
        fs:  `cpe:2.3:a:microsoft:virtual_pc:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.3.0`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.3.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.3.2:sr1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:3.3.4`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)s8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.1.0`,
        fs:  `cpe:2.3:a:compaq:insight_manager_xe:2.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.2.0`,
        fs:  `cpe:2.3:a:wdc:smartware:1.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.2.1`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:007hw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.2.2`,
        fs:  `cpe:2.3:a:borland:paradox:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.2.3`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5116h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.3.0`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.6.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.3.1`,
        fs:  `cpe:2.3:a:gnu:binutils:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.3.3`,
        fs:  `cpe:2.3:h:polycom:mgc-50:7.00.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.3.4`,
        fs:  `cpe:2.3:a:busybox:busybox:1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.3.5`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.5.0:alpha1`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:4.5.3`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:5.0.0:alpha1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:5.0.0:alpha2`,
        fs:  `cpe:2.3:a:openstack:compute:2015.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:richfaces:5.0.0:alpha3`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rsync:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rsync:2.4.6-2`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rsync:2.4.6-5`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rsync:2.5.4-2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xt3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rsync:2.5.5-1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta59:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:rsync:2.5.5-4`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:satellite:5.7`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:satellite:6.1`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.05.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sendmail:-`,
        fs:  `cpe:2.3:o:xen:xen:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sendmail:8.12.5-7`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sendmail:8.12.8-4`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:smart_card_manager:1.1.0-5`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sos:2.2-18`,
        fs:  `cpe:2.3:a:autodesk:material_library_medium_image_library_2011:2.0.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sos:2.2-29`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.9:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spacewalk:-`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spacewalk:1.6`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spacewalk-java:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spacewalk-java:2.1.147-1`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spacewalk-java:2.1.148-1`,
        fs:  `cpe:2.3:a:bea:aqualogic_service_bus:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-activex:-`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.1`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.2`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.3`,
        fs:  `cpe:2.3:h:hp:3com_switch:4200g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.4`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.5`,
        fs:  `cpe:2.3:a:postfix:postfix:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.6`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.7`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.8`,
        fs:  `cpe:2.3:a:dell:wireless_wlan_card_driver:4.100.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.9`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.10`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.191:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.11`,
        fs:  `cpe:2.3:a:drupal:drupal:6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.12`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.12.101`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:5.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.13.17`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.13.29`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.3\(1n\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.14`,
        fs:  `cpe:2.3:a:feeds_project:feeds:7.x-2.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.15`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.17.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.15.3`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.16`,
        fs:  `cpe:2.3:a:qemu:qemu:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.17`,
        fs:  `cpe:2.3:a:alkacon:opencms:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.18`,
        fs:  `cpe:2.3:a:adobe:acrobat:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.19`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs4:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.20`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:spice-gtk:0.21`,
        fs:  `cpe:2.3:a:symantec:epo_plugin:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:storage:2.1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:stronghold:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:stronghold:2.3`,
        fs:  `cpe:2.3:a:nero:coverdesigner:4.0.5.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:stronghold:3.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:subscription_asset_manager:1.0.0`,
        fs:  `cpe:2.3:h:cisco:wireless_control_system:4.1.91.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:subscription_asset_manager:1.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p150:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:subscription_asset_manager:1.2.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:subscription_asset_manager:1.2.1`,
        fs:  `cpe:2.3:a:hansotools:hanso_player:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:subscription_asset_manager:1.3.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sysreport:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sysreport:1.1`,
        fs:  `cpe:2.3:o:netgear:prosafe_firmware:6.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sysreport:1.2`,
        fs:  `cpe:2.3:a:horde:gollem:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sysreport:1.3`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sysstat:-`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:sysstat:4.0.7-3`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tcpdump:-`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tcpdump:3.4-39`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tcpdump:3.6.2-9`,
        fs:  `cpe:2.3:a:apple:itunes:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tcpdump:3.6.2-12`,
        fs:  `cpe:2.3:o:huawei:s9706_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tcpdump:3.6.3-3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tcpdump:3.7.2-1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tcpdump:3.8.0`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x44:d15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:thermostat:1.4`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:thunderbird:-`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.1.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tmpwatch:2.2`,
        fs:  `cpe:2.3:a:docker:docker:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:tmpwatch:2.5.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:uberfire:0.3.0`,
        fs:  `cpe:2.3:a:op5:monitor:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:uberfire:0.3.1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.0.220.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:uberfire:0.3.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:uberfire:0.3.3`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:undertow:1.0.16`,
        fs:  `cpe:2.3:h:intel:wireless_wifi_link_4965agn:1.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:undertow:1.1.0:cr4`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:undertow:1.2.0:beta2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:up2date:-`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.3.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:up2date:3.0.7-1`,
        fs:  `cpe:2.3:a:theforeman:foreman:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:up2date:3.1.23-1`,
        fs:  `cpe:2.3:a:systemtools:hyena:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:wu_ftpd:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:wu_ftpd:2.6.1-16`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.1:*:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:wu_ftpd:2.6.1-18`,
        fs:  `cpe:2.3:a:webmin:usermin:1.070:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:wu_ftpd:2.6.2-5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.5\(1.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:wu_ftpd:2.6.2-8`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.4.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:redhat:xemacs:-`,
        fs:  `cpe:2.3:a:hp:help_and_support_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:f5:big-ip_websafe:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:abbyy:finereader:8.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.1.0.2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2_sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:db2_content_manager_toolkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:quagga:quagga:1.0.20160315:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:o:f5:tmos:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:log4j:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:11.0.656.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.13.121240.574:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redhen_project:redhen:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.8:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:redirection_project:redirection:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.1.0`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7940:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.2.1`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.2.2`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.0:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.3.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.479.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.4.0`,
        fs:  `cpe:2.3:a:symantec:liveupdate_lots_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.4.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.4.2`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.5.0`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.5.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.21:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.6.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.6.1`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.0.b-1.0.2.1-17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.6.2`,
        fs:  `cpe:2.3:a:vmware:capacityiq:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.6.3`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.32:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.6.4`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.7.0`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.7.0:rc1`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.7.1`,
        fs:  `cpe:2.3:h:omron:ns12_hmi_terminal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.7.2`,
        fs:  `cpe:2.3:a:busybox:busybox:1.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.7.3`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.7.4`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.0:rc1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.3`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.4`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.5`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.8.7`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.9.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.9.1`,
        fs:  `cpe:2.3:a:roxio:file_backup:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.9.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s\(.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.9.3`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.9.4`,
        fs:  `cpe:2.3:h:3com:3c13754:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.9.5`,
        fs:  `cpe:2.3:a:hp:software_configuration:6.20.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:0.9.6`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.0.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.0.3`,
        fs:  `cpe:2.3:a:erlang:crypto:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.0.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.370.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.1.0`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1\(.1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.1.1`,
        fs:  `cpe:2.3:a:tic-tac_to_the_max_free_project:tic-tac_to_the_max_free:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.1.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.1.3`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.7.0:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.2.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.2.1`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.2.2`,
        fs:  `cpe:2.3:a:digium:asterisk:11.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.2.3`,
        fs:  `cpe:2.3:a:adobe:connect:9.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.3.0`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.3.1`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs724t:v3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:1.3.2`,
        fs:  `cpe:2.3:a:bitcoin_knots_project:bitcoin_knots:0.11.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.4.0`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.4.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.4.2`,
        fs:  `cpe:2.3:a:hp:trayapp:53.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.4.3`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-24p-ei_ls-5100-24p-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.4.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.4.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.5.0`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.5.1`,
        fs:  `cpe:2.3:a:sap:crystal_enterprise_xi_client_tools:3.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redmine:redmine:2.6.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redprairie:redprairie_application_server:2010.2.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sg.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redprairie:redprairie_client:2010.2.3`,
        fs:  `cpe:2.3:a:kubelabs:phpdug:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redprairie:redprairie_client:2010.2.4`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redprairie:reporting_designer:1.0.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.580.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redwood:cronacle_process_server:7.0.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:redwood:explorer:7.0.4`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5::~~~confluence~~`,
        fs:  `cpe:2.3:a:be-graph:bezip:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.1::~~~confluence~~`,
        fs:  `cpe:2.3:a:google:android_api:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.2::~~~confluence~~`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.3::~~~confluence~~`,
        fs:  `cpe:2.3:a:hp:sitescope:10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.4::~~~confluence~~`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.53:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.5::~~~confluence~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.6::~~~confluence~~`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.7::~~~confluence~~`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.8::~~~confluence~~`,
        fs:  `cpe:2.3:a:magzter:business_intelligence:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.9::~~~confluence~~`,
        fs:  `cpe:2.3:a:ca:netviz_professional:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.10::~~~confluence~~`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.11::~~~confluence~~`,
        fs:  `cpe:2.3:a:automatedqa:testexecute:7.52.678.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.12::~~~confluence~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:3.5.13::~~~confluence~~`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0::~~~confluence~~`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.1::~~~confluence~~`,
        fs:  `cpe:2.3:a:gnu:glibc:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.2::~~~confluence~~`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.3::~~~confluence~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.01.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.4::~~~confluence~~`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.5::~~~confluence~~`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.6::~~~confluence~~`,
        fs:  `cpe:2.3:o:f5:tmos:4.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.7::~~~confluence~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.8::~~~confluence~~`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.9::~~~confluence~~`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2015-ac-ovs-a-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.10::~~~confluence~~`,
        fs:  `cpe:2.3:a:microsoft:directx:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:refinedwiki:refinedwiki_original_theme:4.0.11::~~~confluence~~`,
        fs:  `cpe:2.3:a:breezy:breezy:1.2.13:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:registeredassistant_project:registeredassistant:0.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:elxis:elxis_cms:2009.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:relevanssi:relevanssi:3.3.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:relsoftware:web_link_validator:4.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:relsoftware:web_link_validator:4.0_build_406`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:0.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:relsoftware:web_link_validator:4.5`,
        fs:  `cpe:2.3:a:web2py:web2py:1.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:relsoftware:web_link_validator:4.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.365:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:remote-rac:rac_server:4.0.4`,
        fs:  `cpe:2.3:a:php:php:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:remote-rac:rac_server:4.0.5`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:remote_login_service_hackers:remote_login_service:1.0.0`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rename_project:rename:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:1.0.0`,
        fs:  `cpe:2.3:a:ipswitch:imserver:2.0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:1.0.1`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/rs_firmware:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:1.0.2`,
        fs:  `cpe:2.3:a:ca:unicenter_asset_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:1.0.3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:1.0.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:1.0.5`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:1.0.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.0`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.0.1`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.1`,
        fs:  `cpe:2.3:o:ge:multilink_ml810_firmware:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.2`,
        fs:  `cpe:2.3:a:automatedqa:testcomplete:8.20.538.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.3`,
        fs:  `cpe:2.3:a:devsaran:corporate:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.3.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.4`,
        fs:  `cpe:2.3:a:facebook:al_jazeera:6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.4:beta`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.5`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.6`,
        fs:  `cpe:2.3:a:apple:apple_tv:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:2.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:3.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:3.1`,
        fs:  `cpe:2.3:h:hp:c2s12a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:3.2`,
        fs:  `cpe:2.3:a:tibco:spotfire_professional:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:3.3`,
        fs:  `cpe:2.3:o:microsoft:windows_rt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:4.0`,
        fs:  `cpe:2.3:a:sympa:sympa:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reportico:php_report_designer:4.1:beta`,
        fs:  `cpe:2.3:a:google:chrome:16.0.890.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.10`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.52.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.11`,
        fs:  `cpe:2.3:a:qemu:qemu:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.12`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.13`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.14`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.15`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.16`,
        fs:  `cpe:2.3:a:jansson_project:jansson:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.17`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:research-artisan:research_artisan_lite:1.18`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rest-client_project:rest-client:1.7.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restaurantbiller:restaurant_biller:-`,
        fs:  `cpe:2.3:a:coreftp:core_ftp:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-1.0`,
        fs:  `cpe:2.3:o:huawei:5310hi_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:12.0.0.1444:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-1.0:beta2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-1.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-1.2`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:magzter:digit_magazine:3.01:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:hp:proliant_smart_array_device_manager_extension:6.6.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-2.0:alpha2`,
        fs:  `cpe:2.3:a:abbyy:finereader:10.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-2.0:alpha3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-2.0:alpha4`,
        fs:  `cpe:2.3:a:adobe:air:20.0.0.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restful_web_services_project:restws:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:emc:networker:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:milestone1`,
        fs:  `cpe:2.3:a:php:dirlist:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:milestone2`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:milestone3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:milestone4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:milestone5`,
        fs:  `cpe:2.3:a:magzter:youth_incorporated:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:milestone6`,
        fs:  `cpe:2.3:a:python:python:2.7.2150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:rc1`,
        fs:  `cpe:2.3:a:sun:staroffice:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:rc2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:rc3`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:rc4`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:rc5`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1:rc6`,
        fs:  `cpe:2.3:a:schoolmation:schoolmation:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1.0`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1.1`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:6.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:restlet:restlet:2.1.4`,
        fs:  `cpe:2.3:a:autodesk:design_review_2009:9.1.127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:retale:retale_-_weekly_ads_%26_deals:2.1.3::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:23.0.0.185:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:djblets:0.7.27`,
        fs:  `cpe:2.3:a:wildpackets:remote_update_service:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:djblets:0.7.28`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:djblets:0.7.29`,
        fs:  `cpe:2.3:a:rapidmedia:kayak_angler_magazine:3.12.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:djblets:0.7.30`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:djblets:0.8.1`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:djblets:0.8.2`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:djblets:0.8.3`,
        fs:  `cpe:2.3:a:apache:hadoop:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6:beta1`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6:beta2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6:rc1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6:rc2`,
        fs:  `cpe:2.3:a:opnet:sp_guru_network_planner:16.0.0.10215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_enterprise_console:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.2`,
        fs:  `cpe:2.3:h:cisco:catalyst_6509-neb-a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.3`,
        fs:  `cpe:2.3:a:smarty:smarty:1.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.4`,
        fs:  `cpe:2.3:a:ocportal:ocportal:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.5`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.9:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.6`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update5:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.7`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.8`,
        fs:  `cpe:2.3:a:werdswords:download_shortcode:1.0:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.9`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.10`,
        fs:  `cpe:2.3:a:metalogix:sharepoint_extensions_web_service:4.1.1204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.11`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.12`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.13`,
        fs:  `cpe:2.3:o:dell:bios:a14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.14`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.15`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:8.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.16`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.17`,
        fs:  `cpe:2.3:h:hot:hotbox_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.18`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.19`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.20`,
        fs:  `cpe:2.3:a:services_project:services:7.x-3.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.6.21`,
        fs:  `cpe:2.3:a:devicelock:devicelock:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.0`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.0.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(1\)sy4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.3`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.4`,
        fs:  `cpe:2.3:a:omnikey.aaitg:omnikey_cardman_4040:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.6`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.7`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.8`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.9`,
        fs:  `cpe:2.3:a:microsoft:visual_foxpro:9.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.10`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.2.0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.11`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.12`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.13`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.14`,
        fs:  `cpe:2.3:a:apache:roller:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.15`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.16`,
        fs:  `cpe:2.3:a:sympa:sympa:1.3.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.17`,
        fs:  `cpe:2.3:o:cisco:mds_9000_san-os:2.0\(0.86\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.18`,
        fs:  `cpe:2.3:h:cisco:sg300-52p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.19`,
        fs:  `cpe:2.3:a:tntnet:tntnet:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.20`,
        fs:  `cpe:2.3:a:openstack:cinder:2013.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.21`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.22`,
        fs:  `cpe:2.3:a:apache:openjpa:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.23`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.24`,
        fs:  `cpe:2.3:a:vodafone:vodafone_mobile_connect_lite:9.3.3.10523:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.25`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.26`,
        fs:  `cpe:2.3:a:air-watch:air-watch_mobile_device_management_software:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:1.7.27`,
        fs:  `cpe:2.3:a:vmware:ace:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0:beta1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0:beta2`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0:beta3`,
        fs:  `cpe:2.3:a:codiad:codiad:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0:rc1`,
        fs:  `cpe:2.3:a:hp:network_automation:10.00.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0:rc2`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0:rc3`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0.2`,
        fs:  `cpe:2.3:a:xerox:contents_bridge_utility:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0.3`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:6.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0.4`,
        fs:  `cpe:2.3:a:dell:support:2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:review_board:2.0.5`,
        fs:  `cpe:2.3:h:sprint:evo_shift_4g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:reviewboard:reviewboard:-`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revive-adserver:revive_adserver:3.0.0`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.6:mp4:*:*:*:linux:*:*`,
    },
     
    {
        uri: `cpe:/a:revive-adserver:revive_adserver:3.0.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revive-adserver:revive_adserver:3.0.2`,
        fs:  `cpe:2.3:h:hp:j9265a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revive-adserver:revive_adserver:3.0.4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revive-adserver:revive_adserver:3.0.5`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revouninstaller:uninstaller:1.83`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revouninstaller:uninstaller:1.87`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revouninstaller:uninstaller:1.89`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revouninstaller:uninstaller:1.90`,
        fs:  `cpe:2.3:a:imember360:imember360:3.4.016:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:revouninstaller:uninstaller:1.91`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:revouninstaller:uninstaller:2.0::~~professional~~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:313.30:-:*:*:linux_kernel:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rewardingyourself:rewardingyourself:-::~~~andriod~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rewardingyourself:rewardingyourself:-::~~~android~~`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.92:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rewardingyourself:rewardingyourself:-::~~~blackberry~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rezgo:online_booking:1.8:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x45:d10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rezgo_project:rezgo:1.4.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rgsmartapps:colormania_-_color_quiz_game:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:siemens:openscape_session_border_controller:7r.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhodecode:rhodecode_enterprise:2.2.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhq-project:rhq:1.0.1`,
        fs:  `cpe:2.3:h:oracle:sparc_t4-4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhq-project:rhq:1.1.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhq-project:rhq:3.0.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhq-project:rhq:4.0:beta1`,
        fs:  `cpe:2.3:a:justin_dodge:hotblocks:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhq-project:rhq:4.0.0`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhq-project:rhq:4.0.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhq-project:rhq:4.1.0`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rhq-project:rhq:4.2.0`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ricardo_villalba:smplayer:0.6.9`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:richard_cook:rgpg:0.2.0:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:richard_cook:rgpg:0.2.1:-:~~~ruby~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd391a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:richard_cook:rgpg:0.2.2:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:richard_cook:rgpg:0.2.3:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.7.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:richard_cook:rgpg:0.2.4:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rick_mead:media_library_categories:1.1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:apache:groovy:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ricksoft:wbs_gantt-chart:7.8.1::~~~jira~~`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ricky_morse:excluded_users:6.x-1.0`,
        fs:  `cpe:2.3:a:tec-it:tbarcode_ocx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ricky_morse:excluded_users:6.x-1.1`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator:3.3.1064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ricoh:fiery_print_controller:-`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20160121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:alpha3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(32\)sy9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:alpha4`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:alpha5`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta10`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(36\)ca2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta11`,
        fs:  `cpe:2.3:a:cisco:content_distribution_manager_4630:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta2`,
        fs:  `cpe:2.3:o:dell:sonicwall_uma_em5000_firmware:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta4`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta5`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta6`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta7`,
        fs:  `cpe:2.3:o:hp:mpe_ix:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta8`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.2.1:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.0:beta9`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.1`,
        fs:  `cpe:2.3:h:cisco:mobility_services_engine:10.0\(0.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.2`,
        fs:  `cpe:2.3:a:google:chrome:15.0.862.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.3`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.4`,
        fs:  `cpe:2.3:a:isc:bind:9.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.5:-:~-~-~drupal~~`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.3.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.x`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rik_de_boer:revisioning:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.40::~~~xoops~~`,
        fs:  `cpe:2.3:h:supermicro:x9srg-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.41::~~~xoops~~`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.42::~~~xoops~~`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.43::~~~xoops~~`,
        fs:  `cpe:2.3:a:mvd:surething_cd_labeler:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.44::~~~xoops~~`,
        fs:  `cpe:2.3:a:ektron:ektron_content_management_system:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.45::~~~xoops~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(9\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.46::~~~xoops~~`,
        fs:  `cpe:2.3:a:novell:imanager:2.7:sp4_patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.47::~~~xoops~~`,
        fs:  `cpe:2.3:a:citrix:sharefile_mobile_for_tablets:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:riken:xoonips:3.48::~~~xoops~~`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rim:blackberry:-`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rim:blackberry_7270:-`,
        fs:  `cpe:2.3:a:sun:jre:1.1.8:update13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_desktop_software:3.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_desktop_software:4.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_desktop_software:4.5`,
        fs:  `cpe:2.3:a:novell:file_reporter:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_desktop_software:4.6`,
        fs:  `cpe:2.3:a:alkacon:opencms:9.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_desktop_software:4.7`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_desktop_software:5.0`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.12152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_desktop_software:5.0.1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_desktop_software:6.0`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.3:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0`,
        fs:  `cpe:2.3:a:docker:docker:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0.3`,
        fs:  `cpe:2.3:a:gnu:gpgme:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0.5`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0.6`,
        fs:  `cpe:2.3:a:schneider-electric:wonderware_intouch_access_anywhere_server:10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0.7`,
        fs:  `cpe:2.3:a:emc:networker:8.1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0.7.2942`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.1.104.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0.7.3312`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.0.1:mu_\#3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0.8.4985`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:1.0.8.6067`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:2.0`,
        fs:  `cpe:2.3:a:sendmail:multi_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rim:blackberry_playbook_os:2.0.0.7971`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rim:blackberry_playbook_tablet:-`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_software:-`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_software:4.0`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/rs_firmware:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rim:blackberry_software:4.0:sp1_bundle83`,
        fs:  `cpe:2.3:a:docker:docker:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:1.26.3`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:1.26.4`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:1.26.5`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1034:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.0`,
        fs:  `cpe:2.3:a:gnu:wget:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.01`,
        fs:  `cpe:2.3:a:google:chrome:50.0.2661.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.02`,
        fs:  `cpe:2.3:a:lightdm_project:lightdm:1.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.03`,
        fs:  `cpe:2.3:a:percipientstudios:imagen:2.5.6:-:*:*:*:umbraco_cms:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.0.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.04`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.10.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.05`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.0.5`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.2:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.06`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2.6:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.07`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.08`,
        fs:  `cpe:2.3:a:microsoft:windows_script_host:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.09`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.10`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_desk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.00.11`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.00`,
        fs:  `cpe:2.3:a:arg0:encfs:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.01`,
        fs:  `cpe:2.3:o:adtran:aos:10.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.02`,
        fs:  `cpe:2.3:a:cisco:small_business_ip_phone_firmware:7.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.03`,
        fs:  `cpe:2.3:a:nortel:meridian_option_81c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.04`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)st5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.05`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.06`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.07`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.08`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.09`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.10`,
        fs:  `cpe:2.3:a:apple:safari:3.2.1b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.05.11`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.06`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.06.02`,
        fs:  `cpe:2.3:a:mozilla:camino:0.9:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.07`,
        fs:  `cpe:2.3:a:ibm:rational_build_forge:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.07.01`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.07.02`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.07.03`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.4p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.07.04`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.08`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.08.01`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.09`,
        fs:  `cpe:2.3:o:freebsd:freebsd:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.09.01`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.10`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.10.01`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.10.02`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.10.03`,
        fs:  `cpe:2.3:a:canon:canoscan_toolbox:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.10.04`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.11`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.11.01`,
        fs:  `cpe:2.3:a:redhat:rhel_virtualization:5:*:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.11.02`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.12`,
        fs:  `cpe:2.3:a:adobe:robohelp:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.12.01`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.20`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.20.01`,
        fs:  `cpe:2.3:a:myhabit:myhabit:\@7f080041:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.20.02`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.20.03`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.20.04`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.20.05`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.20.06`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.20.07`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.21`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.21.01`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2.\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.21.02`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.3\(2\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.21.03`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.21.04`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.22`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.22.01`,
        fs:  `cpe:2.3:a:php:php:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.22.02`,
        fs:  `cpe:2.3:a:nancy_wichmann:sitedoc:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.23`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.391:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.24`,
        fs:  `cpe:2.3:h:y-cam:yck002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.24.01`,
        fs:  `cpe:2.3:a:f5:big-ip:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.24.02`,
        fs:  `cpe:2.3:a:trillian:trillian:0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.25`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.25.01`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.25.02`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:sp2:*:*:*:x64:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.26`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.27`,
        fs:  `cpe:2.3:a:fortinet:connect:14.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.28`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.28.01`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.32:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.29`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.30`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.30.01`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.30.02`,
        fs:  `cpe:2.3:h:supermicro:x8sil-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.30.03`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.30.04`,
        fs:  `cpe:2.3:h:cisco:cs-mars:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.31.00`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.40.00`,
        fs:  `cpe:2.3:a:sophos:enterprise_console:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.40.01`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.40.02`,
        fs:  `cpe:2.3:a:condor_project:condor:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.40.03`,
        fs:  `cpe:2.3:o:intel:trusted_execution_technology_sinit_authenticated_code_module:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.40.04`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.41.00`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.0.116.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.42.00`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.43.00`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.44.00`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.45.00`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.45.01`,
        fs:  `cpe:2.3:a:ritecms:ritecms:1.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.45.02`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.46`,
        fs:  `cpe:2.3:o:cisco:sa520w:2.2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.47`,
        fs:  `cpe:2.3:a:compaq:insight_manager_xe:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.47.01`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12.02\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.48`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.48.01`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.48.02`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.50`,
        fs:  `cpe:2.3:a:hp:e\/a_agent_spanish_localization:8.60.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.50.01`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-2830c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.50.02`,
        fs:  `cpe:2.3:a:openstack:horizon:2013.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.50.03`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.50.04`,
        fs:  `cpe:2.3:o:cisco:ip_phone_8800_series_firmware:11.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.50.05`,
        fs:  `cpe:2.3:a:adobe:robohelp:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.50.06`,
        fs:  `cpe:2.3:a:php:php:5.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.50.07`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.51`,
        fs:  `cpe:2.3:a:hp:imc_branch_intelligent_management_system_software_module:7.0:e0201p02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.51.01`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.51.02`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.51.03`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.51.04`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.51.05`,
        fs:  `cpe:2.3:a:merethis:centreon:2.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.51.06`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.51.07`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.52`,
        fs:  `cpe:2.3:a:gnu:wget:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.52.01`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.52.02`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpw939:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.52.03`,
        fs:  `cpe:2.3:a:gnome:glib:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.53`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.0:beta0002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.54`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.55`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.804:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.56`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.56.01`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.56.02`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.2:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.56.03`,
        fs:  `cpe:2.3:a:opsview:opsview:3.12:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.56.04`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.56.05`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.1.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.57.00`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.6.0.546:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.57.01`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.4:mp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.57.02`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.57.03`,
        fs:  `cpe:2.3:a:apache:couchdb:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.58.00`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.59.00`,
        fs:  `cpe:2.3:a:imgburn:imgburn:2.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.60.00`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.60.01`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:milestone3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.61`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.61.01`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.62`,
        fs:  `cpe:2.3:a:joomla-cbe:com_cbe:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.63`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.8:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.64`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.cors:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.64.01`,
        fs:  `cpe:2.3:a:kidasa:milestones_2008:11.0.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.64.02`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.64.03`,
        fs:  `cpe:2.3:a:hp:solution_center:130.0.373.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.64.04`,
        fs:  `cpe:2.3:a:libav:libav:11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.64.05`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.64.06`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.65`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_ops_center:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.65.01`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.65.02`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.65.03`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.65.04`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.65.05`,
        fs:  `cpe:2.3:a:apple:xcode:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.65.06`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.65.07`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.66`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.67`,
        fs:  `cpe:2.3:a:hp:photosmart_essential:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rimarts:becky%21_internet_mail:2.68`,
        fs:  `cpe:2.3:o:huawei:quidway_firmware:v200r003c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rising-global:rising_antivirus:22.83.00.03`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riskdashboard:paarfatron:1.0.0`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ritecms:ritecms:1.0:b`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ritecms:ritecms:1.0.0`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:riverbed:steelapp_traffic_manager:9.6:9620140312`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rivetcode:rivettracker:1.03`,
        fs:  `cpe:2.3:a:webmin:usermin:1.590:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rix_go_locker_theme_project:rix_go_locker_theme:1.20.2::~~~android~~`,
        fs:  `cpe:2.3:a:teradata:sql_assistant:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rmcproject:pm_fastrack:6.0.0`,
        fs:  `cpe:2.3:h:hp:jd659a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roads365:www.roads365.com:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roaraudio:roaraudio:0.3`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.0`,
        fs:  `cpe:2.3:a:uiga:fan_club:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20110123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.4`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.6`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.46.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.8`,
        fs:  `cpe:2.3:a:x2engine:x2crm:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.9`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.11`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.1\(5\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.12`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.14`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.15`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.5.0.1060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.16`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.17`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.18`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_bradford:libsocialweb:0.25.20`,
        fs:  `cpe:2.3:h:axis:2401_video_server:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_loach:sharethis:7.x-2.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_loach:sharethis:7.x-2.0:dev`,
        fs:  `cpe:2.3:h:apple:imac:m9843xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_loach:sharethis:7.x-2.1`,
        fs:  `cpe:2.3:a:oracle:webcenter_content:12.2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_loach:sharethis:7.x-2.2`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.1:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_loach:sharethis:7.x-2.3`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_loach:sharethis:7.x-2.4`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:p05-0022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_loach:sharethis:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_management_foundation:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rob_westgeest:md2pdf:0.0.1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.2:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.0.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.0.3`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_portal_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.0.4`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.0:git:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.1.0`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.0.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.1.1`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:8.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.1.2`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.2.0`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.2.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.432:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.2.2`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:7.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.2.3`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.3.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.3.1`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.3.2`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5570_controller_firmware:20.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.3.3`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.3.4`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.3.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.3.6`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.4.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.4.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.4.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.4.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.4.4`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.8:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.0`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.12.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.1`,
        fs:  `cpe:2.3:a:web2py:web2py:1.99.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.2`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.3`,
        fs:  `cpe:2.3:a:apache:hive:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.4`,
        fs:  `cpe:2.3:a:biscom:faxcom_cover_page_editor:9.3.313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.5`,
        fs:  `cpe:2.3:a:ibm:websphere_cast_iron_solution:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.6`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.7`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.002:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:0.9.8`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.1.1501.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.0`,
        fs:  `cpe:2.3:a:isc:bind:9.8.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.1`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.2`,
        fs:  `cpe:2.3:a:pharscape:hsolink:1.0.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.3`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.2.1:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.4`,
        fs:  `cpe:2.3:o:sgi:advanced_linux_environment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.5`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.6`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.8`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.9`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7941g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.10`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.5.4770.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.0.11`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.0`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.2`,
        fs:  `cpe:2.3:a:sound_exchange_project:sound_exchange:14.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.3`,
        fs:  `cpe:2.3:a:apple:safari:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.4`,
        fs:  `cpe:2.3:a:apple:safari:3.0.4b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.5`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_excel:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.6`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4009:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.7`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.8`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:5.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.1.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yk2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.2.0`,
        fs:  `cpe:2.3:a:sendmail:sendmail:9.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.2.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.2.2`,
        fs:  `cpe:2.3:a:paperthin:commonspot_content_server:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.2.3`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.2:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.2.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.2.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.08:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.2.6`,
        fs:  `cpe:2.3:a:maxthon:maxthon_cloud_browser:4.1.5.2000:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.3.1`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.3.2`,
        fs:  `cpe:2.3:a:3s-software:codesys_runtime_system:2.3.9.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.3.3`,
        fs:  `cpe:2.3:a:biais:reddit_aww:1.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.4.0`,
        fs:  `cpe:2.3:o:yahama:rta52i:4.01.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.4.1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.4.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1669.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.4.3`,
        fs:  `cpe:2.3:a:opscode:chef:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.4.4`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:0.2.1:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.4.5`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.5.0`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.5.1`,
        fs:  `cpe:2.3:a:devsaran:fresh:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.5.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.5.3`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)ew:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.6.2`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:m4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.6.3`,
        fs:  `cpe:2.3:o:sun:sunos:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.0`,
        fs:  `cpe:2.3:a:isc:bind:9.2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.1`,
        fs:  `cpe:2.3:o:suse:suse_linux:8.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.2`,
        fs:  `cpe:2.3:a:brian_altenhofel:slidebox:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.3`,
        fs:  `cpe:2.3:a:oracle:database_server:12.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.4`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.5`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)scj1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.7`,
        fs:  `cpe:2.3:a:alkacon:opencms:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.8`,
        fs:  `cpe:2.3:a:actuate:iserver:7.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.9`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.10`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_space_management:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.11`,
        fs:  `cpe:2.3:a:process-one:exmpp:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.12`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.13`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.14`,
        fs:  `cpe:2.3:a:roxio:update_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.15`,
        fs:  `cpe:2.3:a:ibm:maximo_for_life_sciences:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.16`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.17`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.7.18`,
        fs:  `cpe:2.3:a:drupal:drupal:4.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.8.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.8.1`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.8.2`,
        fs:  `cpe:2.3:a:apple:itunes:4.0.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.8.3`,
        fs:  `cpe:2.3:a:srslabs:srs_premium_sound:1.8.1400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.8.4`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.8.5`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.9.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.9.1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.507.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.9.2`,
        fs:  `cpe:2.3:o:aten:cn8000_firmware:1.6.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robert_ancell:lightdm:1.9.3`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.24`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.25`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.5.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.26`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.27`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.28`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.29`,
        fs:  `cpe:2.3:a:macromedia:flash_player:7.0_r19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.30`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.31`,
        fs:  `cpe:2.3:o:cisco:rv130w_firmware:1.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.31b`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.32`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:02-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.33`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p191:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.34`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1012:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.35`,
        fs:  `cpe:2.3:o:netbsd:netbsd:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.36`,
        fs:  `cpe:2.3:a:bluez:bluez:5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.37`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.38`,
        fs:  `cpe:2.3:a:php:php:7.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.39`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.0.0.40a`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.41.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(44\)sq1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.42.0`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.43.0`,
        fs:  `cpe:2.3:a:contenido:contendio:4.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.44.0`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.50.0`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.50.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.50.4:sp1`,
        fs:  `cpe:2.3:a:hp:icewall_java_agent_library:8.0:*:2007:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.50.4:sp2`,
        fs:  `cpe:2.3:o:cisco:network_access_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:1.50.4:sp3`,
        fs:  `cpe:2.3:h:polycom:hdx_9004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:2.0.0`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:2.0.1`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:2.0.2`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:2.1.0`,
        fs:  `cpe:2.3:a:microsoft:frontpage:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:2.1.1`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:2.1.2`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:2.1.4`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.0.0`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.5:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.0.0:-:server`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-35:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.0.1`,
        fs:  `cpe:2.3:a:isc:bind:9.2.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.0.1:-:server`,
        fs:  `cpe:2.3:a:microsoft:windows_media_services:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.0.2`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.0.3`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.1.0`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.1.0:-:server`,
        fs:  `cpe:2.3:a:diy-cms:diy-cms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.1.1`,
        fs:  `cpe:2.3:o:huawei:s9303_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.1.1:-:server`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.2.0`,
        fs:  `cpe:2.3:a:sun:solaris_pc_netlink:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.2.1:-:server`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:8.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.2.2:-:server`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.2.3:-:server`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.2.4:-:server`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.3.0`,
        fs:  `cpe:2.3:a:invensys:wonderware_intouch:2012:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.4.0`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.5.0`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.0`,
        fs:  `cpe:2.3:o:cisco:wap4410n_firmware:2.0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.1`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.2`,
        fs:  `cpe:2.3:a:pedro_villavicencio_garrido:hipo:0.6.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:6.0.0.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.5`,
        fs:  `cpe:2.3:a:michael_staatz:sofortueberweisung2commerce:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.6`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b_p3k_bl24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.7`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2007:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.8`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.1:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.9`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.10`,
        fs:  `cpe:2.3:a:apache:hadoop:0.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.11`,
        fs:  `cpe:2.3:a:csounds:csound:5.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.2bx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.13`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.0\(4.101\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.14`,
        fs:  `cpe:2.3:a:ca:anti-spyware_for_the_enterprise:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.15`,
        fs:  `cpe:2.3:a:libav:libav:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.16`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.9.0.1060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.6.17`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.7:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.7.0`,
        fs:  `cpe:2.3:h:hp:b5l04a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.7.1`,
        fs:  `cpe:2.3:a:extron:extroncorlib:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.7.2`,
        fs:  `cpe:2.3:a:onesolutionapps:bail_bonds:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.7.3`,
        fs:  `cpe:2.3:o:juniper:junos:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.7.4`,
        fs:  `cpe:2.3:a:novell:iprint:4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.7.5`,
        fs:  `cpe:2.3:a:libraw:libraw:0.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robo-ftp:robo-ftp:3.7.6`,
        fs:  `cpe:2.3:a:landesk:landesk_security_suite:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roboticoverlords:arch_friend:0.4.2::~~~android~~`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:robotstats:robotstats:1.0`,
        fs:  `cpe:2.3:a:microsoft:word:2000:sr1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocketsoftware:rocket_servergraph:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:git7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocketsoftware:rocket_servergraph:1.2`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocklobster:contact_form_7:3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:3.0.0.4.246:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocklobster:contact_form_7:3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_host_on-demand:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocklobster:contact_form_7:3.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:pocket_internet_explorer:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocklobster:contact_form_7:3.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:3com:3c17400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:0.0.4:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:sun:sdk:1.3_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.3`,
        fs:  `cpe:2.3:a:erlang:crypto:1.5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.4`,
        fs:  `cpe:2.3:a:hummingbird:cyberdocs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.5`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.6`,
        fs:  `cpe:2.3:a:singaporemotherhood:singaporemotherhood_forum:3.6.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.7`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.8`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.9`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf233a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.10`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.11`,
        fs:  `cpe:2.3:a:teradata:system_emulation_tool:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.0.12`,
        fs:  `cpe:2.3:h:nvidia:geforce_gt_710:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.1.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.1.2`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.1.3`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.1.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockmongo:rockmongo:1.1.5`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.18_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1756-enbt:-`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1756-eweb:-`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:1763-l16awa_series_a:15.000`,
        fs:  `cpe:2.3:a:optipng_project:optipng:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:1763-l16awa_series_b:15.000`,
        fs:  `cpe:2.3:a:bandainamcogames:madomagi-ip_android:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:1763-l16bbb_series_a:15.000`,
        fs:  `cpe:2.3:a:sophos:unified_threat_management_software:9.355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:1763-l16bbb_series_b:15.000`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:1763-l16bwa_series_a:15.000`,
        fs:  `cpe:2.3:h:polycom:hdx_4002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:1763-l16bwa_series_b:15.000`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:1763-l16dwd_series_a:15.000`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:1763-l16dwd_series_b:15.000`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1653.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1768-enbt:-`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1768-eweb:-`,
        fs:  `cpe:2.3:o:juniper:screenos:6.3.0:r18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1768_compact_guardlogix_l4xs_controller:-`,
        fs:  `cpe:2.3:a:umich:libgssapi:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:18.00`,
        fs:  `cpe:2.3:a:adobe:photoshop_elements:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:19.00`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:20.011`,
        fs:  `cpe:2.3:a:compaq:acms:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:20.013`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1768_compactlogix_l4x_controller:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s_3.4.5s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:16.00`,
        fs:  `cpe:2.3:a:hummingbird:exceed:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:16.020`,
        fs:  `cpe:2.3:a:google:chrome:13.0.765.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:16.025`,
        fs:  `cpe:2.3:h:hp:digital_sender_9250c:cb472a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:17.00`,
        fs:  `cpe:2.3:a:openstack:swift:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:18.00`,
        fs:  `cpe:2.3:a:samba:samba:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:19.00`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:20.00`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:20.011`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:5.2.318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:20.016`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1769_compactlogix_5370_l1_controller:-`,
        fs:  `cpe:2.3:h:xzeres:442sr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l1_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:tekno_apsis_project:tekno_apsis:2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l1_controller_firmware:20.010`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l1_controller_firmware:20.013`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l1_controller_firmware:21.00`,
        fs:  `cpe:2.3:a:profile2_privacy_project:profile2_privacy:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1769_compactlogix_5370_l2_controller:-`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp3:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l2_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l2_controller_firmware:20.010`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l2_controller_firmware:20.013`,
        fs:  `cpe:2.3:a:vmware:workstation:4.0.1_build_5289:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l2_controller_firmware:21.00`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1769_compactlogix_5370_l3_controller:-`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l3_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:adobe:media_player:0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l3_controller_firmware:20.010`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l3_controller_firmware:20.013`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sxa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_5370_l3_controller_firmware:21.00`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1769_compactlogix_l23x_controller:-`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:16.00`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.1:1009:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:17.00`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:18.00`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:19.00`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.1.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:20.00`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:20.010`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:20.013`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1769_compactlogix_l3x_controller:-`,
        fs:  `cpe:2.3:a:perl:perl:0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:16.00`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:16.020`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:16.023`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:17.00`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:18.00`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:19.00`,
        fs:  `cpe:2.3:a:citrix:winframe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:apple:safari:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:20.010`,
        fs:  `cpe:2.3:a:codehaus:redback:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:20.013`,
        fs:  `cpe:2.3:a:hp:smartssd_wear_gauge_utility:9.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:1794-aentr_flex_i%2fo_ethernet%2fip_adapter:-`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:ab_micrologix_controller:1100`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:ab_micrologix_controller:1200`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p244_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:ab_micrologix_controller:1400`,
        fs:  `cpe:2.3:o:cisco:spa_500_series_ip_phone_firmware:7.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:ab_micrologix_controller:1500`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:compactlogix:18.0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:compactlogix:19.0`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l16er-bb1b:-`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l18er-bb1b:-`,
        fs:  `cpe:2.3:a:revouninstaller:uninstaller:1.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l18erm-bb1b:-`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.1.528992:*:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l23e-qb1b:-`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-72:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l23e-qbfc1b:-`,
        fs:  `cpe:2.3:a:trustgo:antivirus_\&amp;_mobile_security:1.2.9:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l24er-qb1b:-`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l24er-qbfc1b:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l27erm-qbfc1b:-`,
        fs:  `cpe:2.3:a:znc:znc:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l30er:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l30er-nse:-`,
        fs:  `cpe:2.3:h:polycom:viewstation_512:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l30erm:-`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l33er:-`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l33erm:-`,
        fs:  `cpe:2.3:a:samba:samba:3.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_1769-l36erm:-`,
        fs:  `cpe:2.3:a:apple:mail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_5830:-`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:compactlogix_5830_firmware:v28.011`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v200r009c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:compactlogix_5830_firmware:v29.011`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:compactlogix_controller_1769_firmware:20.018`,
        fs:  `cpe:2.3:a:face_fun_photo_collage_maker_project:face_fun_photo_collage_maker_2:1.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:compactlogix_controller_1769_firmware:27.011`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_l32e_controller:-`,
        fs:  `cpe:2.3:a:crumbs_project:crumbs:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:compactlogix_l35e_controller:-`,
        fs:  `cpe:2.3:a:solarwinds:orion_user_device_tracker:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix:18.0`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix:20.0`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:controllogix_5560_controller:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:16.00`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:16.020`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:16.022`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:17.00`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:18.00`,
        fs:  `cpe:2.3:a:adobe:captivate:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:19.00`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_technology_for_zachman_framework:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:postfix:postfix:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:20.010`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_controller_firmware:20.013`,
        fs:  `cpe:2.3:o:ibm:global_console_manager_16_firmware:1.20.0.23447:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:controllogix_5560_redundant_controller:-`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_redundant_controller_firmware:16.00`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_redundant_controller_firmware:19.00`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_redundant_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_redundant_controller_firmware:20.050`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5560_redundant_controller_firmware:20.055`,
        fs:  `cpe:2.3:a:artifectx:xclassified:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:controllogix_5570_controller:-`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_controller_firmware:18.00`,
        fs:  `cpe:2.3:a:open-emr:openemr:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_controller_firmware:19.00`,
        fs:  `cpe:2.3:a:goforandroid:go_message_widget:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_controller_firmware:20.010`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_controller_firmware:20.013`,
        fs:  `cpe:2.3:a:ibm:websphere_host_on-demand:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_controller_firmware:21.00`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:controllogix_5570_redundant_controller:-`,
        fs:  `cpe:2.3:a:google:v8:3.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_redundant_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_redundant_controller_firmware:20.050`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_redundant_controller_firmware:20.055`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5570_redundant_controller_firmware:21.00`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:controllogix_5580:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5580_firmware:v28.011`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5580_firmware:v28.012`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5580_firmware:v28.013`,
        fs:  `cpe:2.3:a:mcafee:neotrace_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_5580_firmware:v29.011`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:controllogix_l55_controller:-`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_l55_controller_firmware:16.00`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_l55_controller_firmware:16.020`,
        fs:  `cpe:2.3:a:xavoc:xepan_cms:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:controllogix_l55_controller_firmware:16.022`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:factorytalk_services_platform:cpr9`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:factorytalk_services_platform:cpr9:sr1`,
        fs:  `cpe:2.3:a:arellia:arellia_common_report_language_pack:6.0.1101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:factorytalk_services_platform:cpr9:sr2`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d40:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:factorytalk_services_platform:cpr9:sr3`,
        fs:  `cpe:2.3:a:apc:powerchute:2.0:-:personal:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:factorytalk_services_platform:cpr9:sr4`,
        fs:  `cpe:2.3:a:pyyaml:libyaml:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:factorytalk_services_platform:cpr9:sr5`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:factorytalk_services_platform:cpr9:sr5.1`,
        fs:  `cpe:2.3:a:lookout:lookout_security_\&amp;_antivirus:8.17-8a39d3f:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:factorytalk_services_platform:cpr9:sr6`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:flexlogix_1788-enbt_adapter:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:flexlogix_l34_controller:-`,
        fs:  `cpe:2.3:a:gogago:gogago_youtube_video_converter:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:flexlogix_l34_controller_firmware:16.00`,
        fs:  `cpe:2.3:a:redmine:redmine:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix:18.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix:20.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.3.0.40.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:guardlogix_5570_controller:-`,
        fs:  `cpe:2.3:a:apache:solr:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix_5570_controller_firmware:16.00`,
        fs:  `cpe:2.3:a:microsoft:visio:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix_5570_controller_firmware:17.00`,
        fs:  `cpe:2.3:a:mobilesoft:meteo_belgique:3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix_5570_controller_firmware:18.00`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix_5570_controller_firmware:19.00`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix_5570_controller_firmware:20.00`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix_5570_controller_firmware:20.010`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.08066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix_5570_controller_firmware:20.017`,
        fs:  `cpe:2.3:a:altiris:notification_server_documentation:6.0.1056:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:guardlogix_5570_controller_firmware:21.00`,
        fs:  `cpe:2.3:a:wikiwiki_project:wikiwiki:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:integrated_architecture_builder:9.6.0.7`,
        fs:  `cpe:2.3:a:web2py:web2py:1.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:integrated_architecture_builder:9.7.0.0`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.6b.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:integrated_architecture_builder:9.7.0.1`,
        fs:  `cpe:2.3:a:march-hare:cvsnt:2.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:logix_5000_controller:-`,
        fs:  `cpe:2.3:a:rsa:access_manager_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:micrologix_1100:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:micrologix_1400:-`,
        fs:  `cpe:2.3:a:xnview:xnview:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:plc-5_controller:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslinx_enterprise:cpr9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2fx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslinx_enterprise:cpr9:sr1`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslinx_enterprise:cpr9:sr2`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpw700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslinx_enterprise:cpr9:sr3`,
        fs:  `cpe:2.3:a:wpslideshow:image_news_slider:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslinx_enterprise:cpr9:sr4`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslinx_enterprise:cpr9:sr5`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslinx_enterprise:cpr9:sr5.1`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslinx_enterprise:cpr9:sr6`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:rslogix_5000_design_and_configuration_software:7.0`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:rslogix_5000_design_and_configuration_software:18.0`,
        fs:  `cpe:2.3:a:gewara:gewara:5.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:rslogix_5000_design_and_configuration_software:20.01`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:rslogix_5000_design_and_configuration_software:20.03`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:rslogix_5000_design_and_configuration_software:21.0`,
        fs:  `cpe:2.3:a:ibm:spss_samplepower:3.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rockwellautomation:rslogix_5000_design_and_configuration_software:21.03`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:rslogix_emulate_5000:-`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:9.3.53.6:agee_common_criteria_build:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:rslogix_emulate_5000_firmware:18.00`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:rslogix_emulate_5000_firmware:19.00`,
        fs:  `cpe:2.3:a:cisco:meeting_server:1.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:rslogix_emulate_5000_firmware:20.00`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:rslogix_emulate_5000_firmware:21.00`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:slc_500_controller:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:softlogic:19.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1301.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:softlogix:18.0`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rockwellautomation:softlogix_5800_controller:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:softlogix_5800_controller_firmware:18.00`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:softlogix_5800_controller_firmware:19.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:softlogix_5800_controller_firmware:20.00`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:rockwellautomation:softlogix_5800_controller_firmware:21.00`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:10.1\(2\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.00`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.00::g`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.01`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.01::g`,
        fs:  `cpe:2.3:a:herac:tuxguitar:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.02`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.02::g`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.03`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.03::g`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.04`,
        fs:  `cpe:2.3:a:kvirc:kvirc:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.04::g`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.05`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.05::g`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.06`,
        fs:  `cpe:2.3:a:python:pillow:2.9.0:dev1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.06::g`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.07`,
        fs:  `cpe:2.3:a:isc:bind:8.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.07::g`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.36:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.08`,
        fs:  `cpe:2.3:a:abb:datamanager:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.08::g`,
        fs:  `cpe:2.3:a:freefloat:freefloat_ftp_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.09`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.543:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.09::g`,
        fs:  `cpe:2.3:o:cisco:ios:11.0.12\(a\)bt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.10`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.10::g`,
        fs:  `cpe:2.3:a:actividentity:actividentity_device_installer:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.11`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.11::g`,
        fs:  `cpe:2.3:o:cisco:catos:6.2\(0.110\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.12`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_73:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.12::g`,
        fs:  `cpe:2.3:a:redhat:daredevil_skk:11.6.0-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.13`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.13::g`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.14`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.14::g`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:4.3.0:cp07:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.15`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.16`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.17`,
        fs:  `cpe:2.3:a:gcspublishing:goat_forum:3.9.15:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.18`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board:1.19`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.00`,
        fs:  `cpe:2.3:a:tibco:vault:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.00::g`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.01`,
        fs:  `cpe:2.3:a:logitec:lan-w300n\/rs_firmware:2.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.01::g`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.02`,
        fs:  `cpe:2.3:a:clamav:clamav:0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.02::g`,
        fs:  `cpe:2.3:a:netwitness:netwitness_administrator:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.03`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.03::g`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.9501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.04`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.68.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.04::g`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.05`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.05::g`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.06`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.337:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.06::g`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.07`,
        fs:  `cpe:2.3:o:novell:suse_linux:10:*:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.07::g`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.635:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.08`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.08::g`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:6.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.09`,
        fs:  `cpe:2.3:a:microsoft:word:98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.09::g`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.10`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.10::g`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.11`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.11::g`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.12`,
        fs:  `cpe:2.3:a:ibm:infosphere_import_export_manager:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.12::g`,
        fs:  `cpe:2.3:a:ibm:forms_experience_builder:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.13`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.13::g`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.14`,
        fs:  `cpe:2.3:a:altiris:software_management_language_pack:6.2.4274:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.14::g`,
        fs:  `cpe:2.3:a:h3c:secbladefw:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.15`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.15::g`,
        fs:  `cpe:2.3:a:sun:one_web_server:4.1:sp14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.16`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.16::g`,
        fs:  `cpe:2.3:a:sun:solaris_answerbook2:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.17`,
        fs:  `cpe:2.3:a:citrix:xendesktop:4.0:fp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.17::g`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.18`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_r:1.18::g`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1k\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.00`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.00::g`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.00::gbo`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.01`,
        fs:  `cpe:2.3:a:hp:5600_help:50.0.206.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.01::g`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.01::gbo`,
        fs:  `cpe:2.3:a:debian:qpopper:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.02`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager_bulk_administration_tool:4.6.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.02::g`,
        fs:  `cpe:2.3:a:google:chrome:10.0.612.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.02::gbo`,
        fs:  `cpe:2.3:a:jruby:jruby:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.03`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.03::g`,
        fs:  `cpe:2.3:a:sysax:multi_server:5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.03::gbo`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.04`,
        fs:  `cpe:2.3:a:vmware:player:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.04::g`,
        fs:  `cpe:2.3:a:xerox:freeflow_print_server:8.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.04::gbo`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.05`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.05::g`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.05::gbo`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.06`,
        fs:  `cpe:2.3:o:cisco:ios:11.2wa4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.06::g`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.04:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.06::gbo`,
        fs:  `cpe:2.3:a:titus:message_classification:3.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.07`,
        fs:  `cpe:2.3:a:sun:javamail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.07::g`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.07::gbo`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.08`,
        fs:  `cpe:2.3:a:cisco:acs_solution_engine:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.08::g`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.08::gbo`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.09`,
        fs:  `cpe:2.3:a:sun:javamail:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.09::g`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.09::gbo`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(25\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.10`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.10::g`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.10::gbo`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.11`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.11::g`,
        fs:  `cpe:2.3:o:novell:linux_desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.11::gbo`,
        fs:  `cpe:2.3:a:smwplus:smw\&#43;:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.12`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.12::g`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5:m4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.12::gbo`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.13`,
        fs:  `cpe:2.3:a:ca:brightstor_enterprise_backup:-:*:hpux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.13::g`,
        fs:  `cpe:2.3:a:qemu:qemu:0.11.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.13::gbo`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.14`,
        fs:  `cpe:2.3:a:rpm:rpm:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.14::g`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.15`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.15::g`,
        fs:  `cpe:2.3:a:wellteksoftware:001_file_joiner_\&amp;_splitter:4.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.16`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.16::g`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.17`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.17::g`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.18`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_board_ri:1.19`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.00`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.01`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.02`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.03`,
        fs:  `cpe:2.3:a:google:chrome:13.0.774.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.04`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.12:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.05`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)md1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.06`,
        fs:  `cpe:2.3:h:hp:proliant_ml110_g6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.07`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.08`,
        fs:  `cpe:2.3:a:hp:software_process_control:6.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.09`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.10`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.5:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.11`,
        fs:  `cpe:2.3:a:xen:xen:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.12`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.13`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_diary_r:1.14`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.00`,
        fs:  `cpe:2.3:a:microsoft:windows_script:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.01`,
        fs:  `cpe:2.3:a:exim:exim:4.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.02`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.03`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.04`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.05`,
        fs:  `cpe:2.3:a:user_import_project:user_import:6.x-4.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.06`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.07`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.08`,
        fs:  `cpe:2.3:a:sybari:antigen:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.09`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.10`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:sp1:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.11`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8y:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.12`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.13`,
        fs:  `cpe:2.3:a:sgi:propack:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.15`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.16`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.17`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.18`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.19`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.20`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.21`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.22`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.23`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:2.3.4:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.24`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.25`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.26`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.27`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.28`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.29`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.30`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_forum:1.31`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.00`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.01`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.02`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.10.328:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.03`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.04`,
        fs:  `cpe:2.3:a:awful_ninja_game_project:awful_ninja_game:1.0.23:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.05`,
        fs:  `cpe:2.3:h:huawei:ne20e-x6:v300r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.06`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.07`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_technology_for_togaf:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.08`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.6.0.595:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.09`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.11`,
        fs:  `cpe:2.3:a:mcafee:firewall_enterprise_control_center:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link:1.12`,
        fs:  `cpe:2.3:a:teamspeak:teamspeak2:2.0.32:-:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link_compact:1.00`,
        fs:  `cpe:2.3:a:ibm:db2:10.5:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link_compact:1.01`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link_compact:1.02`,
        fs:  `cpe:2.3:a:microsoft:project_server:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link_compact:1.03`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link_compact:1.04`,
        fs:  `cpe:2.3:a:emc:networker:7.6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_link_compact:1.05`,
        fs:  `cpe:2.3:a:menalto:gallery:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.00`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.0.5:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.00::g`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p363:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.00::gbo`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.01`,
        fs:  `cpe:2.3:a:mahara:mahara:17.04.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.01::g`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.01::gbo`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.16.21:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.02`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.02::g`,
        fs:  `cpe:2.3:a:botan_project:botan:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.02::gbo`,
        fs:  `cpe:2.3:o:debian:debian_linux:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.03`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1052:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.03::g`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.03::gbo`,
        fs:  `cpe:2.3:a:synology:cloud_station:3.0-3103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.04`,
        fs:  `cpe:2.3:a:pocketmags:adt_aesthetic_dentistry_today:\@7f080181:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.04::g`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.04::gbo`,
        fs:  `cpe:2.3:h:samsung:galaxy_s5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.05`,
        fs:  `cpe:2.3:a:compaq:system_healthcheck:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.05::g`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.05::gbo`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.06`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.3:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.06::g`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.5:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.06::gbo`,
        fs:  `cpe:2.3:a:adobe:jrun:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.07`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_library_set:07-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.07::g`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.07::gbo`,
        fs:  `cpe:2.3:a:emc:connectrix_manager:9.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.08`,
        fs:  `cpe:2.3:a:keepass:keepass:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.08::g`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.08::gbo`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.09`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.09::g`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.09::gbo`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)eo1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.10`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.1.4.3104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.10::g`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.10::gbo`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.3051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.11::g`,
        fs:  `cpe:2.3:h:hp:laserjet_4350:q5407a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.11::gbo`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.12::g`,
        fs:  `cpe:2.3:a:adobe:livecycle_data_services:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.12::gbo`,
        fs:  `cpe:2.3:h:siemens:scalance_w786-3pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.13::g`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.13::gbo`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.14::g`,
        fs:  `cpe:2.3:a:ibm:connections_portlets:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.14::gbo`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.15::g`,
        fs:  `cpe:2.3:a:indihiang:web_log_analyzer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.15::gbo`,
        fs:  `cpe:2.3:h:cisco:nexus_3016q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.16::g`,
        fs:  `cpe:2.3:a:menalto:gallery:3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.16::gbo`,
        fs:  `cpe:2.3:h:iij:seil_plus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.17::g`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.17::gbo`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.18::g`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.18::gbo`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.11:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.19::g`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.19::gbo`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.3.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.20`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.20::g`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.342.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.21`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.21::g`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.42.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.22`,
        fs:  `cpe:2.3:o:cisco:ios:3.6.4e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.22::g`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.23`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.537:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.23::g`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.24`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.24::g`,
        fs:  `cpe:2.3:a:microsoft:frontpage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.25`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.25::g`,
        fs:  `cpe:2.3:a:axway:secure_messenger:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.26`,
        fs:  `cpe:2.3:a:ca:cleverpath_eureka:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.26::g`,
        fs:  `cpe:2.3:a:trillian:trillian:0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.27`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.27::g`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.28`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.28::g`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.29`,
        fs:  `cpe:2.3:a:moodle:moodle:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.30`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.31`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.32`,
        fs:  `cpe:2.3:a:webassist:powerstore:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.33`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.34`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_unix_and_openvms:14.0.3670:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.35`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.36`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.37`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.38`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board:1.39`,
        fs:  `cpe:2.3:a:real-estate-php-script:real_estate_php_script:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.00::g`,
        fs:  `cpe:2.3:a:amiscu:michael_baker_federal_credit_union:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.01::g`,
        fs:  `cpe:2.3:a:jxplorer:jxplorer:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.02::g`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.03::g`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.04::g`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.05::g`,
        fs:  `cpe:2.3:a:winzip:winzip:16.0.9686:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.06::g`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.07::g`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.08::g`,
        fs:  `cpe:2.3:o:novell:netware:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.09::g`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.10::g`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:6.x-1.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.11::g`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.12::g`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf551a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.13::g`,
        fs:  `cpe:2.3:h:nvidia:geforce_920mx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.14::g`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2016.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.15::g`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.16::g`,
        fs:  `cpe:2.3:a:mailenable:mailenable:6.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.17::g`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization_manager:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_i:1.18::g`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.00`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.6:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.01`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.02`,
        fs:  `cpe:2.3:a:gnu:tar:1.13.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.03`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.04`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.05`,
        fs:  `cpe:2.3:a:adobe:anchor_service:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.06`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.07`,
        fs:  `cpe:2.3:o:unisys:mcp_firmware:40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.08`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.09`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ewa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.10`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:9.6.0-000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.11`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.12`,
        fs:  `cpe:2.3:a:libav:libav:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.13`,
        fs:  `cpe:2.3:a:quest:toad_for_sql_server:5.5.0.1073:*:*:*:freeware:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.14`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.15`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.16`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1:*:beta:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.17`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.18`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.19`,
        fs:  `cpe:2.3:a:hp:status:140.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.20`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.21`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.22`,
        fs:  `cpe:2.3:a:freedomscientific:document_server:10.14.2289.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.23`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.24`,
        fs:  `cpe:2.3:a:symantec:norton_360:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.25`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.26`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.27`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.99:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.28`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random:1.29`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.71:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:p_up_board_random_2:1.03`,
        fs:  `cpe:2.3:a:osticket:osticket:1.6:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.00`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.01`,
        fs:  `cpe:2.3:a:adobe:flash_mx:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.02`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.03`,
        fs:  `cpe:2.3:a:docker:docker:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.04`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.05`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p416:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.06`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.07`,
        fs:  `cpe:2.3:a:vmware:horizon_view:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_bbs:1.08`,
        fs:  `cpe:2.3:a:hp:openview_performance_core:10.0.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.00`,
        fs:  `cpe:2.3:a:lipbrau:hearsay\:_a_social_party_game:1.7.000:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.01`,
        fs:  `cpe:2.3:h:siemens:ccmd3025-dn18:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.02`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.03`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.03.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.04`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.05`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.06`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2012-ac-ovs-s-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.07`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.08`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.09`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.10`,
        fs:  `cpe:2.3:a:hp:software_xercesa_xml_parser:2.7.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.11`,
        fs:  `cpe:2.3:a:generaldynamics:pc_updater:2.80.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.12`,
        fs:  `cpe:2.3:h:hp:0235a39h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.13`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.14`,
        fs:  `cpe:2.3:a:emc:rsa_data_loss_prevention:9.6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.15`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.16`,
        fs:  `cpe:2.3:a:novell:client:4.91:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.17`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.18`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1057:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_forum:1.19`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.00`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.01`,
        fs:  `cpe:2.3:a:hp:data_protector_media_operations:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.02`,
        fs:  `cpe:2.3:a:google:chrome:6.0.476.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.03`,
        fs:  `cpe:2.3:a:netscape:communicator:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.04`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.05`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)sv3\(1.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.06`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.07`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.08`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pm_up_bbs:1.09`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.4.4:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.12`,
        fs:  `cpe:2.3:a:razorcms:razorcms:0.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.13`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.18:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.14`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.15`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.3:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.16`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110630:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.17`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.18`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.19`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.20`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.21`,
        fs:  `cpe:2.3:o:smoothwall:smoothwall:3.0:sp3:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.22`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.65.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.23`,
        fs:  `cpe:2.3:a:debian:mime-support:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.24`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.25`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.26`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.27`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.290:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.28`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.3.6:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.29`,
        fs:  `cpe:2.3:a:symantec:liveupdate:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.30`,
        fs:  `cpe:2.3:a:rssreader:rssreader:1.0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.31`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.32`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.33`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.34`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.35`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.36`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.37`,
        fs:  `cpe:2.3:a:drupal:drupal:5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.38`,
        fs:  `cpe:2.3:a:ibm:parallel_environment:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.39`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.40`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.41`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.4.135.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.42`,
        fs:  `cpe:2.3:a:monotone:monotone:0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.43`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.44`,
        fs:  `cpe:2.3:a:augeas:augeas:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.45`,
        fs:  `cpe:2.3:a:roxio:recordnow_audio:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.46`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.413:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.47`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.48`,
        fs:  `cpe:2.3:a:wolfssl:wolfssl:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.49`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.50`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.51`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.1.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.52`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.53`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.54`,
        fs:  `cpe:2.3:a:haxx:curl:7.49.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.55`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:rc3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.56`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.57`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.58`,
        fs:  `cpe:2.3:a:expressjs:express:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.59`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.60`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.61`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_71:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.62`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.63`,
        fs:  `cpe:2.3:a:gnu:automake:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.64`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.65`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.66`,
        fs:  `cpe:2.3:h:apc:3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.67`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.68`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.69`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp5:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.70`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.71`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.72`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.73`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:2.74`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.00`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.01`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.02`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.2.0.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.002`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.003`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l23e-qb1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.03`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.14:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.04`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.004`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_ops_center:12.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.05`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.005`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.06`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.07`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.08`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.09`,
        fs:  `cpe:2.3:a:seven_bulls:christmas_words:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.10`,
        fs:  `cpe:2.3:h:nortel:vpn_router_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.11`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.12`,
        fs:  `cpe:2.3:a:google:picasa:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.13`,
        fs:  `cpe:2.3:a:codiad:codiad:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.14`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.15`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.16`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.17`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p207:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.18`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.19`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.20`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:2.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.21`,
        fs:  `cpe:2.3:a:netshinesoftware:com_netinvoice:2.0.8:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.22`,
        fs:  `cpe:2.3:a:vmware:player:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.23`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.24`,
        fs:  `cpe:2.3:a:xchat:xchat:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.25`,
        fs:  `cpe:2.3:a:teradata:tvi-proxy:7.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.26`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.27`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:4.2:rp1:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.28`,
        fs:  `cpe:2.3:a:f5:firepass:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.29`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.30`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.31`,
        fs:  `cpe:2.3:a:adobe:camera_raw:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog:3.32`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.18`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.19`,
        fs:  `cpe:2.3:a:openvpn:openvpn_access_server:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.20`,
        fs:  `cpe:2.3:h:extremenetworks:alpine:6.2.2_68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.21`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.22`,
        fs:  `cpe:2.3:a:maxtor:maxtor_onetouch_iii:4.0.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.23`,
        fs:  `cpe:2.3:a:gnome:glib:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.24`,
        fs:  `cpe:2.3:a:cybozu:kunai:3.0.4:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.25`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.26`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.27`,
        fs:  `cpe:2.3:a:f-secure:server_security:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.28`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.29`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.30`,
        fs:  `cpe:2.3:h:netgear:gs716t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.31`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.32`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.33`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.34`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.35`,
        fs:  `cpe:2.3:a:gnu:libtasn1:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.36`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.37`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.38`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.39`,
        fs:  `cpe:2.3:a:web-dorado:ecommerce_wd:1.2.5:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.40`,
        fs:  `cpe:2.3:h:rockwellautomation:rslinx_enterprise:cpr9:sr5.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.41`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.42`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.43`,
        fs:  `cpe:2.3:a:rhq-project:rhq:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.44`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.45`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.46`,
        fs:  `cpe:2.3:h:juniper:secure_access_2500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.47`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(17\)ct:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.48`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1303.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.49`,
        fs:  `cpe:2.3:a:liftweb:lift:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.50`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.51`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.52`,
        fs:  `cpe:2.3:a:microsoft:atlas_framework:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.53`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.54`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.55`,
        fs:  `cpe:2.3:a:matrikonopc:matrikonopc_a\&amp;e_historian:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.56`,
        fs:  `cpe:2.3:a:tincan:phplist:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.57`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.58`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.9.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.59`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.60`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.61`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.62`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.00.xo.15.0\(2\)xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.63`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.64`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.65`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.66`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(1c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.67`,
        fs:  `cpe:2.3:a:iss:proventia_desktop:8.0.675.1790:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.68`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.19-67.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.69`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.70`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.71`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.72`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.73`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:2.74`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.00`,
        fs:  `cpe:2.3:a:passion4profession:8_minutes_abs_workout:2.0.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.01`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.02`,
        fs:  `cpe:2.3:a:hp:openview_performance_access:10.0.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.002`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.003`,
        fs:  `cpe:2.3:a:apache:poi:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.03`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.04`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.004`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.005`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.05`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.06`,
        fs:  `cpe:2.3:h:cisco:asr_9010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.07`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.08`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.09`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.10`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.11`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.12`,
        fs:  `cpe:2.3:a:patterson_dental:eaglesoft:17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.13`,
        fs:  `cpe:2.3:h:cisco:2900_integrated_service_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.14`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.12a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.15`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.16`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.17`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.18`,
        fs:  `cpe:2.3:a:paul_lesniewsk:autocomplete:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.19`,
        fs:  `cpe:2.3:o:cisco:ios:12.2n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.20`,
        fs:  `cpe:2.3:o:y-cam:ycbl03_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.22`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.17.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.23`,
        fs:  `cpe:2.3:a:util-linux_project:util-linux:2.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.24`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.25`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.12:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.26`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.27`,
        fs:  `cpe:2.3:a:hp:hppscanto:2.102.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.28`,
        fs:  `cpe:2.3:a:gentoo:nullmailer:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.29`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.30`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.31`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.32`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.33`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.34`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.35`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.36`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_html5:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.37`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rocomotion:pplog_2:3.38`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.63`,
        fs:  `cpe:2.3:a:hp:business_availability_center:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.64`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd7.d4xxwtpf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.65`,
        fs:  `cpe:2.3:a:sprint:smartview:2.28.82.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.66`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.4.2:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.67`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.5.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.68`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.69`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.70`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.71`,
        fs:  `cpe:2.3:a:symantec:backupexec_system_recovery:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.72`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.751:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.73`,
        fs:  `cpe:2.3:o:windriver:vxworks:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.74`,
        fs:  `cpe:2.3:o:asus:rt-ac66u_firmware:3.0.0.4.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.75`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.76`,
        fs:  `cpe:2.3:h:schrack:technik_microcontrol:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.77`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.78`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.79`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.80`,
        fs:  `cpe:2.3:a:hp:unified_functional_testing:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.81`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.82`,
        fs:  `cpe:2.3:a:google:chrome:17.0.957.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.83`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.85`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.86`,
        fs:  `cpe:2.3:a:oracle:application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.87`,
        fs:  `cpe:2.3:a:ut-files:utstats:-:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.88`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.89`,
        fs:  `cpe:2.3:a:arbornetworks:peakflow_sp:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.90`,
        fs:  `cpe:2.3:h:intel:mobile_intel_qm57_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.91`,
        fs:  `cpe:2.3:a:oracle:jinitiator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.92`,
        fs:  `cpe:2.3:a:google:chrome:0.2.149.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.93`,
        fs:  `cpe:2.3:a:7andi-fs.co:denny\&#39;s:2.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.94`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.941`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.942`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.11:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.951`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.952`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.953`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.954`,
        fs:  `cpe:2.3:a:altiris:out_of_band_management_language_pack:6.2.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.955`,
        fs:  `cpe:2.3:a:rack_project:rack:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.956`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.957`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:51.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.958`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.436:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.959`,
        fs:  `cpe:2.3:a:newsignature:addressfield_tokens:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.960`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.970`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_workstation:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.973`,
        fs:  `cpe:2.3:a:google:chrome:5.0.360.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.975`,
        fs:  `cpe:2.3:h:cisco:c220_m4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.976`,
        fs:  `cpe:2.3:a:tidio-gallery_project:tidio-gallery:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.977`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xd2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.978`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.979`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.980`,
        fs:  `cpe:2.3:h:cisco:internet_service_node:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.981`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.07\/26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.982`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.991`,
        fs:  `cpe:2.3:h:dell:latitude_e6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.992_01`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.6.0.1351:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.992_02`,
        fs:  `cpe:2.3:a:hp:sitescope:11.24.391:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.992_03`,
        fs:  `cpe:2.3:a:ibm:as400_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.992_04`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.992_05`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:0.992_06`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(50\)sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.000`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.64:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.001`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.002`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.8.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.003`,
        fs:  `cpe:2.3:a:hp:operations_manager_i:9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.004`,
        fs:  `cpe:2.3:a:atlassian:jira:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.005`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.006`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.007`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.7-p1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.008`,
        fs:  `cpe:2.3:o:cisco:staros:19.0.m0.61045:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.009`,
        fs:  `cpe:2.3:a:apache:shindig:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.010`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.011`,
        fs:  `cpe:2.3:h:xerox:workcentre_40_color:01.02.077.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderich_schupp:par-packer_module:1.012`,
        fs:  `cpe:2.3:h:cisco:wrv200_wireless-g_vpn_router_-_rangebooster:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_baier:weberknecht:-`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_baier:weberknecht:0.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_baier:weberknecht:0.1.1`,
        fs:  `cpe:2.3:a:symantec:opscenter_agent:7.0.1:release_update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_braun:ya_googlesearch:0.3.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_braun:ya_googlesearch:0.3.5`,
        fs:  `cpe:2.3:a:snort:snort:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_braun:ya_googlesearch:0.3.6`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_braun:ya_googlesearch:0.3.7`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_braun:ya_googlesearch:0.3.9`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roderick_braun:ya_googlesearch:0.3.10`,
        fs:  `cpe:2.3:a:voetbal_project:voetbal:4.7.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rodrigo_coimbra:nospam_pti:2.1`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rodrigo_polo:stream_video_player:1.4.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roemersoftware:free_hi-q_recorder:1.9`,
        fs:  `cpe:2.3:a:custom_banners_plugin_project:custom_banners:1.2.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:codefabrik:ecomat_cms:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2scb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:java_system_directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.4::~~~drupal~~`,
        fs:  `cpe:2.3:o:bluecoat:proxysg:4.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.5::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.7::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:bluecatnetworks:adonis:5.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:redhat:lv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roger_padilla_camacho:easy_breadcrumb:7.x-2.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roguewaveproductionsllc:wild_women_united:1::~~~android~~`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:5.2.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:yaml-fuer-drupal:linkchecker:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.6.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.21.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nba:nba_game_time_2013-2014:4.11:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.317:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:ichat_av:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:listener:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:8.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:7.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_operations_manager:7.4.6.790:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0564:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:liveauctions:liveauctions.tv:2.005:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.21::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p393:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.22::~~~wordpress~~`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.23::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.24::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.25::~~~wordpress~~`,
        fs:  `cpe:2.3:h:ibm:sng:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.26::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc3:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.27::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.28::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.29::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.565.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.30::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.32::~~~wordpress~~`,
        fs:  `cpe:2.3:a:simon_mcvittie:telepathy_gabble:0.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.33::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.34::~~~wordpress~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.35::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.36::~~~wordpress~~`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.37::~~~wordpress~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.38::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.d3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.39::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.40::~~~wordpress~~`,
        fs:  `cpe:2.3:a:php-fusion:recepies_module:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.41::~~~wordpress~~`,
        fs:  `cpe:2.3:a:horde:gollem:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.42::~~~wordpress~~`,
        fs:  `cpe:2.3:a:softerra:ldap_administrator:2009.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.43::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:compute_systems_manager:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.44::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:onlocation_cs4:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.45::~~~wordpress~~`,
        fs:  `cpe:2.3:a:qemu:qemu:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.46::~~~wordpress~~`,
        fs:  `cpe:2.3:a:riken:xoonips:3.42:*:*:*:*:xoops:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.47::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rsa:securid_web_agent:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.48::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mredsoftware:powershell_script-o-matic:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.49::~~~wordpress~~`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.50::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sony:sound_forge:10.0:b:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.51::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gajim:gajim:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.52::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.3:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.53::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-03-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.54::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.20:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.55::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.5.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.56::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.0:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.57::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.6.0.438:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.58::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.59::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.2.0-284.sles10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.60::~~~wordpress~~`,
        fs:  `cpe:2.3:a:logitech:lws_gallery:13.0.1778.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.61::~~~wordpress~~`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.62::~~~wordpress~~`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.63::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.64::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.65::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.66::~~~wordpress~~`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.3.67::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.06.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:workstation:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:role_scoper_project:role_scoper:1.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:epc2203_cable_modem_firmware:r1_customer_image_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:6.10.58`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:6.12.34`,
        fs:  `cpe:2.3:a:iss:blackice_defender:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:6.13.0`,
        fs:  `cpe:2.3:a:haxx:curl:6.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:6.13.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0`,
        fs:  `cpe:2.3:a:textpattern:textpattern:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.2`,
        fs:  `cpe:2.3:a:sympa:sympa:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.3`,
        fs:  `cpe:2.3:a:erlang:crypto:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.5`,
        fs:  `cpe:2.3:a:cubicfactory:cubic_cms:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.6`,
        fs:  `cpe:2.3:a:jreast:jr_east_japan:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.7`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.8`,
        fs:  `cpe:2.3:a:busybox:busybox:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.9`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.10`,
        fs:  `cpe:2.3:o:netgear:gs108pe_firmware:1.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.11`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.12`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.18:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.13`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.14`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.15`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p58:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.16`,
        fs:  `cpe:2.3:a:samba:samba:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.17`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.18`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.19`,
        fs:  `cpe:2.3:o:siemens:spc6000_firmware:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.20`,
        fs:  `cpe:2.3:a:google:chrome:5.0.365.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.21`,
        fs:  `cpe:2.3:a:google:v8:3.24.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.22`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.23`,
        fs:  `cpe:2.3:a:novell:edirectory:8.5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.24`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.5:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.25`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.26`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.27`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.28`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.29`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x52:d5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.30`,
        fs:  `cpe:2.3:o:microsoft:windows_95:-:osr2.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.31`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.32`,
        fs:  `cpe:2.3:a:micropact:icomplaints:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.33`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.34`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.35`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.36`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.45`,
        fs:  `cpe:2.3:a:drupal:drupal:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.46`,
        fs:  `cpe:2.3:a:opsview:opsview:3.0:-:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.47`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.48`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.49`,
        fs:  `cpe:2.3:a:netscape:navigator:8.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.50`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.51`,
        fs:  `cpe:2.3:a:apache:couchdb:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.52`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cbd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.53`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.54`,
        fs:  `cpe:2.3:h:hp:3com_switch_taa_compliant:5500g-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.55`,
        fs:  `cpe:2.3:a:ibm:http_server:2.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.56`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.57`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.58`,
        fs:  `cpe:2.3:a:gnu:glibc:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.59`,
        fs:  `cpe:2.3:a:hp:secpath1000fe:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.60`,
        fs:  `cpe:2.3:a:hp:smart_web_printing_oc:100.0.189.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.61`,
        fs:  `cpe:2.3:a:ibm:sametime_proxy_server_and_web_client:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.62`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-ampg_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.63`,
        fs:  `cpe:2.3:a:nextapp:echo:3.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.64`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.65`,
        fs:  `cpe:2.3:a:suse:suse_linux_office_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.66`,
        fs:  `cpe:2.3:a:spip:spip:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.67`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.68`,
        fs:  `cpe:2.3:h:cisco:tandberg_550_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.69`,
        fs:  `cpe:2.3:a:apache:openjpa:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.70`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.71`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.72`,
        fs:  `cpe:2.3:a:devicelock:devicelock:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.73`,
        fs:  `cpe:2.3:a:iss:rally_albania_live_2014:0.11:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.74`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.75`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.76`,
        fs:  `cpe:2.3:h:hp:jc653a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.77`,
        fs:  `cpe:2.3:h:supermicro:x9sci-ln4f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.78`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.79`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.0.80`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.0`,
        fs:  `cpe:2.3:h:polycom:rmx_1500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.1`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.2`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.3`,
        fs:  `cpe:2.3:a:sun:cobalt_raq:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.4`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.5`,
        fs:  `cpe:2.3:a:ca:api_gateway:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.6`,
        fs:  `cpe:2.3:a:google_sitemap_project:google_sitemap:0.4.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.7`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.8`,
        fs:  `cpe:2.3:a:wargaming:world_of_tanks_assistant:1.7.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.9`,
        fs:  `cpe:2.3:a:icinga:icinga:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.10`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.11`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.13`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.332:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.14`,
        fs:  `cpe:2.3:a:gnu:gnats:3.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.15`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.16`,
        fs:  `cpe:2.3:o:freebsd:freebsd:7.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.17`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.18`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.19`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.20`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.1.21`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:r2:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.0`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.1`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.2`,
        fs:  `cpe:2.3:a:opencart:opencart:2.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.4`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:3.0.0.4.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.5`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.6`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.7`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.22:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.8`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.9`,
        fs:  `cpe:2.3:a:cisco:unified_web_and_e-mail_interaction_manager:11.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.10`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.11`,
        fs:  `cpe:2.3:a:debian:dpkg:1.15.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.12`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.13`,
        fs:  `cpe:2.3:a:tableausoftware:tableau_server:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.14`,
        fs:  `cpe:2.3:h:supermicro:h8dcl-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.15`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.16`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.17`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.1.3:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.18`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r9_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.19`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.20`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_symantec_ep_integration_component:6.0.1237:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.21`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.29.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.22`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.23`,
        fs:  `cpe:2.3:a:trillian:trillian:0.724:aim_a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.24`,
        fs:  `cpe:2.3:a:gnu:glibc:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.25`,
        fs:  `cpe:2.3:a:adobe:creative_suite_4_design_premium:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.26`,
        fs:  `cpe:2.3:h:viewsonic:vx2240w_22\&#34;_lcd_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.27`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.28`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.29`,
        fs:  `cpe:2.3:a:skyarc:entryimexporter:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.31`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.32`,
        fs:  `cpe:2.3:a:horde:groupware:1.1.6:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.33`,
        fs:  `cpe:2.3:a:apple:safari:3.0.0b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.34`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.35`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p223:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.36`,
        fs:  `cpe:2.3:a:gnome:gnome-keyring:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.37`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_lms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.38`,
        fs:  `cpe:2.3:h:3com:3c13616:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.39`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:6.2.6.62196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.40`,
        fs:  `cpe:2.3:a:adobe:flash_cs4_extension_flash_lite_sti:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.41`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.651.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.42`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.43`,
        fs:  `cpe:2.3:a:google:chrome:50.0.2661.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.44`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.2.47`,
        fs:  `cpe:2.3:a:rsa:ace_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.0`,
        fs:  `cpe:2.3:h:hp:3com_router:5680:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.1`,
        fs:  `cpe:2.3:a:digia:qt:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.2`,
        fs:  `cpe:2.3:a:anjuke:anjuke:7.1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.3`,
        fs:  `cpe:2.3:a:mislav_marohnic:will_paginate:3.0.2:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.4`,
        fs:  `cpe:2.3:a:skype:skype:5.3.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.6`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.7`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.8`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.9`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.10`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.11`,
        fs:  `cpe:2.3:a:cisco:content_distribution_manager_4650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.12`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.13`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.14`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.15`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.16`,
        fs:  `cpe:2.3:a:apache:solr:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.17`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.18`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rom_walton:boinc:7.3.19`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.1.1:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ronan_dowling:node_hierarchy:6.x-1.0`,
        fs:  `cpe:2.3:o:vmware:esx:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ronan_dowling:node_hierarchy:6.x-1.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ronan_dowling:node_hierarchy:6.x-1.2`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:5.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ronan_dowling:node_hierarchy:6.x-1.3`,
        fs:  `cpe:2.3:a:commons_wikis_project:commons_wikis:7.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ronan_dowling:node_hierarchy:6.x-1.4`,
        fs:  `cpe:2.3:a:magzter:electronics_for_you:3.02:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ronan_dowling:node_hierarchy:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:centos:centos:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:room_reservations_project:room_reservations:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_lan_management_solution:2.6:update:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roriis.codeplex.com:rails_for_iis_fast-cgi:1.0.5.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rosettastone:rosettastone:3.2.6`,
        fs:  `cpe:2.3:a:jruby:jruby:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rosettastone:rosettastone:3.2.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ross_burton:libsocialweb:0.25.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ross_burton:libsocialweb:0.25.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ross_burton:libsocialweb:0.25.10`,
        fs:  `cpe:2.3:a:redhat:openstack_folsom:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ross_burton:libsocialweb:0.25.13`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.7:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ross_burton:libsocialweb:0.25.19`,
        fs:  `cpe:2.3:h:emc:file_management_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.0.8`,
        fs:  `cpe:2.3:a:oracle:database_server_lite:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.1:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)xi3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.1:rc`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.1.4`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.1.7`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.2.0`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.2.1`,
        fs:  `cpe:2.3:a:logitech:webcam_software:12.10.1113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.2.2`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:roundcube_webmail:1.2.3`,
        fs:  `cpe:2.3:a:gnu:emacs:23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1`,
        fs:  `cpe:2.3:h:polycom:rmx_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:20050811`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:20050820`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:20051007`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:20051021`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5:a:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:alpha`,
        fs:  `cpe:2.3:a:smartdraw:smartdraw:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:beta`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:beta2`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_developer:01-03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:rc2`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:6.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1:stable`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.51.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.1.1`,
        fs:  `cpe:2.3:o:huawei:s2300_firmware:v100r006c05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.2`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.15:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.2:alpha`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.2:beta`,
        fs:  `cpe:2.3:a:microsoft:project:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.2:stable`,
        fs:  `cpe:2.3:a:altiris:integrated_component_for_microsoft_active_directory:6.1.842.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.2.1`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.2.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:update1:client_workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.3:beta`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.01.306:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.3:rc1`,
        fs:  `cpe:2.3:a:lingotek:lingotek:6.x-1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.3:stable`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.3.1`,
        fs:  `cpe:2.3:a:novell:netmail:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.4`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.4:beta`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.4.1`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.4.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.41.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.5:beta`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.5:rc`,
        fs:  `cpe:2.3:h:hp:laserjet_m3027_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.5.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.5.2`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.5.3`,
        fs:  `cpe:2.3:a:kryo:iodine:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.5.4`,
        fs:  `cpe:2.3:a:sun:ipmitool:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.6`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.7`,
        fs:  `cpe:2.3:a:gnu:inetutils:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.7.1`,
        fs:  `cpe:2.3:o:microsoft:windows_10:-:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.7.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.7.3`,
        fs:  `cpe:2.3:h:xavi:x7968:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.8.0`,
        fs:  `cpe:2.3:a:ca:directory:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.8.1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.8.2`,
        fs:  `cpe:2.3:a:matrikonopc:scada_dnp3_opc_server:1.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.8.3`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.8.4`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.8.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.8.6`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9:beta`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9:rc`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9:rc2`,
        fs:  `cpe:2.3:a:esri:arcgis_arcsde:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9.1`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9.3`,
        fs:  `cpe:2.3:o:freebsd:freebsd:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9.4`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:0.9.5`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.0:git`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:11.0\(17\)bt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.0.4`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.0.5`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.32:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.0.6`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.0.8`,
        fs:  `cpe:2.3:a:sympa:sympa:0.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1:beta`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1:rc`,
        fs:  `cpe:2.3:a:thegr:dl:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1.0`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_ip_vcr_3.0:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.114.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1.5`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.12-200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1.6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.1.7`,
        fs:  `cpe:2.3:a:apache:camel:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.2:rc`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:7.6.110.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.2.0`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20120125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.2.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.2.2`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundcube:webmail:1.2.3`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.1.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.1.1`,
        fs:  `cpe:2.3:a:hp:software_cross_platform_component:6.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.1.2`,
        fs:  `cpe:2.3:a:wellintech:kingview:65.30.2010.18018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.1.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.0`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.6.2:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.1`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.0:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.3`,
        fs:  `cpe:2.3:a:webform_project:webform:6.x-3.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.4`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.5`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.6`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.6.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.7`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.2.8`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.3.0`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.3.0:pre1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.3.0:pre2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p454:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.3.0:pre3`,
        fs:  `cpe:2.3:a:rezgo_project:rezgo:1.4.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.4.0`,
        fs:  `cpe:2.3:a:freeradius:freeradius:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.4.0:b1`,
        fs:  `cpe:2.3:a:apple:itunes:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.4.0:b2`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.4.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.4.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.4.2:pr1`,
        fs:  `cpe:2.3:a:ilearnwith:counting_\&amp;_addition_kids_games:1.8.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.0`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.0:beta1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.0:beta2`,
        fs:  `cpe:2.3:a:atlassian:jira:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.0:pr1`,
        fs:  `cpe:2.3:a:bzrtp_project:bzrtp:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.2`,
        fs:  `cpe:2.3:a:web-dorado:photo_gallery:1.2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.3`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.4`,
        fs:  `cpe:2.3:a:telligent:evolution:7.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.5`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.6`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.7`,
        fs:  `cpe:2.3:a:rockwellautomation:integrated_architecture_builder:9.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.8:stable`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1677.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.5.9`,
        fs:  `cpe:2.3:h:yokogawa:exasmoc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.0:b1`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.10.446:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.0:b2`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.0:b3`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.0:b4`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.1`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.3`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.5`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.60:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.6`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.7`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.8`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.7.1:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.9`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.10`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.6.11`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.0`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.0:b1`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.0:b2`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.0:b3`,
        fs:  `cpe:2.3:a:sourcegear:vault_server:4.1.4.18402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.1`,
        fs:  `cpe:2.3:a:larry_garfield:autosave:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.2`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.3`,
        fs:  `cpe:2.3:a:yassl:cyassl:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.4`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.5`,
        fs:  `cpe:2.3:a:ibm:global_retention_policy_and_schedule_management:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.6`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20140101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.7`,
        fs:  `cpe:2.3:a:adobe:adobe_reader:11.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.8`,
        fs:  `cpe:2.3:a:ibm:net.commerce_hosting_server:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.9`,
        fs:  `cpe:2.3:a:jease:jease:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.10`,
        fs:  `cpe:2.3:a:qemu:qemu:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.11`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.7.12`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.0`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_secure_it_server:7.1.211:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.0:b1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.0:b2`,
        fs:  `cpe:2.3:a:apache:cxf:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:44.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.2`,
        fs:  `cpe:2.3:a:apple:cups:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.3`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.4`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:3.1.322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.5`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.8.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:0.9.0:b1`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.0`,
        fs:  `cpe:2.3:a:echo_project:echo:-:*:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.0.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.1.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:2.10:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.1.1`,
        fs:  `cpe:2.3:a:apache:wicket:6.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.1.2`,
        fs:  `cpe:2.3:a:php:php:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.2.0`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.2.1`,
        fs:  `cpe:2.3:a:ibm:sametime:7.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.3.0`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.88:-:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.3.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.3.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.3.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.0`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.1`,
        fs:  `cpe:2.3:a:microsoft:directx:9.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.2`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.0.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.3`,
        fs:  `cpe:2.3:a:nuance:dragon_naturallyspeaking:8.10.0.285:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.4`,
        fs:  `cpe:2.3:a:apple:safari:3.0.3b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.5`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.7`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.16:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.8`,
        fs:  `cpe:2.3:a:gnu:cpio:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.9`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.10`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.11`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.12`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:rc5:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.13`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.14`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.15`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:05-00-\/i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.16`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.17`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.04:*:le:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.18`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.19`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roundup-tracker:roundup:1.4.20`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:photoshowexpress:2.0.63`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.03.309:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_activation_module:1.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.8:update13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_cineplayer_decoder_pack:4.2.0`,
        fs:  `cpe:2.3:a:microsoft:pocket_ie:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_cineplayer_decoder_pack:4.3.0`,
        fs:  `cpe:2.3:a:x:libxinerama:1.0.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_dla:4.90`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_dla:4.95`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_recordnow:7.10`,
        fs:  `cpe:2.3:a:easy_social_project:easy_social:7.x-2.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_recordnow%21_plus:7.3`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_update_manager:2.9`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rovicorp:sonic_update_manager:3.0.0`,
        fs:  `cpe:2.3:a:citrix:web_interface:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rowlandsolutions:lent_experience:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:network_assistant:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:activation_module:1.0`,
        fs:  `cpe:2.3:a:tobias_maier:paratrooper-pingdom:1.0.0:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:audio_module:2.0.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11b\)e12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:backontrack:1.1`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:backontrack:1.2`,
        fs:  `cpe:2.3:a:microsoft:asp.net:1.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:backontrack:1.3`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.06\/02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:backontrack:1.3.3`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:backontrack:3.0`,
        fs:  `cpe:2.3:a:apple:safari:2.0.4:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:backontrack:4.0`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.1.0.2014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:backontrack:4.0::~~pe~~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:burn:-`,
        fs:  `cpe:2.3:a:x:libfs:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:burn:1.6`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:burn:1.8`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:burn_secure:1.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:20.0.0.306:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:burn_virtual_folder_install:1.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p360:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cd_creator:-`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cd_creator:5.0`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cd_creator:5.3.5`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cd_creator:6.1.1.42`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cd_creator:6.1.1.48`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_audio:3.6`,
        fs:  `cpe:2.3:a:emc:rsa_security_analytics:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_audio:3.7`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_copy:3.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_copy:3.7`,
        fs:  `cpe:2.3:a:ca:brightstor_hierarchical_storage_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_core:3.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.5:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_core:3.7`,
        fs:  `cpe:2.3:o:apple:watchos:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_data:3.6`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_data:3.7`,
        fs:  `cpe:2.3:a:hp:service_manager_web_client:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_tools:3.6`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:central_tools:3.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:-`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a1:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:1.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:1.51`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:1.52`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:2.0`,
        fs:  `cpe:2.3:a:arcsoft:panorama_maker:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:2.2`,
        fs:  `cpe:2.3:a:systemsoftware:community_black_forum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:2.3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70-\/g:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:2.3.1`,
        fs:  `cpe:2.3:a:sun:java_communications_services_delegated_administrator:6:2005q1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:3.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:3.9`,
        fs:  `cpe:2.3:a:netscape:navigator:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:5.6`,
        fs:  `cpe:2.3:a:qemu:qemu:0.9.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer:5.8`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer_decoder_pack:4.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:cineplayer_decoder_pack:4.3`,
        fs:  `cpe:2.3:a:ca:ehealth_systemedge:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:copy_module:2.0.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:1.0.439::~~starter~~~`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:1.1.57::~~gold~~~`,
        fs:  `cpe:2.3:a:cisco:eap-fast_module:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:3.8.0::~~business~~~`,
        fs:  `cpe:2.3:a:openstack:swift:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:5.0.0::~~starter~~~`,
        fs:  `cpe:2.3:a:samba:rsync:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:9.0.574::~~silver~~~`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:10.1:-:business`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:10.1.207::~~business_edition_gold~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)xn1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:10.1.207::~~gold~~~`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:10.1.299::~~business_edition_gold~~~`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:x64-datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:10.3::~~business~~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.21:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:10.3.206::~~enterprise_edition_gold~~~`,
        fs:  `cpe:2.3:h:huawei:ar3600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:12.1.77.0::~~starter~~~`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:2011::~~pro~~~`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator:2012`,
        fs:  `cpe:2.3:a:opensourceclassifieds:opensourceclassifieds:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_audio:3.3`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_audio:3.5`,
        fs:  `cpe:2.3:a:ibm:lotus_foundations_start:1.2.2:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_audio:3.7.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_audio:3.8.0`,
        fs:  `cpe:2.3:a:hp:precisionscan_pro:3.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_basic_v9:3.3.0`,
        fs:  `cpe:2.3:a:organizer_project:organizer:0.5b:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_bdav_plugin:3.3`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_bdav_plugin:3.5`,
        fs:  `cpe:2.3:a:sun:staroffice:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_content:2011`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_content:2012`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.45.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_copy:3.3`,
        fs:  `cpe:2.3:o:openelec:openelec:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_copy:3.5`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_copy:3.7.0`,
        fs:  `cpe:2.3:a:apache:hadoop:0.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_copy:3.8.0`,
        fs:  `cpe:2.3:a:php:php:5.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_data:3.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(7\)wx5\(15a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_data:3.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_data:3.7.0`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_data:3.8.0`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_de:3.3`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_de:3.5`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_de:3.7.0`,
        fs:  `cpe:2.3:a:ca:total_defense:r12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_de:10.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_tools:3.3`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_tools:3.5`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_tools:3.7.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:creator_tools:3.8.0`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:data_module:2.0.4`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:disc_gallery:3.1`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:dla:5.1`,
        fs:  `cpe:2.3:a:umn:mapserver:6.4.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:dla:5.2`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.06.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:drag-to-disc:9.0`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs5:12.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:drag-to-disc:9.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:drag-to-disc:9.5`,
        fs:  `cpe:2.3:a:gemaire:gemaire\&#39;s_hvac_assist:5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:dvdmax_player:2.0`,
        fs:  `cpe:2.3:a:sympa:sympa:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:dvdmax_player:4.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:dvdmax_player:5.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:dvdmax_player:6.1`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_cd_%26_dvd_creator:6.0.0`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144n_firmware:1.47:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_cd_%26_dvd_creator:6.0.0.171`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:1.00.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_cd_%26_dvd_creator:6.1.1.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_cd_%26_dvd_creator:6.1.1.17`,
        fs:  `cpe:2.3:a:python:python:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_cd_%26_dvd_creator:6.2.0.110`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_cd_creator_basic:5.1.0.0`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_application_metering:6.1.1080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_cd_creator_basic:5.3.4.21`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_media_creator:7.0.430.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.99.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:easy_media_creator_basic_edition:7.1.0.183`,
        fs:  `cpe:2.3:a:tektite:turbo_river_racing_free:1.07:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:express_labeler:1.0`,
        fs:  `cpe:2.3:h:pgp:e-ppliance_300:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:express_labeler:2.0`,
        fs:  `cpe:2.3:a:apple:cups:1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:express_labeler:2.1`,
        fs:  `cpe:2.3:a:oracle:customer_interaction_history:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:express_labeler:3.2`,
        fs:  `cpe:2.3:a:xelex:mobiletrack:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:express_labeler:3.2.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.0.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:express_labeler:3.2.2`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:face_filter:1.0.7`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:file_backup:1.1.0`,
        fs:  `cpe:2.3:h:3com:3crwe554g72t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:file_backup:1.3.2`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:media_manager:9.1`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:media_manager:9.1.60`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:media_manager:9.1.72`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:media_manager:9.4`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:media_manager:9.4.23`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp4:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:media_manager:9.4.46`,
        fs:  `cpe:2.3:a:portfolio_project:portfolio:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:media_manager:9.4.51`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:media_manager:9.4.67`,
        fs:  `cpe:2.3:a:oracle:marketing:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:mydvd:10.3.349`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:mydvd_plus:6.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:photoshow:6.0`,
        fs:  `cpe:2.3:a:secunia:csi_agent:6.0.1.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_audio:2.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_audio:2.0.4`,
        fs:  `cpe:2.3:a:dell:client_manager_agent:2.2.1019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_audio:3.5`,
        fs:  `cpe:2.3:a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_copy:2.0`,
        fs:  `cpe:2.3:a:microsoft:content_management_server:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_copy:2.0.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_copy:3.5`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_data:2.0`,
        fs:  `cpe:2.3:h:supermicro:h8dgg-qf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_data:2.0.4`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.6:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:recordnow_data:3.5`,
        fs:  `cpe:2.3:a:suse:suse_linux_firewall_cd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:sonic_recordnow:-`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:sonic_recordnow:7.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:toast:-`,
        fs:  `cpe:2.3:a:landesk:landesk_management_suite:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:update_manager:3.0`,
        fs:  `cpe:2.3:a:zanematthew:zm_ajax_login_\&amp;_register:1.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:update_manager:6.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.14.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:vd64inst:1.0.0`,
        fs:  `cpe:2.3:a:mautic:mautic:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roxio:video_capture_usb:1.22.0`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roy_baxter:better_revisions:7.x-1.0`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roy_baxter:better_revisions:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roy_baxter:better_revisions:7.x-1.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:roy_baxter:better_revisions:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.3.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4.1`,
        fs:  `cpe:2.3:a:oracle:http_server:9.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4.2`,
        fs:  `cpe:2.3:a:agilebits:1password:3.0:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4.2%2fa`,
        fs:  `cpe:2.3:a:python:python:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4.3`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4.4`,
        fs:  `cpe:2.3:a:analogx:proxy:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4.5`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.90.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4.6`,
        fs:  `cpe:2.3:a:hp:event_monitoring_service:a.04.20.11.04:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:1.4.7`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:4.6\(2\):sr6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.1`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.2`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.3`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.5`,
        fs:  `cpe:2.3:a:magzter:legalera:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.6`,
        fs:  `cpe:2.3:a:csc:tsrwebservice:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.7`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.8`,
        fs:  `cpe:2.3:o:vmware:esxi:4.1:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.9`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.10`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.0.11`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.1.1`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.1.2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.607:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.1`,
        fs:  `cpe:2.3:a:agilebits:knox:2.0.2:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.2`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.3`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.0.0.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.3.10`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.3.11`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.4`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.5`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.6`,
        fs:  `cpe:2.3:a:status:statusnet:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.7`,
        fs:  `cpe:2.3:a:ibm:spss_data_collection:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.8`,
        fs:  `cpe:2.3:h:huawei:e200x5:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.9`,
        fs:  `cpe:2.3:h:nvidia:quadro_m5000m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.10`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.2.11`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.1`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.2`,
        fs:  `cpe:2.3:a:python_imaging_project:python_imaging:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.779.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.4`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.5`,
        fs:  `cpe:2.3:a:adobe:acrobat:17.011.30066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.6`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.7`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.8`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1006.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.3.9`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.1`,
        fs:  `cpe:2.3:a:cubecart:cubecart:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.2`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.3`,
        fs:  `cpe:2.3:o:novell:netware:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.5`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.8`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1056.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.9`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.11`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.4.12`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.5`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.6.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.5.1`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.5.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:7.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.5.3`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update8:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.5.4`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.8:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.5.5`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.5.6`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:2.6.7`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:3.0`,
        fs:  `cpe:2.3:h:linksys:wap55ag:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:3.0.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(3a\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:3.0.2`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:3.0.3`,
        fs:  `cpe:2.3:a:jenkins:git:2.4.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:3.0.4`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:3.0.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.03:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:3.0.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.0.`,
        fs:  `cpe:2.3:a:totalseminars:cissp_h_ed_aio_demo:4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.0.1`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.0.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.0.3`,
        fs:  `cpe:2.3:a:bea:weblogic_mobility_server:3.6:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.0.4`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.1`,
        fs:  `cpe:2.3:a:adobe:camera_raw:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.3.3`,
        fs:  `cpe:2.3:o:apple:os_x_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.4.2.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.4.2.2`,
        fs:  `cpe:2.3:a:nuance:realspeak:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.4.2.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.4:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.5.90`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.6.0`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.6.0:rc1`,
        fs:  `cpe:2.3:a:gentoo:media-libs_jpeg:6b:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.6.0:rc2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.6.0:rc3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.6.0:rc4`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.7.0`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.7.1`,
        fs:  `cpe:2.3:a:hp:release_control:9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.7.2`,
        fs:  `cpe:2.3:a:7-zip:p7zip:9.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.8.0`,
        fs:  `cpe:2.3:h:cisco:2911_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.8.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:15.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.9.0`,
        fs:  `cpe:2.3:a:python:python:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.9.0:alpha`,
        fs:  `cpe:2.3:a:epiqo:email:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.9.0:beta1`,
        fs:  `cpe:2.3:h:oracle:sun_blade_x6275:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.9.0:rc1`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.9.1`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.9.1.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.9.1.2`,
        fs:  `cpe:2.3:a:ticketroundup:ticket_round_up:3.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.10.0`,
        fs:  `cpe:2.3:h:avaya:cajun_p330:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.10.1`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.10.2`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.11.1`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rpm:rpm:4.12.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rrdtool_project:rrdtool:1.4.7::~~~python~~`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:access_manager_agent:-`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:access_manager_agent_for_iis_5.0%2f6.0:4.7`,
        fs:  `cpe:2.3:a:dell:wyse_device_manager:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:access_manager_server:6.0`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:access_manager_server:6.1`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:access_manager_server:6.1:sp1`,
        fs:  `cpe:2.3:a:apache:log4j:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:access_manager_server:6.1:sp2`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:access_manager_server:6.1:sp3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_agent:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_agent:5.0`,
        fs:  `cpe:2.3:a:teradata:decision_expert_administrator:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_server:-`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_server:3.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_server:3.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_server:3.3.1`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:2.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_server:4.0`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_management_foundation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_server:4.1`,
        fs:  `cpe:2.3:a:castillobueno:ccmplayer:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:ace_server:5.2`,
        fs:  `cpe:2.3:h:d-link:dsp-w215:a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:archer_egrc_platform:5.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_agent:6.1.3`,
        fs:  `cpe:2.3:a:mcafee:agent:4.0.0.1494:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_agent_for_web:-`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_agent_for_web:5.1`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_agent_for_web:5.1.1`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_agent_for_web:5.2`,
        fs:  `cpe:2.3:a:bannersky:bsk_pdf_manager:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_agent_for_web:5.3`,
        fs:  `cpe:2.3:h:apc:ap9606:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_agent_for_windows:6.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_api:8.1`,
        fs:  `cpe:2.3:a:horde:groupware:5.2.15:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_api:8.1:sp1`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_client:2.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_client:3.0`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_client:3.5.1`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.1.2:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_manager:-`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_manager:6.0`,
        fs:  `cpe:2.3:o:redhat:linux:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_manager:6.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_manager:7.1:-`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_manager:7.1:sp4`,
        fs:  `cpe:2.3:a:wernerd:zrtpcpp:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_manager:8.0`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:authentication_manager:8.0:p1`,
        fs:  `cpe:2.3:a:webroot:security_-_complete:3.6.0.6610:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:bsafe_cert-c:-`,
        fs:  `cpe:2.3:a:alvaro_herrera:pl\/php:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:bsafe_cert-c:2.7`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:bsafe_crypto-c:-`,
        fs:  `cpe:2.3:a:hp:panostandalone:100.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:bsafe_crypto-c:6.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:bsafe_ssl-j_sdk:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.3:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:bsafe_ssl-j_sdk:3.0`,
        fs:  `cpe:2.3:h:d-link:dap-2695:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:bsafe_ssl-j_sdk:3.0.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:bsafe_ssl-j_sdk:3.1`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:cleartrust_servers:6.0`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:3.3.6_build_0115`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:3.5.0`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.3.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:3.5.1`,
        fs:  `cpe:2.3:h:cisco:mds_9100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:3.5.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:3.7.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.5r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:3.7.0:sp1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.5.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:4.0:sp1`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:4.0:sp2`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:4.0:sp3`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.02.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:4.0:sp4`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:envision:4.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:keon_certificate_authority_manager:-`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:keon_certificate_authority_manager:6.5.1`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:keon_certificate_authority_manager:6.6`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.21:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:keon_registration_authority_web_interface:-`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:keon_registration_authority_web_interface:1.0`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:pluggable_authentication_module_agent:6.0`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:pluggable_authentication_module_agent:7.0`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:rsaref:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd243a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:rsaref:2.0`,
        fs:  `cpe:2.3:a:adobe:add_or_remove_creative_suite_3_web_standard:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rsa:securid:-`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rsa:securid:2.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:rsa:securid:5.0`,
        fs:  `cpe:2.3:a:xnview:xnview:1.80.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_software_token_converter:2.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.50.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_software_token_converter:2.6.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_web_agent:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_web_agent:5`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_web_agent:5.2`,
        fs:  `cpe:2.3:a:hp:device_discovery:140.0.213.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_web_agent:5.3`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_web_agent:5.3.4`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_web_agent:5.3.5`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsa:securid_web_agent:7.2.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsbac:rule_set_based_access_control:-`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsbac:rule_set_based_access_control:1.3.3`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsbac:rule_set_based_access_control:1.3.4`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsbr:outlook_attachment_sniffer:4.1.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.289:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.9.0-4:alpha`,
        fs:  `cpe:2.3:h:cisco:2921_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.9.4:alpha`,
        fs:  `cpe:2.3:a:techsmith:snagit:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.9.5:alpha`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.44.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.1:alpha`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.2:alpha`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.5:alpha`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.5:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.6:alpha`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:195.22:-:*:*:esx:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.7:alpha`,
        fs:  `cpe:2.3:a:ariel_barreiro:noderecommendation:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.8:alpha`,
        fs:  `cpe:2.3:a:tibco:spotfire_deployment_kit:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.9:alpha`,
        fs:  `cpe:2.3:h:cisco:7940_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.10:alpha`,
        fs:  `cpe:2.3:a:scriptlogic:sharepoint_web_services:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.11:alpha`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.13:alpha`,
        fs:  `cpe:2.3:h:nokia:n95:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.10.14:alpha`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.0:alpha`,
        fs:  `cpe:2.3:a:google:chrome:6.0.486.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.1:alpha`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.2:alpha`,
        fs:  `cpe:2.3:a:consulo:ip_alarm:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.3:alpha`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.4:alpha`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:pre7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.5:alpha`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x51:d35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.6:alpha`,
        fs:  `cpe:2.3:a:nero:rescue_agent:1.99.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.7:alpha`,
        fs:  `cpe:2.3:h:cisco:c4500m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.8:alpha`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.10:alpha`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1278.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.11.11:alpha`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.12.0:alpha`,
        fs:  `cpe:2.3:a:openstack:swift:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.12.1:alpha`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.12.2:alpha`,
        fs:  `cpe:2.3:o:huawei:mate_7_firmware:mt7-tl00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.13.0:alpha`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:04-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.13.1:alpha`,
        fs:  `cpe:2.3:a:busybox:busybox:1.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.14.0:alpha`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:1.14.1:alpha`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:2.1.0:beta`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:2.1.1`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:2.2.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:2.2.1`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:2.3.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:3.0:rc1`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.5:-:file_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:3.0.1`,
        fs:  `cpe:2.3:h:huawei:ar2200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:3.1.0`,
        fs:  `cpe:2.3:a:mindjet:mindmanager:9.2.504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsgallery2:com_rsgallery2:3.2.0`,
        fs:  `cpe:2.3:h:xerox:workcentre:7675:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsi_video_technologies:frontel_protocol:2.0`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rssbus:rssbus_for_sharepoint:3.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rssreader:rssreader:-`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rssreader:rssreader:1.0.88`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsupport:lg_telepresence:2.0.12::~~~android~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:6.4.2`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:6.5.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:6.6.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.606.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.0`,
        fs:  `cpe:2.3:h:linksys:befsru31:1.43.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.1`,
        fs:  `cpe:2.3:a:hp:hpztlbxfx:0.206.197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.2`,
        fs:  `cpe:2.3:a:percona:percona_server:5.7.10-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.4`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.5`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.6`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.6:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.7`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.9`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.174.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.10`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.11`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.1.12`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.2.1`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.2.2`,
        fs:  `cpe:2.3:a:tqdm_project:tqdm:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.2.3`,
        fs:  `cpe:2.3:a:apache:httpclient:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.2.4`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:10.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.2.5`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.2.6`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.2.7`,
        fs:  `cpe:2.3:a:gnu:gnump3d:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.0`,
        fs:  `cpe:2.3:a:vicidial:vicidial:2.7:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.1`,
        fs:  `cpe:2.3:a:hitachi:jp1\/it_desktop_management-manager:10-01-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.3`,
        fs:  `cpe:2.3:a:ocportal:ocportal:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.4`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.5`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xu2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.7`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.8`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:18.009.20044:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.9`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.10`,
        fs:  `cpe:2.3:a:google:chrome:11.0.664.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.11`,
        fs:  `cpe:2.3:h:cisco:c250_m1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.12`,
        fs:  `cpe:2.3:a:mybb:mybb:1.0:pr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.13`,
        fs:  `cpe:2.3:a:google:chrome:11.0.698.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.14`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.3.15`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ebr:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.4.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.4.1`,
        fs:  `cpe:2.3:a:skyarc:duplicateentry:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.4.2`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.5.0:devel`,
        fs:  `cpe:2.3:a:apple:itunes:8.0.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.5.1:devel`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.5.2:devel`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rsyslog:rsyslog:7.5.3:devel`,
        fs:  `cpe:2.3:a:php:php:5.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rtiindia:rti_india:3.8.21::~~~android~~`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rts:rtsinfo:1.4.8::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubinius:rubinius:-`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-i18n:i18n:0.6.5:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:h:siemens:simatic_s7_cpu_1212c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-i18n:i18n:0.6.6:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:jenkins:git:3.1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-i18n:i18n:0.6.7:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-i18n:i18n:0.6.8:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:openttd:openttd:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-i18n:i18n:0.6.9:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:apache:activemq:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.667.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.26:build110823:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.6-26`,
        fs:  `cpe:2.3:a:oracle:payroll:12.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.9:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p160`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_set:07-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p17`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(3q\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p173`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p174`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p22`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p248`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p249`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p299`,
        fs:  `cpe:2.3:a:abushhab:alwasel:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p301`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p302`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p330`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p334`,
        fs:  `cpe:2.3:h:linksys:befsr11:1.42.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p352`,
        fs:  `cpe:2.3:a:sgminer_project:sgminer:4.1.271:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p357`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p358`,
        fs:  `cpe:2.3:a:mollify:mollify:1.6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p370`,
        fs:  `cpe:2.3:h:micronet:sp916bm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p371`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:d50:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p373`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_mail_data_protection_for_microsoft_exchange_server:7.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p374`,
        fs:  `cpe:2.3:o:google:android:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p71`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:ccg:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:p72`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:preview1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:preview2`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:preview3`,
        fs:  `cpe:2.3:a:adobe:adobe_content_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.8.7:preview4`,
        fs:  `cpe:2.3:a:gnu:fileutils:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.1`,
        fs:  `cpe:2.3:a:core-apps:ismrm-esmrmb_2014:6.0.8.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.2`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3`,
        fs:  `cpe:2.3:h:trendnet:tv-ip422w:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p0`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ecb:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p125`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p194`,
        fs:  `cpe:2.3:a:hp:sitescope_tools:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p286`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p383`,
        fs:  `cpe:2.3:a:devsaran:responsive_blog:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p385`,
        fs:  `cpe:2.3:a:plone:plone:5.1:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p392`,
        fs:  `cpe:2.3:a:gnu:enscript:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p426`,
        fs:  `cpe:2.3:a:aol:internet_software:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:1.9.3:p429`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.23.364:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.25.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0.0:p0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0.0:p195`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0.0:p247`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0.0:preview1`,
        fs:  `cpe:2.3:a:hp:version_control_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0.0:preview2`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0.0:rc1`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.14:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.0.0:rc2`,
        fs:  `cpe:2.3:o:xen:xen:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.1:-`,
        fs:  `cpe:2.3:a:google:v8:3.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.1:preview1`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.1.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.1.5`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ruby-lang:ruby:2.2.0`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubycell:piano_teacher:20140730::~~~android~~`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.0`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.1`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.2`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.4`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00-09:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p146:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.6`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.53:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.7`,
        fs:  `cpe:2.3:a:xixun:xixuntiantian:0.6.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.8`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.9`,
        fs:  `cpe:2.3:o:huawei:5310ei_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.10`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.11`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.12`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(2c\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.13`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.14`,
        fs:  `cpe:2.3:a:microsoft:visual_basic_software_development_kit:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.15`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.16`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.17`,
        fs:  `cpe:2.3:a:openvpn:openvpn_access_server:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.18`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.19`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.20`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.21`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.22`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:1.0.1:rev25421:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.23`,
        fs:  `cpe:2.3:o:conceptronic:c54apm_firmware:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.23.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.351.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.24`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.25`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.1\(3\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.26`,
        fs:  `cpe:2.3:a:apache:hadoop:0.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.27`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:1.8.28`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)t8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.0:preview2`,
        fs:  `cpe:2.3:h:cisco:nexus_9396px:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.0:preview2.1`,
        fs:  `cpe:2.3:a:apple:quicktime:7.67.75.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.0:preview2.2`,
        fs:  `cpe:2.3:a:gnu:bash:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.0:rc2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.13`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.14`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.15`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.0.16`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.2.1`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.2.2`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.2.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.2.4`,
        fs:  `cpe:2.3:o:netbsd:netbsd:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.4.0`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3202a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.4.1`,
        fs:  `cpe:2.3:h:cisco:cable_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.4.2`,
        fs:  `cpe:2.3:a:ca:directory:r12:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.4.3`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.4.4`,
        fs:  `cpe:2.3:a:openstack:swift:1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.4.5`,
        fs:  `cpe:2.3:h:supermicro:x9sre-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.4.6`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubygems:rubygems:2.4.7`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:html_sanitizer:1.0.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:jquery-rails:3.1.2`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:jquery-rails:4.0.0`,
        fs:  `cpe:2.3:a:oracle:learning_management:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:jquery-rails:4.0.1`,
        fs:  `cpe:2.3:a:python-requests:requests:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:jquery-ujs:1.0.3`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:rails:1.2.4`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0001_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.5.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.14159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.5.5`,
        fs:  `cpe:2.3:a:nmedia:member_conversation:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.5.6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.5.7`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.0:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.6.0`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.6.5`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.3.2:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.7.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.8.0`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.12:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.8.5`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.9.0`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.9.1`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.9.2`,
        fs:  `cpe:2.3:a:mautic:mautic:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.9.3`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.9.4`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.9.4.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.10.0`,
        fs:  `cpe:2.3:a:brian_altenhofel:slidebox:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.10.1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.2.1:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.11.0`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.26.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.11.1`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2016:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.12.0`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.13:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.12.1`,
        fs:  `cpe:2.3:a:altiris:agent_for_unix_and_linux:6.2.1378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.13.0`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.13.1`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:2.5.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.14.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.14.2`,
        fs:  `cpe:2.3:a:apache:subversion:0.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.14.3`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:0.14.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.0.0`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.1.0`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.1.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.1.2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:6.0.199.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.1.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.1.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.1.5`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.1.6`,
        fs:  `cpe:2.3:a:hp:unload:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.2.0`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.2.1`,
        fs:  `cpe:2.3:a:vmware:vcenter_server_appliance:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.2.2`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.2.3`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1b.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.2.4`,
        fs:  `cpe:2.3:a:barebones:textwrangler:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.2.5`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.2.6`,
        fs:  `cpe:2.3:a:lenovo:xclarity_administrator:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.9.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:1.9.5`,
        fs:  `cpe:2.3:a:microsoft:publisher:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.0.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.0.0:rc1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p470:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.0.0:rc2`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.0.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.0.2`,
        fs:  `cpe:2.3:h:lexmark:cs720de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.0.4`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.1.0`,
        fs:  `cpe:2.3:a:opera:opera_browser:4.00:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.1.1`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.1.2`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.2.0`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.2.1`,
        fs:  `cpe:2.3:a:ibm:tealeaf_consumer_experience:8.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.2.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.0`,
        fs:  `cpe:2.3:o:huawei:e303_modem_firmware:22.157.18.00.858:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.1`,
        fs:  `cpe:2.3:a:oracle:configurator:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.2`,
        fs:  `cpe:2.3:a:logitech:updater:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.3`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.4`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.9`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.7.9:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.10`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.11`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.12`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.13`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.14`,
        fs:  `cpe:2.3:a:apple:remote_desktop:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.15`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.16`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:2.3.18`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0`,
        fs:  `cpe:2.3:a:digia:qt:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.0:beta`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.0:beta2`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.0:beta3`,
        fs:  `cpe:2.3:o:redhat:linux:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.0:beta4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.0:rc`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.0:rc2`,
        fs:  `cpe:2.3:a:xchat:xchat:2.8.7:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.1`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62s:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.1:pre`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.2:pre`,
        fs:  `cpe:2.3:a:pocketmags:nra_journal:\@7f080181:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.3`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.4`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.4:rc`,
        fs:  `cpe:2.3:a:snitz_communications:snitz_forums_2000:3.3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.4:rc1`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.5c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.5`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.236.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.5:rc1`,
        fs:  `cpe:2.3:h:hp:procurve_router:jc150a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.6`,
        fs:  `cpe:2.3:h:cisco:catalyst_5505:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.6:rc1`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr3232l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.6:rc2`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.7`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_vsx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.7:rc1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.7:rc2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.8`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.0c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.8:rc1`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.8:rc2`,
        fs:  `cpe:2.3:a:manga_facts_project:manga_facts:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.8:rc3`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.0.0.59167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.8:rc4`,
        fs:  `cpe:2.3:a:apple:safari:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.9`,
        fs:  `cpe:2.3:h:siemens:ruggedcom_win5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.9:rc1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.9:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:test10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.9:rc3`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.9:rc4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.452.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.9:rc5`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:s5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.10`,
        fs:  `cpe:2.3:h:siemens:ccpw3025:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.10:rc1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.11`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.12`,
        fs:  `cpe:2.3:a:trillian:trillian:0.721:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.12:rc1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.13`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.13:rc1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.14`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.0.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.16`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.17`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.18`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)db1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.19`,
        fs:  `cpe:2.3:a:hp:openview_report:-:3.70:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.0.20`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0`,
        fs:  `cpe:2.3:a:akronchildrens:care4kids:1.03:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:beta1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:rc1`,
        fs:  `cpe:2.3:o:huawei:s9706_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:rc2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p297:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:rc3`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:7.1.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:rc4`,
        fs:  `cpe:2.3:a:exabot:exabot:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:rc5`,
        fs:  `cpe:2.3:a:ibm:maximo_service_desk:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:rc6`,
        fs:  `cpe:2.3:a:adobe:flash_player:26.0.0.137:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:rc7`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.0:rc8`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.30.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.1`,
        fs:  `cpe:2.3:a:amberfog:vk_amberfog:3.5.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.1:rc1`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller_enterprise_module:1.0_ga:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.1:rc2`,
        fs:  `cpe:2.3:a:juniper:junos_space:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.1:rc3`,
        fs:  `cpe:2.3:a:veritas:backup_exec:2014.1786:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.2`,
        fs:  `cpe:2.3:a:downton_abbey_fan_portal_project:downton_abbey_fan_portal:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.2:rc1`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.2:rc2`,
        fs:  `cpe:2.3:a:adobe:community_help:3.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.2rc1`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.3`,
        fs:  `cpe:2.3:a:microsoft:word_for_mac:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.4`,
        fs:  `cpe:2.3:a:peel:peel_shopping:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.4:rc1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.1.5.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.5`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.5:rc1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.15.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.6`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p232:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.8`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.9`,
        fs:  `cpe:2.3:a:shopware:shopware:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.10`,
        fs:  `cpe:2.3:a:freedownloadmanager:free_download_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.1.12`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.0`,
        fs:  `cpe:2.3:a:schneems:wicked:1.0.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.0:rc1`,
        fs:  `cpe:2.3:a:mozilla:firefox:36.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.0:rc2`,
        fs:  `cpe:2.3:a:scriptlogic:active_administrator_server:5.0.291.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.3f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.2`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.2:rc1`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.3:rc1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.3:rc2`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.4`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.8.4:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.4:rc1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.5`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.1r2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.6`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware_2007:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.7`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.7:rc1`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.8`,
        fs:  `cpe:2.3:h:hp:ce990a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.8:rc1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.8:rc2`,
        fs:  `cpe:2.3:o:xen:xen:4.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.9`,
        fs:  `cpe:2.3:a:rhq-project:rhq:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.9:rc1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.9:rc2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.9:rc3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.11`,
        fs:  `cpe:2.3:a:adobe:flash_player:12.0.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.12`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.9.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.13:rc1`,
        fs:  `cpe:2.3:a:ibm:websphere_dashboard_framework:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.13:rc2`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.15:rc3`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.16`,
        fs:  `cpe:2.3:a:checkpoint:security_gateway:r75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.17`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.18`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.21`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:3.2.22.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(55\)se5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.0:-`,
        fs:  `cpe:2.3:a:ecommercesoft:xse_shopping_cart:1.0.1495.34683:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.0:beta`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.0:rc1`,
        fs:  `cpe:2.3:a:tribiq:tribiq_cms:5.0.12c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:office:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.1:-`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.1:rc1`,
        fs:  `cpe:2.3:a:google:chrome:40.0.2214.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.1:rc2`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.1:rc3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.1:rc4`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.2:-`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.3`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.4`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.4:rc1`,
        fs:  `cpe:2.3:o:d-link:dsr-150_firmware:1.08b44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.5`,
        fs:  `cpe:2.3:a:oracle:primavera_portfolio_management:8.0.8456:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.6`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x48:d10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.6:rc1`,
        fs:  `cpe:2.3:a:sophos:enterprise_console:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.6:rc2`,
        fs:  `cpe:2.3:a:opscode:chef:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.6:rc3`,
        fs:  `cpe:2.3:a:python:python:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.7`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.13-60.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.8`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.9`,
        fs:  `cpe:2.3:a:softartisans:fileup:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.0.10:rc1`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine_for_network_attached_storage:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.0:-`,
        fs:  `cpe:2.3:a:apache:cxf:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.0:beta1`,
        fs:  `cpe:2.3:o:hp:tru64:4.0f_pk6_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.0:beta2`,
        fs:  `cpe:2.3:a:fasterxml:jackson:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.0:rc1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.0:rc2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.2`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:565:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.2:rc1`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.2:rc2`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.10.228257.2253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.2:rc3`,
        fs:  `cpe:2.3:a:oracle:industry_applications:8.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.3`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.4`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.1.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.5`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_endpoints:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.6:rc1`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.6:rc2`,
        fs:  `cpe:2.3:h:cisco:spa3102_voice_gateway_with_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.7`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.7.1`,
        fs:  `cpe:2.3:a:contenido:contendio:4.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.8`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.9:rc1`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.10:rc1`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.10:rc2`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.10:rc3`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.10:rc4`,
        fs:  `cpe:2.3:h:cisco:gss_4490_global_site_selector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.12:rc1`,
        fs:  `cpe:2.3:a:buffalotech:wer-a54g54_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.13:rc1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.14:rc1`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.14:rc2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.14.2`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.15`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.15:rc1`,
        fs:  `cpe:2.3:a:sympa:sympa:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.16`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.1.16:rc1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.0:beta1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)xa5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.0:beta2`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.0:beta3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:05-01-\/l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.0:beta4`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.0:rc1`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.0:rc2`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.0:rc3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.1:rc1`,
        fs:  `cpe:2.3:a:hp:openview_storage_data_protector:5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.1:rc2`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.1:rc3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.1:rc4`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.2`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg253a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.3:rc1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.4`,
        fs:  `cpe:2.3:a:tibco:spotfire_automation_services:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.4:rc1`,
        fs:  `cpe:2.3:a:razorcms:razorcms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.5`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.5:rc1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.5:rc2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.5.1`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.2.62.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.5.2`,
        fs:  `cpe:2.3:a:google:chrome:10.0.609.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.6:rc1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_rich_text_editor:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.7`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1030:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:4.2.7:rc1`,
        fs:  `cpe:2.3:a:spip:spip:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:5.0.0:beta1`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:5.0.0:beta1.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1058.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:5.0.0:beta2`,
        fs:  `cpe:2.3:a:ca:universal_job_management_agent:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:5.0.0:beta3`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:5.0.0:beta4`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:5.0.0:racecar1`,
        fs:  `cpe:2.3:a:apple:itunes:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:5.0.0:rc1`,
        fs:  `cpe:2.3:a:aspen:aspen:0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:ruby_on_rails:5.0.0:rc2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rubyonrails:web_console:2.1.2`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.2:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ruckuswireless:zoneflex_2942:-`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ruckuswireless:zoneflex_2942__firmware:9.6.0.0.267`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runkeeper:runkeeper_-_gps_track_run_walk:4.7::~~~android~~`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:x06ht:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtastic:runtastic_heart_rate:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.28.1913:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtastic:runtastic_me:1.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:forms:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtastic:runtastic_mountain_bike:2.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtastic:runtastic_pedometer:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtastic:runtastic_road_bike:2.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtastic:runtastic_running_%26_fitness:5.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtastic:runtastic_timer:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtime:diskexplorer_for_ntfs:3.3.12`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:runtime:driveimage_xml:2.22::~~private~~~`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf806a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rutaexacta:ruta_exacta:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:client_security:3.1.0.396:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rvappstudios:best_phone_security:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5614:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rwcinc:free_realty:3.1-0.6`,
        fs:  `cpe:2.3:a:hp:randmap:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rxspencer_project:rxspencer:3.8.g5`,
        fs:  `cpe:2.3:a:rodrigo_polo:stream_video_player:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:1.0.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.0.0`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.1:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.0.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.0.2`,
        fs:  `cpe:2.3:a:corel:painter_ica:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.0.3`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.0.4`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.0.5`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.0.6`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.1.0`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:10.2:sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.2.0`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.3.0`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.10.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:2.3.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.1.8:update14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a1`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a3`,
        fs:  `cpe:2.3:a:apache:openoffice:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a5`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a6`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a7`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a8`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a9`,
        fs:  `cpe:2.3:a:mcafee:agent:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.0.a10`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.2`,
        fs:  `cpe:2.3:a:se_html5_album_audio_player_project:se_html5_album_audio_player:1.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1049.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.0.4`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.10:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.1.0`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ryan_davis:ruby_parser:3.1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:rc.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:rzip_project:rzip:2.1`,
        fs:  `cpe:2.3:a:apppasta:aerospace_jobs:1.399:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:s-peek:s-peek_credit_rating_report:2.1.3::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3-video_project:s3-video:0.983::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(1\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3graphics:s3_graphics_utilities:3.3201.25d40-1013`,
        fs:  `cpe:2.3:a:arg0:encfs:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3graphics:s3_graphics_utilities:3.3201.25d43-0216`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3graphics:s3_graphics_utilities:3.6401.25d30-0427`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:1.17`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:1.18`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:1.18.1`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:1.19`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:2.8.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:2.9`,
        fs:  `cpe:2.3:a:redhat:rhx_enterprise_db:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:2.10`,
        fs:  `cpe:2.3:h:hp:laserjet_4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:2.10.1`,
        fs:  `cpe:2.3:a:modelisme:modelisme.com_forum\/portail:3.6.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:s3ql_project:s3ql:2.11`,
        fs:  `cpe:2.3:a:rsa:envision:4.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.3`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.4`,
        fs:  `cpe:2.3:o:cisco:dpc3939_wireless_residential_voice_gateway_firmware:130514acmcst_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.7.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.8`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.8.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.8.2`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.8.3`,
        fs:  `cpe:2.3:a:atheme:atheme:7.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.8.4`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.8.5`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.9`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:04-00-\/a:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:0.9.1`,
        fs:  `cpe:2.3:a:citrix:metaframe_conferencing_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.0`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.0.1`,
        fs:  `cpe:2.3:h:lexmark:x642:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.0.2`,
        fs:  `cpe:2.3:a:tincan:phplist:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.0.3`,
        fs:  `cpe:2.3:a:ibm:java_sdk:5.0.13.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.0.4`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.1.1`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.1.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.1.3`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1:4.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.1.4`,
        fs:  `cpe:2.3:a:webmin:usermin:1.080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.2`,
        fs:  `cpe:2.3:h:netgear:d6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.2.1`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.13:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.3`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.3.1`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.4`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.4.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.5.1`,
        fs:  `cpe:2.3:a:adobe:coldfusion_solr_service:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.5.2`,
        fs:  `cpe:2.3:o:ge:bently_nevada_3500\/22m_serial_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.5.3`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.5.4`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.5.5`,
        fs:  `cpe:2.3:o:trendnet:tew-812dru_firmware:1.0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.6`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.6.1`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.6.2`,
        fs:  `cpe:2.3:a:x:libxfixes:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.7`,
        fs:  `cpe:2.3:a:debian:toolchain-source:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.7.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:1.7.3`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.1:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:2.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:11.3\(11b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:2.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:2.0.4`,
        fs:  `cpe:2.3:a:php:php:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:2.0.5`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:s9y:serendipity:2.1:rc1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sabreairlinesolutions:crew_management:2010.2.12.20008`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sabreairlinesolutions:crew_operations:2010.2.12.20008`,
        fs:  `cpe:2.3:a:teradata:bteq:12.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sabreairlinesolutions:crew_planning:2010.2.12.20008`,
        fs:  `cpe:2.3:a:mozilla:firefox:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sabreairlinesolutions:crew_services:2010.2.12.20008`,
        fs:  `cpe:2.3:a:gnome:glib:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sabreairlinesolutions:crew_training:2010.2.12.20008`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.7-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safari_browser_project:safari_browser:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:sun:java_desktop_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safemode_project:safemode:1.2.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:ctb:asvab_preparation:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:administrative_management_center:6.0.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:luna_jsp_for_luna_sa:4.4.0::~~~~x64~`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:luna_jsp_for_luna_sa:4.4.1::~~~~x64~`,
        fs:  `cpe:2.3:a:heikki_hokkanen:viewgit:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:luna_sa_client_software:4.4.0::~~~~x64~`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:luna_sa_client_software:4.4.1::~~~~x64~`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:luna_sa_software_development_kit:4.4.1::~~~~x64~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:8.2.0`,
        fs:  `cpe:2.3:a:umich:libgssglue:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:8.2.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1057.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:8.4.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:9.0.0`,
        fs:  `cpe:2.3:a:aol:aolserver:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:9.0.3`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:9.0.7`,
        fs:  `cpe:2.3:a:google:talk:1.0.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:9.1.0`,
        fs:  `cpe:2.3:a:postfix:postfix:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:9.2.0`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:9.3.0`,
        fs:  `cpe:2.3:a:ca:license_software:1.62.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectdrive:9.4.0`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:protectpack:2.1.0.9`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x50:d30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:safenet_authentication_service_outlook_web_access_agent:1.03.20212`,
        fs:  `cpe:2.3:a:procmail:procmail:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:safenetmobile_pass:8.3.7.11::~~~android~~`,
        fs:  `cpe:2.3:a:milesj:decoda:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:sentinel_protection_installer:7.3.0`,
        fs:  `cpe:2.3:a:ca:license_software:1.63.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safenet-inc:sentinel_protection_installer:7.4.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safer-networking:spybot_search_and_destroy:-`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safer-networking:spybot_search_and_destroy:1.4`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safer-networking:spybot_search_and_destroy:1.6.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safer_networking:filealyzer:1.6.0.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.tc7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safer_networking:filealyzer:1.6.0.4::beta`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safer_networking:filealyzer:1.6.0.4:beta`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_agent:5.2.0.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:safeway:safeway:4.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:formnage:cutprice:1.0.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:saflink:argus:2.1.18`,
        fs:  `cpe:2.3:a:melodigram:melodigram:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:saflink:fortezza:50.1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saflink:netsign_cac:-`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sage:sage_timesheet:9.85.1`,
        fs:  `cpe:2.3:a:bernhard_wymann:torcs:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sage-mozdev:sage:-`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sage-mozdev:sage:1.3.8`,
        fs:  `cpe:2.3:a:powerproduction:storyboard_quick:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sagecrm:sagecrm:7.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sagecrm:sagecrm:7.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19\)ew:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sagecrm:sagecrm:7.2`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sagecrm:sagecrm:7.3`,
        fs:  `cpe:2.3:h:nortel:vpn_gateway_3070:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sagecrm:sagecrm:7.3:sp1`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sagecrm:sagecrm:7.3:sp2`,
        fs:  `cpe:2.3:a:docker:docker:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sagelighteditor:sagelight:4.4`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sagem:f%40st_2604:-`,
        fs:  `cpe:2.3:a:xangati:xangati_software_release:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sagem:f%40st_2604_firmware:253180972b`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sagepay:sage_pay_direct_module:-`,
        fs:  `cpe:2.3:a:ibm:worklight:6.0.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd1.m0xx0:-`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd1.m0xx0_firmware:1.24.25`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd1.m2xx0:-`,
        fs:  `cpe:2.3:a:lxml:lxml:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd1.m2xx0_firmware:1.24.25`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd2.m5xx0:-`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd2.m5xx0_firmware:1.24.25`,
        fs:  `cpe:2.3:a:qbnz:geshi:1.0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd3.mxx60:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd3.mxx60_firmware:1.24.25`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd3.mxxx0:-`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd3.mxxx0_firmware:1.24.25`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd3.t665:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxd1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd3.t665_firmware:1.24.30`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd3.t666:-`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd3.t666_firmware:1.24.30`,
        fs:  `cpe:2.3:a:novell:zenworks_endpoint_security_management:3.5.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd7.d4xxd:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd7.d4xxd_firmware:1.24.41`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd7.d4xxd_svga_mb:-`,
        fs:  `cpe:2.3:a:busybox:busybox:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd7.d4xxd_svga_mb_firmware:1.24.41`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd7.d4xxv:-`,
        fs:  `cpe:2.3:o:cisco:ios:15.0sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd7.d4xxv_firmware:1.24.41`,
        fs:  `cpe:2.3:a:hp:openview_select_access:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd7.d4xxv_vga_mb:-`,
        fs:  `cpe:2.3:a:vmware:fusion:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd7.d4xxv_vga_mb_firmware:1.24.41`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.18:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd7.d4xxwtpf:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd7.d4xxwtpf_firmware:1.24.41`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd7.d4xxwtpf_wvga_mb:-`,
        fs:  `cpe:2.3:a:mysql-lite-administrator_project:mysql-lite-administrator:-:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd7.d4xxwtpf_wvga_mb_firmware:1.24.41`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:saia_burgess_controls:pcd7.d4xxxt5f:-`,
        fs:  `cpe:2.3:a:symantec:veritas_storage_foundation_for_windows:5.1.11000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:saia_burgess_controls:pcd7.d4xxxt5f_firmware:1.24.41`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saintcorporation:saintscanner:7.9`,
        fs:  `cpe:2.3:a:emery_berger:hoard:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:2.2.8`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.5.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:3.2.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a6\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:3.2.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:3.2.6`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.3:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:4.1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:4.1.5`,
        fs:  `cpe:2.3:a:cubecart:cubecart:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:5.1.1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:5.1.2`,
        fs:  `cpe:2.3:a:solarwinds:ipmonitor:8.50.1158.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:5.1.3`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:salome-platform:salome:5.1.4`,
        fs:  `cpe:2.3:a:ssh:tectia_manager:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.6.0`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.7.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.8.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.8.7`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.8.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)xy6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.8.9`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.0`,
        fs:  `cpe:2.3:h:hp:inkjet_2250_tn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.2`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.3.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.4`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.5`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.6`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.7`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.8`,
        fs:  `cpe:2.3:h:cisco:catalyst_3900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.9.9`,
        fs:  `cpe:2.3:a:otrs:faq:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.10.0`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.10.2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.10.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.10.4`,
        fs:  `cpe:2.3:a:david_king:vino:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.10.5`,
        fs:  `cpe:2.3:h:polycom:viewstation_sp_384:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.11.0`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.12.0`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-855_firmware:t100sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.13.0`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.14.0`,
        fs:  `cpe:2.3:a:ibm:b2b_advanced_communications:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.15.0`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.7.0:06:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.15.1`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.16.0`,
        fs:  `cpe:2.3:a:apache:tomcat:3.3.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.16.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.16.3`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.13:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.16.4`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.17.0`,
        fs:  `cpe:2.3:a:kingsoft:office_2012:8.1.0.3385:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:0.17.1`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:9.2:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt:2014.1.9`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.135:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt_2015:5.0`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt_2015:5.1`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt_2015:5.2`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:22-11-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt_2015:5.3`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.15.4725:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt_2015:5.4`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.50.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt_2015:5.5`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saltstack:salt_2015:8.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:jitterbug:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:jitterbug:1.6.2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:ppp:-`,
        fs:  `cpe:2.3:o:blackberry:blackberry_os:10.1.0.2312:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:ppp:2.4.1`,
        fs:  `cpe:2.3:h:3com:3c16811-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:ppp:2.4.4`,
        fs:  `cpe:2.3:a:digia:qt:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:ppp:2.4.6`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:ppp:2.4.7`,
        fs:  `cpe:2.3:a:sawmill:sawmill:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:rsync:3.0.8`,
        fs:  `cpe:2.3:a:batavi:batavi:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:rsync:3.0.9`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:rsync:3.1.0`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:rsync:3.1.1:pre1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:-`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.17`,
        fs:  `cpe:2.3:a:tryton:tryton:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.17:p1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.17:p2`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.17:p3`,
        fs:  `cpe:2.3:a:citrix:presentation_server_document_center:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.17:p4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.17:p5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.5\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p1`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p10`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp1:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p2`,
        fs:  `cpe:2.3:h:hp:jf430c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p3`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p4`,
        fs:  `cpe:2.3:a:exim:exim:3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p5`,
        fs:  `cpe:2.3:a:perl:perl:5.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p6`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:-:pre6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p7`,
        fs:  `cpe:2.3:h:polycom:hdx_8002:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:1.9.18:p8`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.1.1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2009.312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.0`,
        fs:  `cpe:2.3:a:castech:ezccid_smart_card_reader_setup_for_windows_2000_xp_2003:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.1`,
        fs:  `cpe:2.3:a:atheme:atheme:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.2`,
        fs:  `cpe:2.3:a:ibm:workload_deployer:3.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.3`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.4`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.5`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.5:a`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.5a`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.6`,
        fs:  `cpe:2.3:a:hummingbird:exceed:6.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.7`,
        fs:  `cpe:2.3:a:mozilla:firefox:47.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.8`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.9`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.0.8223:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.0.10`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2:a`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.0`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.0:a`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.40.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.0a`,
        fs:  `cpe:2.3:a:op5:monitor:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.1`,
        fs:  `cpe:2.3:a:apache:activemq:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.1:a`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.1a`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5\(1\)su4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.3`,
        fs:  `cpe:2.3:a:opnet:license_server:16.1.0.10834:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.3:a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.3a`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.4`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.27-25.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.5`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(14\)gs2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.6`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.7`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.7:a`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.7a`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.8`,
        fs:  `cpe:2.3:a:ibm:soliddb:4.5.167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.8:a`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.8a`,
        fs:  `cpe:2.3:a:ibm:sterling_secure_proxy:3.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.9`,
        fs:  `cpe:2.3:a:google:chrome:12.0.727.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.10`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.979:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.11`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:7.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2.12`,
        fs:  `cpe:2.3:a:anshul_sharma:category-grid-view-gallery:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.2a`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:2.18.3`,
        fs:  `cpe:2.3:a:apache:mod_python:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0`,
        fs:  `cpe:2.3:a:openstack:neutron:2012.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.2`,
        fs:  `cpe:2.3:a:debian:sympa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.2:a`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.2a`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.1.5:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.3`,
        fs:  `cpe:2.3:h:virtualaccess:gw6110a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.4:rc1`,
        fs:  `cpe:2.3:o:engardelinux:secure_community:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.5`,
        fs:  `cpe:2.3:a:nmh:nmh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.6`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.023.20056:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.7`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.13.125662.579:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.8`,
        fs:  `cpe:2.3:a:efstechnology:autoform_pdm_archive:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.9`,
        fs:  `cpe:2.3:a:ubi:uplay_pc:4.5.2.3010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.10`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.11`,
        fs:  `cpe:2.3:a:batavi:batavi:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.12`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:248:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.13`,
        fs:  `cpe:2.3:a:shopware:shopware:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.14`,
        fs:  `cpe:2.3:a:cutesite:cutesite_cms:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.14:a`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.14a`,
        fs:  `cpe:2.3:a:martinicreations:passmanlite_password_manager:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.15`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.317:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.16`,
        fs:  `cpe:2.3:a:phplist:phplist:2.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.17`,
        fs:  `cpe:2.3:a:macromedia:jrun:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.19`,
        fs:  `cpe:2.3:o:yahama:rtx3000:9.00.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.20`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.20:a`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.20:b`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.9:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.20a`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.16:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.20b`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.21`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12\)da8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.21:a`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.21:b`,
        fs:  `cpe:2.3:a:loli_chocolate_cake_project:loli_chocolate_cake:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.21:c`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.21a`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.21b`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.21c`,
        fs:  `cpe:2.3:a:netiq:edirectory:8.8.6.4:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.22`,
        fs:  `cpe:2.3:h:hp:laserjet_cm3530_multifuction_printer:cc519a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23:a`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23:b`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23:c`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23:d`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23a`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23b`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23c`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)mc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.23d`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.24`,
        fs:  `cpe:2.3:a:vips:vips:7.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25:a`,
        fs:  `cpe:2.3:a:core-apps:vmware_vforums_2014:6.0.9.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25:b`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25:c`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25:pre1`,
        fs:  `cpe:2.3:a:interactivedata:esignal:10.6.2425:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25:pre2`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.2:*:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25:rc1`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25:rc2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25:rc3`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.7.0\(190\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25a`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25b`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.25c`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.26`,
        fs:  `cpe:2.3:a:citrix:cloudplatform:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.26:a`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.26a`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.27`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.5.0:m3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.27:a`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.28`,
        fs:  `cpe:2.3:o:cisco:ios:11.3da:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.28:a`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.29`,
        fs:  `cpe:2.3:a:debian:kde4libs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.30`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p19:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.31`,
        fs:  `cpe:2.3:o:nec:up-ux_v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.32`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.33`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.34`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.35`,
        fs:  `cpe:2.3:a:git-scm:git:2.2.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.36`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.0.37`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53_94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.1`,
        fs:  `cpe:2.3:a:e107:e107:0.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.1.0`,
        fs:  `cpe:2.3:a:sagecrm:sagecrm:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.2`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.3`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.322:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.6`,
        fs:  `cpe:2.3:a:hp:status:110.0.180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.7`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.69:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.8`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.9`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.10`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.27.1900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.11`,
        fs:  `cpe:2.3:h:cisco:catalyst_2920:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.12`,
        fs:  `cpe:2.3:a:walrus_digit:walrack:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.13`,
        fs:  `cpe:2.3:a:mutiny:standard:4.4-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.14`,
        fs:  `cpe:2.3:a:logitech:mvision:11.0.1218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.2.15`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.0`,
        fs:  `cpe:2.3:a:pixman:pixman:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.1`,
        fs:  `cpe:2.3:o:cisco:edge_340_firmware:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.2`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.3.1:build1013110726.09:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.3`,
        fs:  `cpe:2.3:a:qlogic:sansurfer_fc_hba_manager:2.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.4`,
        fs:  `cpe:2.3:a:iss:blackice_agent:3.1ebh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.5`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.3:p1-beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.7`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.8`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.9`,
        fs:  `cpe:2.3:h:supermicro:x9dbu-3f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.10`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.11`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.13`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.14`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20100617:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.15`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.3.16`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.0`,
        fs:  `cpe:2.3:a:microsoft:clip_art:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.1`,
        fs:  `cpe:2.3:a:redhat:spacewalk-java:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.7`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.8`,
        fs:  `cpe:2.3:a:x:libxv:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.9`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.14:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.10`,
        fs:  `cpe:2.3:a:hp:proliant_ilo_management_controller_package:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.11`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.61:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.12`,
        fs:  `cpe:2.3:h:compal_broadband_networks:ch664oe_wireless_gateway:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.13`,
        fs:  `cpe:2.3:a:cisco:content_security_management_virtual_appliance:8.4.0.0150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.14`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.15`,
        fs:  `cpe:2.3:a:apache:subversion:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.16`,
        fs:  `cpe:2.3:h:juniper:netscreen-5gt:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.4.17`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.11.1:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.1`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.2`,
        fs:  `cpe:2.3:h:dell:latitude_e6320:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.3`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a1\(7a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_2d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.5`,
        fs:  `cpe:2.3:a:symantec:mail_security:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.6`,
        fs:  `cpe:2.3:a:google:chrome:17.0.958.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.7`,
        fs:  `cpe:2.3:h:thecus:n8800_nas_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.8`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.9`,
        fs:  `cpe:2.3:h:hp:laserjet_m5025_mfp:q7840a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.10`,
        fs:  `cpe:2.3:a:livetecs:timeline:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.11`,
        fs:  `cpe:2.3:a:schneider-electric:somachine:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.12`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.13`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.14`,
        fs:  `cpe:2.3:h:cisco:nexus_7000_10-slot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.15`,
        fs:  `cpe:2.3:a:buffalotech:wzr-g144nh_firmware:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.16`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.17`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.18`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.19`,
        fs:  `cpe:2.3:a:hp:laserjet_fonts:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.20`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.21`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.5.22`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.07.4369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.1`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.3`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.4`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.95:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.5`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h:10.74:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.6`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.7\(1.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.8`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.9`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.10`,
        fs:  `cpe:2.3:a:hp:photo_and_imaging_software:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.11`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.12`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.13`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.14`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.15`,
        fs:  `cpe:2.3:o:gehealthcare:optima_ct680_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.16`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.17`,
        fs:  `cpe:2.3:a:opentext:livelink_webdav:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.18`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.5.1077:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.19`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1040:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.20`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.21`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p336:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.22`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.10.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.23`,
        fs:  `cpe:2.3:a:gnu:cpio:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.24`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:3.6.25`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.1`,
        fs:  `cpe:2.3:a:logitech:audio_echo_cancellation_component:10.40.1401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.3`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.4`,
        fs:  `cpe:2.3:a:luracast:restler:1.2.12:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.5`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.6`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.4-143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.7`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.16:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.8`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.9`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.10`,
        fs:  `cpe:2.3:a:perl:perl:5.12.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.11`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.03.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.12`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.13`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.14`,
        fs:  `cpe:2.3:a:apache:solr:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.15`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.16`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.17`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.613:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.18`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.19`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.20`,
        fs:  `cpe:2.3:a:revive-adserver:revive_adserver:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.21`,
        fs:  `cpe:2.3:a:microsoft:isa_server:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.22`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.23`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.24`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-28c-pwr-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.25`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.0.26`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p358:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.1`,
        fs:  `cpe:2.3:a:altiris:deployment_solution:6.9.174:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1040.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.4`,
        fs:  `cpe:2.3:a:peel:peel_shopping:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.5`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp2:media_center:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.6`,
        fs:  `cpe:2.3:a:allqoranvideos:koran_-_alqoranvideos:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.7`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller:3.2.116.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.8`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.9`,
        fs:  `cpe:2.3:o:samsung:samsung_mobile:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.10`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.11`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.12`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.13`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.14`,
        fs:  `cpe:2.3:a:openstack:cinder:2013.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.15`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.16`,
        fs:  `cpe:2.3:h:avaya:cajun_p882:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.17`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.18`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.19`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:10.0.12.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.20`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.21`,
        fs:  `cpe:2.3:a:cisco:nac_agent:4.8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.22`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.1.23`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.0:rc1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.0:rc2`,
        fs:  `cpe:2.3:a:mbtcreations:atkins_diet_free_shopping_list:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.0:rc3`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.8.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.0:rc4`,
        fs:  `cpe:2.3:a:dell:openmanage_client_instrumentation:8.0.1.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.1`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.2`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.3`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc3310:a9863a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.5`,
        fs:  `cpe:2.3:a:oracle:universal_work_queue:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.6`,
        fs:  `cpe:2.3:o:ibm:os2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.7`,
        fs:  `cpe:2.3:a:sun:openoffice.org:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.8`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.9`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_enterprise_http_option:1.3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.10`,
        fs:  `cpe:2.3:a:oracle:retail_applications:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.11`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.12`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.13`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.2.14`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.2`,
        fs:  `cpe:2.3:a:microsoft:psinfo:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.3`,
        fs:  `cpe:2.3:h:buffalotech:wzr-ampg300nh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.4`,
        fs:  `cpe:2.3:a:sun:openoffice.org:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.5`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.6`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.7`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.8`,
        fs:  `cpe:2.3:a:wali:walisms_cn:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.9`,
        fs:  `cpe:2.3:h:cisco:rvs4000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.10`,
        fs:  `cpe:2.3:a:otrs:otrs:2.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.3.11`,
        fs:  `cpe:2.3:a:qualys:qualyssuite:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.0:rc1`,
        fs:  `cpe:2.3:a:sympa:sympa:5.0a.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.0:rc2`,
        fs:  `cpe:2.3:a:john_albin:zen:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.0:rc3`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.0:rc2:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1272.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.3`,
        fs:  `cpe:2.3:a:microsoft:data_access_components:2.1.1.3711.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.4`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:5.0\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.14`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix_5570_controller_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba:4.4.15`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba:samba_server:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba-tng:samba-tng:-`,
        fs:  `cpe:2.3:a:haxx:curl:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba-tng:samba-tng:0.3`,
        fs:  `cpe:2.3:a:netfilter:libmnl:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samba-tng:samba-tng:0.3.1`,
        fs:  `cpe:2.3:h:saia_burgess_controls:pcd7.d4xxv_vga_mb:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:-`,
        fs:  `cpe:2.3:a:authentium:command_antivirus:5.2.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:4.1`,
        fs:  `cpe:2.3:a:logitech:vid_hd:7.2_\(7248\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:4.1:beta`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:4.2:beta7`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:4.3`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:4.3:beta9`,
        fs:  `cpe:2.3:a:apple:itunes:10.4.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:4.4`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.54:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:4.4:beta3`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.0`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(8\)gdr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.0:beta1`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.0:beta2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.0:beta3`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.0:beta4`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.0:beta5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.0:beta6`,
        fs:  `cpe:2.3:a:phpspot:php_bbs_image_capture:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.1`,
        fs:  `cpe:2.3:a:bitcricket:ip_calculator:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.1:beta1`,
        fs:  `cpe:2.3:a:cisco:ip_call_center_express_standard:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.1:beta2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.1:beta3`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.1:beta4`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.99.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.1:beta5`,
        fs:  `cpe:2.3:a:linecorp:line\@:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.2`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.2:beta2`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.2:beta3`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:5.3`,
        fs:  `cpe:2.3:a:schneems:wicked:0.3.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.0`,
        fs:  `cpe:2.3:a:apache:archiva:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.0:beta1`,
        fs:  `cpe:2.3:h:hp:a2w79a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.0:beta3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.0:beta4`,
        fs:  `cpe:2.3:a:adobe:pdf_library_sdk:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.0:beta5`,
        fs:  `cpe:2.3:a:apache:camel:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.1:beta2`,
        fs:  `cpe:2.3:a:otrs:otrs:0.5:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.2`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.3:beta2`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sambar:sambar_server:6.4`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samedia:landshop:0.9.2`,
        fs:  `cpe:2.3:o:cisco:ios:11.1ct:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.1.0`,
        fs:  `cpe:2.3:a:aol:dailyfinance_-_stocks_\&amp;_news:2.0.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.1.3`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.1.5`,
        fs:  `cpe:2.3:a:clutter_project:clutter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2`,
        fs:  `cpe:2.3:o:sun:sunos:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2.1`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2.2`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2.4`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2.5`,
        fs:  `cpe:2.3:a:qemu:qemu:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2.7`,
        fs:  `cpe:2.3:h:siemens:synco_ozw_web_server:ozw772.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2.8`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.2.9`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.3.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.29:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.3.1`,
        fs:  `cpe:2.3:a:microsoft:pskill:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.3.2`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.3.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.3.5`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.3.6`,
        fs:  `cpe:2.3:a:tibco:spotfire_automation_services:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:1.4.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.0`,
        fs:  `cpe:2.3:a:call-cc:chicken:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.0:alpha`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.4:rc2:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.0:beta`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.0:rc1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.0:rc2`,
        fs:  `cpe:2.3:a:cisco:rv042g_dual_gigabit_wan_vpn_firmware:4.2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.0:rc3`,
        fs:  `cpe:2.3:a:zenprise:zenprise_device_manager:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.1`,
        fs:  `cpe:2.3:a:drupal:drupal:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.1:rc3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.413:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.3`,
        fs:  `cpe:2.3:a:oracle:iprocurement:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.0.4`,
        fs:  `cpe:2.3:a:adobe:connect:9.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.1.0`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.1.1`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samlify_project:samlify:2.2.0`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:chromebox_3:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:dvr:-`,
        fs:  `cpe:2.3:a:hp:ocr_software_by_i.r.i.s:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:galaxy_note_2:-`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:galaxy_s:-`,
        fs:  `cpe:2.3:a:go-text:text_me\!_free_texting_\&amp;_call:2.5.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:galaxy_s2:-`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:galaxy_s4:-`,
        fs:  `cpe:2.3:a:microstrategy:microstrategy_office:9.2.200.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:galaxy_s4_mini:-`,
        fs:  `cpe:2.3:a:isc:bind:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:galaxy_s5:-`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:galaxy_s6:-`,
        fs:  `cpe:2.3:h:huawei:wlan_ac_6605:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:ipolis_device_manager:1.8.2`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2013-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:ipolis_device_manager:1.8.7`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:kies:2.3.2.12074`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.2.1_a:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:kies:2.3.2.12074_13_13`,
        fs:  `cpe:2.3:a:ibm:tivoli_management_framework:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:masetupcaller_activex_control:1.4.2012.508`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:ml-85g_gdi_printer_driver:-`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.1.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:ml-85p_printer_driver:-`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.3.3b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:ml-85p_printer_driver:1.0`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_server:12:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:net-i_viewer:1.37`,
        fs:  `cpe:2.3:a:isc:bind:9.4:r5:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:net-i_viewer:1.38`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0-beta3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:printer_firmware:20121031`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization_manager:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:ps50c7700_television:-`,
        fs:  `cpe:2.3:a:iconics:webhmi:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:ps50c7700_television_firmware:-`,
        fs:  `cpe:2.3:h:lexmark:c77x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:samsung_mobile:4.4`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:samsung_mobile:5.0`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(4\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:samsung_mobile:5.1`,
        fs:  `cpe:2.3:a:hp:aserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:samsung_mobile:6.0`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:samsung_mobile:7.0`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:samsung_mobile:7.1`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.0.2:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:samsung_mobile:7.1.1`,
        fs:  `cpe:2.3:a:pootlepress:pootle_button:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:samsung:samsung_mobile:7.1.2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:samsung_monsetup:1.0.0`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:447:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:samsung_security_manager:1.30`,
        fs:  `cpe:2.3:a:sun:java_virtual_machine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:scx-4200_driver:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:scx-4200_driver:2.00.95`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:series_5_550_chromebook:-`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:series_5_chromebook:-`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:shr-5082:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:samsung:shr-5162:-`,
        fs:  `cpe:2.3:a:google:v8:3.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:smart_viewer:-`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:smartviewer:-`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0553:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:samsung:web_viewer:1.0.0.193`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sandisk:u3launcher:1.0.0`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sane-backends_project:sane-backends:1.0.25`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sanriodigital:hello_kitty_cafe:1.4.0::~~~android~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.13:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:santafox:santafox:2.02`,
        fs:  `cpe:2.3:h:axis:2400_video_server:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:santanderbank:santander_personal_banking:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:hp:bufferchm:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:santiagosarceda:elforro.com:2.4.3.10::~~~android~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:3d_visual_enterprise_viewer:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.2.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:activex_viewer:1.0.0`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:p10-0038:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:adminadapter:-`,
        fs:  `cpe:2.3:a:avsmedia:dvd_player:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:afaria:7.0`,
        fs:  `cpe:2.3:a:jffnms:just_for_fun_network_management_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:afaria:7.0.6001.5`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2011-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:afaria:7.0.6398.0`,
        fs:  `cpe:2.3:a:cisco:1000v_virtual_ethernet_module_\(vem\):4.0\(4\):sv1\(1\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:afaria:7.0.6620.2:sp5`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:background_processing:-`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:basis_communication_services:4.6:b`,
        fs:  `cpe:2.3:a:ca:adviseit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:basis_communication_services:7.30`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:bi_universal_data_integration:-`,
        fs:  `cpe:2.3:a:vips:vips:7.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:business_object_processing_framework_for_abap:-`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:business_one_2005-a:6.80.123`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:business_one_2005-a:6.80.320`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.3001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:businessobjects:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.17:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:businessobjects:4.0`,
        fs:  `cpe:2.3:a:lxml:lxml:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:businessobjects_edge:4.0`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:businessobjects_explorer:14.0.5`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:businessobjects_xi:3.1`,
        fs:  `cpe:2.3:a:adobe:after_effects:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:businessobjects_xi:r2`,
        fs:  `cpe:2.3:h:lacie:lac9000436u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:ccms_%2f_database_monitor:-::~~~oracle~~`,
        fs:  `cpe:2.3:h:antlabs:inngate_ig_3100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:ccms_agent:-`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:cm_services:-`,
        fs:  `cpe:2.3:a:apache:subversion:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:cms_services:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.10:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:commoncryptolib:8.4.29`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:crystal_enterprise_xi:3.1:fp_3.1`,
        fs:  `cpe:2.3:a:blackberry:blackberry_universal_device_service:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:crystal_enterprise_xi:3.1:fp_3.4`,
        fs:  `cpe:2.3:a:apache:camel:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:crystal_enterprise_xi:3.1:fp_3.5`,
        fs:  `cpe:2.3:a:apache:struts:2.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:crystal_enterprise_xi_client_tools:3.1:fp_3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:crystal_enterprise_xi_client_tools:3.1:sp3`,
        fs:  `cpe:2.3:a:oracle:http_server:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:crystal_reports:-`,
        fs:  `cpe:2.3:a:isc:bind:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:crystal_reports_basic_for_visual_studio:10.5.0.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:crystal_reports_for_visual_studio:12.51.0.240`,
        fs:  `cpe:2.3:a:oracle:application_server:1.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:customer_relationship_management:7.02:ehp2`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:download_manager:1.1.3.0`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd_dx:8.2.5024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:ecl_viewer:6.0`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:emr_unwired:-:-:~--~-~iphone_os~~`,
        fs:  `cpe:2.3:o:suse:suse_linux:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:enhancement_package:6.0`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.8:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:enterprise_central_component:-`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:enterprise_portal:-`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:enterprise_resource_planning:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:erp:6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yd6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:erp_central_component:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:fi_manager_self-service:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:gui:6.4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:gui:7.2`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.1.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:gui_for_windows:7.20_compilation_2`,
        fs:  `cpe:2.3:a:ibm:tivoli_service_request_manager:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:guided_procedures_archive_monitor:-`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hana:-`,
        fs:  `cpe:2.3:a:cisco:unified_cdm_application_software:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hana_extend_application_services:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.0.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(13\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.0.3.3`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.0.4.4`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.0.4.10`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.1.0.1`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.1.0.10`,
        fs:  `cpe:2.3:a:google:chrome:5.0.364.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.1.1.2`,
        fs:  `cpe:2.3:a:miura:ubercart_bulk_stock_updater:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.1.1.11`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.2.0.3`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:beta3:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.2.0.12`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.2.0.13`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.3.0.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_2902:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.3.0.9`,
        fs:  `cpe:2.3:a:realtimesoft:zenview_manager:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.3.0.10`,
        fs:  `cpe:2.3:a:sdo:youni_sms:2.1.0:d:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.4.0.10`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.5.0.8`,
        fs:  `cpe:2.3:h:celsian:celsian_bridge_g450:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.5.0.9`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.5.1.9`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.5.1.10`,
        fs:  `cpe:2.3:a:vmware:workstation_pro:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.6.0.7`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.6.0.10`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.18.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.7.0.8`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager_for_vmware:6.3:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:5.7.0.14`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:hybris:6.0`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:j2ee_engine:-`,
        fs:  `cpe:2.3:a:op5:system-portal:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:mmc_snapin:7.10.30088`,
        fs:  `cpe:2.3:a:hp:cuetour:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:mmc_snapin:7.10.30109`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:mmc_snapin:7.20.30038`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:mobile_infrastructure:-`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:mobile_platform:2.3`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:mobile_platform:3.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:-`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:4.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:6.4`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.0`,
        fs:  `cpe:2.3:a:cisco:webex_meeting_center:base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.0:ehp1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.4.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.0:ehp2`,
        fs:  `cpe:2.3:a:hp:data_protector_media_operations:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.0:ehp3`,
        fs:  `cpe:2.3:a:snort:snort:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.0:sp15`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(11\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.0:sp8`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.01`,
        fs:  `cpe:2.3:a:x:libxfixes:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.02`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.03`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.3:ehp1`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.166:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.5`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.10`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.20`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.30`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.31`,
        fs:  `cpe:2.3:a:polkit_project:polkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver:7.40`,
        fs:  `cpe:2.3:o:openvas:greenbone_security_assistant:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_abap:7.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_abap:7.02:sp6`,
        fs:  `cpe:2.3:a:python:python:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_abap:7.03:sp4`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_abap:7.31`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.46.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_business_client:-`,
        fs:  `cpe:2.3:a:redhat:up2date:3.0.7-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_business_client_for_html:3.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_business_warehouse:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p468:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_development_infrastructure:-`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_enterprise_portal:7.31`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.400.501:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_exchange_infrastructure_%28bc-xi%29:-`,
        fs:  `cpe:2.3:a:gnu:groff:1.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_java_application_server:-`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_logviewer:6.30:-:~-~-~windows~~`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04:sp15`,
        fs:  `cpe:2.3:h:symantec:security_information_manager_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04:sp16`,
        fs:  `cpe:2.3:h:cisco:ids_4250_xl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04:sp17`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(3\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04:sp18`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04:sp19`,
        fs:  `cpe:2.3:a:apple:itunes:7.3.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04s:sp7`,
        fs:  `cpe:2.3:a:apple:apple_tv:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04s:sp8`,
        fs:  `cpe:2.3:a:mozilla:firefox:45.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04s:sp9`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04s:sp10`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_nw04s:sp11`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)yb4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_software_lifecycle_manager:7.1`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.8:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_solution_manager:7.0`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:netweaver_solution_manager:7.1`,
        fs:  `cpe:2.3:a:humhub:humhub:1.0.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:network_interface_router:7.30`,
        fs:  `cpe:2.3:a:sas:client_connection_profile_configuration:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:network_interface_router:39.3:sp4`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:print_and_output_management:-`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:17.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:production_planning_and_control:-`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:2.0.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:profile_maintenance:-`,
        fs:  `cpe:2.3:a:clamav:clamav:0.80:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:router:710:029`,
        fs:  `cpe:2.3:a:montala:resourcespace:2.2.1240:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:router:720:411`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:router:721:117`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:16.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sap_kernel:7.00::~~~~x86~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sap_kernel:7.40::~~~~x64~`,
        fs:  `cpe:2.3:a:busybox:busybox:0.43:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sap_netweaver_application_server_java:-`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sapcryptolib:5.555.37`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sapseculib:-`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:software_deployment_manager:-`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:-`,
        fs:  `cpe:2.3:o:wdc:my_net_firmware:1.03.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.1`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x47:d20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.1:sp10`,
        fs:  `cpe:2.3:a:samba:rsync:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.1:sp12`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/g:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.1:sp14`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.1:sp5`,
        fs:  `cpe:2.3:a:perl:perl:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.2`,
        fs:  `cpe:2.3:a:nucleustechnologies:kernel_for_ost_to_pst:10.10.1:*:*:*:evaluation:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.2:sp01`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.2:sp03`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.20`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.20:sp01`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.20:sp03`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.50a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:solution_manager:7.31`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sql_anywhere:-`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.28:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sql_anywhere:11.0`,
        fs:  `cpe:2.3:a:a9tech:a9cad:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sql_anywhere:16.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sql_anywhere:17.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p429:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:supplier_relationship_management:-`,
        fs:  `cpe:2.3:a:hl7:c-cda:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:sybase_unwired_platform_online_data_proxy:-`,
        fs:  `cpe:2.3:a:erlang:crypto:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:trex:7.10:revision_63`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.2.3sr2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:xi_3.1_integration_for_sap_solutions_applications:12.3.0.601:sp3`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.2\(1\)_es65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sap:xi_3.1_integration_for_sap_solutions_applications:12.3.5.925:fp_3.5`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sapien:primalscript:4.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gnu:automake:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sapien:primalscript:2009`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:base_sas:9.2:ts2m`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:base_sas:9.3:ts1m1`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:beta14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:base_sas:9.3:ts1m2`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:base_sas:9.4:ts1m0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.22:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:client_connection_profile_configuration:9.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:deployment_tester:1.3`,
        fs:  `cpe:2.3:a:kde:koffice:2.3:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:deployment_tester_client:1.3`,
        fs:  `cpe:2.3:a:inline_entity_form_project:inline_entity_form:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:intelligence_platform_object_framework:9.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:jmp:9.0`,
        fs:  `cpe:2.3:a:hp:savedtoolsdata:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:locale_setup_manager:2.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_server_aus:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:management_console:9.2`,
        fs:  `cpe:2.3:a:bea:tuxedo:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:sas_enterprise_guide:4.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xn:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:versioned_jar_repository:9.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.831.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:visual_analytics:6.4:m1`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sas:xml_mapper:9.2`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sasync:sasync:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.07.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:satechi:smart_travel_router:1.5`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saurabh_gupta:tiny_server:1.0.5`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saurabh_gupta:tiny_server:1.1.5`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:saurabh_gupta:tiny_server:1.1.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p306:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sauter:moduweb_vision:1.5.5`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1681.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:savage_nation_mobile_web_project:savage_nation_mobile_web:0.57.13354.63350::~~~android~~`,
        fs:  `cpe:2.3:a:sympa:sympa:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:savsoft_technologies:savsoft_quiz:-`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:savysoda:wifi_free_hd:1.2`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:savysoda:wifi_free_hd:7.0`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:5.0.21`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.1`,
        fs:  `cpe:2.3:h:huawei:s5300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.2`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.4.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.3`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.4`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.5`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.6`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.7`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.8`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.8a`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.9`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.10`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.11`,
        fs:  `cpe:2.3:h:brocade:silkworm_48000_director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.12`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.13`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.2.14`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.398:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:6.5.1100`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.0`,
        fs:  `cpe:2.3:h:cisco:cache_engine_505:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.7:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.3`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:12.0.1.1738:*:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.4`,
        fs:  `cpe:2.3:a:avast:premier:11.1.2245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.5`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.6`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.7`,
        fs:  `cpe:2.3:a:western:western_federal_credit_union:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.8`,
        fs:  `cpe:2.3:a:vmware:tools:8.8.1.528992:*:*:*:netware:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.9`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:build1011110331.18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10a`,
        fs:  `cpe:2.3:o:trustix:secure_linux:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10b`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10c`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10d`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp1:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10e`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5s\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10f`,
        fs:  `cpe:2.3:a:microfocus:server:5.100.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10g`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10h`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0038:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10i`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10j`,
        fs:  `cpe:2.3:a:siemens:wincc:6.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.0.10k`,
        fs:  `cpe:2.3:a:vmware:view:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.1`,
        fs:  `cpe:2.3:a:al-ahsa_news_project:al-ahsa_news:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.1b`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.2`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:0.93.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.4`,
        fs:  `cpe:2.3:a:ibm:cognos_business_intelligence:10.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.5`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.6`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:0.25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.7`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.8`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.9`,
        fs:  `cpe:2.3:a:gnu:radius:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.10`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2000:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.11`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.6.3\(4042\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.12`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.1.14`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2`,
        fs:  `cpe:2.3:a:cobblerd:cobbler:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.1`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.2`,
        fs:  `cpe:2.3:a:posh_project:posh:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.4`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ecd:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.5`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.6`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.7`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.8`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.10`,
        fs:  `cpe:2.3:a:drupal:drupal:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.11`,
        fs:  `cpe:2.3:a:miniclip:anger_of_stick_3:1.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.12`,
        fs:  `cpe:2.3:a:netfilter:libmnl:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.13`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.14`,
        fs:  `cpe:2.3:a:crawlability:vbseo:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.15`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.16`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.17`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:7.2.18`,
        fs:  `cpe:2.3:a:incrediblepbx:incredible_pbx_11:2.0.6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0`,
        fs:  `cpe:2.3:h:symantec:nexland_isb_soho_firewall_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0:b1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0:b2`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.15.3:beta:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0:b3`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0:b4`,
        fs:  `cpe:2.3:a:cisco:unity_connection:10.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0:b5`,
        fs:  `cpe:2.3:o:apple:iphone_os:10.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0:b6`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0:b7`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.1\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.0:b8`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:4.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.2`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.5`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:11.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.6`,
        fs:  `cpe:2.3:a:spigot:pdfforge_toolbar:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.7`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.2.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.8`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.0.9`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.1`,
        fs:  `cpe:2.3:a:combodo:itop:2.0.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.4`,
        fs:  `cpe:2.3:a:google:chrome:15.0.872.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.5`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_module_for_legacy_software:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.6`,
        fs:  `cpe:2.3:o:asus:rt-ac68u_firmware:3.0.0.4.374_4887:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.7`,
        fs:  `cpe:2.3:a:adobe:acrobat_business_tools:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.8`,
        fs:  `cpe:2.3:a:atlassian:jira:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.9`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.1.10`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5:b3`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5:b4`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5:b5`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.1`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.2`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.4`,
        fs:  `cpe:2.3:a:timedoctor:timedoctor:1.4.72.3:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.5`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.6`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.3\(3\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.7`,
        fs:  `cpe:2.3:a:adobe:flash_player:14.0.0.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.8`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.5.9`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.33:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.6.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.6.1`,
        fs:  `cpe:2.3:a:1kxun:qianxun_yingshi:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.6.2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sawmill:sawmill:8.6.3`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sayakbanerjee:sticky_notes:0.2.27052012.4`,
        fs:  `cpe:2.3:a:promotic:promotic:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sayakbanerjee:sticky_notes:0.2.27052012.5`,
        fs:  `cpe:2.3:a:otrs:faq:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sayakbanerjee:sticky_notes:0.3.09062012.4`,
        fs:  `cpe:2.3:a:sun:enterprise_storage_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scadatec:modbustagserver:4.1.1.81`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scadatec:scadaphone:5.3.11.1230`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scalix:web_access:11.4.6.12377`,
        fs:  `cpe:2.3:h:securecomputing:snapgear_sg565:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scalix:web_access:12.2.0.14697`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scansoft:smart_document_scan_software:1.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:15.08.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.0`,
        fs:  `cpe:2.3:a:macromedia:contribute_publishing_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.0:pre1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.1.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.0:pre2`,
        fs:  `cpe:2.3:a:gnome:glib:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.0:rc1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.0:rc2`,
        fs:  `cpe:2.3:a:keepass:keepass:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p126:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.2`,
        fs:  `cpe:2.3:h:aten:cn8000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.3`,
        fs:  `cpe:2.3:a:apache:mod_python:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.4`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.5`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:16.05.6`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:17.02.0:pre1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:17.02.0:pre2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schedmd:slurm:17.02.0:pre3`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit-32:11.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.0.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.6.1871.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.0.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.1.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:adobe:fireworks:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.1.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.1.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.5.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.1.3::~~~ruby~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.0\(1a\)n1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.1.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-ampg_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.1.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.1.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.2.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:hp:intelligent_management_center:5.1:e0101p01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.3.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.3.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:ol-commerce_project:ol-commerce:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.3.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:ca:anti-virus_for_the_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.3.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.3.4::~~~ruby~~`,
        fs:  `cpe:2.3:o:d-link:dsr-250n_firmware:1.08b44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.4.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.5.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.6.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:0.6.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:1.0.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.12:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:1.0.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneems:wicked:1.0.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:accutech_manager:2.00.1`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0:ru5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:accutech_manager:2.00.2`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxnoc0401:-`,
        fs:  `cpe:2.3:a:staruml:staruml:5.0.2.1570:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxnoe0100:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxnoe0100h:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.481:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxnoe0110:-`,
        fs:  `cpe:2.3:a:ibm:security_directory_server:6.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxnoe0110h:-`,
        fs:  `cpe:2.3:a:apache:struts:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxnor0200:-`,
        fs:  `cpe:2.3:h:cisco:aironet_1040:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxnor0200h:-`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.0_2005.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxp342020:-`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxp342020h:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.1.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxp342030:-`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxp3420302:-`,
        fs:  `cpe:2.3:a:revive-adserver:revive_adserver:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxp3420302h:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:bmxpra0100:-`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:citectscada:7.10`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:citectscada:7.20`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.8-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:clearscada:2010:r2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:clearscada:2010:r2.1`,
        fs:  `cpe:2.3:a:ibm:forms_experience_builder:8.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:clearscada:2010:r3`,
        fs:  `cpe:2.3:a:nokia:qtdemobrowser:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:clearscada:2010:r3.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:concept:2.6:sr7`,
        fs:  `cpe:2.3:a:x:libxv:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:device_type_manager:3.1.6`,
        fs:  `cpe:2.3:a:piriform:ccleaner:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:floating_license_manager:1.0.0`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:floating_license_manager:1.4.0`,
        fs:  `cpe:2.3:a:vimbadmin:vimbadmin:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:interactive_graphical_scada_system:9.0`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:interactive_graphical_scada_system:10.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:micom_s1_studio:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:modbus_serial_driver:1.10`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:modbus_serial_driver:2.2`,
        fs:  `cpe:2.3:a:nobexrc:master_mix:3.3.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:modbus_serial_driver:3.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.163:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:modbuscommdtm_sl:2.1.2`,
        fs:  `cpe:2.3:a:jease:jease:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:modicon_m221:-`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:modicon_m221_firmware:1.1.1.5`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:modicon_m241_firmware:4.0.3.20`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:modicon_m251_firmware:4.0.3.20`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:ofs_test_client_tlxcdlfofs33:3.35`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:ofs_test_client_tlxcdltofs33:3.35`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:ofs_test_client_tlxcdluofs33:3.35`,
        fs:  `cpe:2.3:h:cisco:rv325_dual_wan_gigabit_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:ofs_test_client_tlxcdstofs33:3.35`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:ofs_test_client_tlxcdsuofs33:3.35`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:opc_factory_server:3.5.0`,
        fs:  `cpe:2.3:o:cisco:staros:17.2.0.59184:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:opc_factory_server:3.34`,
        fs:  `cpe:2.3:o:belkin:n150_f9k1009_firmware:1.00.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:opc_factory_server:3.35`,
        fs:  `cpe:2.3:a:commdevices:distributed_database_manager-odbc:4.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:pl7:4.5:sp7`,
        fs:  `cpe:2.3:a:cisco:webns:8.10.5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:powerlogic_scada:7.10`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.23:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:powerlogic_scada:7.20`,
        fs:  `cpe:2.3:h:hp:apache-based_web_server:1.3.27.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:powersuite:2.6`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:proclima:6.0.1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:proclima:6.1`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt_2012_language_pack:18.2.51.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:scada_expert_clearscada:2013:r1`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:scada_expert_clearscada:2013:r1.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:scada_expert_clearscada:2013:r1.1a`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.0\(4.101\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:scada_expert_clearscada:2013:r1.2`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:scada_expert_clearscada:2013:r2`,
        fs:  `cpe:2.3:a:irfanview:irfanview_plugins:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:sft2841:13.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:sft2841:14.0`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.03b27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:software_update_utility:1.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:software_update_utility:1.0.13`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs5:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:software_update_utility:1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:somachine:2.0`,
        fs:  `cpe:2.3:a:realflex:flexview:3.1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:somachine:3.0::~~xs~~~`,
        fs:  `cpe:2.3:a:kurzweiledu:kurzweil_1000:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:somachine:3.0:-`,
        fs:  `cpe:2.3:h:linksys:wvc11b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:somachine:3.1`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:somove:1.7`,
        fs:  `cpe:2.3:a:ibm:multi-enterprise_integration_gateway:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:tburjr900:00002dh0`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:tburjr900:00002eh0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:tburjr900:01002dh0`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:tburjr900:01002eh0`,
        fs:  `cpe:2.3:a:bean_project:bean:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:tburjr900:05002dh0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:tburjr900:05002eh0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1308.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:tburjr900:06002dh0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p143:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider-electric:tburjr900:06002eh0`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:tburjr900_firmware:3.6.0`,
        fs:  `cpe:2.3:a:commerce_ogone_project:commerce_ogone:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:tburjr900_firmware:3.6.1`,
        fs:  `cpe:2.3:a:apache:struts:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:tburjr900_firmware:3.6.2`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2014-05-05c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:tburjr900_firmware:3.6.3`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:telvent_sage_3030_firmware:c3413-500-001d3_p4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.396:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider-electric:telvent_sage_3030_firmware:c3413-500-001f0_pb`,
        fs:  `cpe:2.3:a:goodiware:goodreader:2.8:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:twidosuite:2.31.04`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:u.motion_builder:1.2.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:unity_pro:6.0`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:unity_pro:7.0`,
        fs:  `cpe:2.3:a:serf_project:serf:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:unity_pro:11.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:unityloader:2.3`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:vampset:2.2.145`,
        fs:  `cpe:2.3:h:grandstream:gxv3501:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:vijeo_citect:7.10`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:vijeo_citect:7.20`,
        fs:  `cpe:2.3:a:cisco:meetingplace_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:wonderware_intouch_access_anywhere_server:10.6`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:wonderware_intouch_access_anywhere_server:11.0`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.02:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider-electric:wonderware_system_platform:2014:r2`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider_electric:indusoft_web_studio:7.1:sp3`,
        fs:  `cpe:2.3:a:ibm:tivoli_endpoint_manager_mobile_device_management:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:sage_1410:-`,
        fs:  `cpe:2.3:a:apache:tomcat_jk_web_server_connector:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:sage_1430:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:sage_1450:-`,
        fs:  `cpe:2.3:a:apache:commons_email:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:sage_2300:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:sage_2400:-`,
        fs:  `cpe:2.3:a:mobitrips:dubrovnik_guided_walking_tours:1.3.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:sage_3030m:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p399:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:sage_landac_ii-2:-`,
        fs:  `cpe:2.3:a:php:php:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:struxureware_building_operations_automation_server_as:-`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schneider_electric:struxureware_building_operations_automation_server_as-p:-`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5808:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider_electric:struxureware_building_operations_automation_server_as-p_firmware:1.7`,
        fs:  `cpe:2.3:a:gnome:evolution:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider_electric:struxureware_building_operations_automation_server_as_firmware:1.7`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.819:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider_electric:telvent_rtu_firmware:c3413-500-001d3`,
        fs:  `cpe:2.3:a:avantar:white_\&amp;_yellow_pages:5.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:schneider_electric:telvent_rtu_firmware:c3414-500-s02j1`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.0.42:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schneider_electric:wonderware_intouch_2014:7.1:sp3:~~machine~~~`,
        fs:  `cpe:2.3:a:ca:investigation_tool:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:school_administration_project:school_administration:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:school_administration_project:school_administration:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:school_administration_project:school_administration:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:school_administration_project:school_administration:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.39.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:school_administration_project:school_administration:7.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:citrix:xenappprep:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:school_administration_project:school_administration:7.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schoolmation:schoolmation:2.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.24:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schoolmation:schoolmation:2.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schoolmation:schoolmation:2.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:schoolmation:schoolmation:2.3`,
        fs:  `cpe:2.3:h:hp:laserjet_2600c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:schrack:technik_microcontrol:-`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schrack:technik_microcontrol_firmware:1.7.0`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:schrack:technik_microcontrol_firmware:1.7.0%28937%29`,
        fs:  `cpe:2.3:a:google:chrome:4.0.289.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scientificlinux:luci:0.26.0`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:scientificlinux:scientificlinux:6.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:scientificlinux:scientificlinux:6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3za:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:scientificlinux:scientificlinux:6.2`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:scientificlinux:scientificlinux:6.3`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:scientificlinux:scientificlinux:6.4`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:scientificlinux:scientificlinux:6.5`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:17.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:2.6`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:2.7`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:3.0`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:3.1.1`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:4.0`,
        fs:  `cpe:2.3:a:fortinet:forticlient:5.2.3.091:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:4.1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:4.1.1`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-655:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:4.1.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.0`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.0.1`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.0.2`,
        fs:  `cpe:2.3:a:samba:samba:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.0.3`,
        fs:  `cpe:2.3:a:sierrawireless:sierra_wireless_ac595_firmware_update_package:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.1`,
        fs:  `cpe:2.3:a:bmc:batch_impact_manager:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.1.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.2.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.2.1`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.7:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scilab:scilab:5.2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ya:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_reynen:node_embed:6.x-1.0`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_reynen:node_embed:6.x-1.1`,
        fs:  `cpe:2.3:a:isc:bind:9.9.9:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_reynen:node_embed:6.x-1.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_reynen:node_embed:6.x-1.3`,
        fs:  `cpe:2.3:a:google_doc_embedder_project:google_doc_embedder:2.5.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_reynen:node_embed:6.x-1.4`,
        fs:  `cpe:2.3:a:testa:online_test_management_system:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_reynen:node_embed:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:tradingandinvesting4u:bond_trading:197705:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_reynen:node_embed:7.x-1.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_reynen:node_embed:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.1`,
        fs:  `cpe:2.3:a:redhat:interchange:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.2`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.3`,
        fs:  `cpe:2.3:a:jenkins:git:2.1.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.3.1`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.4`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.5`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.6`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.3160-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.6.1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.6.2`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0:-:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.6.3`,
        fs:  `cpe:2.3:a:cisco:trust_agent:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scott_wheeler:taglib:1.7`,
        fs:  `cpe:2.3:a:x.org:libx11:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scoutmob:scoutmob_local_deals_%26_event:3.0.18::~~~android~~`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-3.15:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:script-shop24:lm_starmail_paidmail:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)mdb13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptbrasil:taboada_macronews:1.0`,
        fs:  `cpe:2.3:a:novell:edirectory:85.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scripteen:free_image_hosting_script:1.2`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scripteen:free_image_hosting_script:1.2.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3020_concentrator:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scripteen:free_image_hosting_script:2.0`,
        fs:  `cpe:2.3:o:fortinet:fortianalyzer_firmware:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scripteen:free_image_hosting_script:2.3`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scripthead:webmail_plus:-`,
        fs:  `cpe:2.3:a:tibco:spotfire_analyst:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptlogic:active_administrator_console:5.0.322.1`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptlogic:active_administrator_server:5.0.291.1`,
        fs:  `cpe:2.3:a:ibm:jdk:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptlogic:secure_copy:3.0`,
        fs:  `cpe:2.3:a:indusoft:web_studio:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptlogic:secure_copy:3.82.8`,
        fs:  `cpe:2.3:a:gnu:bash:1.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptlogic:security_explorer:6.5.1.89`,
        fs:  `cpe:2.3:a:bic_media_widget_plugin:bic_media_widget:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptlogic:sharepoint_web_services:1.0.5`,
        fs:  `cpe:2.3:a:spice_project:spice:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptsfeed:business_directory_software:-`,
        fs:  `cpe:2.3:a:red-gate:sql_doc:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptsfeed:dating_software:-`,
        fs:  `cpe:2.3:a:crear.ne.jp:al-mail32:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scriptsfeed:recipes_listing_portal:1.0`,
        fs:  `cpe:2.3:h:hp:integrated_lights-out:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:scudetto_project:scudetto:2.7::~~~android~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sddm_project:sddm:0.12.0`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sdo:youni_sms:2.1.0:c`,
        fs:  `cpe:2.3:h:hp:3com_baseline_plus_switch:2900g-28pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sdo:youni_sms:2.1.0:d`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:se_html5_album_audio_player_project:se_html5_album_audio_player:1.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:centralview_credit_risk_control:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seagate:blackarmor_nas_220:st320005lsa10g-rk`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seagate:blackarmor_nas_220:st340005lsa10g-rk`,
        fs:  `cpe:2.3:h:cisco:spa_301:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seagate:blackarmor_nas_220:stav6000100`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:seagate:blackarmor_nas_220_firmware:sg2000-2000.1331`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seagate:goflex_sattelite:-`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.40:build111016:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagate:maxtor_manager:4.2.303`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagate:seagate_manager_installer:2.1.600`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seagate:wireless_mobile_storage:-`,
        fs:  `cpe:2.3:a:apple:apple_application_support:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seagate:wireless_plus_mobile_storage:-`,
        fs:  `cpe:2.3:a:project-redcap:redcap:4.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.3:p1-beta`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.4:beta`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.5:beta`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:28.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.5:p1-beta`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.6:beta`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.7`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.44.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.7:beta1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.7:beta2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.7:beta3`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.7:p1`,
        fs:  `cpe:2.3:h:hp:laserjet_m2727_multifunction_printer:cb532a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.7:p2`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.8`,
        fs:  `cpe:2.3:a:hp:openview_performance_access:10.0.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.8:p1`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.9`,
        fs:  `cpe:2.3:a:apache:groovy:2.2.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.9:p1`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:7.01:-:*:*:*:hp-ux:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.10`,
        fs:  `cpe:2.3:a:hp:service_manager:9.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.3.11:p1`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:3.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.0`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.0:dev1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.0:dev2`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.0:dev3`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.1`,
        fs:  `cpe:2.3:a:unitrends:enterprise_backup:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.3`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-52c-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.4`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.5`,
        fs:  `cpe:2.3:a:vmware:vsphere_host_update_utility:4.0.0.15751:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.6`,
        fs:  `cpe:2.3:a:sun:solstice_backup:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.4.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.0`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:3.1.201:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.0:rc1`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.0:rc2`,
        fs:  `cpe:2.3:a:hp:inode_management_center_pc:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.0:rc3`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(1j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.1`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.70.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.2`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.3`,
        fs:  `cpe:2.3:a:apple:itunes:7.7.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.5`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.6`,
        fs:  `cpe:2.3:a:netartmedia:car_portal:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seagullproject:seagull:0.6.7`,
        fs:  `cpe:2.3:a:ca:brightstor_storage_resource_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seamons:net-server:-`,
        fs:  `cpe:2.3:h:supermicro:x9scd-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:0.01`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.7.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:0.02`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:7.0.1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:0.03`,
        fs:  `cpe:2.3:h:omron:ns10_hmi_terminal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:0.04`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.54:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.00`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.01`,
        fs:  `cpe:2.3:a:hp:business_process_monitor:9.3.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.02`,
        fs:  `cpe:2.3:a:combodo:itop:0.8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.03`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp2:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.04`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.05`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.06`,
        fs:  `cpe:2.3:a:mathijs_koenraadt:search_api_sorts:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.07`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.08`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_expansion_module_7915:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.09`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.10`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.11`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.12`,
        fs:  `cpe:2.3:a:hp:photosmart_printer_series:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.13`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.14`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.15`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.16`,
        fs:  `cpe:2.3:h:dell:latitude_e5420:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.17`,
        fs:  `cpe:2.3:a:intel:network_connections:15.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.18`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.18_03`,
        fs:  `cpe:2.3:a:debian:dpkg:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.18_04`,
        fs:  `cpe:2.3:a:apache:xerces2_java:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.18_05`,
        fs:  `cpe:2.3:a:servers-r-us:mysqlauction:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.19`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.20`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.21`,
        fs:  `cpe:2.3:a:google:chrome:13.0.775.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.22`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.30`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.31`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.32`,
        fs:  `cpe:2.3:o:huawei:s5720ei_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.33`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.34`,
        fs:  `cpe:2.3:a:semperfiwebdesign:all_in_one_seo_pack:2.2.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.35`,
        fs:  `cpe:2.3:a:cybozu:mailwise:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.36`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.40_01`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.41`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert_oracle_common:10.1.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.42`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.4.5.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.43`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.44`,
        fs:  `cpe:2.3:a:corel:update_manager:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.45`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.46`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.1.1.319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.47`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.48`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.49`,
        fs:  `cpe:2.3:a:apache:struts:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.50`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20150612:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.51`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.9506:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.52`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53`,
        fs:  `cpe:2.3:a:gnu:bash:2.01.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53_90`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53_91`,
        fs:  `cpe:2.3:a:microsoft:jet:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53_92`,
        fs:  `cpe:2.3:a:wpbeginner:floating_social_bar:1.1.5:*:*:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53_93`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53_94`,
        fs:  `cpe:2.3:a:adobe:photoshop:18.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53_95`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53_96`,
        fs:  `cpe:2.3:a:apache:apache-ssl:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.53_97`,
        fs:  `cpe:2.3:a:google:chrome:6.0.447.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.60`,
        fs:  `cpe:2.3:a:umn:mapserver:5.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.61`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.62`,
        fs:  `cpe:2.3:a:blackberry:qnx_software_development_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.63`,
        fs:  `cpe:2.3:a:nullsoft:winamp:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.64`,
        fs:  `cpe:2.3:h:hp:jg364a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.65`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd346a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.66`,
        fs:  `cpe:2.3:a:gnome:glib:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.67`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.68`,
        fs:  `cpe:2.3:a:studiohitori:twitrocker2_android:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.69`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.70`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.10:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.71`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.72`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.73`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.74`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_java_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.75`,
        fs:  `cpe:2.3:a:symantec:protection_engine:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.76`,
        fs:  `cpe:2.3:a:git-scm:git:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.77`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.78`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.4.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.79`,
        fs:  `cpe:2.3:o:opensuse_project:leap:42.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.800`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.03:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.801`,
        fs:  `cpe:2.3:a:erik_hjortsberg:ember:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.802`,
        fs:  `cpe:2.3:a:oracle:jdk:1.4.2_38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.803`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.804`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.805`,
        fs:  `cpe:2.3:a:vandyke:securecrt:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.806`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(15\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.807`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.808`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.810`,
        fs:  `cpe:2.3:a:teradata:data_connector:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.811`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62t:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.812`,
        fs:  `cpe:2.3:a:vmware:infrastructure_client:2.5.0.64237:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.813`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ym:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.814`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.815`,
        fs:  `cpe:2.3:a:symantec:backup_exec:2010_r3:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.816`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.817`,
        fs:  `cpe:2.3:a:veeam:backup_catalog:5.0.2.230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.818`,
        fs:  `cpe:2.3:a:bilyoner:bilyoner:4.6:*:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.819`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.1:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.820`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.821`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.822`,
        fs:  `cpe:2.3:a:samba:samba:3.0.21:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.823`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.824`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.825`,
        fs:  `cpe:2.3:a:mozilla:firefox:13.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.826`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.827`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.828`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.829`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.40.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.830`,
        fs:  `cpe:2.3:o:qnap:qts:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.831`,
        fs:  `cpe:2.3:a:php:xhprof:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.832`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.833`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.834`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.651.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.835`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5.836`,
        fs:  `cpe:2.3:a:haxx:curl:7.43.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b5`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b6`,
        fs:  `cpe:2.3:a:exim:exim:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b7`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b8`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b10`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:7.6.1:*:*:*:*:solaris:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b11`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.04.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b12`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:3.0:-:coldfusion:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search.cpan:libwww-perl:5b13`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search_api_autocomplete_project:search_api_autocomplete:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search_api_autocomplete_project:search_api_autocomplete:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:catos:2.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:search_api_autocomplete_project:search_api_autocomplete:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:6.2:build_1`,
        fs:  `cpe:2.3:a:hp:loadrunner:9.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:6.3:build_1`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:6.4:build_1`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:6.4:build_2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s9505e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:7.0`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:7.1`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:7.2`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:7.3`,
        fs:  `cpe:2.3:a:gnu:groff:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:7.4`,
        fs:  `cpe:2.3:o:hp:hp-ux:10.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:7.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.06:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:8.1`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:8.2`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:searchblox:searchblox:8.3.0`,
        fs:  `cpe:2.3:a:batavi:batavi:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sears:sears:6.2.8::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:14.0.804.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.0`,
        fs:  `cpe:2.3:h:apple:imac:mc020xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.1`,
        fs:  `cpe:2.3:a:xnview:xnview:1.95.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.2`,
        fs:  `cpe:2.3:a:teradata:tpump:12.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.3`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.4`,
        fs:  `cpe:2.3:a:hp:hppsendfax:1.102.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.02.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.6`,
        fs:  `cpe:2.3:h:sony:snc_dh240t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.7`,
        fs:  `cpe:2.3:h:hp:psc_2400_photosmart_all-in-one:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.8`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.5.1.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.9`,
        fs:  `cpe:2.3:a:vmware:fusion:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.10`,
        fs:  `cpe:2.3:a:sap:mmc_snapin:7.10.30109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.11`,
        fs:  `cpe:2.3:h:cisco:rv220w_wireless_network_security_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.12`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.13`,
        fs:  `cpe:2.3:h:dell:powervault_ml6000:32u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.2.14`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.3.0`,
        fs:  `cpe:2.3:a:milesj:decoda:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.3.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.3.2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seasarfoundation:s2struts:1.3.3`,
        fs:  `cpe:2.3:a:rpm:rpm:4.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.20`,
        fs:  `cpe:2.3:a:adobe:connect:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.30`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.31`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.32`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.33`,
        fs:  `cpe:2.3:a:bci:etasker_scheduling_service_setup:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.34`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.40`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.41`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.17:18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastian_heinlein:aptdaemon:0.42`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastien_sauvage:webgobbler:1.2.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastien_sauvage:webgobbler:1.2.3`,
        fs:  `cpe:2.3:a:busybox:busybox:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastien_sauvage:webgobbler:1.2.4`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastien_sauvage:webgobbler:1.2.5`,
        fs:  `cpe:2.3:o:asus:rt-n10e_firmware:2.0.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sebastien_sauvage:webgobbler:1.2.6`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secondfiction:blitz_bingo:2.3::~~~android~~`,
        fs:  `cpe:2.3:a:busybox:busybox:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secondfiction:codename_birdgame:1::~~~android~~`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:4.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secretcircle:secret_circle_-_talk_freely:2.2.00.26::~~~android~~`,
        fs:  `cpe:2.3:a:justsystems:ichitaro_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secunia:csi_agent:6.0.0.15017`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secunia:csi_agent:6.0.1.1007`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4:ch7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secunia:csi_agent:7.0.0.21`,
        fs:  `cpe:2.3:h:lenovo:thinkserver_rd450:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secure_password_hashes_project:secure_passwords_hashes:6.x-2.0`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securecomputing:safeword_remoteaccess:-`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securecomputing:safeword_remoteaccess:2.1`,
        fs:  `cpe:2.3:a:apple:cups:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:samsung_adsl_modem:-`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sch_i730_phone:-`,
        fs:  `cpe:2.3:a:hp:scan:9.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securecomputing:securityreporter:-`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securecomputing:securityreporter:4.2.30`,
        fs:  `cpe:2.3:o:sun:solaris:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securecomputing:securityreporter:4.6.3`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:-`,
        fs:  `cpe:2.3:a:wp_simplemail_project:wp_simplemail:1.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:5.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:5.2.0.01`,
        fs:  `cpe:2.3:a:apache:openoffice.org:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:5.2.0.02`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:5.2.0.03`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.96:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:5.2.0.04`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:5.2.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8a\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:5.2.1.02`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder:7.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder_g2:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2dd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securecomputing:sidewinder_g2:6.0`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:sidewinder_g2:6.1.0.01`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securecomputing:sidewinder_g2_admin_console:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:smartether_ss6215s_switch:-`,
        fs:  `cpe:2.3:a:blackboard:vista\/ce:8.0:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:snapgear:-`,
        fs:  `cpe:2.3:a:google:chrome:12.0.702.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:snapgear_sg560:-`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:snapgear_sg565:-`,
        fs:  `cpe:2.3:h:apple:imac:mb324xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:snapgear_sg580:-`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_cluster_suite:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:securecomputing:snapgear_sg710:-`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp2:workstation:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:10.3.0:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.1.2`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.1:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.1.3`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.1.4`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.2`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.2.0`,
        fs:  `cpe:2.3:a:dell:sonicwall_global_management_system:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.2.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.2.2`,
        fs:  `cpe:2.3:a:gnu:glibc:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.2.4`,
        fs:  `cpe:2.3:a:sympa:sympa:4.2b.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.2.5`,
        fs:  `cpe:2.3:a:falconsc:wisepoint_authenticator:4.1.19.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.2.6`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.2.7`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.3.5`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.3.6`,
        fs:  `cpe:2.3:a:engardelinux:guardian_digital_webtool:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.3.8`,
        fs:  `cpe:2.3:a:9.dotpp.net:megalith:12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.3.9`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.4.3`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.6.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.4.4`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.0.3.471:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:secureideas:basic_analysis_and_security_engine:1.4.5`,
        fs:  `cpe:2.3:a:ibm:net.commerce_start:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securelogix:computer_based_training_for_the_etm_system:5.10.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:9.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:security_questions_project:security_questions:6.x-1.0`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:security_questions_project:security_questions:6.x-1.x:dev`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:security_questions_project:security_questions:7.x-1.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-60:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:security_questions_project:security_questions:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.06.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securityinnovation:ntru_hybrid_tss:1.5`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securityinnovation:ntru_tcg_software_stack:2.1.25`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:securityinnovation:ntru_tcg_software_stack:2.1.34`,
        fs:  `cpe:2.3:a:mcafee:e-business_server:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seebeyond:seebeyond_editors:1.0.0.0`,
        fs:  `cpe:2.3:a:tufat:mybackup:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seebeyond:windowsinstallersetup:1.0.0.0`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeddms:seeddms:3.3.12`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeddms:seeddms:3.4.3`,
        fs:  `cpe:2.3:a:sun:jre:6.0.250:update25:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:seeddms:seeddms:4.2.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeddms:seeddms:4.3.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.36a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.0`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.2`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.3`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.4`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.5`,
        fs:  `cpe:2.3:a:php:php:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.6`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.7`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.9`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.10`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.12`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.13`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.14`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.15`,
        fs:  `cpe:2.3:a:siemens:openscape_session_border_controller:2r0.32.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.16`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.17`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1077.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.18`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.8.20`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.0:beta`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.1:beta`,
        fs:  `cpe:2.3:a:php:php:5.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.2:beta`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.2.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.3:beta`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.4:beta`,
        fs:  `cpe:2.3:a:sparxsystems:enterprise_architect:8.0.863.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.5:beta`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.6:beta`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.7:beta`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.8:beta`,
        fs:  `cpe:2.3:a:novell:ichain:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.9:beta`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:10.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.10:beta`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.42.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.11:beta`,
        fs:  `cpe:2.3:a:webtitan:webtitan:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.12:beta`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:seeds:acmailer:3.9.14`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seeon:seeon:4.0.7::~~~android~~`,
        fs:  `cpe:2.3:o:juniper:junos:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sefrengo:sefrengo:1.6.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof_security:.45.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sefrengo:sefrengo:1.6.1`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sega:sonic_4_episode_ii_lite:2.3::~~~android~~`,
        fs:  `cpe:2.3:a:teradata:teradata_manager:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sega:sonic_cd_lite:1.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seikoinstruments:smart_label_printer_430:-`,
        fs:  `cpe:2.3:a:aprelium:abyss_web_server_x1:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seikousa:smart_label_printer:7.0.418`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seil:b1:-`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:seil:b1_firmware:-`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.11.257:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seil:bpv_4:-`,
        fs:  `cpe:2.3:a:gnu:ksymoops:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:seil:bpv_4_firmware:-`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seil:x1:-`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:seil:x1_firmware:-`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seil:x2:-`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:seil:x2_firmware:-`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seil:x86_fuji:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.5:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:seil:x86_fuji_firmware:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.234:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:selinc:sel-2241:r113-v0-z001001-d20110721`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:selinc:sel-2241:r123-v0-z002001-d20130117`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:selinc:sel-3505:r119-v0-z001001-d20120720`,
        fs:  `cpe:2.3:a:cisco:desktop_agent:6.1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:selinc:sel-3505:r123-v0-z002001-d20130117`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:selinc:sel-3530:r100_-v0-z001001-d20090915`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:selinc:sel-3530:r123-v0-z002001`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:17.009.20044:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/h:selinc:sel-3530-4:r107-v0-z001001-d20100818`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.5.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:selinc:sel-3530-4:r123-v0-z002001-d20130117`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:semanticforms_project:semanticforms:-::~~~mediawiki~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:semantictitle_project:semantictitle:-::~~~mediawiki~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:semantictitle_project:semantictitle:1.1.0::~~~mediawiki~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.37b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:semper_invicta_fitness_project:semper_invicta_fitness:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:semperfiwebdesign:all_in_one_seo_pack:2.2.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.75.b-1.0.2.1-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:senatorinn:senator_inn_%26_spa:1.2.2.160::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:spa3102_voice_gateway_with_router_firmware:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:1.00`,
        fs:  `cpe:2.3:a:netscape:navigator:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:1.01`,
        fs:  `cpe:2.3:a:apple:remote_desktop:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:1.02`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:1.10`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:1.20`,
        fs:  `cpe:2.3:a:cisco:okena_stormwatch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:2.00`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:2.01`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:7.7.5-835:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.0.0`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.0.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.11.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.0.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.0.3`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.0.4`,
        fs:  `cpe:2.3:a:mavili_guestbook_project:mavili_guestbook:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.0.5`,
        fs:  `cpe:2.3:a:mifashow:mifashow_hairstyles:3.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.0.5:pl1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.0.5:pl2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5b13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.1.0`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:gold:hpc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.1.1`,
        fs:  `cpe:2.3:a:f5:firepass:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.1.2`,
        fs:  `cpe:2.3:a:openstack:ceilometer:2013.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.2.0:rc1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.001:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.2.0:rc2`,
        fs:  `cpe:2.3:a:tbelmans:mm_forms_community:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.2.0:rc3`,
        fs:  `cpe:2.3:h:zte:zxv10_w300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.2.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.2.2`,
        fs:  `cpe:2.3:h:hp:jg363a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.2.3`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.7.0.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.3.0`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.3.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.3.2`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.0.6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.3.3`,
        fs:  `cpe:2.3:a:netty_project:netty:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.4.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.4.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendcard:sendcard:3.5.0`,
        fs:  `cpe:2.3:a:umn:mapserver:4.8:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendio:sendio:7.2.3`,
        fs:  `cpe:2.3:a:irislink:readiris:9.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:advanced_message_server:-`,
        fs:  `cpe:2.3:a:searchblox:searchblox:6.3:build_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:advanced_message_server:1.2`,
        fs:  `cpe:2.3:a:wideimage_project:wideimage:11.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:advanced_message_server:1.3`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:intelligent_quarantine:-`,
        fs:  `cpe:2.3:h:cisco:small_business_ip_phone:spa525g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:intelligent_quarantine:3.0`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:intelligent_quarantine:3.1.8`,
        fs:  `cpe:2.3:a:ibm:installation_manager:1.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:managed_mta:-`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:managed_mta:3.1.7`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:5.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:managed_mta:3.1.8`,
        fs:  `cpe:2.3:a:symantec:vrtsperl:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:message_store_sams:-`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:message_store_sams:2.2`,
        fs:  `cpe:2.3:a:contactgenie:contactgenie_exporter_basic:1.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:message_store_sams:3.1.8`,
        fs:  `cpe:2.3:h:huawei:usg2200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:multi_switch:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:multi_switch:3.1.7`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:multi_switch:3.1.8`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:-`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:2.6`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:2.6.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:2.6.2`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.3:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:3.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.28:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:3.0.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:3.0.2`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:3.0.3`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:4.1`,
        fs:  `cpe:2.3:a:novell:iprint:5.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.6.7`,
        fs:  `cpe:2.3:a:disney:where\&#39;s_my_water\?_free:1.9.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.7.6`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.7.7`,
        fs:  `cpe:2.3:o:netgear:r7300dst_firmware:1.0.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.7.8`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:2.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.7.9`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.7.10`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.8.8`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:4.9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.9.0`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:d26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.9.1`,
        fs:  `cpe:2.3:a:tm_software:tempo:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.9.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.9.3`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.10`,
        fs:  `cpe:2.3:a:google:chrome:15.0.868.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.10.0`,
        fs:  `cpe:2.3:a:cisco:vpn_client:4.7.00.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.10.1`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.10.2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.5.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.11.0`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.0.0.16964:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.11.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1046.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.11.2`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.11.3`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.11.4`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.11.5`,
        fs:  `cpe:2.3:h:emerson:dl_8000_remote_terminal_unit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.11.6`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.11.7`,
        fs:  `cpe:2.3:a:ipswitch:imail:11.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12:beta10`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12:beta12`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12:beta16`,
        fs:  `cpe:2.3:a:piriform:ccleaner:4.12.4657:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12:beta5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12:beta7`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p143:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.2`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.266:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.4`,
        fs:  `cpe:2.3:a:hp:directories_support_for_proliant_management_processors:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.5`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.316:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.102.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.7`,
        fs:  `cpe:2.3:a:hp:ocr_software_by_i.r.i.s:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.8`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:10.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.9`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.6:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.10`,
        fs:  `cpe:2.3:a:hp:oneview:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.12.11`,
        fs:  `cpe:2.3:h:hp:laserjet_4200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.0`,
        fs:  `cpe:2.3:a:oracle:jserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.1.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.2`,
        fs:  `cpe:2.3:a:tiger-fish:fancy_slide:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.3`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.4`,
        fs:  `cpe:2.3:o:siemens:simatic_s7-400_cpu_firmware:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.5`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.285:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.7`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.13.8`,
        fs:  `cpe:2.3:a:roxio:creator:1.1.57:*:*:*:gold:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.0`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.3`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.5`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.6`,
        fs:  `cpe:2.3:a:hp:readme:47.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.7`,
        fs:  `cpe:2.3:h:aterm:wg300hp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.8`,
        fs:  `cpe:2.3:a:microsoft:system.net.security:4.3.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.14.9`,
        fs:  `cpe:2.3:a:apache:commons-httpclient:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:8.15.4`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2009:-:trial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail:9.2.20`,
        fs:  `cpe:2.3:h:axis:2400_video_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail%2bpro:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail_pro:8.9.2`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(28a\)ia:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail_pro:8.9.3`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendmail:sendmail_switch:-`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sendmail:sentrion:-`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sendmail:sentrion:1.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sendmail:sentrion:1.5.1`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendy:sendy:1.1.8.4`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:x64-datacenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sendy:sendy:1.1.9.1`,
        fs:  `cpe:2.3:a:koha:koha:3.14.00:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:senkas:kolibri:2.0`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sensaphone:ims-4000:-`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(8\)sa1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sensatronics:e4_temperature_monitor:-`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.0.0.505:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.0`,
        fs:  `cpe:2.3:a:cookpad:android_mykitchen:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.0:rc1`,
        fs:  `cpe:2.3:a:rocomotion:p_link:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.0:rc2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.1`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.4:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.3`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma611xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.4`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.5`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.6`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.7`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:106sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.8`,
        fs:  `cpe:2.3:a:infradead:openconnect:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.10`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.11`,
        fs:  `cpe:2.3:a:snipsnap:snipsnap:1.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.12`,
        fs:  `cpe:2.3:a:expeditersonline:expeditersonline.com_forum:3.7.13:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.13`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.14`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.12.111745.560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.15`,
        fs:  `cpe:2.3:a:exim:exim:4.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.16`,
        fs:  `cpe:2.3:o:ibm:integrated_management_module_firmware:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.17`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.18`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:1.4.19`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p2_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.0`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.2`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.3`,
        fs:  `cpe:2.3:h:nvidia:geforce_940m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.4`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.5`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.6`,
        fs:  `cpe:2.3:o:cisco:unified_sip_phone_3900_firmware:8.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.7`,
        fs:  `cpe:2.3:a:ocshield:datagard_vpn_\&#43;_av:\@7f050013:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.8`,
        fs:  `cpe:2.3:a:ocportal:ocportal:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.9`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.4.0.46.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.10`,
        fs:  `cpe:2.3:a:redhat:openssl:0.9.6-15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.11`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1003.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.12`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.13`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.14`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1124.2130.38610:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.15`,
        fs:  `cpe:2.3:a:libarchive:libarchive:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.16`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-855:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.17`,
        fs:  `cpe:2.3:a:bugfree:bugfree:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.18`,
        fs:  `cpe:2.3:a:citrix:receiver_usb:13.0.0.6684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.19`,
        fs:  `cpe:2.3:h:juniper:secure_access_6000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.20`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(9\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.21`,
        fs:  `cpe:2.3:a:microsoft:visual_basic:6.0:*:runtime_extended_files:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.0.22`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.1.0`,
        fs:  `cpe:2.3:a:wpsymposium:wp_symposium:14.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.1.1`,
        fs:  `cpe:2.3:a:drupal:realname:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.1.2`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.1.3`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.06.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.1.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.1.5`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.1.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.1.7`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.0`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.871:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.1`,
        fs:  `cpe:2.3:h:huawei:s2700:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.2`,
        fs:  `cpe:2.3:o:redhat:fedora_core:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.3`,
        fs:  `cpe:2.3:a:oracle:application_testing_suite:12.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.4`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.5`,
        fs:  `cpe:2.3:a:gradkell:dbsign_web_signer:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.6`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_7961g:8.0\(4\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.8`,
        fs:  `cpe:2.3:h:mcdata:sphereon_3232_fabric_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.9`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.10`,
        fs:  `cpe:2.3:h:cisco:ids_4230:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.2.11`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.0`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.1`,
        fs:  `cpe:2.3:a:ibm:db2:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.2`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.3`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.904:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.4`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.5`,
        fs:  `cpe:2.3:a:netapp:oncommand_balance:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.6`,
        fs:  `cpe:2.3:a:nonghyup:smart_nhibzbanking:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.7`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.8`,
        fs:  `cpe:2.3:h:emerson:avocent_dsr1021:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.9`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.10`,
        fs:  `cpe:2.3:a:clamav:clamav:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.11`,
        fs:  `cpe:2.3:a:hp:inode_management_center_pc:5.0:e0101:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.12`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.13`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.14`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.15`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.16`,
        fs:  `cpe:2.3:a:apple:quicktime:7.5.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.17`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.18`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.19`,
        fs:  `cpe:2.3:a:apple:quicktime_darwin_mp3_broadcaster:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.20`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.21`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.22`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:2.02.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.23`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.24`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.25`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.0:beta-rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.26`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.27`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.28`,
        fs:  `cpe:2.3:a:cisco:asr_5000_series_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.29`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.30`,
        fs:  `cpe:2.3:a:cisco:business_edition_3000_software:8.6\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.31`,
        fs:  `cpe:2.3:a:hp:secure_web_server_for_tru64:5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.32`,
        fs:  `cpe:2.3:a:tryton:tryton:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.33`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.34`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.36`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.3.40`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.1`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.2`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.4`,
        fs:  `cpe:2.3:a:apple:xcode:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.5`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.6`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.4:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.7`,
        fs:  `cpe:2.3:a:php:php:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.8`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.9`,
        fs:  `cpe:2.3:a:vmware:update_manager:1.0.0.63995:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.4.10`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:12.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.1`,
        fs:  `cpe:2.3:a:netiq:access_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.2`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.3`,
        fs:  `cpe:2.3:a:redhat:enterprise_linux_load_balancer:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.4`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0192:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.5`,
        fs:  `cpe:2.3:a:truecaller:truecaller-caller_id_\&amp;_block:4.32:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.8`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-4.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.9`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.10`,
        fs:  `cpe:2.3:a:filemaker:filemaker:14.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.5.11`,
        fs:  `cpe:2.3:a:wysigot:wysigot:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.0`,
        fs:  `cpe:2.3:a:serf_project:serf:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.1`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.2`,
        fs:  `cpe:2.3:a:zemanta:related_posts:2.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.4`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.7`,
        fs:  `cpe:2.3:o:google:android:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.8`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.9`,
        fs:  `cpe:2.3:h:cisco:nac_appliance:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.10`,
        fs:  `cpe:2.3:a:cfdbplugin:contact_form_db:2.8.26:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.11`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.6.12`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.0`,
        fs:  `cpe:2.3:a:ca:business_protection_suite:r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.1`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.2`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.3`,
        fs:  `cpe:2.3:a:audiograbber:audiograbber_mp3_plugin:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.371.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.5`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.6`,
        fs:  `cpe:2.3:a:pexip:pexip_infinity:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.7`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:108.2146.2565.38893:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.9`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.10`,
        fs:  `cpe:2.3:a:location_module_project:location:7.x-3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.11`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.7.12`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.8.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:5.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.8.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.8.2`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.8.3`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.8.4`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:2.8.5`,
        fs:  `cpe:2.3:a:gnu:emacs:20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:3.0.0`,
        fs:  `cpe:2.3:a:digium:asterisk:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:3.0.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:3.0.2`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:3.0.3`,
        fs:  `cpe:2.3:h:intel:qs77_chipset:-:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:3.0.4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:symfony:3.0.5`,
        fs:  `cpe:2.3:a:redhat:libreport:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sensiolabs:twig:1.19.0`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sentel:aesop:2.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sentinels_randomizer_project:sentinels_randomizer:1.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seopanel:seo_panel:3.3.1`,
        fs:  `cpe:2.3:a:phplist:phplist:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seopanel:seo_panel:3.4.0`,
        fs:  `cpe:2.3:a:rob_loach:sharethis:7.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seopanel:seo_panel:3.5.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seotoaster:seotoaster:1.8.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:va.02.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seotoaster:seotoaster:1.8.3`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seotoaster:seotoaster:1.9`,
        fs:  `cpe:2.3:a:hp:alm-platform_loader:11.0.5844.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:seowonintech:swc-9100:-`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:business_mashups:2009`,
        fs:  `cpe:2.3:o:d-link:dcs-2230l_firmware:1.03.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:changeman_version_manager:8.1.4`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:changeman_version_manager:8.1.4.2`,
        fs:  `cpe:2.3:a:php:php:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:license_manager:2.1.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:mashup_composer:2009`,
        fs:  `cpe:2.3:a:facebook:street_walker:0.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:pvcs_version_manager:8.2`,
        fs:  `cpe:2.3:a:westpac:westpac_mobile_banking:5.21:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:pvcs_version_manager:8.3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:sourcebridge:6.2`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:teamtrack:6.6.1.10`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:teamtrack:6.6.1.19`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.14.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serena:vm_web_client:810000818`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.1.0`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.1.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.1.2`,
        fs:  `cpe:2.3:a:david_king:vino:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.2.0`,
        fs:  `cpe:2.3:h:hp:5m_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.3.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.3.1`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.4.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.391:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.5.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.6.0`,
        fs:  `cpe:2.3:a:opscode:chef:0.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.6.1`,
        fs:  `cpe:2.3:a:combodo:itop:1.2.0:rc282:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.7.0`,
        fs:  `cpe:2.3:a:x:libxvmc:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.7.1`,
        fs:  `cpe:2.3:a:perl:perl:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:0.7.2`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.60.020.1347:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.0.0`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.35.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.0.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.8.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.0.2`,
        fs:  `cpe:2.3:a:apache:qpid:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.0.3`,
        fs:  `cpe:2.3:a:apache:camel:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.1.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.6:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.1.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update4:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.2.0`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.2.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.3.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.3.1`,
        fs:  `cpe:2.3:a:osticket:osticket:1.8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.3.3`,
        fs:  `cpe:2.3:a:url_cloak_\&amp;_encrypt_project:url_cloak_\&amp;_encrypt:2.0:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.3.4`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.3.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.3.6`,
        fs:  `cpe:2.3:a:apple:apple_tv:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serf_project:serf:1.3.7`,
        fs:  `cpe:2.3:a:isc:inn:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:3.0.0.16`,
        fs:  `cpe:2.3:a:gnu:gdb:7.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:3.0.0.17`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:3.1.0.0`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.6.0:-:-:en-us:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:3.1.0.1`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:3.1.0.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:4.0.0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:4.1.0.0`,
        fs:  `cpe:2.3:a:macromedia:coldfusion_professional:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:4.1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.704.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:5.0.0.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p46:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:5.0.0.4`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:5.0.0.9`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:5.0.0.11`,
        fs:  `cpe:2.3:a:digium:asterisk:14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:5.1.0.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:5.2.0.0`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:5.2.0.1`,
        fs:  `cpe:2.3:a:f-prot:f-prot_antivirus:4.6.2.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.0.0.0`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.0.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.0.0.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.1.0.0`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.589.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.1.0.4`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.1.0.5`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.2.0.0`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:2.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.2.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.3.0.0`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.3.0.1`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.4.0.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.4.0.1`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.4.0.2`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.03a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.4.0.3`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:-:commercial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.4.0.4`,
        fs:  `cpe:2.3:h:bluecoat:content_analysis_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.4.0.5`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:6.4.0.6`,
        fs:  `cpe:2.3:a:python:python:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.0.0.1`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.0.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.28:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.0.0.3`,
        fs:  `cpe:2.3:a:hp:virtualvault:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.0.0.4`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.1.0.0`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)t5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.1.0.2`,
        fs:  `cpe:2.3:h:cisco:ipvc-3530-vta:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.2.0.0`,
        fs:  `cpe:2.3:a:hp:fax:50.0.206.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.2.0.1`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.3.0.0`,
        fs:  `cpe:2.3:a:att:connect_participant_application:9.0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.3.0.1`,
        fs:  `cpe:2.3:a:ipswitch:ipswitch_collaboration_suite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.3.0.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.4.0.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:7.4.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p114:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.0.0.1`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.0.0.2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.01.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.0.0.4`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:3.3.1:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.0.0.5`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53_95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.0.0.7`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.1.0.1`,
        fs:  `cpe:2.3:h:festo:cecx-x-c1_modular_master_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.1.0.3`,
        fs:  `cpe:2.3:a:tenable:nessus:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.2.0.0`,
        fs:  `cpe:2.3:h:cisco:nexus_5696q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.2.0.1`,
        fs:  `cpe:2.3:a:jease:jease:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:8.2.0.3`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.0.0.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.0.0.3`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.0.0.5`,
        fs:  `cpe:2.3:a:bundler:bundler:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.1.0.0`,
        fs:  `cpe:2.3:a:avery:avery_wizard:4.0.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.1.0.2`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:4.0:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.2.0.1`,
        fs:  `cpe:2.3:a:sun:ray_windows_connector:2.0:*:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.3.0.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.4.0.0`,
        fs:  `cpe:2.3:a:cgene:security_file_manager:1.0.6:-:-:*:pro:android:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:9.4.0.2`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.7.761:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.0.0.2`,
        fs:  `cpe:2.3:h:xerox:workcentre_m35:4.97.20.032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.0.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.0.0.5`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.0.0.7`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.1.0.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.30.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.1.0.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.2.0.0`,
        fs:  `cpe:2.3:a:artifex:gpl_ghostscript:9.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.2.0.2`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.3.0.1`,
        fs:  `cpe:2.3:a:microsoft:windows_help:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.4.0.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.5.0.4`,
        fs:  `cpe:2.3:a:openfabrics:librdmacm:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.5.0.6`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_master_collection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.5.0.11`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.02:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.5.0.14`,
        fs:  `cpe:2.3:a:apple:itunes:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.5.0.16`,
        fs:  `cpe:2.3:a:ca:etrust_identity_minder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.5.0.19`,
        fs:  `cpe:2.3:a:rename_project:rename:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.5.0.21`,
        fs:  `cpe:2.3:a:ingumadev:bokken:1.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:10.5.0.24`,
        fs:  `cpe:2.3:o:suse:suse_linux:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:11.0.0.0`,
        fs:  `cpe:2.3:a:apple:pages:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:11.0.0.2`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:11.0.0.4`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:11.1.0.3`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serv-u:serv-u:11.1.0.5`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serve:american_express_serve:%407f0901e4::~~~android~~`,
        fs:  `cpe:2.3:a:ubuntu_developers:apt-xapian-index:0.44ubuntu5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serve-static_project:serve-static:1.7.1::~~~node.js~~`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bbet62o:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:servers-r-us:mysqlauction:-`,
        fs:  `cpe:2.3:a:eeye:retina:5.11.13.2120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:serviceacademyforums:service_academy_forums:3.6.12::~~~android~~`,
        fs:  `cpe:2.3:a:avocent:dsview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:6.x-3.0`,
        fs:  `cpe:2.3:a:microsoft:outlook:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:6.x-3.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:6.x-3.2`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:6.x-3.3`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:01-07-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.19.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.1.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.1`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.2`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:winzip:winzip:10.0.7245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.3`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.5::~~~drupal~~`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:wave:trusted_drive_manager:4.0.0.512:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.25:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_project:services:7.x-3.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_single_sign-on_server_helper_project:services_single_sign-on_server_helper:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:web2py:web2py:1.77.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.1.0`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.6:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.2.0`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.2.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.3.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.4.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.12.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p356:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.5.1`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.7265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.6.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.6.1`,
        fs:  `cpe:2.3:a:pcre:pcre:8.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.6.2`,
        fs:  `cpe:2.3:a:openbravo:openbravo_erp:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:services_twitter_group:services_twitter:0.6.3`,
        fs:  `cpe:2.3:a:cisco:asa_with_firepower_services:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:servision:hvg_video_gateway_firmware:2.2.26a77`,
        fs:  `cpe:2.3:a:phpexcel_project:phpexcel:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:servision:hvg_video_gateway_firmware:2.2.26a100`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.0:rc2:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:servision:hvg400:-`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2013-ac-ovs-w-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:setseed:setseed_cms:5.8.20`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:setseed:setseed_cms:5.11.2`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:seven_bulls:christmas_words:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.7.5:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:0.9.1`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_workstation:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:0.9.2`,
        fs:  `cpe:2.3:o:ibm:vios:1.5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:0.9.4`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:0.9.6`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.8-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:0.9.8`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:1.0.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:1.0.2`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:1.1.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.0.0`,
        fs:  `cpe:2.3:a:citrix:nfuse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.0.2`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.0.4`,
        fs:  `cpe:2.3:a:sun:netdynamics:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.0.6`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.0.8`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.0.10`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.6.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.0.12`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.1.0`,
        fs:  `cpe:2.3:a:opensis:opensis:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.1.2`,
        fs:  `cpe:2.3:a:python_bugzilla_project:python-bugzilla:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.1.4`,
        fs:  `cpe:2.3:a:sap:crystal_enterprise_xi:3.1:fp_3.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.1.6`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.1.8`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_design_standard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.1.8:r2`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sfiab:science_fair_in_a_box:2.2.0`,
        fs:  `cpe:2.3:a:springsource:spring_framework:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sfr:sfr_box_router:-`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sfr:sfr_box_router_firmware:nb6-main-r3.3.4`,
        fs:  `cpe:2.3:a:hp:psswcore:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:advanced_linux_environment:-`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:fam:-`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:fam:2.6.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.22:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:fam:2.6.8`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.11:*:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:infosearch:-`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:infosearch:1.0`,
        fs:  `cpe:2.3:a:jasig:uportal:4.0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:irisconsole:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:irisconsole:2.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:-`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.1`,
        fs:  `cpe:2.3:a:david_king:vino:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.1t`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(14\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.338.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.3`,
        fs:  `cpe:2.3:a:unit4:prosoft_hrms:8.14.230.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.4b`,
        fs:  `cpe:2.3:h:hp:officejet_pro_8500:cb793a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.4t`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5_iop`,
        fs:  `cpe:2.3:a:atutor:atutor:1.5.1:pl2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5a`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5b`,
        fs:  `cpe:2.3:a:antoine_beaupre:hostmaster:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5d`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5e`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5f`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5g`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:4.0.5h`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:5.0.1`,
        fs:  `cpe:2.3:a:spip:spip:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:5.1`,
        fs:  `cpe:2.3:a:netscape:directory_server:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:5.1.1`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:5.2`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:5.3`,
        fs:  `cpe:2.3:o:dell:bios:a11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:5.3::xfs`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.0.1`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.0.1::xfs`,
        fs:  `cpe:2.3:a:hp:loadrunner:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.1`,
        fs:  `cpe:2.3:a:php:php:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.2`,
        fs:  `cpe:2.3:a:cisco:enterprise_data_integration:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.3`,
        fs:  `cpe:2.3:a:lttng:ust:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.4`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(0\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.2`,
        fs:  `cpe:2.3:a:apple:itunes:4.7.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.2f`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.2m`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.3f`,
        fs:  `cpe:2.3:a:wysigot:wysigot:5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.3m`,
        fs:  `cpe:2.3:a:owncloud:owncloud:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.4f`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53_96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.4m`,
        fs:  `cpe:2.3:a:ibm:interact:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.5`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.5f`,
        fs:  `cpe:2.3:a:usebb:usebb:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.5m`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.2:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.6`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.6f`,
        fs:  `cpe:2.3:a:gradkell:dbsign_web_signer:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.6m`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.7`,
        fs:  `cpe:2.3:h:apple:imac:mb393xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.7f`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.7m`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.8`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.8f`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.8m`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp3:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.9`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.9f`,
        fs:  `cpe:2.3:a:avast:business_security:11.1.2241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.9m`,
        fs:  `cpe:2.3:a:apache:axis:1.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.10`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.10f`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.10m`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.0:*:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.11`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:1.5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.11f`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.11m`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.61:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.12`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.12f`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.12m`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.20:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.13`,
        fs:  `cpe:2.3:a:google:chrome:0.2.152.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.13f`,
        fs:  `cpe:2.3:a:digium:asterisk:11.20.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.13m`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.14`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.14f`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.14m`,
        fs:  `cpe:2.3:a:nobexrc:radios_del_ecuador:3.2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.15`,
        fs:  `cpe:2.3:a:ajsquare:aj_auction_pro-oopd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.15f`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.15m`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0572:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.16`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.601.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.16f`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.16m`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.17`,
        fs:  `cpe:2.3:a:verkehrsmuseum-dresden:dresden_transport_museum:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.17f`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.17m`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.18`,
        fs:  `cpe:2.3:h:hp:h3c_routing_switch:s12518:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.18f`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.18m`,
        fs:  `cpe:2.3:a:apache:mod_python:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.19`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:9.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.19f`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.19m`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.20`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:6.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.20f`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.20m`,
        fs:  `cpe:2.3:a:tincan:phplist:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.21`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.21f`,
        fs:  `cpe:2.3:a:frontrange:iheat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.21m`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.22`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.22m`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.23`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.24`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.25`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.26`,
        fs:  `cpe:2.3:a:apple:quicktime:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sgi:irix:6.5.27`,
        fs:  `cpe:2.3:a:google:chrome:11.0.690.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:mailx:-`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:mediamail:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0\(5.28\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:mipspro_compilers:-`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:mipspro_compilers:7.1`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:mipspro_compilers:7.2.1`,
        fs:  `cpe:2.3:a:google:chrome:15.0.871.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:nqsdaemon:-`,
        fs:  `cpe:2.3:h:fortinet:fortigate-620b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.1`,
        fs:  `cpe:2.3:a:microsoft:pocket_internet_explorer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.2`,
        fs:  `cpe:2.3:a:process-one:ejabberd:3.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.3`,
        fs:  `cpe:2.3:a:autodesk:dwf_viewer:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.4`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.5`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.24.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.6`,
        fs:  `cpe:2.3:a:altiris:inventory_rule_management:6.2.3593:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.7`,
        fs:  `cpe:2.3:a:op5:system-op5config:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.8`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.9`,
        fs:  `cpe:2.3:a:apple:itunes:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.10`,
        fs:  `cpe:2.3:a:apache:subversion:1.10.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.1.11`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:2.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.4.402.278:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:3.6.4`,
        fs:  `cpe:2.3:a:google:chrome:6.0.427.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:3.6.5`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:performance_co-pilot:3.6.6`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:propack:-`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:propack:2.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.3:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:propack:2.3`,
        fs:  `cpe:2.3:a:ssh:secure_shell_for_servers:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:propack:2.4`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:propack:3:sp6`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l30erm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:propack:3.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:propack:4.0`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:quake_1_server:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:workshop_debugger_and_performance_tools:-`,
        fs:  `cpe:2.3:a:monotone:monotone:0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgi:xfsprogs:3.2.3`,
        fs:  `cpe:2.3:a:hp:unload_support:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgk:sgk_hizmet_dokumu_4a:1.103::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\)e12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgminer_project:sgminer:4.0.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgminer_project:sgminer:4.1.0`,
        fs:  `cpe:2.3:a:gnome:gdk-pixbuf:2.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgminer_project:sgminer:4.1.153`,
        fs:  `cpe:2.3:a:cisco:telepresence_recording_server:1.6.3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgminer_project:sgminer:4.1.242`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgminer_project:sgminer:4.1.271`,
        fs:  `cpe:2.3:o:sun:solaris:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgminer_project:sgminer:4.2.0`,
        fs:  `cpe:2.3:a:emc:eroom:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgminer_project:sgminer:4.2.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgminer_project:sgminer:4.2.2`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sgpsys:gems:1.0.3181`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.0.40:beta`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.0.41:beta`,
        fs:  `cpe:2.3:a:biscom:faxcom_suite_for_windows_admin:9.4.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.0.42:beta`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.0.43:beta`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.1\(1.80\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.0.44:beta`,
        fs:  `cpe:2.3:a:debian:trousers:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.0.45:beta`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.5.0`,
        fs:  `cpe:2.3:a:netiq:privileged_user_manager:2.3.1:hf2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.5.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.5.2`,
        fs:  `cpe:2.3:a:kvirc:kvirc:3.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.5.3`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.5.4`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.6.0`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.6.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.6.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.10:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.6.3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.6.4`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.6.5`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.14:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.7.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.7.1`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.8.0`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.7:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.8.1`,
        fs:  `cpe:2.3:a:emc:rsa_netwitness:9.8.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.8.2`,
        fs:  `cpe:2.3:a:fortinet:fortiweb:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.8.3`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.8.4`,
        fs:  `cpe:2.3:a:administration_views_project:administration_views:7.x-1.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.8.5`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.9.0`,
        fs:  `cpe:2.3:a:openx:openx:2.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.9.1`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.9.2`,
        fs:  `cpe:2.3:a:apache:tomcat:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaarli_project:shaarli:0.9.3`,
        fs:  `cpe:2.3:a:lepton-cms:lepton:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shaklee_product_catalog_project:shaklee_product_catalog:2::~~~android~~`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shape:im%2b:6.6.2::~~~android~~`,
        fs:  `cpe:2.3:o:buffalotech:wmr-300_firmware:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shareaholic:sexybookmarks:6.1.4.0`,
        fs:  `cpe:2.3:a:isc:bind:9.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharelatex:sharelatex:0.1.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:5.2.1`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:5.3`,
        fs:  `cpe:2.3:a:cisco:intelligent_contact_manager:5.0\(0\)_sr13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:5.4.1`,
        fs:  `cpe:2.3:a:apache:camel:2.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:6.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:7.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.8:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:7.0.1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:7.0.2`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:7.0.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.93.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:7.0.4`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:7.0.5`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.25-25.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharethis:sharethis:7.0.6`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharetronix:sharetronix:3.1.1`,
        fs:  `cpe:2.3:a:ati:skins:2009.0113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharetronix:sharetronix:3.1.1.3`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharetronix:sharetronix:3.3`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharetronix:sharetronix:3.4`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sharp:aquos_hn-pp150:-`,
        fs:  `cpe:2.3:a:teamst:testlink:1.8:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sharp:aquos_hn-pp150_firmware:1.04.00`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sharp:aquos_hn-pp150_firmware:1.04.00.04`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharp:eva_animator:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager_for_vmware:6.4:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:sharp:sharpdesk:3.2`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.22.349:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sharp:zaurus:-`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_compliance:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.9.900.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_compliance:2.0.2`,
        fs:  `cpe:2.3:a:portrait:pivot_software:8.21.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_compliance:2.1`,
        fs:  `cpe:2.3:a:google:v8:3.22.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_compliance:3.0`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_compliance:3.1`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.50.020.1288:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_compliance:3.1.0.144`,
        fs:  `cpe:2.3:a:posh_project:posh:1.5:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_configure:-`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_configure:4.0`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_configure:4.0.0.45`,
        fs:  `cpe:2.3:a:bryce_hamrick:janrain_capture:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_configure:4.1`,
        fs:  `cpe:2.3:a:microsoft:dynamics_ax:2012:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_configure:4.1.0.209`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_configure:4.2`,
        fs:  `cpe:2.3:a:nuance:omnipage:18:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.27:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.0.1`,
        fs:  `cpe:2.3:a:apache:struts:2.3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.1`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.5.1.754`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-20:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.6.0.444`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.6.0.446`,
        fs:  `cpe:2.3:h:buffalotech:whr-amg54:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.8.0.577`,
        fs:  `cpe:2.3:a:hp:bpdsoftware:70.0.283.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.8.1.136`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:5.9.0.145`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.0`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.0.10.636`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.0.10.640`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.1`,
        fs:  `cpe:2.3:a:golang:go:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.1.0.57`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.5.0.489`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.5.1.527`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.5.2.611`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:6.5.3.818`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.40.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.0.832.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(2\)sp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.0.841.0`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.1`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.1.410.0`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.2`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.2.155.0`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.5.2733.0`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.8.1340.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.65.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.8.1388.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.379:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shavlik:netchk_protect:7.8.1392.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shawn_bradley:php_ticket_system:1.0:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)yr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shawn_bradley:php_volunteer_management:1.0.0`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:4.0.0:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shawn_bradley:php_volunteer_management:1.0.2`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sheado:furdiburb:1.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.718.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sheepsystems:bookdog:4.0`,
        fs:  `cpe:2.3:a:jogoeusei:eu_sei:eusei_android_5.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:shellinabox_project:shellinabox:2.18`,
        fs:  `cpe:2.3:a:oracle:field_service:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:identity_provider:2.4.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)xr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:opensaml_java:2.6.4`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:1.3.1`,
        fs:  `cpe:2.3:a:gnome:libsocialweb:0.25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:1.3.2`,
        fs:  `cpe:2.3:a:apple:instant_message_framework:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:1.3.3`,
        fs:  `cpe:2.3:h:hp:jd654a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:1.3.4`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:1.3.5`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:1.3f`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.0f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.581.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.2`,
        fs:  `cpe:2.3:a:apple:cups:1.4:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.2.1`,
        fs:  `cpe:2.3:a:python:pillow:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.3`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.3.1`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.4`,
        fs:  `cpe:2.3:a:adobe:digital_editions:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.4.1`,
        fs:  `cpe:2.3:a:gnu:gdb:5.0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.4.2`,
        fs:  `cpe:2.3:a:magzter:travel\&#43;leisure:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:shibboleth:shibboleth-sp:2.4.3`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1295.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiftdelete:sdn_forum:3.6.5::~~~android~~`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.0.00::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nero:essentials:8.3.500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.0.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.0.02::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:justsystems:rekishimail_sengokubusho_no_missho:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.1.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.2.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:6.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.3.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:webns:5.20.0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:juniper:junos:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:automake:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:c-ares_project:c-ares:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.11:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.6.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:9.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:python:python:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.7.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:struts:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.5.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:jdk:7.0:update_97:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.8.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_3d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.8.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.8.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8m:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shinephp:thank_you_counter_button:1.8.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:virtuemart:virtuemart:3.0.14:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:shirakaba_project:shirakaba:1::~~~android~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.36`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.40`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.50`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.60`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.70`,
        fs:  `cpe:2.3:a:dmitry_loac:taxotouch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.80`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.81`,
        fs:  `cpe:2.3:a:x2engine:x2crm:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.90`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:bu2_bbs:2.91`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:-::fs6`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.10:-:fs6`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.20:-:fs6`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.21:-:fs6`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.22:-:fs6`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.24:-:fs6`,
        fs:  `cpe:2.3:o:vmware:esx:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.25:-:fs6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.27:-:fs6`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.28:-:fs6`,
        fs:  `cpe:2.3:a:redhat:rhel_application_stack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:diary:2.40:-:fs6`,
        fs:  `cpe:2.3:a:boa:boa:0.94.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shiromuku:guestbook:1.61`,
        fs:  `cpe:2.3:a:cisco:anyconnect_vpn_client:2.5.3046:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopizer:shopizer:1.1.5`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopizer:shopizer:2.0`,
        fs:  `cpe:2.3:a:lxml:lxml:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.0.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.0.2`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.0.3`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.0.4`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.6\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.0.5`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.0.6`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.0.7`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.0.8`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.1.0`,
        fs:  `cpe:2.3:h:cisco:ie-4000-4s8p4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.1.1`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.1.2`,
        fs:  `cpe:2.3:a:apache:log4j:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.1.3`,
        fs:  `cpe:2.3:a:xchat:xchat:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.1.4`,
        fs:  `cpe:2.3:a:adobe:encore_cs4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.2.1.1`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.2.2`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.2.3`,
        fs:  `cpe:2.3:a:schneider-electric:software_update_utility:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.3.0`,
        fs:  `cpe:2.3:a:dell:sonicwall_global_management_system:7.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.3.1`,
        fs:  `cpe:2.3:a:citrix:presentation_server_document_center:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.3.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.3.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.3.4`,
        fs:  `cpe:2.3:a:hp:sitescope:10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.3.5`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.3.6`,
        fs:  `cpe:2.3:a:altiris:inventory_pack_for_servers_documentation:6.1.1019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:4.3.7`,
        fs:  `cpe:2.3:a:apple:safari:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.0`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.3:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.0:rc1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.0:rc2`,
        fs:  `cpe:2.3:o:vmware:esx:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.0:rc3`,
        fs:  `cpe:2.3:h:cabletron:6h252-17:5.07.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(20\)s9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.2`,
        fs:  `cpe:2.3:a:samba:samba:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.2:rc1`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.3`,
        fs:  `cpe:2.3:a:symantec:powerquest_deploycenter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.3:rc1`,
        fs:  `cpe:2.3:a:palm:blazer:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.0.4:rc1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.0:rc2`,
        fs:  `cpe:2.3:a:samba:samba:3.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.0:rc3`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.11.0:pre.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.2:rc1`,
        fs:  `cpe:2.3:a:stbernard:open_file_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.2:rc2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.3`,
        fs:  `cpe:2.3:a:x.org:x11:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.3:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.5`,
        fs:  `cpe:2.3:h:hp:jh192a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.1.6`,
        fs:  `cpe:2.3:a:vmware:fusion:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.0`,
        fs:  `cpe:2.3:a:openstack:horizon:juno-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.0:beta1`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite_sql-server:12.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.0:rc1`,
        fs:  `cpe:2.3:a:wampserver:wampserver:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.0:rc2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.0:rc3`,
        fs:  `cpe:2.3:a:adobe:flash_cs4_extension_flash_lite_sti:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp12:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.2`,
        fs:  `cpe:2.3:a:nortel:81c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.3`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.4`,
        fs:  `cpe:2.3:h:avaya:cajun_p580:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.5`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110907:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.7`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.8`,
        fs:  `cpe:2.3:a:ibm:lotus_protector_for_mail_security:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.9`,
        fs:  `cpe:2.3:a:xnview:xnview:1.91.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.10`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.11`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.12`,
        fs:  `cpe:2.3:o:canonical:ubuntu_core:15.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.13`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.14`,
        fs:  `cpe:2.3:a:ca:etrust_siteminder_user_context_gateway:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.15`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.16`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.17`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.0:alpha_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.18`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.19`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.24:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.20`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:1.8.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.21`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.22`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.23`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.24`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.25`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.26`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.2.27`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:1.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.3.0`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.3.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.3.0:rc2`,
        fs:  `cpe:2.3:a:metaclassy:byword:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.3.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p403:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.3.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.3.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shopware:shopware:5.3.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shots:shots:1.0.8::~~~android~~`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shoutcast:dnas:1.7.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shoutcast:dnas:2.2.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.229:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:show_do_milhao_2014_project:show_do_milhao_2014:1.4.6::~~~android~~`,
        fs:  `cpe:2.3:a:tiger-fish:fancy_slide:6.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:1.0.0`,
        fs:  `cpe:2.3:a:gnu:libtool:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:1.1.0`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.0.0`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.0.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.0.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.0.3`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.0`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.7:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.25.356:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.9.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.3`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.4`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.6`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.7`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.7:beta1`,
        fs:  `cpe:2.3:h:netgear:fvs318:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.1.7:rc1`,
        fs:  `cpe:2.3:a:git-scm:git:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha2`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha3`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha4`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha5`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1679.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha6`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.23:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha7`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha8`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:shrew:vpn_client:2.2.0:alpha9`,
        fs:  `cpe:2.3:a:emc:documentum_foundation_services:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.1`,
        fs:  `cpe:2.3:a:apple:xcode:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.2`,
        fs:  `cpe:2.3:o:triplc:nano-10_plc_firmware:r80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.3`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:2.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.4`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.5`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.6`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.7`,
        fs:  `cpe:2.3:a:carahsoft:extras_for_the_jabber_xcp:5.4.0.14409:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.8`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm_security_suite:6.1.737.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siege:phpmyid:0.9`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.00`,
        fs:  `cpe:2.3:a:atlassian:jira:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.03`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.013:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.04`,
        fs:  `cpe:2.3:a:nishishi:fumy_teachers_schedule_board:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.06`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.09`,
        fs:  `cpe:2.3:a:samsung:ml-85p_printer_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.10`,
        fs:  `cpe:2.3:a:1024cms:1024_cms:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.12`,
        fs:  `cpe:2.3:a:siemens:wincc:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.13`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.14`,
        fs:  `cpe:2.3:a:businessobjects:report_application_server:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.18`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:5.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.21`,
        fs:  `cpe:2.3:a:microsoft:works:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.24`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.25`,
        fs:  `cpe:2.3:a:foolabs:xpdf:3.02:pl3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.28`,
        fs:  `cpe:2.3:a:intel:mxml:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.40`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.46`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.50`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.02.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.60`,
        fs:  `cpe:2.3:a:drupal:drupal:7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.73`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.06.86`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.07.00`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0eba:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.07.01`,
        fs:  `cpe:2.3:a:ibm:infosphere_replication_server:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.07.08`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.0.06a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.07.09`,
        fs:  `cpe:2.3:a:checkpw_project:checkpw:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.07.11`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_lite:2.07.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.00`,
        fs:  `cpe:2.3:a:guillaume_gauvrit:pyshop:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.03`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.04`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.06`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.09`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.273:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.10`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.12`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.13`,
        fs:  `cpe:2.3:a:microsoft:outlook:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.14`,
        fs:  `cpe:2.3:a:python:python:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.18`,
        fs:  `cpe:2.3:a:monotone:monotone:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.21`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.24`,
        fs:  `cpe:2.3:a:eaton:proview:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.25`,
        fs:  `cpe:2.3:a:tryton:tryton:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.28`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.40`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp1:x64-ultimate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.46`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.50`,
        fs:  `cpe:2.3:a:vmware:workstation_pro:12.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.60`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.73`,
        fs:  `cpe:2.3:a:apple:cups:1.1.6-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.06.86`,
        fs:  `cpe:2.3:a:gajim:gajim:0.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.07.00`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.07.01`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.07.08`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.07.09`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.07.11`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.07.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sielcosistemi:winlog_pro:2.07.14`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:3568i_wap:-`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:apogee_insight:-`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.5:1010:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:automation_license_manager:4.0`,
        fs:  `cpe:2.3:a:brainabundance:brain_abundance_info:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:automation_license_manager:5.0`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:automation_license_manager:5.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.12.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:automation_license_manager:5.1:sp1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:automation_license_manager:5.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccid1445-dn18:-`,
        fs:  `cpe:2.3:h:rockwellautomation:rslinx_enterprise:cpr9:sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccid1445-dn18_firmware:-`,
        fs:  `cpe:2.3:a:taskware:wintask:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccid1445-dn28:-`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.0:rc.3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccid1445-dn28_firmware:-`,
        fs:  `cpe:2.3:a:ibm:connections:2.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccid1445-dn36:-`,
        fs:  `cpe:2.3:a:gajennings:this:1.2.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccid1445-dn36_firmware:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccis1425:-`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccis1425_firmware:-`,
        fs:  `cpe:2.3:a:keepass:keepass:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccmd3025-dn18:-`,
        fs:  `cpe:2.3:a:apache:opentaps:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccmd3025-dn18_firmware:-`,
        fs:  `cpe:2.3:h:siemens:scalance_x-300eec:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccms2025:-`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccms2025_firmware:-`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p299:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccmw1025:-`,
        fs:  `cpe:2.3:a:schneider-electric:scada_expert_clearscada:2013:r1.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccmw1025_firmware:-`,
        fs:  `cpe:2.3:a:altiris:dell_client_manager_documentation:2.2.1017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccmw3025:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccmw3025_firmware:-`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0042:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ccpw3025:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.270:update27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ccpw3025_firmware:-`,
        fs:  `cpe:2.3:o:cisco:ios:11.3xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:cfis1425:-`,
        fs:  `cpe:2.3:h:y-cam:ycw004:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:cfis1425_firmware:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:cfms2025:-`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:cfms2025_firmware:-`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:5.1\(p1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:cfmw1025:-`,
        fs:  `cpe:2.3:a:sap:gui:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:cfmw1025_firmware:-`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.2.5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:cfmw3025:-`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:cfmw3025_firmware:-`,
        fs:  `cpe:2.3:a:apache:ofbiz:11.04.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:9.1:457`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:9.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:9.2.0.6.10`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5408:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:9.2.0.8.1`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:9.2.6.36`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:10.0`,
        fs:  `cpe:2.3:a:hp:wireless_assistant:4.0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:10.0.3.0.4`,
        fs:  `cpe:2.3:a:oracle:human_capital_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:10.0.3.0.18`,
        fs:  `cpe:2.3:a:owncloud:owncloud:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:10.0.3.1.40`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:10.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:comos:10.1.0.0.2`,
        fs:  `cpe:2.3:a:emc:watch4net:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:compas:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:atlassian:jira:2.6:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:cvms2025-ir:-`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:cvms2025-ir_firmware:-`,
        fs:  `cpe:2.3:a:scalix:web_access:12.2.0.14697:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:cvmw3025-ir:-`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.1.0.5790:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:cvmw3025-ir_firmware:-`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.3:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:enterprise_openscape_branch:-`,
        fs:  `cpe:2.3:a:microsoft:pocket_internet_explorer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:gigaset_se361_wlan_router:-`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20010922:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:hinet_lp:-`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:homecontrol_for_room_automation:2.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:m45:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_secureway_policy_director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:openscape_session_border_controller:1r4.17.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.547.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:openscape_session_border_controller:2r0.32.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(28\)w5\(31a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:openscape_session_border_controller:7r.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:openscape_session_border_controller:7r1.7.0`,
        fs:  `cpe:2.3:h:yokogawa:centum_long-term_trend_historian:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ozw672:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ozw672_firmware:5.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ozw772:-`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ozw772_firmware:5.2`,
        fs:  `cpe:2.3:a:pedro_cambra:commerce_extra_panes:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:processsuite:-`,
        fs:  `cpe:2.3:a:dell:bioapi_framework:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:reliant_unix:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:208:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_firmware:bs4.4.4621.31`,
        fs:  `cpe:2.3:a:novell:netmail:3.5.2c1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_firmware:ss4.4.4624.34`,
        fs:  `cpe:2.3:a:microsoft:office:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:ruggedcom_network_management_software:2.0.2`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.2.5`,
        fs:  `cpe:2.3:a:entrouvert:lasso:2.2.1-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.3.6`,
        fs:  `cpe:2.3:a:digium:asterisk:11.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.4.9`,
        fs:  `cpe:2.3:o:microsoft:windows_95:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.5.4`,
        fs:  `cpe:2.3:a:apache:http_server:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.6.6`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:10.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.7.9`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.8.5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.9.3`,
        fs:  `cpe:2.3:a:google:android_api:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.10.1`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.11::~~~~rs950g~`,
        fs:  `cpe:2.3:a:minitab:software_update_manager:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.11:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:198:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.11.0`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.11.4`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.2.2d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.12`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.12.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.12.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:3.12.4`,
        fs:  `cpe:2.3:a:teradata:administrator:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:ruggedcom_rugged_operating_system:4.0::~~~~rsg2488~`,
        fs:  `cpe:2.3:a:ibm:ds_storage_manager_host_software:10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ruggedcom_win5100:-`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.6p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ruggedcom_win5200:-`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ruggedcom_win7000:-`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:ruggedcom_win7200:-`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:s45:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:s55:-`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(5b\)1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:santis_50:-`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_s_firmware:2.1.0`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_s_firmware:2.2.0`,
        fs:  `cpe:2.3:a:bloodshed:dev-c\&#43;\&#43;:4.9.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_s_firmware:2.3.0`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_s_firmware:2.3.0.3`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_s602:v2`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_s612:v2`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_s613:v2`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_w700_series_firmware:4.4.0`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.3:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_w700_series_firmware:4.5.4`,
        fs:  `cpe:2.3:a:citrix:xenapp_commands:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w744-1:-`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w744-1pro:-`,
        fs:  `cpe:2.3:h:supermicro:x9dri-ln4f\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w746-1:-`,
        fs:  `cpe:2.3:a:rsa:envision:3.7.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w746-1pro:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.445.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w747-1:-`,
        fs:  `cpe:2.3:a:phusion:passenger:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w747-1rr:-`,
        fs:  `cpe:2.3:a:shopware:shopware:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w784-1:-`,
        fs:  `cpe:2.3:a:otrs:otrs:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w784-1rr:-`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w786-1pro:-`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w786-2pro:-`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_assurance:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w786-2rr:-`,
        fs:  `cpe:2.3:a:tenable:nessus:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w786-3pro:-`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w788-1pro:-`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w788-1rr:-`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.3.2:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w788-2pro:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_w788-2rr:-`,
        fs:  `cpe:2.3:h:hp:3com_router:5642:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x-200:-`,
        fs:  `cpe:2.3:o:huawei:5710ei_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x-200_series_firmware:4.3`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x-200_series_firmware:4.4`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x-200_series_firmware:4.5.0`,
        fs:  `cpe:2.3:a:bad_behavior_project:bad_behavior:6.x-2.2215:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x-200_series_firmware:5.0.0`,
        fs:  `cpe:2.3:a:codehaus:redback:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x-200_series_firmware:5.0.1`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x-200_series_firmware:5.1.0`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x-200_series_firmware:5.1.1`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x-200irt:-`,
        fs:  `cpe:2.3:o:cisco:spa2102_phone_adapter_with_router_firmware:5.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x-200rna:-`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x-300:-`,
        fs:  `cpe:2.3:h:lenovo:thinkserver_rd650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_firmware:2.2.0`,
        fs:  `cpe:2.3:a:siemens:wincc:6.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_firmware:2.3.1`,
        fs:  `cpe:2.3:a:gnu:libidn:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_firmware:3.0.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)dc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_firmware:3.3.1`,
        fs:  `cpe:2.3:a:cybozu:cybozu_live:2.0.0:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_firmware:3.5.0`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_firmware:3.5.1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_firmware:3.7.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_firmware:3.7.2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300_series_firmware:3.9.3`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0198:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x-300eec:-`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300eec_firmware:3.5.0`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300eec_firmware:3.7.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-300eec_firmware:3.7.2`,
        fs:  `cpe:2.3:a:cherrypy:cherrypy:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x-300poe:-`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x-408:-`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x-408_firmware:3.9.3`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x200-4p_irt:-`,
        fs:  `cpe:2.3:a:boost:boost:1.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x200irt_firmware:5.0.0`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:scalance_x200irt_firmware:5.1.0`,
        fs:  `cpe:2.3:a:gnu:glibc:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x201-3p_irt:-`,
        fs:  `cpe:2.3:a:gnu:gv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x201-3p_irt:-:-:pro`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x201-3p_irt_pro:-`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x201-3pirt:-`,
        fs:  `cpe:2.3:a:erlang:crypto:1.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x202-2irt:-`,
        fs:  `cpe:2.3:h:hp:ce996a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x202-2p_irt:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.91.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x202-2p_irt:-:-:pro`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x202-2p_irt_pro:-`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x202-4p_irt:-`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x204irt:-`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x204irt:-:-:pro`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x204irt_pro:-`,
        fs:  `cpe:2.3:a:synology:download_station:3.8.0-3416:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x308-2m:-`,
        fs:  `cpe:2.3:h:axis:2420-ir_network_camera:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x308-2m_firmware:3.1.1`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x308-2m_firmware:3.5.0`,
        fs:  `cpe:2.3:h:oracle:es1-24:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x308-2m_firmware:3.5.2`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x308-2m_firmware:3.7.0`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x308-2m_firmware:3.7.2`,
        fs:  `cpe:2.3:a:deltek:winsight:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_x414-3e:-`,
        fs:  `cpe:2.3:a:vicidial:vicidial:2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:1.2.2`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:2.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:2.2.0`,
        fs:  `cpe:2.3:a:preplaysports:mlb_preplay:5.4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:2.3.2`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:2.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:11.1aa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:3.0.0`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:3.0.2`,
        fs:  `cpe:2.3:h:cisco:catalyst_7600_ws-svc-nam-2:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:3.3.0`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.3:1002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:3.4.0`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:3.7.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_x414-3e_firmware:3.7.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.3.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_xf-200:-`,
        fs:  `cpe:2.3:a:ibm:platform_symphony:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_xf204irt:-`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_xr-300:-`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.8:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_xr-300_firmware:3.1.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_xr-300_firmware:3.5.0`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_xr-300_firmware:3.7.0`,
        fs:  `cpe:2.3:a:acme:thttpd:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:scalance_xr-300_firmware:3.7.2`,
        fs:  `cpe:2.3:a:oracle:workflow:11.5.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_xr-300eec:-`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:scalance_xr-300poe:-`,
        fs:  `cpe:2.3:a:vmware:player:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_logon:1.5:sp3_update_1`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.04b58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_pcs7:7.1:sp3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_pcs7:8.0`,
        fs:  `cpe:2.3:a:opennms:opennms:1.11.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_pcs7:8.0:sp1`,
        fs:  `cpe:2.3:a:invensys:wonderware_inbatch:9.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_pcs7:8.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_prosave:13.0`,
        fs:  `cpe:2.3:a:foolabs:xpdf:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7-1500_cpu_firmware:1.5.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7-1500_cpu_firmware:1.6`,
        fs:  `cpe:2.3:a:vmware:vsphere_server:5.5:u3a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7-1500_cpu_firmware:1.8.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1511-1_pn_cpu:-`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1511c-1_pn_cpu:-`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1511f-1_pn_cpu:-`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1512c-1_pn_cpu:-`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1513-1_pn_cpu:-`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1513f-1_pn_cpu:-`,
        fs:  `cpe:2.3:a:apache:poi:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1515-2_pn_cpu:-`,
        fs:  `cpe:2.3:a:adobe:photoshop:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1515f-2_pn_cpu:-`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1516-3_pn%2fdp_cpu:-`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1516f-3_pn%2fdp_cpu:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:4.1\(1.40\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1517-3_pn%2fdp_cpu:-`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1517f-3_pn%2fdp_cpu:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1518-4_pn%2fdp_cpu:-`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-1518f-4_pn%2fdp_cpu:-`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-400_cpu_412-2_pn:-`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-400_cpu_414-3_pn%2fdp:-`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-400_cpu_414f-3_pn%2fdp:-`,
        fs:  `cpe:2.3:a:umn:mapserver:4.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-400_cpu_416-3_pn%2fdp:-`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7-400_cpu_416f-3_pn%2fdp:-`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7-400_cpu_firmware:6.0.1`,
        fs:  `cpe:2.3:a:oracle:jserver:8.1.7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7-400_cpu_firmware:6.0.2`,
        fs:  `cpe:2.3:h:d-link:dsr-250n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7-400_cpu_firmware:6.0.3`,
        fs:  `cpe:2.3:a:webtrends:geotrends:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7_1200_cpu:-`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7_1200_cpu_firmware:4.0`,
        fs:  `cpe:2.3:a:florian_balmer:notepad2:4.2.25_:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_s7_cfc:8.0:sp4`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_s7_cfc:8.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7_cpu-1211c:-`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7_cpu_1200_firmware:2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7_cpu_1200_firmware:3.0`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7_cpu_1200_firmware:3.0.2`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:simatic_s7_cpu_1200_firmware:4.0`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp3:express_advanced_services:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7_cpu_1212c:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7_cpu_1214c:-`,
        fs:  `cpe:2.3:a:vips:vips:7.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7_cpu_1215c:-`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:simatic_s7_cpu_1217c:-`,
        fs:  `cpe:2.3:a:citrix:presentation_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_step_7:5.5`,
        fs:  `cpe:2.3:a:ibm:security_guardium:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_step_7:5.5:sp1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.341:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_step_7:5.5:sp2`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_step_7:5.5:sp3`,
        fs:  `cpe:2.3:a:profile2_privacy_project:profile2_privacy:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_step_7:5.5:sp4`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_step_7:12.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_step_7:13.0:sp1`,
        fs:  `cpe:2.3:a:brian_akers:mod_layout:2.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_wincc_runtime:-::~~advanced~~~`,
        fs:  `cpe:2.3:h:supermicro:x9srw-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_wincc_sm%40rtclient:1.0`,
        fs:  `cpe:2.3:a:youtube_embed_project:youtube_embed:3.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_wincc_sm%40rtclient:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simatic_wincc_sm%40rtclient_lite:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:simotion_scout:4.3:sp1`,
        fs:  `cpe:2.3:a:adcillc:simplemeta:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g110:-`,
        fs:  `cpe:2.3:a:gemalto:integrator:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g110d:-`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp2:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g120:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g120c:-`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:2008.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g120d:-`,
        fs:  `cpe:2.3:a:otrs:faq:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g120p:-`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:6.9.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g130:-`,
        fs:  `cpe:2.3:a:logitech:audio_echo_cancellation_component:10.51.2027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g150:-`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_g180:-`,
        fs:  `cpe:2.3:a:spice_project:spice:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:sinamics_s%2fg_family_firmware:4.6`,
        fs:  `cpe:2.3:a:apport_project:apport:2.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:sinamics_s%2fg_family_firmware:4.6.11`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:sinamics_s%2fg_family_firmware:4.7`,
        fs:  `cpe:2.3:a:apple:itunes:10.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_s110:-`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_s120:-`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_s120cm:-`,
        fs:  `cpe:2.3:a:matrikonopc:scada_dnp3_opc_server:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:sinamics_s150:-`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:sinema_server:12.0:-`,
        fs:  `cpe:2.3:a:redhat:kdelibs:3.0.0-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:sinema_server:12.0:sp1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:spc4000:-`,
        fs:  `cpe:2.3:a:polycom:cma_system_software:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:spc4000_firmware:3.5.9`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:spc5000:-`,
        fs:  `cpe:2.3:a:teradata:named_pipes_access_module:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:spc5000_firmware:3.5.9`,
        fs:  `cpe:2.3:a:barracuda:web_filter:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:spc6000:-`,
        fs:  `cpe:2.3:a:isc:bind:9.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:spc6000_firmware:3.5.9`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1:4.1:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:spcanywhere:1.4::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:yandex.metrics_project:yandex_metrics:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:spcanywhere:1.4.1::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:project_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:speedstream_wireless_router:-`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:starter:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:synco_ozw_web_server:ozw672.01`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:synco_ozw_web_server:ozw672.04`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.28:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:synco_ozw_web_server:ozw672.16`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:synco_ozw_web_server:ozw772.01`,
        fs:  `cpe:2.3:h:hp:5000_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:synco_ozw_web_server:ozw772.04`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:synco_ozw_web_server:ozw772.16`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.14:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:synco_ozw_web_server:ozw772.250`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siemens:synco_ozw_web_server:ozw775`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:synco_ozw_web_server_firmware:3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1yb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:siemens:synco_ozw_web_server_firmware:4.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:teamcenter%27s_application_sharing:8.1.9280`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:teamcenter%27s_community_collaboration:8.1.0`,
        fs:  `cpe:2.3:a:altiris:language_pack_for_patch_management_dell_for_linux:6.2.1015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:teamcenter_visualization:8.0.9085`,
        fs:  `cpe:2.3:a:asg:asg_report.web_insight_viewer:3.2.1_\(build_367\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:ugslicensing:4.0.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.1-15:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:5.0:sp1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:6.0`,
        fs:  `cpe:2.3:h:cisco:nexus_5548p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:6.0:sp2`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:6.0:sp3`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.595:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:6.0:sp4`,
        fs:  `cpe:2.3:a:google:chrome:17.0.933.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:7.0`,
        fs:  `cpe:2.3:a:estrongs:es_file_explorer:3.1.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:7.0:sp1`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:7.0:sp2`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:7.0:sp3`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:7.1`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:7.1:sp1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0089:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:7.2`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:7.3`,
        fs:  `cpe:2.3:a:adobe:dreamweaver_cs5.5:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc:13.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siemens:wincc_tia_portal:11.0`,
        fs:  `cpe:2.3:h:siemens:cfmw1025:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierra_wireless:sierra_wireless_aircard_760s:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.1:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierra_wireless:sierra_wireless_aircard_762s:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p354:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierra_wireless:sierra_wireless_aircard_763s:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_at%26t:-`,
        fs:  `cpe:2.3:h:hp:0235a391:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_at%26t_wifi:-`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_bell:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_bell_wifi:-`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_row:-`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_row_wifi:-`,
        fs:  `cpe:2.3:a:searchblox:searchblox:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_sprint:-`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.32:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_sprint_wifi:-`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_telus:-`,
        fs:  `cpe:2.3:a:trillian:trillian:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_telus_wifi:-`,
        fs:  `cpe:2.3:h:supermicro:x9drh-if:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_verizon:-`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.1\(8\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:airlink_mp_verizon_wifi:-`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.0.p-fh-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:pinpoint_x:-`,
        fs:  `cpe:2.3:o:netbsd:netbsd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:pinpoint_xt:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:raven_x:-`,
        fs:  `cpe:2.3:a:dell:idrac6_firmware:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:raven_x_ev-do:-`,
        fs:  `cpe:2.3:a:corel:coreldraw_ica:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sierrawireless:raven_x_ev-do_firmware:4221_4.0.11.003`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sierrawireless:raven_x_ev-do_firmware:4228_4.0.11.003`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:raven_xe:-`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sierrawireless:raven_xt:-`,
        fs:  `cpe:2.3:a:redmine:redmine:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sierrawireless:sierra_wireless_ac595_firmware_update_package:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sierrawireless:sierra_wireless_ac595u_firmware_update_package:1.0`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sierrawireless:sierra_wireless_watcher:5.0.2258.4`,
        fs:  `cpe:2.3:h:nvidia:geforce_gtx_1060:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sierrawireless:sprint_pcs_connection_manager:3.2.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p246_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:expert_advisor%2fvision:7.0.3`,
        fs:  `cpe:2.3:a:emc:networker:8.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2000_datacenter:6.2.904`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2000_datacenter:6.3.502`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2000_server:6.3.403`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2000_server:6.3.405`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2000_server:6.3.407`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2003_server:6.3.1700`,
        fs:  `cpe:2.3:a:gajim:gajim:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2003_server:6.3.1701`,
        fs:  `cpe:2.3:a:mautic:mautic:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2003_server:6.3.1702`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sightlinesystems:power_agent_for_windows_2003_server:6.3.1705`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sightspeed:sightspeed:6.0_%286564%29`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sigmatel:c-major_audio:5.10.4600.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sigmatel:c-major_audio:5.10.4803.0`,
        fs:  `cpe:2.3:a:hp:performance_center:12.50:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sigmatel:c-major_audio:5.10.4820.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sigmatel:c-major_audio:5.10.5102.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sigmatel:c-major_audio:5.10.5210.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p262:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sigmatel:c-major_audio:42xx`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sigong_ebook_project:sigong_ebook:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sil:graphite2:1.2.4`,
        fs:  `cpe:2.3:h:intel:carrier_grade_server_tsrlt2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sil:graphite2:1.3.5`,
        fs:  `cpe:2.3:a:redhat:developer_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silanis:approveit_desktop:6.10.10.1000`,
        fs:  `cpe:2.3:a:quickmobile:ncci\&#39;s_annual_issues_symposium:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:silanis:approveit_desktop:6.50.25.1000`,
        fs:  `cpe:2.3:a:ginkgo-cms:ginkgocms:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silanis:approveit_desktop:7.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.26.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silanis:approveit_desktop:7.3`,
        fs:  `cpe:2.3:a:microsoft:visio_viewer:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silanis:approveit_desktop:8.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silanis:approveit_lotus_fix:2.0`,
        fs:  `cpe:2.3:a:salome-platform:salome:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silanis:approveit_xhtml_signature_module:2.1`,
        fs:  `cpe:2.3:a:microsoft:personal_web_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silberfish:sfimageresize:1.3.1::~~personal~~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.6.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:silex:sx-2000wg:-`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:silex:sx-2000wg_firmware:1.5.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.37:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:silex:sx-2000wg_firmware:1.5.4`,
        fs:  `cpe:2.3:a:vanilla_perl_project:strawberry_perl:5.10.256:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silexlabs:silex:2.0.0:-`,
        fs:  `cpe:2.3:a:php:php:5.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silexlabs:silex:2.0.0:alpha5`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silver-peak:vx:6.2.2.0_47968`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silver-peak:vx:6.2.4`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.0`,
        fs:  `cpe:2.3:a:ultimus:ultimus_business_process_management_suite:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.0:rc1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.1.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.0:rc2`,
        fs:  `cpe:2.3:a:apple:motion:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.0:rc3`,
        fs:  `cpe:2.3:o:iodata:rockdisk_firmware:1.04b-1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)sy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.1:rc1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.1:rc2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.43:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.3`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.4`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.5`,
        fs:  `cpe:2.3:a:cisco:email_security_virtual_appliance:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.6`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.7`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.8`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.9`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.10`,
        fs:  `cpe:2.3:a:lxml:lxml:3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.11`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.12`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.3.13`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.4.0`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.4.1`,
        fs:  `cpe:2.3:a:ca:introscope_workstation:8.2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.4.2`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_43:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.4.3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.4.4`,
        fs:  `cpe:2.3:a:microsoft:ie_toolbar:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.4.5`,
        fs:  `cpe:2.3:o:windriver:wrlinux:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.4.6`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:2.4.7`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.0.0`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.0.1`,
        fs:  `cpe:2.3:a:rockwellautomation:rslogix_5000_design_and_configuration_software:20.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)sl9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.0.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.1.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.1.15`,
        fs:  `cpe:2.3:a:ibm:net.commerce_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.2.0`,
        fs:  `cpe:2.3:o:huawei:s5700_firmware:v200r009c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.4.3`,
        fs:  `cpe:2.3:a:ca:anti-spyware:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.5.0`,
        fs:  `cpe:2.3:a:microsoft:powerpoint:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:silverstripe:silverstripe:3.5.1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.0:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:simbiotnetwork:simgene:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simgear:simgear:1.9.1`,
        fs:  `cpe:2.3:h:hp:t510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simgear:simgear:2.0.0`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simgear:simgear:2.6.0`,
        fs:  `cpe:2.3:a:avast:internet_security:11.1.2241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simgear:simgear:2.6.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)w5\(21\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.0`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.2`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.3`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.4`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.4:beta1`,
        fs:  `cpe:2.3:a:avast:business_security:11.1.2245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.4:beta2`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.4:beta3`,
        fs:  `cpe:2.3:a:lxml:lxml:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.4.1`,
        fs:  `cpe:2.3:a:adobe:bridge_cs4:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.4.1_01`,
        fs:  `cpe:2.3:a:microsoft:directx_files_viewer_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.4.2`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.3.5:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.4.2_01`,
        fs:  `cpe:2.3:h:xerox:workcentre:7665:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.5`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.5:beta1`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cpu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.5:beta2`,
        fs:  `cpe:2.3:a:docker:docker:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.5:beta3`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.5.1`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.6`,
        fs:  `cpe:2.3:a:google:sketchup:8.0:maintenance_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.6:beta1`,
        fs:  `cpe:2.3:a:ows:scald:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.6:beta2`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.6:beta3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.1.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.6.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.7`,
        fs:  `cpe:2.3:o:buffalotech:wsr-1166dhp_firmware:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.7:beta1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.7.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.7.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.8`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.17:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:1.9`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.0`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.3.1:rev38906:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.0.0:m1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.0:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.0.0:m2`,
        fs:  `cpe:2.3:a:drupal:drupal:6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.0.0:m3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.0.0:rc1`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.0.0:rc2`,
        fs:  `cpe:2.3:a:samsung:samsung_monsetup:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.0.1`,
        fs:  `cpe:2.3:a:ninjakiwi:sas\:_zombie_assault_3:2.56:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.1`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.1:rc1`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.2`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.3`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.0.120.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.3.1`,
        fs:  `cpe:2.3:a:symantec:workspace_streaming:6.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.3.2`,
        fs:  `cpe:2.3:a:digium:asterisk:10.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.4`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.4:rc2`,
        fs:  `cpe:2.3:o:cisco:staros:14.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.5`,
        fs:  `cpe:2.3:a:sybase:powerbuilder_virtual_machine:11.5.0.2506:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.5:m1`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.5:m2`,
        fs:  `cpe:2.3:h:dell:remote_access_card:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.5:rc1`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.5.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.5.2`,
        fs:  `cpe:2.3:a:shavlik:netchk_compliance:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.5.3`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc3:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.6`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:3.0:unknown:unknown:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.6:m1`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.2:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.6.1`,
        fs:  `cpe:2.3:a:hp:storageworks_secure_path:4.0c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.6.2`,
        fs:  `cpe:2.3:a:suse:suse_email_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.6.3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:pre.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_brown:pebble:2.6.4`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.16.0`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.16.1`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.16.2`,
        fs:  `cpe:2.3:a:netiq:snmp_trap_receiver:1.2.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.16.3`,
        fs:  `cpe:2.3:a:logitech:setpoint:6.30.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.16.4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.16.5`,
        fs:  `cpe:2.3:a:nvidia:nview_desktop_manager:6.14.10.13530:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.16.6`,
        fs:  `cpe:2.3:a:cimon:ultimateaccess:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.17.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.17.1`,
        fs:  `cpe:2.3:a:microsoft:excel:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.17.2`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.17.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_mcvittie:telepathy_gabble:0.17.4`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:6.x-2.0`,
        fs:  `cpe:2.3:a:hp:enterprise_maps:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:6.x-2.1`,
        fs:  `cpe:2.3:a:google:v8:3.24.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:6.x-2.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:6.x-2.3`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:6.x-2.4`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ebx:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:6.x-2.5`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.0.174:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:6.x-2.6`,
        fs:  `cpe:2.3:a:oracle:jre:8.0:update_74:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:7.x-2.0`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:7.x-2.1`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_rycroft:hashcash:7.x-2.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:-`,
        fs:  `cpe:2.3:a:finalbeta:mywebsearch:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.45`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.3:*:*:*:*:aix:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.46`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.47`,
        fs:  `cpe:2.3:a:isc:bind:9.2.4:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.48`,
        fs:  `cpe:2.3:a:google:chrome:6.0.418.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.49`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.50`,
        fs:  `cpe:2.3:a:openx:openx:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.51`,
        fs:  `cpe:2.3:a:google:chrome:54.0.2840.68:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.52`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.53`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.53:b`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.1:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.53b`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.54`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.55`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3a.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.56`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.57`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.58`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.59`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.60`,
        fs:  `cpe:2.3:a:polycom:realpresence_capture_station_software:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.61`,
        fs:  `cpe:2.3:h:axis:700_network_document_server:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.62`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.63`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p389:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.65`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:0.66`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:4.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simon_tatham:putty:2010-06-01:r8967:~~development_snapshot~~~`,
        fs:  `cpe:2.3:a:perl:perl:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simone_tellini:mod_accounting:0.5`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simpel-reserveren_project:simpel-reserveren:3.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_l35e_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simpilotgroup:pop_up_news:2.0`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_ads_manager_project:simple_ads_manager:2.5.94::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:poi:3.7:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_ads_manager_project:simple_ads_manager:2.5.96::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_ads_manager_project:simple_ads_manager:2.6.94::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tincan:phplist:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_email_form_project:simple_email_form:1.8.5::~~~joomla%21~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_php_agenda_project:simple_php_agenda:2.2.8`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_popup_project:simple_popup:-:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:macromedia:flash_player:5.0_r50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_retail_menus_plugin_project:simple-retail-menus:4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:http_server:6.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_retail_menus_plugin_project:simple-retail-menus:4.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:piriform:ccleaner:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_retail_menus_plugin_project:simple-retail-menus:4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_sticky_footer_project:simple_sticky_footer:1.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atom:electron:0.33.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_subscription_project:simple_subscription:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_subscription_project:simple_subscription:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:yahoo:yui:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simple_visitor_stat_project:simple_visitor_stat:-::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4o\)e2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simpleflickr_project:simpleflickr:3.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:poker_puzzle_project:poker_puzzle:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:simplehrm:simplehrm:2.2`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplehrm:simplehrm:2.3`,
        fs:  `cpe:2.3:a:samba:samba:3.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.1::~~~python~~`,
        fs:  `cpe:2.3:h:supermicro:h8dg6-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.3::~~~python~~`,
        fs:  `cpe:2.3:a:git-scm:git:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.5::~~~python~~`,
        fs:  `cpe:2.3:a:polycom:dma_system_software:2.1.0j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.6::~~~python~~`,
        fs:  `cpe:2.3:a:welcart:welcart_plugin:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.7::~~~python~~`,
        fs:  `cpe:2.3:a:libmms_project:libmms:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.7.1::~~~python~~`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.7.2::~~~python~~`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.13:ga7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.7.4::~~~python~~`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.7.5::~~~python~~`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.8::~~~python~~`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.2.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.8.1::~~~python~~`,
        fs:  `cpe:2.3:a:isc:bind:9.2.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.9::~~~python~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.9.1::~~~python~~`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:17.0.4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.9.2::~~~python~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:1.9.3::~~~python~~`,
        fs:  `cpe:2.3:a:atcom:netvolution:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.0::~~~python~~`,
        fs:  `cpe:2.3:a:kryo:iodine:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.1::~~~python~~`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.2::~~~python~~`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:6.01.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.3::~~~python~~`,
        fs:  `cpe:2.3:a:skype:skype:3.6.0.159:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.4::~~~python~~`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.5::~~~python~~`,
        fs:  `cpe:2.3:a:macromedia:shockwave:10.1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.6::~~~python~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.7::~~~python~~`,
        fs:  `cpe:2.3:a:syndeocms:syndeocms:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.8::~~~python~~`,
        fs:  `cpe:2.3:a:acme:thttpd:2.20:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.0.9::~~~python~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.12.333:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.0::~~~python~~`,
        fs:  `cpe:2.3:a:hp:c4100_help:70.0.231.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.0:rc1:~~~python~~`,
        fs:  `cpe:2.3:h:panasonic:workio_digital_multifunction_copier:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.0:rc2:~~~python~~`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.1::~~~python~~`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.2::~~~python~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.3::~~~python~~`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.4::~~~python~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.5::~~~python~~`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.1.6::~~~python~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.2.0::~~~python~~`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.2.1::~~~python~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.3.0::~~~python~~`,
        fs:  `cpe:2.3:a:rack_project:rack:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.3.1::~~~python~~`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.3.2::~~~python~~`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.3.3::~~~python~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.4.0::~~~python~~`,
        fs:  `cpe:2.3:a:gnu:gnats:3.113.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.5.0::~~~python~~`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.5.1::~~~python~~`,
        fs:  `cpe:2.3:a:golosinassimpson:golosinas_simpson1:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.5.2::~~~python~~`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_telus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.6.1::~~~python~~`,
        fs:  `cpe:2.3:a:cisco:unified_ccx:7.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:2.6.2::~~~python~~`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.0::~~~python~~`,
        fs:  `cpe:2.3:h:huawei:te30:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.1::~~~python~~`,
        fs:  `cpe:2.3:a:iss:blackice_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.2::~~~python~~`,
        fs:  `cpe:2.3:a:apache:wink:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.3::~~~python~~`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.4::~~~python~~`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.5::~~~python~~`,
        fs:  `cpe:2.3:o:y-cam:ycw003_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.6::~~~python~~`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.7::~~~python~~`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.8::~~~python~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.0.9::~~~python~~`,
        fs:  `cpe:2.3:a:adobe:photoshop:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.1.0::~~~python~~`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.1.1::~~~python~~`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.1.2::~~~python~~`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.1.3::~~~python~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.2.0::~~~python~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.9:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.3.0::~~~python~~`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.3.1::~~~python~~`,
        fs:  `cpe:2.3:a:newsoftinc:presto\!_pagemanager:7.15.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.3.2::~~~python~~`,
        fs:  `cpe:2.3:a:umn:mapserver:6.4.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.3.3::~~~python~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.4.0::~~~python~~`,
        fs:  `cpe:2.3:a:oracle:sun_java_system_access_manager_policy_agent:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.5.0::~~~python~~`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.5.1::~~~python~~`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.5.2::~~~python~~`,
        fs:  `cpe:2.3:o:d-link:dap-2230_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.5.3::~~~python~~`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.6.0::~~~python~~`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.1\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.6.1::~~~python~~`,
        fs:  `cpe:2.3:a:hp:event_monitoring_service:a.04.20.11.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.6.2::~~~python~~`,
        fs:  `cpe:2.3:a:microsoft:ie:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.6.3::~~~python~~`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.6.4::~~~python~~`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.6.5::~~~python~~`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.7.0::~~~python~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.7.1::~~~python~~`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.7.2::~~~python~~`,
        fs:  `cpe:2.3:a:plone:plone:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.7.3::~~~python~~`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6:\(2a\)su2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.8.0::~~~python~~`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.8.1::~~~python~~`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3.0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.8.2::~~~python~~`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:3.0\(2c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.9.0::~~~python~~`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.10.0::~~~python~~`,
        fs:  `cpe:2.3:a:me_aliases_project:me_aliases:6.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.11.0::~~~python~~`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.11.1::~~~python~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:cs:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.12.0::~~~python~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.12.1::~~~python~~`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.13.0::~~~python~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.13.1::~~~python~~`,
        fs:  `cpe:2.3:a:vmware:ovf_tool:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplejson_project:simplejson:3.13.2::~~~python~~`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:2.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplelife_project:simplelife:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hummingbird:hostexplorer:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0`,
        fs:  `cpe:2.3:a:apache:groovy:2.4.0:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0:beta4`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:5.5:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0:beta4.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0:beta5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0:beta6`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0:rc1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0:rc2`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update24:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.0.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.2`,
        fs:  `cpe:2.3:a:opscode:chef:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.3`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.4`,
        fs:  `cpe:2.3:o:sun:sunos:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.5`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.6`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.0.161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.7`,
        fs:  `cpe:2.3:a:debian:apt:0.8.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.8`,
        fs:  `cpe:2.3:a:web-dorado:spider_calendar:1.4.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.10`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(2q\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.12`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.13`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.14`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.15`,
        fs:  `cpe:2.3:a:avaya:unified_communication_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.16`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.17`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.0.1:cf2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.18`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.5:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.19`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.20`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.21`,
        fs:  `cpe:2.3:a:actividentity:activcard_gold_for_cac:2.200.66.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.22`,
        fs:  `cpe:2.3:a:apache:traffic_server:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.0.23`,
        fs:  `cpe:2.3:a:horde:groupware:5.0.5:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1`,
        fs:  `cpe:2.3:a:vmware:esx_server:1.5.2:patch2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1:beta1`,
        fs:  `cpe:2.3:a:debian:internet_message:141-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1:beta2`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1:beta3`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1:beta4`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.038_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1:rc1`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1:rc2`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1:rc3`,
        fs:  `cpe:2.3:a:redhat:jboss_weld:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.1`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.2`,
        fs:  `cpe:2.3:o:huawei:5710ei_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.3`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.4`,
        fs:  `cpe:2.3:a:amazon:flexible_payments_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.5`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.6`,
        fs:  `cpe:2.3:a:ssh:secure_shell:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.7`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.05.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.8`,
        fs:  `cpe:2.3:a:qemu:qemu:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.9`,
        fs:  `cpe:2.3:a:david_king:vino:2.25.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.10`,
        fs:  `cpe:2.3:a:kde:koffice:2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.11`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.12`,
        fs:  `cpe:2.3:a:devsaran:responsive_blog:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.13`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.14`,
        fs:  `cpe:2.3:h:cisco:vpn_3020_concentrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.15`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.16`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:1.1.17`,
        fs:  `cpe:2.3:a:symantec:encryption_management_server:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:beta1`,
        fs:  `cpe:2.3:a:shiromuku:guestbook:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:beta2`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:beta2.1`,
        fs:  `cpe:2.3:a:checkpoint:express:ci_r57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:beta3`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:beta3.1`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.48:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:beta4`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.8.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:rc1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:rc2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.251:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:rc3`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:rc4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0:rc5`,
        fs:  `cpe:2.3:a:idleman:leed:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0.2`,
        fs:  `cpe:2.3:a:symantec:vrtsccg:5.0.281:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0.3`,
        fs:  `cpe:2.3:a:redhat:linux_powertools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.398:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.0.6`,
        fs:  `cpe:2.3:h:elecsyscorp:director_industrial_communication_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplemachines:simple_machines_forum:2.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-07-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.0:beta2`,
        fs:  `cpe:2.3:a:hp:solution_center:82.0.188.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.0:beta3`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.0:beta4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.1`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.2`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.3`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.4`,
        fs:  `cpe:2.3:a:7t:termis:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2013.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplerealtytheme:advanced_text_widget_plugin:2.0.1`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplerealtytheme:advanced_text_widget_plugin:2.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplerealtytheme:advanced_text_widget_plugin:2.0.3`,
        fs:  `cpe:2.3:h:rim:blackberry_7270:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplerealtytheme:advanced_text_widget_plugin:2.0.4`,
        fs:  `cpe:2.3:a:ibm:db2:11.1:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplerisk:simplerisk:20130915-001`,
        fs:  `cpe:2.3:a:symantec:vrtsperl:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simplerisk:simplerisk:20130916-001`,
        fs:  `cpe:2.3:a:videowhisper:live_streaming_integration_plugin:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:simulationexams:itesetup:1.0.0`,
        fs:  `cpe:2.3:o:tp-link:archer_c7_\(2.0\)_firmware:141110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sincerely:ink_cards:2.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:singaporemotherhood:singaporemotherhood_forum:3.6.6::~~~android~~`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.8g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:siphon:siphone_enterprise_pbx:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sir:gnuboard:4.31.3`,
        fs:  `cpe:2.3:a:gajim:gajim:0.12.5:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sir:gnuboard:4.31.4`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.11.0:*:*:*:oss:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sir:gnuboard:4.33.2`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sir:gnuboard:4.34.20`,
        fs:  `cpe:2.3:a:pixman:pixman:0.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sir:gnuboard:4.34.21`,
        fs:  `cpe:2.3:a:arclogics:cch_teammate_desktop:9.1.0.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sir:gnuboard:5.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sirana:appanalyzer:4.1.0`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.50`,
        fs:  `cpe:2.3:a:projectsend:projectsend:161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.55`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.60`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.65`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.70`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.80`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.85`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.90`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:0.95`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.31.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.0`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.0:rc1`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.8:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.2`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.35:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.3`,
        fs:  `cpe:2.3:a:intel:mpfwiz:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.4`,
        fs:  `cpe:2.3:a:novell:zenworks_desktop_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.4.1`,
        fs:  `cpe:2.3:a:tincan:phplist:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.4.2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1045.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5`,
        fs:  `cpe:2.3:a:adobe:connect:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.1`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.2`,
        fs:  `cpe:2.3:a:libexpat:expat:1.95.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.3`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.4`,
        fs:  `cpe:2.3:a:luke_kenneth_casson_leighton:pam_ntdom:0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.5`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.6`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.7`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:08-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.8`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:1.5.9`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:3.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:3.01`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:3.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:3.02`,
        fs:  `cpe:2.3:a:google:chrome:14.0.820.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:3.03`,
        fs:  `cpe:2.3:a:prestosoft:examdiff:1.8.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitaram_chamarty:gitolite:3.04`,
        fs:  `cpe:2.3:a:path_breadcrumbs_project:path_breadcrumbs:7.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:site_banner_project:site_banner:7.x-4.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:site2nite:auto_e-manager:-`,
        fs:  `cpe:2.3:a:gnu:tar:1.13.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:site2nite:big_truck_broker:-`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sitecom:wl-111:-`,
        fs:  `cpe:2.3:a:blaine_lang:maestro:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sitecom:wl-153:-`,
        fs:  `cpe:2.3:a:niif:shibboleth_authentication:6.x-4.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:sitecom:wl-153_router_firmware:1.31`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.226:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sitecom:wl-153_router_firmware:1.34`,
        fs:  `cpe:2.3:a:devsaran:responsive:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sitecom:wl-174:-`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_management_console:10.0.13545:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sitecom:wlm-2501:-`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitecore:cms:7.0:3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_agent_for_sharepoint:2010:-`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_federation:12.0:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_federation:12.0:-:standalone`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.19.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_federation:12.1:-:standalone`,
        fs:  `cpe:2.3:a:cb_-_calciatori_brutti_project:cb_-_calciatori_brutti:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_federation:12.5:-`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_federation:r6.0:-`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_for_secure_proxy_server:12.0:-`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_for_secure_proxy_server:12.5:-`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:siteminder_for_secure_proxy_server:6.0:-`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.8.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitepark:information_enterprise_server:2.9`,
        fs:  `cpe:2.3:a:kallithea:kallithea:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitepark:information_enterprise_server:2.9.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:1.8.00`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:2.8.00`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.00`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.00:beta1`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.00:beta2`,
        fs:  `cpe:2.3:o:debian:debian_linux:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.00:beta3`,
        fs:  `cpe:2.3:a:logitech:quickcam_software:8.47.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.01`,
        fs:  `cpe:2.3:h:siemens:scalance_xf-200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.02`,
        fs:  `cpe:2.3:a:vips:vips:7.11.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.03`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.03a`,
        fs:  `cpe:2.3:a:safenet-inc:safenet_authentication_service_outlook_web_access_agent:1.03.20212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.04a`,
        fs:  `cpe:2.3:a:mcafee:siteadvisor_enterprise:1.7.0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.05`,
        fs:  `cpe:2.3:a:sagepay:sage_pay_direct_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.06`,
        fs:  `cpe:2.3:o:cray:unicos:9.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.6`,
        fs:  `cpe:2.3:a:microsoft:word:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.07`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.45`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.45:beta1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.50`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.50:beta1`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_enterasys:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.51`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.60`,
        fs:  `cpe:2.3:a:oracle:javafx:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.61`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.62`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.13:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.63`,
        fs:  `cpe:2.3:o:suse:suse_linux:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.63:beta1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.64`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ebj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:3.65`,
        fs:  `cpe:2.3:a:google:chrome:4.0.239.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:4.8.00`,
        fs:  `cpe:2.3:a:deepnetexplorer:deepnet_explorer:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:7.8.00`,
        fs:  `cpe:2.3:a:sybase:powerbuilder_virtual_machine:11.5.1.4922:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:8.8.00`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:9.8.00`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:10.8.00`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:11.8.00`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:14.8.00`,
        fs:  `cpe:2.3:a:vmware:fusion:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:16.8.00`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:17.8.00`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(26\)w5\(28\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:18.8.00`,
        fs:  `cpe:2.3:h:hp:psc_1300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:21.8.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sitracker:support_incident_tracker:31.07.00`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:3.2::open_source`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.43:devel:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0`,
        fs:  `cpe:2.3:a:skyarc:duplicateentry:1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:beta`,
        fs:  `cpe:2.3:a:apple:pdfkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:beta2`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:beta3`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:1.3.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:beta4`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:beta5`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:beta6`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:beta7`,
        fs:  `cpe:2.3:a:breezy:breezy:1.2.4:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:rc1`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:rc2`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.0:rc3`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.39:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.01`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p248_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(9a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.1:beta`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.01:beta`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.01:beta2`,
        fs:  `cpe:2.3:a:cracklib_project:cracklib:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.1:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)xt3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.1:rc1`,
        fs:  `cpe:2.3:a:intra-mart:webplatform\/appframework:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.01:rc1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.35.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.2`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.2:rc2`,
        fs:  `cpe:2.3:a:samba:samba:4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.2:rc4`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:7.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.2:rc5`,
        fs:  `cpe:2.3:a:vips:vips:7.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.12`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.15:beta1`,
        fs:  `cpe:2.3:a:sun:iplanet_directory_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.15:beta3`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.15:beta4`,
        fs:  `cpe:2.3:a:qemu:qemu:2.0.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.21`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.22`,
        fs:  `cpe:2.3:a:microsoft:powerpoint_rt:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.23`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.24`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.25`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.26`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.27`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.28`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.28::enterprise`,
        fs:  `cpe:2.3:a:boost:boost:1.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.28::open_source`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.29`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.29::enterprise`,
        fs:  `cpe:2.3:a:ibm:informix_open_admin_tool:3.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.29::open_source`,
        fs:  `cpe:2.3:a:adobe:connect:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.31`,
        fs:  `cpe:2.3:a:vmware:converter_enterprise_client:4.0.3.62417:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.32`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.33`,
        fs:  `cpe:2.3:a:taxonews_project:taxonews:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.34`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.35`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:9.0\(2\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.36`,
        fs:  `cpe:2.3:a:cisco:catalyst_29xx_supervisor_software:2.1.501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.36::open_source`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.37`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.37::open_source`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.38`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.62.020.3058:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.38::open_source`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.261`,
        fs:  `cpe:2.3:a:teradata:administrator:13.10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.291`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.30.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.291::enterprise`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.291::open_source`,
        fs:  `cpe:2.3:a:plohni:advanced_comment_system:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.292`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x4170_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.292::enterprise`,
        fs:  `cpe:2.3:a:google:chrome:12.0.725.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.292::open_source`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.361`,
        fs:  `cpe:2.3:a:ibm:daeja_viewone:5.0:*:*:*:virtual:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:4.361::open_source`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0::open_source`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0:beta1`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.825.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0:beta3`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.6\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0:beta4`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0:rc1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-02-\/g:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0:rc2`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.0:rc3`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp4:terminal_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.1`,
        fs:  `cpe:2.3:a:soapmakingforum:soap_making:3.7.13:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.01`,
        fs:  `cpe:2.3:a:foxitsoftware:reader:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.1::advanced`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.1\(2.49\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.01::open_source`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.1::open_source`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.1:beta`,
        fs:  `cpe:2.3:a:gitlist:gitlist:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.1:rc1`,
        fs:  `cpe:2.3:a:janetter:janetter:1.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.02`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.037:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.02::advanced`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.02::open_source`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(9\)p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.2`,
        fs:  `cpe:2.3:a:collabnet:subversion_server:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.3`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.4`,
        fs:  `cpe:2.3:a:winscp:winscp:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.5`,
        fs:  `cpe:2.3:a:php:pear:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.6`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.7`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.1\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.8`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.9`,
        fs:  `cpe:2.3:a:sun:grid_engine:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.2.10`,
        fs:  `cpe:2.3:a:wordpress:wordpress:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.03`,
        fs:  `cpe:2.3:a:php:php:4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.04`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp1:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.04::advanced`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.03:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.04::open_source`,
        fs:  `cpe:2.3:h:schneider-electric:bmxp342020:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.05`,
        fs:  `cpe:2.3:a:symantec:vrtsccg:5.0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.05::advanced`,
        fs:  `cpe:2.3:a:novell:http_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.05::open_source`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.06`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.06::advanced`,
        fs:  `cpe:2.3:a:efssoft:easy_file_sharing_web_server:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.06::open_source`,
        fs:  `cpe:2.3:a:accelatech:bizsearch:3.2:-:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.07`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.07::advanced`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.07::open_source`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.02.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.11`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_9971:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.11::advanced`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.11::open_source`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.12`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.3:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.12::advanced`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.12::open_source`,
        fs:  `cpe:2.3:a:lennart_poettering:rkit:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.13`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-167_with_network_printer_kit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.13::~~professional~~~`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.05:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.13::advanced`,
        fs:  `cpe:2.3:a:password-solutions:office_password_recovery:1.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.13::open_source`,
        fs:  `cpe:2.3:a:dotclear:dotclear:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.17`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.12.4en:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.031`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_broker:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.051`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-00-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.051::advanced`,
        fs:  `cpe:2.3:a:symantec:norton_security_scan:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:5.051::open_source`,
        fs:  `cpe:2.3:a:sun:sun_pci_ii_driver:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:6.0`,
        fs:  `cpe:2.3:a:snapone:snap_secure:9.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:6.0.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:6.0.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:6.0.3`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:3.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:6.0.4`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movable_type:6.0.5`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:3.2`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.2`,
        fs:  `cpe:2.3:a:goahead:goahead_webserver:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.2.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.2.3`,
        fs:  `cpe:2.3:a:sun:java_plug-in:1.4.2_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.2.6`,
        fs:  `cpe:2.3:a:apache:http_server:2.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.2.7`,
        fs:  `cpe:2.3:a:asus:net4switch:1.0.0020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.2.11::~~advanced~~~`,
        fs:  `cpe:2.3:a:dell:mobile_broadband_card_utility:2.05.07.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.2.11::~~open_source~~~`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.2.11::~~pro~~~`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:04-00:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.04`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.11`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.12`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4:beta:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.13`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.10f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.14`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:5.15`,
        fs:  `cpe:2.3:a:adobe:formflow_filler:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:7.00.020.3172:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:tightvnc:tightvnc:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0::~~pro~~~`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg510-25:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.1::~~advanced~~~`,
        fs:  `cpe:2.3:a:eigenwinkelapp:kiddie_kinderschoenen:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.1::~~pro~~~`,
        fs:  `cpe:2.3:a:e2fsprogs_project:e2fsprogs:1.43.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.2::~~advanced~~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.2::~~pro~~~`,
        fs:  `cpe:2.3:a:atmail:atmail:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.3::~~advanced~~~`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.3::~~pro~~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.466.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.4::~~advanced~~~`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.4::~~pro~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.5::~~advanced~~~`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:0.1:beta-4:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.5::~~pro~~~`,
        fs:  `cpe:2.3:a:appsgeyser:backyard_wrestling:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.6::~~advanced~~~`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.6::~~pro~~~`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.7::~~advanced~~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.0.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixapart:movabletype:6.0.7::~~pro~~~`,
        fs:  `cpe:2.3:a:perlmonks:module\:\:signature:0.72:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:sixdead:brain_lab_-_brain_age_games_iq:2.37::~~~android~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sixnet:rtu_firmware:4.7`,
        fs:  `cpe:2.3:a:date_project:date:7.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sixnet:sixview_manager:2.4.1`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sixnet:udr:1.9`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skalfa:skadate_lite:2.0`,
        fs:  `cpe:2.3:a:samba:samba:3.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skin_conditions_and_diseases_project:skin_conditions_and_diseases:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skout:boyahoy_-_gay_chat:4.3.6::~~~android~~`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skout:skout%3a_chats._friends._fun.:4.3.3::~~~android~~`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:0.1.0`,
        fs:  `cpe:2.3:a:pfsense:pfsense:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:0.1.1`,
        fs:  `cpe:2.3:h:cisco:mds_9500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:0.1.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc694a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:0.1.3`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.0.2`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.0.3`,
        fs:  `cpe:2.3:o:moxa:oncell_gateway_firmware:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.0.5`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.1.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.1.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.686.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.1.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.1.3`,
        fs:  `cpe:2.3:h:oracle:netra_sparc_t4-2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.1.4`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sks_keyserver_project:sks_keyserver:1.1.5`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:authoreffective:1.03`,
        fs:  `cpe:2.3:a:goomeo:sopexa_pavillon_france:3.6.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:authoreffective:1.031`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:autotagging:0.1`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:autotagging:0.08`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:duplicateentry:1.2`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_appliance:7.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:duplicateentry:1.24`,
        fs:  `cpe:2.3:a:avg:anti-virus:9.0:-:email_server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:entryimexporter:1.41`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:entryimexporter:1.42`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mailpack:1.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mailpack:1.741`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd377a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.2`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.3`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.3::enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.3::smart`,
        fs:  `cpe:2.3:a:dell:openmanage_server_agent:4.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.21`,
        fs:  `cpe:2.3:a:sun:java_db:10.3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.22`,
        fs:  `cpe:2.3:a:silanis:approveit_desktop:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.23`,
        fs:  `cpe:2.3:a:email\:\:address\:\:list_project:email\:\:address\:\:list:0.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.24`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.24::enterprise`,
        fs:  `cpe:2.3:a:haxx:curl:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.24::smart`,
        fs:  `cpe:2.3:a:allroundautomations:pl\/sql_developer:11.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.25`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:7.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.25::enterprise`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.6.4:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.25::smart`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.251`,
        fs:  `cpe:2.3:a:cisco:mediasense:8.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.251::enterprise`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.12.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.251::smart`,
        fs:  `cpe:2.3:a:hp:bufferchm:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.252`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.252::enterprise`,
        fs:  `cpe:2.3:a:cisco:webns:7.30.3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:mtcms:5.252::smart`,
        fs:  `cpe:2.3:a:intel:processor_id_utility:4.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:multifileuploader:0.44`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.50.4:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarc:multifileuploader:0.45`,
        fs:  `cpe:2.3:a:microsoft:outlook:2003:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarts:neofiler:2.4.2:-:~-~lite~android~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.01.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarts:neofiler:5.4.3:-:~-~-~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyarts:neofiler:5.4.3:-:~-~free~android~~`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboardapps:penguin_run:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.356.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view:3.0`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view:3.5`,
        fs:  `cpe:2.3:a:hp:storeonce_2620_iscsi_backup_system:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view:4.0`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view:4.5`,
        fs:  `cpe:2.3:a:avaya:secure_access_link_gateway:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view:5.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.428:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view:5.5`,
        fs:  `cpe:2.3:a:phusion:passenger:4.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view:6.0`,
        fs:  `cpe:2.3:a:php:php:5.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:skyboxsecurity:skybox_view_appliance:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yi:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view_appliance_iso:6.3.31-2.14`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view_appliance_iso:6.3.33-2.14`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view_appliance_iso:6.4.42-2.54`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view_appliance_iso:6.4.45-2.56`,
        fs:  `cpe:2.3:a:bluecoat:director:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyboxsecurity:skybox_view_appliance_iso:6.4.46-2.57`,
        fs:  `cpe:2.3:a:sybase:central:4.3.0.2314:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skydreams:prof._usman_ali_awheela:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:red-gate:sql_compare:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skydrive_assistant_project:skydrive_assistant:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:fiksu:fiksu_library:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:-`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.90.0.5:beta`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.90.0.10:beta`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.91.0.2:beta`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services_mobile:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.92.0.4:beta`,
        fs:  `cpe:2.3:a:luracast:restler:1.0.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.93.0.18:beta`,
        fs:  `cpe:2.3:a:dog_whistle_project:dog_whistle:1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.93.1.1:beta`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.08.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.94.0.19:beta`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.94.0.28:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.95.0.11:beta`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.95.0.25:beta`,
        fs:  `cpe:2.3:a:adobe:freehand:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.95.0.36:beta`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.95.0.40:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(30\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.96.0.1:beta`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.96.0.3:beta`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.07:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.97.0.1:beta`,
        fs:  `cpe:2.3:h:lexmark:e120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.97.0.3:beta`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.97.0.6:beta`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:*:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.97.0.40:beta`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.98.0.04:beta`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.98.0.6:beta`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.98.0.28:beta`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.98.0.42:beta`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:0.98.0.68:beta`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.0.0.9`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04:sp16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.0.0.10`,
        fs:  `cpe:2.3:a:panopoly_magic_project:panopoly_magic:7.x-1.16:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.0.0.18`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.0.0.29`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.0.0.94`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.0.0.97`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.0.0.100`,
        fs:  `cpe:2.3:a:erlang:erlang\/otp:r14b02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.0.0.106`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.1.0.6`,
        fs:  `cpe:2.3:a:hp:openview_radia_management_portal:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.1.0.73`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.1.0.79`,
        fs:  `cpe:2.3:a:adobe:golive:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.2.0.37`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.2.0.41`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.2.0.48`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.3.0.45`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.3.0.48`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.4.5:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.3.0.51`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.60:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.3.0.54`,
        fs:  `cpe:2.3:a:ibm:security_siteprotector_system:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.3.0.55`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:7.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.3.0.57`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.346:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.3.0.60`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.3.0.66`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.4.0.71`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.4.0.78`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.4-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:1.4.0.84`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.7.22327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.69`,
        fs:  `cpe:2.3:a:ca:cohesion_server:4.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.73`,
        fs:  `cpe:2.3:a:runtastic:runtastic_road_bike:2.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.79`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.9:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.81`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.90`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.97`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.2.53.5169:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.103`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:9.1.008.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.105`,
        fs:  `cpe:2.3:o:cisco:ios:10.3\(19a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.0.0.107`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7912g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.72`,
        fs:  `cpe:2.3:a:microsoft:systems_management_server:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.82`,
        fs:  `cpe:2.3:a:apache:solr:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.91`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:3.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.113`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.0.4.573:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.122`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.126`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp5:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.130`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.137`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.141`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.151`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.5.0.154`,
        fs:  `cpe:2.3:a:david_king:vino:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.6.0.67:beta`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_cp1525nw_color_printer:ce875a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.6.0.74:beta`,
        fs:  `cpe:2.3:a:git-scm:git:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.6.0.81:beta`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je067a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.6.0.97:beta`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.3:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.6.0.103:beta`,
        fs:  `cpe:2.3:a:adobe:reader:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:2.6.0.105:beta`,
        fs:  `cpe:2.3:a:neumann:neumann_student_activities:216607:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.106:beta`,
        fs:  `cpe:2.3:a:winzip:self-extractor:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.123:beta`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.137:beta`,
        fs:  `cpe:2.3:h:juniper:netscreen-idp:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.154:beta`,
        fs:  `cpe:2.3:o:slackware:slackware_linux:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.190`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.198`,
        fs:  `cpe:2.3:o:cisco:catos:6.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.205`,
        fs:  `cpe:2.3:o:suse:suse_linux:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.209`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.362:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.214`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.216`,
        fs:  `cpe:2.3:a:altova:missionkit_2012:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.217`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.0.0.218`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p387:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.1.0.112:beta`,
        fs:  `cpe:2.3:a:mobatek:mobaxterm:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.1.0.134:beta`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.1.0.144`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.1.0.147`,
        fs:  `cpe:2.3:h:cisco:nexus_5672up:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.1.0.150`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:5.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.1.0.152`,
        fs:  `cpe:2.3:a:vmware:workstation:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.53:beta`,
        fs:  `cpe:2.3:h:foundrynet:bigiron_800_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.63:beta`,
        fs:  `cpe:2.3:a:wave:embassy_security_center:4.2.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.82:beta`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6.3:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.115:beta`,
        fs:  `cpe:2.3:o:xen:xen:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.145`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.148`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.152`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.158`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.163`,
        fs:  `cpe:2.3:a:google:chrome:6.0.456.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.2.0.175`,
        fs:  `cpe:2.3:a:lucas_clemente_vella:libpam-pgsql:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.5.0.107:beta`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.5.0.158:beta`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.5.0.178`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.5.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.5.0.202`,
        fs:  `cpe:2.3:a:microsoft:excel:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.5.0.214`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.12:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.5.0.229`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.5.0.234`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.506:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.5.0.239`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.6.0.127:beta`,
        fs:  `cpe:2.3:a:php:php:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.6.0.159:beta`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.6.0.216`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.6.0.244`,
        fs:  `cpe:2.3:a:intel:server_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.6.0.248`,
        fs:  `cpe:2.3:a:montala:resourcespace:2.3.1374:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.8.0.96:beta`,
        fs:  `cpe:2.3:a:aliakay:aptallik_testi:4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.8.0.115`,
        fs:  `cpe:2.3:a:gnu:emacs:24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.8.0.139`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.8.0.144`,
        fs:  `cpe:2.3:a:csounds:csound:5.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.8.0.154`,
        fs:  `cpe:2.3:a:phillip_lougher:squashfs:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.8.0.180`,
        fs:  `cpe:2.3:a:php:php:5.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:3.8.0.188`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0:beta_3`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.145:beta`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.150:beta`,
        fs:  `cpe:2.3:a:cisco:prime_service_catalog:10.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.155:beta_1`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.161:beta`,
        fs:  `cpe:2.3:a:persits:xupload:2.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.166:beta_2`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.168:beta_2`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.169:beta_2`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.176:beta_3`,
        fs:  `cpe:2.3:a:posh_project:posh:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.181:beta_3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.206`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(20\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.215`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.11:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.216`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2016:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.224`,
        fs:  `cpe:2.3:a:perl:perl:5.13.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.226`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.0.0.227`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.1.0.130`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.1.0.130:beta`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.1.0.136`,
        fs:  `cpe:2.3:a:cisco:telepresence_management_suite:14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.1.0.141`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.23:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.1.0.166`,
        fs:  `cpe:2.3:a:ibm:optim_performance_manager:4.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.1.0.179`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.2.0.141:beta`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.2.0.152`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.2.0.155`,
        fs:  `cpe:2.3:a:netscape:communicator:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.2.0.158`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.30.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.2.0.163`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.2.0.166`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:4.2.0.169`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.887:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:5.0.0.105`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.45.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:5.1.112`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.008:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:5.3.111`,
        fs:  `cpe:2.3:a:codehaus:redback:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skype:skype:5.3.116`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:9.0.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:integration_bus:10.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-01-16a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:qualcomm:gobi_single_installer_package_for_zte:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5:a:~~~wordpress~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5:b:~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)yd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5:b2:~~~wordpress~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5:b3:~~~wordpress~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.15:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5:rc1:~~~wordpress~~`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:4.2.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:ie:4.72.3612.1713:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:networker:7.6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openttd:openttd:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.8:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.8:b1:~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.8:b2:~~~wordpress~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.5.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redmine:redmine:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.11:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nero:photosnap:1.53.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.0.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:condor_project:condor:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.23:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:ios:15.2\(2\)ea:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:584:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:redhat:fedora:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.6.6:beta:~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:ambari:2.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc10:~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc11:~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc12:~~~wordpress~~`,
        fs:  `cpe:2.3:o:tails_project:tails:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc13:~~~wordpress~~`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc14:~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:photoshop:6.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc3:~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc4:~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc5:~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc6:~~~wordpress~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc7:~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc8:~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_application_server_control:9.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7:rc9:~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:netmail:3.5.2d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird_esr:17.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.4:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.4:rc2:~~~wordpress~~`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.5:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.5:beta1:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:9.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.5:beta2:~~~wordpress~~`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.1.1219:unknown:online_windows_server_2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:inria:ocaml:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skyphe:file-gallery:1.7.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.0`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.01`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.02`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.1.5.3148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.03`,
        fs:  `cpe:2.3:a:juniper:junos_space:13.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.04`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.05`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.10`,
        fs:  `cpe:2.3:a:fogproject:fog:0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.15`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.17`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.7:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.18`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.19`,
        fs:  `cpe:2.3:a:citrix:receiver_hdx_flash_redirection:13.0.0.6684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.21`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.22`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.23`,
        fs:  `cpe:2.3:o:ibm:websphere_datapower_xc10_appliance_firmware:2.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.24`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.25`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.30`,
        fs:  `cpe:2.3:a:krstarica:forum_krstarice:3.5.14:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.35`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.36`,
        fs:  `cpe:2.3:h:3com:3c13613:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.40`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.45`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.50`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.55`,
        fs:  `cpe:2.3:a:apache:hadoop:2.0.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.56`,
        fs:  `cpe:2.3:h:xerox:workcentre:5623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.60`,
        fs:  `cpe:2.3:a:acidcat:acidcat_cms:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.65`,
        fs:  `cpe:2.3:a:tinysrp_project:tinysrp:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.70`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:skysa:skysa_app_bar_integration_plugin:1.75`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:7.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:7.1`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:8.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:8.1`,
        fs:  `cpe:2.3:a:surveytracker:surveytracker:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:9.0`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:9.1`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2013:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:10.0`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:10.1`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:10.2`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:11.0`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:12.0`,
        fs:  `cpe:2.3:a:atlassian:jira:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:12.1`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_tx9200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:12.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.2:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:13.0`,
        fs:  `cpe:2.3:a:microsoft:windows_script_host:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:13.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:slackware:slackware_linux:13.37`,
        fs:  `cpe:2.3:o:iij:seil\%2fx2_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slavasoft:hashcalc:2.2`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickedit:slickedit:11.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:3.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickedit:slickedit:2008`,
        fs:  `cpe:2.3:h:apple:iphone_5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.3.2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.1`,
        fs:  `cpe:2.3:a:oracle:project_contracts:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.2`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.4`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.5`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.6`,
        fs:  `cpe:2.3:o:cisco:catos:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.7`,
        fs:  `cpe:2.3:a:cdotech:edcl_asset_update:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.8`,
        fs:  `cpe:2.3:a:conky:conky:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:1.9`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1044.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.0`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u6\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.2`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.3`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.4`,
        fs:  `cpe:2.3:a:ewww_image_optimizer_plugin_project:ewww_image_optimizer_plugin:2.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.5`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.6`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.7`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.8`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90.3_p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:2.9`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:3.0`,
        fs:  `cpe:2.3:a:oracle:service_bus:12.2.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:3.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:3.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:3.3`,
        fs:  `cpe:2.3:a:fusedpress:buddypress-extended-frienship-request:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:3.4`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.3.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:3.5`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_integration_for_eclipse:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:3.6`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slickremix:design_approval_system_plugin:3.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:8.2.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.12s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:lxml:lxml:2.1:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_dell_client_manager:2.1.1004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.6\(1.10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dcraw_project:dcraw:7.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.4.8:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:boeing:drs_data_courier_web:3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:xornic:contact_us:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:lingotek:lingotek:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slideshow_project:slideshow:2.2.21::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wellintech:kingalarm\&amp;event:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sliding_social_icons_project:sliding_social_icons:1.61::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.5005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sliksvn:slik_subversion:1.6.16.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:slingo:slingo_lottery_challenge:1.0.34::~~~android~~`,
        fs:  `cpe:2.3:a:mark_burns:ldoce:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sm3ny:www.sm3ny.com:1::~~~android~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smackcoders:wp_ultimate_email_marketer_plugin:1.0.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:wireless_control_system:4.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smackcoders:wp_ultimate_email_marketer_plugin:1.0.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smackcoders:wp_ultimate_email_marketer_plugin:1.0.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:hadoop:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smackcoders:wp_ultimate_email_marketer_plugin:1.0.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:piwik:piwik:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smackcoders:wp_ultimate_email_marketer_plugin:1.1.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:h:dell:5110cn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smart-flv_plugin_project:smart-flv:-::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:aqtime:7.10.380.86::~~professional~~~`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.0`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.295.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.0:beta2`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.0.1`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:gold:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.5`,
        fs:  `cpe:2.3:a:ca:license_software:1.61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.5.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.5.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.6.0`,
        fs:  `cpe:2.3:h:apple:imac:mc413xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.6.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.6.2`,
        fs:  `cpe:2.3:a:wolfcms:wolf_cms:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.6.3`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartbear:soapui:4.6.4`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartcat:our_team_showcase:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:yokogawa:b\/m9000cs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartcatdesign:wp_contruction_mode:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:witcustomcontrols:witcustomcontrols:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartdraw:smartdraw:7.0`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartertools:smartermail:9.2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_products:8.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartertools:smarterstats:5.3`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_hmi\/scada_cimplicity:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartertools:smarterstats:5.3.3819`,
        fs:  `cpe:2.3:a:lavasoft:ad-aware:5.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartsound:common_data:1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:40.0.2214.89:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:smartsound:quicktracks:5.1.7`,
        fs:  `cpe:2.3:a:nero:nero:7.2.8637:*:*:*:ultra:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartsound:quicktracks_plugin:3.0.2.7`,
        fs:  `cpe:2.3:h:microsoft:xbox_360:4548:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartstudy:pinkfong_tv:4::~~~android~~`,
        fs:  `cpe:2.3:a:drupal:drupal:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:notebook_software:10.0.631.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:0108.2146.2565.38893:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:pmt250_risk:2.0.1.1`,
        fs:  `cpe:2.3:a:questfcu:quest_federal_cu_mobile:1.0.27:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_board_software:9.1.0.40`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_board_software:9.5.49.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_classroom_suite_student:1.0.1059.0`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_classroom_suite_teacher:1.0.1059.0`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.1:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_essentials_for_educators:1.0.27.1`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_install_manager:1.0.58.1`,
        fs:  `cpe:2.3:a:vips:vips:7.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_meeting_pro:2.2.140.0`,
        fs:  `cpe:2.3:h:ibm:x345:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_notebook:10.6.94.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttech:smart_notebook:10.7.144.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarttweak:updatemydrivers:7.0.0.147`,
        fs:  `cpe:2.3:h:hp:procurve_switch_9300m:08.0.01f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.0`,
        fs:  `cpe:2.3:a:canonical:php5:5.3.2-1ubuntu4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.0a`,
        fs:  `cpe:2.3:a:veritas:netbackup:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.0b`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.408:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.1.0`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.2.0`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow_set:07-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.2.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.2.2`,
        fs:  `cpe:2.3:a:microsoft:visio:2010:sp1:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.3.0`,
        fs:  `cpe:2.3:a:autodesk:design_review_2011:11.0.0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.3.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.3.2`,
        fs:  `cpe:2.3:a:tenable:nessus:6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.0`,
        fs:  `cpe:2.3:a:microsoft:excel:97:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.0:b1`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.0:b2`,
        fs:  `cpe:2.3:a:f5:enterprise_manager:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1002.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.146:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.4`,
        fs:  `cpe:2.3:a:symantec:mail_security:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.5`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.4.6`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90.1_p0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.5.0`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.5.1`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:1.5.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.0.0`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_enterprise_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.0.1`,
        fs:  `cpe:2.3:h:axis:2400_video_server:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.1.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.1.1`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.2.0`,
        fs:  `cpe:2.3:h:xerox:workcentre_m165:8.47.30.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.3.0`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.3.1`,
        fs:  `cpe:2.3:a:oracle:health_sciences_applications:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.4.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.4.1`,
        fs:  `cpe:2.3:a:adobe:creative_suite_5_master_collection:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.4.2`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.03.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.5.0`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.5.0:rc1`,
        fs:  `cpe:2.3:a:adobe:digital_editions:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.5.0:rc2`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.29:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.0`,
        fs:  `cpe:2.3:a:nalin_dahyabhai:vte:0.11.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.0:rc1`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.0:rc2`,
        fs:  `cpe:2.3:o:cisco:nx-os:base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.0:rc3`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.18:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.1`,
        fs:  `cpe:2.3:o:novell:open_enterprise:9:*:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.2`,
        fs:  `cpe:2.3:a:clearfishing:pescuit_crap_lite:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.3`,
        fs:  `cpe:2.3:a:atmail:atmail:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.4`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.5`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:9.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.6`,
        fs:  `cpe:2.3:o:cisco:ios:10.3\(16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.7`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.9`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.12:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.10`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.11`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.12`,
        fs:  `cpe:2.3:h:cisco:ata-186:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.13`,
        fs:  `cpe:2.3:a:oracle:retail_xstore_point_of_service:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.14`,
        fs:  `cpe:2.3:a:balanced:commerce_balanced_payments:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.15`,
        fs:  `cpe:2.3:a:adobe:air_sdk:15.0.0.302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.16`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.17`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.18`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.20`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.26.361:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.22`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.24`,
        fs:  `cpe:2.3:a:honeywell:comfortpoint_open_manager_station:r100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.25`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:2.6.26`,
        fs:  `cpe:2.3:a:cisco:unity_connection_8.5:base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0`,
        fs:  `cpe:2.3:a:hp:software_deployment:6.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:beta4`,
        fs:  `cpe:2.3:o:sun:solaris:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:beta5`,
        fs:  `cpe:2.3:h:cabletron:2h252-25r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:beta6`,
        fs:  `cpe:2.3:a:emc:isilon_insightiq:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:beta7`,
        fs:  `cpe:2.3:a:quranedu:ahmed_bukhatir_nasheeds_tv:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:beta8`,
        fs:  `cpe:2.3:a:kajona:kajona:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:rc1`,
        fs:  `cpe:2.3:a:barebones:textwrangler:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:rc2`,
        fs:  `cpe:2.3:o:mandriva:corporate_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:rc3`,
        fs:  `cpe:2.3:a:cdotech:edcl_afsdb:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.0:rc4`,
        fs:  `cpe:2.3:a:ubooly:ubooly:4.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.1`,
        fs:  `cpe:2.3:a:mit:kerberos:5_1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.836:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.4`,
        fs:  `cpe:2.3:o:siemens:ccid1445-dn28_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.5`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.6`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.0.7`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:8.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1:rc1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.4.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.0`,
        fs:  `cpe:2.3:h:asus:wl-330nul:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.1`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.2`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.3`,
        fs:  `cpe:2.3:a:att:communication_manager:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.4`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.5`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.6`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.2.0:cp02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.7`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.9`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.638:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.10`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smarty:smarty:3.1.11`,
        fs:  `cpe:2.3:a:apexoo:spider:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:sp_project_%26_document_manager:2.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:itp:harpers_bazaar_art:\@7f080181:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.0.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1073.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.0.2`,
        fs:  `cpe:2.3:a:hp:storageworks_solaris_host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.0.3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.0.4`,
        fs:  `cpe:2.3:a:trillian:trillian:3.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.0.5`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.0.7`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.0.9`,
        fs:  `cpe:2.3:h:hp:jg732a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.1.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.1.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.1.3`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.1.4`,
        fs:  `cpe:2.3:a:cisco:webns:7.40.0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smartypantsplugins:wp-funeral-press:1.1.6`,
        fs:  `cpe:2.3:h:dell:powervault_ml6020:14u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smb4k_project:smb4k:2.0.0`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:smc:smc8024l2_switch:-`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:smc:smc8024l2_switch_firmware:2.4a`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:smc:smc8024l2_switch_firmware:2.5.1.0`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.1.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:smc:smc8024l2_switch_firmware:2.5.1.5`,
        fs:  `cpe:2.3:a:ibm:data_server_client:9.7.400.501:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:5.4.0`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.3.6`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.7.1`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0.8.4985:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.7.2`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.66.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.7.3::~~rim~~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.7.8`,
        fs:  `cpe:2.3:h:intel:d845bg_motherboard:p02-0015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.9.0::~~rim~~~`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.9.1`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.9.8::~~novatel~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.10.8::~~rim~~~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.09.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.10.10`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:9.0\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:6.10.14`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.0.7.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.0.13.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.0.132`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.0.152`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30094:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.2.1.2`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.localization:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.2.7.1`,
        fs:  `cpe:2.3:h:siemens:cvmw3025-ir:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.2.9.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.473.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.2.12.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p174:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.2.173`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.19.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.2.182`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.2.185`,
        fs:  `cpe:2.3:a:wooga:jelly_splash:1.11.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.2.190`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.3.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.3.11.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:7.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.3.13.1`,
        fs:  `cpe:2.3:a:google:android_api:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.3.15.0`,
        fs:  `cpe:2.3:a:vmware:server:1.0.4_build_56528:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.3.23`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.3.48`,
        fs:  `cpe:2.3:a:f-secure:anti-virus:9.00:*:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.3.50`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.4.24`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.0.0`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.1`,
        fs:  `cpe:2.3:h:htc:sensation_4g:gri40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.3.1`,
        fs:  `cpe:2.3:h:cisco:epc3825:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.3.4`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:9.7.0-125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.3.5`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_131:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.4.4`,
        fs:  `cpe:2.3:h:ibm:smart_analytics_system_5600:7200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.32`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.35`,
        fs:  `cpe:2.3:a:gnu:cpio:2.4-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.38`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smithmicro:vzaccess_manager:7.6.52`,
        fs:  `cpe:2.3:a:ibm:java_sdk:7.0.9.31:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smoelenboek_project:smoelenboek:1.0.8::~~~typo3~~`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:smoothwall:smoothwall:3.0:sp3:~~express~~~`,
        fs:  `cpe:2.3:a:keepass:keepass:0.93:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:smoothwall:smoothwall:3.1::~~express~~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd375a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.4.4`,
        fs:  `cpe:2.3:a:poweriso:poweriso:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.4.5`,
        fs:  `cpe:2.3:a:ibm:director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.4.6`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.5.1`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.5.2`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_express:10.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.5.3`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.5.6`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.5.6-1`,
        fs:  `cpe:2.3:a:bokublock:bbadminviewscontrol:2.0:*:*:*:*:ec-cube:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.6.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:smwplus:smw%2b:1.6.0_2`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snake_evolution_project:snake_evolution:1.3.1::~~~android~~`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snapapp_project:snapapp:1.5:-:~~-~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:snapgear:560:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:snapgear:560:3.1.4u2`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:snapgear:580:-`,
        fs:  `cpe:2.3:a:dell:controlvault_host_components_installer:1.7.459.360:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:snapgear:585:-`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:6.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:snapgear:640:-`,
        fs:  `cpe:2.3:a:hp:data_protector_media_operations:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:snapgear:710:-`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:snapgear:720:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snapgear:snapgear_lite%2b_firewall:-`,
        fs:  `cpe:2.3:a:citrix:metaframe:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snaplion:kavita_ks:2.4::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snapone:snap_secure:9.5::~~~android~~`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.22-72.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snilesh:content_slide:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:norman:security_suite:8.0:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snipsnap:snipsnap:1.0b1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snipsnap:snipsnap:1.0b2`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:avatar_mod:1.3`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:9.0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:-`,
        fs:  `cpe:2.3:a:projectforge:projectforge:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.0`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.1:sr4`,
        fs:  `cpe:2.3:a:tibco:spotfire_deployment_kit:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.2.03`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.3`,
        fs:  `cpe:2.3:a:corel:coreldraw_lang_en:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.3.01`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.3.02`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.3.03`,
        fs:  `cpe:2.3:a:tincan:phplist:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.4.02`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.4.03`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.4.04`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.21.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.4.05`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.4.06`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snitz_communications:snitz_forums_2000:3.4.07`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:-`,
        fs:  `cpe:2.3:a:vmware:horizon_view:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.6`,
        fs:  `cpe:2.3:a:altiris:client_task_agent:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.8.0`,
        fs:  `cpe:2.3:a:manuel_garcia:galleryformatter:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.8.1`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.8.2`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.8.3`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.8.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.456:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.8.5`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.6.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.8.6`,
        fs:  `cpe:2.3:a:hp:storageworks_aix_host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.8.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.0wx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.9.0`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:1.9.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:2.0:beta`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.0:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:2.0:rc1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:2.6.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:2.6.1.1`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:2.6.1.2`,
        fs:  `cpe:2.3:o:cisco:catos:5.5\(10a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:2.6.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snort:snort:2.7_beta1`,
        fs:  `cpe:2.3:a:juniper:setup_client_activex_control:2.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snowfoxsoft:snowfox_total_video_converter:2.5.1`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:snowhall:silurus_system:1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.66:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soapmakingforum:soap_making:3.7.13::~~~android~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_connect_project:social_connect:1.0.4::~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:broderbund:calendar_creator:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_microblogging_pro_project:social_microblogging_pro:1.5`,
        fs:  `cpe:2.3:a:cisco:integrated_management_controller_supervisor:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_slider_project:social_slider:7.4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_stats_project:social_stats:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:openbsd:openbsd:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_stats_project:social_stats:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_stats_project:social_stats:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:43.0.2357.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_stats_project:social_stats:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(2\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_stats_project:social_stats:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_stats_project:social_stats:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.01.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:social_stats_project:social_stats:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socialcms:socialcms:1.0.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socialcms:socialcms:1.0.5`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.2.2:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socialknowledge:aquarium_advice:3.7.6::~~~android~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.0_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socialknowledge:forest_river_forums:3.7.5::~~~android~~`,
        fs:  `cpe:2.3:a:k7computing:antivirus:9.77.3565:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socketmail:socketmail:2.2.1`,
        fs:  `cpe:2.3:h:dell:powerconnect_6224p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socketmail:socketmail:2.2.6:-:lite`,
        fs:  `cpe:2.3:a:sun:storage_automated_diagnostic_environment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socketmail:socketmail:2.2.6:-:professional`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socketmail:socketmail:2.2.8`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socketmail:socketmail:2.2.9`,
        fs:  `cpe:2.3:h:huawei:quidway_s6300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:socketmail:socketmail:2.2.9:-:professional`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0.2:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:sodahead:sodahead_polls:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.0.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soft4study:testinside:1.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.0`,
        fs:  `cpe:2.3:a:osisoft:pi_opc_da_interface:2.3.17.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.2`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.3`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.4`,
        fs:  `cpe:2.3:a:hp:diagnostics_server:9.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.5`,
        fs:  `cpe:2.3:h:nortel:vpn_gateway_3050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.6`,
        fs:  `cpe:2.3:h:rockwellautomation:1769_compactlogix_l3x_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.7`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.4:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.8`,
        fs:  `cpe:2.3:o:cisco:catos:5.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:1.9`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.0`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.0.1`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.0.2`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.0.3`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.2.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.0.4`,
        fs:  `cpe:2.3:a:unconfirmed_project:unconfirmed:1.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.0.5`,
        fs:  `cpe:2.3:a:git-scm:git:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.0.6`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.81\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.1.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.1.1`,
        fs:  `cpe:2.3:a:gentoo:portage:2.1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.1.2`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.1.3`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softaculous:webuzo:2.1.4`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:6.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softartisans:fileup:5.0.14`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softartisans:fileup:5.3.0::~~professional~~~`,
        fs:  `cpe:2.3:a:apple:tcp_ip_configuration_utility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softartisans:fileup:5.3.1::~~standard~~~`,
        fs:  `cpe:2.3:a:wave:private_information_manager:6.4.0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softartisans:officewriter:4.6.0`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:001dl`,
        fs:  `cpe:2.3:o:d-link:dap-3662_firmware:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:001ht`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p78:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:003p`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:003sh`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:003z`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:005sh`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:006sh`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.963:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:007hw`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:007sh`,
        fs:  `cpe:2.3:a:oracle:retail_order_management_system_cloud_service:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:007sh:j`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:007sh:kt`,
        fs:  `cpe:2.3:a:microsoft:lync:2010:*:attendant_x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:008z`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:009sh`,
        fs:  `cpe:2.3:a:synology:diskstation_manager:4.2-3243:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:009sh:y`,
        fs:  `cpe:2.3:a:drupal:drupal:8.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:009z`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:101dl`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.0:a:commercial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:101f`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:101k`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:101n`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_series_firmware:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:101p`,
        fs:  `cpe:2.3:a:hp:openview_snmp_runtime:1.30.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:101sh`,
        fs:  `cpe:2.3:a:ayatana_project:unity:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:102p`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:102sh`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:102sh:ii`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:103sh`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:104sh`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1028:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:106sh`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:107sh`,
        fs:  `cpe:2.3:a:feedweb:feedweb:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:200sh`,
        fs:  `cpe:2.3:a:emc:replication_manager:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:201hw`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:201k`,
        fs:  `cpe:2.3:a:adobe:illustrator:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:201m`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:x06ht`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:android_smartphone:x06ht:ii`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:disney_mobile_android_smartphone:dm009sh`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.36.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:disney_mobile_android_smartphone:dm010sh`,
        fs:  `cpe:2.3:a:symantec:mail_security_for_microsoft_exchange:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:disney_mobile_android_smartphone:dm011sh`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:disney_mobile_android_smartphone:dm012sh`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:disney_mobile_android_smartphone:dm013sh`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:mobile_wi-fi_router:101sb`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:mobile_wi-fi_router:102hw`,
        fs:  `cpe:2.3:a:themepunch:slider_revolution:4.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:mobile_wi-fi_router:102z`,
        fs:  `cpe:2.3:a:rpm:rpm:4.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:nec_3g_handset:001n`,
        fs:  `cpe:2.3:a:artifex:mupdf:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:nec_3g_handset:931n`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:nec_3g_handset:940n`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:panasonic_3g_handset:001p`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:panasonic_3g_handset:941p`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:panasonic_3g_handset:942p`,
        fs:  `cpe:2.3:a:ipswitch:imail:11.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:samsung_3g_handset:941sc`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:001n`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:001p`,
        fs:  `cpe:2.3:a:libksba_project:libskba:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:002sh`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(3i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:004sh`,
        fs:  `cpe:2.3:h:hp:laserjet_8150dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:004shp3`,
        fs:  `cpe:2.3:a:oracle:retail_xstore_point_of_service:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:931n`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:940n`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.1r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:940sh`,
        fs:  `cpe:2.3:a:apple:itunes:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:941p`,
        fs:  `cpe:2.3:a:php:php:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:941sc`,
        fs:  `cpe:2.3:a:progress:objectstore:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:941sh`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(2\)s0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:942p`,
        fs:  `cpe:2.3:a:ibm:dashdb_local:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:943sh`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:944sh`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:945sh`,
        fs:  `cpe:2.3:a:sharethis:sharethis:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:sharp_3g_handset:945shg`,
        fs:  `cpe:2.3:a:gnu:findutils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softbank:wi-fi_application:1.7.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p185:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softbank:wi-fi_spot_configuration_software:-`,
        fs:  `cpe:2.3:a:horde:groupware:1.2:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:windows_mobile_smartphone:x01sc`,
        fs:  `cpe:2.3:o:mozilla:firefoxos:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:windows_mobile_smartphone:x02t`,
        fs:  `cpe:2.3:a:jogoeusei:i_know_the_movie:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:windows_mobile_smartphone:x04ht`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:softbank:windows_mobile_smartphone:x05ht`,
        fs:  `cpe:2.3:a:clamav:clamav:0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softbank:wisprclient:1.3.0`,
        fs:  `cpe:2.3:o:huawei:s9703_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softbb:softbb:0.1.3`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softconcept-inc:seenet:1.3.4`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softconcept-inc:sysflowagent:1.3.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softconcept-inc:sysflowagent:1.4.0.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softerra:ldap_administrator:3.3.1.1461`,
        fs:  `cpe:2.3:a:google:gears:0.4.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softerra:ldap_administrator:3.5.0.1750`,
        fs:  `cpe:2.3:a:129zou:zombie_diary:1.2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:softerra:ldap_administrator:2008.1`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softerra:ldap_administrator:2009.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5e.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softerra:ldap_browser:2.6`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.4.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softerra:ldap_browser:4.5.10625.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softmotion3d:softmotion:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softonic:english_toolbar:5.7.2.2`,
        fs:  `cpe:2.3:a:websitepanel:websitepanel:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softsphere:defensewall_personal_firewall:3.24`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwareag:webmethods:4.1.1`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwareag:webmethods:7.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.425:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwarefx:chartfx_net_silent_setup:1.0.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:4.0`,
        fs:  `cpe:2.3:a:microsoft:office:97:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.56.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.3`,
        fs:  `cpe:2.3:a:apple:quicktime:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.4`,
        fs:  `cpe:2.3:a:idt:idt_audio:1.0.6292.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.5`,
        fs:  `cpe:2.3:a:ca:arcserve_backup:6.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.6`,
        fs:  `cpe:2.3:a:mysql:eventum:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.7`,
        fs:  `cpe:2.3:a:vmware:workstation:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.8`,
        fs:  `cpe:2.3:a:google:chrome:45.0.2454.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.9`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.10`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.11`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0_rev_a:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwaretoolbox:top_server:5.12`,
        fs:  `cpe:2.3:h:cisco:catalyst_2900xl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:softwebsnepal:ananda_real_estate:3.4`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:advanced_subnet_calculator:9.1`,
        fs:  `cpe:2.3:a:avst:callxpress:7.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:collector:2.2.1.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:engineers_edition:solarwinds_engineers_edition`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:exchange_monitor:1.0.1.30`,
        fs:  `cpe:2.3:a:softartisans:fileup:5.3.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:firewall_security_manager:6.6.5`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:information_service:2.5.1`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.2.6:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:integrated_virtual_infrastructure_monitor:1.1.674.0`,
        fs:  `cpe:2.3:a:haxx:curl:7.23.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:ip_address_manager_web_interface:3.0`,
        fs:  `cpe:2.3:a:kent-web:clip_board:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:ip_address_manager_web_interface:3.0:hotfix1`,
        fs:  `cpe:2.3:a:psychostats:psychostats:3.0.6b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:ipmonitor:8.50.1158.3`,
        fs:  `cpe:2.3:a:mini_mail_dashboard_widget_project:mini_mail_dashboard_widget:1.42:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:ipmonitor:10.0.1368.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:job_engine:1.5.2.0`,
        fs:  `cpe:2.3:a:plone:plone:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:job_engine:2.1.2.0`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:3.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:kiwi_cattools:3.6.0__%28service_edition%29`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:log_forwarder_for_windows:1.1.17`,
        fs:  `cpe:2.3:a:google:chrome:12.0.723.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:netflow_realtime:10.7.0.91`,
        fs:  `cpe:2.3:a:haxx:curl:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:network_configuration_manager:7.2.0`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:network_configuration_manager:7.2.1`,
        fs:  `cpe:2.3:a:evan_dandrea:usb-creator:0.2.47.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:network_configuration_manager:7.2.2`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_core_services:111.1.3.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_ip_address_manager:4.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_netflow_traffic_analyzer:4.0`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_atlas:1.5.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_configuration_manager:7.3.1`,
        fs:  `cpe:2.3:h:dell:truemobile_2300_wireless_broadband_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:-`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.8.64263.468:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:10.0`,
        fs:  `cpe:2.3:a:google:v8:3.24.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:10.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:10.1.13.0`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:10.2`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:10.2.1`,
        fs:  `cpe:2.3:a:enl_newsletter_plugin_project:enl-newsletter:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:10.2.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:10.3`,
        fs:  `cpe:2.3:a:falconsc:wisepoint:4.1.19.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:10.3.1`,
        fs:  `cpe:2.3:a:adobe:coldfusion_.net_integration_services:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_network_performance_monitor:11.4`,
        fs:  `cpe:2.3:h:siemens:scalance_x202-2p_irt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_server_and_application_manager:6.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_user_device_tracker:3.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_voip_%26_network_quality_manager:4.1`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:orion_web_performance_monitor:2.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:real-time_bandwidth_monitor:1.0.0.113`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:san_monitor_for_emc_clariion:1.0.0.85`,
        fs:  `cpe:2.3:a:gajennings:this:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:scp_server:1.0.0.15`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:scp_server:1.0.1.6`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:server_and_application_monitor:-`,
        fs:  `cpe:2.3:h:alcatel:speedtouch_7g_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:storage_manager:6.1`,
        fs:  `cpe:2.3:a:oracle:corporate_time_outlook_connector:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:tftp_server:-`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:tftp_server:9.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:tftp_server:9.1.0.2`,
        fs:  `cpe:2.3:a:xtendcu:xtendcu_mobile:1.0.28:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:tftp_server:9.1.0.111`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc375xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:tftp_server:solarwinds_tftp_server`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:toolset:10.3.0`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solarwinds:toolset:10.7.0`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2_ms3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solidworks:product_data_management:2014:sp2`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solltech:dias:6.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:solventus:com_jgen:0.9.33`,
        fs:  `cpe:2.3:a:splashid:splashid:7.2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:somcloud:somnote_-_journal%2fmemo:2.1.5::~~~android~~`,
        fs:  `cpe:2.3:a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.4.1:1:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:somcloud:somtodo_-_task%2fto-do_widget:2.0.3::~~~android~~`,
        fs:  `cpe:2.3:a:7mediaws:edutrac:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonarsource:jenkins_plugin:-:-:~-~-~sonarqube~~`,
        fs:  `cpe:2.3:a:apprain:apprain:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonarsource:sonarqube:3.7`,
        fs:  `cpe:2.3:a:mitre:risk_radar:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.0.4:1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.0.5`,
        fs:  `cpe:2.3:a:mit:kerberos:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.0.6`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.1`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.1.1`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.078:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.2`,
        fs:  `cpe:2.3:a:gcspublishing:beekeeping_forum:3.9.15:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.3.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.4.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.4.0::~~open_source~~~`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.4.0::~~professional~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.5.0`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.5.0::~~open_source~~~`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.5.0::~~professional~~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.5.1`,
        fs:  `cpe:2.3:a:anonymous_posting_project:anonymous_posting:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.0`,
        fs:  `cpe:2.3:a:apache:activemq:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.0::~~open_source~~~`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.0::~~professional~~~`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.1`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.1::~~open_source~~~`,
        fs:  `cpe:2.3:a:djinnworks:line_runner_\(free\):4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.1::~~professional~~~`,
        fs:  `cpe:2.3:a:sonicwall:aventail_web_proxy_agent:10.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.2`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.2::~~open_source~~~`,
        fs:  `cpe:2.3:a:swiftkey:swiftkey_keyboard_\&#43;_emoji:5.0.2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.2::~~professional~~~`,
        fs:  `cpe:2.3:a:oracle:agile_product_lifecycle_management:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p171:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.3::~~open_source~~~`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.603310.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.3::~~professional~~~`,
        fs:  `cpe:2.3:h:denon:avr-3313ci:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.4`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.4::~~open_source~~~`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.0.8dv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.4::~~professional~~~`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v100r006c01spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.6.5::~~professional~~~`,
        fs:  `cpe:2.3:o:sun:solaris:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.0`,
        fs:  `cpe:2.3:a:apple:cups:2.1:*:*:*:development:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.0::~~open_source~~~`,
        fs:  `cpe:2.3:a:twd-industries:remote-anything:5.60.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.0::~~professional~~~`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.0:04`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.0:05`,
        fs:  `cpe:2.3:h:apple:imac:mb419xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.0:06`,
        fs:  `cpe:2.3:a:google:chrome:16.0.890.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:x6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.1::~~open_source~~~`,
        fs:  `cpe:2.3:o:illumos:illumos:r13723:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.7.1::~~professional~~~`,
        fs:  `cpe:2.3:a:louis_jimenez:custom_meta:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.11.0::~~oss~~~`,
        fs:  `cpe:2.3:a:ansibleworks:ansible:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonatype:nexus:2.11.0::~~pro~~~`,
        fs:  `cpe:2.3:a:inria:ocaml:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_access_manager:10.1.95`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(2\)xf4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_access_manager:10.4.32`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:313.00:-:*:*:linux_kernel:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_access_manager:10.52.35`,
        fs:  `cpe:2.3:a:digium:asterisk:12.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_opswat_end_point_control:10.1.95`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_web_proxy_agent:10.1.80`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0057:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_web_proxy_agent:10.4.18`,
        fs:  `cpe:2.3:o:ibm:aix:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_web_proxy_agent:10.52.35`,
        fs:  `cpe:2.3:a:ibm:campaign:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_webifiers:10.1.80`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_webifiers:10.3.42`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sonicwall:aventail_webifiers:10.4.18`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:digital_voice_editor:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:digital_voice_editor:3.3.1.11240`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:drx-510ul:-`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:first4internet_xcp_content_management:-`,
        fs:  `cpe:2.3:a:gnu:wget:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:micro_vault_fingerprint_access_software:-`,
        fs:  `cpe:2.3:a:autodesk:inventor:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_3:-`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.7.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.00`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.1:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.10`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:0.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.20`,
        fs:  `cpe:2.3:a:redhat:packstack:2012.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.30`,
        fs:  `cpe:2.3:o:mandriva:enterprise_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.40`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.50`,
        fs:  `cpe:2.3:o:netgear:r6900_firmware:1.0.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.60`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(3b\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.70`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6\(3\)_b35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:playstation_portable:2.80`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.9:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_ch140:-`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_ch180:-`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1055.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_ch240:-`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_ch280:-`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20030626:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_dh140:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_dh140t:-`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.0.4:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_dh180:-`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_dh240:-`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_dh240t:-`,
        fs:  `cpe:2.3:a:logitech:audio_echo_cancellation_component:11.0.1218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:snc_dh280:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:sonicstage_connect_player:-`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:sonicstage_mastering_studio:-`,
        fs:  `cpe:2.3:a:square:okhttp:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:sonicstage_mastering_studio:1.2.02`,
        fs:  `cpe:2.3:a:oracle:sysfw:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:sonicstage_mastering_studio:1.4.00`,
        fs:  `cpe:2.3:h:ubnt:aircam_mini:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:sonicstage_mastering_studio:2.1.00`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:sonicstage_mastering_studio:2.1.01`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6ccg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:sonicstage_mastering_studio:2.2.01`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:sony_network_camera_snc-p5:-`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:sound_forge:10.0:b:pro`,
        fs:  `cpe:2.3:a:cisco:tacacs\&#43;:f4.0.2alpha:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:vaio_manual_cybersupport:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:vaio_manual_cybersupport:3.0`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sony:vaio_manual_cybersupport:3.1`,
        fs:  `cpe:2.3:a:trendmicro:portalprotect:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sony:vaio_media_server:-`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:anti-virus:9.5.1::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:anti-virus:9.6.1::~~~linux_kernel~~`,
        fs:  `cpe:2.3:a:vmware:fusion:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:disk_encryption:5.50.0`,
        fs:  `cpe:2.3:a:macromedia:breeze:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:disk_encryption:5.50.1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:disk_encryption:5.50.8`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:enterprise_console:5.1`,
        fs:  `cpe:2.3:a:toolpage_project:toolpage:1.6.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:enterprise_console:5.2`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:enterprise_console:5.2.1`,
        fs:  `cpe:2.3:a:socketmail:socketmail:2.2.6:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:enterprise_console:5.2.1:r2`,
        fs:  `cpe:2.3:a:prosody:prosody:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:enterprise_console:5.2.2`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_easy_device_encryption_client:5.50.0`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.3:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_easy_device_encryption_client:5.50.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_easy_device_encryption_client:5.50.8`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.6`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.35.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.35.1`,
        fs:  `cpe:2.3:a:netease:netease_pmail:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.35.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.35.3`,
        fs:  `cpe:2.3:h:polycom:viewstation_512:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.40.0`,
        fs:  `cpe:2.3:h:ibm:system_x3650_m4_hd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.50.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.50.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_supplementary:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:safeguard_enterprise_device_encryption:5.50.8`,
        fs:  `cpe:2.3:h:hp:laserjet_p2055d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:2.3`,
        fs:  `cpe:2.3:a:microsoft:visio_viewer:2010:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.4.6`,
        fs:  `cpe:2.3:a:libpng:libpng:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.46`,
        fs:  `cpe:2.3:a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:58.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.78`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.78d`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.79`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.11:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.80`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:17.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.81`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.82`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.83`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.84`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.85`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.86`,
        fs:  `cpe:2.3:a:spip:spip:2.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.90`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.91`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.93`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.95`,
        fs:  `cpe:2.3:a:digia:qt:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:3.96`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:17.0.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.04`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.04:-:windows`,
        fs:  `cpe:2.3:a:openttd:openttd:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.05`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.5.3`,
        fs:  `cpe:2.3:a:rarlab:winrar:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.5.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.5.8`,
        fs:  `cpe:2.3:a:emc:documentum_content_server:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.5.11`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.5.12`,
        fs:  `cpe:2.3:h:hp:procurve_switch_4000m:c.07.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.6.8`,
        fs:  `cpe:2.3:a:fortinet:forticlient:4.3.3.445:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.7.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.7.2`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:4.61.0`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5600-26c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:5.0.1`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:5.0.2`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:5.0.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p377:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:5.1`,
        fs:  `cpe:2.3:a:apache:groovy:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:5.1.3`,
        fs:  `cpe:2.3:a:tenable:nessus:6.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:5.2.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:5.2.0:-:windows`,
        fs:  `cpe:2.3:a:webmin:usermin:1.250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:5.2.1`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.04.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:6.0`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.9504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:6.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)ja1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:6.5.4:r2`,
        fs:  `cpe:2.3:a:citrix:xenmobile_device_manager:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:6.5.8`,
        fs:  `cpe:2.3:a:iss:internet_security_scanner:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:sophos_anti-virus:7.0`,
        fs:  `cpe:2.3:a:hp:6000e609_help_basicweb:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sophos:unified_threat_management:110`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30096:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sophos:unified_threat_management:120`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sophos:unified_threat_management:220`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sophos:unified_threat_management:320`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update9:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sophos:unified_threat_management:425`,
        fs:  `cpe:2.3:a:apache:poi:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sophos:unified_threat_management:525`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.8.6:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:sophos:unified_threat_management:625`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:unified_threat_management_software:8.3`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:unified_threat_management_software:9.007`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:unified_threat_management_software:9.107`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:unified_threat_management_software:9.108`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:unified_threat_management_software:9.109`,
        fs:  `cpe:2.3:a:oracle:field_service:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:unified_threat_management_software:9.319`,
        fs:  `cpe:2.3:a:apache:tomcat:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:unified_threat_management_software:9.351`,
        fs:  `cpe:2.3:a:hp:hpptoolboxfx:1.2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:unified_threat_management_software:9.355`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sophos:web_appliance:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.0.0`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.1:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.0.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.0.1.1`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.0.2`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.9.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.0.3`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.0.4`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.0.5`,
        fs:  `cpe:2.3:a:microsoft:excel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.0.5.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.1.0`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.1.0.1`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.1.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.1.2`,
        fs:  `cpe:2.3:o:juniper:junos:14.2r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.1.3`,
        fs:  `cpe:2.3:a:barebones:yojimbo:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.1.4`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.2.1`,
        fs:  `cpe:2.3:a:microsoft:asp.net_signalr:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.2.2`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.2.2.1`,
        fs:  `cpe:2.3:a:intercom:web_kyukincho:3.0.030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.2.3`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.2.4`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.1.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.2.5`,
        fs:  `cpe:2.3:a:nero:essentials:7.2.7903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.2.6`,
        fs:  `cpe:2.3:h:huawei:vp_9610:v100r002c02b019sp05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.2.7`,
        fs:  `cpe:2.3:h:d-link:dap-1350:rev._a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.0`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.1`,
        fs:  `cpe:2.3:o:cisco:spa_500_series_ip_phone_firmware:7.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.3.1`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.5`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(3g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.5.1`,
        fs:  `cpe:2.3:h:hp:psc_1210_all-in-one:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.6`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3210a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.3.6.1`,
        fs:  `cpe:2.3:o:apple:watchos:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.0`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.3`,
        fs:  `cpe:2.3:a:redmine:redmine:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.3.1`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.7:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.4`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.5`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.6`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.7`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.7c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.4.8`,
        fs:  `cpe:2.3:h:hp:vpn_firewall_appliance:jd271a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.0`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.5:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.1`,
        fs:  `cpe:2.3:h:xerox:document_centre_240:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.1.1`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.1\(1\)_es12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.1.2`,
        fs:  `cpe:2.3:a:huawei:seco_versatile_security_manager:v200r002c00spc200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.2`,
        fs:  `cpe:2.3:a:ati:hydravision:4.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.3`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.5`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.5.6`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.11:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.1`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6ccd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.1.1`,
        fs:  `cpe:2.3:a:ibm:lotus_protector_for_mail_security:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.2`,
        fs:  `cpe:2.3:a:hp:mercury_monitor_over_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.2.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.2.3`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.2.4.0`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.2.4.1`,
        fs:  `cpe:2.3:a:hp:omniback_ii:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.3`,
        fs:  `cpe:2.3:a:raize:codesite_client_tools:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.4`,
        fs:  `cpe:2.3:a:gnu:make:3.77.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.4.1`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.1\(3\)sr4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.6.4.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.0`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.1`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_pc_protection:3.6:cpu:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.2`,
        fs:  `cpe:2.3:a:isc:bind:9.4.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.1:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.4`,
        fs:  `cpe:2.3:a:apple:cups:1.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.5`,
        fs:  `cpe:2.3:a:ninjaforge:com_ninjaxplorer:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.6`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.8.1`,
        fs:  `cpe:2.3:a:citrix:netscaler:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.8.2`,
        fs:  `cpe:2.3:a:commvault:commcell_console:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.7.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.8.0`,
        fs:  `cpe:2.3:a:emc:navisphere_agent:28.20.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sophos:web_appliance:3.8.1`,
        fs:  `cpe:2.3:a:citadel:hercules:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sophos:web_appliance_firmware:3.7.8.1`,
        fs:  `cpe:2.3:a:chifro:chifro_kids_coloring_game:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:sophos:web_appliance_firmware:3.7.8.2`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.2.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:sophos:web_appliance_firmware:3.8.0`,
        fs:  `cpe:2.3:a:ca:license_software:1.60.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sophos:web_appliance_firmware:3.8.1`,
        fs:  `cpe:2.3:a:pgp:corporate_desktop:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sophos:web_appliance_firmware:3.8.1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sophos:web_appliance_firmware:3.8.2`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soprano:fonecta_verify:7.x-1.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6.0:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soprano:fonecta_verify:7.x-1.1`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soprano:fonecta_verify:7.x-1.2`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:soprano:fonecta_verify:7.x-1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soprano:fonecta_verify:7.x-1.4`,
        fs:  `cpe:2.3:a:vmware:player:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soprano:fonecta_verify:7.x-1.5`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soprano:fonecta_verify:7.x-1.6`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soprano:fonecta_verify:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.513:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:soraxsoft:sorax_reader:2.0.3129.70`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sortir-en-alsace:sortir_en_alsace:0.5b::~~~android~~`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sos_recette_project:sos_recette:1::~~~android~~`,
        fs:  `cpe:2.3:a:divx:player:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sosocome:family_location:3.4::~~~android~~`,
        fs:  `cpe:2.3:o:sgi:irix:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sosreport_project:sosreport:-`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sound_exchange_project:sound_exchange:14.4.1`,
        fs:  `cpe:2.3:a:curtis_galloway:exif:0.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:campsite:3.4.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:3.5.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:3.5.0:rc2`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:3.5.1`,
        fs:  `cpe:2.3:a:citrix:enhanced_desktop_experience:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:3.5.2`,
        fs:  `cpe:2.3:a:oracle:http_server:9.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:3.5.3`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:3.5.4`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.1.3:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:3.5.5`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:4.0:rc3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:4.0.1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:4.0.2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:4.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:4.0.4`,
        fs:  `cpe:2.3:a:bokublock:bbadminviewscontrol213:1.0:*:*:*:*:ec-cube:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcefabric:newscoop:4.1.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcegear:diffmerge:3.3.1.1118::~~~~x64~`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcegear:vault_client:4.1.4.18402`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcegear:vault_server:4.1.4.18402`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcelink:multitrac:1.04::~~~android~~`,
        fs:  `cpe:2.3:a:nana_project:african_radios_live:1.0.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.0.1`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.467:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.0.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.1.0`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.1.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.1.5`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.12.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.1.6`,
        fs:  `cpe:2.3:a:splunk:splunk:108.2.13425:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.1.7`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.15.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.1.9`,
        fs:  `cpe:2.3:h:hp:psc_2510_photosmart:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.2.9`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.3.2`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.90\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.3.4`,
        fs:  `cpe:2.3:a:netty_project:netty:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.3.6`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5137-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.3.9`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.4.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.4.2`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.0.546.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.4.4`,
        fs:  `cpe:2.3:a:scott_reynen:node_embed:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.4.5`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.4.8`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.5.3`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.5.4`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.5.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.5.8`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.6.1`,
        fs:  `cpe:2.3:a:x3cms:x3_cms:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.6.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.816:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.6.4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.402:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.6.5`,
        fs:  `cpe:2.3:a:debian:ldapscripts:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.6.6`,
        fs:  `cpe:2.3:h:oberthur:id-one_cosmo:64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.6.7`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1671.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.7.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ea1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.7.6`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.09:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.8.1`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.8.5`,
        fs:  `cpe:2.3:a:atlassian:confluence:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.9.0`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.9.3`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.9.4`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.9.5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.0.1570:unknown:online_windows_2000:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.9.6`,
        fs:  `cpe:2.3:a:perl:perl:0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sourcetreesolutions:mojoportal:2.3.9.7`,
        fs:  `cpe:2.3:o:hp:arcsight_logger_appliance_firmware:5.2.0.6288.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.17`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050624:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.18`,
        fs:  `cpe:2.3:a:symantec:web_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.19`,
        fs:  `cpe:2.3:a:mcafee:wireless_home_network_security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.20`,
        fs:  `cpe:2.3:a:libav:libav:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.22`,
        fs:  `cpe:2.3:a:cisco:1000v_virtual_ethernet_module_\(vem\):4.0\(4\):sv1\(3a\):*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.23`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.24`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.25`,
        fs:  `cpe:2.3:h:hp:deskjet_1220c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.26`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.27`,
        fs:  `cpe:2.3:h:lenovo:thinkserver_td350:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.28`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.29`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.30`,
        fs:  `cpe:2.3:h:intel:d845wn_motherboard:p11-0040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.0.31`,
        fs:  `cpe:2.3:a:ibm:java:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.1.33`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.2\(1d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:1.11.34`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.0.44:beta`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.00.95`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.01.96`,
        fs:  `cpe:2.3:o:novell:linux_desktop:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.02.99`,
        fs:  `cpe:2.3:a:perl:perl:5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.10.119`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.239:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.10.120`,
        fs:  `cpe:2.3:a:adobe:community_help:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.10.121`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.11.132`,
        fs:  `cpe:2.3:a:paymentsplus:payments_plus:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.20.140`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.21.142`,
        fs:  `cpe:2.3:h:huawei:vp_9620:v100r002c02b019sp05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.30.151`,
        fs:  `cpe:2.3:a:sympa:sympa:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.31.152`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator_software:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:2.40.155`,
        fs:  `cpe:2.3:a:winzip:self-extractor:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.00.162`,
        fs:  `cpe:2.3:o:novell:suse_openstack_cloud:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.01.163`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.02.165`,
        fs:  `cpe:2.3:a:meinberg:network_time_protocol:4.2.4p7\@copenhagen-o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.10.169`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.12.172`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.20.175`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:2.4.4:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.21.177`,
        fs:  `cpe:2.3:a:image_title_project:image_title:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.22.178`,
        fs:  `cpe:2.3:a:vastal:phpvid:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:3.30.186`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.00.245`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.01.246`,
        fs:  `cpe:2.3:a:plogger:plogger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.02.248`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.03.249`,
        fs:  `cpe:2.3:a:php:php:5.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.05.252`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.10.256`,
        fs:  `cpe:2.3:h:d-link:dsl-2730u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.11.257`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.13.260`,
        fs:  `cpe:2.3:a:findingscience:mod_auth_openid:0.2.1:*:*:*:*:apache:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.14.261`,
        fs:  `cpe:2.3:a:gnome:evolution:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.20.263`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.786.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.21.264`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.22.265`,
        fs:  `cpe:2.3:a:daiki_ueno:libfep:0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.23.266`,
        fs:  `cpe:2.3:a:borland:starteam_server:10.0.57.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.30.269`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:4.31.272`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d44.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.00.303`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.01.306`,
        fs:  `cpe:2.3:a:nvidia:install_application:2.0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.02.307`,
        fs:  `cpe:2.3:h:htc:evo_view_4g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.03.308`,
        fs:  `cpe:2.3:a:chillcreations:mod_ccnewsletter:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.03.309`,
        fs:  `cpe:2.3:a:surfcontrol:superscout_email_filter:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.03.310`,
        fs:  `cpe:2.3:a:ibm:optim_workload_replay:2.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.04.311`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.04.312`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.04.313`,
        fs:  `cpe:2.3:o:cisco:mds_9000_nx-os:6.2\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.04.314`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.04.315`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.1:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.316`,
        fs:  `cpe:2.3:o:seil:x2_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.317`,
        fs:  `cpe:2.3:a:netty_project:netty:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.318`,
        fs:  `cpe:2.3:a:pedro_villavicencio_garrido:hipo:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.319`,
        fs:  `cpe:2.3:h:supermicro:x8siu-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.320`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.321`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.322`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.323`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_software_development_kit:11:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.324`,
        fs:  `cpe:2.3:a:node_template_project:node_template:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.325`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.326`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.05.327`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.10.328`,
        fs:  `cpe:2.3:a:saflink:fortezza:50.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.10.329`,
        fs:  `cpe:2.3:a:cloudera:cdh:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.11.330`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.11.331`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.12.332`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop:5:unknown:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.12.333`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.4.402.287:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.12.334`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_417:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.12.335`,
        fs:  `cpe:2.3:a:adobe:bridge:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.12.336`,
        fs:  `cpe:2.3:a:gnu:wget:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.20.342`,
        fs:  `cpe:2.3:a:apache:wss4j:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.21.347`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:12.2.41.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.22.350`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.0.2:-:liberty_profile:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.23.351`,
        fs:  `cpe:2.3:h:juniper:netscreen-idp_500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.24.352`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.25.356`,
        fs:  `cpe:2.3:a:opnet:sp_guru_network_planner:15.0.0.8631:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.26.361`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.27.362`,
        fs:  `cpe:2.3:a:rsa:ace_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.30.367`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.31.373`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:6.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.32.376`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.33.380`,
        fs:  `cpe:2.3:a:google:chrome:6.0.408.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.33.381`,
        fs:  `cpe:2.3:a:emc:networker:7.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.35.385`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.36.386`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.37.387`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.38.388`,
        fs:  `cpe:2.3:a:tibco:spotfire_analyst:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:5.39.389`,
        fs:  `cpe:2.3:o:cisco:ios:15.3s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.00.492`,
        fs:  `cpe:2.3:a:samba:samba:4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.01.512`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:164:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.03.537`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.04.545`,
        fs:  `cpe:2.3:a:sane-backends_project:sane-backends:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.05.550`,
        fs:  `cpe:2.3:a:phpjabbers:vacation_rental_script:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.06.555`,
        fs:  `cpe:2.3:a:emc:rsa_access_manager:6.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.10.560`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:6.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.20.587`,
        fs:  `cpe:2.3:a:searchblox:searchblox:6.4:build_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.21.596`,
        fs:  `cpe:2.3:o:bluecoat:cacheos_sa:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.23.616`,
        fs:  `cpe:2.3:a:ibm:security_appscan:6.0.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.24.621`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.25.622`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:6.26.630`,
        fs:  `cpe:2.3:a:google:chrome:6.0.432.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:7.00`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(23\)s6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:7.01`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:7.02`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:7.10`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:7.12`,
        fs:  `cpe:2.3:a:busybox:busybox:1.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:8.00`,
        fs:  `cpe:2.3:o:cisco:catos:8.3glx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:8.01`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:6.1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:8.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.17.3:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:8.10.1125`,
        fs:  `cpe:2.3:a:openstack:horizon:juno-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:10.0.1733`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:10.01.1740`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:10.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:10.30`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.3.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:10.40`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.5sq:3.5.1sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:10.40.1829`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.13s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:titan_ftp_server:10.42`,
        fs:  `cpe:2.3:a:sympa:sympa:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:southrivertech:webdrive:9.14.2353`,
        fs:  `cpe:2.3:a:adobe:svg_viewer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sowsoft:effective_file_search:6.7`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-1.0`,
        fs:  `cpe:2.3:a:bluecoat:content_analysis_system_software:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:infosphere_import_export_manager:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-2.0`,
        fs:  `cpe:2.3:a:redhat:open_iscsi:2.0-864:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-3.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-3.0:beta1`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-3.0:beta2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-3.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-3.2`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_designer:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-3.3`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-3.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:7.x-1.0`,
        fs:  `cpe:2.3:a:restlet:restlet:2.1:milestone4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:7.x-1.1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:7.x-1.2`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:7.x-1.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spambot_module_project:spambot:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.04.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.0.0`,
        fs:  `cpe:2.3:o:cisco:intrusion_prevention_system:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.0.1`,
        fs:  `cpe:2.3:a:plone:plone:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.2`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.4`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.5`,
        fs:  `cpe:2.3:a:tibco:spotfire_automation_services:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.6`,
        fs:  `cpe:2.3:a:sybase:replication_server:12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.7`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:3.1.8`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:0.1.7:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.0:beta1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.0:beta2`,
        fs:  `cpe:2.3:a:qemu:qemu:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.0:beta3`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:4.7-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.0:rc1`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:562:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.22.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_client:5.0.9a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.4`,
        fs:  `cpe:2.3:a:broadcom:management_programs:8.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)xz7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.5:beta1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.5:beta2`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.5:beta3`,
        fs:  `cpe:2.3:a:values_project:values:7.x-1.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.5:beta4`,
        fs:  `cpe:2.3:a:netiq:self_service_password_reset:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.6`,
        fs:  `cpe:2.3:a:productcart:productcart:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.7`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.8`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.1.1-22.sles10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.9`,
        fs:  `cpe:2.3:a:bulbsecurity:smartphone_pentest_framework:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.0.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.8:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.1.0`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-00:-:enterprise:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.2.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamdyke:spamdyke:4.2.1`,
        fs:  `cpe:2.3:a:elxis:elxis_cms:2006.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.04`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.05`,
        fs:  `cpe:2.3:h:linksys:befn2ps4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.06`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.07`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_dnp3_i\/o_driver:7.20:g:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.08`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.10`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.11`,
        fs:  `cpe:2.3:a:sympa:sympa:5.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.12`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_advanced_pdf_editor:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:5.13`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:6.00`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:6.01`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_inotes_client:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:6.03`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:spamtitan:6.04`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.9:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:webtitan:3.50`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spamtitan:webtitan:3.60`,
        fs:  `cpe:2.3:a:sap:download_manager:1.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparkjava:spark:2.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparkpay:capital_one_spark:0.9.81::~~~android~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:enterprise_architect:7.0.817`,
        fs:  `cpe:2.3:o:netgear:wndr4700_firmware:1.0.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:enterprise_architect:7.0.827`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:enterprise_architect:7.5.850.34`,
        fs:  `cpe:2.3:a:novell:netmail_xe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:enterprise_architect:8.0.863.13`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_integration_for_eclipse:4.0.8`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_integration_for_microsoft_visual_studio:4.0.4`,
        fs:  `cpe:2.3:h:conceptronic:c54apm:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_link_for_doors:2.1`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.18:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_link_for_eclipse:4.0.5`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.90:update9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_link_for_microsoft_visio:1.5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_link_for_visual_studio:3.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(23\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_technology_for_bpmn:1.3.7`,
        fs:  `cpe:2.3:a:adobe:connect:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_technology_for_corba:1.3.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_technology_for_dds:2.0.12`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_technology_for_dodaf-modaf:1.0.30`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_technology_for_python:1.10`,
        fs:  `cpe:2.3:a:brotherscripts:business_directory:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_technology_for_sysml:1.0.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_technology_for_togaf:2.0.8`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sparxsystems:mdg_technology_for_zachman_framework:1.1.4`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(9\)ia:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:speed-dreams:speed_dreams:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(18\)s7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:speed_software:explorer:2.1.5`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:speed_software:root_explorer:3.1`,
        fs:  `cpe:2.3:h:d-link:dcs-2310l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sphider:sphider:1.3.2`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sphider:sphider:1.3.3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sphider:sphider:1.3.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_1w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sphider:sphider:1.3.4:b`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sphider:sphider:1.3.5`,
        fs:  `cpe:2.3:a:keepass:keepass:0.96:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sphider:sphider:1.3.6`,
        fs:  `cpe:2.3:o:pheonixcontact-software:proconos_eclr:-:*:*:*:softplc:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spi%2fsi263b:message_classification:2.2.0.12`,
        fs:  `cpe:2.3:a:gomlab:gom_player:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spi%2fsi263b:message_classification:2.2.0.13`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:6.0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:spi%2fsi263b:outlook_security_settings:11.0`,
        fs:  `cpe:2.3:a:commerce_ogone_project:commerce_ogone:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.5.2`,
        fs:  `cpe:2.3:a:arellia:application_control_solution:6.1.1318:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.5.3`,
        fs:  `cpe:2.3:h:huawei:campus_s6700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.6.0`,
        fs:  `cpe:2.3:a:amberdms:amberdms_billing_system:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.6.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.6.2`,
        fs:  `cpe:2.3:h:siemens:ccmw1025:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.6.3`,
        fs:  `cpe:2.3:a:cisco:webns:5.0_2.005s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.6.4`,
        fs:  `cpe:2.3:a:ireadercity:short_stories:3.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.7.1`,
        fs:  `cpe:2.3:a:ncrafts:formcraft:1.3.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.7.2`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.7.3`,
        fs:  `cpe:2.3:a:emc:legato_networker:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.8.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.8.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p154:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.8.2`,
        fs:  `cpe:2.3:a:mythinkpal:thinkpal:1.6.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.8.3`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.9.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.9.1`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.9.2:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.10.0`,
        fs:  `cpe:2.3:a:f5:big-iq_application_delivery_controller:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.10.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd372a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.11.0`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.11.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.12.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.12.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.324.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.12.3`,
        fs:  `cpe:2.3:a:samba:samba:3.0.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spice_project:spice:0.12.4`,
        fs:  `cpe:2.3:a:moshe_weitzman:organic_groups:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spider_contacts_project:spider_contacts:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:mcafee:network_security_manager:7.1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spigot:dealio_toolbar:4.4`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.11:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spigot:pdfforge_toolbar:4.6`,
        fs:  `cpe:2.3:h:linksys:befsr11:1.40.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spigot:pdfforge_toolbar:4.7`,
        fs:  `cpe:2.3:h:lexmark:e360d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.0`,
        fs:  `cpe:2.3:a:motorola:airdefense_personal_agent:3.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.1`,
        fs:  `cpe:2.3:a:adobe:photodeluxe:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.2`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.3`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.4`,
        fs:  `cpe:2.3:a:alionscience:standard_frequency_action_format_conversion_tool:1.00.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.5`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.6`,
        fs:  `cpe:2.3:a:ab_google_map_travel_project:ab_google_map_travel:3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.7`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.8`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.9`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.10`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.11`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.12`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p3_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.13`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.14`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.15`,
        fs:  `cpe:2.3:h:intel:server_board_scb2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.16`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.17`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.18`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.19`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.1:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.20`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.21`,
        fs:  `cpe:2.3:a:codecanyon:phpsound:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.0.22`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.1`,
        fs:  `cpe:2.3:a:adobe:update_manager:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.2`,
        fs:  `cpe:2.3:o:sun:solaris:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.3`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.4`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.5`,
        fs:  `cpe:2.3:a:microsoft:word:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.6`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.7`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.8`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.9`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.10`,
        fs:  `cpe:2.3:a:tincan:phplist:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.12`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.13`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.14`,
        fs:  `cpe:2.3:a:google:chrome:6.0.399.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.15`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.16`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.17`,
        fs:  `cpe:2.3:h:novatech:orion5r_dnp_master:1.27.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.18`,
        fs:  `cpe:2.3:a:altiris:notification_server_configurator:6.1.7325.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.19`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.20`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:g06.31.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.22`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.23`,
        fs:  `cpe:2.3:a:ibm:sterling_secure_proxy:3.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:2.1.24`,
        fs:  `cpe:2.3:a:connectiva:linux:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.2`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.754.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.4`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner_documentation:16.0.0.10355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.5`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.6`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.7`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.8`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.9`,
        fs:  `cpe:2.3:a:mcafee:security_center:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.10`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.11`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.0.13`,
        fs:  `cpe:2.3:h:hp:j9472a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.1.0:alpha`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.1.0:beta`,
        fs:  `cpe:2.3:a:teklynx:labelview:8.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.1.0:rc`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.1.0:rc2`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.1.0:rc3`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.1.1`,
        fs:  `cpe:2.3:a:views_project:views:7.x-3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.1.2`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spip:spip:3.1.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splashid:splashid:7.2.2::~~~android~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:2.1`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.05.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:2.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:2.2.1`,
        fs:  `cpe:2.3:h:cisco:ios:12.4xl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:2.2.3`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:2.2.6`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.0`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:9.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.0.1`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:beta8:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.0.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1674.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.1`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.1.1`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.1.2`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.1.3`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.1.4`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.2`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.2.1`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.2.2`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.4:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.2.3`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.0.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.2.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.2.5`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.2.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.3.1`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.3.2`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.3.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.22.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.3.4`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.1`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.2`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(9\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.3`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_for_windows_servers:12.0.1364:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.5`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.6`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.8`,
        fs:  `cpe:2.3:o:google:android:4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.9`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.10`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.11`,
        fs:  `cpe:2.3:a:ibm:sterling_b2b_integrator:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.12`,
        fs:  `cpe:2.3:o:sun:sunos:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20\)sp:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:3.4.14`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0`,
        fs:  `cpe:2.3:a:microsoft:ie:7.0.5730.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update8:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.2.3p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.4`,
        fs:  `cpe:2.3:a:debian:unp:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.5`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.6`,
        fs:  `cpe:2.3:a:hidemaru:editor:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.7`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.8`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_the_web_2008:10.2.527:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.9`,
        fs:  `cpe:2.3:a:piwik:piwik:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.10`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.77a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.0.11`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration:10.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1.1`,
        fs:  `cpe:2.3:a:christian_johansson:restrict_node_page_view:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1.2`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1.3`,
        fs:  `cpe:2.3:a:gnu:automake:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1.4`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1.5`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1.6`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1.7`,
        fs:  `cpe:2.3:a:fatfreecrm:fat_free_crm:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.1.8`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.2`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.2.`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.2.1`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5104c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.2.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.2.3`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.2.4`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.2.5`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.5:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.3`,
        fs:  `cpe:2.3:a:mingle_forum_project:mingle_forum:1.0.34:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.3.2`,
        fs:  `cpe:2.3:a:vmware:player:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.3.3`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.3.4`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.3.5`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.3.6`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.2.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:4.3.7`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0`,
        fs:  `cpe:2.3:h:supermicro:x9drg-hf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:exim:exim:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.2`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:2.0.001:patch01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.3`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.4`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance:a5_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.5`,
        fs:  `cpe:2.3:a:facebook_profits_on_steroids_project:facebook_profits_on_steroids:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.6`,
        fs:  `cpe:2.3:a:plone:plone:5.1:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:thegr:dl:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.7`,
        fs:  `cpe:2.3:a:apache:activemq:5.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.8`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.8::~~enterprise~~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.9`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nec:universal_raid_utility:2.5:rev_2244:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.12::~~enterprise~~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.13::~~enterprise~~~`,
        fs:  `cpe:2.3:a:isc:bind:9.1.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.14::~~enterprise~~~`,
        fs:  `cpe:2.3:h:axis:2401_video_server:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.15::~~enterprise~~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:5.0.16::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:5.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:netty_project:netty:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-51-\/k:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.2::~~enterprise~~~`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_indoor_fixed_dome_ip_hd_camera:5011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.4`,
        fs:  `cpe:2.3:h:avaya:cajun_p882:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.4::~~enterprise~~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)m5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.5`,
        fs:  `cpe:2.3:a:apache:camel:2.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.6`,
        fs:  `cpe:2.3:a:devincentiis:gazie:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:freeswitch:freeswitch:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:amberdms:amberdms_billing_system:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:unitedecu:united_educational_cu:1.0.27:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:invitation_project:invitation:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.0.12::~~enterprise~~~`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.0::~~enterprise~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1h:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.4`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:yahoo:messenger:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:louis_jimenez:custom_meta:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.8::~~enterprise~~~`,
        fs:  `cpe:2.3:h:ibm:m32:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.1.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:koha:koha:3.16.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.0::~~light~~~`,
        fs:  `cpe:2.3:a:symantec:livestate_recovery:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.1::~~light~~~`,
        fs:  `cpe:2.3:h:netgear:gs724t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.2::~~light~~~`,
        fs:  `cpe:2.3:a:intel:graphics_accelerator_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.3::~~enterprise~~~`,
        fs:  `cpe:2.3:o:gentoo:linux:2.3.30:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.3::~~light~~~`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:1.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:checkpoint:remote_access_clients:e75.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.9::~~enterprise~~~`,
        fs:  `cpe:2.3:a:individualsoftware:professor_teaches_word:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.10::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.2:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.11::~~enterprise~~~`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.2.12::~~enterprise~~~`,
        fs:  `cpe:2.3:o:openvas:greenbone_security_assistant:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.0::~~light~~~`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.1:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ibm:java_sdk:8.0.1.10:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.1::~~light~~~`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:nobexrc:amnesia_groove:3.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.2::~~light~~~`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):juno-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.3::~~enterprise~~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.3::~~light~~~`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:bernhard_wymann:torcs:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.4::~~light~~~`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.5::~~enterprise~~~`,
        fs:  `cpe:2.3:a:wysija_newsletters_project:wysija_newsletters:2.1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.6::~~enterprise~~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.7::~~enterprise~~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.3.8::~~enterprise~~~`,
        fs:  `cpe:2.3:a:altova:xmlspy_2006:30.1:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.4.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p319:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.4.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.4.2::~~enterprise~~~`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.4.2::~~light~~~`,
        fs:  `cpe:2.3:o:xen:xen:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.4.3::~~enterprise~~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.29:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.4.4::~~enterprise~~~`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.5.0::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.2.130.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.5.1::~~enterprise~~~`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:6.5.1::~~light~~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.925.1706.28889:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:108.2.8775`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3040-ac-poe-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:splunk:108.2.13425`,
        fs:  `cpe:2.3:a:ocportal:ocportal:5.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:universal_forwarder:4.2.3.105575`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.1\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:splunk:universal_forwarder:4.2.4.110225`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spotlightyour:spotlightyour:4.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:skype:skype:2.5.0.151:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.1:-`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.2`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.3`,
        fs:  `cpe:2.3:a:vmware:player:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc124a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.5`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.4\(0.253\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.6`,
        fs:  `cpe:2.3:a:bulbsecurity:smartphone_pentest_framework:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.7`,
        fs:  `cpe:2.3:a:inria:ocaml:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.8`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.0.9`,
        fs:  `cpe:2.3:a:dell:wyse_device_manager:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.2.0`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.4.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.4.1`,
        fs:  `cpe:2.3:a:field_group_project:field_group:7.x-1.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.5.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.6.0`,
        fs:  `cpe:2.3:a:hp:fax:100.0.272.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.7.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.80:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.7.1`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.6.0:m4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.8.0`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.8.1`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.8.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.8.3`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.8.4`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.8.5`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.9.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.9.1`,
        fs:  `cpe:2.3:a:kvirc:kvirc:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.9.2`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.9.3`,
        fs:  `cpe:2.3:a:intra-mart:webplatform\/appframework:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.9.4`,
        fs:  `cpe:2.3:a:iconics:dialog_wrapper_module_activex_control:8.4.165.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.10.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.10.1`,
        fs:  `cpe:2.3:a:apple:cups:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.10.2`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.11.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.11.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:0.30.0:beta1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.0`,
        fs:  `cpe:2.3:a:openstack:python_glanceclient:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.0.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.0.2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2s\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.0.3`,
        fs:  `cpe:2.3:a:inlinks_project:inlinks:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.0.5`,
        fs:  `cpe:2.3:a:f5:big-ip:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.0.6`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.0.7`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.1.1`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.1.2`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.1.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.489.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.1.4`,
        fs:  `cpe:2.3:a:google:chrome:5.0.343.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.1.5`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.1.6`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.2.0`,
        fs:  `cpe:2.3:a:apache:commons_fileupload:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.2.1`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.2.2`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.2.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.2.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.606:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.3.0`,
        fs:  `cpe:2.3:a:restful_web_services_project:restws:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.3.1`,
        fs:  `cpe:2.3:a:mahara:mahara:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spreecommerce:spree:1.3.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springcm:privia_platform:5.1.1.4`,
        fs:  `cpe:2.3:a:logitech:quickcam:10.50.1096:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springshare:libcal:2.0`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.2.0`,
        fs:  `cpe:2.3:a:info-zip:unzip:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.2.0:rc1`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.2.0:rc2`,
        fs:  `cpe:2.3:a:linux-sottises:news-tnk:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.2.1`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.2.2`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.2.3`,
        fs:  `cpe:2.3:a:php:php:5.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.4.0`,
        fs:  `cpe:2.3:a:ibm:websphere_dashboard_framework:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.4.0:rc1`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.0.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.4.1`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsignage:xibo:1.4.2`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.0.6`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.0:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.0.7`,
        fs:  `cpe:2.3:h:iodata:hdl-a\/e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.1.0`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.7.1p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.1.1`,
        fs:  `cpe:2.3:a:adobe:connect:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.1.2`,
        fs:  `cpe:2.3:a:wesjones:multisite_search:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.1.3`,
        fs:  `cpe:2.3:a:redhat:openshift:1.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.1.4`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.2.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:storage:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.2.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.5:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.2.2`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.2.3`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.14.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:3.2.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2_2d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:4.0.0:m1`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:springsource:spring_framework:4.0.0:m2`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sprint:airave:-`,
        fs:  `cpe:2.3:a:apache:storm:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprint:airave_software:2.5`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:2.7.1_j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sprint:evo_shift_4g:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprint:smartview:1.12.15.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprint:smartview:2.27.64.0`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_solution_engine:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprint:smartview:2.28.82.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.1.3`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.2.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.3.2`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.4.5`,
        fs:  `cpe:2.3:a:all_navalny_project:all_navalny:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.5.0`,
        fs:  `cpe:2.3:h:hp:scanjet_7650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.6.0`,
        fs:  `cpe:2.3:a:hp:scan_to:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.7.0`,
        fs:  `cpe:2.3:a:dx_library_project:dx_library:3.16b:*:*:*:*:visual_c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.8.2`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.9.3`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.10.1`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3l\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.11.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.642.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:2.12.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sprockets_project:sprockets:3.0.0:beta.2`,
        fs:  `cpe:2.3:a:sap:netweaver_java_application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spumko_project:hapi_server_framework:2.0.0:-:~~~node.js~~`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spumko_project:hapi_server_framework:2.0.0:preview:~~~node.js~~`,
        fs:  `cpe:2.3:a:oswald_buddenhagen:isync:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spumko_project:hapi_server_framework:2.1.1::~~~node.js~~`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spumko_project:hapi_server_framework:2.1.2::~~~node.js~~`,
        fs:  `cpe:2.3:h:nortel:ethernet_routing_switch_1612:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:spumko_project:hapi_server_framework:2.2.0::~~~node.js~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.0`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.0:beta1`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.0:beta2`,
        fs:  `cpe:2.3:h:hp:d3l10a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.0:beta3`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.1`,
        fs:  `cpe:2.3:a:ca:etrust_admin:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.2`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.3`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.4`,
        fs:  `cpe:2.3:a:cisco:video_surveillance_software:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.5`,
        fs:  `cpe:2.3:a:ca:etrust_threat_management_console:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.6`,
        fs:  `cpe:2.3:a:redhat:sendmail:8.12.5-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.6.7`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.4.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.7.0`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.7.0:b1`,
        fs:  `cpe:2.3:a:adobe:acrobat:1.0:*:*:*:suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.7.0:b2`,
        fs:  `cpe:2.3:a:batch_jobs_project:batch_jobs:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.7.0:b3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.8_pre1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlalchemy:sqlalchemy:0.7.0:b4`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.0.196:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlbuddy:sql_buddy:1.3.3`,
        fs:  `cpe:2.3:a:netapp:snapdrive:6.2.0.5007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqldts:dtsbackup:2000`,
        fs:  `cpe:2.3:a:adobe:adobe_content_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlite:sqlite:3.8.2`,
        fs:  `cpe:2.3:a:niif:shibboleth_authentication:7.x-4.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlite:sqlite:3.8.8.3`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlite:sqlite:3.12.2`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlsentry:sql_sentry:4.2`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.48.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqlstress:sqlstress:3.2.5`,
        fs:  `cpe:2.3:a:buffalotech:wzr-ampg300nh_firmware:1.50:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.2`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.0.6`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.0.7`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.25:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.0.8`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.0.9`,
        fs:  `cpe:2.3:a:heikki_hokkanen:viewgit:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.0.10`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.11.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.4`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.5`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_66:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.6`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.2:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.7`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.8`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.9`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.0.250.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.10`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.11`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.12`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.13`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.14`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.11:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.16`,
        fs:  `cpe:2.3:a:oracle:oracle_data_provider_for_.net_help:11.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.17`,
        fs:  `cpe:2.3:a:gnu:emacs:20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.18`,
        fs:  `cpe:2.3:a:canonical:acpi-support:0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.3.5.19`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.4.1`,
        fs:  `cpe:2.3:h:sun:netra_1280:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.4.2`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare:7.0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.4.2:rc2`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.4.2:rc3`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sqltools:sqltools:1.5`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf813a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:square:okhttp:2.7.3`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:square:okhttp:3.0.0`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0034:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:square:okhttp:3.0.0:rc1`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.5.0:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:square:okhttp:3.0.1`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:square:okhttp:3.1.0`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:square:okhttp:3.1.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squareup:okhttp:2.7.3`,
        fs:  `cpe:2.3:a:itu:srsfix:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squareup:okhttp3:3.0.0`,
        fs:  `cpe:2.3:a:tryton:trytond:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squareup:okhttp3:3.0.0:rc1`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squareup:okhttp3:3.0.1`,
        fs:  `cpe:2.3:a:kde:ark:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squareup:okhttp3:3.1.0`,
        fs:  `cpe:2.3:h:hp:officejet_pro_8500:cb874a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squareup:okhttp3:3.1.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squash:square_squash:-`,
        fs:  `cpe:2.3:a:pcre:pcre:8.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:2.0`,
        fs:  `cpe:2.3:h:huawei:ar500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:2.1`,
        fs:  `cpe:2.3:a:debian:apt:0.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:2.2`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.4:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:2.3`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:2.4`,
        fs:  `cpe:2.3:a:hesk:hesk:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:2.5`,
        fs:  `cpe:2.3:a:ibm:license_metric_tool:9.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:2.6`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:2.7`,
        fs:  `cpe:2.3:a:apport_project:apport:2.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0:-:pre1`,
        fs:  `cpe:2.3:a:usebb:usebb:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0:-:pre2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0:-:pre3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.437.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0:-:pre4`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1.2:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0:-:pre5`,
        fs:  `cpe:2.3:a:dell:repository_manager:1.1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0:-:pre6`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0:-:pre7`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.03.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0:rc4`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable1`,
        fs:  `cpe:2.3:a:google:v8:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable3`,
        fs:  `cpe:2.3:a:trivantis:coursemill_learning_management_system:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable4`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable5`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable6`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable7`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.5.388:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable8`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable9`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30201:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable10`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable11`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.9:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable11:rc1`,
        fs:  `cpe:2.3:a:motorola:motorola_scanner_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable12`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable13`,
        fs:  `cpe:2.3:a:adobe:photoshop:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable14`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable15`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable16`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable16:rc1`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable17`,
        fs:  `cpe:2.3:a:vips:vips:7.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable18`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable19`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable20`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable21`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable22`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable23`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable24`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(26\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.0.stable25`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.653:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.1`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.2`,
        fs:  `cpe:2.3:a:microsoft:web_applications:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.3`,
        fs:  `cpe:2.3:a:git-scm:git:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.4`,
        fs:  `cpe:2.3:a:fishshell:fish:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.5`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.6`,
        fs:  `cpe:2.3:a:sun:seam:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.7`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.8`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.9`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.10`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.11`,
        fs:  `cpe:2.3:a:apache:struts:2.0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.12`,
        fs:  `cpe:2.3:a:home_shopping_apps:buy_a_gift:13529.90084:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.13`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:11.0.5721.5145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.14`,
        fs:  `cpe:2.3:o:cisco:catos:5.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.15`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a3:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.16`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.17`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)t16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.0.18`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.1`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.2`,
        fs:  `cpe:2.3:a:mark_burdett:securelogin:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.3`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.4`,
        fs:  `cpe:2.3:a:bitrix:xscan:1.0.3:*:*:*:*:bitrix:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.5`,
        fs:  `cpe:2.3:h:cisco:catalyst_3750-x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.5.1`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.6`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.7`,
        fs:  `cpe:2.3:o:iij:seil\%2fx86_firmware:2.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.8`,
        fs:  `cpe:2.3:a:hp:storeonce_d2d:2.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.10`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.11`,
        fs:  `cpe:2.3:h:supermicro:x9drff-i\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.12`,
        fs:  `cpe:2.3:a:magzter:touriosity_travelmag:3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.12.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.12.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.12.3`,
        fs:  `cpe:2.3:a:otrs:otrs:3.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.13`,
        fs:  `cpe:2.3:a:adobe:formflow_filler:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.14`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.15`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.1.23`,
        fs:  `cpe:2.3:h:hp:j9263a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.1`,
        fs:  `cpe:2.3:a:antoine_beaupre:hostmaster:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.2`,
        fs:  `cpe:2.3:a:openstack:keystone_essex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.250.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.4`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.5`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.6`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.7`,
        fs:  `cpe:2.3:h:juniper:mx104:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.8`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r8_b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.9`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.10`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.11`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.12`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.13`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.14`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.15`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.16`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.17`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.18`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.0.19`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.1`,
        fs:  `cpe:2.3:a:nortel:callpilot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.2`,
        fs:  `cpe:2.3:a:yahoo:messenger:8.1.0.401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.3`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.4`,
        fs:  `cpe:2.3:a:hobbylobby:hobby_lobby_stores:2.1.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.5`,
        fs:  `cpe:2.3:a:cisco:business_edition_6000_software:8.5\(1\)su3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.6`,
        fs:  `cpe:2.3:a:openttd:openttd:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.8`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:20.0.0.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.9`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.10`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.11`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.12`,
        fs:  `cpe:2.3:a:ibm:notes_traveler_companion:1.0:*:*:*:*:windows_phone:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.13`,
        fs:  `cpe:2.3:a:logitech:video_enumerator:10.40.1401:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.2.14`,
        fs:  `cpe:2.3:a:march-hare:cvsnt:2.5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.0`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_webscan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.0.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.16:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.0.3`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.78.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.1`,
        fs:  `cpe:2.3:a:hp:device_discovery:110.0.180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.2`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.3`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.4`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.5`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.016.20041:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.6`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.7`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.3.0r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.8`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.9`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.10`,
        fs:  `cpe:2.3:a:google:v8:3.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.11`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.14:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.12`,
        fs:  `cpe:2.3:a:shopware:shopware:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.13`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.3.14`,
        fs:  `cpe:2.3:a:isc:bind:9.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.0.1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.0.2`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.0.3`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.0.4`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:07-00-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p436:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.3`,
        fs:  `cpe:2.3:a:avast:file_server_security:8.0.1609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.4`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_supply_chain_management_eprocurement:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.4.2`,
        fs:  `cpe:2.3:a:emc:networker:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.8`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.9`,
        fs:  `cpe:2.3:o:netgear:raidiator:4.1:-:-:*:-:-:readynas:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.10`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.11`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.12`,
        fs:  `cpe:2.3:a:openstack:keystone:2012.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.13`,
        fs:  `cpe:2.3:a:oracle:industry_applications:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.4.14`,
        fs:  `cpe:2.3:a:david_king:vino:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.0.1`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:10.6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.0.2`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.0.3`,
        fs:  `cpe:2.3:a:mahara:mahara:1.2.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.0.4`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.2`,
        fs:  `cpe:2.3:a:hp:secure_web_server_for_tru64:5.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.16`,
        fs:  `cpe:2.3:a:python:python:2.7.1150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.17`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.18`,
        fs:  `cpe:2.3:a:apache:mod_python:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.19`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0580:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.20`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.21`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:3.5.22`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.1`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.2`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.3`,
        fs:  `cpe:2.3:a:daiki_ueno:libfep:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.4`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.5`,
        fs:  `cpe:2.3:a:isc:bind:9.6.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.10s.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.8`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.9`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.10`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.11`,
        fs:  `cpe:2.3:a:status2k:status2k:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.12`,
        fs:  `cpe:2.3:h:hp:laserjet_p2055dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.13`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.15`,
        fs:  `cpe:2.3:o:xen:xen:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squid-cache:squid:4.0.16`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squirrelmail:squirrelmail:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squishy_birds_project:squishy_birds:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:gpgme:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:squiz:mysource_matrix:3.28.3`,
        fs:  `cpe:2.3:a:qemu:qemu:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:srslabs:srs_premium_sound:1.8.1400`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:srvx:srvx:1.3.1`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssfcu:security_service_mybranch_app:7.88.00.145::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:accession:ssh_accession_1.2.84`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:daemon:-`,
        fs:  `cpe:2.3:o:sun:sunos:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell:-`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell:1.2.23`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell:1.2.25`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:942p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell:3.0.0`,
        fs:  `cpe:2.3:h:siemens:cvms2025-ir:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell:3.1`,
        fs:  `cpe:2.3:h:intel:express_510t:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell:3.2`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell_for_servers:-`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell_for_servers:3.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell_for_servers:3.0.1`,
        fs:  `cpe:2.3:a:commvault:exchange_web_proxy_archiver_agent:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell_for_servers:3.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:secure_shell_for_servers:3.1.1`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_human_capital_management_eperformance:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.1`,
        fs:  `cpe:2.3:a:codehaus:redback:1.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.2`,
        fs:  `cpe:2.3:a:oracle:jre:1.6.0:update_71:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.3`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.4`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.5`,
        fs:  `cpe:2.3:a:hp:storageworks_red_hat_enterprise_linux_advanced_server_1_host_agent_files:2.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.6`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.1:beta-5:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.7`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_mobilepdf_-_pdf_reader:2.2.0.0616:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.8`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.9`,
        fs:  `cpe:2.3:a:ca:anti-virus_for_the_enterprise:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.11`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.12`,
        fs:  `cpe:2.3:a:gajim:gajim:0.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.13`,
        fs:  `cpe:2.3:a:alkacon:opencms:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.14`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.15`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.8:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.16`,
        fs:  `cpe:2.3:a:oracle:jre:1.5.0:update_55:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.17`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.18`,
        fs:  `cpe:2.3:a:apache:struts:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.19`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.20`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.21`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.22`,
        fs:  `cpe:2.3:a:apple:cups:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.23`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.24`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.25`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.26`,
        fs:  `cpe:2.3:o:hp:700_series_firmware:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.27`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.28`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.29`,
        fs:  `cpe:2.3:a:qemu:qemu:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.30`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh:1.2.31`,
        fs:  `cpe:2.3:a:apple:safari:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.2`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.541:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.3`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.4`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.016:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.5`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:10.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.6`,
        fs:  `cpe:2.3:a:ayatana_project:unity:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.7`,
        fs:  `cpe:2.3:a:microsoft:learning_essentials:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.8`,
        fs:  `cpe:2.3:a:cdotech:edcl-picsadc:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.9`,
        fs:  `cpe:2.3:a:ibm:java:7.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.10`,
        fs:  `cpe:2.3:a:harvestyourdata:droid_survey_offline_forms:2.5.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.11`,
        fs:  `cpe:2.3:a:hp:universal_configuration_management_database:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.12`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:ssh2:2.0.13`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:-`,
        fs:  `cpe:2.3:o:openbsd:openbsd:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.0.1`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.0.3`,
        fs:  `cpe:2.3:a:perl:perl:1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.0.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.466:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.1.1`,
        fs:  `cpe:2.3:a:pcre:pcre2:10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.1.5`,
        fs:  `cpe:2.3:a:huawei:espace_7910:v200r002c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90:rc1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.1`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.1j`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:6.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.2`,
        fs:  `cpe:2.3:a:tincan:phplist:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.2j`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.3`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.4`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.4:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.5`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.6`,
        fs:  `cpe:2.3:a:ibm:sterling_file_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.7`,
        fs:  `cpe:2.3:a:sightspeed:sightspeed:6.0_\(6564\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.8k`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.3.9k`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.186.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.1`,
        fs:  `cpe:2.3:h:dell:optiplex_790:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.2`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.3`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.4`,
        fs:  `cpe:2.3:a:libav:libav:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.6`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.7`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.8`,
        fs:  `cpe:2.3:a:rsa:securid_web_agent:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.9`,
        fs:  `cpe:2.3:a:no_magic_inc.:magicdraw_floating_license_server:16.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.10`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:4.4.11`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.0`,
        fs:  `cpe:2.3:a:symantec:netbackup_client:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.0.844`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:1.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.0f`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.1`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.1f`,
        fs:  `cpe:2.3:a:avaya:speech_access:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.2`,
        fs:  `cpe:2.3:a:opsview:opsview:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.2f`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.2.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.3`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.0.3f`,
        fs:  `cpe:2.3:a:polarnavy:polarcom:1.6.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.1.0`,
        fs:  `cpe:2.3:h:novatech:orion5_dnp_master:1.27.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.1.1`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.1.1.26`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.1.2`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.1.2.17`,
        fs:  `cpe:2.3:a:franz_holzinger:static_methods:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.1.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.2.0`,
        fs:  `cpe:2.3:a:hp:bufferchm:140.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.2.1`,
        fs:  `cpe:2.3:a:zend:zend_server:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.2.2`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.2.3`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.2.4`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.3.0`,
        fs:  `cpe:2.3:a:microsoft:pocket_internet_explorer:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.3.1`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.3.2`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.3.3`,
        fs:  `cpe:2.3:a:monotone:monotone:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.3.5`,
        fs:  `cpe:2.3:a:nosltd:getplus_for_adobe:1.5.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.3.6`,
        fs:  `cpe:2.3:a:citrix:sharefile_mobile_for_tablets:2.4.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.3.7`,
        fs:  `cpe:2.3:a:caucho:resin:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:5.3.8`,
        fs:  `cpe:2.3:a:sun:staroffice:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.0`,
        fs:  `cpe:2.3:a:oracle:commerce_platform:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.1`,
        fs:  `cpe:2.3:a:docker:docker:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.1.16`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.2`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.3`,
        fs:  `cpe:2.3:a:adobe:coldfusion:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.4`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:6.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.6.19`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.7.28`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.8.52`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.9.24`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.6:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.0.11.5`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.1.0.668`,
        fs:  `cpe:2.3:a:altiris:carbon_copy_solution_agent:6.2.1144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.1.4.83`,
        fs:  `cpe:2.3:h:hp:cz244a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.1.7.139`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.1.8.136`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.1.9.95`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.2.1.168`,
        fs:  `cpe:2.3:a:microsoft:word:1.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client:6.2.2.198`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.17m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:-`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:4.0.0`,
        fs:  `cpe:2.3:a:redhat:linux_powertools:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:4.0.1`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:4.0.2`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:4.0.3`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:9.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:4.0.4`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:7.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:4.0.5`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70f:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:4.0.6`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:5.0.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:5.0.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:5.0.2`,
        fs:  `cpe:2.3:a:meta_tags_quick_project:meta_tags_quick:7.x-2.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_client_server_connector:5.1.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:-`,
        fs:  `cpe:2.3:a:efunfun:love_dance:1.2.0626:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.0.7`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.1.2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(5\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.1.3`,
        fs:  `cpe:2.3:a:isc:bind:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.1.5`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.2.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.04:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.3.0`,
        fs:  `cpe:2.3:a:nagios:nagios:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.3.4`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.3.5`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.4.0`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.4.2`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:7.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.4.4`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.4.6`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.5.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.4.7`,
        fs:  `cpe:2.3:a:invensys:wonderware_information_server:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.4.9`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:4.4.10`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-10:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.0.0`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:5.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt102i:2.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.0.2`,
        fs:  `cpe:2.3:a:zurmo:zurmo_crm:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.0.3`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.1.0`,
        fs:  `cpe:2.3:a:kedit:kedit_for_windows:1.60_service_level_1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.1.1`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.1.2`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.1.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p317:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.2.2`,
        fs:  `cpe:2.3:a:apple:safari:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.3.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.3.1`,
        fs:  `cpe:2.3:a:janetter:janetter:2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.3.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.368.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.3.3`,
        fs:  `cpe:2.3:a:sap:hana_extend_application_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.3.7`,
        fs:  `cpe:2.3:a:xerox:docushare:6.6.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_connector:5.3.8`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_manager:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.226:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_manager:1.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_manager:1.3`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_manager:1.4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_manager:2.0`,
        fs:  `cpe:2.3:a:stage_file_proxy_project:stage_file_proxy:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_manager:2.1.2`,
        fs:  `cpe:2.3:a:vms_development:installdeployservice:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_manager:2.1.3`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_manager:2.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(5c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:-`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.0`,
        fs:  `cpe:2.3:a:google:chrome:0.4.154.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.0.3`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop_supplementary:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.0.4`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.0.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.0.7`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.1.2`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5820x-28s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.1.3`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.1.5`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.2.0`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.2.1`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.8.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.2.2`,
        fs:  `cpe:2.3:a:webtree:printkey:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3.0`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3.1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3.2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3.3`,
        fs:  `cpe:2.3:a:foobla:com_obsuggest:1.6.1:b8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3.4`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3.5`,
        fs:  `cpe:2.3:h:polycom:serial_gateway_s4gw:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3.6`,
        fs:  `cpe:2.3:a:vips:vips:7.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.3.7`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.1:*:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.0`,
        fs:  `cpe:2.3:a:hp:java_jre-jdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.2`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.3`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.4`,
        fs:  `cpe:2.3:a:visionsolutions:double-take:4.4.2.2.1414.s.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.6`,
        fs:  `cpe:2.3:a:nextdc:onedc:1.51:-:-:*:-:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.7`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.8`,
        fs:  `cpe:2.3:a:broadcom:management_programs:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.9`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.10`,
        fs:  `cpe:2.3:a:intel:network_connections:15.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:4.4.11`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.1:*:lombardi:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.0`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.0.0`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.0.0_a`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.0.0_f`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.0.0_t`,
        fs:  `cpe:2.3:a:cisco:webex:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.0.1`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.12.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.0.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.07.019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.0.3`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.1.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.1.1.26`,
        fs:  `cpe:2.3:a:moodle:moodle:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.1.2`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.1.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.332:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.2.0`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.2.2`,
        fs:  `cpe:2.3:a:php:php:5.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.2.3`,
        fs:  `cpe:2.3:a:php:php:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.2.4`,
        fs:  `cpe:2.3:a:apache:traffic_server:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.0`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.1`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.2`,
        fs:  `cpe:2.3:a:adobe:coldfusion:11.0:update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.3`,
        fs:  `cpe:2.3:a:cardscan:cardscan:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.3.56`,
        fs:  `cpe:2.3:a:bea:weblogic_server:7.0.0.1:sp1:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.4`,
        fs:  `cpe:2.3:a:roxio:media_manager:9.1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.5`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.6`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.7`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:5.3.8`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.0`,
        fs:  `cpe:2.3:a:wokamoto:wp-cron_dashboard:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.0.362`,
        fs:  `cpe:2.3:a:realnetworks:realplayer_sp:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.1.16`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.3`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.4`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.4::linux_ibm_zos`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p65:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.5`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs510tp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.6`,
        fs:  `cpe:2.3:h:xerox:workcentre:5675:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.6.19`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_9.0_firmware:9.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.7`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.8`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.8.52`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.9`,
        fs:  `cpe:2.3:a:iconics:genesis32:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.9.24`,
        fs:  `cpe:2.3:o:cisco:ios:15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.10`,
        fs:  `cpe:2.3:a:webidsupport:webid:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.11`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.12`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.13`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.14`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.17`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.0.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.18`,
        fs:  `cpe:2.3:h:ibm:flashsystem_9848-ae2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.19`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.0.20.`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.0`,
        fs:  `cpe:2.3:a:plone:plone:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.2`,
        fs:  `cpe:2.3:a:zonelabs:zonealarm:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.3`,
        fs:  `cpe:2.3:a:xymon:xymon:4.1.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.4`,
        fs:  `cpe:2.3:a:google:chrome:10.0.642.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.5`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:5.9.0.145:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.6`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.7`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.7.149`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.20.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.8`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.8.136`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.9`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_link_for_eclipse:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.9.95`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.1.12`,
        fs:  `cpe:2.3:a:nancy_wichmann:realname:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.2.0`,
        fs:  `cpe:2.3:a:vmware:tools:8.0.4.24748:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.2.0.1275`,
        fs:  `cpe:2.3:a:owncloud:owncloud:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.2.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.2.2`,
        fs:  `cpe:2.3:a:papoo:cms_papoo_light:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.2.3`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.4.0:beta0002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.2.4`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.2.5`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.3.0`,
        fs:  `cpe:2.3:a:tibco:formvine:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.3.1`,
        fs:  `cpe:2.3:a:craig_knudsen:webcalendar:1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssh:tectia_server:6.3.2`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ssp-europe:secure_data_space:3.4.14`,
        fs:  `cpe:2.3:a:apache:camel:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:st:accelerometerp11:2.0.10.22`,
        fs:  `cpe:2.3:a:gajim:gajim:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:st:accelerometerp11:2.0.10.33`,
        fs:  `cpe:2.3:o:compaq:tru64:5.0_pk4_bl17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:st:tpm_software:1.0.13`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stackideas:komento:1.7.0`,
        fs:  `cpe:2.3:a:shiromuku:bu2_bbs:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stackideas:komento:1.7.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stackideas:komento:1.7.2`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stackideas:komento:1.7.3`,
        fs:  `cpe:2.3:a:adobe:formflow_filler:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stage_file_proxy_project:stage_file_proxy:7.x-1.0`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stage_file_proxy_project:stage_file_proxy:7.x-1.1`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.3\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stage_file_proxy_project:stage_file_proxy:7.x-1.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stage_file_proxy_project:stage_file_proxy:7.x-1.3`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stage_file_proxy_project:stage_file_proxy:7.x-1.4`,
        fs:  `cpe:2.3:a:watchguard:watchguard_system_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stage_file_proxy_project:stage_file_proxy:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:hp:fax:47.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:standardchartered:breeze_jersey:1::~~~android~~`,
        fs:  `cpe:2.3:a:agilebits:knox:1.6.1:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:standards_based_linux_instrumentation_project:standards-based_linux_common_information_model_client:2.1.11`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:standards_based_linux_instrumentation_project:standards-based_linux_common_information_model_client:2.1.12`,
        fs:  `cpe:2.3:a:oracle:hyperion_strategic_finance:11.1.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanford:protege:4.0.2`,
        fs:  `cpe:2.3:a:emc:networker:8.1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:1.4.7`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:1.6.5`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:1.6.6`,
        fs:  `cpe:2.3:a:polylang_plugin_project:polylang:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:1.6.7`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:1.6.8`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.0.0`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.1.0`,
        fs:  `cpe:2.3:h:cisco:adaptive_security_appliance:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.2.0`,
        fs:  `cpe:2.3:a:nuuo:crystal:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.2.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.2.3`,
        fs:  `cpe:2.3:h:cisco:12000_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.2.4`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.2.5`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.3.0`,
        fs:  `cpe:2.3:a:oracle:mysql_documents:5.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.3.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.3.4`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.3.5`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.3.6`,
        fs:  `cpe:2.3:a:zen-cart.jp:zen_cart:1.3.0.2:*:*:ja-jp:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.4`,
        fs:  `cpe:2.3:a:sun:openwindows:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.1`,
        fs:  `cpe:2.3:a:netapp:data_ontap_dsm_for_windows_mpio:3.4.3741.1243:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.2`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.9:ga12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.3`,
        fs:  `cpe:2.3:a:apache:hive:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.4`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_designer:2013:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.5`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1011.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.6`,
        fs:  `cpe:2.3:a:anyfont_plugin_project:anyfont:2.2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.11`,
        fs:  `cpe:2.3:a:sap:adminadapter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.12`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.13`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.14`,
        fs:  `cpe:2.3:a:vmware:vcenter_server_appliance:5.1:update_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.15`,
        fs:  `cpe:2.3:a:yahoo:yui:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.16`,
        fs:  `cpe:2.3:o:vmware:esxi:5.1:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.17:18`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.5.19`,
        fs:  `cpe:2.3:a:isc:bind:9.10.4:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:sr_feuser_register:2.6.1`,
        fs:  `cpe:2.3:a:maxthon:maxthon_browser:1.6.7.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.0.0`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.1.0`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.1.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.2.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.3.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.4.0`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.5_build_56455:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.5.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.6.0`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.7.0`,
        fs:  `cpe:2.3:a:dell:pre-boot_authentication_driver:1.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:1.8.0`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.0.0`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.0.1`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.0.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.15:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.0.3`,
        fs:  `cpe:2.3:a:international-arbitration-attorney:international-arbitration-attorney.com:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.0.4`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.0.5`,
        fs:  `cpe:2.3:a:schneider-electric:scada_expert_clearscada:2013:r1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.0.6`,
        fs:  `cpe:2.3:a:intel:control_center:1.2.1.1007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.3.1`,
        fs:  `cpe:2.3:a:psychostats:psychostats:2.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:2.3.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:6.0.0`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.613:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:6.0.1`,
        fs:  `cpe:2.3:o:arubanetworks:instant_access_point_firmware:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:6.0.2`,
        fs:  `cpe:2.3:a:koha:koha:3.16.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:6.0.3`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.2.0:*:*:*:*:check_services:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:6.0.4`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:4.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stanislas_rolland:static_info_tables:6.0.5`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:staperpetua:l%27informatiu:2::~~~android~~`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:staples:staples_usb-to-serial_adapter:2.3`,
        fs:  `cpe:2.3:a:roxio:media_manager:9.4.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:starbucks:starbucks:2.6.1`,
        fs:  `cpe:2.3:a:nagios:plugins:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:starcms:starcms:-`,
        fs:  `cpe:2.3:a:namazu:namazu:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stardock:fences:1.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:starkvilleelectric:sed_account:1.153.0034::~~~android~~`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:starluxstudios:puppy_slots:3.0::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)t3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:starnet:x_win32:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:staruml:staruml:5.0.2.1570`,
        fs:  `cpe:2.3:a:gentoo:qt-unixodbc:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:status:statusnet:0.9.6`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.0.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:status:statusnet:1.0.0`,
        fs:  `cpe:2.3:a:opentext:administration_client:10.1.0.271:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:status:statusnet:1.0.1`,
        fs:  `cpe:2.3:a:hp:openview_performance_access:10.0.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:status:statusnet:1.0.2`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:status:statusnet:1.1.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:status:statusnet:1.1.1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:status2k:status2k:-`,
        fs:  `cpe:2.3:a:lulusoftware:soda_pdf:5.1.183.10520:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stbernard:open_file_manager:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stdutility:stdu_explorer:1.0.201`,
        fs:  `cpe:2.3:o:hp:hp-ux:11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steema:teechart_activex_control:version_5.0::~~pro~~~`,
        fs:  `cpe:2.3:a:novell:imanager:2.7.3:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steema:teechart_for_.net:2010::~~eval~~~`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stefan_tannhaeuser:tv21_talkshow:1.0.1`,
        fs:  `cpe:2.3:h:schneider-electric:bmxnoe0110h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steinberg:mymp3pro:5.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.0`,
        fs:  `cpe:2.3:o:hp:3com_officeconnect_gigabit_vpn_firewall_software:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.1`,
        fs:  `cpe:2.3:o:juniper:junos:17.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.1:beta1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.2`,
        fs:  `cpe:2.3:a:phorum:phorum:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.2:beta1`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.2:beta2`,
        fs:  `cpe:2.3:o:fortinet:fortios:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.2:beta3`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.3`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:9.1.0-032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.3:beta1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1b.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.3:beta2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.599:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.3:beta3`,
        fs:  `cpe:2.3:a:redhat:interchange:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.4`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.4:beta1`,
        fs:  `cpe:2.3:a:mozilla:firefox:43.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.4:beta2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:pl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steindom:contact_save:6.x-1.x:dev`,
        fs:  `cpe:2.3:h:apple:imac:mc511xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stellarinfo:stellar_phoenix_outlook_pst_repair:4.5`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.01::~~~perl~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.93::~~~perl~~`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.95::~~~perl~~`,
        fs:  `cpe:2.3:a:david_king:vino:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.96::~~~perl~~`,
        fs:  `cpe:2.3:a:snort:snort:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.961::~~~perl~~`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.4:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.962::~~~perl~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.963::~~~perl~~`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.80:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.964::~~~perl~~`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.965::~~~perl~~`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.30.020.1917:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.966::~~~perl~~`,
        fs:  `cpe:2.3:a:smartbear:soapui:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.967::~~~perl~~`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.968::~~~perl~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(15b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stephen_adkins:app%3a%3acontext:0.9661::~~~perl~~`,
        fs:  `cpe:2.3:a:cleaninternet:clean_internet_browser:1.36:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:sterlitetechnologies:sam300_ax_router:-`,
        fs:  `cpe:2.3:a:debian:apt:0.7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_lockwood:ticketyboo_news_ticker:-`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_8.0_firmware:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:1.0`,
        fs:  `cpe:2.3:h:intel:qs77_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:1.01`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.08:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:2.0`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:2.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:2.2`,
        fs:  `cpe:2.3:a:gnu:gdb:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:2.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:2.4`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:2.5`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:7.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:2.6`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steve_souza:java_application_monitor:2.7`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:alpha2`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:beta1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1s.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:beta2`,
        fs:  `cpe:2.3:a:file_project:file:5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:beta3`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:beta4`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.6-156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:beta5`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:beta6`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:beta7`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:rc1`,
        fs:  `cpe:2.3:a:cisco:firepower:5.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:rc2`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-2.0:rc3`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1\)db:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:alpha1`,
        fs:  `cpe:2.3:a:avigilon:avigilon_control_center:5.4.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:alpha2`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:beta1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:beta2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.11:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:beta3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:beta4`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:beta5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:beta6`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:beta7`,
        fs:  `cpe:2.3:a:connections_project:connections:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:beta8`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:rc1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.0:rc2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p77:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.1`,
        fs:  `cpe:2.3:a:x:libxxf86dga:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.2`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.3`,
        fs:  `cpe:2.3:a:php:php:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0`,
        fs:  `cpe:2.3:h:hp:jf640a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:alpha1`,
        fs:  `cpe:2.3:a:ucweb:ucmobile_blovestorm:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:alpha2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.4.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:alpha3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:beta1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:beta2`,
        fs:  `cpe:2.3:a:gnome:glib:2.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:beta3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:beta4`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:beta5`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:beta6`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.0:beta7`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.1`,
        fs:  `cpe:2.3:a:microsoft:learning_essentials:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:steven_jones:context:7.x-3.x:dev`,
        fs:  `cpe:2.3:h:asus:rt-ac87u:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stilesoft:netcaptor:7.5.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stillbreathing:bannerman:0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.0:update_4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stillbreathing:bannerman:0.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stillbreathing:bannerman:0.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stillbreathing:bannerman:0.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stillbreathing:bannerman:0.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:storagetek:d280:-`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:14.04:*:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:storagetek:library_console:1.0.0.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:storagetek:santricity:-`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:store_locator_project:store_locator:3.3.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2001:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:straightrunning:xming:6.9.0.31`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:streamingidiot:bodyguard_for_hire:0.18.13146.42280::~~~android~~`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:street_walker_project:street_walker:0.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:corel:activecgm_browser:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stripshow_plugin_project:stripshow:2.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stripshow_plugin_project:stripshow:2.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:msvcsetup:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.0.0`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.0.1`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.2014.0216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.0.2`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62f:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.1.0`,
        fs:  `cpe:2.3:a:fabien_coelho:mod_macro:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.1.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.1.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.1.3`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.1.4`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc106a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.1.5`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.3.0`,
        fs:  `cpe:2.3:a:apple:cups:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.3.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.8:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.3.2`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.82.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.4.0`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.4.0:a`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.4.1`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.4.2`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.4.3`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.4.4`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.3718.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.5.0`,
        fs:  `cpe:2.3:a:gnu:cpio:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.5.1`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.5.2`,
        fs:  `cpe:2.3:a:f5:big-ip_application_acceleration_manager:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.5.3`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.5.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.5.5`,
        fs:  `cpe:2.3:h:cisco:ons_15216_optical_add_drop_multiplexer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.5.6`,
        fs:  `cpe:2.3:a:haxx:curl:7.21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.5.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.1`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.2`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.13:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.4`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.14`,
        fs:  `cpe:2.3:a:huawei:utps:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.16`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.20`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.6.21`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.7.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p176:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.7.1`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.7.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.7.3`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.0`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.1`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.2`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2007:-:home:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(25e\)jap1m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.4`,
        fs:  `cpe:2.3:a:mcafee:spamkiller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.5`,
        fs:  `cpe:2.3:a:vmware:view:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.6`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.7`,
        fs:  `cpe:2.3:a:plone:plone:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.8`,
        fs:  `cpe:2.3:a:hp:unified_functional_testing:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.9`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.10`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:2.8.11`,
        fs:  `cpe:2.3:h:3com:3c16988a-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.0.0`,
        fs:  `cpe:2.3:h:hp:deskjet_694c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.0.1`,
        fs:  `cpe:2.3:a:wdc:wd_my_cloud:4.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.0.2`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.0.3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-50-\/f:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.0.4`,
        fs:  `cpe:2.3:a:op5:monitor:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.0.5`,
        fs:  `cpe:2.3:o:huawei:s5300ei_firmware:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.0.6`,
        fs:  `cpe:2.3:a:microsoft:ie:5.0.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.0.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.0`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.1`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.2`,
        fs:  `cpe:2.3:a:sebastian_heinlein:aptdaemon:0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.3`,
        fs:  `cpe:2.3:a:citrix:access_management_console_web_interface:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.4`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.5`,
        fs:  `cpe:2.3:h:sierrawireless:pinpoint_x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.6`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.7`,
        fs:  `cpe:2.3:o:juniper:junos:16.1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.8`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:7.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.9`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.10`,
        fs:  `cpe:2.3:a:opera:opera_browser:12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.1.11`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.80\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.0`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.1`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.2`,
        fs:  `cpe:2.3:a:runtime:diskexplorer_for_ntfs:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.3`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.5`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.03:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.6`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.7`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.08.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.8`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.9`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.10`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.11`,
        fs:  `cpe:2.3:a:google:chrome:16.0.883.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.12`,
        fs:  `cpe:2.3:a:omeka:omeka:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.13`,
        fs:  `cpe:2.3:a:scilab:scilab:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.14`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.3:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.15`,
        fs:  `cpe:2.3:a:vmware:vsphere_update_manager:5.0.0.8039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.2.16`,
        fs:  `cpe:2.3:a:todaysseniorsnetwork:todaysseniorsnetwork:0.21.13245.84038:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.3.0`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.52:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.3.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.3.2`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.3.3`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.3.5`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d43.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.3.6`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.3.7`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.617:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.4.0`,
        fs:  `cpe:2.3:a:touchnote:touchnote_postcards:4.2.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.4.1`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.5.0`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.5.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.5.2`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.052:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.5.3`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.6.0`,
        fs:  `cpe:2.3:a:alrazylabs:lostword:5.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.6.1`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.6.2`,
        fs:  `cpe:2.3:o:google:android:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.6.3`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.8:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:4.6.4`,
        fs:  `cpe:2.3:o:d-link:dsr-150n_firmware:1.05b48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.0.0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.0.1`,
        fs:  `cpe:2.3:a:ca:service_desk_manager:12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.0.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.0.3`,
        fs:  `cpe:2.3:a:ca:license_software:1.8.0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.0.4`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.1.0`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:10.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.1.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.1.2`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.1.3`,
        fs:  `cpe:2.3:a:sirana:appanalyzer:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.2.0`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.20.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.2.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.2.2`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.2.3`,
        fs:  `cpe:2.3:a:quagga:quagga:0.98.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.3.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.13:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1.4\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.3.2`,
        fs:  `cpe:2.3:a:jenkins:git:1.0.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan:5.3.3`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:strongswan:strongswan_vpn_client:1.4.5::~~~android~~`,
        fs:  `cpe:2.3:a:netscape:navigator:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stuart_watret:sms_adminconsole_additions:1.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:studio.gd:gd_infinite_scroll:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:studiohitori:twitrocker2_android:1.0.18`,
        fs:  `cpe:2.3:a:altiris:security_audit_agent_solution:6.2.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:studiohitori:twitrocker2_android:1.0.19`,
        fs:  `cpe:2.3:a:percona:percona_server:5.5.50-38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:studiohitori:twitrocker2_android:1.0.20`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:studiohitori:twitrocker2_android:1.0.21`,
        fs:  `cpe:2.3:h:hp:jf431a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:studiohitori:twitrocker2_android:1.0.22`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:studiohitori:twitrocker2_android:1.0.23`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:4.55`,
        fs:  `cpe:2.3:a:gots:civa:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:4.56`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.00`,
        fs:  `cpe:2.3:a:http-body_project:http-body:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.01`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.02`,
        fs:  `cpe:2.3:a:krisonav:krisonav:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.03`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.04`,
        fs:  `cpe:2.3:a:mozilla:firefox:37.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.05`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:4.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.06`,
        fs:  `cpe:2.3:a:isc:bind:9.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.07`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.08`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.2:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.09`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.10`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.11`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.12`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:stunnel:stunnel:5.13`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:style_it_project:style_it:1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:submain:ghostdoc:2.1.3`,
        fs:  `cpe:2.3:a:cisco:webns:7.20.5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:submain:ghostdoc:2.5.9150`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:subnet:substation_server:2.7.0033`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:subnet:substation_server:2.8.0106`,
        fs:  `cpe:2.3:a:nagios:plugins:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:subrion:cms:3.2.2`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:subsplash:first_assembly_nlr:2.8.0::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.7\(0.15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:subsplash:renny_mclean_ministries:2.8.1::~~~android~~`,
        fs:  `cpe:2.3:a:apple:safari:3.2.0b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:successsecrets:successsecrets_project:1.2.3::~~~android~~`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suckless:slock:0.9`,
        fs:  `cpe:2.3:a:emery_berger:hoard:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suckless:slock:1.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sudaninet:sudaninet:2::~~~android~~`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:6.5.26::~~community~~~`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_5370_l1_controller_firmware:20.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.7.2.2`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.8.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.8.0.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.8.1.0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.8.2.0`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.8.2.1`,
        fs:  `cpe:2.3:a:march-hare:cvsnt:2.5.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.9.0.0`,
        fs:  `cpe:2.3:a:phpcms:guesbook_module:-:*:*:*:*:phpcms:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.9.0.1`,
        fs:  `cpe:2.3:o:yamaha:rta50i:3.03.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sugarcrm:sugarcrm:7.9.1.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sumaria:afway_cbt:3.0`,
        fs:  `cpe:2.3:a:unisys:enterprise_output_manager_client:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:chilisoft:-`,
        fs:  `cpe:2.3:a:oracle:reports:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:chilisoft:3.5.2`,
        fs:  `cpe:2.3:a:otrs:otrs_itsm:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:chilisoft:3.6.2`,
        fs:  `cpe:2.3:a:libming:libming:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:cluster:-`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:cluster:2.0`,
        fs:  `cpe:2.3:h:avaya:definity_one_media_server:r9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:cluster:3.1`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:cluster:3.1:4_04`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:cluster:3.2`,
        fs:  `cpe:2.3:h:snapgear:640:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:cobalt_raq:-`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:cobalt_raq_2:-`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:cobalt_raq_3i:-`,
        fs:  `cpe:2.3:a:microsoft:internet_information_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:cobalt_raq_4:-`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.3\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:cobalt_raq_xtr:-`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:crypto_accelerator_4000:-`,
        fs:  `cpe:2.3:a:perl:perl:0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:crypto_accelerator_4000:1.0`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:dtmail:-`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:embedded_lights_out_manager:-`,
        fs:  `cpe:2.3:a:naist.jp:chasen:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:enterprise_authentication_mechanism:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.830:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:enterprise_storage_manager:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.2.1:update3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:enterprise_storage_manager:2.1`,
        fs:  `cpe:2.3:a:hp:panostandalone:110.0.180.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:extended_system_control_facility:-`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:extended_system_control_facility_xcp:-`,
        fs:  `cpe:2.3:a:analog:soundmax:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:extended_system_control_facility_xcp_1040:-`,
        fs:  `cpe:2.3:a:novell:modular_authentication_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x2100_m2:3.19:-:x86`,
        fs:  `cpe:2.3:a:iconics:genesis32:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x2100_m2:3.19:_nil_:x86`,
        fs:  `cpe:2.3:a:phplist:phplist:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x2200_m2:2.19:-:x86`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x2200_m2:2.19:_nil_:x86`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000_entry_class_software:3.09.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x2250_server:sw_1.1`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4100_server:sw_1.5.1`,
        fs:  `cpe:2.3:a:openstack:heat:2014.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4100m2_server:sw_2.1`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4140_server:sw_2.1`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4150_server:sw_2.0`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4200_server:sw_1.5.1`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4200m2_server:sw_2.1`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4240_server:sw_2.1`,
        fs:  `cpe:2.3:a:nathan_haug:webform:7.x-3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4250_server:sw_1.1`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4440_server:sw_2.1`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4450_server:sw_2.1.0`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-20-\/d:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4500_server:sw_1.5`,
        fs:  `cpe:2.3:a:mahara:mahara:15.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4540_server:sw_1.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100831:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4600_server:sw_1.4`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:fire_x4600m2_server:sw_2.1.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:forte:-`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:-`,
        fs:  `cpe:2.3:a:webmin:usermin:0.960:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:5.3`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus_ee:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:5.3:beta1`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:5.3:beta2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:6.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:6.0:update1`,
        fs:  `cpe:2.3:a:fluxbb:fluxbb:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:6.0:update2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:6.0:update3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:6.0:update4`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:6.0:update5`,
        fs:  `cpe:2.3:a:tag1consulting:support_timer:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:6.0:update6`,
        fs:  `cpe:2.3:a:microsoft:active_directory_application_mode:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:grid_engine:6.0:update7`,
        fs:  `cpe:2.3:a:famatech:advanced_port_scanner:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:hotjava_browser:-`,
        fs:  `cpe:2.3:a:viewvc:viewvc:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:hotjava_browser:3.0`,
        fs:  `cpe:2.3:a:xchat:xchat:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:i-runbook:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_certificate_management_system:-`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_certificate_management_system:4.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_directory_server:-`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_directory_server:5.0`,
        fs:  `cpe:2.3:a:iconics:bizviz:8.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_directory_server:5.1`,
        fs:  `cpe:2.3:o:google:android:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_directory_server:5.1:sp1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_directory_server:5.1:sp2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_messaging_server:-`,
        fs:  `cpe:2.3:a:componentone:sizerone:8.0.20081.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_messaging_server:5.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:19.0.0.245:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_messaging_server_messenger_express:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:-`,
        fs:  `cpe:2.3:a:samba:samba:4.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp1`,
        fs:  `cpe:2.3:a:frontend_uploader_project:frontend_uploader:0.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp1:enterprise`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp10`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp10:enterprise`,
        fs:  `cpe:2.3:a:cognos:office_connection:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp2`,
        fs:  `cpe:2.3:a:docker:docker:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp2:enterprise`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.4:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp3:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp4`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp4:enterprise`,
        fs:  `cpe:2.3:a:adobe:flash_player:23.0.0.207:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp5`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp5:enterprise`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp6`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp6:enterprise`,
        fs:  `cpe:2.3:a:content_rating_project:content_rating:1.0.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp7`,
        fs:  `cpe:2.3:a:hp:business_availability_center:8.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp7:enterprise`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp8`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp8:enterprise`,
        fs:  `cpe:2.3:a:samba:samba:3.0.14a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:iplanet_web_server:4.1:sp9:enterprise`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ipmitool:-`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ipmitool:1.0.0`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.16:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ipmitool:1.8.9`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.7:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:j2ee_sdk:5.0`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:2.0.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.0.2.1`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.0.2.4`,
        fs:  `cpe:2.3:a:avst:callxpress:7.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.0.3.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.21.347:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.0.4.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.0.5.1`,
        fs:  `cpe:2.3:h:juniper:fips_secure_access_6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.0.6.1`,
        fs:  `cpe:2.3:a:tec-it:tbarcode3_activex:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.1.5.1`,
        fs:  `cpe:2.3:a:anixis:password_policy_client:3.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.1.5.2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_auto_updater:2.1.5.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_communications_services_delegated_administrator:-`,
        fs:  `cpe:2.3:o:xen:xen:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_communications_services_delegated_administrator:6:2005q1`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_db:10.2.2.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_db:10.3.1.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_db:10.4.1.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3080_concentrator:4.7.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_db:10.4.2.1`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1f:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_db:10.5.3.0`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_desktop_system:-`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.1.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:java_desktop_system:2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_desktop_system:2.0`,
        fs:  `cpe:2.3:a:netty_project:netty:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_dynamic_management_kit:-`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_dynamic_management_kit:5.1`,
        fs:  `cpe:2.3:a:redhat:richfaces:5.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_embedding_plugin:-`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_enterprise_system:-`,
        fs:  `cpe:2.3:o:fortinet:fortianalyzer_firmware:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_enterprise_system:5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p127:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_enterprise_system:5.0:update10`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_plug-in:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.15:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_plug-in:1.4`,
        fs:  `cpe:2.3:a:apache:qpid_java:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_plug-in:1.4.2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_plug-in:1.4.2_01`,
        fs:  `cpe:2.3:a:prosody:prosody:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_plug-in:1.4.2_02`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_plug-in:1.4.2_03`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_plug-in:1.4.2_04`,
        fs:  `cpe:2.3:a:adam_zaninovich:sounder:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_studio_enterprise:-`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_studio_enterprise:8`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_access_manager:-`,
        fs:  `cpe:2.3:h:ibm:r07:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_access_manager:6.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_access_manager:6.2`,
        fs:  `cpe:2.3:o:microsoft:windows_95:-:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_access_manager:6.3`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100504:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_access_manager:6.3:2005q4`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_access_manager:6.3_2005q4`,
        fs:  `cpe:2.3:a:winscp:winscp:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_access_manager:7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_access_manager:7.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:-`,
        fs:  `cpe:2.3:h:nvidia:geforce_gtx_1050:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:6.0`,
        fs:  `cpe:2.3:a:x3cms:x3_cms:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:7.0`,
        fs:  `cpe:2.3:a:hexagon:erdas_er_viewer:11.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:7.1`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp4:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.1`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.1::linux`,
        fs:  `cpe:2.3:a:compaq:storage_allocation_reporter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.1::sparc`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.1::windows`,
        fs:  `cpe:2.3:a:vessio:netbill:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.1::x86`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.1:ur1`,
        fs:  `cpe:2.3:a:vistasystems:spyder_control_suite_2005:2.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.1:ur1:platform`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.2`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.2::linux`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.2::sparc`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.2::windows`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:8.2::x86`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:9.0`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:9.0_0.1`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_application_server:9.1`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_calendar_server:-`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p334:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_calendar_server:6.2`,
        fs:  `cpe:2.3:a:rakus:maildealer:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_communications_express:-`,
        fs:  `cpe:2.3:a:ibm:spss_statistics:22.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_communications_express:2004q2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_communications_express:2005q1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.825:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_content_delivery_server:-`,
        fs:  `cpe:2.3:a:redhat:certificate_server:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_content_delivery_server:4.0`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:rc5:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_content_delivery_server:4.1`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_content_delivery_server:5.0`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_proxy_server:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_proxy_server:5.2:2003q4`,
        fs:  `cpe:2.3:a:namazu:namazu:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_proxy_server:5.2:2004q2`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_proxy_server:5.2:2005q1`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:-`,
        fs:  `cpe:2.3:a:tenable:nessus:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:5.0:-:enterprise`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:5.2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r12_b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:5.2:2003q4`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:5.2:2004q2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:5.2:2005q1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:5.2:2005q4`,
        fs:  `cpe:2.3:a:magento:magento2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:6.0`,
        fs:  `cpe:2.3:a:thirdwire:strike_fighters_israel:1.2.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_directory_server:7.0:-:enterprise`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_identity_manager:-`,
        fs:  `cpe:2.3:a:webmin:usermin:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_identity_manager:7.0`,
        fs:  `cpe:2.3:a:apache:traffic_server:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_identity_manager:7.1`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:-`,
        fs:  `cpe:2.3:h:cisco:ie-4000-8gs4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.2`,
        fs:  `cpe:2.3:a:crear.ne.jp:al-mail32:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.2:-:sparc`,
        fs:  `cpe:2.3:a:oracle:http_server:10.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.2:-:x86`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.2:_nil_:sparc`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.2:_nil_:x86`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.3`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.3:-:sparc`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.3:-:x86`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.3:_nil_:sparc`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:nl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messaging_server:6.3:_nil_:x86`,
        fs:  `cpe:2.3:a:garrettcom:magnum_managed_networks_software-6k:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messenger_express:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.017.20050:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_messenger_express:6`,
        fs:  `cpe:2.3:a:emc:powerpath:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_portal_server:-`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_portal_server:7.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_portal_server:7.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_portal_server:7.2`,
        fs:  `cpe:2.3:a:plone:plone:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2009.113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp1`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp10`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp2`,
        fs:  `cpe:2.3:a:snort:snort:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp3`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp4`,
        fs:  `cpe:2.3:o:cisco:catos:6.4\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp5`,
        fs:  `cpe:2.3:a:wdc:smartware:1.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp8`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:3.6:sp9`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:4.0`,
        fs:  `cpe:2.3:a:microsoft:office:2013:*:*:*:*:rt:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:4.0.2`,
        fs:  `cpe:2.3:a:rob_loach:sharethis:7.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:4.0.3`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:4.0.4`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.7270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:4.0.5`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.52:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:4.0.6`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_proxy_server:4.0.7`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:-`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.0`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds5300_storage_controller:1818:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:108.2146.2564.38893:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.1:sp1`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.1:sp2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.1:sp3`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.1:sp4`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.1:sp5`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.62:bpet62p:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.1:sp6`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:6.1:sp7`,
        fs:  `cpe:2.3:a:salome-platform:salome:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:7.0`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_system_web_server:7.0::hp_ux`,
        fs:  `cpe:2.3:a:hp:directories_support_for_proliant_management_processors:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_virtual_machine:-`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_console:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_console:2.2.2`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_console:2.2.3`,
        fs:  `cpe:2.3:h:ibm:netezza:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_console:2.2.4`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:1.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_console:2.2.5`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_start:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_start:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(26\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_start:1.0.1`,
        fs:  `cpe:2.3:o:yamaha:rta52i:4.01.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:java_web_start:1.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:javafx_sdk:1.3.0`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:javamail:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:javamail:1.1.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager_im_and_presence_service:10.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:javamail:1.2`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:javamail:1.3`,
        fs:  `cpe:2.3:a:inline:ihtml:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:javamail:1.3.2`,
        fs:  `cpe:2.3:o:sgi:irix:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:javaserver_web_dev_kit:-`,
        fs:  `cpe:2.3:h:cisco:network_analysis_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:-`,
        fs:  `cpe:2.3:a:ipswitch:imail_plus:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.0`,
        fs:  `cpe:2.3:h:cisco:spa941_4-line_ip_phone_with_1-port_ethernet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.6`,
        fs:  `cpe:2.3:a:opendental:opendental:16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.6:update7`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.7b`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.7b:update5`,
        fs:  `cpe:2.3:h:hp:cz256a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.8:update10`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.8:update13`,
        fs:  `cpe:2.3:a:pocketmags:inside_crochet:\@7f08017a:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.8:update14`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.8:update2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.395.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.8:update7`,
        fs:  `cpe:2.3:a:winscp:winscp:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.1.8:update8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.2.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.2.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.2.1:update3`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:beta3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.2.2:update4`,
        fs:  `cpe:2.3:a:netscape:directory_server:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.2.2:update5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.0`,
        fs:  `cpe:2.3:a:symantec:vrtsmh:5.0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.0_01`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.0_02`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.0_03`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)yg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.0_04`,
        fs:  `cpe:2.3:a:oracle:http_server:10.1.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.0_05`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1`,
        fs:  `cpe:2.3:a:ibm:trading_partner_interchange:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1:update19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1:update2`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1:update20`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_01`,
        fs:  `cpe:2.3:h:lexmark:cx725dthe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_01a`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_02`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.3.04027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_03`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_04`,
        fs:  `cpe:2.3:a:ca:erwin_process_modeler:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_05`,
        fs:  `cpe:2.3:a:imember360:imember360:3.5.001:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_06`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(28a\)ct:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_07`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:2nd_gen_i5_i7_sinit_51.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_08`,
        fs:  `cpe:2.3:a:th3professional:th3_professional_al_mohtarif:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_09`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_10`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_11`,
        fs:  `cpe:2.3:a:apache:libcloud:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_12`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_13`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.3.0.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_14`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_15`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_16`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-4520c_firmware:t450sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_17`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_18`,
        fs:  `cpe:2.3:a:emc:networker:7.5.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_19`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_20`,
        fs:  `cpe:2.3:a:emc:rsa_identity_management_and_governance:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_21`,
        fs:  `cpe:2.3:a:ibm:security_qradar_incident_forensics:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_22`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_23`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_24`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_25`,
        fs:  `cpe:2.3:a:webmin:usermin:0.950:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_26`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:9.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_27`,
        fs:  `cpe:2.3:a:invage:views:6.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.3.1_28`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3015_concentrator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.1:update7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)bc2f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2:update10`,
        fs:  `cpe:2.3:a:ati:hydravision_aps:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2:update14`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2:update19`,
        fs:  `cpe:2.3:a:openbsd:openssh:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2:update28`,
        fs:  `cpe:2.3:a:actividentity:corestreet_desktop_validation_client:2.1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2:update30`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:ko:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_3`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.7.2:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_4`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_5`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_6`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_7`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1054.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_8`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.12.464:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_9`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_10`,
        fs:  `cpe:2.3:a:sendmail:advanced_message_server:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_11`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_12`,
        fs:  `cpe:2.3:a:emc:my_documentum_for_microsoft_outlook:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_13`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_14`,
        fs:  `cpe:2.3:a:landesk:landesk_management_suite:8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_15`,
        fs:  `cpe:2.3:a:redhat:livecd-tools:18.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_16`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_17`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_18`,
        fs:  `cpe:2.3:a:google:v8:3.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_19`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_22`,
        fs:  `cpe:2.3:o:cisco:rv130w_wireless-n_multifunction_vpn_router_firmware:1.0.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_23`,
        fs:  `cpe:2.3:o:xen:xen:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_24::solaris`,
        fs:  `cpe:2.3:o:ibm:z\/os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_25`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_26`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_27`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_28`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.9.0:*:*:*:*:*:*:development_snapshot`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_29`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_30`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_31`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_32`,
        fs:  `cpe:2.3:a:mahara:mahara:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_33`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_34`,
        fs:  `cpe:2.3:h:samsung:dvr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_35`,
        fs:  `cpe:2.3:a:iconics:genesis32:9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_36`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24:rc1.7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.4.2_37`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0`,
        fs:  `cpe:2.3:a:dell:toolbar:1.8.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update1`,
        fs:  `cpe:2.3:a:b-e-soft:artweaver:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update11`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update11_b03`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update12`,
        fs:  `cpe:2.3:a:gnome:glib:2.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update13`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update14`,
        fs:  `cpe:2.3:a:adobe:robohelp:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update16`,
        fs:  `cpe:2.3:a:nero:installer:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update17`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.0.2:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update18`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update19`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update2`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:7.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update20`,
        fs:  `cpe:2.3:a:mahara:mahara:16.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update21`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update22`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update23`,
        fs:  `cpe:2.3:a:hp:sockd:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update24`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.1.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update25`,
        fs:  `cpe:2.3:h:hp:color_laserjet_enterprise_cp4025:cc490a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update26`,
        fs:  `cpe:2.3:a:tenfourzero:shutter:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update27`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update28`,
        fs:  `cpe:2.3:a:autodesk:material_library_base_resolution_image_library_2012:2.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update29`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update31`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update33`,
        fs:  `cpe:2.3:a:studiohitori:twitrocker2_android:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update4`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update5`,
        fs:  `cpe:2.3:a:atlassian:jira:3.10.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update6`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:a6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update7`,
        fs:  `cpe:2.3:a:samba:samba:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update7_b03`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update8`,
        fs:  `cpe:2.3:a:apache:derby:10.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0:update9`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0.180`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0.220:update22`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0.260:update26`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0.280:update28`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.19:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0.300:update30`,
        fs:  `cpe:2.3:o:d-link:dir505_shareport_mobile_companion_firmware:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.5.0.320:update32`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0`,
        fs:  `cpe:2.3:a:impresspages:impresspages_cms:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_10`,
        fs:  `cpe:2.3:a:corner_project:corner:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_11`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_12`,
        fs:  `cpe:2.3:a:debian:apt:0.7.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_13`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_14`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.1.0.4880:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_15`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_16`,
        fs:  `cpe:2.3:a:augeas:augeas:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_17`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_18`,
        fs:  `cpe:2.3:a:jamroom:search_module:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_19`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_2`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.3:-:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_20`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_20:x64`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_21`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_3`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_4`,
        fs:  `cpe:2.3:a:gnome:glib:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_5`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.5.102.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_6`,
        fs:  `cpe:2.3:a:microsoft:java_virtual_machine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update_7`,
        fs:  `cpe:2.3:a:beroux:rename-it:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update1`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update1_b06`,
        fs:  `cpe:2.3:a:springsignage:xibo:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0:update2`,
        fs:  `cpe:2.3:a:entity_reference_project:entityreference:7.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.110`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.160`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.7:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.170`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.170::~~~~x64~`,
        fs:  `cpe:2.3:a:wec_map_project:wec_map:3.0.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.180`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.190`,
        fs:  `cpe:2.3:a:apache:derby:10.9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.200:update20`,
        fs:  `cpe:2.3:o:sixnet:rtu_firmware:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.200:update20:~~~~x64~`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.210:update21`,
        fs:  `cpe:2.3:h:hp:3com_switch:4500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.210:update21:~~~~x64~`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.220:update22`,
        fs:  `cpe:2.3:a:cyberlink:labelprint:2.5.3602:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.220:update22:~~~~x64~`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.230:update23`,
        fs:  `cpe:2.3:a:f5:big-ip_protocol_security_module:11.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.240:update24`,
        fs:  `cpe:2.3:a:photoxhibit_project:photoxhibit:2.1.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.240:update24:~~~~x64~`,
        fs:  `cpe:2.3:a:powersoftware:winarchiver:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.250:update25`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.250:update25:~~~~x64~`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.3.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.260:update26`,
        fs:  `cpe:2.3:a:cnn:cnnmoney_portfolio_for_stocks:1.0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.260:update26:~~~~x64~`,
        fs:  `cpe:2.3:a:f5:big-ip_configuration_utility:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.270:update27`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.270:update27:~~~~x64~`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.290:update29`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.290:update29:~~~~x64~`,
        fs:  `cpe:2.3:a:apport_project:apport:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jdk:1.6.0.300:update30`,
        fs:  `cpe:2.3:a:novell:imanager:2.7.3:ftf2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:-`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.1.7`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.13.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.1.8:update13`,
        fs:  `cpe:2.3:a:kajona:kajona:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.1.8:update14`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.1.8:update7`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.1.8:update8`,
        fs:  `cpe:2.3:o:ibm:linux_on_zseries:-:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.2.2:update10`,
        fs:  `cpe:2.3:a:apache:standard_taglibs:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.0`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.0:update1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.0:update2`,
        fs:  `cpe:2.3:o:d-link:dcs-942l_firmware:2.11.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.0:update3`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.0:update4`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.0:update5`,
        fs:  `cpe:2.3:o:redhat:desktop:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update1`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update12`,
        fs:  `cpe:2.3:a:bea:liquid_data:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update15`,
        fs:  `cpe:2.3:a:sosocome:family_location:3.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update16`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update17`,
        fs:  `cpe:2.3:o:novell:suse_linux_enterprise_software_development_kit:11.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update18`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update19`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update1a`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update2`,
        fs:  `cpe:2.3:a:goforandroid:go_sms_pro:3.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update20`,
        fs:  `cpe:2.3:a:emurasoft:emftp:-:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update4`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.37:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1:update8`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_2`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-4.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_03`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_04`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_05`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_06`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_07`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_08`,
        fs:  `cpe:2.3:a:marek_gutkowski:mod_chroot:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_09`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_10`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_11`,
        fs:  `cpe:2.3:a:ibm:pureapplication_system:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_12`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_13`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_14`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_15`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_16`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_17`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.1.95.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_18`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_19`,
        fs:  `cpe:2.3:a:citrix:edgesight_for_presentation_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_20`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_21`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_22`,
        fs:  `cpe:2.3:a:mochiweb_project:mochiweb:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_23`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.2.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_24`,
        fs:  `cpe:2.3:a:mcafee:securitycenter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_25`,
        fs:  `cpe:2.3:a:adobe:adobe_application_manager:2.0.240.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_26`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_27`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.3.1_28`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.1`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.1:update1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.1:update2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.1:update3`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.1:update4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.6-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.1:update7`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2`,
        fs:  `cpe:2.3:a:apache:ambari:2.4.2:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update10`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.0.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update11`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.0.1270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update12`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update13`,
        fs:  `cpe:2.3:a:novell:zenworks_patch_management_server:6.0.0.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update14`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update15`,
        fs:  `cpe:2.3:a:interactivedata:esignal:10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update19`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_link_for_visual_studio:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update21`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update28`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update3`,
        fs:  `cpe:2.3:a:cgene:security_file_manager:1.0.6:-:-:*:trial:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update4`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update5`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update6`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update7`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update8`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2:update9`,
        fs:  `cpe:2.3:a:microsoft:ie:4.01:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_2`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.00.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_4`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_5`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_6`,
        fs:  `cpe:2.3:a:google:android_api:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_7`,
        fs:  `cpe:2.3:a:hitachi:serverconductor\/deploymentmanager:01-01:-:-:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_8`,
        fs:  `cpe:2.3:a:google:chrome:17.0.954.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_9`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:update9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_10`,
        fs:  `cpe:2.3:a:adobe:soundbooth_cs4:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_11`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.28-25.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_12`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.2.0.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_13`,
        fs:  `cpe:2.3:o:cisco:ios:12.3jeb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_14`,
        fs:  `cpe:2.3:a:otrs:otrs:1.3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_15`,
        fs:  `cpe:2.3:a:keepass:keepass:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_16`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_17`,
        fs:  `cpe:2.3:a:mrcgiguy:guestbook:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_18`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_19`,
        fs:  `cpe:2.3:o:microsoft:windows-ce:4.20.1081:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_20`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_21`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_22`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_23`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.244:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_24`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:17.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_25`,
        fs:  `cpe:2.3:a:redhat:lv:4.49.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_26`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3.4b.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_27`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_28`,
        fs:  `cpe:2.3:a:rsbac:rule_set_based_access_control:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_29`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_30`,
        fs:  `cpe:2.3:a:emc:iomega_automatic_backup:1.2.10.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_31`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_32`,
        fs:  `cpe:2.3:a:bluecoat:unified_agent:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_33`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_34`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_35`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_36`,
        fs:  `cpe:2.3:a:google:chrome:14.0.788.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.4.2_37`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1\(2.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.419:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update10`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update11`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(10.5\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update12`,
        fs:  `cpe:2.3:a:adobe:animate:15.2.1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update13`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update14`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update15`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:08-00-02:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update16`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update17`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update18`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-52p-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update19`,
        fs:  `cpe:2.3:a:caucho:resin:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update2`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update20`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update21`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update22`,
        fs:  `cpe:2.3:a:valve:steam:2.10.91.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update23`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update24`,
        fs:  `cpe:2.3:h:polycom:hdx_8006:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update25`,
        fs:  `cpe:2.3:a:joobi:com_jnews:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update26`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update27`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update28`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update29`,
        fs:  `cpe:2.3:a:david_king:vino:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update3`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update31`,
        fs:  `cpe:2.3:a:teradata:wincli_developer\&#39;s_kit:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update33`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update4`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:7.5.29.0:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update5`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.0.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update6`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update7`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update8`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0:update9`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.02b25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.40:update4`,
        fs:  `cpe:2.3:h:xerox:workcentre_32_color:01.02.058.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.50:update5`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.13:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.60:update6`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.90:update9`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.100`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.110`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.120`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.130`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.6:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.140`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.150`,
        fs:  `cpe:2.3:a:oracle:http_server:9.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.170`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.180`,
        fs:  `cpe:2.3:a:alexis_wilke:protected_node:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.190`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.200:update20`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)sc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.220:update22`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.260:update26`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.280:update28`,
        fs:  `cpe:2.3:a:citrix:single_sign-on_console:4.8.6410.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.300:update30`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.8.820:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.5.0.320:update32`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.37a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_10`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_11`,
        fs:  `cpe:2.3:a:pootlepress:pootle_button:1.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_12`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_13`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_14`,
        fs:  `cpe:2.3:a:qemu:qemu:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_15`,
        fs:  `cpe:2.3:a:microsoft:directx:9.0c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_16`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_17`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf235a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_18`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(3e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.13:pre15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_2`,
        fs:  `cpe:2.3:a:acronis:true_image_agent:9.1.3854:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_20`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_21`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.8.0u\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_4`,
        fs:  `cpe:2.3:a:oracle:service_contracts:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_5`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_6`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_7`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update_9`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.6.3.633:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update1`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.3.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update2`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0:update3`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0.10`,
        fs:  `cpe:2.3:a:haxx:curl:7.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0.20`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p147:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0.30`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0.50`,
        fs:  `cpe:2.3:a:corel:painter:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0.60`,
        fs:  `cpe:2.3:a:cyberlink:powerdirector:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:1.6.0.70`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:5.0.22.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.100:update10`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.110:update11`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.120:update12`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.130:update13`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.130:update13:~~~~x64~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.140:update14`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.150:update15`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.3:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.160:update16`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.12:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.170:update17`,
        fs:  `cpe:2.3:h:hp:jf285a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.170:update17:~~~~x64~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.180:update18`,
        fs:  `cpe:2.3:a:bfac:grandparenting_is_great:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.190:update19`,
        fs:  `cpe:2.3:h:dell:poweredge_r710:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.200:update20`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker_toolkit:6.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.200:update20:~~~~x64~`,
        fs:  `cpe:2.3:a:snort:snort:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.210:update21`,
        fs:  `cpe:2.3:a:grape_project:grape:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.210:update21:~~~~x64~`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.220:update22`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.220:update22:~~~~x64~`,
        fs:  `cpe:2.3:a:marked_project:marked:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.230:update23`,
        fs:  `cpe:2.3:a:symantec:vrtsccg:5.0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.230:update23:~~~~x64~`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.240:update24`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.240:update24:~~~~x64~`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:2.1:*:ia64-ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.250:update25`,
        fs:  `cpe:2.3:a:bea:weblogic_portal:9.2:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.250:update25:~~~~x64~`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.260:update26`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.260:update26:~~~~x64~`,
        fs:  `cpe:2.3:a:mahara:mahara:1.3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.270:update27`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.270:update27:~~~~x64~`,
        fs:  `cpe:2.3:a:field_group_project:field_group:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.290:update29`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.290:update29:~~~~x64~`,
        fs:  `cpe:2.3:a:spice_project:spice:0.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jre:6.0.300:update30`,
        fs:  `cpe:2.3:h:intel:pentium:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jsse:-`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jsse:1.0.3`,
        fs:  `cpe:2.3:o:apple:os_x_server:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jsse:1.0.3_01`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jsse:1.0.3_02`,
        fs:  `cpe:2.3:a:google:v8:3.24.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:jsse:1.0.3_03`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p160:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:libattach:1.4.2`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r8-s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:linux:-`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.10.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:management_center:-`,
        fs:  `cpe:2.3:a:rack_project:rack:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:mysql_connector%2fj:-`,
        fs:  `cpe:2.3:a:dell:openmanage_baseboard_management_controller_utilities:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:mysql_connector%2fj:5.1.8`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:mysql_connector_c:6.0.2`,
        fs:  `cpe:2.3:a:divx:codec:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:n1_grid_engine:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:n1_grid_engine:5.3`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:n1_grid_engine:6.0`,
        fs:  `cpe:2.3:a:jenkins:git:0.8.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:n1_system_manager:-`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:n1_system_manager:1.1`,
        fs:  `cpe:2.3:a:intermesh:group-office:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:net_connect_software:-`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300eec_firmware:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:net_connect_software:3.2.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.6.6\(4109\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:net_connect_software:3.2.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:netbeans_developer:-`,
        fs:  `cpe:2.3:a:adobe:air:17.0.0.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:netdynamics:-`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:netdynamics:4.0`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:netdynamics:4.1`,
        fs:  `cpe:2.3:a:brio:folder_size_for_windows:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:netdynamics:4.1.2`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:netdynamics:4.1.3`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_9951:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:netdynamics:5.0`,
        fs:  `cpe:2.3:a:hp:openview_select_access:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:netra_1280:-`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:nfs:-`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:nss:-`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_administration_server:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_administration_server:5.2`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:5.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_application_server:-`,
        fs:  `cpe:2.3:a:tony_freixas:ubercart_product_keys:6.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_application_server:6.0`,
        fs:  `cpe:2.3:a:symantec:norton_security_scan:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_application_server:6.5`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_application_server:7.0`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:4.16`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:4.16:sp1`,
        fs:  `cpe:2.3:a:perl:perl:5.12.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.0`,
        fs:  `cpe:2.3:h:hp:arcsight_logger_appliance:l7400-san:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.0:sp1`,
        fs:  `cpe:2.3:h:supermicro:x9drw-7tpf\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.1`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.1:sp1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.1:sp2`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.1:sp3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.665.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.1:sp3:x86`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.1:sp4`,
        fs:  `cpe:2.3:a:google:chrome:15.0.869.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_directory_server:5.2`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_messaging_server:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.184:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_messaging_server:5.2`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_messaging_server:6.2`,
        fs:  `cpe:2.3:a:libtiff:libtiff:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:-`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.24.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp10`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds3512:1746:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp11`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11b\)e14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp12`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp13`,
        fs:  `cpe:2.3:h:hp:ibrix_x9300:aw540d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp14`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20\)sl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp3`,
        fs:  `cpe:2.3:a:adobe:flex_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp5`,
        fs:  `cpe:2.3:a:adobe:flash_player_esr:18.0.0.329:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp6`,
        fs:  `cpe:2.3:h:cisco:unity_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp7`,
        fs:  `cpe:2.3:a:cisco:ip_contact_center_hosted:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp8`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:4.1:sp9`,
        fs:  `cpe:2.3:a:vidyo:vidyo_conferencing_outlook_plug-in:2.0.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:6.1`,
        fs:  `cpe:2.3:a:longtailvideo:jw_player_for_flash_\&amp;_html5_video_plugin:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:6.1:sp1`,
        fs:  `cpe:2.3:a:isc:bind:9.3.5:p2_w1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:one_web_server:6.1:sp2`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1_pk5_bl19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:1.1.0`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:2.0.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_5500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:2.1.0`,
        fs:  `cpe:2.3:a:cisco:catalyst_12xx_supervisor_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:2.2.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:2.3.0`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:2.4.0`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:2.4.1`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:2.4.2`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:3.0.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:3.0.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:3.1.0`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd3.t666_firmware:1.24.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:3.1.1`,
        fs:  `cpe:2.3:a:aimluck:aipo-plus:5.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:3.1.9420`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org:3.3.9567`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert2:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org_installer:1.0`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openoffice.org_installer:1.0.9221`,
        fs:  `cpe:2.3:a:fourkitchens:block_class:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openwindows:-`,
        fs:  `cpe:2.3:h:intel:c202_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openwindows:3.0`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openwindows:3.6`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openwindows:3.6.1`,
        fs:  `cpe:2.3:a:exim:exim:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:openwindows:3.6.2`,
        fs:  `cpe:2.3:h:huawei:s5700:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:patch_manager:-`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:patchpro:-`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.3.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:patchpro:2.0`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:-`,
        fs:  `cpe:2.3:a:microsoft:outlook:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:1.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:2.0`,
        fs:  `cpe:2.3:a:umn:mapserver:5.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.0`,
        fs:  `cpe:2.3:a:david_king:vino:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.0::linux`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.1`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:3.0.0.4.360:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.1.1`,
        fs:  `cpe:2.3:a:google:talk_plugin:1.9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.1.1::linux`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.1.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.2`,
        fs:  `cpe:2.3:a:google:chrome:17.0.960.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3jk:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.5`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(1s\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.6`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_server_software:3.7`,
        fs:  `cpe:2.3:a:apache:syncope:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_windows_connector:1.1::linux`,
        fs:  `cpe:2.3:a:milesj:decoda:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_windows_connector:1.1::sparc`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_windows_connector:1.1::x86`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_windows_connector:2.0::linux`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_windows_connector:2.0::sparc`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:ray_windows_connector:2.0::x86`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:rpc.ruserd:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:rte:-`,
        fs:  `cpe:2.3:a:tenable:nessus:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:rte:1.4.1`,
        fs:  `cpe:2.3:a:mibizapps:no_fuss_home_loans:1.0035.b0035:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:rte:1.4.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20120426:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:-`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.1.3`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.15.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.1.8_007`,
        fs:  `cpe:2.3:a:python:pillow:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.2.2_010`,
        fs:  `cpe:2.3:a:hp:executive_scorecard:9.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.2.2_10`,
        fs:  `cpe:2.3:a:citrix:cloudportal_services_manager:10.0:cu2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.2.2_14`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.0`,
        fs:  `cpe:2.3:a:rsa:authentication_agent_for_web:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.0_01`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.0_02`,
        fs:  `cpe:2.3:a:security_questions_project:security_questions:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.0_03`,
        fs:  `cpe:2.3:a:mono:mono:1.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.0_04`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)yy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.0_05`,
        fs:  `cpe:2.3:a:emc:rsa_access_manager:6.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_01`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:5.1.2:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_01a`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_02`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_03`,
        fs:  `cpe:2.3:a:google:chrome:4.0.212.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_04`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_05`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_06`,
        fs:  `cpe:2.3:a:ibm:rational_directory_server:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_07`,
        fs:  `cpe:2.3:o:gehealthcare:optima_ct540_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_08`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_09`,
        fs:  `cpe:2.3:a:powerquest:deploycenter:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_10`,
        fs:  `cpe:2.3:a:webyog:sqlyog:1.71:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_11`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0562:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_12`,
        fs:  `cpe:2.3:a:citrix:xendesktop:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_13`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_14`,
        fs:  `cpe:2.3:h:hp:jd671a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_15`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_16`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.2:*:free:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_17`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_18`,
        fs:  `cpe:2.3:a:apple:webkit:522.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_19`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_20`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_21`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:-:opscenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_22`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_23`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_24`,
        fs:  `cpe:2.3:a:fontconfig_project:fontconfig:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_25`,
        fs:  `cpe:2.3:a:tigase:tigase:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_26`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_27`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3.1_28`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3_02`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.3_05`,
        fs:  `cpe:2.3:a:pragyan_cms_project:pragyan_cms:2.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2`,
        fs:  `cpe:2.3:h:nvidia:geforce_gtx_960m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_1`,
        fs:  `cpe:2.3:a:microsoft:jet:4.0.8618.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_2`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_02`,
        fs:  `cpe:2.3:a:sunil_nanda:blue_wrench_video_widget:2.0.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_03`,
        fs:  `cpe:2.3:a:google:cityhash:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_3`,
        fs:  `cpe:2.3:a:cisco:trust_agent:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_4`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_04`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.4:p7_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_5`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5103:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_6`,
        fs:  `cpe:2.3:a:mochiweb_project:mochiweb:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_7`,
        fs:  `cpe:2.3:a:drupal:drupal:6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_8`,
        fs:  `cpe:2.3:a:algosec:firewall_analyzer:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_08`,
        fs:  `cpe:2.3:a:sympa:sympa:3.1b.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_09`,
        fs:  `cpe:2.3:a:drupal:drupal:6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_9`,
        fs:  `cpe:2.3:a:google:android_api:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_10`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_11`,
        fs:  `cpe:2.3:h:3com:3c17701-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_12`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_13`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_14`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_4500e_ip_cameras:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_15`,
        fs:  `cpe:2.3:a:apache:subversion:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_16`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_17`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_18`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_19`,
        fs:  `cpe:2.3:a:google:v8:3.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_20`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_21`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_22`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_23`,
        fs:  `cpe:2.3:a:redhat:jboss_community_application_server:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_24`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.8:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_25`,
        fs:  `cpe:2.3:a:mcafee:virusscan:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_26`,
        fs:  `cpe:2.3:a:t1lib:t1lib:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.2_27`,
        fs:  `cpe:2.3:a:wordfence_security_project:wordfence_security:5.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.4.3_13`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.5`,
        fs:  `cpe:2.3:h:supermicro:x8dtl-3f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.5.0_05`,
        fs:  `cpe:2.3:a:plone:plone:4.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sdk:1.5.0_6`,
        fs:  `cpe:2.3:a:perl:perl:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:seam:-`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:seam:1.0`,
        fs:  `cpe:2.3:a:alphazip:alphazip:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:seam:1.0.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:seam:1.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:secure_global_desktop:-`,
        fs:  `cpe:2.3:a:nzhondas:nzhondas.com:3.6.14:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:secure_global_desktop:3.42`,
        fs:  `cpe:2.3:a:citrix:access_management_console_knowledge_base:4.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:secure_global_desktop:4.0`,
        fs:  `cpe:2.3:a:sybase:powerdynamo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:secure_global_desktop_client:4.41.907`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:service_tags:1.1.3`,
        fs:  `cpe:2.3:a:hp:trayapp:82.0.188.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:-`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.0`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.0.1`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.1`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.1.1a`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.1.2`,
        fs:  `cpe:2.3:a:ibm:atlas_ediscovery_process_management:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.1.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.243:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.1.4`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.1c`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:1.2`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.0`,
        fs:  `cpe:2.3:a:red-gate:sql_prompt:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.3`,
        fs:  `cpe:2.3:a:plone:plone:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.13s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.5.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.6`,
        fs:  `cpe:2.3:o:huawei:s7712_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.6:hw3`,
        fs:  `cpe:2.3:a:emil_stjerneman:linkit:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.6:hw3:x86`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0404hf-s-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.6:hw5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.274:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.6:hw5:x86`,
        fs:  `cpe:2.3:h:verizon:wireless_network_extender:scs-2u01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.7`,
        fs:  `cpe:2.3:a:python:python:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:2.8`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:4.1.1`,
        fs:  `cpe:2.3:a:sun:grid_engine:6.0:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:4.1.2`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:4.1.3`,
        fs:  `cpe:2.3:a:directwebremoting:direct_web_remoting:3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:4.1.3:u1`,
        fs:  `cpe:2.3:a:isc:bind:9.10.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:5.3`,
        fs:  `cpe:2.3:a:tresata:tree-orion:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:5.4`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnivista:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:5.5`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:5.5.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.3.0.878:unknown:online_windows_2000:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:5.6`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_peopletools:8.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:5.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:5.9`,
        fs:  `cpe:2.3:a:dymo:dymo_file:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:7.0`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(27b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:8.0`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.3:*:free:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:8.1`,
        fs:  `cpe:2.3:a:bm:bank_of_moscow_eirts_rent:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:8.2`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.3.7:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:9`,
        fs:  `cpe:2.3:a:altiris:auditexpress_setup_solution:6.2.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:9.0`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:9.1`,
        fs:  `cpe:2.3:o:f5:tmos:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:10`,
        fs:  `cpe:2.3:a:ibm:tivoli_it_asset_management_for_it:7.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:10.0`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:11`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:solaris:11.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metabrokers_\&amp;_bridges:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_answerbook2:-`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_answerbook2:1.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_answerbook2:1.4.2`,
        fs:  `cpe:2.3:a:gnome:screensaver:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_answerbook2:1.4.4`,
        fs:  `cpe:2.3:a:rockwellautomation:factorytalk_services_platform:cpr9:sr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_isp_server:-`,
        fs:  `cpe:2.3:a:xnview:xnview:1.95.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_libfont:-`,
        fs:  `cpe:2.3:a:brian_akers:mod_mp3:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_libxfont:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_pc_netlink:-`,
        fs:  `cpe:2.3:a:koha:koha:3.14.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_pc_netlink:1.0`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_pc_netlink:1.1`,
        fs:  `cpe:2.3:h:enterasys:roamabout_ap3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_pc_netlink:1.2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solaris_pc_netlink:2.0`,
        fs:  `cpe:2.3:h:oracle:sun_blade_x6250:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solstice_adminsuite:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solstice_adminsuite:2.1`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solstice_adminsuite:2.2`,
        fs:  `cpe:2.3:a:grape_project:grape:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solstice_backup:-`,
        fs:  `cpe:2.3:h:xerox:workcentre_5855:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solstice_backup:5.1`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solstice_backup:6.0`,
        fs:  `cpe:2.3:a:pdlk:hardest_game_collection:1.5.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solstice_x.25:9.2:unknown:sparc`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:solstice_x.25:9.2:unknown:x86`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:staroffice:-`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:staroffice:5.1`,
        fs:  `cpe:2.3:a:hp:workload_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:staroffice:5.2`,
        fs:  `cpe:2.3:h:axis:2130_ptz_network_camera:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:staroffice:6.0`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:staroffice:7.0`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(3c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:staroffice:8.0`,
        fs:  `cpe:2.3:a:php:php:5.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:starsuite:-`,
        fs:  `cpe:2.3:a:spip:spip:3.1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:storage_automated_diagnostic_environment:-`,
        fs:  `cpe:2.3:a:mysql:mysql:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:storage_automated_diagnostic_environment:2.4`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:storagetek_3510:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:5.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:storedge_3310_scsi_array:-`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:storedge_3510_fc_array:-`,
        fs:  `cpe:2.3:h:intel:server_board_s5000xvn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:storedge_6130_arrays:-`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:storedge_6130_arrays:06.12.10.11`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:storedge_enterprise_backup_software:-`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.1_3e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:storedge_enterprise_backup_software:7.0`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:storedge_enterprise_backup_software:7.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.28:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:storedge_enterprise_backup_software:7.2`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sun:sun_fire:-`,
        fs:  `cpe:2.3:o:cisco:ios_xr:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sun_ftp:-`,
        fs:  `cpe:2.3:a:ibm:sterling_connect_direct_user_interface:1.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sun_pci_ii_driver:2.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sunforum:-`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:es:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sunone_starter_kit:-`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server_solution_engine:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:-`,
        fs:  `cpe:2.3:a:kvirc:kvirc:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:3.5`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:5.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.0`,
        fs:  `cpe:2.3:a:horde:imp:5.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.0.1`,
        fs:  `cpe:2.3:h:siemens:hinet_lp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.0.2`,
        fs:  `cpe:2.3:a:mailtraq:mailtraq:2.17.3.3150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.0.3`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.0.3c`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.1`,
        fs:  `cpe:2.3:a:monotone:monotone:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.1.1`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.05:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.1.2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.1.3`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.1.3c`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.1.3u1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.1.4`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:4.1psr_a`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.1`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.2`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.6:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.3`,
        fs:  `cpe:2.3:a:marconi:forethought:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.4`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.5`,
        fs:  `cpe:2.3:h:f5:big-ip_access_policy_manager:11.2.0:*:*:*:*:*:*:standalone`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.5.1`,
        fs:  `cpe:2.3:o:cray:unicos_max:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.6`,
        fs:  `cpe:2.3:a:quantum:management_console:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.7`,
        fs:  `cpe:2.3:a:conky:conky:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.8`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.9`,
        fs:  `cpe:2.3:a:teradata:c_pp2:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.10`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.10:-:~~~~amd64~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.10:-:sparc`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.11`,
        fs:  `cpe:2.3:a:sebastien_sauvage:webgobbler:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.11::~~~~sparc~`,
        fs:  `cpe:2.3:a:tenon:itools:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.11::express`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_3_firmware:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.11:-:~~~~amd64~`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sun:sunos:5.11:-:~~~~x86~`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:7.0:xpu_22.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sunpci_ii_driver_software:-`,
        fs:  `cpe:2.3:a:rsa:authentication_agent_for_web:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sunvts:-`,
        fs:  `cpe:2.3:a:isc:bind:9.7.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sunvts:4.0`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sunvts:4.1`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sunvts:4.2`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:sunvts:4.3`,
        fs:  `cpe:2.3:a:google:chrome_frame:15.0.874.121:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:wbem_services:-`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.3.4:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:web-based_enterprise_management:-`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.07.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sun:workshop:-`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.63:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunil_nanda:blue_wrench_video_widget:1.0.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-71-\/f:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunil_nanda:blue_wrench_video_widget:1.0.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1660.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunil_nanda:blue_wrench_video_widget:1.0.2:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunil_nanda:blue_wrench_video_widget:1.0.3:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunil_nanda:blue_wrench_video_widget:1.0.4:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache_friends:xampp:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunil_nanda:blue_wrench_video_widget:1.0.5:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunil_nanda:blue_wrench_video_widget:2.0.0:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:usr:netwaiting:2.5.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunil_nanda:blue_wrench_video_widget:2.0.1:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sunstormgames:donut_maker:1.27::~~~android~~`,
        fs:  `cpe:2.3:a:apache:hadoop:0.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:superluckycasino:slots_heaven%3afree_slot_machine:1.123::~~~android~~`,
        fs:  `cpe:2.3:a:iss:blackice_server_protection:3.6ccc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dcl-6f:-`,
        fs:  `cpe:2.3:a:gentoo:glibc:2.5:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dcl-if:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dct-hibqf:-`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dct-hln4f:-`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dct-ibqf:-`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dg6-f:-`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dgg-qf:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.7:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dgi-f:-`,
        fs:  `cpe:2.3:o:huawei:s12700_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dgt-hf:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.579:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dgt-hibqf:-`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dgt-hlf:-`,
        fs:  `cpe:2.3:a:netiq:self_service_password_reset:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dgt-hlibqf:-`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dgu-f:-`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8dgu-ln4f%2b:-`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8scm-f:-`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8sgl-f:-`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8sme-f:-`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_mobile:8.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8sml-7:-`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8sml-7f:-`,
        fs:  `cpe:2.3:a:lxml:lxml:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8sml-i:-`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:h8sml-if:-`,
        fs:  `cpe:2.3:a:squirrelmail:squirrelmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:supermicro:intelligent_platform_management_firmware:2.24:-:~-~-~-~x9_generation_motherboards~`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.14:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:supermicro:intelligent_platform_management_firmware:2.26:-:~-~-~-~x9_generation_motherboards~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:supermicro:intelligent_platform_management_firmware:3.15:-:~-~-~-~x9_generation_motherboards~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x7spa-hf:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.29.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x7spa-hf-d525:-`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x7spe-h-d525:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x7spe-hf:-`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x7spe-hf-d525:-`,
        fs:  `cpe:2.3:h:hp:storageworks_p2000_g3_iscsi_dual_controller_lff_array_system:bk830a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x7spt-df-d525:-`,
        fs:  `cpe:2.3:a:apache:poi:2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x7spt-df-d525%2b:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtl-3f:-`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.1.3.108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtl-6f:-`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtl-if:-`,
        fs:  `cpe:2.3:h:juniper:srx110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtn%2b-f:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:21.0.0.97:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtn%2b-f-lr:-`,
        fs:  `cpe:2.3:o:huawei:s9312e_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtu-6f%2b:-`,
        fs:  `cpe:2.3:a:plone:plone:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtu-6f%2b-lr:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:14.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtu-6tf%2b:-`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtu-6tf%2b-lr:-`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtu-ln4f%2b:-`,
        fs:  `cpe:2.3:a:libav:libav:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8dtu-ln4f%2b-lr:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8si6-f:-`,
        fs:  `cpe:2.3:a:basespace_ruby_sdk_project:basespace_ruby_sdk:0.1.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8sia-f:-`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8sie-f:-`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8sie-ln4f:-`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ecg:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8sil-f:-`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8sit-f:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8sit-hf:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x8siu-f:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.010.20056:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dax-7f:-`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dax-7f-hft:-`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dax-7tf:-`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dax-if:-`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dax-if-hft:-`,
        fs:  `cpe:2.3:a:oracle:virtualization:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dax-itf:-`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(5b\)su6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9db3-f:-`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.43.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9db3-tpf:-`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.4.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dbi-f:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dbi-tpf:-`,
        fs:  `cpe:2.3:a:ati:catalyst_install_manager:3.0.682.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dbl-3f:-`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.1.7.l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dbl-if:-`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dbu-3f:-`,
        fs:  `cpe:2.3:o:buffalotech:whr-300hp2_firmware:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dbu-if:-`,
        fs:  `cpe:2.3:a:mybb:mybb:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dr3-f:-`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dr3-ln4f%2b:-`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dr7-ln4f:-`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.3c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dr7-ln4f-jbod:-`,
        fs:  `cpe:2.3:a:redhat:kernel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dr7-tf%2b:-`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drd-7jln4f:-`,
        fs:  `cpe:2.3:a:adobe:camera_raw:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drd-7ln4f:-`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drd-7ln4f-jbod:-`,
        fs:  `cpe:2.3:h:crossbeamsystems:x40:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drd-ef:-`,
        fs:  `cpe:2.3:a:wt_directory_project:wt_directory:1.4.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drd-if:-`,
        fs:  `cpe:2.3:a:inline_entity_form_project:inline_entity_form:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dre-ln4f:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dre-tf%2b:-`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff:-`,
        fs:  `cpe:2.3:a:symantec:product_authentication_service_client:4.3.28.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-7:-`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.0.0:alpha:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-7%2b:-`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.4.1-14:fix02:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-7g%2b:-`,
        fs:  `cpe:2.3:a:ibm:spectrum_scale:4.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-7t%2b:-`,
        fs:  `cpe:2.3:a:qemu:qemu:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-7tg%2b:-`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-i%2b:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-ig%2b:-`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-it%2b:-`,
        fs:  `cpe:2.3:a:podofo_project:podofo:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drff-itg%2b:-`,
        fs:  `cpe:2.3:a:citrix:xenserver:5.6:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drfr:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drg-hf:-`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drg-hf%2b:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drg-htf:-`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drg-htf%2b:-`,
        fs:  `cpe:2.3:o:huawei:nip6600_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drh-7f:-`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drh-7tf:-`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drh-if:-`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:4.1.1.0805:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drh-itf:-`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dri-f:-`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9dri-ln4f%2b:-`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drl-3f:-`,
        fs:  `cpe:2.3:a:vmware:workstation:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drl-ef:-`,
        fs:  `cpe:2.3:h:siemens:scalance_xr-300poe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drl-if:-`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drt-f:-`,
        fs:  `cpe:2.3:a:danielkorte:nodeaccesskeys:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drt-h6f:-`,
        fs:  `cpe:2.3:a:sun:sun_ftp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drt-h6ibff:-`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r2-s2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drt-h6ibqf:-`,
        fs:  `cpe:2.3:a:pocoproject:poco_c\&#43;\&#43;_libraries:1.4.6:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drt-hf%2b:-`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drt-ibff:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)md4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drt-ibqf:-`,
        fs:  `cpe:2.3:o:cisco:catos:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drw-3ln4f%2b:-`,
        fs:  `cpe:2.3:a:ibm:visualage_for_java:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drw-3tf%2b:-`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drw-7tpf%2b:-`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drw-itpf%2b:-`,
        fs:  `cpe:2.3:a:miniclip:istunt_2:1.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9drx%2b-f:-`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller:7.4\(110.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9qr7-tf:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9qr7-tf%2b:-`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9qr7-tf-jbod:-`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9qri-f:-`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9qri-f%2b:-`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9sbaa-f:-`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9sca-f:-`,
        fs:  `cpe:2.3:a:netapp:snapdrive:6.3.0.4601:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9scd-f:-`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9sce-f:-`,
        fs:  `cpe:2.3:a:hp:business_availability_center:9.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9scff-f:-`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a5\(1.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9sci-ln4f:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xs1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9scl%2b-f:-`,
        fs:  `cpe:2.3:a:apache:apr-util:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9scl-f:-`,
        fs:  `cpe:2.3:o:d-link:dsp-w215_firmware:1.01:b06:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9scm-f:-`,
        fs:  `cpe:2.3:a:latexeditor:led:beta_0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9scm-iif:-`,
        fs:  `cpe:2.3:a:nancy_wichmann:taxonomy_list:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9spu-f:-`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9srd-f:-`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9sre-3f:-`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9sre-f:-`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9srg-f:-`,
        fs:  `cpe:2.3:a:watchguard:xcs:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9sri-3f:-`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9sri-f:-`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9srl-f:-`,
        fs:  `cpe:2.3:a:adobe:connect:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:supermicro:x9srw-f:-`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:superwebmailer:superwebmailer:5.60.0.01190`,
        fs:  `cpe:2.3:a:hp:panostandalone:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supmua:sup:0.13.0`,
        fs:  `cpe:2.3:a:quest:toad_for_oracle:10.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supmua:sup:0.13.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supmua:sup:0.13.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supmua:sup:0.13.2.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supmua:sup:0.14.0`,
        fs:  `cpe:2.3:a:sun:java_system_web_server:6.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supmua:sup:0.14.1`,
        fs:  `cpe:2.3:h:lucent:ascend_max_router:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supmua:sup:0.14.1.1`,
        fs:  `cpe:2.3:a:ca:unicenter_management_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supportezzy_ticket_system_project:supportezzy_ticket_system:1.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:businessobjects:business_explorer:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:supportpro:supportdesk:3.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surdoc:surdoc_-_100gb%2b_free_storage:1.3.4.0::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surfcontrol:soap_runtime:2.0:sp2`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surfcontrol:superscout:-`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surfcontrol:superscout_email_filter:-`,
        fs:  `cpe:2.3:h:hp:0235a31v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surfcontrol:superscout_email_filter:3.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surfcontrol:superscout_email_filter:4.0`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surfcontrol:superscout_web_filter:-`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.0.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:surfcontrol:web_filter:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suriname_radio_project:suriname_radio:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:survey.com:survey.com_mobile:3.2.16::~~~android~~`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surveytracker:surveytracker:4.0.0`,
        fs:  `cpe:2.3:a:ibm:access_manager_for_microsoft_.net:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surveytracker:surveytracker:5.5::~~desktop~~~`,
        fs:  `cpe:2.3:h:cisco:rv215w_wireless-n_vpn_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:surveytracker:surveytracker:5.6::~~desktop~~~`,
        fs:  `cpe:2.3:a:novell:iprint:5.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susanglathar:suzanne_glathar:1.399::~~~android~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:kiwi:4.85`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:kiwi:4.85.1`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_historian:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:kiwi:4.98.04`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:kiwi:4.98.05`,
        fs:  `cpe:2.3:a:slickedit:slickedit:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:kiwi:4.98.07`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:kiwi:4.98.08`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux:-`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise:12.0`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:linux_enterprise_debuginfo:11:sp2`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:linux_enterprise_debuginfo:11:sp3`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:linux_enterprise_debuginfo:11:sp4`,
        fs:  `cpe:2.3:a:oracle:jai:1.1.3:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_desktop:-`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:3.5.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_desktop:10:sp4:~~lts~~~`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_desktop:11:sp3`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_desktop:11:sp4`,
        fs:  `cpe:2.3:o:fortinet:fortianalyzer_firmware:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_desktop:12`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:8`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2006:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:9`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.18:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:10:sp4:~~ltss~~~`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:11:sp2:~~ltss~~~`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:11:sp3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:11:sp3:~~~vmware~~`,
        fs:  `cpe:2.3:h:huawei:s2350ei:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:11:sp3:vmware`,
        fs:  `cpe:2.3:h:fortinet:fortigate-800c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:11:sp4`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:11.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_server:12`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:linux_enterprise_server_8_on_ibm_zseries_s390:-`,
        fs:  `cpe:2.3:a:debian:mime-support:3.52-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_software_development_kit:11:sp3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.591:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_software_development_kit:11:sp4`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.128:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_software_development_kit:12`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:linux_enterprise_workstation_extension:12`,
        fs:  `cpe:2.3:a:luke_herrington:stickynote:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:linux_firewall_on_cd_admin_host:-`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:manager:1.7`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:office_server:-`,
        fs:  `cpe:2.3:a:plone:plone:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:opensuse:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.4`,
        fs:  `cpe:2.3:a:merethis:centreon:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p217:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.7`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.8`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.9`,
        fs:  `cpe:2.3:a:samba:samba:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.95`,
        fs:  `cpe:2.3:a:bluechip:bc_post2facebook:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.96`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.3.1:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.97`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.98`,
        fs:  `cpe:2.3:a:pervasive:data_integrator_connectors:9.0.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.99`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.2\(19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.100`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.101`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.102`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.103`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma464xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.104`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.5\(1.98991.13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.105`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.106`,
        fs:  `cpe:2.3:a:symantec:web_security:3.01.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.107`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_os_deployment:7.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.108`,
        fs:  `cpe:2.3:a:usr:digital_line_detect:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.109`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.110`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp7:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.111`,
        fs:  `cpe:2.3:a:vdgsecurity:vdg_sense:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.112`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.0i:p11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.113`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.114`,
        fs:  `cpe:2.3:a:isc:inn:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.115`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.116`,
        fs:  `cpe:2.3:a:cognos:planning_client_framework:8.4.6035.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.117`,
        fs:  `cpe:2.3:a:gnu:xemacs:21.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.119`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.120`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.121`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.121.1`,
        fs:  `cpe:2.3:a:adobe:coldfusion:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.122`,
        fs:  `cpe:2.3:a:gnome:glib:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.123`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.124`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.125`,
        fs:  `cpe:2.3:a:altn:mdaemon:9.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.126`,
        fs:  `cpe:2.3:a:cisco:ios:15.2\(2\)eb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.127`,
        fs:  `cpe:2.3:o:rockwellautomation:guardlogix:20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.128`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p27:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.129`,
        fs:  `cpe:2.3:a:gnome:evolution:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.130`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.74:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.131`,
        fs:  `cpe:2.3:a:wernerd:zrtpcpp:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.132`,
        fs:  `cpe:2.3:a:cisco:finesse:10.5\(1\)_es4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.133`,
        fs:  `cpe:2.3:a:keepass:keepass:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.134`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.135`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.135.1`,
        fs:  `cpe:2.3:a:tom_braider:count_per_day:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.136`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.137`,
        fs:  `cpe:2.3:a:altiris:software_delivery_solution_for_unix_and_linux_documentation:6.1.1028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.138`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:7.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.139`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.140`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.141`,
        fs:  `cpe:2.3:h:hp:j8692a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.142`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.143`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:opensuse_osc:0.144`,
        fs:  `cpe:2.3:h:ibm:system_storage_ds3200:1726:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:studio_extension_for_system_z:1.2`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.0.6:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:studio_extension_for_system_z:1.2.1`,
        fs:  `cpe:2.3:a:david_noguera_gutierrez:dalogin:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:studio_extension_for_system_z:1.3`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:studio_onsite:1.2`,
        fs:  `cpe:2.3:a:acme:micro_httpd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:studio_onsite:1.2.1`,
        fs:  `cpe:2.3:a:zencast:zencast:1.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:studio_onsite:1.3`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_cvsup:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_email_server:-`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_iptables:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:-`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:1.0`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:4.2`,
        fs:  `cpe:2.3:a:perl:perl:5.14.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:4.3`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:4.4`,
        fs:  `cpe:2.3:a:cisco:vpn_client:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:4.4.1`,
        fs:  `cpe:2.3:a:fogproject:fog:0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:5.0`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:5.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.4:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:5.2`,
        fs:  `cpe:2.3:a:apache:httpclient:4.1:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:5.3`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r008c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:6.0`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.03.018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:6.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:6.1:alpha`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:6.2`,
        fs:  `cpe:2.3:a:apache:spamassassin:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:6.3`,
        fs:  `cpe:2.3:a:microsoft:access:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:6.3:alpha`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:6.4`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.61.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:6.4:alpha`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2005-07-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:7.0`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.7255:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:7.0:alpha`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-11-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:7.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:7.1:alpha`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:7.2`,
        fs:  `cpe:2.3:h:d-link:dsl-2641r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:7.3`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:8.0`,
        fs:  `cpe:2.3:a:emc:documentum_d2:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:8.0:alpha`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:8.1`,
        fs:  `cpe:2.3:o:yahama:rt140e:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:8.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:9.0`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15:exp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:9.1`,
        fs:  `cpe:2.3:a:thegr:dl:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:9.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:9.3`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:10.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux:10.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.12.334:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_admin-cd_for_firewall:-`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_connectivity_server:-`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0079:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_database_server:-`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:11`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:11:sp1`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.15:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:11:sp2`,
        fs:  `cpe:2.3:a:jenkins:git:3.0.0:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:11:sp3`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:11:sp4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2svd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:11.0:sp3`,
        fs:  `cpe:2.3:a:solarwinds:scp_server:1.0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:12`,
        fs:  `cpe:2.3:a:pantech:uml290:1.5.33.429:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:12:sp1`,
        fs:  `cpe:2.3:h:yokogawa:daqopc_for_darwin:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:12:sp2`,
        fs:  `cpe:2.3:a:apple:itunes:5.0.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_desktop:12:sp3`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_service_bus:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:11`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:11:sp1`,
        fs:  `cpe:2.3:a:altiris:energy_saver_toolkit_documentation:6.0.1006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:11:sp2`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:11:sp3`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:11:sp4`,
        fs:  `cpe:2.3:a:mozilla:firefox:44.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:11.0:sp3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:11.0:sp3:~~~vmware~~`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:12`,
        fs:  `cpe:2.3:a:redhat:libreport:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:12:sp1`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:12:sp2`,
        fs:  `cpe:2.3:a:ibm:rational_appscan:8.5.0.1:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_linux_enterprise_server:12:sp3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:6.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_enterprise_software_development_kit:11.0:sp2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1667.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_enterprise_software_development_kit:11.0:sp3`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)ec:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_firewall:-`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.4.189822.1355:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_firewall_cd:-`,
        fs:  `cpe:2.3:a:apache:log4j:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_firewall_live-cd:-`,
        fs:  `cpe:2.3:h:hp:laserjet_4345_mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_imap_server:-`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_office_server:-`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_openexchange_server:-`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller:1.0\(1n\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_school_server:-`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.1.2.232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_linux_standard_server:-`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_office_server:-`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_open_enterprise_server:-`,
        fs:  `cpe:2.3:a:john_albin:zen:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:suse_sled_beagle:-`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:suse_united_linux:-`,
        fs:  `cpe:2.3:a:apple:cups:1.1.20:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:webyast:1.2`,
        fs:  `cpe:2.3:h:lexmark:cx820de:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:suse:webyast:1.3`,
        fs:  `cpe:2.3:a:exim:exim:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:yast2:-`,
        fs:  `cpe:2.3:a:ca:erwin_data_modeler:7.1.1075:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:yast2-backup:2.14.2`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:suse:yast2-backup:2.16.6`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.01`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.36:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.02`,
        fs:  `cpe:2.3:a:apple:iphoto:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.03`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.04`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.169:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.05`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:3.5.705:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.06`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.07`,
        fs:  `cpe:2.3:a:efstechnology:autoform_pdm_archive:6.920:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.08`,
        fs:  `cpe:2.3:a:citrix:xenapp_server_configuration_tool:1.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.09`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.10`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.11`,
        fs:  `cpe:2.3:a:samba:samba:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.12`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.13`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.14`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.15`,
        fs:  `cpe:2.3:a:blackberry:enterprise_server:5.0.4:mr6:*:*:*:exchange_server:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.20`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1055.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.21`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.5.3:devel:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.22`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.23`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.165:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.24`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.25`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.30`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.31`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.32`,
        fs:  `cpe:2.3:a:cisco:content_security_management_appliance:9.1.0-31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.33`,
        fs:  `cpe:2.3:a:hp:webinspect:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.34`,
        fs:  `cpe:2.3:a:phpbb:phpbb:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.35`,
        fs:  `cpe:2.3:a:drupal:drupal:7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.36`,
        fs:  `cpe:2.3:a:real:realplayer:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.37`,
        fs:  `cpe:2.3:h:crossbeamsystems:x45:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.38`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.39`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.40`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.41`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.42`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:sp3:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.50`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.51`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1306.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.52`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.60`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.61`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.8.2.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.70`,
        fs:  `cpe:2.3:a:amcharts:flash:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.71`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.72`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.73`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:2013.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.74`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.7.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.75`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.76`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.77`,
        fs:  `cpe:2.3:a:david_king:vino:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.78`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.79`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.80`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.81`,
        fs:  `cpe:2.3:a:nvidia:physx_system_software:9.9.814:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.82`,
        fs:  `cpe:2.3:a:mcafee:agent:4.0.0.1345:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.83`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:8.5.6-113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.84`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:8.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.85`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1018.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.86`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.87`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.88`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p4_rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.89`,
        fs:  `cpe:2.3:a:cdotech:edcl_common_components:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.89a`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.90`,
        fs:  `cpe:2.3:a:gnu:coreutils:5.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.91`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.92`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:susumu_terao:terapad:0.93`,
        fs:  `cpe:2.3:a:mythicsoft:agent_ransack:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:6.x-1.0`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:6.x-1.1`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:6.x-1.2`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:6.x-1.3`,
        fs:  `cpe:2.3:a:icinga:icinga:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:6.x-1.4`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:6.x-1.5`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:7.x-1.0`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.10-186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svendecabooter:webform_validation:7.x-1.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd351a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:svnlabs:html5_mp3_player_with_playlist_free:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.2`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.3`,
        fs:  `cpe:2.3:a:microsoft:sharepoint_server:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.5`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1037:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.6`,
        fs:  `cpe:2.3:a:oracle:sysfw:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.8`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1285.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.9`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.10`,
        fs:  `cpe:2.3:a:hp:destinations:53.0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.11`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.12`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.13`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.14`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.1:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.15`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.16`,
        fs:  `cpe:2.3:a:pkware:pkzip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.17`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.18`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.19`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.20`,
        fs:  `cpe:2.3:a:apache:struts:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.21`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.22`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.23`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.24`,
        fs:  `cpe:2.3:a:progress:webspeed:3.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.25`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.26`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.27`,
        fs:  `cpe:2.3:a:ubnt:unifi:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.29`,
        fs:  `cpe:2.3:a:redhat:network_satellite:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.30`,
        fs:  `cpe:2.3:a:samba:samba:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.31`,
        fs:  `cpe:2.3:a:icinga:icinga:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.32`,
        fs:  `cpe:2.3:o:linux:linux_kernel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:1.0.33`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:2.0.0`,
        fs:  `cpe:2.3:a:apple:itunes:12.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:2.0.0:rc0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:2.0.0:rc1`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swagger:swagger-parser:2.0.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swamiji:swamiji.tv:2::~~~android~~`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.6:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:swann:dvr4-securanet:-`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:swann:srnvw-470lcd:-`,
        fs:  `cpe:2.3:a:koha:koha:3.14.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:swann:srnvw-470lcd_firmware:0114`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:swann:swnvw-470cam:-`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:swann:swnvw-470cam_firmware:1022`,
        fs:  `cpe:2.3:o:juniper:junos:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:sweex:lb000021:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:sweex:lb000021_router_firmware:3.15`,
        fs:  `cpe:2.3:a:cisco:agent_desktop:80.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.50`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.51`,
        fs:  `cpe:2.3:o:brocade:fabric_os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.52`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.53`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.0-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.54`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.55`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.56`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.57`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.58`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.59`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.61`,
        fs:  `cpe:2.3:o:cisco:vpn_3020_concentrator:4.7\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.62`,
        fs:  `cpe:2.3:a:microsoft:biztalk_server:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.63`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.6.64`,
        fs:  `cpe:2.3:a:emc:it_operations_intelligence:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.8.0`,
        fs:  `cpe:2.3:a:isc:bind:9.8.5:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.8.1`,
        fs:  `cpe:2.3:a:samba:samba:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.8.2`,
        fs:  `cpe:2.3:a:apple:cups:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.8.3`,
        fs:  `cpe:2.3:a:whydowork_adsense_project:whydowork_adsense:1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.10.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.10.1`,
        fs:  `cpe:2.3:a:red-gate:sql_refactor:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.10.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.10.3`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.10.4`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:5.10.5`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.0.0`,
        fs:  `cpe:2.3:a:apple:mac_os_runtime_for_java:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.0.1`,
        fs:  `cpe:2.3:a:freelance-it-consultant:eu_cookie_compliance:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.0.2`,
        fs:  `cpe:2.3:a:yahoo:yui:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.2.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je106a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.2.1`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.1.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.2.2`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.2.3`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.2.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.6.0_20030409:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.3.0`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.3.1`,
        fs:  `cpe:2.3:a:sun:netbeans_developer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.3.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.3.3`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.3.4`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.3.5`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swi-prolog:swi-prolog:6.3.6`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swiftkey:swiftkey_keyboard_%2b_emoji:5.0.2.4::~~~android~~`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swiftkey:swiftkey_sdk:-`,
        fs:  `cpe:2.3:h:huawei:s7703:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swim_team_project:swim_team:1.44.10777::~~~wordpress~~`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swipe_checkout_for_eshop_project:swipe_checkout_for_eshop:3.7.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:swishzone:swish_max3:3.0.2009.11.30`,
        fs:  `cpe:2.3:a:x:libxfixes:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybari:antigen:-`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2-p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server:-`,
        fs:  `cpe:2.3:a:mjsware:m-player:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server:12.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server:12.5`,
        fs:  `cpe:2.3:a:openbsd:openssh:5.5:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_anywhere:-`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.00.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_anywhere:6.0.3.2747`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ze:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_anywhere:9.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.4_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:-`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2006-06-04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:4.3`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:11.03.3`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:11.5`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.6:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:11.5.1`,
        fs:  `cpe:2.3:a:apache:camel:2.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:11.9.2`,
        fs:  `cpe:2.3:a:pxz_project:pxz:4.999.99:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:12.0`,
        fs:  `cpe:2.3:o:hp:hp-ux:8.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:12.0.1`,
        fs:  `cpe:2.3:a:websense:websense:6.3.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:12.5`,
        fs:  `cpe:2.3:a:otrs:faq:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:12.5.2`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.0:rc1:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:12.5.3`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:15.0.3`,
        fs:  `cpe:2.3:a:analogx:proxy:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:15.5`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:adaptive_server_enterprise:15.7`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.981:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:advantage_database_server:-`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:central:-`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:central:4.3.0.2314`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:-`,
        fs:  `cpe:2.3:a:gnu:readline:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:4.0`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:4.2.5`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.7.1r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:5.0`,
        fs:  `cpe:2.3:a:sun:java_communications_services_delegated_administrator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:5.0.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:5.1`,
        fs:  `cpe:2.3:a:splunk:splunk:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:5.2`,
        fs:  `cpe:2.3:o:d-link:dsr-150_firmware:1.05b50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:5.2.1`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:5.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:5.5`,
        fs:  `cpe:2.3:a:ibm:b2b_advanced_communications:1.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:6.0`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:6.0.1`,
        fs:  `cpe:2.3:a:vips:vips:7.21.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:6.0.2`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:6.1`,
        fs:  `cpe:2.3:a:connections_project:connections:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:6.2`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:6.3`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.03b43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:6.3.1`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver:6.3.1::developer`,
        fs:  `cpe:2.3:a:openafs:openafs:1.0.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:easerver_manager:-`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:financial_fusion_consumer_banking_solution:-`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.10:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:m-business_anywhere:6.7`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerbuilder_client_runtime:9.0.0.0`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerbuilder_virtual_machine:10.2.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_device_manager:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerbuilder_virtual_machine:10.2.1.9004`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerbuilder_virtual_machine:11.5`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerbuilder_virtual_machine:11.5.0.2506`,
        fs:  `cpe:2.3:a:oracle:sun_products_suite:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerbuilder_virtual_machine:11.5.0.3127`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerbuilder_virtual_machine:11.5.1.4922`,
        fs:  `cpe:2.3:a:e-mail_extractor:e-mail_extractor:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:7.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:7.5`,
        fs:  `cpe:2.3:a:ubercart:ubercart:7.x-3.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:8.0`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:368.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:9.0`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.01.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:9.5`,
        fs:  `cpe:2.3:a:apple:apple_mobile_device_support:2.1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:10.0`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.6.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:11.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:11.1`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:11.1.1`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:12.0`,
        fs:  `cpe:2.3:a:gnu:libtool:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:12.1`,
        fs:  `cpe:2.3:a:google:v8:3.25.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:12.5`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner:15.0`,
        fs:  `cpe:2.3:a:skype:skype:0.95.0.40:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner_repository_proxy_:12.5`,
        fs:  `cpe:2.3:a:fast_permissions_administration_project:fast_permission_administration:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdesigner_repository_proxy_:15.0`,
        fs:  `cpe:2.3:a:apache:subversion:0.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:powerdynamo:-`,
        fs:  `cpe:2.3:a:brocade:network_advisor:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:pylon_anywhere:-`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:pylon_anywhere:5.5.4`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:pylon_anywhere:6.2.1`,
        fs:  `cpe:2.3:a:netiq:security_manager:6.0.0.194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:pylon_anywhere:6.3.2`,
        fs:  `cpe:2.3:h:netgear:rp114:3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:pylon_anywhere:6.4.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.12.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:pylon_anywhere:6.4.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:pylon_anywhere:6.4.9`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:replication_server:-`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:replication_server:12.6`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:software_developer%27s_kit:15.0_ga`,
        fs:  `cpe:2.3:a:vmware:view:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:sql_anywhere:10.0.1.3619`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:sql_anywhere:11.1.2506`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:sql_anywhere_documentation:10.0.1.3415`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:sql_anywhere_documentation:11.0.0`,
        fs:  `cpe:2.3:a:blaine_lang:maestro:7.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:sql_anywhere_studio:9.0.2.2451`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sybase:sql_anywhere_studio:9.0.2.3702`,
        fs:  `cpe:2.3:a:invensys:intouch\/wonderware_application_server:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sycamore_networks:modeler:4.3.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sylpheo:sylphone:5.3.8::~~~android~~`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:advanced_threat_protection:2.0.3`,
        fs:  `cpe:2.3:a:symphony-cms:symphony_cms:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:altiris_deployment_solution:-`,
        fs:  `cpe:2.3:a:apple:xsan:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:altiris_it_management_suite:7.6`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ams:10.0.0.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.9.900.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:anti-virus_engine:20151.1.0.32`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus:10.1.6000.6::~~~~ia64~`,
        fs:  `cpe:2.3:a:openttd:openttd:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus:10.1.9100.9`,
        fs:  `cpe:2.3:a:pootlepress:pootle_button:1.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:-`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.9.620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.0`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.1`,
        fs:  `cpe:2.3:a:python:python:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.1.8`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.1.9`,
        fs:  `cpe:2.3:o:hp:hp-ux:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)t9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.3.3`,
        fs:  `cpe:2.3:a:siemens:teamcenter\&#39;s_application_sharing:8.1.9280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.3.7.27`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.3.8.29`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:4.3.12`,
        fs:  `cpe:2.3:a:huawei:espace_desktop:v100r001c02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p331:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:5.0.0.24`,
        fs:  `cpe:2.3:h:xerox:workcentre:265:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine:5.0.1`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine_clearswift:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:antivirus_scan_engine_for_network_attached_storage:-`,
        fs:  `cpe:2.3:a:weibo_project:weibo:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:application_service_dashboard:2.0.0`,
        fs:  `cpe:2.3:a:php:php:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:automated_support_assistant:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backup_exec:2010_r3:sp1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.4\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backup_exec:2010_r3:sp2`,
        fs:  `cpe:2.3:a:libraw:libraw:0.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backup_exec:2012:sp1`,
        fs:  `cpe:2.3:a:digium:asterisk:11.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backupexec_system_recovery:-`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backupexec_system_recovery:7.0.0.20351`,
        fs:  `cpe:2.3:h:avaya:converged_communications_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backupexec_system_recovery:7.0.1.21475`,
        fs:  `cpe:2.3:a:withhive:puzzle_family:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backupexec_system_recovery:8.0.1.24976`,
        fs:  `cpe:2.3:a:adobe:livecycle_es:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backupexec_system_recovery:2010`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:backupexec_system_recovery:2011`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:brightmail_antispam:-`,
        fs:  `cpe:2.3:a:gnu:inetutils:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:brightmail_antispam:4.0`,
        fs:  `cpe:2.3:a:samba:samba:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:brightmail_antispam:5.5`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:brightmail_antispam:6.0`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_software_development_kit:11:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:brightmail_antispam:6.0.1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:brightmail_antispam:6.0.2`,
        fs:  `cpe:2.3:a:symantec:mail_security_for_domino:8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:brightmail_antispam:6.0.3`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:brightmail_antispam:6.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:12.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_firewall:-`,
        fs:  `cpe:2.3:a:rocomotion:p_diary_r:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_firewall:5.01`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:10.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_firewall:5.1.1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:-`,
        fs:  `cpe:2.3:a:cisco:finesse:9.1\(1\)_es5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.3.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.425a:mr1`,
        fs:  `cpe:2.3:a:samba:samba:4.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.425b:mr1`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.429c:mr2`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.434:mr3`,
        fs:  `cpe:2.3:a:vanillaforums:vanilla_forums:2.0.18:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.437`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_92:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.446:mr4`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.457:mr5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.460:mr6`,
        fs:  `cpe:2.3:a:google:toolbar_for_internet_explorer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.464:mr7`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.471:mr8`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0.1_build_8.01.501:mr9`,
        fs:  `cpe:2.3:a:rsa:bsafe_crypto-c:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.0_build_8.01.9374`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:1.1.1`,
        fs:  `cpe:2.3:a:breezy:breezy:1.2.10:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.1`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.0.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.1_build_9.0.1.1000:mr1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.91.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.2_build_9.0.2.1000:mr2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.3`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:3.00.0615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.3_build_9.0.3.1000:mr3`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.4`,
        fs:  `cpe:2.3:o:opensuse:opensuse:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.5`,
        fs:  `cpe:2.3:a:gilles_lamiral:imapsync:1.500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.5_build_1100_mp1:mr5`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.6`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:2.0.6:mr6`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.344:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0`,
        fs:  `cpe:2.3:h:lexmark:e462:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.0.359`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.1.1000`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-48p-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.1.1001`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:7.9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.1.1007`,
        fs:  `cpe:2.3:a:isc:inn:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.1.1008`,
        fs:  `cpe:2.3:a:progea:movicon:11.4.1150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.2.2000`,
        fs:  `cpe:2.3:a:mono:mono:1.1.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.2.2001`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.2.2002`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.2.2010`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.8:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.2.2011`,
        fs:  `cpe:2.3:a:google:chrome:6.0.496.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.2.2020`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.0.2.2021`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:4.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.1.0.396`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.1.0.401`,
        fs:  `cpe:2.3:h:apple:imac:mb417xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.1.394`,
        fs:  `cpe:2.3:a:marc_deslauriers:software-properties:0.82.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.1.396`,
        fs:  `cpe:2.3:a:hp:storageworks_windows_host_agent_files:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:client_security:3.1.400`,
        fs:  `cpe:2.3:a:codologic:com_freichat:9.4:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:clientless_vpn_gateway_4400:-`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:critical_system_protection:5.2.8`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:critical_system_protection:5.2.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:csapi:10.0.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.307:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_center_security_server:6.0`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_1000_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_center_security_server:6.0:mp1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)by:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_center_security_server:6.0.0::~~advanced~~~`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_center_security_server:6.5`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1300.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_center_security_server:6.5:mp1`,
        fs:  `cpe:2.3:a:digia:qt:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_center_security_server:6.6`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_center_security_server:6.6:mp1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_insight:3.0`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_insight:3.0.1`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_insight:4.0`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:6.2\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_insight:4.5`,
        fs:  `cpe:2.3:a:hitachi:compute_systems_manager:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:data_loss_prevention:12.5.1`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:deployment_solution:6.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:deployment_solution_wise_packager:6.10.443`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:discovery:-`,
        fs:  `cpe:2.3:h:h3c:s5820_secblade_vpn_firewall_module:0231a94j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_desktop:10.3.0`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb986xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_desktop:10.3.0::~~professional~~~`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_desktop:10.3.1`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_desktop:10.3.1::~~professional~~~`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_desktop:10.3.2:-:~~professional~~~`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ecc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_desktop:10.3.2:mp1:~~professional~~~`,
        fs:  `cpe:2.3:h:lexmark:x422:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_management_server:3.3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_management_server:3.3.0:mp1`,
        fs:  `cpe:2.3:a:hp:network_node_manager_i:8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_management_server:3.3.0:mp2`,
        fs:  `cpe:2.3:a:gnu:glibc:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:encryption_management_server:3.3.2:mp11`,
        fs:  `cpe:2.3:a:phpace:samswhois:1.4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_encryption:11.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.2:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_encryption:11.0.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_encryption:11.0.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.25:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11`,
        fs:  `cpe:2.3:a:marked_project:marked:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0:ru5`,
        fs:  `cpe:2.3:o:cisco:vpn_3080_concentrator:4.7\(rel\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0:ru6`,
        fs:  `cpe:2.3:a:ca:2e_web_option:r8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0:ru6a`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0:ru6mp1`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.a3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0:ru6mp2`,
        fs:  `cpe:2.3:a:vmware:tools:8.0.3.17828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.1:mp1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.1:mp2`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.2`,
        fs:  `cpe:2.3:a:hp:fortify_software_security_center:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.2:mp1`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.2:mp2`,
        fs:  `cpe:2.3:a:sun:java_auto_updater:2.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.4`,
        fs:  `cpe:2.3:a:marek_gutkowski:mod_chroot:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.4:mp1a`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.4:mp2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.7`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.7.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.7.2`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:2.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.7.3`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.3001`,
        fs:  `cpe:2.3:a:serv-u:serv-u:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.6000`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.0:1033:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.6100`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.6200`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.6200.754`,
        fs:  `cpe:2.3:o:suse:suse_linux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.6300`,
        fs:  `cpe:2.3:h:moxa:miineport_e1_7080:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.7000`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.618:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:11.0.7100`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.0:-:small_business`,
        fs:  `cpe:2.3:a:php:blog_cms:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1:-:small_business`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.1`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.1.1`,
        fs:  `cpe:2.3:a:quest:intrust_predefined_objects_for_microsoft_iis:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.2`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.2.1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.3`,
        fs:  `cpe:2.3:a:vmware:player:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.4`,
        fs:  `cpe:2.3:a:socialcms:socialcms:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.6:mp4`,
        fs:  `cpe:2.3:a:google:chrome:47.0.2526.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.6:mp4:~~~linux~~`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.6:mp4:~~~mac~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.6:mp4:~~~mac_os_x~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(9\)ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.671`,
        fs:  `cpe:2.3:a:bentley:bentley_view:8.11.7.440:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection:12.1.1000`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_center:12.0.0:-:small_business`,
        fs:  `cpe:2.3:a:opensymphony:xwork:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_center:12.0.1:-:small_business`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_center:12.1.3:-:small_business`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ez:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_manager:11.0`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_manager:12.1:ru6-mp4`,
        fs:  `cpe:2.3:a:oleg_kovalchuk:cctags:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_manager:12.1.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_manager:12.1.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_manager:12.1.2`,
        fs:  `cpe:2.3:a:cisco:unified_presence_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_manager:12.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:13.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:endpoint_protection_manager:12.1.6:mp4`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_firewall:-`,
        fs:  `cpe:2.3:a:emc:networker:8.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_firewall:6.5.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.30.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_firewall:7.0`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_firewall:7.0.4`,
        fs:  `cpe:2.3:a:vmware:horizon_view:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_firewall:8.0`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:9.0.0-461:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:-`,
        fs:  `cpe:2.3:a:google:chrome:3.0.195.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:6.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.16.2bs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:6.5`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.60.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:6.5.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:6.5.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.596:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:6.5.2`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:6.5.3`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta38:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:9.0`,
        fs:  `cpe:2.3:a:opsview:opsview:3.1:-:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:9.0.1`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.12a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:10.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:enterprise_security_manager:11.0`,
        fs:  `cpe:2.3:a:skype:skype:5.3.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:epo_plugin:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:firewall_vpn_appliance_100:-`,
        fs:  `cpe:2.3:a:lucent:vitalanalysis:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:firewall_vpn_appliance_200:-`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:firewall_vpn_appliance_200r:-`,
        fs:  `cpe:2.3:a:oracle:secure_enterprise_search:10.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:gateway_security:-`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_300:-`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_320:-`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_360:-`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_360r:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p59:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_400:-`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_460:-`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_460r:-`,
        fs:  `cpe:2.3:a:teradata:shared_icu_libraries:12.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_5100:-`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_5200:-`,
        fs:  `cpe:2.3:h:cisco:887v_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_5300:-`,
        fs:  `cpe:2.3:a:samba:samba:4.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_5310:-`,
        fs:  `cpe:2.3:a:e-xoopport:samsara:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:gateway_security_5400:-`,
        fs:  `cpe:2.3:h:tropos:6320_mesh_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_console_and_standard_tools:110.2.1573`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_console_and_standard_tools:115.0.2113`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_console_and_standard_tools:115.1.2266`,
        fs:  `cpe:2.3:a:matrikonopc:matrikonopc_security_gateway:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_console_client:110.2.1573`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8\)ea2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_console_client:115.0.2113`,
        fs:  `cpe:2.3:a:gnu:coreutils:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_console_client:115.0.2141`,
        fs:  `cpe:2.3:h:cisco:catalyst_2948:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_console_client:115.1.2266`,
        fs:  `cpe:2.3:o:ibm:aix:5.3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_solutions_suite:-`,
        fs:  `cpe:2.3:a:sendmail:sendmail:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_solutions_suite:1.0`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ghost_solutions_suite:2.0`,
        fs:  `cpe:2.3:a:stephen_adkins:app\:\:context:0.962:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:host_ids:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:i-gear:-`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:4.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:i-gear:3.5`,
        fs:  `cpe:2.3:a:cisco:meeting_server:1.7_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:i-gear:3.5.7`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:i3_listener_agent:8.7`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:6.0`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:6.5`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20000815:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:7.0`,
        fs:  `cpe:2.3:o:yahama:rtx1000:7.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:7.5`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.3`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.0`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.1`,
        fs:  `cpe:2.3:a:docker:docker:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.2`,
        fs:  `cpe:2.3:a:childrens:help_for_doc:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.5`,
        fs:  `cpe:2.3:a:ibm:os2_ftp_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.6`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.7`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.01.512:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.8`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_plugin_for_database_control:12.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.9`,
        fs:  `cpe:2.3:a:hp:icewall_sso_saml2_option:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.10`,
        fs:  `cpe:2.3:a:cisco:meetingplace_web_confrencing:5.3\(235\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.11`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/odbc:5.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.12`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:im_manager:8.4.15`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:installation_manager:7.1.75`,
        fs:  `cpe:2.3:a:vips:vips:7.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:intruder_alert:-`,
        fs:  `cpe:2.3:a:lostpassword:windows_key:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:intruder_alert:3.6`,
        fs:  `cpe:2.3:a:cybozu:office:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:intruder_alert_manager:-`,
        fs:  `cpe:2.3:a:boost:boost:1.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:intruder_alert_workstation:-`,
        fs:  `cpe:2.3:o:yamaha:rtx1500:8.03.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:java_liveupdate:2.1.7`,
        fs:  `cpe:2.3:a:x:libxv:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:java_liveupdate:3.0.27`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:license_inventory_agent:4.2.16.7`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livereg:2.0.6.1314`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livereg:2.1.5.1502`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livereg:2.3.0.1833`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livereg:2.4.2.2295`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livestate:-`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_p1102:ce657a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livestate_agent_for_windows:7.1`,
        fs:  `cpe:2.3:a:ibm:elastic_storage_server:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livestate_recovery:-`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livestate_recovery:3.0`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livestate_recovery:6.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(2i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livestate_recovery:6.01`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:livestate_recovery:6.02`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:-`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:1.0`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:1.4`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:1.5`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:1.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:1.7`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:1.8`,
        fs:  `cpe:2.3:a:smarttech:smart_classroom_suite_student:1.0.1059.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:1.9`,
        fs:  `cpe:2.3:a:oracle:e-business_suite_application_management_pack:121030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:1.80.19.0`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:2.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:2.5`,
        fs:  `cpe:2.3:a:monotone:monotone:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:2.6`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:2.7`,
        fs:  `cpe:2.3:a:apache:axis:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.0`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.0.0.134`,
        fs:  `cpe:2.3:a:gnome:glib:2.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.0.0.160`,
        fs:  `cpe:2.3:a:emc:documentum_taskspace:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.0.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.0.2`,
        fs:  `cpe:2.3:a:f5:linerate:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.0.3`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.1`,
        fs:  `cpe:2.3:a:apache:hive:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.1.0.90`,
        fs:  `cpe:2.3:a:openstack:compute:2012.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.1.0.99`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.2.0.26`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.2.0.41`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.2.0.59`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.2.0.67`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.2.0.68`,
        fs:  `cpe:2.3:a:sears:sears:6.2.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.2:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3.0.69`,
        fs:  `cpe:2.3:o:juniper:junose_e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3.0.71`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3.0.73`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3.0.78`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3.0.85`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3.0.92`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3.0.96`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administration_utility:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.3.0.99`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate:3.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administration_utility:-`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administration_utility:1.5.7`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.22:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:1.5.3.21`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.28:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:1.5.4`,
        fs:  `cpe:2.3:a:hummingbird:connectivity:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:1.5.7.19`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:2.1.0`,
        fs:  `cpe:2.3:h:cisco:epc3928:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:2.1.2`,
        fs:  `cpe:2.3:a:microsoft:windows_media_format_runtime:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:2.1.3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:2.2.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:2.2.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sre:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:2.2.2.9`,
        fs:  `cpe:2.3:a:intel:threading_building_blocks:2.2.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_administrator:2.3.0`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.38:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:liveupdate_lots_manager:-`,
        fs:  `cpe:2.3:a:docker:docker:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail-gear:-`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:beta:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail-gear:1.0`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:-`,
        fs:  `cpe:2.3:a:mscsoftware:msc_nastran:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.1.4`,
        fs:  `cpe:2.3:a:gnu:coreutils:5.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.5`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:2.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.5.4.743`,
        fs:  `cpe:2.3:a:offertaviaggi:venezia_map:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.5_build_719`,
        fs:  `cpe:2.3:a:hp:bufferchm:82.0.173.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.5_build_719::exchange`,
        fs:  `cpe:2.3:o:trustix:secure_linux:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.5_build_736`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.5_build_736::exchange`,
        fs:  `cpe:2.3:a:cisco:leap:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.5_build_741`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.5_build_741::exchange`,
        fs:  `cpe:2.3:o:cisco:catos:6.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.6`,
        fs:  `cpe:2.3:a:allroundautomations:pl\/sql_developer:11.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.6.1.107`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.6.3`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.6_build_97`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:4.6_build_97::exchange`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:5.0`,
        fs:  `cpe:2.3:a:oracle:database_server:11.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:5.0.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:5.0.0.24`,
        fs:  `cpe:2.3:a:php:php:5.4.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:5.0.0.47`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:5.0.0.204`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:5.0.1`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:25-10-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:5.1.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.2:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:5.1.2.28`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:6.0.0`,
        fs:  `cpe:2.3:a:apple:itunes:10.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security:7.5`,
        fs:  `cpe:2.3:a:hitachi:it_operations_analyzer:02-51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:mail_security_8820_appliance:-`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security_for_domino:8.0.9`,
        fs:  `cpe:2.3:h:netgear:fvs318:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security_for_domino:8.1.3`,
        fs:  `cpe:2.3:a:apache:solr:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security_for_microsoft_exchange:6.0`,
        fs:  `cpe:2.3:a:hp:jetadmin:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security_for_microsoft_exchange:6.5`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security_for_microsoft_exchange:6.5.8`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security_for_microsoft_exchange:7.0.4`,
        fs:  `cpe:2.3:h:cisco:ip_video_phone_e20:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security_for_microsoft_exchange:7.5.4`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:mail_security_for_smtp:5.0.1`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:management_platform:7.1`,
        fs:  `cpe:2.3:a:hp:openview_event_correlation_services:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:management_platform:7.1:sp1`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:message_gateway:10.6.1-3`,
        fs:  `cpe:2.3:a:ibm:rational_automation_framework:3.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:message_gateway_for_service_providers:10.5`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:message_gateway_for_service_providers:10.6`,
        fs:  `cpe:2.3:a:apache:libcloud:0.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:9.5`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.26.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:9.5.1`,
        fs:  `cpe:2.3:a:prosody:prosody:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:9.5.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:9.5.3`,
        fs:  `cpe:2.3:h:juniper:netscreen-5200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:9.5.4`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:10.0`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:10.0.1`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:10.0.2`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:10.0.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:10.5.0`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:10.5.1`,
        fs:  `cpe:2.3:a:nvidia:nview:135.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:messaging_gateway:10.5.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup:7.0`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.0.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup:7.1`,
        fs:  `cpe:2.3:a:debian:dpkg:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_client:7.0`,
        fs:  `cpe:2.3:a:schneider-electric:u.motion_builder:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_client:7.1`,
        fs:  `cpe:2.3:o:d-link:dir-600l_firmware:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_enterprise_server:5.1`,
        fs:  `cpe:2.3:o:asus:rt-ac68u_firmware:3.0.0.4.376.3715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_enterprise_server:6.0`,
        fs:  `cpe:2.3:a:jetbrains:intellij_idea:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_enterprise_server:6.5`,
        fs:  `cpe:2.3:a:gnu:finger_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_opscenter:7.6.0.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_opscenter:7.6.0.3`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_opscenter:7.6.0.4`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.4.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_opscenter:7.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_server:5.1`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.00.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_server:6.0`,
        fs:  `cpe:2.3:a:hp:ad_install:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:netbackup_server:6.5`,
        fs:  `cpe:2.3:a:cisco:finesse:9.1\(1\)_es4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:11.0.6000`,
        fs:  `cpe:2.3:a:ibm:netezza_performance_portal:2.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:11.0.6100`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phones_9900_series_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:11.0.6200`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:102sh:ii:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:11.0.6300`,
        fs:  `cpe:2.3:a:mailgod:letters_to_god_-_soc._network:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:11.0.7000`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:11.0.7100`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:12.1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:12.1.1`,
        fs:  `cpe:2.3:h:hp:jg412a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:network_access_control:12.1.1.1`,
        fs:  `cpe:2.3:a:techsmith:snagit:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:nexland_isb_soho_firewall_appliance:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2.16\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:nexland_pro100_firewall_appliance:-`,
        fs:  `cpe:2.3:o:cisco:rv130w_firmware:1.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:nexland_pro400_firewall_appliance:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:nexland_pro800_firewall_appliance:-`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:nexland_pro800turbo_firewall_appliance:-`,
        fs:  `cpe:2.3:a:businessobjects:lifecycle_manager:12.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:nexland_wavebase_firewall_appliance:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:ngc:22.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_360:-`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_java:0.2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antispam:-`,
        fs:  `cpe:2.3:a:adobe:download_assistant:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:-`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:1.0`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.9-178:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:2.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.b2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:2.1`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:2.5`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:5.0`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.0.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.0.1.501`,
        fs:  `cpe:2.3:h:hp:procurve_switch_6200yl:k.11.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.1`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.1.0.825a`,
        fs:  `cpe:2.3:a:yahoo:messenger:7.0.438:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.1.1`,
        fs:  `cpe:2.3:a:cups-pk-helper_project:cups-pk-helper:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.1.1.319`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.1.1.323`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.1.1.329`,
        fs:  `cpe:2.3:a:mistelix:mistelix:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.1.1.366`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.1.1.377`,
        fs:  `cpe:2.3:a:hp:hppwebregmm:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.01.434`,
        fs:  `cpe:2.3:a:cisco:network_assistant:5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.01.437`,
        fs:  `cpe:2.3:a:apache:rave:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.01.446`,
        fs:  `cpe:2.3:a:web2py:web2py:1.94.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.01.457`,
        fs:  `cpe:2.3:a:freemind:freemind:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.01.460`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.01.464`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:8.01.471`,
        fs:  `cpe:2.3:a:apache:shiro:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.6.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.0`,
        fs:  `cpe:2.3:a:rsbr:outlook_attachment_sniffer:4.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.0.338`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.1`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.1.1.1000`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.1.1000`,
        fs:  `cpe:2.3:o:redhat:linux:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.2.1000`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:7.6.1:05:*:*:*:solaris:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.3`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.3.1000`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.4:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.4`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.2:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.4:mr4_build_1000`,
        fs:  `cpe:2.3:a:aol:internet_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.4:mr4_build_1000:corporate_edition`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update3:as:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.5`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.5.1100`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:9.0.6.1000`,
        fs:  `cpe:2.3:h:linksys:wap54g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0`,
        fs:  `cpe:2.3:a:cipherdyne:fwknop:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.0`,
        fs:  `cpe:2.3:a:synology:video_station:1.6-0844:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.0.359`,
        fs:  `cpe:2.3:a:drupal:drupal:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.4.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.1.1000`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.1.1007`,
        fs:  `cpe:2.3:a:x.org:libxrender:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.1.1008`,
        fs:  `cpe:2.3:o:ibm:aix:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.2.2000`,
        fs:  `cpe:2.3:a:microsoft:jet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.2.2001`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.2.2002`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.2.2010`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.2.2011`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.2.2020`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.0.2.2021`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_antivirus:10.1`,
        fs:  `cpe:2.3:h:siemens:sinamics_g150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_bootable_removal_tool:2016.0`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.3:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_ghost:-`,
        fs:  `cpe:2.3:a:ibm:director_agent_pefix_pfn:5.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_internet_security:-`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.28:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_internet_security_2010:17.5.0.127`,
        fs:  `cpe:2.3:a:redhat:manageiq_enterprise_virtualization_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_partitionmagic:8.5.0`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:6.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_pc_checkup:1.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_pc_checkup:1.5`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_pc_checkup:2.5`,
        fs:  `cpe:2.3:a:fusebox:fusebox:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_personal_firewall:-`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_power_eraser:5.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_save_and_recovery:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security:13.0.1::~~~mac~~`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:12.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security:13.0.1::~~~mac_os_x~~`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:7.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security_scan:1.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security_scan:1.3`,
        fs:  `cpe:2.3:a:rackspace:openstack_windows_guest_agent:1.2.5.0:-:-:*:-:xen_server:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security_scan:1.4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security_scan:2.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.1415:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security_scan:2.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_security_with_backup:-`,
        fs:  `cpe:2.3:a:milesj:decoda:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_system_works:-`,
        fs:  `cpe:2.3:a:typo3:typo3:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:norton_utilities:-`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:on-demand_agent:-`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:on-demand_protection:-`,
        fs:  `cpe:2.3:a:gnu:bash:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:on_command_ccm:-`,
        fs:  `cpe:2.3:o:juniper:junos:12.2:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:on_command_discovery:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:7.1.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:on_icommand:-`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:opscenter_agent:7.0`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:opscenter_agent:7.0.1:release_update_1`,
        fs:  `cpe:2.3:a:f5:big-iq_cloud:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:8.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.01:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:8.0.1`,
        fs:  `cpe:2.3:a:yoshinori_tahara:mycaljp:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:8.0.2`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:9.0`,
        fs:  `cpe:2.3:a:apache:struts:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:9.0.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:9.2`,
        fs:  `cpe:2.3:a:adobe:coldfusion:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:10.0`,
        fs:  `cpe:2.3:a:ariel_barreiro:noderecommendation:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:10.5`,
        fs:  `cpe:2.3:a:microsoft:windows_script_host:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:11.0`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:11.0.0.730`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:11.0.1`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:11.0.1.764`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:11.5`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:11.5.1`,
        fs:  `cpe:2.3:o:novell:opensuse:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:12.0`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pcanywhere:12.1.0`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:-:-:~~~windows~~`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.0.0`,
        fs:  `cpe:2.3:a:acquia:mollom:6.x-2.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.0.0:-:~~~windows~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.0.1`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.0.1:-:~~~windows~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.0.2`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.0.2:-:~~~windows~~`,
        fs:  `cpe:2.3:a:oxwall:oxwall:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.0.3:-:~~~windows~~`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.1.0`,
        fs:  `cpe:2.3:a:apple:webkit:312.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.1.0:-:~~~windows~~`,
        fs:  `cpe:2.3:o:fedoraproject:fedora_core:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.1.1`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.1.1:-:~~~windows~~`,
        fs:  `cpe:2.3:a:isc:bind:9.2.4:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.1.2`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp13:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.1.2:-:~~~windows~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.2.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.2.0:-:~~~windows~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg236a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.2.1`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:006sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.2.1:-:~~~windows~~`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop:10.2.2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:1.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_desktop_for_windows:-`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_universal_server:3.2.0`,
        fs:  `cpe:2.3:a:oracle:cadview-3d:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_universal_server:3.2.1`,
        fs:  `cpe:2.3:a:fujitsu:scansnap_manager:v5.0l20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:pgp_universal_server:3.2.1:mp2`,
        fs:  `cpe:2.3:a:mysql:eventum:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:platform_and_solutions:7.1.75`,
        fs:  `cpe:2.3:a:naxsi_project:naxsi:0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:powerquest_deploycenter:-`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:powerquest_deploycenter:5.5`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:private_branch_exchange:1.3.23.7`,
        fs:  `cpe:2.3:a:xnview:xnview:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:private_branch_exchange:1.3.26.6`,
        fs:  `cpe:2.3:a:php:php:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:private_branch_exchange:1.3.28.7`,
        fs:  `cpe:2.3:h:nortel:switched_firewall_5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:private_branch_exchange:1.3.31.2`,
        fs:  `cpe:2.3:a:apache:subversion:m4\/m5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:product_authentication_service:4.3.32.6`,
        fs:  `cpe:2.3:o:yahama:rt102i:2.01.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:product_authentication_service:4.3.42.1`,
        fs:  `cpe:2.3:a:fbpromotions_project:fbpromotions:1.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:product_authentication_service_client:4.3.28.3`,
        fs:  `cpe:2.3:a:oracle:global_order_promising:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:product_authentication_service_client:4.3.28.4`,
        fs:  `cpe:2.3:a:netiq:access_manager:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:product_authentication_service_client:4.3.32.0`,
        fs:  `cpe:2.3:a:certblaster:certblaster_security\&#43;_2008:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:product_authentication_service_client:4.3.34.8`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:product_authentication_service_client:4.3.34.12`,
        fs:  `cpe:2.3:a:emc:eroom:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:product_authorization_service:4.3.20.2`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:protection_center:12.0::~~small_business~~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(22\)ea6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:protection_engine:7.0.5`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:protection_engine:7.5.4`,
        fs:  `cpe:2.3:h:hp:jd656a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:protection_engine:7.8.0`,
        fs:  `cpe:2.3:o:cisco:rv130w_firmware:1.0.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:protection_for_sharepoint_servers:6.03`,
        fs:  `cpe:2.3:a:openbsd:openssh:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:protection_for_sharepoint_servers:6.04`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:protection_for_sharepoint_servers:6.05`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.0.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:protection_for_sharepoint_servers:6.06`,
        fs:  `cpe:2.3:a:belasfrasesdeamor:belas_frases_de_amor:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:raptor_firewall:-`,
        fs:  `cpe:2.3:a:iii:sierra:1.2_3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:raptor_firewall:6.5`,
        fs:  `cpe:2.3:a:perl:perl:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:raptor_firewall:6.5.3`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:reporting_agents:1.0.224.0`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:reporting_agents:1.0.234.0`,
        fs:  `cpe:2.3:a:citrix:presentation_server_client:10.100.55836:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:reporting_agents:1.0.248.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:reporting_agents:1.0.258.0`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:reporting_server:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(1\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:reporting_server:1.0.197.0`,
        fs:  `cpe:2.3:a:openfabrics:enterprise_distribution:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:sav_filter_for_domino_nt:-`,
        fs:  `cpe:2.3:a:oracle:api_gateway:11.1.2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:scan_engine:-`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp0c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:scan_engine:5.2.8.58`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.2:rc2:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_check:-`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_check_virus_detection:-`,
        fs:  `cpe:2.3:a:symantec:ghost_console_client:115.1.2266:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:-`,
        fs:  `cpe:2.3:a:adobe:output_module:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2`,
        fs:  `cpe:2.3:a:apache:struts:2.5:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.1`,
        fs:  `cpe:2.3:h:huawei:e200e-usg2100:v100r005c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.2`,
        fs:  `cpe:2.3:a:apple:webobjects:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.3`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.4`,
        fs:  `cpe:2.3:a:adobe:pdf_ifilter:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.5`,
        fs:  `cpe:2.3:a:ibm:rational_automation_framework:3.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.6`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.0\(2a\)sr2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.8`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.9`,
        fs:  `cpe:2.3:a:libsndfile_project:libsndfile:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.10`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.11`,
        fs:  `cpe:2.3:o:d-link:dap-2360_firmware:2.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.12`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.13`,
        fs:  `cpe:2.3:h:buffalotech:whr-hp-g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.14`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.15`,
        fs:  `cpe:2.3:a:gnu:emacs:20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.16`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.17`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.18`,
        fs:  `cpe:2.3:a:ibm:rational_test_workbench:8.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.19`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s\(.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.20`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.48.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.21`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.22`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.23`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.24`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.25`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.26`,
        fs:  `cpe:2.3:a:cisco:unified_ip_ivr:7.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.27`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:3000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.28`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.0.2.29`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.7.0`,
        fs:  `cpe:2.3:o:edimax:6114wg_router_firmware:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.7.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.7.2`,
        fs:  `cpe:2.3:o:iij:seil\%2fb1_firmware:4.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.7.3`,
        fs:  `cpe:2.3:a:microsoft:excel:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.7.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p475:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.8.0`,
        fs:  `cpe:2.3:h:nec:ix1011:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:security_information_manager:4.8.1`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:security_information_manager_appliance:-`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:sms-smtp-mysql-init:5.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:sms-smtp-tomcat:5.5.13`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:sms-smtp-xml_mm:1.0.0`,
        fs:  `cpe:2.3:a:macromedia:captivate:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:storage_exec:5.5.2310`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:sygate_management_server:-`,
        fs:  `cpe:2.3:a:skype:skype:3.1.0.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:sygate_network_access_control:-`,
        fs:  `cpe:2.3:a:genixcms:genixcms:0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:sygate_personal_firewall:-`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:symantec_antivirus_filtering_%2bfor_domino:-`,
        fs:  `cpe:2.3:a:nullsoft:winamp:1.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:symav_filter_domino_nt:-`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:system_center:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:system_center:10.1.6000.6`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:system_center:10.1.8000.8`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:unified_logging:2.0.2.0`,
        fs:  `cpe:2.3:a:hp:intelligent_provisioning:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:velociraptor:-`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_authentication_service:4.1.2.7`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_authentication_service:4.3.32.6`,
        fs:  `cpe:2.3:a:autonomy:survey_editor:430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec:-`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec:10.0`,
        fs:  `cpe:2.3:a:marked_project:marked:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec:10d`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.341:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec:13.0.2896`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec:13.0.5204`,
        fs:  `cpe:2.3:h:intel:carrier_grade_server_tsrmt2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec:2010`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec:2010_r3`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_desktop_agent:3.1.0.0`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_for_windows_servers:10.1.5629`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_for_windows_servers:12.0.1364`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.1.1:mu_\#15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_for_windows_servers:12.5.2213`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_row_wifi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_license_assessment_tool:2.0.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2_sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_remote_agent_for_windows_servers:9.1.4691`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.04.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_remote_agent_for_windows_servers:10.1.5629`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:8.2.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:11.0.7170`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:12.0.1364`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.2_156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:12.5.2213`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.034:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:13.0.2896`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.10.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:13.0.5204`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_backup_exec_vss_provider:13.0.5204`,
        fs:  `cpe:2.3:a:digium:asterisk:c.1.6.1:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_commandcentral:5.1.294.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_commandcentral:5.2.473.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_commandcentral:5.2.2203.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_commandcentral:5.2.20000.0`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_dmp_dsm_solution:5.0.0`,
        fs:  `cpe:2.3:a:safenet-inc:sentinel_protection_installer:7.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_dmp_dsm_solution:5.1.0`,
        fs:  `cpe:2.3:a:feeds_project:feeds:7.x-2.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_dmp_dsm_solution:5.1.21`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u3\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_dmp_dsm_solution:5.1.10000`,
        fs:  `cpe:2.3:h:hp:jg513a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_dmp_dsm_solution:5.1.11000`,
        fs:  `cpe:2.3:a:openx:openx:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_dmp_dsm_solution:5.1.20000`,
        fs:  `cpe:2.3:a:apple:safari:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator:3.3.782`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator:3.3.903`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1674.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator:3.3.929`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator:3.3.1048`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.24:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator:3.3.1064`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:1.0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator:3.3.1066`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.801.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_agent_framework:3.3.782`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_agent_framework:3.3.903`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_agent_framework:3.3.929`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.12:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_agent_framework:3.3.1048`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_agent_framework:3.3.1064`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_agent_framework:3.3.1066`,
        fs:  `cpe:2.3:a:gajim:gajim:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_service:3.3.782`,
        fs:  `cpe:2.3:a:ubnt:unifi_controller:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_service:3.3.903`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:r331.00:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_service:3.3.929`,
        fs:  `cpe:2.3:a:huawei:e355_web_ui:11.001.08.00.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_service:3.3.1048`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_service:3.3.1064`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_enterprise_administrator_service:3.3.1066`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:3.6ecb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_gridnode_agent:5.0.91`,
        fs:  `cpe:2.3:h:apple:imac:m9249xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_gridnode_agent:5.0.141`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_gridnode_agent:5.0.281`,
        fs:  `cpe:2.3:a:php:php:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_gridnode_agent:5.0.286`,
        fs:  `cpe:2.3:a:yokogawa:centum_vp:r5.01.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_gridnode_agent:5.0.433`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_jre_redistribution:1.5.0.1`,
        fs:  `cpe:2.3:a:netiq:security_solutions_for_iseries:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup:6.5.0`,
        fs:  `cpe:2.3:o:airties:rt-210_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup:6.5.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)ja:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup:6.5.2a`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.7.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup:6.5.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1654.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup:6.5.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup:6.5.5`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup:7.0.1`,
        fs:  `cpe:2.3:a:teradata:multiload:12.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_client:-`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_client:5.0`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_client:5.1`,
        fs:  `cpe:2.3:a:barebones:textwrangler:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_client:6.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_client:6.5.0`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_client:6.5.4`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_enterprise_server:-`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_enterprise_server:5.0`,
        fs:  `cpe:2.3:h:cisco:catalyst_6000_ws-svc-nam-1:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_enterprise_server:5.1`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_enterprise_server:6.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:0.2000`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.20.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:6.0.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:6.5.3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:6.5.4`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:6.5.5`,
        fs:  `cpe:2.3:a:ca:unicenter_software_delivery:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:7.0`,
        fs:  `cpe:2.3:a:keepass:keepass:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:7.0.1`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:7.1`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_java:1000.0`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_server:-`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.04.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_server:5.0`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.3.0:cp01:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_server:5.1`,
        fs:  `cpe:2.3:a:buffalotech:whr-amg54_firmware:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_netbackup_server:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_operations_manager:3.0.357`,
        fs:  `cpe:2.3:a:ibm:websphere_host_on-demand:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_operations_manager:3.0.358`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_exec:5.3.2190`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_exec:5.5.2310`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation:-`,
        fs:  `cpe:2.3:a:oracle:project_contracts:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation:5.0`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:4.3`,
        fs:  `cpe:2.3:o:servision:hvg_video_gateway_firmware:2.2.26a77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.0`,
        fs:  `cpe:2.3:a:avg:internet_security:2015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.0:rollup_patch_1a`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.0:rollup_patch_2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.0.0`,
        fs:  `cpe:2.3:h:cisco:aironet_ap1400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.0.0::~~~~x64~`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.0.200`,
        fs:  `cpe:2.3:a:apache:struts:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.1`,
        fs:  `cpe:2.3:a:google:talk:1.0.0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.1.0`,
        fs:  `cpe:2.3:a:google:chrome:1.0.154.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.1.100:sp1`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.07.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.1.200:sp2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p355:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.1.10000`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.1.11000`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.1.20000`,
        fs:  `cpe:2.3:a:apache:ignite:1.5.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows:5.10.0`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_apppack:5.1.10`,
        fs:  `cpe:2.3:a:trafficgate:rakuten_install:1.5.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_apppack:5.1.110`,
        fs:  `cpe:2.3:a:keepass:keepass:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_apppack:5.1.1000.0`,
        fs:  `cpe:2.3:a:lxml:lxml:3.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_client:5.0.0.188`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_client:5.0.201:rp2`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_client:6.0.0`,
        fs:  `cpe:2.3:a:twitter_pull_project:twitter_pull:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_client:6.1.10000`,
        fs:  `cpe:2.3:a:koha:koha:3.14.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_client:6.1.20000`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_client_apppack:6.0.1`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_server:5.0.0.188`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_server:5.0.200.0:rp1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_server:5.0.201:rp2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.30.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_server:6.0.0`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns1200x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_server:6.1.10000`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.13:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_server:6.1.20000`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_ccf_server_apppack:6.0.1`,
        fs:  `cpe:2.3:a:apache:struts:2.3.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_for_windows_device_driver_installation:5.1.110:sp1`,
        fs:  `cpe:2.3:a:ckeditor:fckeditor:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_storage_foundation_ha_for_windows:5.1.200:sp2`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_update:1.0.4691`,
        fs:  `cpe:2.3:a:sun:extended_system_control_facility_xcp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_update:1.0.5629`,
        fs:  `cpe:2.3:a:spip:spip:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:-`,
        fs:  `cpe:2.3:a:isc:bind:9.0.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:3.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.806:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:3.5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.0`,
        fs:  `cpe:2.3:h:supermicro:h8dct-hln4f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.1`,
        fs:  `cpe:2.3:a:symantec:web_security_for_microsoft_isa_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.1:rp1`,
        fs:  `cpe:2.3:a:collectivecolors:taxonomy_view_integrator_module:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.1:rp1:windows`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.2`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.2:rp1`,
        fs:  `cpe:2.3:a:trivantis:coursemill_enterprise_learning_management_system:4.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.2:rp1:windows`,
        fs:  `cpe:2.3:a:drupal:drupal:6.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.2:rp2`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.2:rp2:windows`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:4.3`,
        fs:  `cpe:2.3:a:stunnel:stunnel:4.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:veritas_volume_replicator:5.0`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsaa:5.0.91`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsaa:5.0.141`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.59.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsaa:5.0.281`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsaa:5.0.286`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsaa:5.0.433`,
        fs:  `cpe:2.3:a:imember360:imember360:3.6.000:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsaa:5.0.442`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.52.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsaa:5.0.443`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.08.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsccg:5.0.91`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsccg:5.0.141`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsccg:5.0.281`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsccg:5.0.286`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsccg:5.0.433`,
        fs:  `cpe:2.3:a:ibm:kenexa_lcms_premier:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsccg:5.0.442`,
        fs:  `cpe:2.3:h:qnap:ts-ec1679u-rp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsccg:5.0.443`,
        fs:  `cpe:2.3:h:dell:powerconnect_6248:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsccscmserver:5.2.202.0`,
        fs:  `cpe:2.3:h:iodata:ts-ptcam\/poe_camera_firmware:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsjre:1.5.1.4`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsjre:1.5.3.9`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsjre:1.6.0.16`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:sp1a:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsmh:5.0.91`,
        fs:  `cpe:2.3:h:intel:netstructure_7180:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsmh:5.0.141`,
        fs:  `cpe:2.3:a:mobilityware:freecell_solitaire:2.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsmh:5.0.281`,
        fs:  `cpe:2.3:a:avg:anti-virus:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsmh:5.0.433`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsperl:5.0.0`,
        fs:  `cpe:2.3:a:samba:samba:3.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsperl:5.1.0`,
        fs:  `cpe:2.3:a:rob_loach:sharethis:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsperl:5.1.10000`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtsscmui:5.2.202.0`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtssfmh:2.1.210`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtssfmh:3.0.357`,
        fs:  `cpe:2.3:h:rsa:securid:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtssfmh:3.0.358`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:vrtssmweb:1.2.99`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.0`,
        fs:  `cpe:2.3:a:boson:exam_environment:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.0.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.0.2`,
        fs:  `cpe:2.3:a:gentoo:app-crypt_pinentry:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.0.3`,
        fs:  `cpe:2.3:a:ibm:connections_portlets:4.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.0.3.18`,
        fs:  `cpe:2.3:a:zeroclipboard_project:zeroclipboard:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.1`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.1.1`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.3:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.2`,
        fs:  `cpe:2.3:a:opensymphony:webwork:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_gateway:5.2.1`,
        fs:  `cpe:2.3:a:logitech:lws_motion_detection:13.30.1395.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:web_gateway_appliance_8450:-`,
        fs:  `cpe:2.3:a:hitachi:cosminexus\/opentp1_web_web_front-endset:02-00-\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:symantec:web_gateway_appliance_8490:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:-`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:7.5.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:3.01.59`,
        fs:  `cpe:2.3:h:honeywell:midas:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:3.01.60`,
        fs:  `cpe:2.3:h:linksys:befsx41:1.43.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:3.01.61`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:3.01.62`,
        fs:  `cpe:2.3:a:solarwinds:exchange_monitor:1.0.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:3.01.63`,
        fs:  `cpe:2.3:h:supermicro:x7spt-df-d525:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:3.01.67`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1001.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:3.01.68`,
        fs:  `cpe:2.3:a:cisco:webex_advanced_recording_format_player:27.11.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security:5.0`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:web_security_for_microsoft_isa_server:5.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.1.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:windows_liveupdate:-`,
        fs:  `cpe:2.3:o:siemens:cvms2025-ir_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:wise_package_studio:7.2.31`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:wise_package_studio:7.3.385`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:workspace_streaming:6.1:sp1`,
        fs:  `cpe:2.3:a:htc:evo_4g_software:4.22.651.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:workspace_streaming:6.1:sp2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.00.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:workspace_streaming:6.1:sp3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:workspace_streaming:6.1:sp4`,
        fs:  `cpe:2.3:a:microsoft:security_compliance_manager:1.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:workspace_streaming:7.5.0`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:workspace_streaming:7.5.0.749`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:workspace_virtualization:6.4.1895.0`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:workspace_virtualization:6.4.1953.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:wxrt_ccf_client_apppack:6.1.2`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.8:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symantec:wxrt_ccf_server_apppack:6.1.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:5.3.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symas:connexitor_directory_services:3.11.3::~~silver_edition~~~`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symmetricom:symmtime:4.9.0`,
        fs:  `cpe:2.3:a:adobe:photoshop:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.001`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.002`,
        fs:  `cpe:2.3:a:husdawg:system_requirements_lab_for_intel:4.4.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.003`,
        fs:  `cpe:2.3:a:percona:xtradb_cluster:5.6.30-25.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.004`,
        fs:  `cpe:2.3:a:gnu:glibc:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.005`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.006`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.007`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.008`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.009`,
        fs:  `cpe:2.3:a:compaq:foundation_agents:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.010`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.1.8:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:0.011`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.2.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.2.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.2.2`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.3.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)n2\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.3.1`,
        fs:  `cpe:2.3:a:paymentsplus:payments_plus:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.3.1-2`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta43:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.3.2`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.3.3`,
        fs:  `cpe:2.3:h:lexmark:t654:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.3.4`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.3.4-1`,
        fs:  `cpe:2.3:h:huawei:secospace_antiddos8000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.4.0`,
        fs:  `cpe:2.3:a:freedomscientific:talking_installer:9.0.552.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.4.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.4.2`,
        fs:  `cpe:2.3:a:e107:e107:0.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.4.2-1`,
        fs:  `cpe:2.3:o:cisco:ios:10.3\(3.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:1.5`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc3310:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.2.1b`,
        fs:  `cpe:2.3:a:apple:safari:3.0.2b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.2.2b`,
        fs:  `cpe:2.3:o:yahama:srt100:10.00.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.2.3b`,
        fs:  `cpe:2.3:a:debian:mime-support:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.2.4`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.2.5`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:5.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.2.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.2.7`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.2b`,
        fs:  `cpe:2.3:a:niif:shibboleth_authentication:6.x-4.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.3:beta`,
        fs:  `cpe:2.3:h:tp-link:tl-wrd740n_\(5.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(25\)w5-27d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.3.1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.3.2`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.3.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p469:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.3.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.4`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.5`,
        fs:  `cpe:2.3:a:fancybox_project:fancybox:3.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.5.1`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.5.2`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_center:12.0.0:-:small_business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.5.3b`,
        fs:  `cpe:2.3:a:exim:exim:4.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.5.4b`,
        fs:  `cpe:2.3:a:bluecoat:advanced_secure_gateway:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.6`,
        fs:  `cpe:2.3:a:veritas:netbackup:4.5.0:mp8:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.6.1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.7`,
        fs:  `cpe:2.3:h:cisco:nexus_92304qc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.7.1`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.7.2`,
        fs:  `cpe:2.3:a:kernel:linux-pam:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.7.3`,
        fs:  `cpe:2.3:a:qualys:qualysguardsuite:7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.7a`,
        fs:  `cpe:2.3:a:ajax-random-post_project:ajax-random-post:2.00:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.7b.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.6.1r10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.7b.2`,
        fs:  `cpe:2.3:a:borland:caliberrm:9.0.847:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:2.7b.3`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.0a`,
        fs:  `cpe:2.3:a:wernerd:zrtpcpp:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.0a.1`,
        fs:  `cpe:2.3:h:schneider_electric:sage_landac_ii-2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.0b.4`,
        fs:  `cpe:2.3:a:ncr:bootdiskmon:2.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.0b.8`,
        fs:  `cpe:2.3:a:jease:jease:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.0b.9`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.1.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.1b.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.1b.8`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.9.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.1b.9`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(3\)n1\(3.12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.1b.10`,
        fs:  `cpe:2.3:a:plone:plone:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.1b.12`,
        fs:  `cpe:2.3:h:apple:macbook_pro:ma895xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.1b.13`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.2`,
        fs:  `cpe:2.3:a:cisco:finesse:10.5\(1\)_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.2.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(0\)n1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.2.2a`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.1.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.3`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.4b.3`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.4b.4`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.4:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.4b.5`,
        fs:  `cpe:2.3:a:microsoft:works:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.4b.6`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system_central_software:1.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.4b.7`,
        fs:  `cpe:2.3:h:apple:imac:mc022xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.4b.8`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.4b.9`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:2.6.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.5`,
        fs:  `cpe:2.3:a:ibm:lotuslive_meetings_for_ibm:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.6b.1`,
        fs:  `cpe:2.3:a:connections_project:connections:0.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.6b.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc105a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.6b.3`,
        fs:  `cpe:2.3:a:oracle:retail_service_backbone:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.6b.4`,
        fs:  `cpe:2.3:a:rpm:rpm:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.6b.5`,
        fs:  `cpe:2.3:h:axis:neteye_200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3.6b.6`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.6:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3b.3`,
        fs:  `cpe:2.3:a:minitab:license_manager:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.3b.4`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:3.4`,
        fs:  `cpe:2.3:a:shopizer:shopizer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.a1`,
        fs:  `cpe:2.3:a:cyber-will:social-button_premium:1.0:*:*:*:*:ec-cube:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.a3`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.a4`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.a5`,
        fs:  `cpe:2.3:a:samba:samba:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.a6`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.a7`,
        fs:  `cpe:2.3:a:symantec:data_center_security_server:6.6:mp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.a8`,
        fs:  `cpe:2.3:a:augeas:augeas:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.a9`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.26:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.b1`,
        fs:  `cpe:2.3:a:oracle:web_cache:11.1.1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.b2`,
        fs:  `cpe:2.3:a:iss:blackice_agent_for_workstation:3.1:eal:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.0.b3`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.1`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.2b.1`,
        fs:  `cpe:2.3:a:hp:radia_client:3.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:4.2b.3`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.0a`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.0a.1`,
        fs:  `cpe:2.3:a:hp:service_center:6.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.0b`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.0b.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.1`,
        fs:  `cpe:2.3:h:buffalotech:bhr-4rv:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.1.2`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.0:rc2-a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.2b`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg9000-5:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.2b2`,
        fs:  `cpe:2.3:a:cisco:security_agent:5.0.193:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3`,
        fs:  `cpe:2.3:a:jeremy_massel:underconstruction:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3.2`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3a.8`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.622:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3a.9`,
        fs:  `cpe:2.3:a:perl:perl:0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3a.10`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3b.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3b.3`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3b.4`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:3.0.0.4.376.3715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.3b.5`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.4`,
        fs:  `cpe:2.3:a:ibm:rational_requisitepro:2.1.1202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.4.1`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.4.2`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.4.3`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.4a.2`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(2\):-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.4a.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:5.4b.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.0`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.2`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.3`,
        fs:  `cpe:2.3:a:microsoft:sql_server:7.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.4`,
        fs:  `cpe:2.3:h:siemens:scalance_x-300poe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.7`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.8`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0.9`,
        fs:  `cpe:2.3:a:whcms_project:whcms:0.115:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0b.1`,
        fs:  `cpe:2.3:a:apache:activemq:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0b.2`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0b.3`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.0b.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.0`,
        fs:  `cpe:2.3:a:buffalotech:whr-amg54_firmware:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.1`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp1:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.2`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.3`,
        fs:  `cpe:2.3:a:schedmd:slurm:15.08.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.4`,
        fs:  `cpe:2.3:a:apache:camel:2.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.5`,
        fs:  `cpe:2.3:a:zarafa:webapp:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2seb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.7`,
        fs:  `cpe:2.3:a:python:python:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.8`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.953:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.9`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.11`,
        fs:  `cpe:2.3:a:google:chrome:8.0.554.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.12`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)ey2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.13`,
        fs:  `cpe:2.3:h:hp:laserjet_m4555:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.14`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.15`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.16`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.17`,
        fs:  `cpe:2.3:o:apple:mac_os_server:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.18`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.19`,
        fs:  `cpe:2.3:a:horde:groupware:1.1:rc1:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.20`,
        fs:  `cpe:2.3:a:jreast:jr_east_japan:1.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.21`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_customer_relationship_management:8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.22`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.14:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1.23`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1b.1`,
        fs:  `cpe:2.3:a:ibm:filenet_business_process_framework:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1b.2`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1b.3`,
        fs:  `cpe:2.3:h:hp:laserjet_4100mfp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1b.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:7.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympa:sympa:6.1b.6`,
        fs:  `cpe:2.3:h:fortinet:fortianalyzer-300d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.0`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.0.3`,
        fs:  `cpe:2.3:a:netiq:appmanager_repository_installation:7.0.10160.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.0.4`,
        fs:  `cpe:2.3:h:nortel:optical_metro_5100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.0.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)m0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.0.6`,
        fs:  `cpe:2.3:a:hp:version_control_repository_manager:1.0.2289.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.0.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.1.0`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.40:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.1.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.3.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.1\(3f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.3.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.3.2`,
        fs:  `cpe:2.3:a:mobleeps:job_mobleeps:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.6.2`,
        fs:  `cpe:2.3:a:permadi:mahjong_galaxy_space_lite:2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:symphony-cms:symphony_cms:2.6.3`,
        fs:  `cpe:2.3:a:hitachi:groupmax_collaboration:07-35-\/g:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sympies:wordpress_survey_and_poll:1.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synametrics:xeams:4.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synapse:ishuttle:1::~~~android~~`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.0`,
        fs:  `cpe:2.3:a:crawlability:vbseo:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.1`,
        fs:  `cpe:2.3:o:google:android:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.1.5`,
        fs:  `cpe:2.3:a:vips:vips:7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.1.6`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.1.7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3\(2.243\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.1.8`,
        fs:  `cpe:2.3:a:busybox:busybox:1.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.1.9`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.2.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.2.2`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.2.3`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:1.2.4`,
        fs:  `cpe:2.3:a:gnome:gnome_online_accounts:3.7.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:2.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:2.0.1`,
        fs:  `cpe:2.3:a:digia:qt:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:2.0.2`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.3.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:2.0.3`,
        fs:  `cpe:2.3:a:atlassian:jira:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:2.0.4`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.7691:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:3.0`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:3.1`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2003:-:*:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:4.0`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7960g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:4.1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:4.2`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:5.0`,
        fs:  `cpe:2.3:a:gnu:libtool:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:5.1`,
        fs:  `cpe:2.3:a:geeklog:geeklog:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:6.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:6.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.405:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:6.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.0.12.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:7.0`,
        fs:  `cpe:2.3:a:accelatech:bizsearch:3.2:-:*:*:*:sunos:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:7.1`,
        fs:  `cpe:2.3:a:oracle:common_applications:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:7.2`,
        fs:  `cpe:2.3:a:emc:my_documentum_for_microsoft_outlook:6.7:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:8.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.18:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:8.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.8:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:8.2`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:9.0`,
        fs:  `cpe:2.3:a:ibm:integration_bus:9.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:9.1`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.0.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:9.2`,
        fs:  `cpe:2.3:a:libmms_project:libmms:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:9.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:10.0`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.5.0:devel:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:10.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:10.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:10.3`,
        fs:  `cpe:2.3:a:symantec:mail-gear:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:11.0`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:11.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:11.2`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:12.0`,
        fs:  `cpe:2.3:a:winscp:winscp:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:12.1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:12.2`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:13.0`,
        fs:  `cpe:2.3:a:namazu:namazu:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:13.1`,
        fs:  `cpe:2.3:a:samba:samba:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sync:oxygen_xml_editor:13.2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synck_graphica:download_log_cgi:3.0`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synck_graphica:mailform_pro_cgi:4.1.4`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synck_graphica:mailform_pro_cgi:4.1.5`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synck_graphica:mailform_pro_cgi:4.20`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syncsort:backup_express:-`,
        fs:  `cpe:2.3:a:avonesoft:psp_video_converter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.4`,
        fs:  `cpe:2.3:a:christoph_dorn:firephp:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.4.10`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_3200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.5.00`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.5.01`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.4_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.6.00`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.7.00`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.5:-:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.8.00`,
        fs:  `cpe:2.3:a:ibm:rational_change:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.8.1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.8.02`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.4.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:2.9.00`,
        fs:  `cpe:2.3:o:nuuo:nvrsolo:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:3.0.00`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syndeocms:syndeocms:3.0.01`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(9\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synergy-foss:synergy:1.3.7`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synnefoims:internet_management_software:2015`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-48p-si_ls-5100-48p-si-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:1.1-2291`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:2.0-2291`,
        fs:  `cpe:2.3:o:yamaha:rt200i:3.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:2.0-2402`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:2.1-2561`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.77:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:2.1-2570`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:2.1-2577`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.5\(1\)su6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:3.0-3005`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:3.0-3103`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:3.0-3108`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:3.0-3109`,
        fs:  `cpe:2.3:a:microsoft:netmeeting:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:3.0-3111`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:3.1-3317`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d70:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:cloud_station:3.1-3320`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:diskstation_manager:3.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:diskstation_manager:4.0`,
        fs:  `cpe:2.3:h:linksys:befsr11:1.42.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:diskstation_manager:4.0-2259`,
        fs:  `cpe:2.3:a:hp:loadrunner:11.52:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:diskstation_manager:4.2`,
        fs:  `cpe:2.3:a:apache:subversion:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:diskstation_manager:4.2-3243`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:diskstation_manager:4.3`,
        fs:  `cpe:2.3:a:invisionpower:ip.nexus:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:diskstation_manager:4.3-3810`,
        fs:  `cpe:2.3:a:macromedia:flash_player:6.0.65.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:diskstation_manager:4.3-3810:1`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.4-2557`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.4-2558`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2638`,
        fs:  `cpe:2.3:a:php:php:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2705`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2706`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.2:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2955`,
        fs:  `cpe:2.3:a:php:php:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2962`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:04-00:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2967`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2968`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2970`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2973`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2980`,
        fs:  `cpe:2.3:a:progress:objectstore:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.5-2982`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.8.0-3416`,
        fs:  `cpe:2.3:a:choiceoflove:free_dating_heart_col:2.6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.8.1-3420`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.8.2-3455`,
        fs:  `cpe:2.3:a:automatedqa:testrecorder:7.52.678.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.8.3-3458`,
        fs:  `cpe:2.3:a:david_king:vino:3.3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:download_station:3.8.4-3468`,
        fs:  `cpe:2.3:a:php:pear:1.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:ds_audio:3.4::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.7.0.19480:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:ds_file:4.1.1::~~~android~~`,
        fs:  `cpe:2.3:o:freenas:freenas:0.686.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:ds_photo%2b:3.3::~~~android~~`,
        fs:  `cpe:2.3:a:attachmate:verastream_host_integrator:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:photo_station:6.3-2944`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.2-0439`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.10.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.2-0443`,
        fs:  `cpe:2.3:a:uninett:radsecproxy:1.0:alpha-p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.2-0447`,
        fs:  `cpe:2.3:a:claroline:claroline:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.2-0451`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir:3.9.1.4000:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.2-0453`,
        fs:  `cpe:2.3:a:mesa3d:mesa:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.5-0753`,
        fs:  `cpe:2.3:a:ecava:integraxor:3.71.4200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.5-0763`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.5-0770`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.6-0835`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.6-0840`,
        fs:  `cpe:2.3:a:shiromuku:diary:2.10:-:fs6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.6-0841`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synology:video_station:1.6-0844`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:synrevoice:safe_arrival:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0:rc1`,
        fs:  `cpe:2.3:a:mutiny:mutiny_virtual_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0:rc2`,
        fs:  `cpe:2.3:a:symantec:java_liveupdate:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0:rc2a`,
        fs:  `cpe:2.3:a:emc:retrospect:7.50.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0:rc3`,
        fs:  `cpe:2.3:a:solarwinds:tftp_server:solarwinds_tftp_server:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0.1`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0.2`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0.3`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.7:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0.4`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0.5`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0.6`,
        fs:  `cpe:2.3:a:tecnick:tcexam:10.1.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.0.7`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1:rc1`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.7.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1:rc2`,
        fs:  `cpe:2.3:o:meinberg:ntp_server_firmware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1:rc3`,
        fs:  `cpe:2.3:a:isc:bind:9.6.3:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1:rc4`,
        fs:  `cpe:2.3:a:php:php:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1:rc5`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1:rc6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.1`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_provisioning:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.2`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.3`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.4`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.5`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.6`,
        fs:  `cpe:2.3:a:hp:icc_profiles:2.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.7`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.19.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.8`,
        fs:  `cpe:2.3:a:adobe:framemaker:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:2.1.9`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0`,
        fs:  `cpe:2.3:a:avactis:avactis_shopping_cart:1.9.1:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0:rc1`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0:rc2`,
        fs:  `cpe:2.3:a:fujitsu:interstage_application_server:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0:rc3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:f9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.2`,
        fs:  `cpe:2.3:a:djangoproject:django:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.4`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.5`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.6`,
        fs:  `cpe:2.3:a:opscode:chef:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.7`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.8`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.9`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:3.0.10`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0`,
        fs:  `cpe:2.3:a:herac:tuxguitar:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0:rc8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.2`,
        fs:  `cpe:2.3:a:igrafx:igrafx:14.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.3`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.4`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.5`,
        fs:  `cpe:2.3:h:cisco:asr_5500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.6`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.core:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.7`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.8`,
        fs:  `cpe:2.3:a:condusiv:diskeeper_2011:15.0.956.32:*:*:*:pro_premier:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.9`,
        fs:  `cpe:2.3:a:sun:grid_engine:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.10`,
        fs:  `cpe:2.3:a:keepass:keepass:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:4.0.11`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.6\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0:beta_1`,
        fs:  `cpe:2.3:a:owncloud:owncloud:5.0.14:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0:beta_2`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0:beta_3`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.7.0-142:online_linux:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0:beta_4`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0:rc1`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0:rc2`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0:rc3`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0:rc4`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0.1`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0.2`,
        fs:  `cpe:2.3:a:mozilla:camino:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0.3`,
        fs:  `cpe:2.3:a:att:communication_manager:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0.4`,
        fs:  `cpe:2.3:a:f5:big-ip_advanced_firewall_manager:11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0.5`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:5.0.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.460:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0:beta_1`,
        fs:  `cpe:2.3:a:apache:commons-compress:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0:beta_2`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2011-05-25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0:beta_3`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0:rc1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.404:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0:rc2`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0.1`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0.3`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0.4`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:4.0:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0.5`,
        fs:  `cpe:2.3:h:lg:l-09c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0.6`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.5.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0.7`,
        fs:  `cpe:2.3:a:vmware:springsource_spring_security:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:syntevo:smartsvn:6.0.8`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysaid:sysaid:6.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:sysaid:sysaid:6.5`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs5.1:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysaid:sysaid:14.4`,
        fs:  `cpe:2.3:a:apache:camel:2.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysaid:sysaid:15.1`,
        fs:  `cpe:2.3:a:pixman:pixman:0.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysaid:sysaid_admin_tools:6.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysax:multi_server:4.3`,
        fs:  `cpe:2.3:a:clamav:clamav:0.96.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysax:multi_server:4.5`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysax:multi_server:5.50`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysax:multi_server:5.52`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p384:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysflow:sysflowagent:1.2.0.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:14.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysphonic:thetis:2.1.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.615.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysphonic:thetis:2.2.0`,
        fs:  `cpe:2.3:a:oracle:corporate_time_outlook_connector:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysphonic:thetis:2.3.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.22.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:sysprogs:wincdemu:3.6`,
        fs:  `cpe:2.3:a:zooeffect:zooeffect:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemsoftware:community_black_forum:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.2.2`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.3`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.4`,
        fs:  `cpe:2.3:a:haxx:curl:7.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.3`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.4`,
        fs:  `cpe:2.3:a:apache_software_foundation:tomcat:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.5`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.7`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.8`,
        fs:  `cpe:2.3:a:deceiver:anahi_a_adopter_fr:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.9`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.10`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.12`,
        fs:  `cpe:2.3:a:infineon:trusted_platform_module:3.0.2:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.13`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.5.14`,
        fs:  `cpe:2.3:a:sun:jre:6.0.200:update20:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.6`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update9:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.6.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xe3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.7.2`,
        fs:  `cpe:2.3:o:f5:tmos:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.8`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.9`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:2009-02-14b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.9.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.9.7`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.9.8`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:0.9.9`,
        fs:  `cpe:2.3:a:google:chrome:16.0.893.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p180:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.1`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:8.0:-:*:*:*:windows_server_2003:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.2`,
        fs:  `cpe:2.3:a:razorcms:razorcms:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.3`,
        fs:  `cpe:2.3:a:teeworlds:teeworlds:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.4`,
        fs:  `cpe:2.3:a:adrotateplugin:adrotate:3.9.1:*:pro:*:wordpress:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.5`,
        fs:  `cpe:2.3:h:hp:jg596a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.6`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.6.7`,
        fs:  `cpe:2.3:a:postgresql:psqlodbc:8.3.400:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtap:systemtap:1.7`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtools:dumpsec:2.8.6`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtools:hyena:4.2.0`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtools:hyena:6.3.1`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtools:hyena:6.7.1`,
        fs:  `cpe:2.3:a:jenkins:git:3.6.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtools:hyena:8.0.3`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtools:hyena:8.50.2000`,
        fs:  `cpe:2.3:a:memcache_project:memcache:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:systemtools:ost_recovery:3.2`,
        fs:  `cpe:2.3:a:isc:bind:9.4.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:t-com:speedport_500v:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:t-com:speedport_500v_firmware:1.31`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:sp1:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/h:t-mobile:g2:-`,
        fs:  `cpe:2.3:h:huawei:cx600:v600r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t-mobile:my_t-mobile:%407f0c0030::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.9sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:t-mobile:mytouch_3g_slide:-`,
        fs:  `cpe:2.3:a:isc:bind:9.6.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:t-mobile:mytouch_4g_slide:-`,
        fs:  `cpe:2.3:a:adobe:photoshop_cc:16.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.1:alpha`,
        fs:  `cpe:2.3:a:islonline:isl_desktop_plugin:1.4.1:-:-:*:windows:isl_light:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.2:beta`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.3:beta`,
        fs:  `cpe:2.3:h:ibm:security_network_protection_xgs_7100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.4:beta`,
        fs:  `cpe:2.3:a:ibm:lotus_expeditor:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.5:beta`,
        fs:  `cpe:2.3:a:oracle:database_server:10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.6:beta`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.7:beta`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:6.0:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.8:beta`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.9`,
        fs:  `cpe:2.3:a:hitachi:jp1\/it_desktop_management-manager:09-51-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.9.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:0.9.2`,
        fs:  `cpe:2.3:a:soprano:fonecta_verify:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:1.0`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:1.0.1`,
        fs:  `cpe:2.3:h:hp:integrated_lights_out:1.50a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:1.1.0`,
        fs:  `cpe:2.3:h:lexmark:t430:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:1.1.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:1.2`,
        fs:  `cpe:2.3:a:quest:toad_data_modeler:3.3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:1.3`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:1.3.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:9.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:5.0.0`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:5.0.1`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.6:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:5.0.2`,
        fs:  `cpe:2.3:a:oracle:database_server_lite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:5.1.0`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:5.1.1`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:t1lib:t1lib:5.1.2`,
        fs:  `cpe:2.3:a:ibm:sterling_control_center:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.0`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:r2:*:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.0.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1074.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.0.2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.0.3`,
        fs:  `cpe:2.3:a:php:php:5.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.0.4`,
        fs:  `cpe:2.3:a:cybozu:cybozu_office:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.0.5`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.0.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(27b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.1`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tableausoftware:tableau_server:8.1.1`,
        fs:  `cpe:2.3:h:cisco:mds_9000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tablefield_project:tablefield:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_30:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tablefield_project:tablefield:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:sun:service_tags:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tablefield_project:tablefield:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tabtale:abc_song:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:h:lenovo:thinkserver_rd350:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tabtale:enchanted_fashion_crush:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:wave:preboot_manager:2.0.0.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tacticalforcellc:tactical_force_llc:1.9.23.276::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:creative_suite_4:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tadaa%21_project:tadaa%21:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:corel:coreldraw_lang_fr:x4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.0`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.0:rc2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.1:rc1`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:10.0:*:*:*:enterprise:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.2:rc1`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:441:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.3`,
        fs:  `cpe:2.3:a:gnu:gdb:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.3:rc1`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.0.5:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.4`,
        fs:  `cpe:2.3:a:possesports:posse_softball_director_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.4:rc1`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.5`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.5:rc1`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.6:rc1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p158:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:siemens:simatic_step_7:5.5:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support_timer:6.x-1.0`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support_timer:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support_timer:6.x-1.1`,
        fs:  `cpe:2.3:h:cisco:wireless_control_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support_timer:6.x-1.2`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support_timer:6.x-1.3`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop_for_windows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support_timer:6.x-1.4`,
        fs:  `cpe:2.3:a:honeywell:symmetre:r400.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tag1consulting:support_timer:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:eclipse:jetty:9.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tails_project:tails:1.6`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tamalaki:hidden_object_mystery:1.0.65::~~~android~~`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tamos:commtraffic:-`,
        fs:  `cpe:2.3:a:totalseminars:cissp_5th_ed_aio:9.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tamos:commtraffic:2.1`,
        fs:  `cpe:2.3:h:hp:psc_900:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tamrielma:skyrim_map:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.0.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.0.0::~~~wotlab_burning_board~~`,
        fs:  `cpe:2.3:a:freeradius:freeradius:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.0.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.0.1::~~~wotlab_burning_board~~`,
        fs:  `cpe:2.3:a:acronis:true_image_echo_enterprise_server:9.7.8206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.0.2::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.0.2::~~~wotlab_burning_board~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_business_systems_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.1.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.1.0::~~~wotlab_burning_board~~`,
        fs:  `cpe:2.3:o:openvz:vzkernel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.1.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.0.3:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.1.1::~~~wotlab_burning_board~~`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:3.0.11171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.1.2::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.2.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:e107:e107:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.2.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:kelly_d._redding:kelredd-pruview:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.2.3::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:sun:seam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:1.2.6::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.428:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:2.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.1.2::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:php_kobo:photo_gallery_cms_free:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.1.3::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.1.4::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.8.64739.471:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.1.5::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.493:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.2.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.9.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:altiris:patch_management_agent:6.2.2514:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.9.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.9.2::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:iojs:io.js:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:3.9.3::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:david_king:vino:2.19.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.0.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.1.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.2.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.2.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:home_and_student:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.3.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:adobe:connect_outlook_add-in:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.3.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.0.1198:online_windows_2000:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.4.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.5.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:ibm:rational_license_key_server:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.5.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:microsoft:xml_core_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.5.2::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.5.7::~~~mybb~~`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.6.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.93.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.7.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:o:ampedwireless:r10000_firmware:2.5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.7.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.7.2::~~~vbulletin~~`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:630:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.8.0::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.8.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:o:juniper:junos:13.1:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:4.8.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:5.0.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:5.0.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:adobe:extension_manager:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:5.1.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:aol:aim:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:5.1.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:5.1.2::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:hp:array_diagnostic_utility:8.10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:5.1.3::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:5.2.0::~~~vbulletin~~`,
        fs:  `cpe:2.3:a:nvidia:control_panel:275.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tapatalk:tapatalk:5.2.1::~~~vbulletin~~`,
        fs:  `cpe:2.3:h:apple:airport_extreme:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tappocket:dino_zoo:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:taskware:wintask:3.7.1`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:taskware:wintask:3.8.1`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a1:7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tasofro:touhou-hisouten:1.01`,
        fs:  `cpe:2.3:a:arbornetworks:peakflow_sp:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tasofro:touhou-hisouten:1.02`,
        fs:  `cpe:2.3:a:zonelabs:integrity:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tasofro:touhou-hisouten:1.03`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.8-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tasofro:touhou-hisouten:1.04`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:tasofro:touhou-hisouten:1.06`,
        fs:  `cpe:2.3:a:gnu:glibc:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tasofro:touhou-hisouten:1.06:alpha`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tattyan:tattyan_hptown:5_9_3`,
        fs:  `cpe:2.3:a:roundcube:webmail:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tattyan:tattyan_hptown:5_10`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:taxonews_project:taxonews:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.12:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:taxonews_project:taxonews:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:taxonomy_accordion_project:taxonomy_accordion:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:gnu:bash:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:taxonomy_path_project:taxonomy_path:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:8.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tbb:taiwan_business_bank:2.04::~~~android~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tbelmans:mm_forms_community:2.2.5`,
        fs:  `cpe:2.3:a:facebook:kazakhstan_radio:2.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tbelmans:mm_forms_community:2.2.6`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tcpdump:tcpdump:4.7.0`,
        fs:  `cpe:2.3:a:logitech:erlt:1.20.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tdah:t-day_webmail:3.2.0-2.3`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0049:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamlava:fashion_story%3a_neon_90%27s:1.5.6.5::~~~android~~`,
        fs:  `cpe:2.3:a:ca:etrust_audit_datatools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(3\)i1\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.1`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.3`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.11.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.4`,
        fs:  `cpe:2.3:a:microsoft:msde:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.5`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:2.1.8:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.10`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.13`,
        fs:  `cpe:2.3:a:bea:weblogic_server:4.5.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.14`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.15`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.18`,
        fs:  `cpe:2.3:a:microsoft:xml_core_services:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.19`,
        fs:  `cpe:2.3:a:siemens:simatic_wincc_sm\@rtclient:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.20`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.20:beta`,
        fs:  `cpe:2.3:o:d-link:dsr-250_firmware:1.01b56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.21`,
        fs:  `cpe:2.3:h:lexmark:xc6152dtfe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.22`,
        fs:  `cpe:2.3:a:pineapp:mail-secure:3.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.23.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.23.2`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.23.3`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.5\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.23.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2011.707.2315.39839:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.24.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.24.1`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.24.2`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.24.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.24.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30279:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.25.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.6.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.25.1`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.17:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.25.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.826.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.7.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.0`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.1`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a4:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.2`,
        fs:  `cpe:2.3:a:trihedral:vtscada:11.0.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.3`,
        fs:  `cpe:2.3:a:jenkins:sidebar_link:1.9:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.4`,
        fs:  `cpe:2.3:a:horde:imp:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.5`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.6`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.7`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.5-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.9`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.10`,
        fs:  `cpe:2.3:a:horde:imp:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.11`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.0.0_0001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.12`,
        fs:  `cpe:2.3:o:cisco:catos:7.6\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.13`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.14`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.15`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.16`,
        fs:  `cpe:2.3:a:apache:camel:2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.17`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.18`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.19`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.14.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.26.20`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.1`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.0.3:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.3`,
        fs:  `cpe:2.3:a:umich:libgssglue:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.4`,
        fs:  `cpe:2.3:a:microsoft:netmeeting:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.5`,
        fs:  `cpe:2.3:a:nokia:9500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.6`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.7`,
        fs:  `cpe:2.3:h:hp:jc474b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.8`,
        fs:  `cpe:2.3:a:hp:service_manager:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.9`,
        fs:  `cpe:2.3:a:dadabik:dadabik:4.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teampass:teampass:2.1.27.10`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:alert:10.1_pf_20080815`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:it_service_analyzer%2freporter:10.2.533`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:manager:10.1`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:manager:10.1_pf_20080402`,
        fs:  `cpe:2.3:a:alex_barth:data:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:manager:10.1_pf_20081001`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:manager:10.2.3445`,
        fs:  `cpe:2.3:a:hummingbird:enterprise_collaboration:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:model:10.2.2280`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:view:9.2_pf_20060315`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.22:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:view:10.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:view:10.1_pf_20080815`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.8.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamquest:view:10.2.2476`,
        fs:  `cpe:2.3:a:labanquepostale:acces_compte:3.2.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak_classic:1.5`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.5:i3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak_classic:1.5.0.6`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak2:2.0.23.19:-:server`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.156:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak2:2.0.24.1:-:server`,
        fs:  `cpe:2.3:a:gnu:emacs:24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak2:2.0.32:-:client`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.306:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak2:2.0.32.60:-:client`,
        fs:  `cpe:2.3:h:belkin:f5d8236-4:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak2:2.0.33.7:-:client`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak3:3.0.0:beta29:server`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:8.26.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamspeak:teamspeak3:3.0.0:beta32:client`,
        fs:  `cpe:2.3:a:torproject:tor:0.3.1.3:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.7`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.7.0`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:7.0.6.1126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.7.1`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.21-70.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.7.2`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.7.3`,
        fs:  `cpe:2.3:a:dotclear:dotclear:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.7.4`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8`,
        fs:  `cpe:2.3:a:ultraseek:ultraseek:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8:beta1`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8:beta2`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8:beta3`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8:rc1`,
        fs:  `cpe:2.3:a:aircrack-ng:aircrack-ng:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8.0`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8.1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8.2`,
        fs:  `cpe:2.3:h:intel:server_board_s5000psl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8.3`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.8.4`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamst:testlink:1.9.3`,
        fs:  `cpe:2.3:a:ibm:infosphere_datastage:11.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamviewer:teamviewer:-`,
        fs:  `cpe:2.3:a:avaya:sip_enablement_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamviewer:teamviewer:1.85`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:2.1.5-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamviewer:teamviewer:2.44`,
        fs:  `cpe:2.3:o:f5:tmos:9.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamviewer:teamviewer:3.6.5523`,
        fs:  `cpe:2.3:o:cisco:content_services_switch_11500:7.30_\(00.09\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamviewer:teamviewer:4.1.8107`,
        fs:  `cpe:2.3:a:phorum:phorum:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teamviewer:teamviewer:5.0.8703`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:teatrofrancoparenti:teatro_franco_parenti:1.4.0::~~~android~~`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tec-it:tbarcode_ocx:-`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tec-it:tbarcode3_activex:-`,
        fs:  `cpe:2.3:a:nokia:affix:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tec-it:tbarcode3_dll:-`,
        fs:  `cpe:2.3:a:djvulibre_project:djvulibre:3.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techjoomla:com_socialads:-`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:technicolor:tc7200:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:technicolor:tc7200_firmware:std6.01.12`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:technicolor:td5130_router_firmware:2.05.c29gv`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2010.706.2128.36662:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techradar_news_project:techradar_news:1::~~~android~~`,
        fs:  `cpe:2.3:h:apple:apple_airport_base_station_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_relay:6.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_relay:6.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_relay:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:term_merge_project:term_merge:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_relay:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_relay:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:1.0`,
        fs:  `cpe:2.3:a:oracle:database_server:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:1.0.1`,
        fs:  `cpe:2.3:a:novell:iprint:5.90:-:*:*:*:windows_vista:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:1.1`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:1.1.1`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.0`,
        fs:  `cpe:2.3:a:otrs:faq:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.0.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.0.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.0.4`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.0.5`,
        fs:  `cpe:2.3:a:rakus:maildealer:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.1.0`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.1.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:222:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:2.1.2`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.2.2:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:3.0.0`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:3.0.1`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:3.0.2`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:3.1.0`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:3.1.1`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:3.1.2`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:4.0.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:4.0.1`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:4.0.2`,
        fs:  `cpe:2.3:a:apache:tomcat_jk_web_server_connector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:5.0.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_23:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:5.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.236:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:5.0.2`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:5.1.0`,
        fs:  `cpe:2.3:a:gnu:chess:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:6.0.0`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:6.0.1`,
        fs:  `cpe:2.3:a:docker:docker:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:6.0.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:6.0.3`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:7.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.4-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:7.0.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:7.1.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd370a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:camtasia_studio:7.1.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:1.0`,
        fs:  `cpe:2.3:a:symantec:on-demand_protection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:1.6.1`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:2.0.2`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:2.1`,
        fs:  `cpe:2.3:h:nec:bluefire_ix1035_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:2.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:08-00-01:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:2.5`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.17:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:3.0`,
        fs:  `cpe:2.3:o:ibm:vios:1.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:3.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.5.0:rc.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:3.1.3`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:3.2`,
        fs:  `cpe:2.3:a:mylittleforum:my_little_forum:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:3.2.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:3.2.2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:3.2.3`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.30-76.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:3.2.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.0`,
        fs:  `cpe:2.3:a:plone:plone:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.0.1`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.1`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2.2:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.1.1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.2.1`,
        fs:  `cpe:2.3:a:google:chrome:10.0.644.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.2.2`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:12.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.2.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.347:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.3`,
        fs:  `cpe:2.3:a:microsoft:orca:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.3.1`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.3.2`,
        fs:  `cpe:2.3:a:schneider-electric:somove:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.3.3`,
        fs:  `cpe:2.3:a:vips:vips:7.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.3.5`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:4.3.6`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:5.0`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:5.1`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:5.1.1`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:5.2`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:5.2.1`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:5.2.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.0`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.0.1`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.0.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.1`,
        fs:  `cpe:2.3:a:microsoft:directx:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.1.1`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.1.2`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.1.3`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.2`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.2.1`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.2.2`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20091009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:6.3`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.0`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.0.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.0.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.0.3`,
        fs:  `cpe:2.3:o:yahama:rt140p:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.1`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.72.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.1.1`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.1.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.290.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.2.1`,
        fs:  `cpe:2.3:a:vips:vips:7.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.2.2`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.2.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.2.4`,
        fs:  `cpe:2.3:h:hp:cp1160_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:7.2.5`,
        fs:  `cpe:2.3:a:keepass:keepass:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.11:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.0.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.0.2`,
        fs:  `cpe:2.3:h:yokogawa:exaquantum:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.1.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.12:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.2.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.2.1`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.2.2`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.12:ga13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:8.2.3`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.0`,
        fs:  `cpe:2.3:a:reviewboard:review_board:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.0.1`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.0.2`,
        fs:  `cpe:2.3:a:alkacon:opencms:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.1`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(13a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.1.0`,
        fs:  `cpe:2.3:a:simon_rycroft:hashcash:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.1.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd325a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.1.1.261`,
        fs:  `cpe:2.3:h:iij:seil\/x86:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.1.2`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.2.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.1.3`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:9.1.3.19`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:10.0.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:techsmith:snagit:10.0.1`,
        fs:  `cpe:2.3:a:lxml:lxml:2.3:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.000`,
        fs:  `cpe:2.3:a:sun:jre:6.0.130:update13:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.001`,
        fs:  `cpe:2.3:a:emc:vplex_geosynchrony:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.002`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yw:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.003`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.004`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:6.2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.005`,
        fs:  `cpe:2.3:a:symantec:netbackup_server:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.006`,
        fs:  `cpe:2.3:a:oracle:jai:1.1.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.007`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.008`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.009`,
        fs:  `cpe:2.3:a:cmsproducts:bounceback_ultimate:9.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.010`,
        fs:  `cpe:2.3:a:xchat:xchat:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.011`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.00.492:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.012`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:10.1.013`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.2:a:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.000`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(3b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.001`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.002`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.003`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.004`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.184:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.005`,
        fs:  `cpe:2.3:a:abbyy:finereader_sprint:6.0.1990.41618:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.006`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.007`,
        fs:  `cpe:2.3:a:isc:bind:4.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.008`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:9.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.009`,
        fs:  `cpe:2.3:o:qnap:qts:4.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.010`,
        fs:  `cpe:2.3:a:ca:etrust_ez_armor:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.011`,
        fs:  `cpe:2.3:a:hp:webproxy:a.02.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.012`,
        fs:  `cpe:2.3:a:drupal:drupal:7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.013`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.014`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.015`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.0.016`,
        fs:  `cpe:2.3:a:google:v8:3.24.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.000`,
        fs:  `cpe:2.3:a:citrix:netscaler:8.0_build_47.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.001`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.002`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.003`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.004`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.30:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.005`,
        fs:  `cpe:2.3:a:steven_jones:context:6.x-2.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.006`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.007`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.008`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.8:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.009`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.010`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.011`,
        fs:  `cpe:2.3:a:john_koleszar:libvpx:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.012`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.013`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.014`,
        fs:  `cpe:2.3:a:freetype:freetype:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.015`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.016`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.017`,
        fs:  `cpe:2.3:h:hp:officejet_4100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.018`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:9.1.603.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.019`,
        fs:  `cpe:2.3:a:gnome:glib:2.19.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.020`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:20.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.021`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.29.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.022`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20120731:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.023`,
        fs:  `cpe:2.3:a:canonical:telepathy-idle:0.1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.024`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.025`,
        fs:  `cpe:2.3:a:status:statusnet:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.026`,
        fs:  `cpe:2.3:h:juniper:srx3400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.027`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:beta0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.028`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.029`,
        fs:  `cpe:2.3:o:bluecoat:avos:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.030`,
        fs:  `cpe:2.3:h:f5:big-ip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.1.031`,
        fs:  `cpe:2.3:a:vmware:vmci_sockets:9.1.54.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.000`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.587:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.001`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.002`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.003`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.004`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.005`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.006`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.007`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.008`,
        fs:  `cpe:2.3:a:microsoft:project:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.010`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.011`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.012`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.013`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.014`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.015`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.016`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.017`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.018`,
        fs:  `cpe:2.3:h:softbank:sharp_3g_handset:940sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.020`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3r6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.021`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.022`,
        fs:  `cpe:2.3:a:mathijs_koenraadt:search_api_sorts:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.023`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.025`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.026`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.027`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d75:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.028`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.3.254:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.029`,
        fs:  `cpe:2.3:a:nuance:paperport:10.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.030`,
        fs:  `cpe:2.3:a:news_project:news:3.5.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.031`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.2.032`,
        fs:  `cpe:2.3:a:skype:skype:1.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.000`,
        fs:  `cpe:2.3:a:google:chrome:12.0.738.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.001`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.002`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1683.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.003`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11_build_6.0.14.748:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.004`,
        fs:  `cpe:2.3:a:microsoft:biztalk_srv:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.005`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.006`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.007`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_sp_isp:1.23.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.008`,
        fs:  `cpe:2.3:a:ibm:emptoris_contract_management:10.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecnick:tcexam:11.3.009`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_client:06-00-\/i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecolote:acdbdotnet:1.0.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecolote:aceit:7.1.82`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecolote:aceit:7.2.50`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecolote:aceit:7.2.51`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecolote:aceit:7.3.54`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tecorange:simple_e-document:1.31`,
        fs:  `cpe:2.3:a:github:gaug.es:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tecvoz:cmnc-200:-`,
        fs:  `cpe:2.3:a:videowhisper:live_streaming_integration_plugin:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.0`,
        fs:  `cpe:2.3:a:ca:enterprise_common_services:8.2.9.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.1`,
        fs:  `cpe:2.3:a:isc:bind:4.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.2`,
        fs:  `cpe:2.3:a:avaya:aura_application_server_5300:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.3`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.7`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.8`,
        fs:  `cpe:2.3:a:perl:perl:5.13.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.9`,
        fs:  `cpe:2.3:a:digium:asterisk:10.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.10`,
        fs:  `cpe:2.3:a:x.org:x11:6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.11`,
        fs:  `cpe:2.3:h:hp:laserjet_m3035_mfp:cb414a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.12`,
        fs:  `cpe:2.3:a:sambar:sambar_server:5.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.13`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050613:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.14`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.15`,
        fs:  `cpe:2.3:a:freedesktop:udisks:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tedfelix:acpid2:2.0.16`,
        fs:  `cpe:2.3:a:salome-platform:salome:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teeworlds:teeworlds:6.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teeworlds:teeworlds:6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teeworlds:teeworlds:6.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.0\(1e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:1.6`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:1.8`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.3.0`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-282:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.3.1`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.29.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.3.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.3.4`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4`,
        fs:  `cpe:2.3:a:google:chrome:16.0.901.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.0`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1\(2\)es33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.1`,
        fs:  `cpe:2.3:a:scilab:scilab:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.2`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.3`,
        fs:  `cpe:2.3:a:femanager_project:femanager:1.0.7:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.4`,
        fs:  `cpe:2.3:a:scalix:web_access:11.4.6.12377:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.5`,
        fs:  `cpe:2.3:a:mit:kerberos:5_1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.6`,
        fs:  `cpe:2.3:a:huawei:espace_7950:v200r002c00spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.7`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.8`,
        fs:  `cpe:2.3:h:ibm:system_x3200_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.4.8.1`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.5.0`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.5.1`,
        fs:  `cpe:2.3:a:ibm:spss_analytic_server:1.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.5.2`,
        fs:  `cpe:2.3:h:supermicro:h8sml-7f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.5.3`,
        fs:  `cpe:2.3:a:canonical:telepathy-idle:0.1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.5.4`,
        fs:  `cpe:2.3:o:cisco:ios:11.2\(8\)sa3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.5.5`,
        fs:  `cpe:2.3:h:hp:trucluster_server:5.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.5.6`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.5.8`,
        fs:  `cpe:2.3:a:kalahari:kalahari.com_shopping:1.4.2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.0`,
        fs:  `cpe:2.3:a:oracle:collaboration_suite:10.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.0:rc2`,
        fs:  `cpe:2.3:a:corel:corelcad:2014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.0:rc2.1`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.1`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf431c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.3`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.4`,
        fs:  `cpe:2.3:o:ibm:security_network_protection_firmware:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.5`,
        fs:  `cpe:2.3:a:telos:amhs:11.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.6`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.6.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.6.2`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.7`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.8`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultracompare:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.9`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:3.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.10`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.11`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.3sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.6.11.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.7.0`,
        fs:  `cpe:2.3:a:social_stats_project:social_stats:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.7.1`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.7.2`,
        fs:  `cpe:2.3:a:hp:centralview_roaming_fraud_control:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.7.3`,
        fs:  `cpe:2.3:a:apache:derby:10.13.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.7.4`,
        fs:  `cpe:2.3:a:novell:zenworks_handheld_management:7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.0:beta4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.53:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.0:beta5`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp4:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.0:beta6`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.4sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.0:beta7`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.0:beta8`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.0:rc1`,
        fs:  `cpe:2.3:a:kennziffer:ke_search:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.0:rc2`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.1`,
        fs:  `cpe:2.3:a:schneider-electric:citectscada:7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.2`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.07.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.4`,
        fs:  `cpe:2.3:o:cisco:vpn_3080_concentrator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.5`,
        fs:  `cpe:2.3:a:php:pear:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.6`,
        fs:  `cpe:2.3:o:ge:snmp\/web_adapter_firmware:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.7`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(4a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.8`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2016:cumulative_update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.9`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.9.1`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.10`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.10.1`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.0:rc1.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.8.11`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.9.1`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_hp:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.9.2`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0:feature_pack_8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.0`,
        fs:  `cpe:2.3:a:dlc_solutions:course:6.x-1.0-rc5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.0:alpha1`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.0:alpha2`,
        fs:  `cpe:2.3:a:dymo:rhino_connect_software:1.3.0.242:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.0:beta1`,
        fs:  `cpe:2.3:a:logitech:camerahelpermsi:13.0.1774.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.0:beta2`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.0:rc1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.0:rc2`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.1`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:001ht:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.2`,
        fs:  `cpe:2.3:a:tribulant:tibulant_slideshow_gallery:1.4.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.3`,
        fs:  `cpe:2.3:a:citrix:receiver:13.0.0.6684:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.4`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.4.1`,
        fs:  `cpe:2.3:a:oracle:developer_suite:9.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.4.2`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.3:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.5`,
        fs:  `cpe:2.3:a:google:chrome:4.0.222.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.7`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.8`,
        fs:  `cpe:2.3:a:oracle:ireceivables:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.9`,
        fs:  `cpe:2.3:a:ibm:tivoli_business_systems_manager:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.10`,
        fs:  `cpe:2.3:a:convergine:file_king_advanced_file_management:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.11`,
        fs:  `cpe:2.3:a:alephsystem:cms_ariadna:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.12`,
        fs:  `cpe:2.3:a:xhanch:my_twitter:2.6.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.13`,
        fs:  `cpe:2.3:a:redhat:jboss_web_framework_kit:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.10.13.1`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:r55w:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.2`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd972a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.3`,
        fs:  `cpe:2.3:a:elinks:elinks:0.12:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.3.1`,
        fs:  `cpe:2.3:a:oracle:application_server:10.1.2.0.0:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.4`,
        fs:  `cpe:2.3:a:bestpractical:rtfm:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.5`,
        fs:  `cpe:2.3:h:cisco:nac_guest_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.5.1`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.6`,
        fs:  `cpe:2.3:h:cisco:ons_15310-cl_sonet_multiservice_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.11.7`,
        fs:  `cpe:2.3:a:ibm:infosphere_fasttrack:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.0`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta53:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.0:beta1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.0:beta2`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(3\)x1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.0:beta3`,
        fs:  `cpe:2.3:o:d-link:dap_1150_firmware:1.2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.0:rc1`,
        fs:  `cpe:2.3:o:cisco:staros:19.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.0:rc2`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.2`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.3`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.4`,
        fs:  `cpe:2.3:a:libssh:libssh:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.5`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.6`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.7`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p467:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.9`,
        fs:  `cpe:2.3:a:monotone:monotone:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.10`,
        fs:  `cpe:2.3:a:pfsense:snort_package:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.11`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.12`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.13`,
        fs:  `cpe:2.3:a:apple:safari:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.14`,
        fs:  `cpe:2.3:o:iij:seil\%2fx86_firmware:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.14.1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.15`,
        fs:  `cpe:2.3:a:apache:struts:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.16`,
        fs:  `cpe:2.3:a:automon:ledline.gr_official:1.4.0.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.17`,
        fs:  `cpe:2.3:a:novell:groupwise:8.02:hp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.17.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.12.18`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p170:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.0`,
        fs:  `cpe:2.3:a:redhat:tcpdump:3.4-39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.1`,
        fs:  `cpe:2.3:a:amebra_ameba_project:amebra_ameba:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.2`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.3`,
        fs:  `cpe:2.3:a:samba:samba:2.2.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:te4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.5`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.6`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.7`,
        fs:  `cpe:2.3:a:lucent:radius:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.13.8`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.0`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.4.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.0:beta1`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.10.102363.531:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.0:beta2`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.0:beta3`,
        fs:  `cpe:2.3:o:netbsd:netbsd:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.0:beta4`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.0:rc1`,
        fs:  `cpe:2.3:a:ibm:monitoring_agent_for_unix_logs:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.1`,
        fs:  `cpe:2.3:a:rakus:maildealer:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.1.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.9:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.2`,
        fs:  `cpe:2.3:h:hp:imaging_barcode_scanner_bw868aa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.2.1`,
        fs:  `cpe:2.3:a:apache:ignite:1.5.0:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.3`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.4`,
        fs:  `cpe:2.3:a:microsoft:office_2013_rt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.4.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.32:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:2.14.5`,
        fs:  `cpe:2.3:o:iij:seil_plus_firmware:1.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.0`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:8.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.0:alpha1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.0:alpha2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.0:alpha3`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.0b`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:12.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.1`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.2`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.4`,
        fs:  `cpe:2.3:a:analogx:simpleserver_www:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.5`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.6`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.0.6.1`,
        fs:  `cpe:2.3:a:ibm:spss_modeler:14.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.1.0`,
        fs:  `cpe:2.3:a:acmailer:acmailer:3.9.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.1.1`,
        fs:  `cpe:2.3:a:impliedbydesign:navigate:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.1.2`,
        fs:  `cpe:2.3:a:webform_project:webform:7.x-4.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.1.3`,
        fs:  `cpe:2.3:a:sap:xi_3.1_integration_for_sap_solutions_applications:12.3.5.925:fp_3.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.1.3.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.1.4`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:9.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.1.5`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.2:rc1`,
        fs:  `cpe:2.3:a:apache:camel:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.2.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.2.1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.2.2`,
        fs:  `cpe:2.3:a:claroline:claroline:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.2.2.1`,
        fs:  `cpe:2.3:a:aol:email_toolbar:5.22.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.2.3`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.2b`,
        fs:  `cpe:2.3:h:netscout:ngenius_express_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.3.0`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.39:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.3.2`,
        fs:  `cpe:2.3:o:mozilla:firefox_os:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4:rc1`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:4.1\(3\)sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.0.1`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.1.1`,
        fs:  `cpe:2.3:h:dell:latitude_e6420_atg:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.3`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.4`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.51:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.4.1`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.7.0:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.5`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.6`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.6.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.6.2`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.7`,
        fs:  `cpe:2.3:a:phppgadmin_project:phppgadmin:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.9`,
        fs:  `cpe:2.3:h:enterasys:xsr-3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.9.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.9.2`,
        fs:  `cpe:2.3:a:opnet:sp_guru_network_planner_documentation:16.0.0.10106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.10`,
        fs:  `cpe:2.3:a:kent-web:post-mail:6.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.11`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.11.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.266:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.12`,
        fs:  `cpe:2.3:h:cisco:nexus_2232pp_fex_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.12.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zd3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.13`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.8.4\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.14`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.14.1`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:20.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.15`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.3.248:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.15.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.16`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.17`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.18`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_pro:2.07.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.19`,
        fs:  `cpe:2.3:a:pcre:pcre:8.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.21`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4.21.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)bc1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.4b`,
        fs:  `cpe:2.3:a:altiris:audit_integration_component:6.2.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.5.0`,
        fs:  `cpe:2.3:o:cisco:catos:5.1\(2a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.0`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.1`,
        fs:  `cpe:2.3:a:google:android_sdk_platform_tools:18.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.2`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.3`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:6.1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.4`,
        fs:  `cpe:2.3:a:cyberlink:streamauthor:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)jn1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.7`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.8`,
        fs:  `cpe:2.3:o:hp:zbook_firmware:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.9`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp4:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.9.1`,
        fs:  `cpe:2.3:a:hp:hpf_productcontext:60.0.196.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.6.13`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.0`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:2008.3:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.1`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.2`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.3`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.4`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.5`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.5.1`,
        fs:  `cpe:2.3:o:hp:1000_series_firmware:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.6`,
        fs:  `cpe:2.3:a:cisco:unified_videoconferencing:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejimaya:openpne:3.8.9`,
        fs:  `cpe:2.3:a:gnu:glibc:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejonstore:dieta_dukan_passo_a_passo:1::~~~android~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tejonstore:secretos_de_belleza:1::~~~android~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tek:phaser_network_printer_740:-`,
        fs:  `cpe:2.3:a:henri_wahl:nagstamon:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tek:phaser_network_printer_750:-`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tek:phaser_network_printer_750dp:-`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tek:phaser_network_printer_840:-`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tek:phaser_network_printer_930:-`,
        fs:  `cpe:2.3:a:commpower:xml_portal:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tek:phaserlink:-`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teklynx:codesoft:7.10.100::~~special_edition~~~`,
        fs:  `cpe:2.3:a:ca:web_agents:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teklynx:label_matrix:8.60.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teklynx:labelview:8.20.1`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tekno_apsis_project:tekno_apsis:2.4::~~~android~~`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp6:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teknopoint:a_king_sperm_by_dr._seema_rao:0.63.13384.23020::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tektite:turbo_river_racing_free:1.07::~~~android~~`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.5.5`,
        fs:  `cpe:2.3:a:veritas:volume_manager_services_provider:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.5.6`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.5.6.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.6.0`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.6.1`,
        fs:  `cpe:2.3:a:apache:qpid:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.6.2`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.6.2.1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.6.3`,
        fs:  `cpe:2.3:o:cisco:staros:15.0\(935\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.6.4`,
        fs:  `cpe:2.3:a:websense:enterprise:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.6.5`,
        fs:  `cpe:2.3:a:t1lib:t1lib:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.7.0`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.7.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.dataannotations:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.7.2`,
        fs:  `cpe:2.3:a:novell:identity_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.0`,
        fs:  `cpe:2.3:a:isc:bind:9.2.4:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.7:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.1.1`,
        fs:  `cpe:2.3:a:acme:thttpd:2.21:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.2`,
        fs:  `cpe:2.3:h:supermicro:x9scl\&#43;-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.2.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.2.2`,
        fs:  `cpe:2.3:a:hp:database_and_middleware_automation:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.2.3`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_web_premium:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.2.4`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telaxus:epesi:1.8.2.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telelogic:doors:-`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telelogic:doors:8`,
        fs:  `cpe:2.3:h:hp:jc072b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telelogic:telelogic_license_server:1.0.0`,
        fs:  `cpe:2.3:a:avira:premium_security_suite:10.0.0.536:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telelogic:telelogic_license_server:1.3.0`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7700:1.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telenavsoftware:autonavi:4.6.1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telerik:analytics_monitor_library:3.2.122`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telerik:asp.net_ajax_radeditor_control:2009.3.1208.20`,
        fs:  `cpe:2.3:a:privatemsg_project:privatemsg:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telerik:asp.net_ajax_radeditor_control:2014.1.403.35`,
        fs:  `cpe:2.3:a:git-scm:git:2.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telerik:ui_for_asp.net_ajax:2014.3.1209`,
        fs:  `cpe:2.3:a:python:python:2.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telligent:evolution:6.1.19`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telligent:evolution:6.1.19.36103`,
        fs:  `cpe:2.3:a:civicrm:civicrm_private_report:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:telligent:evolution:7.1.12`,
        fs:  `cpe:2.3:a:gnome:evolution:2.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telligent:evolution:7.1.12.36162`,
        fs:  `cpe:2.3:a:bioinformatics:htmlawed:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telligent:evolution:7.5.0`,
        fs:  `cpe:2.3:a:testinside:testinside_640-802:ver_17.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telligent:evolution:7.5.0.32466`,
        fs:  `cpe:2.3:a:horde:groupware:1.1.1:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telligent:evolution:7.6.7`,
        fs:  `cpe:2.3:a:ibm:iss_blackice_server_protection:3.5:cdf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telligent:evolution:7.6.7.36651`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telly:telly-watch_the_good_stuff:2.5.1::~~~android~~`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:11.3.0.8`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:11.4.0.7`,
        fs:  `cpe:2.3:a:php:php:5.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:11.4.0.8`,
        fs:  `cpe:2.3:a:apache:camel:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:11.5.5.3`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:12.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:11.6.0.8`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:12.2.0.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je025a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:12.3.0.8`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.1:sp10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:12.4.0.25`,
        fs:  `cpe:2.3:a:php-proxima:php-proxima:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:12.7.0.15`,
        fs:  `cpe:2.3:a:citrix:xenapp_server_configuration_tool:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:12.8.0.8`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.6.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:12.9.0.10`,
        fs:  `cpe:2.3:a:ibm:spss_statistics:20.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:12.10.0.21`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:12.11.0.9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs:13.1.0.550`,
        fs:  `cpe:2.3:a:packagekit_project:packagekit:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs_activex_cab_update:1.0.0.3`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs_activex_spell_checker:1.0`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.6.120.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs_data:10.11.2.7`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:amhs_data:11.3.0.8`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:pump_dms_xml:5.1.0`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.8.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:xacta_assessment_engine:-`,
        fs:  `cpe:2.3:h:hp:jg555a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:xacta_asset_manager:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.372:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:xacta_automated_messaging_handling_system:-`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.27-76.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:xacta_detect_server:-`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:telos:xacta_hostinfo:-`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.10.1\(43\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:4.4.1.15078::~~~~x64~`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:5.2.0`,
        fs:  `cpe:2.3:o:d-link:dsr-250_firmware:1.05b53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:5.2.1`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:5.2.2`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:5.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:5.2.3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:5.2.4`,
        fs:  `cpe:2.3:a:doryphores:audio_player:2.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:5.2.5`,
        fs:  `cpe:2.3:a:debian:apt:0.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:5.2.6`,
        fs:  `cpe:2.3:a:iomega:hotburn:2.5.1:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:5.2.7`,
        fs:  `cpe:2.3:a:redhat:rhel_application_server:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.0.0`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.0.1`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_controller_firmware:17.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.0.2`,
        fs:  `cpe:2.3:o:sharp:aquos_hn-pp150_firmware:1.04.00.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.1.0`,
        fs:  `cpe:2.3:a:st:accelerometerp11:2.0.10.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.1.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.222.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.1.2`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.2.0`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.0:ea1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.2.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_asset_management_for_it:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.3.0`,
        fs:  `cpe:2.3:a:script-shop24:lm_starmail_paidmail:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.3.1`,
        fs:  `cpe:2.3:o:rim:blackberry_playbook_os:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.3.2`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.0.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.3.3`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.3.4`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_4f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.3.5`,
        fs:  `cpe:2.3:a:collabnet:scrumworks:5.1:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.3.6`,
        fs:  `cpe:2.3:o:suse:suse_linux:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.3.7`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.4.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.4.1`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.4.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.4.3`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.5.0`,
        fs:  `cpe:2.3:a:hp:c6100_help:70.0.231.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.5.1`,
        fs:  `cpe:2.3:a:razorcms:razorcms:1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.5.2`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.5.3`,
        fs:  `cpe:2.3:a:apache:axis:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.5.4`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.018:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.5.5`,
        fs:  `cpe:2.3:a:smartypantsplugins:wp-funeral-press:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.5.6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.6.0`,
        fs:  `cpe:2.3:a:gnu:groff:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.6.2`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)gc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.7`,
        fs:  `cpe:2.3:a:rack_project:rack:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.7.0`,
        fs:  `cpe:2.3:a:certblaster:certblaster_comptia_security:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.8`,
        fs:  `cpe:2.3:a:adobe:fireworks_cs3:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.8.0`,
        fs:  `cpe:2.3:a:novell:sentinel_log_manager:1.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.8.2`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.9`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.113.2221.40119:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.9.0`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.9.1`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.9.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.3.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.9.3`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.10.0`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.10.2`,
        fs:  `cpe:2.3:a:m2osw:tableofcontents:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.10.3`,
        fs:  `cpe:2.3:a:ca:unicenter_software_delivery:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.10.5`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.10.6`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.10.7`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_hosted:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:nessus:6.10.8`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:plugin-set:201402092115`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:plugin-set:201402262215`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:securitycenter:4.6`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs5:12.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:securitycenter:4.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p210:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:web_ui:2.3.3`,
        fs:  `cpe:2.3:a:nero:mediahome:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:web_ui:2.3.4`,
        fs:  `cpe:2.3:a:ca:unicenter_application_performance_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenable:web_ui:2.3.5`,
        fs:  `cpe:2.3:a:busybox:busybox:1.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tenda:a5s:-`,
        fs:  `cpe:2.3:a:alcatel-lucent:omnitouch_8670_automated_delivery_message_delivery_system:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tenda:a5s_firmware:3.02.05_cn`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tenda:n3_wireless_n150:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenfourzero:shutter:0.1.4`,
        fs:  `cpe:2.3:a:nttdocomo:spmode_mail_android:4500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenmiles:helpdesk_pilot:-`,
        fs:  `cpe:2.3:a:pinnaclesys:studio:11.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenmiles:helpdesk_pilot:5.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenon:itools:8.0.5`,
        fs:  `cpe:2.3:a:nortel:meridian_mail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenon:itools:8.2.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2010.302.2233.40412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tenon:itools:8.2.4`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router_firmware:1.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tequilagames:battlefriends_at_sea_gold:1.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:nikola_posa:webfoliocms1.1.4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tera-charts_project:tera-charts:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tera_charts_plugin_project:tera-charts:0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tera_charts_plugin_project:tera-charts:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:teracom:t2-b-gawv1.4u10y-bi:-`,
        fs:  `cpe:2.3:a:supmua:sup:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:.net_data_provider:13.1.0.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:.net_data_provider:13.10.0.0`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.3.3:rev39177:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:administrator:6.0`,
        fs:  `cpe:2.3:a:cubecart:cubecart:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:administrator:7.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:administrator:12.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:administrator:13.10.0.2`,
        fs:  `cpe:2.3:a:haxx:curl:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:administrator:13.10.0.3`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:bootdiskmon:2.7.0.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.15.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:bteq:12.0`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.54:bpet54v:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:bteq:12.0.0.4`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:bteq:12.0.0.6`,
        fs:  `cpe:2.3:a:nagios:nagios:4.0.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:bteq:13.10.0.1`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:bteq:13.10.0.6`,
        fs:  `cpe:2.3:a:cisco:meeting_server:1.8_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:c_pp2:8.0`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:data_connector:12.0`,
        fs:  `cpe:2.3:a:apache:rave:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:data_connector:12.0.0.2`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:data_connector:13.10.0.2`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:data_connector:13.10.0.5`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:14.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:decision_expert_administrator:12.1`,
        fs:  `cpe:2.3:a:cooperindustries:dnp3_master_opc_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:dssp:7.1.1.1`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.03.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:dynamic_workload_manager:6.1`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:dynamic_workload_manager:12.0`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:-:opscenter:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:fastexport:12.0`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:fastexport:12.0.0.8`,
        fs:  `cpe:2.3:a:phplist:phplist:2.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:fastexport:13.10.0.3`,
        fs:  `cpe:2.3:a:skyarc:authoreffective:1.031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:fastexport:13.10.0.10`,
        fs:  `cpe:2.3:a:sap:hybris:5.3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:fastload:12.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:fastload:12.0.0.10`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:fastload:13.10.0.3`,
        fs:  `cpe:2.3:a:openbsd:opensmtpd:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:fastload:13.10.0.9`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.3\(106.146\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:gsctools:9.9.18`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:b.01.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:index_wizard:12.0`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:index_wizard:13.0.0.4`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.47.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:index_wizard:13.10.0.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:manager:12.0`,
        fs:  `cpe:2.3:a:milesj:decoda:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:multiload:12.0`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:multiload:12.0.0.6`,
        fs:  `cpe:2.3:a:erlang:crypto:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:multiload:13.10.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.0-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:multiload:13.10.0.6`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:named_pipes_access_module:1.5`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:2000:sp3a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:named_pipes_access_module:12.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.00c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:named_pipes_access_module:13.10.0.3`,
        fs:  `cpe:2.3:a:rack_project:rack:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:ole_db_access_module:12.0.0.0`,
        fs:  `cpe:2.3:o:mozilla:firefoxos:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:pci_configurator:1.2.1.0`,
        fs:  `cpe:2.3:a:citrix:management_console_for_metaframe_presentation_server:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:performance_monitor:12.0`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:putjre:1.4.2.13`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.2.2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:putsrc:3.5.2.14a`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:puttools:1.2.0.5`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:shared_icu_libraries:0.0.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:shared_icu_libraries:0.2`,
        fs:  `cpe:2.3:a:cybozu:office:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:shared_icu_libraries:1.1`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:shared_icu_libraries:12.0.0.0`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:shared_icu_libraries:12.0.0.2`,
        fs:  `cpe:2.3:a:vmware:workstation:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:sm3g_open:1.1.0.2`,
        fs:  `cpe:2.3:o:ibm:aix:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:sql_assistant:6.1`,
        fs:  `cpe:2.3:a:intergraph:funding_initiation_tool:1.5.28.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:sql_assistant:7.0`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:sql_assistant:12.0`,
        fs:  `cpe:2.3:a:apache:tomcat:9.0.0:m15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:sql_assistant:12.0::~~web~~~`,
        fs:  `cpe:2.3:h:cisco:nexus_3064x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:sql_assistant:12.0.0.10`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:sql_assistant:12.0.0.13`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.326:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:sql_assistant:13.10.0.7`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.1:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:statistics_wizard:12.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:statistics_wizard:13.0.0.5`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:2.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:statistics_wizard:13.10.0.3`,
        fs:  `cpe:2.3:a:ains:foiaxpress:6.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:system_emulation_tool:12.0`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:system_emulation_tool:13.10.0.5`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:11.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:tdput:3.5.1.14`,
        fs:  `cpe:2.3:h:nortel:ethernet_routing_switch_1624:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:tdput:3.5.2.14`,
        fs:  `cpe:2.3:a:ca:unicenter_asset_management:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:teradata_manager:12.0`,
        fs:  `cpe:2.3:a:services_project:services:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:teradata_manager:13.0.0.12`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:tpump:12.0`,
        fs:  `cpe:2.3:h:rockwellautomation:controllogix_5560_redundant_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:tpump:12.0.0.9`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.2:2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:tpump:13.10.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:tpump:13.10.0.7`,
        fs:  `cpe:2.3:a:vmware:movie_decoder:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:tvi-proxy:7.0.5.0`,
        fs:  `cpe:2.3:a:intel:2200bg_proset_wireless:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:tvi-proxy:7.0.6.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:visual_explain:12.0`,
        fs:  `cpe:2.3:h:asus:rt-n10e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:visual_explain:13.0.0.7`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:visual_explain:13.10.0.5`,
        fs:  `cpe:2.3:a:busybox:busybox:0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:wincli_developer%27s_kit:3.2.9`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:wintools:2.5.0.0`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.05.0290:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:wintools:2.6.0.0`,
        fs:  `cpe:2.3:a:adobe:premiere_elements:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:workload_analyzer:12.0`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradata:workload_analyzer:13.10.0.4`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:teradici:pcoip_host_software:3.3.20`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.0:beta17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:term_merge_project:term_merge:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.0:pre.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:term_queue_project:term_queue:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:terragotech:geopdf_toolbar:4.1.208`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:terrarienbilder:terrarienbilder.com_forum:3.8.20::~~~android~~`,
        fs:  `cpe:2.3:a:digineo:thumbshooter:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tesla:gateway_ecu:-`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:testa:online_test_management_system:2.0.0.1`,
        fs:  `cpe:2.3:o:sun:solaris:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:testa:online_test_management_system:2.0.0.2`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:testinside:testinside_640-802:ver_17.11`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.4:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:testout_corporation:labsim:3.1.57`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.5:sr_3.10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texasweddingmall:villa_antonia:1::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.24:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.0.17`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.0:*:*:*:light:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.1`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.2`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.2:r3`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3:r2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.1`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.1:r2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.1:r3`,
        fs:  `cpe:2.3:h:buffalotech:whr-300hp2_firmware:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.3`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.4`,
        fs:  `cpe:2.3:a:apple:safari:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.5`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.7`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.8`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.9`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:20.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.10`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.3.11`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4:r2`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4:r3`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4.1`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.8.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4.3`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4.5`,
        fs:  `cpe:2.3:a:opentext:enterprise_library_enterprise_server:9.7.1.313:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4.6`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.4.7`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5`,
        fs:  `cpe:2.3:a:microsoft:sna_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.73.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.2`,
        fs:  `cpe:2.3:o:corega:cg-wlbargmh_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.3`,
        fs:  `cpe:2.3:h:hp:5_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.4`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.5`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.6`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.7`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.8`,
        fs:  `cpe:2.3:a:apache:derby:10.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.9`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2000:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.10`,
        fs:  `cpe:2.3:o:yamaha:rt250i:8.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.11`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20140102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.11:r2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.5.12`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.9.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.1`,
        fs:  `cpe:2.3:a:horde:internet_mail_program:6.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.2`,
        fs:  `cpe:2.3:a:nttdata:terasoluna_server_framework_for_java_web:2.0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.3`,
        fs:  `cpe:2.3:a:citadel:ux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.4:r2`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4501_series_software:4.3\(1.68\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.7`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.8`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.10`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.11`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.5.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.12`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.14`,
        fs:  `cpe:2.3:a:rapidleech:rapidleech:2.3:rev42_svn_r399:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.6.15`,
        fs:  `cpe:2.3:a:ettercap_project:ettercap:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.7.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.319:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.7.2`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.7.3`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.14.3.901:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.7.4`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.7.5`,
        fs:  `cpe:2.3:a:ibm:db2:9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:texmacs:texmacs:1.0.7.6`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textangular:textangular:1.3.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:1.0:rc1`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:1.0:rc4`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:1.0:rc5`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.0`,
        fs:  `cpe:2.3:a:sun:java_web_start:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.1`,
        fs:  `cpe:2.3:h:yokogawa:centum_cs_3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.3`,
        fs:  `cpe:2.3:o:asus:rt_series_firmware:3.0.0.4.374.x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.4`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.5`,
        fs:  `cpe:2.3:a:cubecart:cubecart:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.6`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.7`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.0.8`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:textpattern:textpattern:4.2.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_light:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tforum:tforum:b0.915`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tgrmn:viceversa:2.0.0.9::~~professional~~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:th3professional:th3_professional_al_mohtarif:1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:rational_license_server_tl:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thailand_investor_news_project:thailand_investor_news:1.39s::~~~android~~`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thalesgroup:datacryptor_element_manager:4.4.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.1`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.2`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.3`,
        fs:  `cpe:2.3:h:iomega:cd-rw_52x24x52_usb:2.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.4`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.6.3\(113\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.5`,
        fs:  `cpe:2.3:a:alvaro_herrera:pl\/php:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.6`,
        fs:  `cpe:2.3:a:keepass:keepass:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.7`,
        fs:  `cpe:2.3:a:frontaccounting:frontaccounting:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.8`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.0.9`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp5:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.0`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.9.3:p383:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.1`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.2:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.3`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.6.2084.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.5`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.7`,
        fs:  `cpe:2.3:o:juniper:junos:13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.7.1`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.7.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_server_software:3.0\(2.24\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.7.3`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.7.4`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.8`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.8.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.9`,
        fs:  `cpe:2.3:o:compaq:tru64:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.9.1`,
        fs:  `cpe:2.3:a:codiad:codiad:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.1.9.2`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.2.0`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.2.1`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.2.2`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.2.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.5.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.2.4`,
        fs:  `cpe:2.3:a:alquimia:managesite:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.2.5`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:10.1.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress:1.2.5.1`,
        fs:  `cpe:2.3:a:plume-cms:plume_cms:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecartpress:thecartpress_ecommerce_shopping_cart:1.3.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.11.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thecleanerapp:the_cleaner_-_speed_up_%26_clean:1.4.2::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:thecus:n8800_nas_server:-`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.6.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:thecus:n8800_nas_server_firmware:5.03.01`,
        fs:  `cpe:2.3:a:docker:docker:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thedevildoggamer_project:thedevildoggamer:1::~~~android~~`,
        fs:  `cpe:2.3:a:magzter:sanctuary_asia:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:thedigitalcraft:atomcms:2.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theflip:flipshare:5.0.5.52727`,
        fs:  `cpe:2.3:a:php:php:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:0.1`,
        fs:  `cpe:2.3:a:debian:unp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:0.2`,
        fs:  `cpe:2.3:a:metalgenix:genixcms:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:0.3`,
        fs:  `cpe:2.3:a:unisys:enterprise_output_manager_client:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:0.4`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:0.4.1`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.0`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.1`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.2.0`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.2.0:rc1`,
        fs:  `cpe:2.3:a:plainblack:webgui:7.10.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.2.0:rc2`,
        fs:  `cpe:2.3:a:apple:safari:3.1.2b:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.2.1`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.2.2`,
        fs:  `cpe:2.3:a:belarc:advisor:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.2.3`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.4.0`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.4.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.4.2`,
        fs:  `cpe:2.3:a:apple:quicktime:7.4.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.4.3`,
        fs:  `cpe:2.3:a:philips:xper_information_management_physiomonitoring_5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.4.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.4.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.5.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.5.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.5.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.6.0`,
        fs:  `cpe:2.3:a:7-zip:p7zip:4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.6.1`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.0\(5\)e2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.8.3`,
        fs:  `cpe:2.3:a:logosquest_-_beginnings_project:logosquest_-_beginnings:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.8.4`,
        fs:  `cpe:2.3:a:microsoft:word:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.9.0`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.9.1`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.9.2`,
        fs:  `cpe:2.3:a:apple:cups:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.9.3`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.10.1`,
        fs:  `cpe:2.3:a:google:v8:3.12.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.10.2`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.10.3`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.10.4`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.11.0`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.5_build_736:*:exchange:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.11.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.11.0:rc2`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.11.0:rc3`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.11.1`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.11.2`,
        fs:  `cpe:2.3:a:debian:netstd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.11.3`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf807a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.11.4`,
        fs:  `cpe:2.3:a:adobe:creative_suite_3_design_premium:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.12.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.12.1`,
        fs:  `cpe:2.3:a:foxitsoftware:reader:7.3.0.118:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.12.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.275.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.12.3`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.12.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.13.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.13.2`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.13.3`,
        fs:  `cpe:2.3:a:buffalotech:whr-amg54_firmware:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.13.4`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.14.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.14.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.14.3`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.15.1`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.15.2`,
        fs:  `cpe:2.3:a:adobe:creative_suite:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.15.3`,
        fs:  `cpe:2.3:a:vmware:workstation:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.15.4`,
        fs:  `cpe:2.3:a:kbs:weblygo:5.10:*:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:foreman:1.16.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg222a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-08-08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.3`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.4`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.5`,
        fs:  `cpe:2.3:h:milan:fastport_print_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.6`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.7`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.8`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:2007:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.9`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.10`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.11`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pa.03.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.12`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.13`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.14`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.20f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.15`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.16`,
        fs:  `cpe:2.3:a:skype:skype:0.91.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.0.17`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.358:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.1.0`,
        fs:  `cpe:2.3:a:dovecot:dovecot:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.2.0`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.11.263.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.2.1`,
        fs:  `cpe:2.3:a:apache:struts:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.2.2`,
        fs:  `cpe:2.3:a:wp_social_invitations_project:wp_social_invitations:1.4.4.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.0`,
        fs:  `cpe:2.3:a:cisco:firepower_management_center:5.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.1`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.2`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.3`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.30.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.5`,
        fs:  `cpe:2.3:a:quest:intrust_knowledge_pack_for_microsoft_sql_server:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.6`,
        fs:  `cpe:2.3:a:isc:bind:9.9.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.7`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.0:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.8`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.9`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.10`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.623:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.11`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_3_firmware:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.12`,
        fs:  `cpe:2.3:a:openbravo:openbravo_erp:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.13`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.14`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.15`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.20.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.16`,
        fs:  `cpe:2.3:a:redhat:libreport:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.3.17`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.4.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jpb1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.5.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.5.1`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.5.2`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.5.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theforeman:kafo:0.5.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegameboss:street_racing:4.0.4::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.2.2021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.2`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.3`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.4`,
        fs:  `cpe:2.3:a:mollify:mollify:1.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.5`,
        fs:  `cpe:2.3:a:avg:anti-virus:9.0:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.6`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.9.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.7`,
        fs:  `cpe:2.3:a:oracle:human_resources:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.8`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.3\(2\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.9`,
        fs:  `cpe:2.3:a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.9.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.10`,
        fs:  `cpe:2.3:o:yahama:rt102i:1.06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thegr:dl:0.10.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.4`,
        fs:  `cpe:2.3:a:bluecoat:director:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.5`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.6`,
        fs:  `cpe:2.3:a:hp:loadrunner:12.00:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.7`,
        fs:  `cpe:2.3:a:gnome:librsvg:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.95`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:fp3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.96`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.98`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.992`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:0.996`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.6:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.0`,
        fs:  `cpe:2.3:a:displaylink:displaylink_graphics:5.5.27358.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:4.00:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.3`,
        fs:  `cpe:2.3:a:infradead:openconnect:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.4`,
        fs:  `cpe:2.3:a:hp:centralized_management_console_software:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.16:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.6`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:184:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.7`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.8`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.9`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.10`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.17.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.12`,
        fs:  `cpe:2.3:a:joe_haskins:og_manager_change:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.13`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:4.0:r1e:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.14`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.15`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.16`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.17`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:1.18`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p471:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.1`,
        fs:  `cpe:2.3:a:microsoft:office_word_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.2`,
        fs:  `cpe:2.3:a:apache:cassandra:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.3`,
        fs:  `cpe:2.3:a:tibco:slingshot:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.4`,
        fs:  `cpe:2.3:h:hp:3com_switch:4510g_pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.5`,
        fs:  `cpe:2.3:a:php:php:5.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.6`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.7`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.8`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.9`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.10`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.11`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.12`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.4c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.13`,
        fs:  `cpe:2.3:a:tenable:nessus:4.4.1.15078:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.14`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.15`,
        fs:  `cpe:2.3:a:mcafee:hercules_administrator:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.16`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.17`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.18`,
        fs:  `cpe:2.3:a:oracle:jdk:1.8.0:update_77:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.19`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-1.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.20`,
        fs:  `cpe:2.3:a:bundler:bundler:1.12.0:rc.4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.21`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.22`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.23`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.24`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.25`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.26`,
        fs:  `cpe:2.3:a:mahara:mahara:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.27`,
        fs:  `cpe:2.3:a:piwik:piwik:0.6.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.28`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.29`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.30`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.31`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.33`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.34`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.35`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta52:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.36`,
        fs:  `cpe:2.3:a:filesanywhere:filesanywhere:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.37`,
        fs:  `cpe:2.3:a:realtek:realtek_ac\&#39;97_audio:5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.38`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.39`,
        fs:  `cpe:2.3:a:emc:vplex_geosynchrony:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.40`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:rc3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.41`,
        fs:  `cpe:2.3:a:trojita_project:trojita:0.2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.42`,
        fs:  `cpe:2.3:h:3com:3c17706-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.43`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2se.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.44`,
        fs:  `cpe:2.3:a:hp:smart_zero_core:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.45`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.46`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:8.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.47`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.48`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.49`,
        fs:  `cpe:2.3:a:invensys:wonderware_information_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.50`,
        fs:  `cpe:2.3:a:buffalotech:fs-g54_firmware:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.51`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.52`,
        fs:  `cpe:2.3:a:ubercart_views_project:uc_views:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.53`,
        fs:  `cpe:2.3:a:novell:bordermanager:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.54`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.55`,
        fs:  `cpe:2.3:a:rpm:rpm:4.5.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.56`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.57`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.58`,
        fs:  `cpe:2.3:a:intel:mscfg:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.59`,
        fs:  `cpe:2.3:a:psyced:psyced:20090323:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.60`,
        fs:  `cpe:2.3:a:md-systems:simplenews:7.x-1.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.61`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.62`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.63`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.64`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.164:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thekelleys:dnsmasq:2.65`,
        fs:  `cpe:2.3:h:hp:j8700a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:themebeans:blooog_theme:1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:rational_doors_next_generation:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:themelogik:cmslogik:1.2.0`,
        fs:  `cpe:2.3:o:qnap:ts-459u_firmware:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:themelogik:cmslogik:1.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:themepunch:showbiz_pro:1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redmine:redmine:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:themepunch:slider_revolution:3.0.95::~~~wordpress~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.14:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:themepunch:slider_revolution:4.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:themepunch:slider_revolution:4.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.07.15a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:theonegames:gunship_battle%3ahelicopter_3d:1.1.7::~~~android~~`,
        fs:  `cpe:2.3:a:steindom:contact_save:6.x-1.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thingslabo:things_bbs:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.14:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:5.x-0.1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:5.x-0.2`,
        fs:  `cpe:2.3:a:hp:destinations:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:5.x-0.3`,
        fs:  `cpe:2.3:a:google:v8:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:5.x-0.4`,
        fs:  `cpe:2.3:a:mutiny:standard:4.5-1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:5.x-1.0`,
        fs:  `cpe:2.3:o:cisco:ios:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:6.x-1.0`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:6.x-1.1`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.050826:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:6.x-1.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.1\(2\)i2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:6.x-1.3`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:6.x-1.4`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkleft:submenu_tree:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:symantec:liveupdate_administrator:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.0`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:3.2.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.0:beta1`,
        fs:  `cpe:2.3:a:jabberd2:jabberd2:2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.0:beta2`,
        fs:  `cpe:2.3:a:businessobjects:infoview:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.0:rc1`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.0:rc2`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.1`,
        fs:  `cpe:2.3:a:netiq:secure_configuration_manager:5.7.0.390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.2`,
        fs:  `cpe:2.3:a:codiad:codiad:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.3`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.4`,
        fs:  `cpe:2.3:a:sharetronix:sharetronix:3.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.5`,
        fs:  `cpe:2.3:a:kingsoft:writer_2010:2723:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.6`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mailchimp:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mandrill:7.x-1.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.495.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mandrill:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mandrill:7.x-1.0:beta1`,
        fs:  `cpe:2.3:h:samsung:galaxy_s6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mandrill:7.x-1.1`,
        fs:  `cpe:2.3:a:vips:vips:7.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thinkshout:mandrill:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:craig_drummond:cantata:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thirdwire:strike_fighters_israel:1.2.4::~~~android~~`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_eibner:mod_rpaf:0.5`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0075:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_eibner:mod_rpaf:0.6`,
        fs:  `cpe:2.3:a:ulead:photo_explorer:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:softaculous:webuzo:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta10`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta2`,
        fs:  `cpe:2.3:a:apple:cups:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta3`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta4`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.5.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta5`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta6`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta7`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta8`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:beta9`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.0:rc1`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u5\(1h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.1`,
        fs:  `cpe:2.3:a:mautic:mautic:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.2`,
        fs:  `cpe:2.3:a:uaepd:shopping_cart_script:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.3`,
        fs:  `cpe:2.3:h:redhat:network_satelite_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomas_seidl:search_api:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.10:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:thomson:twg87ouir:-`,
        fs:  `cpe:2.3:a:openstack:swift:1.2.0:gamma1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thomsonreuters:velocity_analytics_vhayu_analytic_server:6.94`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.3.0:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:mobile_foundation:5.0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.3.1:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.3.2:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:apc:powerchute:1.3.4:-:personal:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.4.0:-:~~~ruby~~`,
        fs:  `cpe:2.3:o:huawei:s3300_firmware:v100r006c01spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.4.1:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.24:*:smart:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.4.2:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:cisco:webns:8.20.3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.5.0::~~~ruby~~`,
        fs:  `cpe:2.3:a:docker:docker:0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.5.1:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:realvnc:realvnc:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.5.2:-:~~~ruby~~`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:cocaine:0.5.3:-:~~~ruby~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd318b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtbot:paperclip:4.2.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:amd:app_sdk_runtime:2.5.793.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thoughtworks-studios:mingle:3.0.3.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.65.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:threadflip:threadflip_%3a_buy_sell_fashion:1.1.11::~~~android~~`,
        fs:  `cpe:2.3:a:horde:imp:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:three:my3:%407f0a0001::~~~android~~`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:threedify:threedify_designer:5.0.2`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:8.10:-:*:*:*:windows_server_2003:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.00`,
        fs:  `cpe:2.3:a:mybb:mybb:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.01`,
        fs:  `cpe:2.3:o:cisco:mds_9000_san-os:3.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.02`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.10`,
        fs:  `cpe:2.3:a:dadabik:dadabik:1.0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.20`,
        fs:  `cpe:2.3:a:phplist:phplist:2.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.30`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.40`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.50`,
        fs:  `cpe:2.3:a:beneplus:bene\&#43;_odmeny_a_slevy:1.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.60`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.61`,
        fs:  `cpe:2.3:h:advantech:vesp211-eu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.70`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.80`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.81`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:1.82`,
        fs:  `cpe:2.3:a:php:php:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.00`,
        fs:  `cpe:2.3:a:apache:struts:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.01`,
        fs:  `cpe:2.3:a:freeftpd:freeftpd:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.10`,
        fs:  `cpe:2.3:a:sambar:sambar_server:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.11`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.20`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.21`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.22`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.23`,
        fs:  `cpe:2.3:a:novell:imanager:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.24`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.25`,
        fs:  `cpe:2.3:a:rob_bradford:libsocialweb:0.25.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.26`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.30`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.31`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.32`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.33`,
        fs:  `cpe:2.3:a:french_national_commission_on_informatics_and_liberty:cookieviz:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.34`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.35`,
        fs:  `cpe:2.3:h:hp:z238_microtower_workstation_n51:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.36`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.37`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi-simple:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.38`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.40`,
        fs:  `cpe:2.3:o:cisco:spa500_firmware:7.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.41`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.50`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.24:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.51`,
        fs:  `cpe:2.3:a:janetter:janetter:2.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.52`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.53`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.60:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.54`,
        fs:  `cpe:2.3:a:mysql:mysql:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.55`,
        fs:  `cpe:2.3:a:abbyy:finereader_sprint:6.0.1735.41615:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.56`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:9.0.1:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.57`,
        fs:  `cpe:2.3:a:magzter:hot_cars:3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.58`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.59`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.60`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.61`,
        fs:  `cpe:2.3:a:twistedmatrix:twistedweb:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.62`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.63`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.64`,
        fs:  `cpe:2.3:a:dirphp_project:dirphp:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.70`,
        fs:  `cpe:2.3:a:mobileappspartner:parque_imperial:1.02:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.71`,
        fs:  `cpe:2.3:h:g4stechnology:mn-nic-4-enc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.72`,
        fs:  `cpe:2.3:a:microsoft:asp.net_core:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.73`,
        fs:  `cpe:2.3:a:tenable:plugin-set:201402262215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.75`,
        fs:  `cpe:2.3:a:cybozu:office:9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.76`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.77`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.78`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.79`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.80`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.81`,
        fs:  `cpe:2.3:a:gnu:zlib:1.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.82`,
        fs:  `cpe:2.3:a:intel:network_connections:16.4.69.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.83`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.128:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.84`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.85`,
        fs:  `cpe:2.3:a:git-scm:git:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.86`,
        fs:  `cpe:2.3:h:hp:ibrix_x9320:qp330b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.87`,
        fs:  `cpe:2.3:a:google:chrome:16.0.893.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.88`,
        fs:  `cpe:2.3:a:x:libdmx:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.89`,
        fs:  `cpe:2.3:h:apple:ipad2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.90`,
        fs:  `cpe:2.3:a:pygments:pygments:1.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.91`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.92`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass_guest:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.93`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.94`,
        fs:  `cpe:2.3:a:haxx:curl:7.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.95`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.96`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.97`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.98`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:2.99`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jf847a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:3.00`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:3.01`,
        fs:  `cpe:2.3:o:xen:xen:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:3.02`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.00`,
        fs:  `cpe:2.3:a:keepass:keepass:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.01`,
        fs:  `cpe:2.3:a:microsoft:office:2007:*:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.02`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.03`,
        fs:  `cpe:2.3:a:samba:samba:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.04`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.05`,
        fs:  `cpe:2.3:a:php:php:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.06`,
        fs:  `cpe:2.3:a:atlassian:jira:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.07`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.08`,
        fs:  `cpe:2.3:o:asus:rt-n10e_firmware:2.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.09`,
        fs:  `cpe:2.3:a:shopware:shopware:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:4.10`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.00`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.01`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-8:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.02`,
        fs:  `cpe:2.3:o:cisco:cisco_ons_15454_system_software:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.03`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.04`,
        fs:  `cpe:2.3:a:safer_networking:filealyzer:1.6.0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.05`,
        fs:  `cpe:2.3:a:squid-cache:squid:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.06`,
        fs:  `cpe:2.3:a:file_project:file:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.07`,
        fs:  `cpe:2.3:a:ocportal:ocportal:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.08`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.09`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-28f-ei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.10`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.11`,
        fs:  `cpe:2.3:a:cisco:policy_suite:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.12`,
        fs:  `cpe:2.3:a:filemaker:filemaker_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.13`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.14`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.15`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.16`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.153:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.17`,
        fs:  `cpe:2.3:a:apple:quicktime:7.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.18`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.19`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.13.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.20`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.21`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sed:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.22`,
        fs:  `cpe:2.3:a:microsoft:outlook_express:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.23`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(23\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:5.24`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:1.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.00`,
        fs:  `cpe:2.3:a:ibm:maximo_industry_solutions:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.01`,
        fs:  `cpe:2.3:a:mollify:mollify:1.6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.02`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:git4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.03`,
        fs:  `cpe:2.3:a:scott_wheeler:taglib:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.04`,
        fs:  `cpe:2.3:h:intel:mobile_intel_qs57_express_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.05`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.3.0:cp03:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.06`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.10`,
        fs:  `cpe:2.3:a:dotnetblogengine:blogengine.net:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thulasidas:easy-adsense-lite:6.20`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thycotic:secret_server:2.3::~~~iphone_os~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thycotic:secret_server:8.6.000000`,
        fs:  `cpe:2.3:a:tibco:activematrix_management_agent:1.2.0:*:*:*:*:windows_communication_foundation:*:*`,
    },
     
    {
        uri: `cpe:/a:thycotic:secret_server:8.6.000009`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thycotic:secret_server:8.6.000010`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(3\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thycotic:secret_server:8.7.000000`,
        fs:  `cpe:2.3:a:gnu:tar:1.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thycotic:secret_server:8.8.000000`,
        fs:  `cpe:2.3:a:php:php:5.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thycotic:secret_server:8.8.000001`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:thycotic:secret_server:8.8.000004`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:4.5.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ti:cardbus:2.0.1`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ti:pci_7510_cardbus_controller_with_smartcard_and_software:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ti:ti_inst:1.3.1`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:5.5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibbo:aggregate:5.21.02`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_management_agent:1.0.0::~~~websphere~~`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_management_agent:1.0.0::~~~windows_communication_foundation~~`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_management_agent:1.1.0::~~~websphere~~`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.3.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_management_agent:1.1.0::~~~windows_communication_foundation~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_management_agent:1.2.0::~~~websphere~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_management_agent:1.2.0::~~~windows_communication_foundation~~`,
        fs:  `cpe:2.3:a:otrs:otrs:2.3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_policy_agent:3.0.0`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_policy_agent:3.1.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.20:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_policy_agent:3.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_policy_manager:3.0.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air:4.0.0.1390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_policy_manager:3.1.0`,
        fs:  `cpe:2.3:a:redhat:libreport:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:activematrix_policy_manager:3.1.1`,
        fs:  `cpe:2.3:a:google:talk_plugin:2.1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:enterprise_administrator:1.0.0`,
        fs:  `cpe:2.3:a:acs:putty_connection_manager:0.7.1.136beta:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:enterprise_administrator:1.1.0`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7961g:8.0\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:enterprise_administrator_sdk:1.0.0`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:enterprise_administrator_sdk:1.1.0`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:formvine:3.0.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:formvine:3.1.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:formvine:3.1.1`,
        fs:  `cpe:2.3:a:futomi:revocounter_cgi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:formvine:3.1.2`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:formvine:3.2.0`,
        fs:  `cpe:2.3:a:x:libxext:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:formvine:3.2.1`,
        fs:  `cpe:2.3:a:microsoft:system_center_operations_manager:2007:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_command_center:6.7`,
        fs:  `cpe:2.3:a:hp:web_jetadmin:7.5.2546:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_command_center:7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_command_center:7.0.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_command_center:7.1.0`,
        fs:  `cpe:2.3:a:hp:solution_center:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_command_center:7.2.0`,
        fs:  `cpe:2.3:a:artifex:mupdf:2008.09.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_command_center:7.2.1`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.1.2:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_command_center:7.2.2`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_command_center:7.2.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_internet_server:6.7`,
        fs:  `cpe:2.3:o:f5:tmos:4.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_internet_server:7.0`,
        fs:  `cpe:2.3:a:php:php123_top_sites:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_internet_server:7.0.1`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_internet_server:7.1.0`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.2800.1106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_internet_server:7.2.0`,
        fs:  `cpe:2.3:h:xerox:docutech_6115:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_internet_server:7.2.1`,
        fs:  `cpe:2.3:h:hp:0231a84q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_internet_server:7.2.2`,
        fs:  `cpe:2.3:a:intel:network_connections:16.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:managed_file_transfer_internet_server:7.2.3`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.42:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:silver_fabric_enabler:1.6.0::~~~spotfire_web_player~~`,
        fs:  `cpe:2.3:a:busybox:busybox:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:silver_fabric_enabler_for_spotfire_webplayer:2.1.0`,
        fs:  `cpe:2.3:a:fluke:power_log:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:silver_mobile:1.1.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)ya1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:silver_mobile:1.1.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p191:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:slingshot:1.7.0`,
        fs:  `cpe:2.3:a:hybridauth_social_login_project:hybridauth_social_login:7.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:slingshot:1.8.0`,
        fs:  `cpe:2.3:a:adobe:flash_player:23.0.0.207:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:slingshot:1.8.1`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:slingshot:1.9.0`,
        fs:  `cpe:2.3:a:apache:axis:-:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:slingshot:1.9.1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:slingshot:1.9.2`,
        fs:  `cpe:2.3:a:novell:suse_lifecycle_management_server:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analyst:5.5.1`,
        fs:  `cpe:2.3:a:t1lib:t1lib:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analyst:6.0.0`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_anywhere:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analyst:6.0.1`,
        fs:  `cpe:2.3:a:symantec:enterprise_security_manager:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analyst:6.0.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analyst:6.5.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analyst:6.5.1`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analyst:6.5.2`,
        fs:  `cpe:2.3:a:vmware:tools:8.0.3.21653:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analyst:7.0.0`,
        fs:  `cpe:2.3:h:sun:fire_x2100_m2:3.19:_nil_:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analytics_platform_for_aws:6.5`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_analytics_platform_for_aws:7.0.0`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_automation_services:5.5.1`,
        fs:  `cpe:2.3:a:codiad:codiad:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_automation_services:6.0.0`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_automation_services:6.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_automation_services:6.0.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je101a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_automation_services:6.5.0`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_center:12.0.1:-:small_business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_automation_services:6.5.1`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_automation_services:6.5.2`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_automation_services:7.0.0`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_deployment_kit:5.5.1`,
        fs:  `cpe:2.3:a:sympa:sympa:3.1b.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_deployment_kit:6.0.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_deployment_kit:6.0.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.509.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_deployment_kit:6.0.2`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.12.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_deployment_kit:6.5.0`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_deployment_kit:6.5.1`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_deployment_kit:6.5.2`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_deployment_kit:7.0.0`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_desktop:6.5.1`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_desktop:7.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_desktop_language_packs:7.0.0`,
        fs:  `cpe:2.3:a:python:pillow:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_professional:5.5.1`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:9.3.61.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_professional:6.0.1`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_professional:6.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_professional:6.5.0`,
        fs:  `cpe:2.3:a:where2stop:where2stop-cardlocks-free:6.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_professional:6.5.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.222:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_professional:6.5.2`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_professional:7.0.0`,
        fs:  `cpe:2.3:a:cloudera:cloudera_manager:3.7.5:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:4.5.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:5.0.2`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.6.7.637:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:5.5.1`,
        fs:  `cpe:2.3:a:blackberry:blackberry_enterprise_service:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:5.5.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:5.5.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:6.0.2`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_base_platform:12.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:6.0.3`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:6.0.4`,
        fs:  `cpe:2.3:a:rpm:rpm:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:6.5.0`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:6.5.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:6.5.2`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2.2:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:6.5.3`,
        fs:  `cpe:2.3:a:microsoft:office:2007:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_server:7.0.0`,
        fs:  `cpe:2.3:a:samba:samba:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_statistics_services:3.3`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_statistics_services:4.5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p229:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_statistics_services:5.0.0`,
        fs:  `cpe:2.3:h:intel:mobile_intel_qs67_chipset:_express-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:3.3`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux_corporate_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:3.3.2`,
        fs:  `cpe:2.3:h:hp:3com_switch:4210_pwr_9p_taa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:4.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:4.0.1`,
        fs:  `cpe:2.3:a:h2o_project:h2o:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:4.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_requirements_composer:3.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:4.5.0`,
        fs:  `cpe:2.3:a:skype:skype:1.0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:5.0.0`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:5.5.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.181.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:6.0.0`,
        fs:  `cpe:2.3:a:trianglemicroworks:ansi_c_source_code_libraries:3.09.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:6.0.1`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:6.0.2`,
        fs:  `cpe:2.3:o:siemens:cfms2025_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:6.5.0`,
        fs:  `cpe:2.3:a:aimluck:aipo:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:6.5.1`,
        fs:  `cpe:2.3:a:trillian:trillian:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:6.5.2`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:spotfire_web_player:7.0.0`,
        fs:  `cpe:2.3:a:be-graph:bezip:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:vault:1.0.0`,
        fs:  `cpe:2.3:a:dadabik:dadabik:2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:vault:1.0.1`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tibco:vault:1.1.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.6:cert4:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tic-tac_to_the_max_free_project:tic-tac_to_the_max_free:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:1.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ticketone:ticketone.it:2.2::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ticketroundup:ticket_round_up:3.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ticstyle:bultmonster_registret:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:websphere_portal_unified_task_list_portlet:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tidestone:formula_one_activex_control:6.3.5.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tidio-form_project:tidio-form:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:facebook:suriname_radio:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tidio-gallery_project:tidio-gallery:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.12.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigase:tigase:5.2.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigase:tigase:5.2.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiger-fish:fancy_slide:6.x-2.2`,
        fs:  `cpe:2.3:a:ultraedit:uestudio:10.30.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiger-fish:fancy_slide:6.x-2.4`,
        fs:  `cpe:2.3:a:location_module_project:location:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiger-fish:fancy_slide:6.x-2.5`,
        fs:  `cpe:2.3:a:altiris:asset_management_solution:6.5.1126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiger-fish:fancy_slide:6.x-2.6`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiger-fish:fancy_slide:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigerlogic:d3_odbc_client:2.0.32`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigertext:tigertext:3.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:o:cisco:staros:16.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigertext:tigertext:3.1.402:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigertext:tigertext:3.1.405:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:0.0.90`,
        fs:  `cpe:2.3:a:splunk:splunk:6.4.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:0.0.91`,
        fs:  `cpe:2.3:a:hp:insight_control_server_deployment:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:1.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:1.0.0`,
        fs:  `cpe:2.3:a:emc:rsa_archer_egrc:5.5:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:1.0.1`,
        fs:  `cpe:2.3:a:news_project:news:3.2.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:1.1:beta1`,
        fs:  `cpe:2.3:a:koha:koha:3.14.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:1.1.0`,
        fs:  `cpe:2.3:a:vmware:workstation:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:1.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:1.3.1`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigervnc:tigervnc:1.7`,
        fs:  `cpe:2.3:a:nginx:nginx:1.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tightvnc:tightvnc:-`,
        fs:  `cpe:2.3:a:debian:netkit:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tightvnc:tightvnc:1.3.9`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tightvnc:tightvnc:1.3.10`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg9000-10:-:-:full_proxy:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigo:tigo_copa_mundial_fifa_2014:3.1::~~~android~~`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.1`,
        fs:  `cpe:2.3:a:microsoft:malware_protection_engine:1.1.10701.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.2`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.30.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.3`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.4`,
        fs:  `cpe:2.3:a:sysprogs:wincdemu:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.5`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.5.1`,
        fs:  `cpe:2.3:o:huawei:s9712_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.6.1`,
        fs:  `cpe:2.3:a:horde:imp:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.7`,
        fs:  `cpe:2.3:a:veritas:volume_manager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.8`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.8.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.9.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:9.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.9.2`,
        fs:  `cpe:2.3:a:openx:openx:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.10.0`,
        fs:  `cpe:2.3:a:winscp:winscp:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.11.0`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.11.2`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.12`,
        fs:  `cpe:2.3:a:avg:anti-virus:8.5:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.12.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.14`,
        fs:  `cpe:2.3:a:apache:traffic_server:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.15`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.4:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.15.1`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.15.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.0\(3\)i1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.16`,
        fs:  `cpe:2.3:a:zarafa:webapp:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.17`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.18`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.19`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.20`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf018:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.20.1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.20.2`,
        fs:  `cpe:2.3:a:gnu:zlib:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.21`,
        fs:  `cpe:2.3:a:microsoft:sysinternals_pstools:2.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.22`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.23`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_92:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.24`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.25`,
        fs:  `cpe:2.3:a:ark-web:a-form_bamboo:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:0.26`,
        fs:  `cpe:2.3:a:python:python:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0.2`,
        fs:  `cpe:2.3:a:7-zip:p7zip:9.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0.3`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0.4`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0.5`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0.6`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20060517:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0.7`,
        fs:  `cpe:2.3:a:opera:opera_browser:3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.0.8`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.0`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.0:rc1`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.0:rc2`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2009:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.1`,
        fs:  `cpe:2.3:h:hp:jf804a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.2`,
        fs:  `cpe:2.3:a:netscape:navigator:4.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.3`,
        fs:  `cpe:2.3:a:prodad:vitascene:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.4`,
        fs:  `cpe:2.3:a:apache:ambari:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.5`,
        fs:  `cpe:2.3:a:novell:small_business_suite:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.6`,
        fs:  `cpe:2.3:a:hp:creativeprojects_panorama1config:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.1.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.2.0`,
        fs:  `cpe:2.3:a:synology:cloud_station:2.1-2561:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.2.1`,
        fs:  `cpe:2.3:a:teradata:tdput:3.5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.2.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.2.3`,
        fs:  `cpe:2.3:o:nuuo:nvrmini_2:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.2.4`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_human_capital_management_global_payroll:9.1:*:*:*:switzerland:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.2.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.310:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.2.6`,
        fs:  `cpe:2.3:a:redhat:cloudforms_management_engine:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.2.6.4786`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server_metadata_workbench:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.3.0`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.3.1`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:-:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.3.2`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.3.3`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.3.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.3.5`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.3.6219`,
        fs:  `cpe:2.3:a:sugarcrm:sugarcrm:6.5.26:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.0`,
        fs:  `cpe:2.3:o:yahama:rt60w:5.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.0:rc1`,
        fs:  `cpe:2.3:a:bluecoat:director_mc:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.3`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.05:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.4`,
        fs:  `cpe:2.3:a:alex_barth:data:6.x-1.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.5`,
        fs:  `cpe:2.3:a:macromedia:matrix_screen_saver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.6`,
        fs:  `cpe:2.3:a:mozilla:firefox:43.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.7`,
        fs:  `cpe:2.3:o:asus:rt-ac68u_firmware:3.0.0.4.374.4755:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.8`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.4.12137`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.0`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.107:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.0:alpha1`,
        fs:  `cpe:2.3:o:lenovo:thinkserver_rd450_firmware:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.0:beta1`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.0:rc1`,
        fs:  `cpe:2.3:a:idt:idt_audio:1.0.6124.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.0:rc2`,
        fs:  `cpe:2.3:a:plaatsoft:addressbook:6.x-4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.0:rc3`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.1`,
        fs:  `cpe:2.3:o:sun:solaris:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.2`,
        fs:  `cpe:2.3:a:citadel:ux:6.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.3`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.4`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.5`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:cf05:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.6`,
        fs:  `cpe:2.3:o:cisco:catos:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.7`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.8`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.10`,
        fs:  `cpe:2.3:o:huawei:honor_6_firmware:h60-l11c00b850:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.5.14361`,
        fs:  `cpe:2.3:a:oracle:interaction_center_intelligence:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.3`,
        fs:  `cpe:2.3:a:autodesk:autocad_architecture_2011:6.5.49.0:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.4`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.5`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.6`,
        fs:  `cpe:2.3:a:hp:solution_center:50.0.152.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.16344`,
        fs:  `cpe:2.3:a:enigmail:enigmail:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.17493`,
        fs:  `cpe:2.3:h:hp:jg776a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.18415`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.19116`,
        fs:  `cpe:2.3:a:cisco:acs_for_windows:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.19369`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.19370::~~~~x64~`,
        fs:  `cpe:2.3:a:intrinsyc:j-integra_for_exchange:2.11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.19725`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20111005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.19898`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.21042`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.21511`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.21737`,
        fs:  `cpe:2.3:a:cmsdevelopment:business_card_web_builder:2.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.6.21923`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.7.22161`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.7.22161::~~~~x64~`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:gold:tablet_pc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tigris:tortoisesvn:1.7.22327`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.5.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiket:tiket.com_hotel_%26_flight:1.1.2::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:12.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.6.1`,
        fs:  `cpe:2.3:o:maygion:ip_camera_firmware:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.8.1`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.0`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:5.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.0:rc1`,
        fs:  `cpe:2.3:a:oracle:commerce_guided_search_and_experience_manager:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.0:rc2`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.0:rc3`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8s\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.1.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.12.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.2`,
        fs:  `cpe:2.3:a:debian:ldapscripts:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.3`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p71:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.3.1`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:9.5.1.3225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.3.2`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:zh:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.5`,
        fs:  `cpe:2.3:a:red-gate:sql_response:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.6`,
        fs:  `cpe:2.3:h:huawei:s9700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.7`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.8`,
        fs:  `cpe:2.3:a:agilebits:knox:1.6.4:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.8.1`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.8.2`,
        fs:  `cpe:2.3:a:citrix:vdi-in-a-box:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.9`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xk3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:1.9.11`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:2.2`,
        fs:  `cpe:2.3:a:vmware:view:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:3.0`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:3.1`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:3.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:3.3`,
        fs:  `cpe:2.3:a:adobe:connect:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:3.5`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.6.4\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:4`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.0.60831.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:4.0`,
        fs:  `cpe:2.3:a:gigablast:gigabot:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:4.1`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2004-09-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:4.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:5.0`,
        fs:  `cpe:2.3:a:google:chrome:4.0.252.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:5.1`,
        fs:  `cpe:2.3:a:daemontools:daemon_tools_lite:4.40.2.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:5.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:5.3`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.0`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:3.0.0.3.178:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.1`,
        fs:  `cpe:2.3:a:microsoft:visio:2002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.2`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:10.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.3:-:lts`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.5:-:lts`,
        fs:  `cpe:2.3:o:bluecoat:proxysgos:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.7:-:lts`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_edge_95_mxp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.8:-:lts`,
        fs:  `cpe:2.3:a:buffalotech:whr-g_firmware:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.9:-:lts`,
        fs:  `cpe:2.3:a:symantec:livereg:2.1.5.1502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.10:-:lts`,
        fs:  `cpe:2.3:a:ocportal:ocportal:6.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.11:-:lts`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.578:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.12:-:lts`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:6.13:-:lts`,
        fs:  `cpe:2.3:a:oracle:universal_work_queue:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:7.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:7.1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:7.2`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.5:dev8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:8.0`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_pdf_sdk_activex:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:8.1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:9.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:8.2`,
        fs:  `cpe:2.3:a:exim:exim:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:8.3`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:1.0.1.7c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:8.4`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.0:-:lts`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:5.0\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.0:alpha:lts`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.0:beta:lts`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.4:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.0:beta2:lts`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_desktop_central:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.1:-:lts`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.2:-:lts`,
        fs:  `cpe:2.3:a:oracle:pharmaceutical:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.2:beta1:lts`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5600-50c-pwr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.3:-:lts`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.4:-:lts`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.4.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.5:-:lts`,
        fs:  `cpe:2.3:a:privatemsg_project:privatemsg:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.6:-:lts`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:9.7:-:lts`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(25e\)jap10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:10.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:10.0:alpha`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:10.0:beta`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:10.1`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:10.2`,
        fs:  `cpe:2.3:h:3com:3c16986a-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:10.3`,
        fs:  `cpe:2.3:a:hitachi:ibm_xl_c\/c\&#43;\&#43;_v7_for_aix_\&amp;_hitachi_developer\&#39;s_kit_for_java:02-05-\/q:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:10.4`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.53:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:10.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(22\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:11.0`,
        fs:  `cpe:2.3:h:3com:3crwe754g72-a:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:11.0:beta`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:9.5.0-201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:11.1`,
        fs:  `cpe:2.3:o:rockwellautomation:softlogix_5800_controller_firmware:21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.0`,
        fs:  `cpe:2.3:a:perl:perl:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.1`,
        fs:  `cpe:2.3:o:novell:netware:3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.2`,
        fs:  `cpe:2.3:a:citrix:xendesktop:5.6.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.3`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.0\(5.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.4`,
        fs:  `cpe:2.3:a:ikiwiki_hosting_project:ikiwiki_hosting:0.20110420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.5`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.6`,
        fs:  `cpe:2.3:a:isc:bind:9.6.2:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.7`,
        fs:  `cpe:2.3:a:intel:2200bg_proset_wireless:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.8`,
        fs:  `cpe:2.3:a:openbsd:opensmtpd:5.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:12.9::lts`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:15.0`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:15.1`,
        fs:  `cpe:2.3:a:oracle:service_contracts:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:15.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiki:tikiwiki_cms%2fgroupware:16.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u6\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tilman_hausherr:xenu_link_sleuth:1.0g`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tilman_hausherr:xenu_link_sleuth:1.0u`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update_15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tilman_hausherr:xenu_link_sleuth:1.2d`,
        fs:  `cpe:2.3:a:feedweb:feedweb:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tilman_hausherr:xenu_link_sleuth:1.2i`,
        fs:  `cpe:2.3:h:juniper:netscreen-idp_10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tilman_hausherr:xenu_link_sleuth:1.2j`,
        fs:  `cpe:2.3:a:apache:openoffice.org:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tim_ban_bon_phuong_project:tim_ban_bon_phuong:2.2::~~~android~~`,
        fs:  `cpe:2.3:a:emc:smarts_network_configuration_manager:9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tim_heuer:rss_feedreader_web_part:1.0.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tim_robbins:libmagic:-`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.5.1:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:tim_taylor:icon_restore:1.0`,
        fs:  `cpe:2.3:a:blackboard:transact_suite:3.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:time_tracker_project:time_tracker:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:intel:network_connections:15.4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:time_tracker_project:time_tracker:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:time_tracker_project:time_tracker:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:time_tracker_project:time_tracker:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:sgminer_project:sgminer:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:timedmediahandler_project:timedmediahandler:-::~~~mediawiki~~`,
        fs:  `cpe:2.3:a:openvpn:openvpn:2.4.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:timedoctor:timedoctor:1.4.72.3::~~pro~~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.302.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:timelessblack:timeless_black:2.10.6::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:gimp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:timely:all-in-one_event_calendar:1.4`,
        fs:  `cpe:2.3:a:hp:ignite-ux:a.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:timely:all-in-one_event_calendar:1.5`,
        fs:  `cpe:2.3:a:xchat:xchat:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:timuz:bike_racing_2014:1.6::~~~android~~`,
        fs:  `cpe:2.3:h:korenix:jetport:5604i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinc-vpn:tinc:1.0.17`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinc-vpn:tinc:1.0.18`,
        fs:  `cpe:2.3:a:google:chrome:14.0.786.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinc-vpn:tinc:1.0.19`,
        fs:  `cpe:2.3:o:cisco:aireos:7.6:100.0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinc-vpn:tinc:1.0.20`,
        fs:  `cpe:2.3:o:debian:debian_linux:2.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinc-vpn:tinc:1.1:pre3`,
        fs:  `cpe:2.3:a:sun:n1_system_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinc-vpn:tinc:1.1:pre4`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tinc-vpn:tinc:1.1:pre5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:7.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinc-vpn:tinc:1.1:pre6`,
        fs:  `cpe:2.3:a:rsa:access_manager_server:6.1:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.0`,
        fs:  `cpe:2.3:a:emc:rsa_security_analytics:10.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.0.1`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.3.1:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.1.2b`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.1.3b`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.1.4b`,
        fs:  `cpe:2.3:a:debian:shadow-utils:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.1.5`,
        fs:  `cpe:2.3:a:justin_dodge:hotblocks:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.1.5b`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.1.6`,
        fs:  `cpe:2.3:a:plone:plone:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.1.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.2cz:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.3.5`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(1m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.3.7`,
        fs:  `cpe:2.3:a:websense:websense_web_security:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.4.1`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.5.0`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.5.1`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option:08-00\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.6.0`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.6.1`,
        fs:  `cpe:2.3:h:qeiinc:epaq-9410_substation_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.6.3`,
        fs:  `cpe:2.3:a:samba:samba:4.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.6.4`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.7.0`,
        fs:  `cpe:2.3:a:surfcontrol:soap_runtime:2.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.7.1`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.8.0`,
        fs:  `cpe:2.3:a:awesomeseating:buy_tickets:2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.9.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.9.1`,
        fs:  `cpe:2.3:a:gentoo:portage:2.1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.9.2`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:1.9.3`,
        fs:  `cpe:2.3:a:google:chrome:7.0.499.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.1.0`,
        fs:  `cpe:2.3:a:microsoft:desktop_engine:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.1.1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.1.3`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.1.4`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.2.0`,
        fs:  `cpe:2.3:a:php:php:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.2.1`,
        fs:  `cpe:2.3:a:microsoft:ie:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.3.0`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.3.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.548:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.3.2`,
        fs:  `cpe:2.3:a:siemens:comos:10.0.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.3.3`,
        fs:  `cpe:2.3:h:cabletron:6h202-24:5.07.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.3.4`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.4.0`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.4.7`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.2`,
        fs:  `cpe:2.3:a:oracle:communications_online_mediation_controller:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.4`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.15:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.5`,
        fs:  `cpe:2.3:a:icq:icq:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.6`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server_for_product_information_management:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.7`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.1:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.5.8`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.6`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.6.0`,
        fs:  `cpe:2.3:a:roxio:express_labeler:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.6.1`,
        fs:  `cpe:2.3:a:mollify:mollify:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.6.2`,
        fs:  `cpe:2.3:a:tryton:tryton:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.6.3`,
        fs:  `cpe:2.3:a:lunarcms:lunar_cms:3.3:3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.6.4`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.6.5`,
        fs:  `cpe:2.3:a:debian:apt:0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.7.1`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.5:-:-:*:-:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.7.2`,
        fs:  `cpe:2.3:a:koha:koha:3.16.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.8.2`,
        fs:  `cpe:2.3:a:gnome:eye_of_gnome:3.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.8.7`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.8.12`,
        fs:  `cpe:2.3:a:apple:safari:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.9.3`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.9.4`,
        fs:  `cpe:2.3:a:apple:mpeg2_codec:6.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.9.5`,
        fs:  `cpe:2.3:a:libmenu-cache_project:libmenu-cache:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.1`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.2`,
        fs:  `cpe:2.3:o:bluecoat:security_gateway_os:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.3`,
        fs:  `cpe:2.3:h:cisco:catalyst_4510r\&#43;e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.4`,
        fs:  `cpe:2.3:a:linksalpha:social_sharing_toolkit_plugin:2.1.0:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.5`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.6`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.47.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.7`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.8`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.9`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.10`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.11`,
        fs:  `cpe:2.3:a:cramerdev:document_library:5.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.12`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tincan:phplist:2.10.13`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.01`,
        fs:  `cpe:2.3:a:ayatana_project:unity:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.02`,
        fs:  `cpe:2.3:a:cypherpunks:libotr:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.03`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.9:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.04`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.05`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.5`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.20.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.06`,
        fs:  `cpe:2.3:a:wave:embassy_remote_administration_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.07`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0-p2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.08`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.09`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.51`,
        fs:  `cpe:2.3:a:sun:sunvts:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.52`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.53`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.54`,
        fs:  `cpe:2.3:a:inspire_ircd:inspircd:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.55`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.5se:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.56`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.57`,
        fs:  `cpe:2.3:a:cabletron:spectrum_enterprise_manager:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.58`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.5:beta-rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.59`,
        fs:  `cpe:2.3:a:python:pillow:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.60`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.61`,
        fs:  `cpe:2.3:a:sap:mmc_snapin:7.10.30088:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.62`,
        fs:  `cpe:2.3:a:skype:skype:4.1.0.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.64`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinycouch:tiny_password:1.65`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:7.0.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0`,
        fs:  `cpe:2.3:a:apache:poi:3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0:a1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0:a2`,
        fs:  `cpe:2.3:h:enterasys:matrix_n3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0:b1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0:b2`,
        fs:  `cpe:2.3:a:cisco:telepresence_supervisor_mse_8050_software:2.2\(1.17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0:b3`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0:rc1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.52.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0.1`,
        fs:  `cpe:2.3:a:mitsubishielectric:mx4_scada:7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0.2`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0.3`,
        fs:  `cpe:2.3:a:winzip:winzip:15.5.9468:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:spellchecker_php:2.0.6`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinymce:tinymce:3.5.8`,
        fs:  `cpe:2.3:a:apple:keynote:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinysrp_project:tinysrp:0.7.5`,
        fs:  `cpe:2.3:a:bravenewcode:wptouch:1.9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinytap:hundred_thousands_kid_book:1.6.3::~~~android~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinytap:math_for_kids_-_subtraction:1.2.10::~~~android~~`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:5.4:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinytap:not_lost_just_somewhere_else:1.6.1::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tinywebgallery:tinywebgallery:1.8.6`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tiomobilepay:tio_mobilepay_-_bill_payments:1.1.1::~~~android~~`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tionetworks:gulf_power_mobile_bill_pay:1::~~~android~~`,
        fs:  `cpe:2.3:a:mathjs:math.js:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tips_and_tricks_hq:all_in_one_wordpress_security_and_firewall:3.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.54:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tips_and_tricks_hq:all_in_one_wordpress_security_and_firewall:3.8.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:debian:trousers:0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tips_and_tricks_hq:all_in_one_wordpress_security_and_firewall:3.8.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:roxio:creator:12.1.77.0:*:*:*:starter:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kde:koffice:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nortel:cs1000m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tt4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-developer_set:07-60-\/i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:catalyst_4510r-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3a\)xi8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:9.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(19\)s2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_alcatel:2.50.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webform_multiple_file_upload_project:webform_multiple_file_upload:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:networker:8.1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:google:android:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.5\(0.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(13a\)bc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bluecoat:k9_web_protection:3.2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tibco:silver_mobile:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.17:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:maximo_industry_solutions:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:elephantdrive:elephantdrive:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sympa:sympa:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.9.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:9.0.280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:titan_framework_project:titan_framework:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emulex:common_san_management:32.1.1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:titus:message_classification:3.0.59`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:titus:message_classification_administration_tool:3.1.37`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.33:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tivoli_storage_productivity_center:5.0:-`,
        fs:  `cpe:2.3:a:marcel_brinkkemper:lazyest-gallery:1.1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tivoli_storage_productivity_center:5.1:-`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tivoli_storage_productivity_center:5.1.1:-`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tizen:tizen:-`,
        fs:  `cpe:2.3:a:ca:network_and_systems_management:r11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tizen:tizen:-`,
        fs:  `cpe:2.3:a:anixis:password_policy_enforcer:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tizen:tizen:2.1`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:2.2`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:2.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:2.3.1`,
        fs:  `cpe:2.3:a:hp:software_perl:5.8.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:2.4.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:2.5.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:2.6.1`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:2.7.1`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:2.8.1`,
        fs:  `cpe:2.3:a:adobe:after_effects_cs4:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.0.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.1`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.2`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.3`,
        fs:  `cpe:2.3:a:huge-it_catalog_project:huge-it_catalog:1.0.7:*:*:*:*:joomla:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(53\)sg3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.4.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.4-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.5`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:4.5.2`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.1`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.4.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.1.1`,
        fs:  `cpe:2.3:a:atlassian:confluence:6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.2`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.2.1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.2.2`,
        fs:  `cpe:2.3:a:pinnaclesys:instant_dvd_recorder:2.6.0.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.2.3`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_ip_gateway:2.0.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.0:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.3.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.3.3`,
        fs:  `cpe:2.3:a:hp:decnet_osi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.3.3.1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.4`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53_91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.4.1`,
        fs:  `cpe:2.3:a:omeka:omeka:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:5.4.2`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.0.1`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.0.2`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_75:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.0.3`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.1.0:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.1.0`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.1.1:jira42`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.9:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.2.0`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.2.1-jira42`,
        fs:  `cpe:2.3:a:novell:iprint:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.2.2:jira42`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.2.3:jira42`,
        fs:  `cpe:2.3:a:piwik:piwik:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.2.4:jira42`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.2.5:jira42`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.2.6:jira42`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.2.7:jira42`,
        fs:  `cpe:2.3:a:trihedral:vtscada:9.0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.3.1:jira42`,
        fs:  `cpe:2.3:a:cisco:telepresence_manager:1.7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.4:jira42`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.4.2`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.4.3`,
        fs:  `cpe:2.3:a:xnview:xnview:1.91.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:6.5`,
        fs:  `cpe:2.3:a:oracle:database_server:11.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:7.0`,
        fs:  `cpe:2.3:a:jenkins-ci:monitoring_plugin:1.43.0:*:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:7.0.0:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:7.0.0:rc2`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor_agent:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo:7.0.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)a6\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo6.3.0:jira42`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tm_software:tempo6.3.2:jira42`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.124:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tmobile:webconnect_manager:2.5.16.0`,
        fs:  `cpe:2.3:a:f5:big-ip:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tmobile:webconnect_manager:2.5.55.0`,
        fs:  `cpe:2.3:a:apple:quicktime:7.3.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tnef_project:tnef:1.4.12`,
        fs:  `cpe:2.3:a:tincan:phplist:2.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tnef_project:tnef:1.4.14`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tntnet:cxxtools:2.2`,
        fs:  `cpe:2.3:a:phplist:phplist:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tntnet:tntnet:2.0`,
        fs:  `cpe:2.3:a:cisco:prime_central_for_hosted_collaboration_solution_assurance:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tntnet:tntnet:2.1`,
        fs:  `cpe:2.3:a:arg0:encfs:1.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tntnet:tntnet:2.2`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tntnet:tntnet:2.2.1`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tobias_bathge:wp-table_reloaded:1.9.0`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.1c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tobias_bathge:wp-table_reloaded:1.9.1`,
        fs:  `cpe:2.3:o:asus:rt-n16_firmware:1.0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tobias_bathge:wp-table_reloaded:1.9.2`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_portal_platform:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tobias_bathge:wp-table_reloaded:1.9.3`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tobias_bathge:wp-table_reloaded:1.9.4`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:x64-standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tobias_maier:paratrooper-pingdom:1.0.0:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:h:siemens:sinamics_g130:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todaysseniorsnetwork:todaysseniorsnetwork:0.21.13245.84038::~~~android~~`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6`,
        fs:  `cpe:2.3:a:cisco:vpn_5000_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.2`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.5.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.2p3`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_agent:11.0.17217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.3`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.3_p7`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.0.2359:online_windows_server_2003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.4`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.4p2`,
        fs:  `cpe:2.3:h:foundrynet:bigiron_8000_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.5`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.6`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.7`,
        fs:  `cpe:2.3:a:jenkins-ci:build_failure_analyzer:1.2.0:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.7p5`,
        fs:  `cpe:2.3:h:dell:3000cn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.8`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.8p12`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.9`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.9p20`,
        fs:  `cpe:2.3:a:nuance:pdf_reader_plus:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.9p21`,
        fs:  `cpe:2.3:a:isc:bind:9.7.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.9p22`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.6.9p23`,
        fs:  `cpe:2.3:o:yamaha:rta55i:4.06.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.0`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.5.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.1`,
        fs:  `cpe:2.3:a:haxx:curl:7.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.2`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.1m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.2p1`,
        fs:  `cpe:2.3:a:andrew_levine:multiblock:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.2p2`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.2p3`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.2p4`,
        fs:  `cpe:2.3:a:redhat:kdelibs_sound_devel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.2p5`,
        fs:  `cpe:2.3:h:huawei:atn:v200r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.2p6`,
        fs:  `cpe:2.3:a:apache:derby:10.12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.2p7`,
        fs:  `cpe:2.3:o:yamaha:rt58i:9.01.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.3b1`,
        fs:  `cpe:2.3:a:botcha_spam_prevention_project:botcha:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.4p1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.4p2`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.4p3`,
        fs:  `cpe:2.3:a:apache:solr:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.4p4`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.4p5`,
        fs:  `cpe:2.3:a:apache:archiva:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.4p6`,
        fs:  `cpe:2.3:a:emunching:harry\&#39;s_pub:1.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.5`,
        fs:  `cpe:2.3:a:netiq:self_service_password_reset:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.6`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.6p1`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.6p2`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.4.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.7`,
        fs:  `cpe:2.3:h:canon:network_camera_server_vb100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.8`,
        fs:  `cpe:2.3:a:sybase:easerver:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.8p1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.8p2`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5s_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.9`,
        fs:  `cpe:2.3:a:jason_savino:fp:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.9p1`,
        fs:  `cpe:2.3:a:gnu:tar:1.13.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.4:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p1`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p2`,
        fs:  `cpe:2.3:a:digia:qt:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p3`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p5`,
        fs:  `cpe:2.3:h:hp:0235a29l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p6`,
        fs:  `cpe:2.3:a:deon_george:phpldapadmin:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p7`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p8`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ebf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p9`,
        fs:  `cpe:2.3:a:google:chrome:5.0.317.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.7.10p10`,
        fs:  `cpe:2.3:a:janrain:ruby-openid:2.2.1:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.0`,
        fs:  `cpe:2.3:a:synnefoims:internet_management_software:2015:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.678.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.1p1`,
        fs:  `cpe:2.3:a:microsoft:entourage:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.1p2`,
        fs:  `cpe:2.3:h:winwebmail:winwebmail_server:3.8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.3`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.3p1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.3p2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.4`,
        fs:  `cpe:2.3:a:joachim_ruhs:locator:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.4p1`,
        fs:  `cpe:2.3:a:nuance:visual_c\&#43;\&#43;_runtime_for_dragon_naturallyspeaking:10.0.200.184:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.4p2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.4p3`,
        fs:  `cpe:2.3:a:snapgear:snapgear_lite\&#43;_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.4p4`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.4p5`,
        fs:  `cpe:2.3:a:google:chrome:7.0.504.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.5`,
        fs:  `cpe:2.3:a:sun:jsse:1.0.3_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.5p1`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.5p2`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.5p3`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.6`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.6p1`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.0.1061:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.6p2`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.6p3`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.6p4`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.6p5`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.6p6`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todd_miller:sudo:1.8.6p7`,
        fs:  `cpe:2.3:a:aptana:aptana_studio:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toddm:gravity_bounce:1.1::~~~android~~`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todo_filter_project:todo_filter:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.11:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:todo_filter_project:todo_filter:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:todo_filter_project:todo_filter:7.x-1.x-dev::~~~drupal~~`,
        fs:  `cpe:2.3:a:posh_project:posh:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:token_insert_entity_project:token_insert_entity:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:5.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tollgrade:smartgrid_lighthouse_sensor_management_system:4.1.0`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tollgrade:smartgrid_lighthouse_sensor_management_system:5.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_software:4.2\(1.43\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.2`,
        fs:  `cpe:2.3:a:adobe:coldfusion_8:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.2.1`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6ecc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.2.2`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.4.14:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.2.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(12\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.7-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.4`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.5`,
        fs:  `cpe:2.3:a:netkit-ftp:netkit_ftp:0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:1.5.1`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.00.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.0`,
        fs:  `cpe:2.3:h:intel:server_platform_sr870bn4:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.0.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.2`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.6:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.3`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.3.1`,
        fs:  `cpe:2.3:a:sun:java_plug-in:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.4`,
        fs:  `cpe:2.3:a:rob_loach:sharethis:7.x-2.0:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.4.2`,
        fs:  `cpe:2.3:o:hp:network_switch_software:15.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.5`,
        fs:  `cpe:2.3:a:xaraya:xaraya:2.4.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.6`,
        fs:  `cpe:2.3:a:avaya:libsafe:2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.7`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.1\(1\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.8`,
        fs:  `cpe:2.3:a:ibm:rational_collaborative_lifecycle_management:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.9`,
        fs:  `cpe:2.3:a:redhat:sos:2.2-18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.10`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.10.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)ew:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.11`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:gold:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.12`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.13`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.13.1`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.26:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.14`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.1:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.15`,
        fs:  `cpe:2.3:a:vmware:fusion:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.15.1`,
        fs:  `cpe:2.3:a:phorum:phorum:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.16`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp1:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.16.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00-05:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:2.17`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:3.0`,
        fs:  `cpe:2.3:a:mocoga:kakao_bingo_garden:1.0.14:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:3.1`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:6.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_braider:count_per_day:3.2`,
        fs:  `cpe:2.3:a:wenlin_institute:wenlin:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_m8te_plugin_project:tom-m8te_plugin:1.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nvidia:display_control_panel:6.14.12.6883:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tom_wilkason:snackamp:3.1.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tomatocart:tomatocart:1.1.8.6.1`,
        fs:  `cpe:2.3:a:atutor:atutor:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_freixas:ubercart_product_keys:6.x-1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_freixas:ubercart_product_keys:6.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:apache:log4j:2.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_freixas:ubercart_product_keys:6.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_freixas:ubercart_product_keys:6.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.07.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_freixas:ubercart_product_keys:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_freixas:ubercart_product_keys:6.x-1.0:rc1`,
        fs:  `cpe:2.3:a:sysaid:sysaid:14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_freixas:ubercart_product_keys:6.x-1.0:rc2`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_freixas:ubercart_product_keys:6.x-1.1`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tony_million:tuniac:090517c`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toocharger:myboard:1.0.12`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller:1.0\(2m\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toocharger:smartblog:1.3`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toocharger:trombinoscope:3.5`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toolpage_project:toolpage:1.6.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:veritas_volume_replicator:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tools4ever:user_management_resource_administrator:6.0`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topappsbuilder_project:animal_kaiser_zangetsu:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topazsystems:e-signatures_sigplus:3.74`,
        fs:  `cpe:2.3:a:projectsend:projectsend:412:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topazsystems:sigplus_pro_activex_control:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topazsystems:sigplus_pro_activex_control:3.74`,
        fs:  `cpe:2.3:o:cisco:vpn_3030_concentator:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topazsystems:sigplus_pro_activex_control:3.89`,
        fs:  `cpe:2.3:o:iij:seil_turbo_firmware:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topazsystems:sigplus_pro_activex_control:3.95`,
        fs:  `cpe:2.3:a:oracle:jre:1.8.0:update_77:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:5.7.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.001`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.005`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.5.1:devel:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.006`,
        fs:  `cpe:2.3:a:free_ebooks_project:free_ebooks:14.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.008`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.011`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.012`,
        fs:  `cpe:2.3:a:mortbay:jetty:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.013`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.015`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.04.016`,
        fs:  `cpe:2.3:a:web_browser_for_android_project:web_browser_for_android:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.05.002`,
        fs:  `cpe:2.3:a:gurock:testrail:3.1.1.3130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.05.006`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0047:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.05.007`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.05.008`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.05.009`,
        fs:  `cpe:2.3:o:cisco:staros:19.0.m0.60828:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.05.010`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.05.016`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.05.017`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.002`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.003`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.004`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.005`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.006`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.007`,
        fs:  `cpe:2.3:a:pivotal_software:redis:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.013`,
        fs:  `cpe:2.3:o:yamaha:rt80i:3.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.014`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.06.020`,
        fs:  `cpe:2.3:a:simplenews_scheduler_project:simplenews_scheduler:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.07.002`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:3.2.4:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.07.005`,
        fs:  `cpe:2.3:a:mcafee:rogue_system_detection_sensor:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.07.007`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.07.010`,
        fs:  `cpe:2.3:a:htacg:tidy:4.9.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.07.014`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.07.019`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:fnc9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.07.022`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.07.023`,
        fs:  `cpe:2.3:a:lxml:lxml:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.001`,
        fs:  `cpe:2.3:a:compaq:enterprise_volume_manager_command_scripter:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.011`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.016`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.020`,
        fs:  `cpe:2.3:a:sympa:sympa:4.0.a1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.021`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.024`,
        fs:  `cpe:2.3:a:perl:perl:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.025`,
        fs:  `cpe:2.3:a:vmware:vcloud_director:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.029`,
        fs:  `cpe:2.3:a:hk_exif_tags_project:hk_exif_tags:1.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.030`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.031`,
        fs:  `cpe:2.3:o:cisco:catos:4.5\(4b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.033`,
        fs:  `cpe:2.3:a:python:python:3.3.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.08.034`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.001`,
        fs:  `cpe:2.3:a:serv-u:serv-u:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.005`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.010`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.011`,
        fs:  `cpe:2.3:a:ingo_renner:apache_solr:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.012`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)wc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.013`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.014`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.015`,
        fs:  `cpe:2.3:a:cisco:webex_meetings_server:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.017`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1a_pk2_bl2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.018`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software\&#39;:8.5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.019`,
        fs:  `cpe:2.3:a:koha:koha:3.14.00:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.021`,
        fs:  `cpe:2.3:a:bundler:bundler:1.2.0:rc.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.022`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.023`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_client:5.3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.09.024`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.008`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_design_manager:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.015`,
        fs:  `cpe:2.3:a:microsoft:viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.021`,
        fs:  `cpe:2.3:a:cisco:security_agent:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.022`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.025`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.026`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(16f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.027`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.037`,
        fs:  `cpe:2.3:a:mathjs:math.js:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.10.040`,
        fs:  `cpe:2.3:a:shawn_bradley:php_volunteer_management:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.11.003`,
        fs:  `cpe:2.3:a:google:toolbar:1.1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.11.015`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.11.024`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.123:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.11.030`,
        fs:  `cpe:2.3:a:redhat:libvirt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.006`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(28\)sb4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.007`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.008`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1208.101.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.013`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.3.2:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.015`,
        fs:  `cpe:2.3:a:citrix:broadcast_server:2.0:*:avaya:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.020`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_servers_software:x7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.022`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.025`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:6.12.026`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.01.001`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:7.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.01.008`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.2:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.01.020`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.01.024`,
        fs:  `cpe:2.3:a:ibm:emptoris_sourcing_portfolio:9.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.02.012`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.02.013`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.02.014`,
        fs:  `cpe:2.3:a:hp:portable_file_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.02.016`,
        fs:  `cpe:2.3:a:visiwave:site_survey:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.02.021`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)bc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.03.007`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.03.008`,
        fs:  `cpe:2.3:a:yiiframework:yiiframework:1.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.03.018`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.03.019`,
        fs:  `cpe:2.3:a:synology:diskstation_manager:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.03.020`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.03.022`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.04.001`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2013:-:gen_trial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.04.004`,
        fs:  `cpe:2.3:a:iss:realsecure_server_sensor:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.04.019`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.4.4:build20111103.18:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.04.021`,
        fs:  `cpe:2.3:o:cisco:catos:7.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.04.023`,
        fs:  `cpe:2.3:a:fiddler2:fiddler2:2.3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.05.006`,
        fs:  `cpe:2.3:a:getusedtoit:wp_slimstat:3.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.05.007`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.05.020`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.05.023`,
        fs:  `cpe:2.3:o:compaq:tru64:5.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.06.001`,
        fs:  `cpe:2.3:a:svendecabooter:webform_validation:7.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.06.005`,
        fs:  `cpe:2.3:a:nfsen:nfsen:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.06.010`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.06.011`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topdesk:topdesk:7.06.014`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topfreegames:bike_race_free_-_top_free_game:4.3::~~~android~~`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topgames:top_games_script:1.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topgames:top_games_script:1.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topgames:top_games_script:1.2`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topicsviewer:topicsviewer:3.0:beta1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.12.332:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:topline_systems:opportunity_form:-`,
        fs:  `cpe:2.3:h:lexmark:x543:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tor_browser_the_short_guide_project:tor_browser_the_short_guide:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torchsoft:malware_defender:2.6.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:1.0`,
        fs:  `cpe:2.3:a:apple:safari:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:1.0.1`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:1.1`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:1.1.1`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.6:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:1.2`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:1.2.1`,
        fs:  `cpe:2.3:a:apple:itunes:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:2.0`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:1.5.4.302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:2.1`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.0.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:2.1.1`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:2.2`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tornadoweb:tornado:2.2.1`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2`,
        fs:  `cpe:2.3:a:openttd:openttd:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre13`,
        fs:  `cpe:2.3:h:buffalotech:whr-300hp2_firmware:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre14`,
        fs:  `cpe:2.3:a:emc:rsa_data_protection_manager_software_server:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre15`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre16`,
        fs:  `cpe:2.3:a:oracle:retail_applications:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre17`,
        fs:  `cpe:2.3:a:apache:derby:10.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre18`,
        fs:  `cpe:2.3:a:rpm:rpm:4.9.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre19`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre20`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre21`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre22`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre23`,
        fs:  `cpe:2.3:h:lucent:ascend_pipeline_router:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre24`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre25`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.xml:1.0.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre26`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre27`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.2:pre8`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.941:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.3`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.4`,
        fs:  `cpe:2.3:a:symantec:network_access_control:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.5`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.6`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.6.1`,
        fs:  `cpe:2.3:a:cisco:jabber:9.2\(.0\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.6.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.8-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.7`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:7.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.7.1`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:1.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.7.2`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.7.3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.8`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.8:pre1`,
        fs:  `cpe:2.3:o:dahuasecurity:dvr_firmware:2.608.0000.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.8:pre2`,
        fs:  `cpe:2.3:a:apache:openjpa:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.8:pre3`,
        fs:  `cpe:2.3:a:php:php:5.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.8:rc1`,
        fs:  `cpe:2.3:a:louis_jimenez:custom_meta:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.8:rc2`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.8.1`,
        fs:  `cpe:2.3:h:3com:3c13750:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9`,
        fs:  `cpe:2.3:o:cisco:ios:12.2srb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:pre1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:pre2`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:pre3`,
        fs:  `cpe:2.3:h:xerox:workcentre_40_color:01.02.65.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:pre4`,
        fs:  `cpe:2.3:a:theforeman:foreman:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:pre5`,
        fs:  `cpe:2.3:a:augeas:augeas:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:pre6`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:rc1`,
        fs:  `cpe:2.3:h:ge:snmp\/web_adapter_1024747:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:rc2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:rc3`,
        fs:  `cpe:2.3:a:google:chrome:8.0.551.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:rc4`,
        fs:  `cpe:2.3:a:embedthis:goahead:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:rc5`,
        fs:  `cpe:2.3:a:tm_software:tempo:6.2.6:jira42:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:rc6`,
        fs:  `cpe:2.3:a:percona:xtrabackup:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9:rc7`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.2`,
        fs:  `cpe:2.3:a:node_limit_number_project:node_limitnumber:5.x-1.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.3`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.4`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:2.9:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.5`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.6`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.7`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.8`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.9`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.0.9.10`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(12\)da3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.1`,
        fs:  `cpe:2.3:a:iss:realsecure_sentry:3.6:ecb:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.2`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.4`,
        fs:  `cpe:2.3:a:avast:premier:11.1.2262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.5`,
        fs:  `cpe:2.3:a:openstack:neutron:2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.6`,
        fs:  `cpe:2.3:a:openttd:openttd:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.7`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.56.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.9`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.350:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.10`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.11`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.12`,
        fs:  `cpe:2.3:h:netgear:wgr614:v8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.13`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.7.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.14`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.24.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.15`,
        fs:  `cpe:2.3:a:cyrus:imap:2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.16`,
        fs:  `cpe:2.3:a:bareftp:bareftp:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.0.17`,
        fs:  `cpe:2.3:a:smarty:smarty:1.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.1:alpha`,
        fs:  `cpe:2.3:a:novell:netmail:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.2:alpha`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.1.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.4:alpha`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.5:alpha`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.2:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.6:alpha`,
        fs:  `cpe:2.3:a:consona:servicedesk_online:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.7:alpha`,
        fs:  `cpe:2.3:a:janrain:rpx:6.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.8:alpha`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.9:alpha`,
        fs:  `cpe:2.3:h:d-link:dir-100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.10:alpha`,
        fs:  `cpe:2.3:a:arris:touchstone_tg862g\/ct_firmware:7.6.59s.ct:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.11:alpha`,
        fs:  `cpe:2.3:a:jessgramp:minicms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.12:alpha`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.13:alpha`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.14:alpha`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)md:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.15`,
        fs:  `cpe:2.3:a:docker:docker:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.16`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.17`,
        fs:  `cpe:2.3:o:netgear:wnr1000v3_firmware:1.0.2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.18`,
        fs:  `cpe:2.3:a:redmine:redmine:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.19`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.20`,
        fs:  `cpe:2.3:o:sierrawireless:raven_x_ev-do_firmware:4221_4.0.11.003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.21`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.22`,
        fs:  `cpe:2.3:a:fusiondrupalthemes:fusion:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.23`,
        fs:  `cpe:2.3:a:vips:vips:7.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.24`,
        fs:  `cpe:2.3:a:apache:struts:2.3.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.25`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.1.26`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x4470_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.1:alpha`,
        fs:  `cpe:2.3:a:emc:rsa_access_manager:6.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.2:alpha`,
        fs:  `cpe:2.3:a:adobe:adobe_air:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.3:alpha`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.4:alpha`,
        fs:  `cpe:2.3:o:hp:arcsight_connector_appliance_firmware:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.5:alpha`,
        fs:  `cpe:2.3:a:sap:hana:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.6:alpha`,
        fs:  `cpe:2.3:a:dell:openmanage:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.7:alpha`,
        fs:  `cpe:2.3:h:belden:hirschmann_l3p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.8:beta`,
        fs:  `cpe:2.3:a:exim:exim:4.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.9`,
        fs:  `cpe:2.3:a:bea:jolt:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.10`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:5.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.11`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.2.1:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.12`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.13`,
        fs:  `cpe:2.3:o:hp:ignite-ux:c.7.3.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(6.8a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.15`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.16`,
        fs:  `cpe:2.3:a:google:v8:3.24.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.17`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.18`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.1.2.19`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.368:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.1:alpha`,
        fs:  `cpe:2.3:a:ibm:db2:11.1.0.0:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.2:alpha`,
        fs:  `cpe:2.3:a:redhat:certificate_system:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.3:alpha`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.4:alpha`,
        fs:  `cpe:2.3:h:yokogawa:rpo_production_supervisor_vp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.5:alpha`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.6:alpha`,
        fs:  `cpe:2.3:a:quest:toad_for_data_analysts:2.6.2.580:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.7:alpha`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_50-40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.8:alpha`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.9:alpha`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.1\(2\)su1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.10:alpha`,
        fs:  `cpe:2.3:a:alphabetic_sitemap_project:alphabetic_sitemap:0.0.1:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.11:alpha`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.12:alpha`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.13:alpha`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.8.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.14:alpha`,
        fs:  `cpe:2.3:a:apache:wss4j:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.15:alpha`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.16:alpha`,
        fs:  `cpe:2.3:a:apache:camel:2.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.17:alpha`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.18:alpha`,
        fs:  `cpe:2.3:h:supermicro:x9drff-7:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.19:alpha`,
        fs:  `cpe:2.3:a:rpm:rpm:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.20`,
        fs:  `cpe:2.3:a:oracle:pharmaceutical:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.21`,
        fs:  `cpe:2.3:a:ibm:daeja_viewone:4.1.5:*:*:*:virtual:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.22`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.23`,
        fs:  `cpe:2.3:a:c-board_moyuku_project:c-board_moyuku:1.02:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.24`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.25`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.26`,
        fs:  `cpe:2.3:a:zonelabs:imsecure:1.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.27`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.28`,
        fs:  `cpe:2.3:a:cookpad:android_mykitchen:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.29`,
        fs:  `cpe:2.3:h:nvidia:quadro_m2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.30`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20030409:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.31`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.32`,
        fs:  `cpe:2.3:a:pivotal_software:spring_security:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.33`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p141:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.34`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.28:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.0.35`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.1:alpha`,
        fs:  `cpe:2.3:a:oracle:transportation_management:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.2:alpha`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.3:alpha`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.4:alpha`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.5:alpha`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.6:alpha`,
        fs:  `cpe:2.3:h:netgear:prosafe_gs752txs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.7:alpha`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.8:alpha`,
        fs:  `cpe:2.3:a:w1.f1:hostapd:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.9:alpha`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.10:alpha`,
        fs:  `cpe:2.3:a:nomachine:nx_web_companion:3.2.0-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.11:alpha`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.12:alpha`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.2:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.13:alpha`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.14`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.15`,
        fs:  `cpe:2.3:a:sap:hybris:5.2.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.16`,
        fs:  `cpe:2.3:h:hp:laserjet_5200l:q7543a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.17`,
        fs:  `cpe:2.3:a:mysql:mysql:3.22.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.18`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30119:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.19`,
        fs:  `cpe:2.3:a:kde:kauth:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.20`,
        fs:  `cpe:2.3:a:apache:subversion:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.21`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.01.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.22`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.23`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.24`,
        fs:  `cpe:2.3:a:ibm:infosphere_biginsights:1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.25`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.26`,
        fs:  `cpe:2.3:a:antisamy_project:antisamy:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.27`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.3\(2.34\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.28`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.29`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.30`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.31`,
        fs:  `cpe:2.3:a:otrs:faq:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.1.32`,
        fs:  `cpe:2.3:a:malwarebytes:malwarebytes_anti-exploit:1.04.1.1012:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.1:alpha`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.2:alpha`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.3:alpha`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.4:alpha`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.5:alpha`,
        fs:  `cpe:2.3:h:siphon:siphone_enterprise_pbx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.6:alpha`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.7:alpha`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:6.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.8:alpha`,
        fs:  `cpe:2.3:a:ntop:ntopng:2.0.151021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.9:alpha`,
        fs:  `cpe:2.3:a:hp:smart_update_manager:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.10:alpha`,
        fs:  `cpe:2.3:a:novell:netmail:3.10h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.11:alpha`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.12:alpha`,
        fs:  `cpe:2.3:a:vmware:player:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.13:alpha`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.14:alpha`,
        fs:  `cpe:2.3:a:liquidthreads_project:liquidthreads:2.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.15:alpha`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.16:alpha`,
        fs:  `cpe:2.3:a:apache:camel:2.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.17:alpha`,
        fs:  `cpe:2.3:a:hp:http_communication:6.20.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.18`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.18:alpha`,
        fs:  `cpe:2.3:h:cisco:telepresence_multipoint_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.19`,
        fs:  `cpe:2.3:a:cisco:finesse:10.5\(1\)_su1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.19:alpha`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.20`,
        fs:  `cpe:2.3:a:7-zip:7zip:15.05:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.20:alpha`,
        fs:  `cpe:2.3:a:adobe:flash_player:22.0.0.211:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.21`,
        fs:  `cpe:2.3:a:avast:endpoint_protection_suite:8.0.1609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.21:alpha`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.22`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.15:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.22:alpha`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_3_firmware:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.23`,
        fs:  `cpe:2.3:a:sendcard:sendcard:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.23:alpha`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:0.1:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.24`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.61:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.24:alpha`,
        fs:  `cpe:2.3:a:bullguard:online_backup:14.1.287:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.25`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:19-11-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.25:alpha`,
        fs:  `cpe:2.3:o:cisco:ios:12.1ax:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.26`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.26:beta`,
        fs:  `cpe:2.3:a:smarty:smarty:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.27`,
        fs:  `cpe:2.3:a:oracle:jre:1.7.0:update_45:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.27:beta`,
        fs:  `cpe:2.3:a:lemon-s_php:gazou_bbs_plus:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.28`,
        fs:  `cpe:2.3:a:scriptlogic:security_explorer:6.5.1.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.28:beta`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.29`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.29:beta`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.30`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.31`,
        fs:  `cpe:2.3:h:netgear:prosafe_s716t:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.32`,
        fs:  `cpe:2.3:a:schneider-electric:clearscada:2010:r2.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.33`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.34`,
        fs:  `cpe:2.3:a:lucent:vitalsuite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.35`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1022:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.36`,
        fs:  `cpe:2.3:a:dell:bioapi_framework:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.37`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.38`,
        fs:  `cpe:2.3:a:redhat:richfaces:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.2.39`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.0:beta-3:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.19.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.1:alpha`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.2:alpha`,
        fs:  `cpe:2.3:a:tryton:tryton:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.3:alpha`,
        fs:  `cpe:2.3:a:borland:caliberrm:10.0.229:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.4:alpha`,
        fs:  `cpe:2.3:a:google:v8:3.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.5:alpha`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.6:alpha`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.7:alpha`,
        fs:  `cpe:2.3:a:pcre:perl_compatible_regular_expression_library:8.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.8:alpha`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.9:alpha`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.10:alpha`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.11:alpha`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.12:alpha`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.232:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.13:alpha`,
        fs:  `cpe:2.3:a:extended_module_player_project:extended_module_player:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.14:alpha`,
        fs:  `cpe:2.3:a:digium:asterisk:c.3.6.2:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.15:alpha`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.16:alpha`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.17:beta`,
        fs:  `cpe:2.3:a:gnome:gnome-terminal:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.18`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je105a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.18:rc`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.19`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.19:rc`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.20`,
        fs:  `cpe:2.3:a:busybox:busybox:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.20:rc`,
        fs:  `cpe:2.3:a:dell:remote_console_switch_software:3.0.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.21`,
        fs:  `cpe:2.3:a:endonesia:endonesia:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.21:rc`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.22`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.22:rc`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.22:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.23:rc`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta47:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.24`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.24:rc`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.3.25`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d44.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.1:alpha`,
        fs:  `cpe:2.3:a:lunascape:lunascape:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.2:alpha`,
        fs:  `cpe:2.3:a:lsoft:listserv:14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.3:alpha`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.4:alpha`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:0.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.5:alpha`,
        fs:  `cpe:2.3:a:clamav:clamav:0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.6:alpha`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.9-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.7:alpha`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1.4s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.8:alpha`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.9:alpha`,
        fs:  `cpe:2.3:a:ca:ccc_harvest:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.10:alpha`,
        fs:  `cpe:2.3:a:novell:netmail:3.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.11:alpha`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:5.x-2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.12:alpha`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(14\)eb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.13:alpha`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.14:alpha`,
        fs:  `cpe:2.3:a:opentext:deployment_wizard:13.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.15`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.15:rc`,
        fs:  `cpe:2.3:a:puppetlabs:marionette-collective:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.16`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.02:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.16:rc`,
        fs:  `cpe:2.3:a:hitachi:cobol_gui_option_server:07-01\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.17`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.17:rc`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.18`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.18:rc`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.19`,
        fs:  `cpe:2.3:a:cisco:broadband_access_center_telco_wireless_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.20`,
        fs:  `cpe:2.3:a:pureedge:pureedge_viewer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.21`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.21:alpha`,
        fs:  `cpe:2.3:a:vmware:workstation:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.22`,
        fs:  `cpe:2.3:a:ca:unicenter_service_desk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.22:alpha`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.23`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.23:alpha`,
        fs:  `cpe:2.3:a:hp:storageworks_secure_path_windows:4.0c:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.24`,
        fs:  `cpe:2.3:a:adobe:coldfusion:7.2:unknown:mx:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.25`,
        fs:  `cpe:2.3:a:apc:switched_rack_pdu_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.26`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.27`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.7:gamma:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.28`,
        fs:  `cpe:2.3:a:mcafee:antivirus_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.4.29`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.1:alpha`,
        fs:  `cpe:2.3:a:actividentity:actividentity_device_installer:2.3:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.2:alpha`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.3:alpha`,
        fs:  `cpe:2.3:a:google:chrome:13.0.761.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.4:alpha`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.5:alpha`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.24:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.6:alpha`,
        fs:  `cpe:2.3:o:cisco:ios:12.1az:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.7`,
        fs:  `cpe:2.3:a:rarlab:winrar:5.30:beta_4:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.8`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.9`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.10`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.11`,
        fs:  `cpe:2.3:a:perl:perl:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.12`,
        fs:  `cpe:2.3:a:mono:mono:1.1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.13`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.5.14`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.1:alpha`,
        fs:  `cpe:2.3:a:geopainting:gpsmapedit:1.1.73.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.2:alpha`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.3:alpha`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.7.700.279:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.4`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.5`,
        fs:  `cpe:2.3:a:rsa:keon_certificate_authority_manager:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.6`,
        fs:  `cpe:2.3:a:real:realplayer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.7`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.8`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.9`,
        fs:  `cpe:2.3:a:splunk:splunk:6.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.10`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p381:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.11`,
        fs:  `cpe:2.3:o:apple:iphone_os:3.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.6.12`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.7.1:alpha`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:16.20.0.1009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.7.2:alpha`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-71:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.7.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p466:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.7.4`,
        fs:  `cpe:2.3:a:ross_burton:libsocialweb:0.25.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.7.5`,
        fs:  `cpe:2.3:o:ibm:z\/os:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.7.6`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.7.7`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.7.8`,
        fs:  `cpe:2.3:a:sun:openwindows:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.1:alpha`,
        fs:  `cpe:2.3:a:oracle:database_lite:10.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.2:alpha`,
        fs:  `cpe:2.3:a:lightdm_gtk\&#43;_greeter_project:lightdm_gtk\&#43;_greeter:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.3:alpha`,
        fs:  `cpe:2.3:a:avsmedia:video_tools:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.4`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1284.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.5`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.51.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.7`,
        fs:  `cpe:2.3:a:email\:\:address\:\:list_project:email\:\:address\:\:list:0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.8`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.9`,
        fs:  `cpe:2.3:a:lockon:ec-cube:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.10`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.7.722:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.11`,
        fs:  `cpe:2.3:a:dx_library_project:dx_library:3.15e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.12`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.13`,
        fs:  `cpe:2.3:a:drupal:drupal:6.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.8.14`,
        fs:  `cpe:2.3:a:cafuego:simple_document_management_system:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.0`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30394:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.0:alpha`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:9.40.xc5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.1:alpha`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.2:alpha`,
        fs:  `cpe:2.3:a:sun:javafx_sdk:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.3:alpha`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.4:alpha`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.5:alpha`,
        fs:  `cpe:2.3:a:phorum:phorum:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.6`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.8`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4501_series_software:4.1\(1.59\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.9`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.10`,
        fs:  `cpe:2.3:a:ca:ehealth_systemedge:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.2.9.11`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.0.1:alpha`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.496:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.0.2:alpha`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.1.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.0.3:alpha`,
        fs:  `cpe:2.3:a:busybox:busybox:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.0.4`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.0.5`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.0.6`,
        fs:  `cpe:2.3:a:samba:samba:3.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.0.7`,
        fs:  `cpe:2.3:h:hp:psc_1210_all-in-one:1.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.0.8`,
        fs:  `cpe:2.3:a:systemtools:dumpsec:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.1.1:alpha`,
        fs:  `cpe:2.3:a:php-sqrl_project:php-sqrl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.1.2:alpha`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torproject:tor:0.3.1.3:alpha`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torrentflux:torrentflux:2.4`,
        fs:  `cpe:2.3:a:samlify_project:samlify:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:torrnad0:sprint_jump:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:toshiba:4690_operating_system:6.3`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshiba:acpi_flash_bios:-`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:toshiba:chec:6.6`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshiba:chec:6.7`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(4\):sr3a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshiba:e210c:-`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshiba:surveillix:-`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.02.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:toshibacommerce:4690_point_of_sale_operating_system:6.2`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:toshibacommerce:4690_point_of_sale_operating_system:6.3`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:toshibacommerce:4690_point_of_sale_operating_system:6.4`,
        fs:  `cpe:2.3:a:bundler:bundler:1.9.0:pre.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-167_with_network_printer_kit:-`,
        fs:  `cpe:2.3:a:livetecs:timeline:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-167_with_network_printer_kit_firmware:t282cn0j421`,
        fs:  `cpe:2.3:a:novell:groupwise:6.0.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-181_with_network_printer_kit:-`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-181_with_network_printer_kit_firmware:t282cn0j421`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-182_with_network_printer_kit:-`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-182_with_network_printer_kit_firmware:t282cn0j421`,
        fs:  `cpe:2.3:a:richard_cook:rgpg:0.2.3:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-207_with_network_printer_kit:-`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-207_with_network_printer_kit_firmware:t282cn0j421`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-232:-`,
        fs:  `cpe:2.3:h:hp:jd653a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-232_firmware:t377sy0j354`,
        fs:  `cpe:2.3:a:oracle:opensso:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-233:-`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-2330c:-`,
        fs:  `cpe:2.3:a:adobe:illustrator:13.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-2330c_firmware:t450sy0j302`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.44:test2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-2500c:-`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-2500c_firmware:t380sy0j354`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.3.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-255:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.335:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-255_firmware:t470sy0j302`,
        fs:  `cpe:2.3:h:3com:3crwe747a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-255p:-`,
        fs:  `cpe:2.3:a:webbynode:webbynode:1.0.5.1:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-255p_firmware:t470sy0j302`,
        fs:  `cpe:2.3:a:oracle:webcenter_interaction:10.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-281c:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-281c_firmware:t410sy0j354`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-282:-`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-282_firmware:t377sy0j354`,
        fs:  `cpe:2.3:a:skyarc:mtcms:5.25:*:smart:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-283:-`,
        fs:  `cpe:2.3:a:oracle:tuxedo:12.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-2830c:-`,
        fs:  `cpe:2.3:a:modx:modx_revolution:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-2830c_firmware:t450sy0j302`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.64.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-3500c:-`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-3500c_firmware:t380sy0j354`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.6.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-3510c:-`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-3510c_firmware:t380sy0j354`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-351c:-`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1014:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-351c_firmware:t410sy0j354`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-352:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-352_firmware:t364sy0j354`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-3520c:-`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-3520c_firmware:t450sy0j302`,
        fs:  `cpe:2.3:o:yamaha:rt140i:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-355:-`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-355_firmware:t470sy0j302`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-451c:-`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-451c_firmware:t410sy0j354`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:5.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-452:-`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.1.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-452_firmware:t364sy0j354`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-4520c:-`,
        fs:  `cpe:2.3:a:winzip:winzip:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-4520c_firmware:t450sy0j302`,
        fs:  `cpe:2.3:a:exim:exim:4.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-455:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-455_firmware:t470sy0j302`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-5520c:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-5520c_firmware:t430sy0j302`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.7.0.1860:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-600:-`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-600_firmware:t390sy0j354`,
        fs:  `cpe:2.3:a:apache:myfaces:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-6520c:-`,
        fs:  `cpe:2.3:o:huawei:s6300_firmware:v100r006c01spc100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-6520c_firmware:t430sy0j302`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-6530c:-`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-6530c_firmware:t430sy0j302`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:64-bit-2002:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-655:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-655_firmware:t100sy0j302`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-720:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.6-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-720_firmware:t390sy0j354`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.1:beta-3:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-755:-`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-755_firmware:t100sy0j302`,
        fs:  `cpe:2.3:a:apache:cloudstack:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-850:-`,
        fs:  `cpe:2.3:a:sun:jre:1.5.0:update33:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-850_firmware:t390sy0j354`,
        fs:  `cpe:2.3:a:samba:samba:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-855:-`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-855_firmware:t100sy0j302`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.2.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:e-studio-tf-182_with_network_printer_kit:-`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toshibatec:e-studio-tf-182_with_network_printer_kit_firmware:t282cn0j421`,
        fs:  `cpe:2.3:a:condor_project:condor:7.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:toshibatec:estudio_4511:-`,
        fs:  `cpe:2.3:a:horizon_quick_content_management_system_project:horizon_quick_content_management_system:3.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalseminars:a%2b_2006_demo:4.10.0`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:totalseminars:a%2b_2009_701_and_702_voucher_demo:10.0.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.53:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalseminars:a%2b_2009_book_demo:9.20.0`,
        fs:  `cpe:2.3:a:ibm:db2_universal_database:8.1.7b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalseminars:cissp:4.0.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalseminars:cissp_5th_ed_aio:9.20.0`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalseminars:cissp_h_ed_aio_demo:4.10.0`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalseminars:network%2b_2009_book_demo:9.0.0`,
        fs:  `cpe:2.3:a:emailarchitect:emailarchitect_email_server:10.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalseminars:network%2b_demo:4.0.0`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.0`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.1`,
        fs:  `cpe:2.3:a:displaylink:displaylink_core_software:5.5.27257.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.2`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.3`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.3.1`,
        fs:  `cpe:2.3:a:sympa:sympa:0.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.3.2`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.3.3`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.4.0`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.4.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.5.0`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.5.0.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.5.1`,
        fs:  `cpe:2.3:a:apple:cups:1.5:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.5.2`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.5.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.5.4`,
        fs:  `cpe:2.3:a:gnu:automake:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.6.0`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.6.1`,
        fs:  `cpe:2.3:o:cisco:firepower_extensible_operating_system:1.1\(1.160\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.6.2`,
        fs:  `cpe:2.3:a:jrbcs:webform_report:5.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.6.3`,
        fs:  `cpe:2.3:a:intel:mwmi:5.74.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.7`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.474:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.7.0`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1684.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.7.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:1.7.2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.05:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:2.0.0`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:2.0.1`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:2.0.2`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:2.0.3`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.15:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:2.1.0`,
        fs:  `cpe:2.3:a:adobe:digital_editions:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:2.1.1`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:totalshopuk:ecommerce:2.1.2`,
        fs:  `cpe:2.3:a:sun:staroffice:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:touchnote:touchnote_postcards:4.2.7::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(19\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:toyotaownersclub:toyota_oc:3.6.1::~~~android~~`,
        fs:  `cpe:2.3:a:lina_wolf:seo_pack_for_tt_news:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:archer_c5_%281.2%29:-`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:archer_c5_%281.2%29_firmware:141126`,
        fs:  `cpe:2.3:a:winscp:winscp:4.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:archer_c7_%282.0%29:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:archer_c7_%282.0%29_firmware:141110`,
        fs:  `cpe:2.3:a:redhat:aeolus_conductor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:archer_c8_%281.0%29:-`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:archer_c8_%281.0%29_firmware:141023`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:archer_c9_%281.0%29:-`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:archer_c9_%281.0%29_firmware:150122`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:lm_firmware:1.6.18p12_sign5`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:td-8816:-`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-sc3130:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-sc3130g:-`,
        fs:  `cpe:2.3:a:baseurl:yum:3.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-sc3171:-`,
        fs:  `cpe:2.3:a:websitepanel:websitepanel:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-sc3171g:-`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.113:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wdr3500_%281.0%29:-`,
        fs:  `cpe:2.3:a:sendio:sendio:7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wdr3500_%281.0%29_firmware:141113`,
        fs:  `cpe:2.3:a:oracle:retail_applications:13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wdr3600_%281.0%29:-`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wdr3600_%281.0%29_firmware:141022`,
        fs:  `cpe:2.3:a:google:chrome:10.0.616.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wdr4300_%281.0%29:-`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wdr4300_%281.0%29_firmware:141113`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wr740n_%285.0%29:-`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:7.x-1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wr740n_%285.0%29_firmware:141217`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wr741nd_%285.0%29:-`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wr741nd_%285.0%29_firmware:141217`,
        fs:  `cpe:2.3:a:foolabs:xpdf:1.00:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wr840n:1.0`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wr840n_firmware:3.13.27`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wr841n:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.8.800.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wr841n_%2810.0%29:-`,
        fs:  `cpe:2.3:a:adobe:bridge_cs3:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wr841n_%2810.0%29_firmware:150104`,
        fs:  `cpe:2.3:a:redhat:hawtjni:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wr841n_%289.0%29:-`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wr841n_%289.0%29_firmware:150104`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-standard_set:07-20-\/b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wr841n_firmware:3.13.9`,
        fs:  `cpe:2.3:a:elinks:elinks:0.12:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wr841nd_%2810.0%29:-`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wr841nd_%2810.0%29_firmware:150104`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.2:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wr841nd_%289.0%29:-`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wr841nd_%289.0%29_firmware:150104`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wrd740n_%285.0%29:-`,
        fs:  `cpe:2.3:a:aol:aim:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wrd740n_%285.0%29_firmware:141217`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wrd741nd_%285.0%29:-`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wrd741nd_%285.0%29_firmware:141217`,
        fs:  `cpe:2.3:a:netscape:proxy_server:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wrd841n_%2810.0%29:-`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wrd841n_%2810.0%29_firmware:150104`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wrd841n_%289.0%29:-`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_hmi\/scada_cimplicity:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wrd841n_%289.0%29_firmware:150104`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wrd841nd_%2810.0%29:-`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.3.2:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wrd841nd_%2810.0%29_firmware:150104`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tp-link:tl-wrd841nd_%289.0%29:-`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tp-link:tl-wrd841nd_%289.0%29_firmware:150104`,
        fs:  `cpe:2.3:a:qualiteam:x-cart:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tqdm_project:tqdm:4.4.1`,
        fs:  `cpe:2.3:a:semper_invicta_fitness_project:semper_invicta_fitness:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tqdm_project:tqdm:4.10`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.5.2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:traauctions:tra_auctions_for_buyers:2.6::~~~android~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.572:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.0:-:viewer`,
        fs:  `cpe:2.3:a:yahoo:messenger:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0188`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0189`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:9.40.uc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0190`,
        fs:  `cpe:2.3:h:juniper:fips_secure_access_4500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0191`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0192`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(23\)jy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0193`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0194`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0195`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.27:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0196`,
        fs:  `cpe:2.3:a:teamst:testlink:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0197`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0198`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0199`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0200`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.0201`,
        fs:  `cpe:2.3:a:facebook:bilingual_magic_ball:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.202`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.203`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:2011.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.204`,
        fs:  `cpe:2.3:a:microsoft:infopath:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.205`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.206`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.207`,
        fs:  `cpe:2.3:a:imagemenu_project:imagemenu:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:2.5.208`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:3.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracker-software:pdf-xchange:3.60.0128`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tracking_code_project:tracking_code:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:pbm212030_project:pbm212030:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tradehero:tradehero:2.2.5::~~~android~~`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tradingandinvesting4u:bond_trading:197705::~~~android~~`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trafficgate:rakuten_install:1.5.0::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.1`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_carbon_copy_solution:6.2.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.3`,
        fs:  `cpe:2.3:a:mcafee:advanced_threat_defense:3.4.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.4`,
        fs:  `cpe:2.3:a:apache:juddi:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.5`,
        fs:  `cpe:2.3:a:kozos:easyctf:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.6`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.1:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.7`,
        fs:  `cpe:2.3:a:dell:system_e-support_tool:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.8`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc613a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.9`,
        fs:  `cpe:2.3:a:oracle:database_assistant:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transifex:transifex:0.10`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:translation_widget_project:translation_widget:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:jeff_ortel:suds:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.1`,
        fs:  `cpe:2.3:a:process-one:exmpp:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.2`,
        fs:  `cpe:2.3:a:gnu:binutils:2.29.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.4`,
        fs:  `cpe:2.3:a:haxx:curl:7.21.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.5`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.992_06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.6`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.6.1`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.70`,
        fs:  `cpe:2.3:a:google:v8:3.24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.71`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.72`,
        fs:  `cpe:2.3:a:netshinesoftware:com_netinvoice:1.2.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.80`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.81`,
        fs:  `cpe:2.3:a:sun:jre:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.82`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.90`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.91`,
        fs:  `cpe:2.3:a:mcafee:virusscan_enterprise:8.0i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.92`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.93`,
        fs:  `cpe:2.3:a:hummingbird:deployment_wizard:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.94`,
        fs:  `cpe:2.3:a:webyog:sqlyog:7.15:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.95`,
        fs:  `cpe:2.3:a:epson:event_manager:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:0.96`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.9-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.00`,
        fs:  `cpe:2.3:a:im5_fans_planet_project:im5_fans_planet:2.3.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.01`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.02`,
        fs:  `cpe:2.3:a:ray_stode:accountsservice:0.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.2`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.03`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x51:d60:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.04`,
        fs:  `cpe:2.3:h:huawei:e200e-x2:v100r005c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.05`,
        fs:  `cpe:2.3:a:ezbsystems:ultraiso:9.3.6.2750:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.06`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.10`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.11`,
        fs:  `cpe:2.3:a:puppetlabs:facter:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.20`,
        fs:  `cpe:2.3:a:cisco:videoscape_delivery_system_for_internet_streamer:3.2.1.b9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.21`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.22`,
        fs:  `cpe:2.3:a:akamai:kona_site_defender_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.30`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.31`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.2p4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.32`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.33`,
        fs:  `cpe:2.3:a:hp:product_detection:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.34`,
        fs:  `cpe:2.3:o:yamaha:rtx1200:10.01.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.40`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.41`,
        fs:  `cpe:2.3:a:drupal:drupal:7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.42`,
        fs:  `cpe:2.3:a:debian:trousers:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.50`,
        fs:  `cpe:2.3:h:ge:multilink_ml3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.51`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.0:rc2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.52`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jnd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.53`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.54`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.60`,
        fs:  `cpe:2.3:a:adobe:help_viewer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.61`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.70`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.71`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.72`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.73`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.6e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.74`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.75`,
        fs:  `cpe:2.3:a:google:chrome:11.0.683.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.76`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.77`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.80`,
        fs:  `cpe:2.3:a:apache:derby:10.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.81`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.82`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.83`,
        fs:  `cpe:2.3:o:cisco:catos:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.90`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.91`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.92`,
        fs:  `cpe:2.3:o:huawei:5700hi_firmware:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:1.93`,
        fs:  `cpe:2.3:h:cisco:asr_1023_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.00`,
        fs:  `cpe:2.3:a:xceedium:xsuite:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.01`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.02`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.06.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.03`,
        fs:  `cpe:2.3:a:oracle:iplanet_web_proxy_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.04`,
        fs:  `cpe:2.3:a:hp:scan:13.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.10`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(2\)sg6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.11`,
        fs:  `cpe:2.3:a:google:chrome:6.0.440.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.12`,
        fs:  `cpe:2.3:a:citrix:presentation_server_client:10.00.52110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.13`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2009.925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.20`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.21`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.22`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.30`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.7e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.31`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.32`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.33`,
        fs:  `cpe:2.3:a:oracle:oracle_data_provider_for_.net_help:10.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.40`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.4.d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.41`,
        fs:  `cpe:2.3:a:rockwellautomation:integrated_architecture_builder:9.6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.42`,
        fs:  `cpe:2.3:o:cisco:catos:6.4\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.50`,
        fs:  `cpe:2.3:h:d-link:dap-2660:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.51`,
        fs:  `cpe:2.3:a:ibm:rational_agent_controller:7.0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.52`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.60`,
        fs:  `cpe:2.3:a:hitachi:jp1\/performance_management-manager_web_option:07-00:*:*:*:*:solaris:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.61`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je096a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.70`,
        fs:  `cpe:2.3:a:redhat:richfaces:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.71`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.72`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.73`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.74`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.75`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.76`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.77`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.80`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.81`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.82`,
        fs:  `cpe:2.3:a:git-scm:git:2.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.83`,
        fs:  `cpe:2.3:h:hp:elitebook_folio_1040_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:transmissionbt:transmission:2.84`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trapster:trapster:4.3.2::~~~android~~`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.2.0`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.3.0`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.3.1`,
        fs:  `cpe:2.3:a:ipswitch:imail:10.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.4.0`,
        fs:  `cpe:2.3:a:gnugk:gnu_gatekeeper:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.5.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.5.1`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.0:-`,
        fs:  `cpe:2.3:a:symantec:mail_security:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.0:rc1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.1`,
        fs:  `cpe:2.3:a:intel:miwa:9.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.2`,
        fs:  `cpe:2.3:a:horde:groupware:5.1.3:*:*:*:webmail:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.4`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.5`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.6`,
        fs:  `cpe:2.3:a:juniper:junos_space:13.1:r1.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.8`,
        fs:  `cpe:2.3:a:ponsoftware:archive_decoder:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.9`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.10`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\)xt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.12`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.13`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.15s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.14`,
        fs:  `cpe:2.3:o:cisco:catos:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.16`,
        fs:  `cpe:2.3:a:analog:soundmax:5.12.01.7000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.17`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.6.18`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.7.0:-`,
        fs:  `cpe:2.3:a:php:php:5.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.7.0:rc2`,
        fs:  `cpe:2.3:a:adobe:color_common_setcmyk:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.7.1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.7.2`,
        fs:  `cpe:2.3:a:t1lib:t1lib:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.7.3`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:travis_shirk:eyed3:0.7.4`,
        fs:  `cpe:2.3:a:google:toolbar_for_firefox:7.1.20101113b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trend_micro:hijackthis:1.99.1`,
        fs:  `cpe:2.3:h:hp:0235a237:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trend_micro:hijackthis:2.0.0`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:8.0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trend_micro:interscan_web_security_suite:2.5`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trend_micro:interscan_web_security_suite:3.1`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trend_micro:interscan_web_security_virtual_appliance:3.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg243a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trend_micro:mobile_security:3.1::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trend_micro:trend_micro_common_cgi:2.0.0.1227`,
        fs:  `cpe:2.3:a:sophos:unified_threat_management_software:9.007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trend_micro:trend_micro_portalprotect:1.7`,
        fs:  `cpe:2.3:a:apache:geronimo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:common_cgi:2.0.0.1227`,
        fs:  `cpe:2.3:a:boost:boost:1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:hijackthis:1.99.1`,
        fs:  `cpe:2.3:h:hp:procurve_router:jc150b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:hijackthis:2.0.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management:11.3:*:*:*:collaborative:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:internet_security:8.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(3d\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:internet_security:10.0`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:internet_security:2010::pro`,
        fs:  `cpe:2.3:a:hp:operations_manager:8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:internet_security_2010:17.50.1647.0000:-:professional`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_messaging_security_suite:5.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_messaging_security_virtual_appliance:8.5.1.1516`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_web_security_suite:2.5`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_web_security_suite:3.1`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_web_security_virtual_appliance:3.1`,
        fs:  `cpe:2.3:a:x:libxi:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_web_security_virtual_appliance:5.1`,
        fs:  `cpe:2.3:a:avaya:vpnremote:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_web_security_virtual_appliance:5.5`,
        fs:  `cpe:2.3:a:gnu:tar:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_web_security_virtual_appliance:5.6`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:interscan_web_security_virtual_appliance:6.0`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:portalprotect:1.7`,
        fs:  `cpe:2.3:a:acdsee:photo_editor_2008:5.0:build291:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendmicro:tmeext.sys:2.0.0.1014`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.25.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:trendnet:securview_wireless_internet_camera:tv-ip121wn`,
        fs:  `cpe:2.3:h:netgear:wgr614:v9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trendnet:securview_wireless_internet_camera_activex_control:1.1.52.18`,
        fs:  `cpe:2.3:a:cisco:remote_monitoring_suite_option:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:trendnet:tew-812dru:-`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.01.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trendnet:tew-812dru_firmware:1.0.8.0`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trendnet:tew-812dru_firmware:1.0.9.0`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:trendnet:tv-ip422w:-`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.7\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:trendnet:tv-ip422wn:-`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tresata:tree-orion:0.2.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.3160-1`,
        fs:  `cpe:2.3:a:apple:safari:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.4369-1`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.4410-2`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.55.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.4494-1`,
        fs:  `cpe:2.3:a:siemens:scalance_x-300_firmware:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.4794-1`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:036:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.4916-1`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:02-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5033-1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5037-1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5054-1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5068-1`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.24.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5092-1`,
        fs:  `cpe:2.3:h:huawei:s3300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5098-2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5105-1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5137-1`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:4.1.0.17435:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5137-2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p133:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5137-3`,
        fs:  `cpe:2.3:a:vmware:tools:8.4.6.16648:*:*:*:netware:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5137-4`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5137-5`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5192-1`,
        fs:  `cpe:2.3:a:adobe:acrobat:11.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trevor_mckay:cumin:0.1.5192-4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.1.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-1.1`,
        fs:  `cpe:2.3:a:microsoft:visio:2002:sp2:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-1.x-dev`,
        fs:  `cpe:2.3:a:adobe:air_sdk_\&amp;_compiler:19.0.0.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-2.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_2980g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-2.2`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-2.3`,
        fs:  `cpe:2.3:a:usebb:usebb:0.5.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-2.4`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-2.5`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0.200:update20:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-3.0:beta1`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-3.0:beta2`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-3.0:beta3`,
        fs:  `cpe:2.3:a:adobe:bridge_start_meeting:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trexart:campaignmonitor:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trialtracker:trial_tracker:1.1.9::~~~android~~`,
        fs:  `cpe:2.3:a:nowsms:now_sms_\&amp;_mms_gateway:2013.09.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.06.0.171`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.01.00046:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.07.00`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:7.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.08.00`,
        fs:  `cpe:2.3:a:samba:samba:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.09.00`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.371:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.10.00`,
        fs:  `cpe:2.3:a:winpcap:winpcap:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.11.00`,
        fs:  `cpe:2.3:a:openstack:compute:2013.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.14.00`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:4.0.00061:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.15.00`,
        fs:  `cpe:2.3:a:ibm:informix_i-connect:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:.net_communication_protocol_components:3.15.0.369`,
        fs:  `cpe:2.3:a:desire2learn_fusion_2014_project:desire2learn_fusion_2014:4.0.729.1748:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.06.0000`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.90.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.07.0000`,
        fs:  `cpe:2.3:a:google:chrome:43.0.2357.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.08.0000`,
        fs:  `cpe:2.3:a:merethis:centreon:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.09.0000`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.10.0000`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.11.0000`,
        fs:  `cpe:2.3:a:gentoo:xdg-utils:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.12.0000`,
        fs:  `cpe:2.3:a:vmware:server:1.0.1_build_29996:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.13.0000`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.14.0000`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:ansi_c_source_code_libraries:3.15.0000`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:11.5:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.50`,
        fs:  `cpe:2.3:a:hp:openview_omniback_ii:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.50.0309`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.4.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.51`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.53`,
        fs:  `cpe:2.3:a:openchrome:openchrome:0.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0515`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0516`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0517`,
        fs:  `cpe:2.3:a:oracle:exalogic_infrastructure:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0518`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0528`,
        fs:  `cpe:2.3:a:rsi_video_technologies:frontel_protocol:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0529`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s_3.3.1s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0536`,
        fs:  `cpe:2.3:h:hp:nonstop_server:g06.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0540`,
        fs:  `cpe:2.3:a:atlassian:jira:3.9.1:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0544`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.1_beta4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0545`,
        fs:  `cpe:2.3:a:gnu:cvs:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0552`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.227:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0553`,
        fs:  `cpe:2.3:a:hp:web_registration:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0558`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0561`,
        fs:  `cpe:2.3:a:google:chrome:38.0.2125.101:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0562`,
        fs:  `cpe:2.3:a:apple:java_1.4:1:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0564`,
        fs:  `cpe:2.3:a:cybozu:office:9.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0565`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.8:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0566`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.2:*:*:*:professional:android:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0567`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0569`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0570`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0571`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0572`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:263:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0573`,
        fs:  `cpe:2.3:a:apple:itunes:5.0.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0574`,
        fs:  `cpe:2.3:a:intel:network_connections:13.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0575`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.07.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0576`,
        fs:  `cpe:2.3:a:google:search_appliance_software:6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0577`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.70.020.1378:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0578`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.3.2.9.:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0579`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0580`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0581`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0582`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0583`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:2.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0584`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention_server:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0586`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0587`,
        fs:  `cpe:2.3:a:crawlability:vbseo:3.2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0588`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0589`,
        fs:  `cpe:2.3:h:polycom:viewstation_dcp:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0590`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0591`,
        fs:  `cpe:2.3:a:jenkins:git:0.3.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0592`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.3.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0594`,
        fs:  `cpe:2.3:a:stellarinfo:stellar_phoenix_outlook_pst_repair:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0595`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0596`,
        fs:  `cpe:2.3:a:cisco:jabber:9.0\(.1\):-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0597`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.2.3.6514:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0598`,
        fs:  `cpe:2.3:a:individualsoftware:professor_teaches_powerpoint:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:2.54.0599`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:3.00`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2009.312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:3.00.0612`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:3.00.0615`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(26\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:3.00.0616`,
        fs:  `cpe:2.3:h:cisco:aironet_3600:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:3.00.0630`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trianglemicroworks:scada_data_gateway:3.00.0633`,
        fs:  `cpe:2.3:o:conectiva:linux:4.0es:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribiq:tribiq_cms:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribiq:tribiq_cms:5.0.9:b`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.0:-:commercial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribiq:tribiq_cms:5.0.9a:beta`,
        fs:  `cpe:2.3:a:tedfelix:acpid2:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribiq:tribiq_cms:5.0.10a`,
        fs:  `cpe:2.3:a:toshiba:acpi_flash_bios:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribiq:tribiq_cms:5.0.10b:-:community`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:5.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribiq:tribiq_cms:5.0.11e:-:community`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.1\@824267:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tribiq:tribiq_cms:5.0.12c`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribiq:tribiq_cms:5.2.7b`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd921a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribulant:tibulant_slideshow_gallery:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribulant:tibulant_slideshow_gallery:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:cups:1.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribulant:tibulant_slideshow_gallery:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribulant:tibulant_slideshow_gallery:1.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribulant:tibulant_slideshow_gallery:1.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribulant:tibulant_slideshow_gallery:1.4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribulant:tibulant_slideshow_gallery:1.4.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tribunenews365:john_macarthur:1.0.26::~~~android~~`,
        fs:  `cpe:2.3:a:quest:knowledge_xpert:10.1.0.188:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tricerat:screwdrivers_client:4.0.16.77`,
        fs:  `cpe:2.3:o:cisco:ios_xe_99.9z:99.9.0z:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trick_question_project:trick_question:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0wc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trick_question_project:trick_question:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins:git:3.3.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:trick_question_project:trick_question:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:splunk:splunk:6.3.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trick_question_project:trick_question:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:altiris:client_task_server:6.0.1524:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tridentsw:powerzip:-`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tridium:niagra_ax_framework:3.5`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.1.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tridium:niagra_ax_framework:3.6`,
        fs:  `cpe:2.3:a:x.org:libx11:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tridium:niagra_ax_framework:3.7`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:6.5`,
        fs:  `cpe:2.3:a:altiris:express_deployment_datastore:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:8.0.05`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:8.0.12`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:5.0:beta9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:8.0.16`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(2\)e5b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:8.0.18`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.7:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:8.1.05`,
        fs:  `cpe:2.3:a:apple:itunes:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:8.1.06`,
        fs:  `cpe:2.3:a:sap:netweaver_nw04:sp15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.0`,
        fs:  `cpe:2.3:a:uswebstyle:activecollab_chat_module:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.0.02`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p351:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.0.03`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.0.08`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.1.02`,
        fs:  `cpe:2.3:a:tenable:nessus:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.1.03`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.1.05`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.1.09`,
        fs:  `cpe:2.3:a:novell:netmail:3.52a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.1.11`,
        fs:  `cpe:2.3:a:gnu:libtool:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.1.14`,
        fs:  `cpe:2.3:a:apache:poi:3.11:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.1.19`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:9.1.20`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.6.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.13:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.0.11`,
        fs:  `cpe:2.3:a:gnu:gnumeric:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.0.13`,
        fs:  `cpe:2.3:a:redhat:sysstat:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.0.14`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.2.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.0.16`,
        fs:  `cpe:2.3:a:apple:itunes:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.0.17`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.1.05`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.1.06`,
        fs:  `cpe:2.3:a:monotone:monotone:0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.1.07`,
        fs:  `cpe:2.3:h:skyboxsecurity:skybox_view_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.1.12`,
        fs:  `cpe:2.3:o:vmware:esx:2.5.3:patch1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.05`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:b.02.02.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.07`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.08`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.11`,
        fs:  `cpe:2.3:a:hp:thinpro_linux:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.13`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.14`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.15`,
        fs:  `cpe:2.3:a:posh_project:posh:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.17`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.19`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.20`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.21`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:10.2.22`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:5.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.0`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.0.05`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.0.07`,
        fs:  `cpe:2.3:a:oracle:complex_maintenance_repair_and_overhaul:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.05`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.06`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.07`,
        fs:  `cpe:2.3:h:iodata:ts-wlc2_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.09`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.10`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.13`,
        fs:  `cpe:2.3:a:alaaliwat:www.alaaliwat.com:4.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.14`,
        fs:  `cpe:2.3:a:barton:ngircd:18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.15`,
        fs:  `cpe:2.3:a:google:search_appliance_software:6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.16`,
        fs:  `cpe:2.3:a:atlassian:jira:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.17`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr2012-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.18`,
        fs:  `cpe:2.3:a:hp:performance_center:12.20:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.19`,
        fs:  `cpe:2.3:h:sweex:lb000021:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.20`,
        fs:  `cpe:2.3:a:docker:docker:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.21`,
        fs:  `cpe:2.3:a:macromedia:shockwave:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.22`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trihedral:vtscada:11.1.24`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:-`,
        fs:  `cpe:2.3:a:gitlab:gitlab:0.9.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.52`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.60`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.61`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p378:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.62`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.63`,
        fs:  `cpe:2.3:a:packetfence:packetfence:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.70`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.71`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.72`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.73`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.4-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.74`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)u1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.74:f`,
        fs:  `cpe:2.3:a:phpnuke:php-nuke:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.521`,
        fs:  `cpe:2.3:a:adobe:adobe_air:13.0.0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.635`,
        fs:  `cpe:2.3:a:samba:samba:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.721`,
        fs:  `cpe:2.3:a:ibm:security_appscan_source:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.722`,
        fs:  `cpe:2.3:a:rpm:rpm:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.723`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p2_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.724:aim_a`,
        fs:  `cpe:2.3:a:oracle:field_service:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.724:aim_b`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite_sql-server:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.724:aim_c`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:0.6351`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_products:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:1.0`,
        fs:  `cpe:2.3:a:qpw.famvanakkeren:quick_post_widget:1.9.1:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.0`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1`,
        fs:  `cpe:2.3:a:symantec:reporting_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.5.0`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.6000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.5.1`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.6.0`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.7.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.8.0`,
        fs:  `cpe:2.3:o:apple:iphone_os:5.0:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.9.0`,
        fs:  `cpe:2.3:h:symantec:web_gateway_appliance_8450:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.10.0`,
        fs:  `cpe:2.3:h:kyocera:xw300k:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.13.0`,
        fs:  `cpe:2.3:a:hp:thinpro_linux:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:3.1.14.0`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.1.15:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:4.0`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trillian:trillian:5.1.0.19`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.12:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trimble:sketchup:8.0:maintenance_5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trimble:sketchup:2013`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trimble:sketchup_viewer:13.0.4124`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trioniclabs:sentinel:1.0.0`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.7.f12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trioniclabs:sentinel:1.0.1`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:14.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trioniclabs:sentinel:1.0.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trioniclabs:sentinel:1.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trioniclabs:sentinel:1.2`,
        fs:  `cpe:2.3:o:cisco:staros:17.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trioniclabs:sentinel:1.2.1`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trioniclabs:sentinel:1.3`,
        fs:  `cpe:2.3:a:milesj:decoda:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trioniclabs:sentinel:1.31`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tripadvisor:tripadvisor:6.6:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:triplc:nano-10_plc:-`,
        fs:  `cpe:2.3:a:sap:netweaver_business_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:triplc:nano-10_plc_firmware:r80`,
        fs:  `cpe:2.3:a:sun:jdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:triplc:nano-10_plc_firmware:r81`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)t8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tripwire:securecheq:1.0.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tripwire:tripwire_enterprise:8.2.0.5`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tripwire:tripwire_enterprise_agent:8.0.0`,
        fs:  `cpe:2.3:a:jenkins:git:0.6.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:tripwire:tripwire_enterprise_console:8.0.0.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5116he:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tripwire:twoval_plug-in:1.0.0`,
        fs:  `cpe:2.3:a:apache:httpclient:4.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tripwire:via_agent:2.2.0`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:triumfant:triumfant_agent:1.1.3.3165`,
        fs:  `cpe:2.3:a:oracle:database_server:1.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:triumfant:triumfant_agent:4.3.3165`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:-:pre2:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:triumfant:triumfant_agent:4.3.4033.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:triumfant:triumfant_agent:4.3.4065.1`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trivantis:coursemill_enterprise_learning_management_system:4.1:-`,
        fs:  `cpe:2.3:a:refinedwiki:refinedwiki_original_theme:3.5.7:*:*:*:*:confluence:*:*`,
    },
     
    {
        uri: `cpe:/a:trivantis:coursemill_enterprise_learning_management_system:4.1:sp4`,
        fs:  `cpe:2.3:a:moodle:moodle:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trivantis:coursemill_learning_management_system:6.6`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trivantis:coursemill_learning_management_system:6.8`,
        fs:  `cpe:2.3:a:alliedtelesyn:at-tftp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.1`,
        fs:  `cpe:2.3:h:cisco:video_surveillance_4000_ip_cameras:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.2`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.4021:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.2.9`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.2.9.1`,
        fs:  `cpe:2.3:a:wouter_verhelst:nbd:2.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.2.9.2`,
        fs:  `cpe:2.3:a:cisco:prime_infrastructure:2.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.2.9.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.2.9.4`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.3`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-26:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.3.90`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.3.91`,
        fs:  `cpe:2.3:a:sympa:sympa:1.3.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.3.92`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.3.93`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:tr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.3.96`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trojita_project:trojita:0.4`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tropos:1310_distrubution_automation_mesh_router:-`,
        fs:  `cpe:2.3:a:happylabs:hotel_story\:_resort_simulation:1.7.9b:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:tropos:1410_mesh_router:-`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tropos:1410_wireless_mesh_router:-`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.17:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/h:tropos:3310_indoor_mesh_router:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tropos:3320_indoor_mesh_router:-`,
        fs:  `cpe:2.3:a:cipherdyne:fwsnort:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tropos:4310_mobile_mesh_router:-`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tropos:6310_mesh_router:-`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tropos:6320_mesh_router:-`,
        fs:  `cpe:2.3:h:f5:big-ip_1000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tropos:mesh_os:7.9.1`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tropos:mesh_os:7.9.1.1`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:truecaller:truecaller-caller_id_%26_block:4.32::~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trusteer:rapport:3.5.1108.52`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r8_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trusteer:rapport:3.5.1108.55`,
        fs:  `cpe:2.3:a:sun:openwindows:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.2.7:-:~~~android~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.2.8:-:~~~android~~`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.2.9:-:~~~android~~`,
        fs:  `cpe:2.3:o:apple:airport_base_station_firmware:7.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.3.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.3.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.592.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.3.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.3.3:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:4.0.2:001:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.3.4:-:~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(10c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustgo:antivirus_%26_mobile_security:1.3.5:-:~~~android~~`,
        fs:  `cpe:2.3:a:altiris:inventory_solution_documentation:6.1.1059:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustix:antivirus:-`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:-`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:1.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:1.01`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:1.1`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:3.0.25.378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:1.2`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:1.5`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1291.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:2.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:2.1`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.07.0440:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:2.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:trustix:secure_linux:3.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustport:webfilter:5.5.0.2232`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:trustport:webfilter:6.0.0.3033`,
        fs:  `cpe:2.3:a:lesterchan:wp-postviews:1.30:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.0`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:a.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.3`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.8.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.4`,
        fs:  `cpe:2.3:a:apple:cups:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.6`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.0.1.004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.7`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow_set:07-50-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.8`,
        fs:  `cpe:2.3:o:d-link:dcs-932l_firmware:1.13.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.0.9`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.0`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.1`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.2`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.3`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:6.x-1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.4`,
        fs:  `cpe:2.3:a:hp:openview_operations:a.07.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.5`,
        fs:  `cpe:2.3:a:yokogawa:centum_vp_entry_class_software:5.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.6`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.7`,
        fs:  `cpe:2.3:a:isc:bind:9.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.8`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.9`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.2.10`,
        fs:  `cpe:2.3:a:microsoft:lync_server:2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.0`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.1`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0050:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.2`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.3`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.5`,
        fs:  `cpe:2.3:a:cisco:webex_advanced_recording_format_player:t28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.6`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.7`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.8`,
        fs:  `cpe:2.3:a:ibm:websphere_virtual_enterprise:7.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.9`,
        fs:  `cpe:2.3:a:novell:zenworks_servers:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.10`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.11`,
        fs:  `cpe:2.3:h:3com:hiperarc:4.2.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.12`,
        fs:  `cpe:2.3:a:bea:weblogic_server:9.1:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.4.13`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p106:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.1`,
        fs:  `cpe:2.3:a:apache:storm:0.9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.2`,
        fs:  `cpe:2.3:a:otrs:otrs:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.3`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.4`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:12.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.5`,
        fs:  `cpe:2.3:h:nortel:succession_communication_server_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.6`,
        fs:  `cpe:2.3:a:transifex:transifex:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.7`,
        fs:  `cpe:2.3:a:rsa:authentication_manager:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.8`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.9`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.6.10`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.0`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.1`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.81.b-1.0.2.1-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.2`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.3`,
        fs:  `cpe:2.3:a:haxx:curl:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.4`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.5`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.6`,
        fs:  `cpe:2.3:a:juniper:networks_mobility_system_software:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.7`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro:245:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.8`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:6.31.0.0:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.9`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.10`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.7:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:1.8.11`,
        fs:  `cpe:2.3:a:cogentdatahub:cogent_datahub:7.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.0`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.223:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:4.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.4`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.5`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.6`,
        fs:  `cpe:2.3:a:playscape:bouncy_bill_monster_smasher_ed:1.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.7`,
        fs:  `cpe:2.3:a:google:v8:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.8`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.9`,
        fs:  `cpe:2.3:a:redhat:kdelibs:3.1-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.10`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.6.2_rev_a:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.11`,
        fs:  `cpe:2.3:h:moxa:iologic_e2242-t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.12`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.0.13`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.0`,
        fs:  `cpe:2.3:a:oracle:javafx:2.2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.1`,
        fs:  `cpe:2.3:a:x:libx11:1.5.99.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.2`,
        fs:  `cpe:2.3:a:microsoft:exchange_server:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.3`,
        fs:  `cpe:2.3:a:sun:openoffice.org:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.4`,
        fs:  `cpe:2.3:o:opensuse:opensuse:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.5`,
        fs:  `cpe:2.3:a:drupalauth_project:drupalauth:1.2.2:-:-:*:-:simplesamlphp:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.6`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.07.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.7`,
        fs:  `cpe:2.3:o:bluecoat:proxysg:6.5.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.8`,
        fs:  `cpe:2.3:a:josh_fradley:burden:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.9`,
        fs:  `cpe:2.3:h:alliedtelesyn:at-9000_24_ethernetswitch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.10`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.11`,
        fs:  `cpe:2.3:a:google:chrome:2.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.12`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.13`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.2.14`,
        fs:  `cpe:2.3:a:microsoft:active_directory_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.0`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.1`,
        fs:  `cpe:2.3:a:libssh:libssh:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.2`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.5.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.3`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.4`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.5`,
        fs:  `cpe:2.3:a:nashaplaneta:nashaplaneta.su:1.02:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.6`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.7`,
        fs:  `cpe:2.3:a:cisco:meeting_manager_for_mozilla_firefox\/netscape_navigator:7.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.8`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.9`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.10`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.11`,
        fs:  `cpe:2.3:a:hp:openview_omniback_ii:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.12`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd432a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.13`,
        fs:  `cpe:2.3:a:drupal:drupal:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.14`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.15`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.4.16`,
        fs:  `cpe:2.3:a:redhat:uberfire:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.0`,
        fs:  `cpe:2.3:a:cisco:prime_data_center_network_manager:4.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.1`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.72:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.2`,
        fs:  `cpe:2.3:h:willcom-inc:android_smartphone:wx06k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.4`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.5`,
        fs:  `cpe:2.3:a:ca:etrust_identity_minder:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.6`,
        fs:  `cpe:2.3:a:google:chrome:4.0.288.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.7`,
        fs:  `cpe:2.3:a:avaya:wireless_ap-4:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.8`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.9`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.10p9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.10`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.11`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.2019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.12`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.13`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.14`,
        fs:  `cpe:2.3:h:huawei:p7-l10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.15`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.16`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.17`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.1.9:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.6.18`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.20c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:23.0.0.185:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.2`,
        fs:  `cpe:2.3:a:htc:hero_software:1.29.651.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.3`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.5`,
        fs:  `cpe:2.3:a:libav:libav:11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.6`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.9.0-4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.7`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.83.b-1.0.2.1-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.8`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:1.0.2:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.9`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.10`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update33:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.11`,
        fs:  `cpe:2.3:a:vandyke:securecrt_and_securefx:6.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.12`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.13`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.1.71.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.14`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.15`,
        fs:  `cpe:2.3:a:typo3:flow:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:2.8.16`,
        fs:  `cpe:2.3:a:gnu:bash:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.0`,
        fs:  `cpe:2.3:a:qualcomm:gobi_single_installer_package_for_zte:1.1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.1`,
        fs:  `cpe:2.3:a:microsoft:office:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.2`,
        fs:  `cpe:2.3:a:rpm:rpm:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.3`,
        fs:  `cpe:2.3:a:bitcoin:bitcoin-qt:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.4`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.5`,
        fs:  `cpe:2.3:a:imember360:imember360:3.8.009:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.6`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.7`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.8`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.9`,
        fs:  `cpe:2.3:a:atlassian:jira:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.10`,
        fs:  `cpe:2.3:a:ssh:secure_shell_for_servers:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.11`,
        fs:  `cpe:2.3:a:plataformatec:devise:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.12`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.13`,
        fs:  `cpe:2.3:a:drupal:drupal:7.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.14`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.15`,
        fs:  `cpe:2.3:a:altiris:dell_client_configuration_utility:3.0.1210.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.16`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:12.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.0.17`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.0`,
        fs:  `cpe:2.3:a:xymon:xymon:4.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector_net:6.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.2`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.3`,
        fs:  `cpe:2.3:a:intuit:quickbooks:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.4`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.5`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.6`,
        fs:  `cpe:2.3:a:almanah_project:almanah:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.7`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.8`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2011.728.1723.29300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.9`,
        fs:  `cpe:2.3:a:bib2html_project:bib2html:0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.10`,
        fs:  `cpe:2.3:o:novell:opensuse:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.11`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.12`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.13`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.14:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.14`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.15`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.01:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.16`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.2.17`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.0`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.1`,
        fs:  `cpe:2.3:a:arubanetworks:clearpass:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.2`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.3`,
        fs:  `cpe:2.3:a:cisco:catalyst_29xx_supervisor_software:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.4`,
        fs:  `cpe:2.3:a:intel:network_connections:16.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.5`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.6`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(3\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.7`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(14\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.8`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.9`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.10`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.11`,
        fs:  `cpe:2.3:h:hp:officejet_7100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.12`,
        fs:  `cpe:2.3:h:cisco:global_site_selector:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.13`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.14`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.03.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.15`,
        fs:  `cpe:2.3:a:redhat:sendmail:8.12.8-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.16`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.4.17`,
        fs:  `cpe:2.3:a:ibm:intelligent_operations_center:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.0`,
        fs:  `cpe:2.3:a:arellia:arellia_file_inventory_report_pack:6.1.1100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.1`,
        fs:  `cpe:2.3:o:fortinet:fortimanager_firmware:5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.2`,
        fs:  `cpe:2.3:a:piriform:ccleaner:2.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.3`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:51.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.4`,
        fs:  `cpe:2.3:a:gnu:gnubiff:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.5`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.6`,
        fs:  `cpe:2.3:a:redhat:network_satellite_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.7`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.8`,
        fs:  `cpe:2.3:a:kunena:kunena:5.0.3:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.9`,
        fs:  `cpe:2.3:a:otrs:faq:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.10`,
        fs:  `cpe:2.3:a:microsoft:visual_c\&#43;\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.11`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.12`,
        fs:  `cpe:2.3:a:codehaus:redback:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.13`,
        fs:  `cpe:2.3:a:apache:openjpa:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.14`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.15`,
        fs:  `cpe:2.3:a:f5:linerate:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.6.16`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.3\(1.50\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.0`,
        fs:  `cpe:2.3:a:plone:plone:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.1`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.3`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.4`,
        fs:  `cpe:2.3:a:php:php:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.5`,
        fs:  `cpe:2.3:a:bestpractical:rt:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.6`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p248:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.7`,
        fs:  `cpe:2.3:a:cisco:webns:5.0_1.012s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.8`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.9`,
        fs:  `cpe:2.3:a:expressjs:express:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.10`,
        fs:  `cpe:2.3:o:cisco:content_router_4430:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.11`,
        fs:  `cpe:2.3:a:isc:bind:9.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.12`,
        fs:  `cpe:2.3:h:huawei:me60:v600r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.13`,
        fs:  `cpe:2.3:h:cisco:ons_15454_optical_transport_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:3.8.14`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.0`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.1`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.2`,
        fs:  `cpe:2.3:o:huawei:s7700_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.3`,
        fs:  `cpe:2.3:a:openafs:openafs:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.4`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.5`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.6`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.7`,
        fs:  `cpe:2.3:a:divx:divx_player:7.2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.8`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.12.0:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.0.9`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.2.0`,
        fs:  `cpe:2.3:a:marked_project:marked:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.2.1`,
        fs:  `cpe:2.3:a:openinfosecfoundation:suricata:2.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:tryton:4.2.2`,
        fs:  `cpe:2.3:a:daiki_ueno:libfep:0.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:1.4.13`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:1.6.8`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:1.8.7`,
        fs:  `cpe:2.3:a:emc:documentum_foundation_services:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:2.0.5`,
        fs:  `cpe:2.3:a:ipass:ipass_open_mobile:2.4.4:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:2.2.3`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:3.2.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:3.2.9`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:3.4.7`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:3.6.4`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tryton:trytond:3.8.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tsutaya:tsutaya:5.3::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0\(.4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ttfreeware:tigertoms_chat_room:1.0.4`,
        fs:  `cpe:2.3:a:dirlist:dirlist_php:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ttnetmuzik:ttnet_muzik:3.2::~~~android~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tucarro:tucarro:2.0.5::~~~android~~`,
        fs:  `cpe:2.3:a:jruby:jruby:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tufat:mybackup:1.4.0`,
        fs:  `cpe:2.3:o:novell:opensuse:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuleap:tuleap:7.6`,
        fs:  `cpe:2.3:a:apache:qpid:0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:desktop_validator:-`,
        fs:  `cpe:2.3:a:simple_sticky_footer_project:simple_sticky_footer:1.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:desktop_validator:4.7.3`,
        fs:  `cpe:2.3:o:hp:tru64:4.0g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:desktop_validator:4.9.0`,
        fs:  `cpe:2.3:a:adobe:svg_viewer:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:desktop_validator:4.9.2`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:desktop_validator:4.10`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:6.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:desktop_validator:4.11`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.0.0r10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:mailgate_email_firewall:-`,
        fs:  `cpe:2.3:a:ibm:rational_test_virtualization_server:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:mailgate_email_firewall:6.0`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:mailgate_email_firewall:6.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:mailgate_email_firewall:6.2`,
        fs:  `cpe:2.3:h:schneider-electric:tburjr900:05002dh0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:messaging_management_system:-`,
        fs:  `cpe:2.3:o:cisco:small_business_wireless_access_points_firmware:1.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:server_validator_suite:4.9`,
        fs:  `cpe:2.3:a:oracle:retail_open_commerce_platform_cloud_service:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:server_validator_suite:4.10`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:validation_authority:1.0`,
        fs:  `cpe:2.3:a:tibco:spotfire_server:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:validation_authority:1.0.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:validation_authority:4.9`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.3:sp2:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:validation_authority:4.10.6`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.1.9:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:validation_authority:4.11.0`,
        fs:  `cpe:2.3:a:webtrends:system_repository:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tumbleweed:validation_authority_publisher:4.10`,
        fs:  `cpe:2.3:a:pecio-cms:pecio_cms:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:turck:bl20_programmable_gateway:-`,
        fs:  `cpe:2.3:o:freebsd:freebsd:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:turck:bl20_programmable_gateway_firmware:-`,
        fs:  `cpe:2.3:a:avaya:octeldesigner_tm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:turck:bl67_programmable_gateway:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.396:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:turck:bl67_programmable_gateway_firmware:-`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:tus-radis:tus_1947_radis:1::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuttophp:happy_chat:1.0`,
        fs:  `cpe:2.3:o:cisco:ios:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.0`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.1`,
        fs:  `cpe:2.3:a:polarssl:polarssl:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.18`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.11.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.19`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.19.99.1`,
        fs:  `cpe:2.3:a:tincan:phplist:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.19.99.2`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.19.99.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(24\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.20`,
        fs:  `cpe:2.3:a:liftweb:lift:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.21`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.07.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.21:pre1`,
        fs:  `cpe:2.3:a:inria:ocaml:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.23`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:tc3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.23:pre1`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:1.7.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.23.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p5_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.24`,
        fs:  `cpe:2.3:a:mahara:mahara:1.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.24:pre1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.25`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_laptops_desktops:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.25:pre1`,
        fs:  `cpe:2.3:o:yamaha:rtx1200:10.01.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.25:pre2`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.26`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.26:pre1`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.27`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:3.5.0.1060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.27:pre1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.28`,
        fs:  `cpe:2.3:h:cisco:spa922_1-line_ip_phone_with_1-port_ethernet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.28:pre1`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.29`,
        fs:  `cpe:2.3:a:ipython:ipython_notebook:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.31`,
        fs:  `cpe:2.3:a:craig_barratt:backuppc:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:1.31.1`,
        fs:  `cpe:2.3:a:autodesk:autocad:2010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:2.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:2.1`,
        fs:  `cpe:2.3:a:python:python:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:2.1.1`,
        fs:  `cpe:2.3:a:citrix:web_interface:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:chrony:2.2`,
        fs:  `cpe:2.3:a:cisco:webns:7.40.3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tuxfamily:vhffs:4.1.0`,
        fs:  `cpe:2.3:a:ibm:java:6.0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tvbengali:tv_bengali_open_directory:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:wordpress:slideshow_gallery2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tvdr:vdr:1.4.7`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:2.24:build1110801:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tvdr:vdr:1.6.0`,
        fs:  `cpe:2.3:a:synology:video_station:1.2-0453:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:tvt:dvr:td-2308ss-b:-`,
        fs:  `cpe:2.3:a:ibm:tealeaf_customer_experience:9.0.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.6.p-1.0.2.1-03`,
        fs:  `cpe:2.3:o:debian:debian_linux:2.1.8.8.p3-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.7.b-1.0.2.1-00`,
        fs:  `cpe:2.3:a:josso:java_open_single_sign-on_project_home:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.43.b`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.43.p`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.75.b-1.0.2.1-00`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.81.b-1.0.2.1-00`,
        fs:  `cpe:2.3:a:netbeans:netbeans_ide:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.83.b-1.0.2.1-00`,
        fs:  `cpe:2.3:a:seotoaster:seotoaster:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.83.p-1.0.4.2-03`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.87.p-1.0.4.2-17`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.91.p-1.0.2.1-03`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.92.p-1.0.2.1-00`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.1.93.b-1.0.2.1-17`,
        fs:  `cpe:2.3:a:schneider-electric:opc_factory_server:3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.0.b-1.0.2.1-17`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.0.p-1.0.2.1-03`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.2.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.0.p-1.0.2.1-17`,
        fs:  `cpe:2.3:a:12net:login_rebuilder:1.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.0.p-1.0.6.0.32-00`,
        fs:  `cpe:2.3:a:teradata:visual_explain:13.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.0.p-3520a-03`,
        fs:  `cpe:2.3:a:gnu:glibc:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.0.p-3531-00`,
        fs:  `cpe:2.3:h:cisco:guard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.0.p-3531-11`,
        fs:  `cpe:2.3:a:libupnp_project:libupnp:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.0.p-fh-00`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:tvt:dvr_firmware:3.2.9.p-3520a-06`,
        fs:  `cpe:2.3:a:webform_invitation_project:webform_invitation:7.x-2.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:twd-industries:remote-anything:5.60.15`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.0.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:commerce_platform:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.0.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.0.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:winzip:winzip:11.3.8261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.0.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.0.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:autodesk:autocad_civil_3d:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.0.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.368:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.2.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch_6200yl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.2.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.2.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:netscape:communicator:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.2.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.3.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.4.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cart66:cart66_lite_plugin:1.5.1.1:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.4.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.21:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.4.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:lunarcms:lunar_cms:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.4.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:kankun:smartsocket:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.4.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.7:a_beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.4.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.4.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:freebsd:freebsd:9.1:release-p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:2.4.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.5:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.2.11sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:logitech:quickcam:11.70.1200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:esri:arcgis:10.0.2.3200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.4:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:citrix:metaframe_password_manager:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.0.8:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:hp:sitescope_components_patch:11.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.4\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.00:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(23\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:milesj:decoda:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:preplogic:cissp:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.8:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.9:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.10:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:illustrator:16.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.11:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:yamaha:rt103i:4.00.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.12:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.13:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0002_2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.14:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.15:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.16:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.17:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.1.18:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:packettrap:pt360_tool_suite:2.2.5459:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.2.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.2.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.2.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.2.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.2.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:techsmith:camtasia_studio:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_client:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:4.3.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:video_project:video:7.x-2.2:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:novell:data_synchronizer:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:apache:poi:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(2\)_build_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.8:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:siemens:wincc:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.9:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ca:advantage_data_transport:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.10:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.11:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:munin-monitoring:munin:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.12:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:nagios:remote_plug_in_executor:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.13:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.14:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:16.0.889.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:3.3.15:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:dolibarr:dolibarr:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:4.0.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:linksys_playerpt_activex_control:1.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:4.0.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unity_connection:2.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweet-blender:tweet-blender:4.0.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tweetscribe_project:tweetscribe:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twibright:links:2.7`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twibright:links:2.7:pre1`,
        fs:  `cpe:2.3:h:cisco:integrated_services_router_819:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twiki:twiki:-`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twiki:twiki:5.1.0`,
        fs:  `cpe:2.3:a:crazybrowser:crazybrowser:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twiki:twiki:5.1.1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twiki:twiki:5.1.2`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.4.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twiki:twiki:5.1.3`,
        fs:  `cpe:2.3:a:google:chrome:13.0.760.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twiki:twiki:6.0.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilightcms:twilight_cms:5.17:::en`,
        fs:  `cpe:2.3:a:reasoncms:reasoncms:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilightcms:twilight_cms:5.17:::ru`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilio_project:twilio:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilio_project:twilio:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilio_project:twilio:7.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(4\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilio_project:twilio:7.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:openview_performance_core:10.0.131:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilio_project:twilio:7.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8zd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilio_project:twilio:7.x-1.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:dotclear:dotclear:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twilio_project:twilio:7.x-1.9::~~~drupal~~`,
        fs:  `cpe:2.3:h:hp:laserjet_pro_300_color_printer_m351:ce955a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twimp-wp_project:twimp-wp:0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twin_lin_project:twin_lin:5::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:live_meeting:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twistedmatrix:twisted:11.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.3.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:twistedmatrix:twistedweb:2.2.0`,
        fs:  `cpe:2.3:a:hp:solution_center:140.0.213.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twistedmatrix:twistedweb:2.5.0`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitget_project:twitget:3.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:service_manager_extension:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter:groupama_toujours_la:1.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_liveblog_project:twitter_liveblog:1.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:6.x-1.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.5.5.1681:online_windows_2003_x64:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:6.x-1.1`,
        fs:  `cpe:2.3:a:isc:bind:9.10.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:6.x-1.2`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:02-50-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:6.x-1.3`,
        fs:  `cpe:2.3:o:yamaha:rt140e:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:google:chrome:5.0.342.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager_for_vmware:3.1.1:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:7.x-1.0:rc1`,
        fs:  `cpe:2.3:a:adobe:photoshop:17.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:7.x-1.0:rc2`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:7.x-1.0:rc3`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:7.x-1.0:rc4`,
        fs:  `cpe:2.3:a:ubnt:unifi_controller:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:twitter_pull_project:twitter_pull:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:altova:missionkit_2012:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:tylertech:taxweb:3.13.3.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typemoon:fate%2fhollow_ataraxia:-`,
        fs:  `cpe:2.3:a:hp:snmp_agents_for_linux:8.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typemoon:fate%2fstay_night:-`,
        fs:  `cpe:2.3:a:iss:realsecure_workgroup_manager:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typemoon:fate%2fstay_night_%2b_hollow_ataraxia_set:-`,
        fs:  `cpe:2.3:a:isc:bind:9.9.8:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typemoon:witch_on_the_holy_night:-`,
        fs:  `cpe:2.3:a:iconics:genesis32:8.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:flow:1.0.0`,
        fs:  `cpe:2.3:a:libreoffice:libreoffice:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:flow:1.1.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:flow:1.1.1`,
        fs:  `cpe:2.3:h:hp:eliteone_800_g2_23in_t\/nt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:flow:2.0.0`,
        fs:  `cpe:2.3:a:apache:apr-util:0.9.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:flow:2.0.1`,
        fs:  `cpe:2.3:a:galleryproject:gallery:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:neos:1.1.0`,
        fs:  `cpe:2.3:a:elsio:mapa_da_mina:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:neos:1.1.1`,
        fs:  `cpe:2.3:a:yard_radius:yard_radius:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:neos:1.1.2`,
        fs:  `cpe:2.3:a:roderick_braun:ya_googlesearch:0.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:neos:1.2.0`,
        fs:  `cpe:2.3:a:microsoft:excel:2000:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:neos:1.2.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.05.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:neos:1.2.2`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_agent:10.0.13762:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:-`,
        fs:  `cpe:2.3:o:f5:tmos:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:0.4.1`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:3.8.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0`,
        fs:  `cpe:2.3:a:microsoft:works:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.0`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5\)ea:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.2`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.3`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.4`,
        fs:  `cpe:2.3:o:juniper:junos:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.6`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.7`,
        fs:  `cpe:2.3:a:python:python:3.1.2150:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.8`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.9`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.10`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.6.1:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.11`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.12`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.1.0.5:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.0.13`,
        fs:  `cpe:2.3:a:google_doc_embedder:google_doc_embedder:2.5.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1`,
        fs:  `cpe:2.3:a:citrix:hmr_test_pack:2.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.0`,
        fs:  `cpe:2.3:a:cisco:webex_advanced_recording_format_player:28.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.1`,
        fs:  `cpe:2.3:a:gnu:libtool:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.2`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.3`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.4`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.5`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.6`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.7`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p136:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.8`,
        fs:  `cpe:2.3:a:isc:bind:9.8.0:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.9`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:7.6.0.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.10`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.11`,
        fs:  `cpe:2.3:a:redhat:undertow:1.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.12`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.13`,
        fs:  `cpe:2.3:a:slingo:slingo_lottery_challenge:1.0.34:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.14`,
        fs:  `cpe:2.3:o:cisco:rv215w_wireless-n_vpn_router_firmware:1.2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.1.15`,
        fs:  `cpe:2.3:a:citrix:xendesktop:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2`,
        fs:  `cpe:2.3:a:ibm:cognos_express:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.0`,
        fs:  `cpe:2.3:a:skype:skype:3.8.0.96:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.1`,
        fs:  `cpe:2.3:a:redmine:redmine:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_operator:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.3`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p156:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.5`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.6`,
        fs:  `cpe:2.3:a:kaspersky:kaspersky_internet_security:11.4.4.232:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.7`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.3\(1i\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.8`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.9`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.2:rc2:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.10`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:8.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.11`,
        fs:  `cpe:2.3:a:ubercart:ubercart:6.x-2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.12`,
        fs:  `cpe:2.3:a:david_king:vino:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.13`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.14`,
        fs:  `cpe:2.3:a:oracle:sql_trace_analyzer:12.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.15`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.16`,
        fs:  `cpe:2.3:a:enanocms:enano_cms:1.0.6:pl1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.2.17`,
        fs:  `cpe:2.3:a:ibm:integration_bus:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.0`,
        fs:  `cpe:2.3:a:isc:bind:9.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.2`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.3`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.4`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller_enterprise_module:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.5`,
        fs:  `cpe:2.3:a:redhat:rhel_stronghold:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.6`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1276.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.7`,
        fs:  `cpe:2.3:a:digium:asterisk:b.1.3.2:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.8`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:9.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.9`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.10`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.11`,
        fs:  `cpe:2.3:a:arcsight:arcsight_smartconnector:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.12`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.13`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.3.14`,
        fs:  `cpe:2.3:a:rpm:rpm:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4`,
        fs:  `cpe:2.3:a:concrete5:concrete5:5.5.2.1:-:-:ja-jp:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.0`,
        fs:  `cpe:2.3:o:apple:apple_tv:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.2`,
        fs:  `cpe:2.3:h:hp:jf815a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.3`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.4`,
        fs:  `cpe:2.3:a:anydesk:anydesk:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.5`,
        fs:  `cpe:2.3:a:barton:ngircd:20.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.6`,
        fs:  `cpe:2.3:a:hp:insight_control_performance_management:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.7`,
        fs:  `cpe:2.3:a:vmware:gsx_server:2.5.1_build_5336:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.8`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8s\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.9`,
        fs:  `cpe:2.3:a:sun:cluster:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.10`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24:rc1.9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.11`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.12`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.03b43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.13`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.14`,
        fs:  `cpe:2.3:a:boatmob:boat_browser_mini:3.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.4.15`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5`,
        fs:  `cpe:2.3:a:apache:mod_fcgid:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2009.925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_branding:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.2`,
        fs:  `cpe:2.3:a:trihedral:vtscada:8.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.3`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.4`,
        fs:  `cpe:2.3:a:gnu:mailman:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.5`,
        fs:  `cpe:2.3:a:zonelabs:integrity:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.6`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_service_broker:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.7`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.2_18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.8`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.16.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.9`,
        fs:  `cpe:2.3:a:apache:derby:10.8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.10`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.08.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.11`,
        fs:  `cpe:2.3:o:schneider_electric:telvent_rtu_firmware:c3413-500-001d3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.12`,
        fs:  `cpe:2.3:a:keepass:keepass:0.83:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.13`,
        fs:  `cpe:2.3:a:sap:sap_kernel:7.00:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.14`,
        fs:  `cpe:2.3:a:spamtitan:spamtitan:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.15`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.16`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:2.0.5_j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.17`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc3925:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.18`,
        fs:  `cpe:2.3:a:gnu:automake:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.19`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:alpha1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.20`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.21`,
        fs:  `cpe:2.3:a:mcafee:policy_auditor:5.3.0.167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.22`,
        fs:  `cpe:2.3:a:hp:cifs-9000_server:a.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.23`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.24`,
        fs:  `cpe:2.3:o:buffalotech:whr-600d_firmware:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.25`,
        fs:  `cpe:2.3:a:php:php:5.5.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.26`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.27`,
        fs:  `cpe:2.3:a:process-one:ejabberd:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.28`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.29`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:-:syslog:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.30`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.31`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.32`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.33`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.10:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.34`,
        fs:  `cpe:2.3:a:raphael_zschorsch:rzautocomplete:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.35`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.36`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.37`,
        fs:  `cpe:2.3:a:htmlcleaner_project:htmlcleaner:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.38`,
        fs:  `cpe:2.3:a:lookout:lookout:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.5.39`,
        fs:  `cpe:2.3:a:apple:quicktime:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6`,
        fs:  `cpe:2.3:a:google:v8:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.0`,
        fs:  `cpe:2.3:a:peel:peel_shopping:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.18:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.2`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.3`,
        fs:  `cpe:2.3:a:mcafee:email_gateway:7.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.4`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.5`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.6`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.9:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.8`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.9`,
        fs:  `cpe:2.3:a:synology:download_station:3.4-2558:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.10`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:2.63.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.11`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.12`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.13`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.14`,
        fs:  `cpe:2.3:a:roxio:burn_secure:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.15`,
        fs:  `cpe:2.3:a:rocomotion:pm_forum:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.16`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sw4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.17`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.6.18`,
        fs:  `cpe:2.3:a:gnome:evolution:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7`,
        fs:  `cpe:2.3:a:ca:etrust_intrusion_detection:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.0`,
        fs:  `cpe:2.3:a:freelancerkit:freelancerkit:2.35.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.1`,
        fs:  `cpe:2.3:a:json-c_project:json-c:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.2`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.3`,
        fs:  `cpe:2.3:a:djangoproject:django:1.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.4`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r5b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.5`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.6`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.7`,
        fs:  `cpe:2.3:a:apache:traffic_server:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.8`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.9`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.10`,
        fs:  `cpe:2.3:a:sonatype:nexus:2.6.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.11`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.12`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.13`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.14`,
        fs:  `cpe:2.3:a:goautodial:goadmin_ce:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.15`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p147:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.16`,
        fs:  `cpe:2.3:h:apple:airport_extreme:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.17`,
        fs:  `cpe:2.3:h:brivo:acs5000-s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.18`,
        fs:  `cpe:2.3:o:cisco:catos:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.19`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:4.7.20`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(13\)zh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.1`,
        fs:  `cpe:2.3:a:roxio:cineplayer:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.4`,
        fs:  `cpe:2.3:a:contactus:contact_form_7_integrations:1.3.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.5`,
        fs:  `cpe:2.3:h:lexmark:x94x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.6`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.224:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.7`,
        fs:  `cpe:2.3:a:apache:coyote_http_connector:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.8`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.544:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.9`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.10`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:1.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.11`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.12`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.20.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.13`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.0.14`,
        fs:  `cpe:2.3:a:webmin:usermin:1.430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.1`,
        fs:  `cpe:2.3:a:ibm:api_management:4.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.2`,
        fs:  `cpe:2.3:a:netscape:portable_runtime_api:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.3`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.4`,
        fs:  `cpe:2.3:a:monotone:monotone:0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.5`,
        fs:  `cpe:2.3:a:nextapp:echo:3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.7`,
        fs:  `cpe:2.3:o:microsoft:windows_95:-:osr2.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.8`,
        fs:  `cpe:2.3:a:ibm:connections:2.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.1.9`,
        fs:  `cpe:2.3:a:o-dyn:collabtive:0.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2`,
        fs:  `cpe:2.3:a:php:easymoblog:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:alpha1`,
        fs:  `cpe:2.3:a:boeing:drs_data_courier_web:3.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:alpha2`,
        fs:  `cpe:2.3:a:apache:mod_python:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:alpha3`,
        fs:  `cpe:2.3:a:binarymoon:timthumb:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:beta1`,
        fs:  `cpe:2.3:a:hp:operations_agent:8.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:beta2`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:beta3`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.07.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:beta4`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.587:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:beta5`,
        fs:  `cpe:2.3:a:redhat:certificate_system:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:beta6`,
        fs:  `cpe:2.3:a:novell:netware:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:beta7`,
        fs:  `cpe:2.3:a:iobit:amc_security-_antivirus_clean:4.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:rc1`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.0:rc2`,
        fs:  `cpe:2.3:a:ibm:document_connect_for_application_support_facility:1.0.0.1204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.1`,
        fs:  `cpe:2.3:o:f5:tmos:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.2`,
        fs:  `cpe:2.3:a:adobe:framemaker:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.3`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(5.10\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.4`,
        fs:  `cpe:2.3:a:opnet:modeler:16.0.0.10353:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.5`,
        fs:  `cpe:2.3:a:ibm:domino:9.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.6`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.7`,
        fs:  `cpe:2.3:a:ez:ez_publish:3.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.8`,
        fs:  `cpe:2.3:a:3dprotect:3d_eqsecure:4.2:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.9`,
        fs:  `cpe:2.3:o:cisco:vpn_3060_concentrator:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.10`,
        fs:  `cpe:2.3:a:cat:quick_heal:11.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.10:rc1`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.11`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.12`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.13`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.14`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.15`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:6.2.23`,
        fs:  `cpe:2.3:a:qemu:qemu:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.0.0`,
        fs:  `cpe:2.3:a:ncp:vpn_universal_secure_entry_client_premium:2.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.0.1`,
        fs:  `cpe:2.3:a:clamav:clamav:0.68.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.0.2`,
        fs:  `cpe:2.3:a:condor_project:condor:7.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.1.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.2.0`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:6.2.2:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.2.7`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.3.0`,
        fs:  `cpe:2.3:a:isc:bind:9.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.3.1`,
        fs:  `cpe:2.3:h:ibm:system_x3400_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.4.0`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.5.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_desktop:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.0`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.1`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.2`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.3`,
        fs:  `cpe:2.3:a:emc:data_domain_openstorage_plugin:2.3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.4`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.5`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.336:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.7`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.8`,
        fs:  `cpe:2.3:a:piwik:piwik:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:7.6.15`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.54:bpet54l:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typo3:typo3:8.1.1`,
        fs:  `cpe:2.3:a:apache:subversion:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.3`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:9.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.4`,
        fs:  `cpe:2.3:a:cacti:cacti:0.8.6e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.5`,
        fs:  `cpe:2.3:o:tp-link:tl-wrd740n_\(5.0\)_firmware:141217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.1201.1503.27008:*:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.7`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.8`,
        fs:  `cpe:2.3:o:yahama:rt250i:8.02.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.9`,
        fs:  `cpe:2.3:a:cisco:ip_call_center_express_standard:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.10`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.11`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.12`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.13`,
        fs:  `cpe:2.3:a:tincan:phplist:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.14`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.15`,
        fs:  `cpe:2.3:a:oracle:application_server:7.0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:0.9.16`,
        fs:  `cpe:2.3:a:digia:qt:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:1.0.0`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.164:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:1.1.0`,
        fs:  `cpe:2.3:a:thomas_eibner:mod_rpaf:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:1.2.0`,
        fs:  `cpe:2.3:a:oracle:workflow:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:1.3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typoheads:formhandler:1.4.0`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:0.85`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:0.93`,
        fs:  `cpe:2.3:a:microsoft:frontpage:2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:0.95`,
        fs:  `cpe:2.3:a:html-scrubber_project:html-scrubber:0.14:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:0.96`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:bungei:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:0.97`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:0.97.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:7.0.0:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:0.99.8`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.8.7.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:1.1`,
        fs:  `cpe:2.3:a:pavel_zolnikov:command_prompt_explorer_bar:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:1.10`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:typsoft:typsoft_ftp_server:1.11`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:u.s._army_cerdec:armadillo:1.1.0`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uacinemas:ua_cinemas_-_mobile_ticketing:2.9::~~~android~~`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.7.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:uaepd:shopping_cart_script:-`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:7.6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uangel:realtalk:a.0.9.250`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:38.1.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:uanw:united_advantage_nw_federal_cr:1.7::~~~android~~`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubcd4win:ubcd4win:3.50`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:-`,
        fs:  `cpe:2.3:a:telelogic:doors:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0`,
        fs:  `cpe:2.3:a:apache:ofbiz:11.04.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:beta1`,
        fs:  `cpe:2.3:a:elipse:e3:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:beta2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:beta3`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:beta4`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_ibm:14.0.3558:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:beta5`,
        fs:  `cpe:2.3:a:dest-unreach:socat:2.0.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:beta6`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:dev`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:rc1`,
        fs:  `cpe:2.3:a:emc:networker:7.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:rc2`,
        fs:  `cpe:2.3:o:siemens:sinamics_s\/g_family_firmware:4.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:rc3`,
        fs:  `cpe:2.3:a:freebsd:libarchive:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:rc4`,
        fs:  `cpe:2.3:a:netscape:directory_server:4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:rc5`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:rc6`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.262:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.0:rc7`,
        fs:  `cpe:2.3:a:john_franklin:advertisement:6.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.1`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.2`,
        fs:  `cpe:2.3:h:alcatel:omniswitch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.3`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.4`,
        fs:  `cpe:2.3:h:brother:nc-3100h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.7`,
        fs:  `cpe:2.3:a:google:chrome:42.0.2311.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.8`,
        fs:  `cpe:2.3:a:apache:camel:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.9`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.10`,
        fs:  `cpe:2.3:a:ibm:soliddb:7.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p145:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.12`,
        fs:  `cpe:2.3:h:intel:d845bg_motherboard:p04-0023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:6.x-2.13`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:alpha1`,
        fs:  `cpe:2.3:a:k5n:webcalendar:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:alpha2`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:alpha3`,
        fs:  `cpe:2.3:a:shopware:shopware:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:beta1`,
        fs:  `cpe:2.3:a:analects_of_confucius_project:analects_of_confucius:8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:beta2`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:beta3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:beta4`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.0\(.11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:dev`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:rc1`,
        fs:  `cpe:2.3:a:apple:itunes:10.2.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:rc2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.5:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:rc3`,
        fs:  `cpe:2.3:a:typo3:neos:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.0:rc4`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.47.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.1`,
        fs:  `cpe:2.3:a:novell:netmail:3.52e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.2`,
        fs:  `cpe:2.3:a:macromedia:dreamweaver_ultradev:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.4`,
        fs:  `cpe:2.3:a:bea:aqualogic_enterprise_security:2.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.5`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart:ubercart:7.x-3.6`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_currency_conversion_project:ubercart_currency_conversion:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:h:sony:playstation_portable:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:o:bluecoat:proxysg:6.2.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:salome-platform:salome:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.01b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:poi:3.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_views_project:uc_views:6.x-1.0`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_views_project:uc_views:6.x-1.1`,
        fs:  `cpe:2.3:a:ultraedit:ultracompare_professional:4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_views_project:uc_views:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_views_project:uc_views:6.x-2.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.298:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_views_project:uc_views:6.x-3.0`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_views_project:uc_views:6.x-3.1`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_performance_monitor:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_views_project:uc_views:6.x-3.2`,
        fs:  `cpe:2.3:a:nikias_bassen:usbmuxd:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_views_project:uc_views:6.x-3.x:dev`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:7.x-3.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_webform_checkout_pane_project:ubercart_webform_checkout_pane:6.x-3.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:internet_streamer_content_delivery_system:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubercart_webform_checkout_pane_project:ubercart_webform_checkout_pane:7.x-3.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:rayman_legends:1.0.95278`,
        fs:  `cpe:2.3:a:busybox:busybox:1.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:rayman_legends:1.1.100477`,
        fs:  `cpe:2.3:a:oracle:database_server:9.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:rayman_legends:1.2.103716`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.8.1\(34\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:rayman_legends:1.3.140380`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:uplay_pc:2.0`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:uplay_pc:2.0.1`,
        fs:  `cpe:2.3:h:softbank:nec_3g_handset:931n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:uplay_pc:2.0.2`,
        fs:  `cpe:2.3:h:linksys:wet11:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:uplay_pc:2.0.3`,
        fs:  `cpe:2.3:a:nextapp:echo:2.1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:uplay_pc:2.0.4`,
        fs:  `cpe:2.3:o:zyxel:nbg-418n_firmware:1.00\(aadz.3\)c0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:uplay_pc:4.5.2.3010`,
        fs:  `cpe:2.3:a:dli.tools:uploader:1.5.4:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:uplay_pc:4.6.1.3217`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.12.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubi:uplay_pc:4.6.3208`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:49`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:52`,
        fs:  `cpe:2.3:a:ibm:qradar_security_information_and_event_manager:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:53`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:54`,
        fs:  `cpe:2.3:a:desktopstandard:policymaker_software_update_client:2.0.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:55`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:56`,
        fs:  `cpe:2.3:a:emc:documentum_eroom:7.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:57`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:7.0ebr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:58`,
        fs:  `cpe:2.3:a:mediaonlinecenter:lagu_pop_indonesia:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:58.1`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubiquity_slideshow_team:ubiquity-slideshow-ubuntu:58.2`,
        fs:  `cpe:2.3:a:emc:networker:8.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ubnt:aircam:-`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:ubnt:aircam_dome:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zl1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:ubnt:aircam_mini:-`,
        fs:  `cpe:2.3:h:rsa:securid:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ubnt:airvision_firmware:1.1.5`,
        fs:  `cpe:2.3:a:debian:netkit:0.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:ubnt:airvision_firmware:1.1.6`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi:2.3.5`,
        fs:  `cpe:2.3:a:silexlabs:silex:2.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi:2.3.6`,
        fs:  `cpe:2.3:a:vmware:workstation:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi_controller:2.4.3`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi_controller:2.4.4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi_controller:2.4.5`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi_controller:2.4.6`,
        fs:  `cpe:2.3:a:samba:samba:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi_controller:3.1.13`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi_controller:3.2.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi_video:2.1.3`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.2.1-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubnt:unifi_video:3.0.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2009.1104.959.17837:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubooly:ubooly:4.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:database_server:10.1.0.4.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:apt-xapian-index:0.44ubuntu5`,
        fs:  `cpe:2.3:a:tera-charts_project:tera-charts:1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:apt-xapian-index:0.44ubuntu7`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:apt-xapian-index:0.45ubuntu2`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:10.5\(0.98000.88\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:language-selector:0.79`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:12.3.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:language-selector:0.79.1`,
        fs:  `cpe:2.3:a:teradata:multiload:13.10.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:language-selector:0.79.2`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(5\)sr3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:language-selector:0.79.3`,
        fs:  `cpe:2.3:a:google:toolbar:2.0.114.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:language-selector:0.90`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:language-selector:0.110`,
        fs:  `cpe:2.3:a:apache:struts:2.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:obby:-`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ubuntu_developers:systemd:-`,
        fs:  `cpe:2.3:a:hp:shareins:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucdok:tomato:0.0.5::~~~node.js~~`,
        fs:  `cpe:2.3:a:grapecity:data_dynamics_reports:1.6.1871.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucdok:tomato:0.0.6::~~~node.js~~`,
        fs:  `cpe:2.3:a:oracle:sysfw:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucontrol:ucontrol_smart_home_automation:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:uc_browser:5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:1.0`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:1.1`,
        fs:  `cpe:2.3:o:cisco:ios:15.1\(3\)s3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:1.3.0`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:1.4.0`,
        fs:  `cpe:2.3:a:microsoft:plus:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:1.5.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:2.1.0`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g06.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:2.2.0`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:3.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:3.1.1`,
        fs:  `cpe:2.3:a:dlo:simple_anti_bot_registration_engine_plugin:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ucweb:ucmobile_blovestorm:3.2.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:sa540:2.2.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:drupal:drupal:7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:mozilla:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:11.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ni:labwindows:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:0235a20s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:excel:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:wireless_lan_controller_software:8.1.111.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:citrix:password_manager_plugin:4.6.269.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:macromedia:coldfusion_mx:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:toshiba:chec:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:w1.fi:hostapd:0.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_full_existing:2008.225.2153.39091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1057.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:http_server:1.3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.4.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:antivirus_scan_engine:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:qbnz:geshi:1.0.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:erlang-solutions:mongooseim:1.3.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.5.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows_7:-:-:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:4.2:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:winscp:winscp:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:framemaker:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:razorcms:razorcms:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.4::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:airespace_6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openvpn:openvpn_access_server:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:concursive:concursive:2.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:udesign_project:udesign:2.7.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uhcu:united_heritage_mobile:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uiga:fan_club:-`,
        fs:  `cpe:2.3:o:fortinet:fortianalyzer_firmware:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uiga:personal_portal:-`,
        fs:  `cpe:2.3:a:joomlaboat:com_youtubegallery:4.0.0:*:*:*:*:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/a:uiu4you:universal_imaging_utility:3.0.0.9`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uiu4you:universal_imaging_utility:4.0.3.0::~~live_version~~~`,
        fs:  `cpe:2.3:a:docker:docker:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uiu4you:universal_imaging_utility:4.6.1.0::~~live_version~~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p302:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uiu4you:universal_imaging_utility:4.6.2.0::~~live_version~~~`,
        fs:  `cpe:2.3:a:kadu:kadu:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ukbusinessaid:nigerias_business_directory:0.70.13414.17619::~~~android~~`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.13.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulead:photo_explorer:8.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulead:photoimpact:10.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:2011205`,
        fs:  `cpe:2.3:h:cisco:rv110w_wireless-n_vpn_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20100208`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110609`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110610`,
        fs:  `cpe:2.3:a:microsoft:systems_management_srv:1.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110614`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110615`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110616`,
        fs:  `cpe:2.3:a:nvidia:physx_system_software:260.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110621`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.10-60.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110622`,
        fs:  `cpe:2.3:a:freemind:freemind:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110627`,
        fs:  `cpe:2.3:a:vandyke:absoluteftp:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110630`,
        fs:  `cpe:2.3:h:hp:t5740e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110701`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110714`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110716`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110722`,
        fs:  `cpe:2.3:a:ibm:soliddb:4.5.176:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110726`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.5:-:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110727`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110730`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro_55:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110731`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110803`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.04.315:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110807`,
        fs:  `cpe:2.3:a:mcafee:quickclean:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110808`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110809`,
        fs:  `cpe:2.3:a:vmware:gsx_server:2.0.1_build_2129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110810`,
        fs:  `cpe:2.3:o:cisco:nx-os:11.2\(3e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110811`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.1r1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110813`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110826`,
        fs:  `cpe:2.3:a:konstanty_bialkowski:libmodplug:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110829`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110830`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110901`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110905`,
        fs:  `cpe:2.3:a:lxml:lxml:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110906`,
        fs:  `cpe:2.3:a:apache:groovy:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110907`,
        fs:  `cpe:2.3:a:schneems:wicked:0.3.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110919`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110920`,
        fs:  `cpe:2.3:a:synology:cloud_station:3.0-3108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110921`,
        fs:  `cpe:2.3:a:redhen_project:redhen:7.x-1.5:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20110930`,
        fs:  `cpe:2.3:a:ibm:rational_rhapsody_design_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111003`,
        fs:  `cpe:2.3:a:gnu:mailutils:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111005`,
        fs:  `cpe:2.3:a:apple:safari:2.0.3:417.9.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111013`,
        fs:  `cpe:2.3:a:qemu:qemu:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111028`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0.0:p247:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111102`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111108`,
        fs:  `cpe:2.3:a:trendmicro:internet_security:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111115`,
        fs:  `cpe:2.3:a:rsyslog:rsyslog:7.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111129`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111230`,
        fs:  `cpe:2.3:a:oracle:application_server_web_cache:10.1.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20111231`,
        fs:  `cpe:2.3:a:arg0:encfs:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120102`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120106`,
        fs:  `cpe:2.3:a:lenovo:shareit:2.5.1.1:*:*:*:*:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120117`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120125`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120201`,
        fs:  `cpe:2.3:a:zip_attachments_project:zip_attachments:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120202`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120203`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120204`,
        fs:  `cpe:2.3:a:apple:itunes:12.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120207`,
        fs:  `cpe:2.3:a:adobe:air_sdk:20.0.0.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120301`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.821:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120305`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120404`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.8:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120406`,
        fs:  `cpe:2.3:a:csp_mysql_user_manager_project:csp_mysql_user_manager:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120407`,
        fs:  `cpe:2.3:a:plone:plone:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120426`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.30.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120502`,
        fs:  `cpe:2.3:a:isode:m-link:15.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120504`,
        fs:  `cpe:2.3:a:sixapart:movabletype:5.2.11:*:*:*:open_source:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120601`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120605`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.0.0:ea3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120606`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120621`,
        fs:  `cpe:2.3:a:netiq:self_service_password_reset:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120701`,
        fs:  `cpe:2.3:h:3com:3c8432:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120702`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120705`,
        fs:  `cpe:2.3:a:google:web_toolkit:1.4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120709`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120710`,
        fs:  `cpe:2.3:a:gnu:a2ps:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120711`,
        fs:  `cpe:2.3:h:cisco:as5400_universal_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120715`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.2.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20120718`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20121027`,
        fs:  `cpe:2.3:h:hp:1055_network_printer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20130211`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(1\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20140313`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20140530`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ulli_horlacher:fex:20140603`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimate_target-armored_sniper_project:ultimate_target-armored_sniper:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimus:adaptive_bpm_suite:8.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimus:adaptive_bpm_suite:8.2_cp3`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.2:-:driveshield:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimus:ultimus_business_process_management_suite:5.0`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimus:ultimus_business_process_management_suite:6.0`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2003_server:6.3.1701:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimus:ultimus_business_process_management_suite:7.0`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimus:ultimus_business_process_management_suite:7.1`,
        fs:  `cpe:2.3:a:libtiff:libtiff:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimus:ultimus_business_process_management_suite:8.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultimus:ultimus_client:8.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:uestudio:10.30.2`,
        fs:  `cpe:2.3:a:cisco:firepower_threat_defense:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:6.00`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:6.10`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:6.20`,
        fs:  `cpe:2.3:a:ibm:worklight:6.1.0.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:6.30`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:6.40`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:6.40.1`,
        fs:  `cpe:2.3:o:iij:seil\%2fturbo_firmware:2.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:7.0.95`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:7.0.97`,
        fs:  `cpe:2.3:a:apple:apple_remote_desktop:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:7.2.1010`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:8.0.1010`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare:8.0.1012`,
        fs:  `cpe:2.3:a:altiris:realtime_console_infrastructure:6.3.1066:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare_professional:4.10a`,
        fs:  `cpe:2.3:a:tibco:formvine:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultracompare_professional:4.20`,
        fs:  `cpe:2.3:a:umn:mapserver:6.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:1`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:8.00`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:8.00a`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:8.00b`,
        fs:  `cpe:2.3:a:nero:recode_help:3.53.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:8.10`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:8.10a`,
        fs:  `cpe:2.3:a:opsview:opsview:4.1:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:8.10b`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:8.20`,
        fs:  `cpe:2.3:a:thegr:dl:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:8.20a`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.00`,
        fs:  `cpe:2.3:a:jayj:cakifo:1.4.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.00a`,
        fs:  `cpe:2.3:a:oracle:payroll:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.00b`,
        fs:  `cpe:2.3:a:f5:linerate:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.00c`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.11.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.10`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.10a`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.60:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.10b`,
        fs:  `cpe:2.3:a:juniper:network_and_security_manager_software:2012.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.20`,
        fs:  `cpe:2.3:a:teamquest:manager:10.2.3445:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.20a`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:9.20b`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.00`,
        fs:  `cpe:2.3:a:lester_chan:wp-downloadmanager:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.00a`,
        fs:  `cpe:2.3:a:janesoft:janetter:3.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.00b`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.00c`,
        fs:  `cpe:2.3:h:mcdata:intrepid_6064_director_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.10`,
        fs:  `cpe:2.3:a:avaya:communication_manager:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.10a`,
        fs:  `cpe:2.3:a:sawmill:sawmill:6.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.10b`,
        fs:  `cpe:2.3:a:kde:koffice:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.10c`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.20`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.20a`,
        fs:  `cpe:2.3:a:oracle:traffic_director:11.1.1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.20b`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.20c`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:10.20d`,
        fs:  `cpe:2.3:a:apple:cups:1.1.6-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:11.00`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_data_growth_for_oracle_e-business_suite:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:11.00a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:11.00b`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:11.10`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:11.10a`,
        fs:  `cpe:2.3:a:sap:ccms_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:11.10b`,
        fs:  `cpe:2.3:a:jetaudio:jetaudio:8.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:11.10c`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.97.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:11.20`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:12.00`,
        fs:  `cpe:2.3:a:google:chrome:13.0.777.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:12.10`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:12.10a`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.0.3.b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:12.10b`,
        fs:  `cpe:2.3:a:iss:realsecure_desktop:3.6eca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:12.20`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:12.20a`,
        fs:  `cpe:2.3:a:tryton:tryton:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:12.20b`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:13.00`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:13.00a`,
        fs:  `cpe:2.3:a:virginhealthmiles:gozone_isync:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:13.10`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:13.10a`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:13.20`,
        fs:  `cpe:2.3:a:vmware:player:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.00`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.00a`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.00b`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:15.02.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.2`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.2.31`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.10.0`,
        fs:  `cpe:2.3:o:siemens:ruggedcom_rugged_operating_system:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.10.1`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.20.0`,
        fs:  `cpe:2.3:a:emc:vmware_server:1.0.4_build_56528:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:14.20.1`,
        fs:  `cpe:2.3:a:google:v8:3.12.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:15.00.0`,
        fs:  `cpe:2.3:a:hp:openview_nnm_advanced_edition_device_support_for_fdp:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:15.0.32`,
        fs:  `cpe:2.3:a:drupal:drupal:8.2.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:15.10.0`,
        fs:  `cpe:2.3:o:y-cam:ycb002_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:15.20.0`,
        fs:  `cpe:2.3:a:emc:legato_networker:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:16.10.0.1036`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:16.20.0.1009`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:16.30.4`,
        fs:  `cpe:2.3:a:sympa:sympa:5.4b.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit:16.30.11`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.0.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit-32:10.10b`,
        fs:  `cpe:2.3:a:tornadoweb:tornado:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit-32:10.20d%2b`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1001.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit-32:11.00a`,
        fs:  `cpe:2.3:a:dotcms:dotcms:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit-32:11.20b`,
        fs:  `cpe:2.3:a:debian:toolchain-source:3.0.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit-32:12.10b`,
        fs:  `cpe:2.3:a:samba:samba:3.0.21:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraedit:ultraedit-32:12.20b`,
        fs:  `cpe:2.3:o:novell:suse_linux:11:sp1:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraiso:ultraiso:9.35::~~premium~~~`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraplayer:ultraplayer_media_player:-`,
        fs:  `cpe:2.3:a:simple_visitor_stat_project:simple_visitor_stat:-:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraplayer:ultraplayer_media_player:2.112`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.5.2-201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultrapop:i-httpd:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraseek:ultraseek:5.1.1`,
        fs:  `cpe:2.3:a:ircd-hybrid:ircd-hybrid:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraseek:ultraseek:5.2.2`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraseek:ultraseek:5.3.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraseek:ultraseek:5.3.4`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.3.2j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraseek:ultraseek:5.4.1`,
        fs:  `cpe:2.3:a:smarty:smarty:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraseek:ultraseek:5.4.2`,
        fs:  `cpe:2.3:h:xerox:workcentre_m165:8.47.33.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraseek:ultraseek:5.6.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultraseek:ultraseek:5.7.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)ys1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultravnc:vnc_viewer:-`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ultravnc:vnc_viewer:3.3.3_r2`,
        fs:  `cpe:2.3:a:matrixssl:matrixssl:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.3.3.9`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.5.0`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:0.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.5.2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.5.3`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.6`,
        fs:  `cpe:2.3:a:ncr:wintools_for_windows:2.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.6.1`,
        fs:  `cpe:2.3:a:bundler:bundler:1.4.0:pre.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.6.2`,
        fs:  `cpe:2.3:a:vmware:vcenter_update_manager:4.1.0.6589:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.6.3`,
        fs:  `cpe:2.3:h:bradfordnetworks:network_sentry_appliance:ns500x:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.6.4`,
        fs:  `cpe:2.3:a:gnu:data_display_debugger:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.6.5`,
        fs:  `cpe:2.3:a:python:python:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.6.7`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.6.8`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.7.0`,
        fs:  `cpe:2.3:a:saltstack:salt:0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.7.2`,
        fs:  `cpe:2.3:a:juralsulek:realurlmanagement:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.7.3`,
        fs:  `cpe:2.3:a:web2py:web2py:1.88.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.7.4`,
        fs:  `cpe:2.3:a:artis.imag:basilic:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.0.5`,
        fs:  `cpe:2.3:a:redhat:jbpm:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.1`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd946a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.1.2`,
        fs:  `cpe:2.3:a:microsoft:excel_for_mac:2011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.1.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.3`,
        fs:  `cpe:2.3:a:christoph_dorn:firephp:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.4`,
        fs:  `cpe:2.3:a:cisco:ip_communicator:8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.4.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.99:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.4.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.4.3`,
        fs:  `cpe:2.3:o:redhat:linux:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.4.4`,
        fs:  `cpe:2.3:a:oracle:http_server:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.5.1`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.5.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-crytography-api:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.5.3`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.6`,
        fs:  `cpe:2.3:a:gnu:gzip:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.8.6.1`,
        fs:  `cpe:2.3:a:oracle:olap:12.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.9`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.9.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla_suite:1.7.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umi-cms:umi.cms:2.9.5`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.1:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.2`,
        fs:  `cpe:2.3:a:skype:skype:1.0.0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.3`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.4`,
        fs:  `cpe:2.3:a:google:chrome:16.0.886.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.5`,
        fs:  `cpe:2.3:a:quassel-irc:quassel_irc:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.6`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.7`,
        fs:  `cpe:2.3:a:perl:perl:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.8`,
        fs:  `cpe:2.3:a:apache:openjpa:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.9`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.8:cert1_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.10`,
        fs:  `cpe:2.3:a:gromada:multimedia_conversion_library:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssapi:0.11`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssglue:0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:11.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssglue:0.2`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssglue:0.3`,
        fs:  `cpe:2.3:a:altiris:helpdesk_solution:6.0.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umich:libgssglue:0.4`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:20.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.2:beta1`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.4.0`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.4.0:beta1`,
        fs:  `cpe:2.3:a:ibm:lotus_symphony:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.4.0:beta2`,
        fs:  `cpe:2.3:a:gnu:glibc:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.4.0:beta3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.6.0`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.6.0:beta1`,
        fs:  `cpe:2.3:a:codiad:codiad:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.6.0:beta2`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.6.0:beta3`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.0.0:-:liberty_profile:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.6.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:15.4\(2\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.8:beta1`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.9:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.8:beta2`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.8:beta3`,
        fs:  `cpe:2.3:a:cybozu:kunai:2.1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.8:rc1`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.8:rc2`,
        fs:  `cpe:2.3:a:atmail:atmail:6.20.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10:beta1`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:3.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10:beta2`,
        fs:  `cpe:2.3:a:pgp:personal_privacy:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10:beta3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-50-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10:rc1`,
        fs:  `cpe:2.3:a:babygekko:baby_gekko:0.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10.0`,
        fs:  `cpe:2.3:a:cisco:vpn_client:4.8.00.0000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10.1`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10.2`,
        fs:  `cpe:2.3:a:freedownloadmanager:free_download_manager:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10.3`,
        fs:  `cpe:2.3:a:baidu:baidu_navigation:3.5.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10.4`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:4.10.5`,
        fs:  `cpe:2.3:a:rpm:rpm:2.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0`,
        fs:  `cpe:2.3:a:ssh:tectia_client:5.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0:beta1`,
        fs:  `cpe:2.3:a:adobe:illustrator:12.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0:beta2`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:3.5.1:015:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0:beta3`,
        fs:  `cpe:2.3:a:cisco:telepresence_advanced_media_gateway:1.1\(1.40\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0:beta4`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0:beta5`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:6.0.0.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0:beta6`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0:rc1`,
        fs:  `cpe:2.3:a:jffnms:just_for_fun_network_management_system:0.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.0.0:rc2`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.2.0`,
        fs:  `cpe:2.3:a:crawlability:vbseo:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.2.0:beta1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.2.0:beta2`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.2.0:beta3`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.2.0:beta4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.430:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.2.0:rc1`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.2.1`,
        fs:  `cpe:2.3:a:microsoft:virtual_machine_manager:2012:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.0`,
        fs:  `cpe:2.3:a:firaxis:sid_meiers_civilization_chronicles:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.0:beta1`,
        fs:  `cpe:2.3:h:wdc:my_net_n750:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.0:beta2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.0:beta3`,
        fs:  `cpe:2.3:a:samba:samba:3.6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.0:beta4`,
        fs:  `cpe:2.3:a:xnview:xnview:1.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.0:rc1`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.0:rc2`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.4.2`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.6.0`,
        fs:  `cpe:2.3:a:tripwire:tripwire_enterprise:8.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.6.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:5.6.3`,
        fs:  `cpe:2.3:a:embedthis:appweb:4.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.0.1`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.314:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.0.2`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.0.3`,
        fs:  `cpe:2.3:a:hp:storageworks_xp_paxp_service_host_agent:3.40.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.0.4`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.0.5`,
        fs:  `cpe:2.3:o:hp:tru64:5.1a_pk6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.0`,
        fs:  `cpe:2.3:a:tryton:tryton:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.0:b1`,
        fs:  `cpe:2.3:a:corel:wordperfect:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.0:b2`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.0:b3`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:07-00:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.0:b4`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.6:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.0:rc1`,
        fs:  `cpe:2.3:h:cisco:dpq3925:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.1`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.2.3`,
        fs:  `cpe:2.3:h:sony:sony_network_camera_snc-p5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.4.0`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.4.0:b1`,
        fs:  `cpe:2.3:a:novell:netware_client:4.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.4.0:b2`,
        fs:  `cpe:2.3:a:php:php:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.4.0:rc1`,
        fs:  `cpe:2.3:h:huawei:secospace_usg6500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.4.1`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.42:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.4.2`,
        fs:  `cpe:2.3:a:keepass:keepass:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.4.3`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.01:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:6.4.4`,
        fs:  `cpe:2.3:h:galilmc:rio-47100_plc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:7.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:7.0.0:b1`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_elastic_runtime:1.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:7.0.0:b2`,
        fs:  `cpe:2.3:a:php:php:5.4.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:7.0.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:umn:mapserver:7.0.3`,
        fs:  `cpe:2.3:a:python:python:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unace_project:unace:1.2b`,
        fs:  `cpe:2.3:a:symantec:veritas_gridnode_agent:5.0.141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unadf_project:unadf:1.0`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unconfirmed_project:unconfirmed:1.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unicreditgroup:unicredit_investors:1::~~~android~~`,
        fs:  `cpe:2.3:a:panasonic:network_camera_view:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unify:sqlbase_clients:7.6.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unify:sqlbase_sqlconsole:7.6.0`,
        fs:  `cpe:2.3:a:hp:support_solution_framework:11.51.0027:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unikey:unikey:3.63`,
        fs:  `cpe:2.3:a:ibm:maximo_anywhere:7.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:mod_auth_mellon:0.8.0`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.0`,
        fs:  `cpe:2.3:o:dell:idrac7_firmware:1.23.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.0:alpha`,
        fs:  `cpe:2.3:h:linksys:wet11:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.0:alpha-p1`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.0:p1`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.1:alpha`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.12.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.1:beta`,
        fs:  `cpe:2.3:o:google:chrome_os:20.0.1132.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.3:alpha`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.3:beta`,
        fs:  `cpe:2.3:a:dotnetblogengine:blogengine.net:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.3.1`,
        fs:  `cpe:2.3:a:adobe:robohelp:x5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.4`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.4.1`,
        fs:  `cpe:2.3:h:hp:j9470a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.4.2`,
        fs:  `cpe:2.3:a:pgp:keyserver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.4.3`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp0a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.5`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.0.4:-:win32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.6`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.4.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uninett:radsecproxy:1.6.1`,
        fs:  `cpe:2.3:h:fortinet:fortigate-5001b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:enterprise_output_manager:6.1.0`,
        fs:  `cpe:2.3:a:tibco:spotfire_analyst:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:enterprise_output_manager:6.1.2`,
        fs:  `cpe:2.3:a:cisco:vpn_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:enterprise_output_manager:9.0.0.0`,
        fs:  `cpe:2.3:a:ibm:cognos_disclosure_management:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:enterprise_output_manager_client:7.1.6`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.2:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:enterprise_output_manager_client:9.0.0.0`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:enterprise_output_manager_secure_e-mail:1.0.0.0`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:enterprise_output_manager_service:7.1.6`,
        fs:  `cpe:2.3:a:symantec:veritas_dmp_dsm_solution:5.1.10000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:unisys:fs600:-`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:unisys:libra_4300:-`,
        fs:  `cpe:2.3:a:freeradius:freeradius:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:unisys:libra_6300:-`,
        fs:  `cpe:2.3:h:hp:jf287a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:unisys:libra_8300:-`,
        fs:  `cpe:2.3:o:raritan:px:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:unisys:mcp_firmware:40.0`,
        fs:  `cpe:2.3:a:novell:groupwise_enhancement_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:sentinel_alert_service:9.2.8`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:13.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:sma_microsoft_lsam_.net:5.3.3.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:sma_sam_and_supporting_services:4.25.5`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unisys:sma_user_interface:4.25.4`,
        fs:  `cpe:2.3:a:simple_ads_manager_project:simple_ads_manager:2.5.96:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:unit4:prosoft_hrms:8.14.230.47`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yt:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unitedecu:united_educational_cu:1.0.27::~~~android~~`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0.4:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unitedhawknation:united_hawk_nation:2.1::~~~android~~`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unitedplanet:intrexx:5.2::~~professional~~~`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unitedplanet:intrexx:6.0::~~professional~~~`,
        fs:  `cpe:2.3:h:hp:0235a38n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unitrends:enterprise_backup:7.3.0`,
        fs:  `cpe:2.3:a:info-zip:unzip:6.10b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unitronics:visilogic_oplc_ide:9.8.0.00`,
        fs:  `cpe:2.3:a:mcafee:asset_baseline_monitor:3.5.0.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.2`,
        fs:  `cpe:2.3:a:intel:proset_wireless:12.4.4000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.2:1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14.5\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.2:2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.2:3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.03.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.2:4`,
        fs:  `cpe:2.3:a:surveytracker:surveytracker:5.6:*:*:*:desktop:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.2:5`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(4\)ea1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.3`,
        fs:  `cpe:2.3:a:nodejs:node.js:6.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.3:1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.5.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.3:2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.3:3`,
        fs:  `cpe:2.3:a:apache:tomcat:4.1.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.3:4`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:15-11-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.3:5`,
        fs:  `cpe:2.3:a:paloaltonetworks:globalprotect:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.3:6`,
        fs:  `cpe:2.3:a:apache:poi:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.3:7`,
        fs:  `cpe:2.3:a:boost:boost:1.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.4`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.01:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.4:1`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.4:2`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.4:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:2.4:3`,
        fs:  `cpe:2.3:a:litespeedtech:litespeed_web_server:4.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:univention:univention_corporate_server:3.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.0.0:alpha`,
        fs:  `cpe:2.3:a:digium:asterisk:10.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.0.0:beta`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.0.2:beta`,
        fs:  `cpe:2.3:o:cisco:ios:11.2bc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.0.5:beta`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:6.1.0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.0.6:beta`,
        fs:  `cpe:2.3:a:symantec:product_authentication_service:4.3.32.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.7:beta`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:5.40.020.1238:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8`,
        fs:  `cpe:2.3:o:virtualaccess:gw6110a_firmware:9.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.1`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.3`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.5`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.6`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.7`,
        fs:  `cpe:2.3:o:brocade:fabric_os:5.2.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.8`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.9`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.10`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.11`,
        fs:  `cpe:2.3:a:square:okhttp:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.12`,
        fs:  `cpe:2.3:h:nortel:vpn_router_1010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:1.8.13`,
        fs:  `cpe:2.3:a:apache:struts:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.0:alpha`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:20.0.0.306:*:*:*:*:internet_explorer:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.1:alpha`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.2`,
        fs:  `cpe:2.3:h:foundrynet:bigiron_15000_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.3`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.4`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.202:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.22:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.6`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.7`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.8`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.9`,
        fs:  `cpe:2.3:a:christophe_thibault:k-meleon:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.10`,
        fs:  `cpe:2.3:a:gajim:gajim:0.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.0.11`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:1.1\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.1.0`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.1.1`,
        fs:  `cpe:2.3:a:lucent:vitalsuite:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.1`,
        fs:  `cpe:2.3:a:sophos:safeguard_easy_device_encryption_client:5.50.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.2`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.10:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.3`,
        fs:  `cpe:2.3:a:gizra:og_vocab:6.x-1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.4`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.5`,
        fs:  `cpe:2.3:a:appsflyer:appsflyer:-:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.6`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.7`,
        fs:  `cpe:2.3:h:xerox:phaser_8560:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.8`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.0518.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.9`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.10`,
        fs:  `cpe:2.3:h:kyocera:xw310k:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.11`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(1\)xd3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.12`,
        fs:  `cpe:2.3:a:google:chrome:16.0.902.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.13`,
        fs:  `cpe:2.3:a:apache:activemq:4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.2.14`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.3.0`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:2.3.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:3.0.0:alpha`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:8.5.0-000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:3.0.1:alpha`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unixodbc:unixodbc:3.0.2:alpha`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.1.0:a2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unrealircd:unrealircd:3.2.10`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unrealircd:unrealircd:3.2.10.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unrealircd:unrealircd:3.2.10.2`,
        fs:  `cpe:2.3:a:google:chrome:0.1.42.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unrtf_project:unrtf:0.21.6`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(4\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:unzoo:unzoo:-`,
        fs:  `cpe:2.3:a:agi:stk_engine_deployment_resources:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uoregon:tau:2.16.4`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.4.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:upasanhar:harivijay:4::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:upc:ireland_cisco_epc2425:-`,
        fs:  `cpe:2.3:o:cisco:ons_15454_optical_transport_platform:4.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.4.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.4.5.1::~~~ruby~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.4xj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.4.5.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.4.5.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.4.5.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.4.5.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:ultravnc:vnc_viewer:3.3.3_r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.5.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.5.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.5.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.5.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:gnu:tar:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:vmware:server:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.2::~~~ruby~~`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:*:x64-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.4::~~~ruby~~`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.5::~~~ruby~~`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.5.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:combodo:itop:1.2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.5.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:adobe:photoshop_cs5:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.5.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.6::~~~ruby~~`,
        fs:  `cpe:2.3:a:sybase:adaptive_server:12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.6.1::~~~ruby~~`,
        fs:  `cpe:2.3:a:maccabi4u:maccabi_pakal:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.6.2::~~~ruby~~`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplawski:creme_fraiche:0.6.6.3::~~~ruby~~`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.0.0:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/h:uplogix:local_manager_5000:-`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplus:u%2bbox_2.0:2.0.2`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplus:u%2bbox_2.0:2.0.8.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uplus:u%2bbox_2.0_pad:2.0.8.4`,
        fs:  `cpe:2.3:a:metastorm:process_manager:8.1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ups:worldship_msichecker:9.0.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:3.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ups:worldship_system:14.0.0`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ups:worldship_upsdb:14.0.0`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ups:worldship_upsvcmm:1.0.0`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ups:worldship_upsvcmm:12.0.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urbanairship:python-oauth2:-`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.37.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urbantwilight:duperazor:3.3`,
        fs:  `cpe:2.3:a:microsoft:windows_media_rights_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:url_cloak_%26_encrypt_project:url_cloak_%26_encrypt:2.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.0.0`,
        fs:  `cpe:2.3:a:ati:control_panel:6.14.10.5125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.0.1`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.0.2`,
        fs:  `cpe:2.3:h:symantec:nexland_pro800turbo_firewall_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.1.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_application_server:06-70-\/g:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.1.1`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-beta2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.1.2`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.1.3`,
        fs:  `cpe:2.3:a:double-take_software:double-take:5.1.1.1136.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.1.4`,
        fs:  `cpe:2.3:h:cisco:mds_9140:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.2.0`,
        fs:  `cpe:2.3:a:altiris:notification_server_configurator:6.0.5010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_maag:maag_form_captcha:1.2.1`,
        fs:  `cpe:2.3:a:pgp:universal_server:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_wolfer:kwebkitpart:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:urs_wolfer:kwebkitpart:0.9.6:beta`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usaa:mobile_banking:7.10::~~~android~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usaf:accm:1.0.0.1047`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usaf:accm:1.0.0.1066`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.0:beta.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usarmy:viewer_armyifx:3.5.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usbank:academy_sports_%2b_outdoors_visa:1.18::~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:site_server_commerce:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:5.1.160.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.1.1`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.2`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.2.1`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.2.2`,
        fs:  `cpe:2.3:a:hp:select_identity:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.2.3`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:4.0.0:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.2.3:a`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.231:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.3.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.3.2`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.4`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.15:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.4.1`,
        fs:  `cpe:2.3:a:gajim:gajim:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.5`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.5.1`,
        fs:  `cpe:2.3:a:justsystems:ichitaro_viewer:19.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.5.1:a`,
        fs:  `cpe:2.3:a:webform_multiple_file_upload_project:webform_multiple_file_upload:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.6-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.6:a`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.15:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.7:beta1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxf4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:0.7:beta2`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0`,
        fs:  `cpe:2.3:a:tryton:tryton:2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0:rc1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:16.0.885.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0:rc3`,
        fs:  `cpe:2.3:a:barracudadrive:barracudadrive:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.1`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.2`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.1.0.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.3`,
        fs:  `cpe:2.3:a:canonical:telepathy-idle:0.1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.4`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.0-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.6`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.7`,
        fs:  `cpe:2.3:a:sap:hybris:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.9`,
        fs:  `cpe:2.3:a:mark_burdett:securelogin:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usebb:usebb:1.0.10`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.293:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_import_project:user_import:6.x-4.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:user_import_project:user_import:6.x-4.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_import_project:user_import:6.x-4.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_import_project:user_import:6.x-4.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.1.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:user_import_project:user_import:6.x-4.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:6.x-1.0`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:6.x-1.1`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:6.x-1.2`,
        fs:  `cpe:2.3:a:owncloud:owncloud:7.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:6.x-1.3`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:7.x-1.0`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:7.x-1.1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:7.x-1.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p241_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:7.x-1.3`,
        fs:  `cpe:2.3:a:nishishi:fumy_teachers_schedule_board:2.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_read-only_project:user_readonly:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:emc:documentum_administrator:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta10`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.839.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta3`,
        fs:  `cpe:2.3:h:raritan:dpxr20a-16:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta4`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow-professional_set:07-50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta5`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta6`,
        fs:  `cpe:2.3:a:bundler:bundler:1.5.0:rc.2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta7`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:p05-0022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta8`,
        fs:  `cpe:2.3:o:yahama:rtx1500:8.03.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:beta9`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:rc1`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:16.025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:rc2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:161:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:rc3`,
        fs:  `cpe:2.3:a:david_king:vino:2.23.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:rc4`,
        fs:  `cpe:2.3:a:moodle:moodle:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:rc5`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.0:rc6`,
        fs:  `cpe:2.3:a:koha:koha:3.14.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.18:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.2`,
        fs:  `cpe:2.3:a:openbsd:opensmtpd:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.3`,
        fs:  `cpe:2.3:a:inclind:custom_pub:7.x-1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:5.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:7.x-1.0:alpha1`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:7.x-1.0:alpha2`,
        fs:  `cpe:2.3:a:gnome:gnome-shell:3.11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:7.x-1.0:alpha3`,
        fs:  `cpe:2.3:a:gnu:gdb:7.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:7.x-1.0:alpha4`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:user_relationships_project:user_relationships:7.x-1.x:dev`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.1\(3\)n1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:userfriendlymedia:joe%27s_lawn_service:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:userfriendlymedia:mills-hazel_property_mgmt:3.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:monitoring_agent_for_unix_logs:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usfbcm:usf_bcm:252847::~~~android~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.20.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:1.0`,
        fs:  `cpe:2.3:a:schneider-electric:somachine:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:1.2`,
        fs:  `cpe:2.3:a:katello:katello_installer:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.0`,
        fs:  `cpe:2.3:h:bluecoat:proxysg_sg810-20:-:-:acceleration:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.1`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.2`,
        fs:  `cpe:2.3:h:cisco:cius:7-k9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.2.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.3.1`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.3.2`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.08.033:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.4`,
        fs:  `cpe:2.3:o:cisco:wrvs4400n_firmware:2.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.4.1`,
        fs:  `cpe:2.3:a:yahoo:messenger:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.5`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.6`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.6.1`,
        fs:  `cpe:2.3:a:qemu:qemu:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.7`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.7.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:tr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.7.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ushahidi:ushahidi_platform:2.7.3`,
        fs:  `cpe:2.3:a:microsoft:psservice:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usps:shipping_assistant:3.7.190`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usr:bvrp_software_modem_helper:3.02`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usr:digital_line_detect:1.10`,
        fs:  `cpe:2.3:a:redhat:libtirpc:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usr:digital_line_detect:1.21`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usr:faxtools:5.8`,
        fs:  `cpe:2.3:a:iconcool:pdfcool_studio:3.32:build130330:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usr:netwaiting:2.5.12`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usr:netwaiting:2.5.47`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usr:netwaiting:2.5.59`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.8:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.6`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.1.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.6.1`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.6.2`,
        fs:  `cpe:2.3:a:php-fusion:world_of_warcraft_tracker_infusion_module:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.6.3`,
        fs:  `cpe:2.3:a:alterpoint:logwatch:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.6.4`,
        fs:  `cpe:2.3:h:foundrynet:fastiron_4802_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.6.5`,
        fs:  `cpe:2.3:a:imember360:imember360:3.7.004:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.7`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.7.1`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.5.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:0.7.2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:6.0.0r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:1.0.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.8.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:1.0.1`,
        fs:  `cpe:2.3:a:altiris:console_data:6.5.31.0:update_kb34732:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:1.0.2`,
        fs:  `cpe:2.3:a:cognos:financial_statement_reporting_web_services:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:1.0.3`,
        fs:  `cpe:2.3:a:quest:benchmark_factory_for_databases:6.1.1.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:1.0.4`,
        fs:  `cpe:2.3:a:gnome:glib:2.27.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:1.0.5`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:usvn:user-friendly_svn:1.0.7`,
        fs:  `cpe:2.3:a:david_king:vino:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.0`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.1`,
        fs:  `cpe:2.3:a:auctiontrac:auctiontrac_dealer:2.0.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.1.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.51.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.2`,
        fs:  `cpe:2.3:a:apple:itunes:7.7.1:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.3`,
        fs:  `cpe:2.3:a:morequick:greenbrowser:6.1.0117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.3.2`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-02:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.8:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.4.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:21.0.0.226:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.5`,
        fs:  `cpe:2.3:a:x:x.org_x11:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:uswebstyle:activecollab_chat_module:1.5.1`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.2.1:windows:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ut-files:utstats:-:beta3`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.cors:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:ut-files:utstats:-:beta4`,
        fs:  `cpe:2.3:a:hp:proliant_array_diagnostics:9.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utage.org:enkai:030511`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utage.org:enkai:110916`,
        fs:  `cpe:2.3:a:nuance:image_retriever:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:utc:utc_fire_%26_security_ge-mc100-ntp%2fgps-zb_master_clock_device:-`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:util-linux_project:util-linux:2.24.2-1`,
        fs:  `cpe:2.3:a:apache:cxf:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:util-linux_project:util-linux:2.29`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:util-linux_project:util-linux:2.29.1`,
        fs:  `cpe:2.3:a:logitech:lws_pictures_and_video:13.0.1778.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:util-linux_project:util-linux:2.29.2`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.10.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:util-linux_project:util-linux:2.30`,
        fs:  `cpe:2.3:a:avg:internet_security:9.0.791:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:util-linux_project:util-linux:2.30.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:util-linux_project:util-linux:2.30.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_e20_software:te4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:util-linux_project:util-linux:2.31`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2.5.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utorrent:utorrent:1.8`,
        fs:  `cpe:2.3:h:huawei:e200e-x1:v100r005c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utorrent:utorrent:1.8.1`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utorrent:utorrent:1.8.1:rc1`,
        fs:  `cpe:2.3:o:microsoft:ms-dos:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utorrent:utorrent:1.8.2`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1049.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utorrent:utorrent:1.8.3`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utorrent:utorrent:1.8.4`,
        fs:  `cpe:2.3:o:google:chrome_os:0.9.110.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utorrent:utorrent:1.8.5`,
        fs:  `cpe:2.3:o:cisco:catos:7.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utorrent:utorrent_remote:1.0.20110929::~~~android~~`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:utsa:utsa_mobile:1.4.21::~~~android~~`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:v-one:smartpass:4.6`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:valcom:vip-821:-`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:validated_plugin_project:validated_plugin:1.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:citrix:access_management_console_diagnostics:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:hancom:hancom_office_2014:9.1.0.2176:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_mobile_8.0_firmware:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0:rc2:~~~drupal~~`,
        fs:  `cpe:2.3:a:mailup:wp-mailup:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0:rc3:~~~drupal~~`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0:rc4:~~~drupal~~`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.05.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.0:rc5:~~~drupal~~`,
        fs:  `cpe:2.3:a:horde:gollem:1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:values_project:values:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:valve:steam:2.10.91.91`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:11.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:valvesoftware:steam_link:-`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.325:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:388`,
        fs:  `cpe:2.3:a:f5:big-ip_policy_enforcement_manager:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:390`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass_pro:6.3.5:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:398`,
        fs:  `cpe:2.3:a:hp:marketresearch:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:400`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:406`,
        fs:  `cpe:2.3:a:nliteos:nlite:1.4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:410`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:412`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:414`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:430`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.0:alpha7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:433`,
        fs:  `cpe:2.3:a:jgaa:warftpd:1.8.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:435`,
        fs:  `cpe:2.3:a:abbyy:finereader_sprint_plus:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:437`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:441`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:447`,
        fs:  `cpe:2.3:a:ibm:content_manager_ondemand_for_multiplatforms:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:449`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:462`,
        fs:  `cpe:2.3:a:cisco:cns_network_registrar:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:484`,
        fs:  `cpe:2.3:a:bogofilter_project:bogofilter:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:487`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:494`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:497`,
        fs:  `cpe:2.3:a:cisco:enterprise_content_delivery_network_software:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:499`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:7.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:503`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:507`,
        fs:  `cpe:2.3:a:hp:product_assistant:60.0.155.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:513`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:515`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:516`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:517`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:518`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:0.39:pl2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:522`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:524`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:1.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:528`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:2.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:532`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:538`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:540`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.5:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:546`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:550`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:554`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d46.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:560`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.2.2020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:562`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:564`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.5:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:565`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:566`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:572`,
        fs:  `cpe:2.3:a:debian:txt2man:1.5.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:574`,
        fs:  `cpe:2.3:h:supermicro:x9drff-7g\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:575`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.6.602.167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:578`,
        fs:  `cpe:2.3:a:haxx:curl:7.19.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:581`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:582`,
        fs:  `cpe:2.3:h:sony:drx-510ul:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:584`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.14.1402:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:585`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:587`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:589`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:597`,
        fs:  `cpe:2.3:o:debian:debian_linux:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:600`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:606`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:607`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:609`,
        fs:  `cpe:2.3:a:techsmith:snagit:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:610`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:613`,
        fs:  `cpe:2.3:a:apple:software_update:2.1.0.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:614`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:615`,
        fs:  `cpe:2.3:a:vim:vim:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:617`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:620`,
        fs:  `cpe:2.3:a:pcre:pcre:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:623`,
        fs:  `cpe:2.3:h:snapgear:710:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:624`,
        fs:  `cpe:2.3:o:omron:ns_series_system_program_firmware:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:626`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:628`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:630`,
        fs:  `cpe:2.3:a:bea:weblogic_workshop:8.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:637`,
        fs:  `cpe:2.3:a:oracle:forms:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:639`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:640`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:644`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steam_link_firmware:645`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(15a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:valvesoftware:steamos:-:beta`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:1.9.6`,
        fs:  `cpe:2.3:h:sierra_wireless:sierra_wireless_aircard_760s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.0.3`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.0.4`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.955:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.0.5`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.1`,
        fs:  `cpe:2.3:a:gnu:queue:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.2`,
        fs:  `cpe:2.3:a:apache:tomcat:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.3`,
        fs:  `cpe:2.3:a:views_bulk_operations_project:views_bulk_operations:7.x-3.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.4`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.4.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.5`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.6.5.a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.6`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.7`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.0_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.8`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.9`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:absoluteftp:2.2.10`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt:4.1`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt:5.5`,
        fs:  `cpe:2.3:a:research-artisan:research_artisan_lite:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt:6.2.0`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt:6.5.2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt:6.5.3`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt:6.6.2`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:11:sp2:*:*:ltss:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt:6.7.2`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt_and_securefx:6.0.0`,
        fs:  `cpe:2.3:a:autonomy:keyview_filter_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securecrt_and_securefx:6.6.3`,
        fs:  `cpe:2.3:h:avaya:sg5:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:securefx:4.0`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.27:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:vandyke:vshell:3.5.0.0`,
        fs:  `cpe:2.3:o:cisco:clean_access:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanilla_perl_project:strawberry_perl:5.10.256`,
        fs:  `cpe:2.3:a:wordpress:wordpress:4.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanilla_perl_project:strawberry_perl:5.12.1`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanilla_perl_project:strawberry_perl:5.12.512`,
        fs:  `cpe:2.3:a:google:chrome:9.0.582.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanilla_perl_project:strawberry_perl:5.12.768`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:-`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0`,
        fs:  `cpe:2.3:a:sambar:sambar_server:4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.5\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.3`,
        fs:  `cpe:2.3:a:oracle:industry_applications:10.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.4`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.152.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.5`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.6`,
        fs:  `cpe:2.3:h:cisco:ids_4235:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.7`,
        fs:  `cpe:2.3:o:hp:laserjet_pro_p1102w_firmware:20130703:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.9`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.10:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.10`,
        fs:  `cpe:2.3:a:altiris:it_analytics_service_management_pack:6.1.1085:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.11`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_feature_pack_for_web_services:6.1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.12`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.13`,
        fs:  `cpe:2.3:a:vmware:tools:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.14`,
        fs:  `cpe:2.3:a:tibco:spotfire_deployment_kit:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.15`,
        fs:  `cpe:2.3:a:vmware:workstation:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.16`,
        fs:  `cpe:2.3:a:daemontools:daemon_tools_toolbar:1.1.8.285:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.16.1`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-52c-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17`,
        fs:  `cpe:2.3:a:almas:compiere:j253b_a02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.1`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.2`,
        fs:  `cpe:2.3:a:ibm:alphaworks_tftp_server:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.4`,
        fs:  `cpe:2.3:a:hp:solution_center:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.5`,
        fs:  `cpe:2.3:a:openstack:grizzly:2013.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.6`,
        fs:  `cpe:2.3:a:emulex:common_san_management:32.1.1.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.7`,
        fs:  `cpe:2.3:a:justsystems:just_frontier:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.8`,
        fs:  `cpe:2.3:a:oracle:http_server:9.0.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.17.10`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.2.0.1275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18:a3`,
        fs:  `cpe:2.3:h:axis:m1014_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18:b1`,
        fs:  `cpe:2.3:h:y-cam:yceb03:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18:b2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18:b4`,
        fs:  `cpe:2.3:a:gnome:glib:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18:rc1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18:rc2`,
        fs:  `cpe:2.3:a:avaya:communication_manager:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18:rc3`,
        fs:  `cpe:2.3:o:canyon-tech:cn-wf512_router_firmware:1.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18.1`,
        fs:  `cpe:2.3:a:jgroups:jgroup:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18.3`,
        fs:  `cpe:2.3:a:chamilo:chamilo_lms:1.8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18.4`,
        fs:  `cpe:2.3:a:redhat:rhel_global_file_system:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18.5`,
        fs:  `cpe:2.3:a:justsystems:ichitaro:2006:-:government:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18.6`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a4:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18.7`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.0.18.12`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.1:a26`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vanillaforums:vanilla_forums:2.1:a32`,
        fs:  `cpe:2.3:a:apache:ofbiz:12.04.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vantagelinguistics:answerworks_runtime:10.0.101:::en`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varec:fuelsmanager_defense:6.0_sp4`,
        fs:  `cpe:2.3:a:organizer_project:organizer:0.6.1b:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:varec:fuelsmanager_defense_dormant_account_manager:1.0.0`,
        fs:  `cpe:2.3:a:google:chrome:13.0.775.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.0.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.889.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.0.2`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.0.3`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.0.4`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.0.5`,
        fs:  `cpe:2.3:a:net-snmp:net-snmp:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.0.6`,
        fs:  `cpe:2.3:h:wangkongbao:cns-1100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.1.0`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr3224l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.1.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.1.2`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.1.3`,
        fs:  `cpe:2.3:a:db_backup_project:db_backup:4.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.1.4`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:2.1.5`,
        fs:  `cpe:2.3:a:wildpackets:omniengine:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:3.0.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:3.0.0:beta1`,
        fs:  `cpe:2.3:a:gnu:grep:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:3.0.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:3.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(30\)s2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:3.0.2`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:3.0.3`,
        fs:  `cpe:2.3:h:f5:firepass_4100:5.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish-cache:varnish:3.0.4`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish_http_accelerator_integration_project:varnish:6.x-1.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc652a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish_http_accelerator_integration_project:varnish:6.x-1.1`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v100r006c00spc800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish_http_accelerator_integration_project:varnish:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish_http_accelerator_integration_project:varnish:7.x-1.0:beta1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:varnish_http_accelerator_integration_project:varnish:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:desktopstandard:policymaker_application_security_client:2.0.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasco:identikey_authentication_server:3.4`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasco:identikey_authentication_server:3.5`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vastal:freelance_zone:-`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vastal:phpvid:0.9.9`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vastal:phpvid:1.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd308a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vastal:phpvid:1.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vastal:phpvid:1.2.3`,
        fs:  `cpe:2.3:h:xerox:workcentre_pro:255:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:applications_framework:12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cds:cds_client:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.5.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.5.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows_ce:3.0.9348:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:agilebits:knox:2.1.12:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6.8:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:staros:12.2_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.6.9:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.6.1001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.7:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0\(.4.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.7.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.7.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.7.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:horde:imp:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vasthtml:forumpress:1.7.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:softerra:ldap_browser:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:3.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:3.8.7`,
        fs:  `cpe:2.3:a:secureideas:basic_analysis_and_security_engine:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:3.8.8`,
        fs:  `cpe:2.3:a:sun:sdk:1.2.2_010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:3.8.9`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.0`,
        fs:  `cpe:2.3:a:vips:vips:7.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.1`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.3`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.4`,
        fs:  `cpe:2.3:a:citrix:cloudplatform:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.5`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.6`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.7`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.0.8`,
        fs:  `cpe:2.3:a:sendcard:sendcard:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.1`,
        fs:  `cpe:2.3:h:sierra_wireless:sierra_wireless_aircard_763s:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.1.1`,
        fs:  `cpe:2.3:a:openafs:openafs:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.1.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.1.3`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.2.2:patch_level_4`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:2.0.40:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.2.3`,
        fs:  `cpe:2.3:a:yahoo:toolbar:1.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:4.4.2`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.0.0:beta_11`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.5.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.0.0:beta_28`,
        fs:  `cpe:2.3:a:otrs:otrs:3.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.0.1`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.0.2`,
        fs:  `cpe:2.3:a:marked_project:marked:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.0.3`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.0.4`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.0.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.1.0`,
        fs:  `cpe:2.3:a:islonline:isl_desktop_plugin:1.4.2:-:-:*:windows:isl_light:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.1.0:rc1`,
        fs:  `cpe:2.3:a:marvil07:vote_up_down:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.1.1`,
        fs:  `cpe:2.3:o:avm:fritz\!_os:6.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.1.2`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.8:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.1.2:beta1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.1.0r11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.1.2:rc1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.38.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.1.2:rc2`,
        fs:  `cpe:2.3:a:sun:iplanet_directory_server:5.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.1.3:alpha5`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.2.0`,
        fs:  `cpe:2.3:a:avaya:argent_office:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.2.1`,
        fs:  `cpe:2.3:a:ishii:pukiwikimod:1.5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.2.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbulletin:vbulletin:5.2.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vbwebdesigner:brevir_harian_v2:2::~~~android~~`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vcccd:myvcccd:1.4.14::~~~android~~`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vdgsecurity:vdg_sense:2.3.13`,
        fs:  `cpe:2.3:a:apple:cups:1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vdgsecurity:vdg_sense:2.3.14`,
        fs:  `cpe:2.3:a:openstack:swift:1.13.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vdstech:aspmap:1.2`,
        fs:  `cpe:2.3:a:apple:itunes:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vector:ultra_mini_httpd:1.21`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vector:vector_outage_manager:1.7::~~~android~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:3.00.162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veeam:backup_and_replication:5.0.2.230`,
        fs:  `cpe:2.3:a:infradead:openconnect:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veeam:backup_and_replication:8.0.0.2030`,
        fs:  `cpe:2.3:o:tp-link:tl-wr841nd_\(10.0\)_firmware:150104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veeam:backup_and_replication_active_directory_restore:5.0.2.224`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x49:d55:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veeam:backup_catalog:5.0.2.230`,
        fs:  `cpe:2.3:a:qlogic:sansurfer_fc_hba_manager:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veoh:veoh_web_player:1.1.2.0`,
        fs:  `cpe:2.3:a:google:v8:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vercot:serva32:2.1.0`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verification_code_for_comments_project:verification_code_for_comments:2.1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verifone:vericentre_web_console:2.0`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verifone:vericentre_web_console:2.0.1`,
        fs:  `cpe:2.3:a:sony:sonicstage_connect_player:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verifone:vericentre_web_console:2.2`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec:15.1180`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec:16.1142`,
        fs:  `cpe:2.3:a:google:chrome:5.0.394.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec:2014.1786`,
        fs:  `cpe:2.3:a:mcafee:mcafee_agent:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec_remote_agent:9.0.4367:sp1:windows_servers`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec_remote_agent:9.0.4454:sp1:windows_servers`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec_remote_agent:9.1.4691:sp2:windows_servers`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(24.2\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec_remote_agent:9.1.4691:sp3:windows_servers`,
        fs:  `cpe:2.3:a:mybb:mybb:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec_remote_agent:9.1.4691:sp4a:windows_servers`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec_remote_agent:10.0.5484:sp1:windows_servers`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.47:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec_remote_agent:10.0.5484:sp3:windows_servers`,
        fs:  `cpe:2.3:a:xrms_crm_project:xrms_crm:1.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:backup_exec_remote_agent:10.0.5484:sp4:windows_servers`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.1.0r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:enterprise_administrator:-`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:enterprise_administrator:3.0.2.261`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:file_system_management_services_provider:-`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.36b:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:license_utilities:-`,
        fs:  `cpe:2.3:o:yamaha:rt200i:4.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:4.5.0:mp1:netware_media_servers`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:4.5.0:mp2:netware_media_servers`,
        fs:  `cpe:2.3:a:atlassian:jira:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:4.5.0:mp3:netware_media_servers`,
        fs:  `cpe:2.3:o:breakingpointsystems:breakingpoint_storm_appliance_ctm:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:4.5.0:mp4:netware_media_servers`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.6:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:4.5.0:mp5:netware_media_servers`,
        fs:  `cpe:2.3:a:mantisbt:mantisbt:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:4.5.0:mp6:netware_media_servers`,
        fs:  `cpe:2.3:a:markus_blaschke:tq_seo:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:4.5.0:mp7:netware_media_servers`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:4.5.0:mp8:netware_media_servers`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:5.0.0:mp1:netware_media_servers`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.53:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:5.0.0:mp2:netware_media_servers`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:5.0.0:mp3:netware_media_servers`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:5.0.0:mp4:netware_media_servers`,
        fs:  `cpe:2.3:a:oracle:e-business_intelligence:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:5.0.0:mp5:netware_media_servers`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:5.1.0:mp1:netware_media_servers`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:5.1.0:mp2:netware_media_servers`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:5.1.0:mp3:netware_media_servers`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.0`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.0.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.1.0.1`,
        fs:  `cpe:2.3:a:samba:samba:1.9.18:p10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.1.0.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.22:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.1.0.3`,
        fs:  `cpe:2.3:a:gnome:glib:2.25.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.1.0.4`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.5.0.1`,
        fs:  `cpe:2.3:a:microsoft:exchange_srv:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.5.0.3`,
        fs:  `cpe:2.3:a:redhat:cloudforms:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.5.0.4`,
        fs:  `cpe:2.3:a:microsoft:lync:2013:-:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.5.0.5`,
        fs:  `cpe:2.3:a:csounds:csound:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.5.0.6`,
        fs:  `cpe:2.3:a:aimluck:aipo:4.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.5.0.7`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.6.0.2`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1285.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.6.0.3`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1028:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.6.0.4`,
        fs:  `cpe:2.3:a:seeddms:seeddms:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.6.1.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.433.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.6.1.2`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup:7.7.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:1.1.0.1`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:1.1.0.2`,
        fs:  `cpe:2.3:h:siemens:scalance_s612:v2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:1.2`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.0.1`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.0.2`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.0.3`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.4.0.46.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.5`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.5.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.83:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.5.2`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.5.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.6.0.2`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.6.0.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.6.0.4`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.7.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.6.1`,
        fs:  `cpe:2.3:a:samba:samba:4.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.6.1.1`,
        fs:  `cpe:2.3:o:suse:opensuse:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.6.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(22\)mda:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:netbackup_appliance:2.7.1`,
        fs:  `cpe:2.3:a:sas:management_console:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:volume_manager:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:volume_manager:4.1`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.1.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:veritas:volume_manager_services_provider:-`,
        fs:  `cpe:2.3:a:oracle:jrockit:r28.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verity:k2_dashboard:5.5`,
        fs:  `cpe:2.3:h:t-mobile:mytouch_3g_slide:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:verizon:fios_actiontec_mi424wr-gen31_router:-`,
        fs:  `cpe:2.3:a:microsoft:rich_textbox_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:verizon:fios_actiontec_mi424wr-gen31_router_firmware:40.19.36`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verizon:vz_in_home_agent:7.7.2`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verizon:vzaccess_manager:3.1.4`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:verizon:wireless_network_extender:scs-2u01`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:verizon:wireless_network_extender:scs-26uc4`,
        fs:  `cpe:2.3:a:tinc-vpn:tinc:1.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verizon_instant_refills_24%2f7_project:verizon_instant_refills_24%2f7:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:jruby:jruby:1.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verkehrsmuseum-dresden:dresden_transport_museum:2.2::~~~android~~`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vermontsystems:progress:-`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:versentbooks:versent_books:1.1.99::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:application_server:9.0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:verweise-wordpress-twitter_project:verweise-wordpress-twitter:1.0.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:telos:xacta_automated_messaging_handling_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vessio:netbill:1.2`,
        fs:  `cpe:2.3:a:f5:big-ip_analytics:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vevo:vevo-watch_hd_music_videos:2.0.27::~~~android~~`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:16.0.1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vicidial:vicidial:2.7:-`,
        fs:  `cpe:2.3:a:hotbar:hbtools:4.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vicidial:vicidial:2.7:rc1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vicidial:vicidial:2.8:403a`,
        fs:  `cpe:2.3:h:enterasys:6h302-48:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viddy:viddy:1.3.9::~~~android~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video-lead-form:uk-cookie:-`,
        fs:  `cpe:2.3:a:dell:poweredge_diagnostics:2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video-lead-form:uk-cookie:0.5`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video-lead-form:uk-cookie:0.6`,
        fs:  `cpe:2.3:a:oracle:database_server:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.0:alpha1`,
        fs:  `cpe:2.3:a:1024cms:1024_cms:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.0:alpha2`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.0:alpha3`,
        fs:  `cpe:2.3:a:nuance:smart_document_scan_software:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.0:alpha4`,
        fs:  `cpe:2.3:a:ibm:tivoli_management_framework:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.0:alpha5`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.6a:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.0:alpha6`,
        fs:  `cpe:2.3:a:symantec:sygate_personal_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.1:alpha1`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.4:-:ipodtouch:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.1:alpha2`,
        fs:  `cpe:2.3:h:hp:color_laserjet_5550:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.1:alpha3`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.2`,
        fs:  `cpe:2.3:h:lexmark:e238:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.2:beta1`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.2:beta2`,
        fs:  `cpe:2.3:a:trevor_mckay:cumin:0.1.5137-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.2:beta3`,
        fs:  `cpe:2.3:a:arthurdejong:nss-pam-ldapd:0.6.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.2:beta4`,
        fs:  `cpe:2.3:a:usebb:usebb:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.2:beta5`,
        fs:  `cpe:2.3:a:corel:paint_shop_pro_studio:1.0.0:*:*:*:dell_editon:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.280:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.4`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.5`,
        fs:  `cpe:2.3:a:canon:canoscan_toolbox:4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.6`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.7`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.8`,
        fs:  `cpe:2.3:a:samba:samba:3.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:storeonce_2610_iscsi_backup_system:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:video_project:video:7.x-2.x:dev`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videocharge:videocharge_studio:2.9.0.632`,
        fs:  `cpe:2.3:a:bigware:bigware_shop:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videocharge:watermark_master:2.2.23`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc:2.1.4`,
        fs:  `cpe:2.3:a:metalogix:selective_restore_manager_for_sharepoint_backups:4.1.904:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99a`,
        fs:  `cpe:2.3:a:ca:messaging:1.11.29.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99b`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99c`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99d`,
        fs:  `cpe:2.3:a:gentoo:linux_eix:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99e`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99f`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.0.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99g`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99h`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.1.99i`,
        fs:  `cpe:2.3:h:cisco:1801_integrated_service_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.0`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:rc4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.50`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.12:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.60`,
        fs:  `cpe:2.3:a:drupal:drupal:7.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.61`,
        fs:  `cpe:2.3:a:exim:exim:4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.62`,
        fs:  `cpe:2.3:a:microsoft:remote_desktop_protocol:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.63`,
        fs:  `cpe:2.3:a:tryton:tryton:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.70`,
        fs:  `cpe:2.3:a:redhat:directory_server:8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.71`,
        fs:  `cpe:2.3:a:elemata:elemata_cms:3.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.72`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.73`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.80`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.81`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:1.0.10e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.82`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.83`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.90`,
        fs:  `cpe:2.3:a:adobe:acrobat:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.91`,
        fs:  `cpe:2.3:a:mahara:mahara:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.2.92`,
        fs:  `cpe:2.3:h:linksys:befsr41w:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.3.0`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.3.1`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.4.0`,
        fs:  `cpe:2.3:a:endeavorsystems:openfisma:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.4.1`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.4.2`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.55:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.4.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3015_concentrator:4.7.1.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.4.3-ac3`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.4.4`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.4.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.4.6`,
        fs:  `cpe:2.3:a:emc:networker:8.1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.5.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.16.2.901:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.5.1`,
        fs:  `cpe:2.3:a:novell:ichain:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.5.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:7.0.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.5.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.6.0`,
        fs:  `cpe:2.3:a:cgminer_project:cgminer:3.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(24\)md2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.6.2`,
        fs:  `cpe:2.3:a:adobe:flash_player:22.0.0.211:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.7.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.7.1`,
        fs:  `cpe:2.3:a:qemu:qemu:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.7.2`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.0`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:12.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.1`,
        fs:  `cpe:2.3:a:acronis:true_image_management_console:9.7.8206:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.2`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.4`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.4a`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.5`,
        fs:  `cpe:2.3:a:google:chrome:2.0.157.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.27.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6a`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:2.11.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6b`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6c`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6d`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6e`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6f`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6g`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6h`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.6i`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.2.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.8.1337`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.02.013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.0`,
        fs:  `cpe:2.3:a:tuxfamily:chrony:1.25:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.1`,
        fs:  `cpe:2.3:a:libproxy_project:libproxy:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.2`,
        fs:  `cpe:2.3:a:novell:open_enterprise_server:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.2-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.4`,
        fs:  `cpe:2.3:h:netgear:fsm726s:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.5`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.6`,
        fs:  `cpe:2.3:a:isc:bind:9.9.3:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.8a`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:1.0.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.9`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.9a`,
        fs:  `cpe:2.3:a:trioniclabs:sentinel:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:0.9.10`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.447.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.0.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.21.596:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.0.1`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:6.10.560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.0.2`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:6.0.1\(50\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.0.4`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.21.264:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.0.5`,
        fs:  `cpe:2.3:a:freka:yr_verdata:6.x-1.5:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.0.6`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.0`,
        fs:  `cpe:2.3:a:hp:readme:71.0.215.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.1`,
        fs:  `cpe:2.3:a:march-hare:cvs_suite:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.2`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.307:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.3`,
        fs:  `cpe:2.3:a:altiris:deployment_server_extension_for_ibm_director:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.4`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.4.1`,
        fs:  `cpe:2.3:a:mplayer2:mplayer2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.5`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_418_382:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.6`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compactlogix_l4x_controller_firmware:17.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.6.1`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:8.00b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.7`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.8`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.9`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.10`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:j06.05.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.10.1`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.11`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.17:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.12`,
        fs:  `cpe:2.3:o:hp:arcsight_connector_appliance_firmware:6.2.0.6244.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:1.1.13`,
        fs:  `cpe:2.3:a:techsmith:snagit:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.0`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.1`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.2m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.2`,
        fs:  `cpe:2.3:a:google:chrome:4.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.3`,
        fs:  `cpe:2.3:a:jason_sexauer:churchcms:0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.4`,
        fs:  `cpe:2.3:a:libraw:libraw:0.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.5`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1306.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.6`,
        fs:  `cpe:2.3:a:kallithea:kallithea:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.7`,
        fs:  `cpe:2.3:a:freso:languageicons:6.x-2.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.8`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.7:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.0.9`,
        fs:  `cpe:2.3:a:ibm:security_appscan:9.0.1.0:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.1.0`,
        fs:  `cpe:2.3:a:isc:bind:9.2.5:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.1.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.1.2`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.1.3`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.1.5`,
        fs:  `cpe:2.3:a:gentoo:rootkit_hunter:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.1.6`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.2.1`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.2.3`,
        fs:  `cpe:2.3:h:xerox:workcentre:m128:unknown:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.2.4`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.2.5.1`,
        fs:  `cpe:2.3:a:isc:inn:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.2.6`,
        fs:  `cpe:2.3:a:sap:activex_viewer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videolan:vlc_media_player:2.2.7`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videos_tube_project:videos_tube:1.0`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:6.1.2_ce_ga3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videotelecom:russkoe_tb_hd:3.6::~~~android~~`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:1.02.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.0.2`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.0.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.6\(3\)m2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.0.4`,
        fs:  `cpe:2.3:h:cisco:cs-mars:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.0.5`,
        fs:  `cpe:2.3:a:vbulletin:vbulletin:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.2`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.3`,
        fs:  `cpe:2.3:h:hp:color_inkjet_cp1700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.4`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.4.1`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.3r8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.4.2`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.4.3`,
        fs:  `cpe:2.3:a:siemens:scalance_x414-3e_firmware:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.4.4`,
        fs:  `cpe:2.3:a:gnu:groff:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.4.5`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.4.6`,
        fs:  `cpe:2.3:a:freetype:freetype2:2.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.4.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.5`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videousermanuals:white-label-cms:1.5.1`,
        fs:  `cpe:2.3:h:intel:xircom_rex_6000:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:live_streaming_integration_plugin:1.0.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_provisioning_manager_os_deployment:5.1.0.116:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:live_streaming_integration_plugin:2.0`,
        fs:  `cpe:2.3:a:game-insight:my_railway:1.1.33:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:live_streaming_integration_plugin:2.1`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:live_streaming_integration_plugin:2.2`,
        fs:  `cpe:2.3:a:apache:subversion:0.28.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:live_streaming_integration_plugin:4.05`,
        fs:  `cpe:2.3:o:google:android:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:live_streaming_integration_plugin:4.07`,
        fs:  `cpe:2.3:a:gnome:glib:1.1.12-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:live_streaming_integration_plugin:4.25`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:live_streaming_integration_plugin:4.25.3`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:video_posts_webcam_recorder:1.55.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:2.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:video_presentation:3.25:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:good:good_messaging_server:_6.3.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:adodb_project:adodb:5.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:o:juniper:junos:14.1x53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper_live_streaming_integration:4.27::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper_live_streaming_integration:4.27.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper_live_streaming_integration:4.27.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.6.11:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper_live_streaming_integration:4.27.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:xml_developers_kit:11.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper_live_streaming_integration:4.29.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper_live_streaming_integration:4.29.16::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:call_manager:3.3\(5\)es30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper_live_streaming_integration:4.29.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:videowhisper:videowhisper_live_streaming_integration:4.29.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:automake:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vidyo:vidyo_conferencing_outlook_plug-in:2.0.4.20`,
        fs:  `cpe:2.3:a:yahoo:messenger:5.0.1046:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vidyo:vidyo_desktop:2.0.1`,
        fs:  `cpe:2.3:a:gajim:gajim:0.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viedemerde:vdm_officiel:5.0::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.5.1.17730:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:6.x-1.17::~~~drupal~~`,
        fs:  `cpe:2.3:a:acme:thttpd:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:6.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:alpha1:~~~drupal~~`,
        fs:  `cpe:2.3:a:splunk:splunk:6.2.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:alpha2:~~~drupal~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:alpha3:~~~drupal~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:beta1:~~~drupal~~`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:beta2:~~~drupal~~`,
        fs:  `cpe:2.3:a:ruby-i18n:i18n:0.6.9:-:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:beta3:~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.0:rc1:~~~drupal~~`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:6.2.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.6:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_bulk_operations_project:views_bulk_operations:7.x-3.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.0`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg315a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.0:alpha1`,
        fs:  `cpe:2.3:a:intersectalliance:system_intrusion_analysis_and_reporting_environment:1.5.0:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.0:beta1`,
        fs:  `cpe:2.3:a:luracast:restler:1.5.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.0:beta2`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.0:beta3`,
        fs:  `cpe:2.3:a:x:libxfont:1.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.0:rc1`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_studio:05-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.0:rc3`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.2`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.4`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.5`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:8.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:views_project:views:7.x-3.x:dev`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30094:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/h:viewsonic:vg2427wm_24%22_lcd_monitor:-`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:viewsonic:vx2240w_22%22_lcd_monitor:-`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:0.8`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:0.9`,
        fs:  `cpe:2.3:a:microsoft:excel:2013:*:*:*:*:x86:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:0.9.1`,
        fs:  `cpe:2.3:a:ibm:security_key_lifecycle_manager:2.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:0.9.2`,
        fs:  `cpe:2.3:h:hp:j9822a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:0.9.3`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance:a5\(3.0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:0.9.4`,
        fs:  `cpe:2.3:h:ibm:s38:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.0`,
        fs:  `cpe:2.3:a:armin_burgmeier:net6:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\)ea6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.2`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.5`,
        fs:  `cpe:2.3:a:csounds:csound:5.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.6`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.7`,
        fs:  `cpe:2.3:h:polycom:hdx_9006:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.8`,
        fs:  `cpe:2.3:a:ca:unicenter_software_delivery:3.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.9`,
        fs:  `cpe:2.3:a:3s-software:codesys_gateway-server:2.3.9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.10`,
        fs:  `cpe:2.3:a:apache:struts:2.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.0.11`,
        fs:  `cpe:2.3:a:bmc:service_desk_express:10.2.1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.0:qa4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.1`,
        fs:  `cpe:2.3:a:mistelix:mistelix:0.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.2`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.10.22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.3`,
        fs:  `cpe:2.3:a:gnu:gnash:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.4`,
        fs:  `cpe:2.3:a:python:python:2.5.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.5`,
        fs:  `cpe:2.3:a:citrix:access_management_console_framework:5.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.6`,
        fs:  `cpe:2.3:a:iproute2_project:iproute2:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.7`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.1:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.8`,
        fs:  `cpe:2.3:a:sony:sonicstage_mastering_studio:1.2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.9`,
        fs:  `cpe:2.3:a:autodesk:autocad:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.10`,
        fs:  `cpe:2.3:h:d-link:dsr-500n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.11`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.12`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.13`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:7.0:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viewvc:viewvc:1.1.14`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:7.5.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vim:vim:5.6`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.6.7d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vim:vim:6.1`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vim:vim:6.3`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.889:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:vim:vim:7.2`,
        fs:  `cpe:2.3:a:chamilo_integration_project:chamilo_integration:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:vim:vim:7.3`,
        fs:  `cpe:2.3:a:alberto_trujillo_gonzalez:protest:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vim:vim:8.0.0055`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.2:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vim:vim:8.0.0376`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vim:vim:8.0.0377`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vimbadmin:vimbadmin:3.0.15`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vinay_sajip:python-gnupg:0.3.0`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vinay_sajip:python-gnupg:0.3.1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:4.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vinay_sajip:python-gnupg:0.3.2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.1:*:*:*:application_server:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vinay_sajip:python-gnupg:0.3.3`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vinay_sajip:python-gnupg:0.3.4`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vine_mv_project:vine_mv:2015-09-09`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.12:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.6`,
        fs:  `cpe:2.3:a:apple:safari:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7`,
        fs:  `cpe:2.3:a:ibm:powerkvm:2.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.1`,
        fs:  `cpe:2.3:h:hp:3com_router:3012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.2`,
        fs:  `cpe:2.3:a:project-redcap:redcap:4.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)zo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.4`,
        fs:  `cpe:2.3:a:apache:subversion:0.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.5`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.2.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.6`,
        fs:  `cpe:2.3:a:mcafee:virusscan:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.7`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.8`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.9`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.10`,
        fs:  `cpe:2.3:a:redhat:cairo:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.11`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.12`,
        fs:  `cpe:2.3:a:cisco:web_security_appliance:7.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.14`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.15`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.16`,
        fs:  `cpe:2.3:a:jenkins:git:3.2.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.17`,
        fs:  `cpe:2.3:h:supermicro:h8dgu-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.18`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.13:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.19`,
        fs:  `cpe:2.3:a:apache:openmeetings:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.20`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.21`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.22`,
        fs:  `cpe:2.3:a:owncloud:owncloud:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.23`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.7.24`,
        fs:  `cpe:2.3:h:cisco:ips_4250_sx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.0`,
        fs:  `cpe:2.3:a:redhat:libreport:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(1\)st:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.3`,
        fs:  `cpe:2.3:o:siemens:scalance_x-200_series_firmware:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.4`,
        fs:  `cpe:2.3:a:vmware:zimbra_desktop:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.291:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.6`,
        fs:  `cpe:2.3:a:crunchify:facebook_members:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.7`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.8`,
        fs:  `cpe:2.3:a:apple:safari:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.9`,
        fs:  `cpe:2.3:a:python:pillow:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.10`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.8.11`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.9.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.9.1`,
        fs:  `cpe:2.3:a:broadcom:advanced_control_suite:8.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.9.2`,
        fs:  `cpe:2.3:a:oracle:configurator:11.5.7.17.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.9.3`,
        fs:  `cpe:2.3:a:gnu:bash:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.9.4`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.9.5`,
        fs:  `cpe:2.3:a:schneider-electric:pl7:4.5:sp7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.9.6`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.0`,
        fs:  `cpe:2.3:a:faronics:deep_freeze:6.30.020.1875:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.1`,
        fs:  `cpe:2.3:a:graphite_project:graphite:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.2`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.3`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.4`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.159:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.6`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.7`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.8`,
        fs:  `cpe:2.3:o:engardelinux:secure_professional:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.9`,
        fs:  `cpe:2.3:o:ibm:os_400:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.11`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.10.12`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp7:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11`,
        fs:  `cpe:2.3:a:serv-u:serv-u:3.0.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.2`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.5`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.33.380:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.6`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:3.9.3:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.7`,
        fs:  `cpe:2.3:a:red-gate:sql_data_compare:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.8`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.9`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.10`,
        fs:  `cpe:2.3:a:hp:insight_management_agent:7.90.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.11`,
        fs:  `cpe:2.3:a:hp:sitescope:10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.12`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:1.1f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.14`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.15`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:4.030_02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.16`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.17`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.18`,
        fs:  `cpe:2.3:a:ixiacom:ixautomateapi:6.30.24.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.19`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:8.01.460:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.20`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.332:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.11.21`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.12.1`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.12.2`,
        fs:  `cpe:2.3:a:rsa:envision:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.12.3`,
        fs:  `cpe:2.3:a:samba:samba:3.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.12.4`,
        fs:  `cpe:2.3:a:mediawiki:rssreader:0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.12.5`,
        fs:  `cpe:2.3:a:spice_project:spice:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.13.0`,
        fs:  `cpe:2.3:a:nero:coverdesigner_help:4.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.13.1`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.13.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.13.3`,
        fs:  `cpe:2.3:a:libgd:libgd:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.14.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.6.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.15.0`,
        fs:  `cpe:2.3:a:sendmail:sendmail:8.13.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.16.0`,
        fs:  `cpe:2.3:h:sun:fire_x4540_server:sw_1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.16.1`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.16.2`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.3.101.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.16.3`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.17.0`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.17.2`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.17.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(31\)sb12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.18.0`,
        fs:  `cpe:2.3:a:netscape:communicator:4.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.19.0`,
        fs:  `cpe:2.3:a:systemtap:systemtap:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.20.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.20.1`,
        fs:  `cpe:2.3:a:microsoft:ie:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.20.2`,
        fs:  `cpe:2.3:a:mandrakesoft:mandrake_lam-runtime:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.20.3`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.21.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3s\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.21.1`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.21.2`,
        fs:  `cpe:2.3:o:xen:xen:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.21.3`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:2.0\(2q\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.22.0`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.22.1`,
        fs:  `cpe:2.3:a:polycom:hdx_system_software:2.5.0.7_g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.22.2`,
        fs:  `cpe:2.3:a:zend:zendto:4.11-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.22.3`,
        fs:  `cpe:2.3:a:digia:qt:4.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.22.4`,
        fs:  `cpe:2.3:a:jaumo:chat_flirt_\&amp;_dating_heart_jaumo:2.7.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.22.5`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:5.1\(4\)e1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.22.6`,
        fs:  `cpe:2.3:a:oracle:mobile_application_server:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vips:vips:7.22.7`,
        fs:  `cpe:2.3:a:certblaster:certblaster_comptia:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viralheat:argyle_social:2011-04-26`,
        fs:  `cpe:2.3:o:asus:rt-n65u_firmware:3.0.0.4.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virginhealthmiles:gozone_isync:2.0.0`,
        fs:  `cpe:2.3:a:git-scm:git:2.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:-`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:0.2`,
        fs:  `cpe:2.3:a:live555:streaming_media:2011.09.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:0.3`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:0.4`,
        fs:  `cpe:2.3:a:redhat:tmpwatch:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:0.5`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:0.6`,
        fs:  `cpe:2.3:a:hp:secbladefw:5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:0.7`,
        fs:  `cpe:2.3:a:alexis_wilke:protected_node:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:0.8`,
        fs:  `cpe:2.3:a:vips:vips:7.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virt-who_project:virt-who:0.9`,
        fs:  `cpe:2.3:a:jenkins:git:2.5.0:beta-1:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:virtools:virtools_3d_life_player:4.0.0.x`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.9:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:virtualaccess:gw6110a:-`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:virtualaccess:gw6110a_firmware:9.00`,
        fs:  `cpe:2.3:a:lucent:vitalhelp:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:virtualaccess:gw6110a_firmware:9.09.27`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:virtualaccess:gw6110a_firmware:9.50`,
        fs:  `cpe:2.3:a:gnome:glib:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:virtualaccess:gw6110a_firmware:9.50.21`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:virtualaccess:gw6110a_firmware:10.00`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:virtualaccess:gw6110a_firmware:10.00.21`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6a:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virtuemart:virtuemart:3.0.14::~~~joomla%21~~`,
        fs:  `cpe:2.3:h:huawei:eudemon8000e-x:v200r001c00spc600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:virusbuster:virusbuster_internet_securit_suite:3.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8:gold`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8:rc1`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8:rc2`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8:rc3`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)m1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8:rc4_pl1`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8:rc5`,
        fs:  `cpe:2.3:a:jextn:com_jefaqpro:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8:rc6`,
        fs:  `cpe:2.3:a:oracle:global_order_promising:12.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8:rc7`,
        fs:  `cpe:2.3:a:ibm:iss_proventia_desktop:8.0.812.1790:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8.1`,
        fs:  `cpe:2.3:a:python:python:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscacha:viscacha:0.8.1.1`,
        fs:  `cpe:2.3:a:dell:system_e-support_tool:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscomsoft:image_viewer_cp_gold_sdk:6.0`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:viscomsoft:image_viewer_cp_pro_sdk:8.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visionael:visionael_studio:8.1.0.3455`,
        fs:  `cpe:2.3:a:more-cowbell:cowbell:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:visioneer:onetouch_8650:-`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.6.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visionsolutions:double-take:4.3.0.0.1170.s.1`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visionsolutions:double-take:4.3.4.0.1271.s.1`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visionsolutions:double-take:4.4.1.0.1352.s.11`,
        fs:  `cpe:2.3:a:mollify:mollify:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visionsolutions:double-take:4.4.1.0.1352.s.29`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.26.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visionsolutions:double-take:4.4.2.2.1414.s.1`,
        fs:  `cpe:2.3:a:apache:camel:2.0.0:m2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visiwave:site_survey:1.6.12`,
        fs:  `cpe:2.3:a:avast:pro_antivirus:11.1.2261:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visiwave:site_survey:2.0.12`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visiwave:site_survey:2.1`,
        fs:  `cpe:2.3:h:hp:9100c_digital_sender:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visiwave:site_survey:2.1.9`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visiwave:site_survey:3.0:beta`,
        fs:  `cpe:2.3:h:hp:0235a322:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vistasystems:spyder_control_suite_2005:2.10.8`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualcertexam:visual_certexam_suite:1.9`,
        fs:  `cpe:2.3:a:patrick_przybilla:addtoany:6.x-3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:3.0`,
        fs:  `cpe:2.3:a:bytemark:symbiosis:1321:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.1.2.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.1.5.0`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:rc2009-02-06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.1.8.0`,
        fs:  `cpe:2.3:a:apache:groovy:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.2.8.0`,
        fs:  `cpe:2.3:a:teamquest:manager:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.2.11.0`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.2.13.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.2.14.0`,
        fs:  `cpe:2.3:a:libav:libav:0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.3.2.0`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.3.5.0`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.4.0.0`,
        fs:  `cpe:2.3:a:passion4profession:chest_workout:2.0.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.4.2.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.4.3.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.634.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.4.5.0`,
        fs:  `cpe:2.3:a:sixapart:movabletype:6.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.4.6.0`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.2:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.4.7.0`,
        fs:  `cpe:2.3:a:bea:weblogic_server:4.5.1:sp15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.5.0.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.5.1.0`,
        fs:  `cpe:2.3:a:clamav:clamav:0.90.2_p0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.5.2.0`,
        fs:  `cpe:2.3:a:ca:unicenter_service_desk:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.5.3.0`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualsoftru:visual_quickbar:4.6.1`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualware:myconnection_server:8.2b`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:visualware:myconnection_server:9.7i`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vitamin_plugin_project:vitamin:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:debian:reprepro:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vitamin_plugin_project:vitamin:1.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:vitamin_plugin_project:vitamin:1.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:rv016_multi-wan_vpn_firmware:4.0.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vitei:qlock:1.44`,
        fs:  `cpe:2.3:h:planex:brl-04r:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vivonet:albion_college:2.1.16::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vkr_soft:government_best_jobs:0.1::~~~android~~`,
        fs:  `cpe:2.3:h:intel:5500_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vms_development:installdeployservice:1.0.0`,
        fs:  `cpe:2.3:a:libical_project:libical:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmturbo:operations_manager:4.0`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmturbo:operations_manager:4.5:-`,
        fs:  `cpe:2.3:a:isc:bind:9.10.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmturbo:operations_manager:4.5:1`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmturbo:operations_manager:4.6`,
        fs:  `cpe:2.3:a:phplist:phplist:2.11.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ace:-`,
        fs:  `cpe:2.3:a:freemind:freemind:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ace:1.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.5:i5p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ace:1.0.3`,
        fs:  `cpe:2.3:a:hp:hppiofiles:2.0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ace:1.0.3_build_54075`,
        fs:  `cpe:2.3:a:conky:conky:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ace:2.0`,
        fs:  `cpe:2.3:a:emc:networker:8.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ace:2.0.1_build_55017`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s5500-52c-pwr-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ace_2:-`,
        fs:  `cpe:2.3:a:emc:documentum_xplore:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:airwatch:7.3.0.0`,
        fs:  `cpe:2.3:a:siemens:wincc:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:airwatch:7.3.3.0`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacity_planner:2.6.2.22938`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa:3.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacityiq:1.0.0`,
        fs:  `cpe:2.3:a:avaya:communication_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacityiq:1.0.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.50.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacityiq:1.0.2`,
        fs:  `cpe:2.3:a:yumenomachi:demaecan:2.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacityiq:1.0.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacityiq:1.0.4`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.2.0:-:black:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacityiq:1.5.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacityiq:1.5.1`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:capacityiq:1.5.2`,
        fs:  `cpe:2.3:a:simpilotgroup:pop_up_news:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:consolidated_backup_framework:1.5.0.2192`,
        fs:  `cpe:2.3:a:google:chrome:10.0.626.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:converter:1.0.0`,
        fs:  `cpe:2.3:a:david_king:vino:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:converter:3.0.2`,
        fs:  `cpe:2.3:a:microsoft:infopath:2003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:converter:3.0.3`,
        fs:  `cpe:2.3:h:3com:superstack_ii_2000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:converter_enterprise_client:4.0.3.62417`,
        fs:  `cpe:2.3:a:hp:openview_performance_core:10.0.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:data_recovery:1.2.0`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:-`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.3\(2.37\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:1.5.2:patch1`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:1.5.2:patch2`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.9.1.2401:unknown:online_windows_server_2003:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:1.5.2:patch3`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.0`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.0:build_5257`,
        fs:  `cpe:2.3:o:cisco:ios:12.2zd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.0.1`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:1.0.1.e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.0.1:build6403`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.0.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.1`,
        fs:  `cpe:2.3:o:juniper:junos:12.3x50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.1.1`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.1.2`,
        fs:  `cpe:2.3:a:microsoft:visio_2003-:sp3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.1.3`,
        fs:  `cpe:2.3:h:3com:3c16486:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.5`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.5.2`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.5.3`,
        fs:  `cpe:2.3:a:powerprogrammer:software_update_wizard:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.5.3:patch1`,
        fs:  `cpe:2.3:a:freetype:freetype:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:2.5.4`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:3.0.0`,
        fs:  `cpe:2.3:a:mozilla:firefox:19.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:3.0.1`,
        fs:  `cpe:2.3:a:cisco:unified_customer_voice_portal:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:3.0.2`,
        fs:  `cpe:2.3:a:webtrends:main_application:8.7.4.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:3.0.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:3.5`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:3.5:update1`,
        fs:  `cpe:2.3:a:hp:openview_network_node_manager:7.53:-:linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:3.5:update2`,
        fs:  `cpe:2.3:a:ibm:thinkvantage_power_manager:1.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:3.5:update3`,
        fs:  `cpe:2.3:a:hp:smart_web_printing:140.0.186.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:4.0`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.7.5:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:4.1`,
        fs:  `cpe:2.3:a:tryton:tryton:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esx:5.0`,
        fs:  `cpe:2.3:h:dell:latitude_e6400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(15\)t9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:1.5.2:patch1`,
        fs:  `cpe:2.3:a:spip:spip:3.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:1.5.2:patch2`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:1.5.2:patch3`,
        fs:  `cpe:2.3:a:varnish-cache:varnish:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.0`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.458.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.0.1_build_6403`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.0.2`,
        fs:  `cpe:2.3:h:cisco:unity_server:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.0_build_5257`,
        fs:  `cpe:2.3:a:watchguard:server_center:11.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.1`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.1.1`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.12.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.1.2`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.1.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.0dpb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.5`,
        fs:  `cpe:2.3:a:redhat:freeipa:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.5.2`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.5.3`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:8.0.204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.5.3:patch1`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:2.5.4`,
        fs:  `cpe:2.3:a:avanset:visual_certexam_manager:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:3.0.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:3.0.1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:esx_server:3.0.2`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-java-crytography-api:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:3.5`,
        fs:  `cpe:2.3:a:exim:exim:4.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:3.5:1`,
        fs:  `cpe:2.3:a:cisco:telepresence_multipoint_switch_software:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:4.0`,
        fs:  `cpe:2.3:a:isc:dhcp_client:3.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:4.0:1`,
        fs:  `cpe:2.3:h:hp:3com_router:3016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:4.0:2`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:4.0:3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:4.0:4`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.01:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:4.1`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:4.1:1`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:4.1:2`,
        fs:  `cpe:2.3:o:hp:1000_series_firmware:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:5.0`,
        fs:  `cpe:2.3:a:ca:itechnology_igateway:4.0.041221:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:5.0:1`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:5.0:2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:5.1`,
        fs:  `cpe:2.3:a:php:php:5.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:5.1:1`,
        fs:  `cpe:2.3:a:lxml:lxml:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:5.5`,
        fs:  `cpe:2.3:a:php:php:5.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:esxi:6.0`,
        fs:  `cpe:2.3:h:hp:3com_router:5642_taa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:3.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.12.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:3.1.1`,
        fs:  `cpe:2.3:a:hp:centralview_credit_risk_control:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:3.1.2`,
        fs:  `cpe:2.3:a:mozilla:firefox:10.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:4.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)n2\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:4.0.1`,
        fs:  `cpe:2.3:o:yamaha:rt200i:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:4.0.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:4.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.7:*:*:*:base:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:4.1.1`,
        fs:  `cpe:2.3:a:nuance:pdf_create:4.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:4.1.2`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:4.1.3`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:4.1.4`,
        fs:  `cpe:2.3:a:ibm:db2:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:5.0`,
        fs:  `cpe:2.3:a:mozilla:firefox_mobile:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:5.0.1`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2008:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:5.0.2`,
        fs:  `cpe:2.3:a:safari_browser_project:safari_browser:1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:7.0`,
        fs:  `cpe:2.3:a:winzip:winzip:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:7.1`,
        fs:  `cpe:2.3:a:skype:skype:3.5.0.202:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:7.1.1`,
        fs:  `cpe:2.3:a:paolo_bacchilega:file_roller:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:8.0.0`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:8.0.1`,
        fs:  `cpe:2.3:a:libpng:libpng:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:8.0.2`,
        fs:  `cpe:2.3:a:anything-digital:sh404sef:2.1.3.680:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:8.1.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:8.5.0`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion:8.5.1`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion_pro:8.0.0`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion_pro:8.0.1`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion_pro:8.0.2`,
        fs:  `cpe:2.3:h:huawei:s9306e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion_pro:8.1.0`,
        fs:  `cpe:2.3:a:controlmicrosystems:clearscada_2009:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion_pro:8.1.1`,
        fs:  `cpe:2.3:a:vips:vips:7.11.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion_pro:8.5.0`,
        fs:  `cpe:2.3:a:moodle:moodle:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:fusion_pro:8.5.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:-`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:2.0`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.52:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:2.0.0_build_2050`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.5:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:2.0.1_build_2129`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:2.5.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.3.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:2.5.1_build_5336`,
        fs:  `cpe:2.3:a:apache:groovy:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:2.5.2`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.0m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:3.0_build_7592`,
        fs:  `cpe:2.3:a:bundler:bundler:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:3.1`,
        fs:  `cpe:2.3:a:adobe:acrobat:17.011.30068:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:gsx_server:3.2`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.00.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:5.0`,
        fs:  `cpe:2.3:a:hp:array_diagnostic_utility:7.85.16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:5.0.1`,
        fs:  `cpe:2.3:o:hp:vvos:10.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:5.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:5.1.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:5.2.0`,
        fs:  `cpe:2.3:a:google:chrome:17.0.962.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:5.3`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:6.0`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers:2.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:6.0.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(8\)yw2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:6.1`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:6.1.1`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:4.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:6.2`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:horizon_view:7.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.3:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:hyperic_hq:4.2`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:hyperic_hq:4.3`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:54.1.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:hyperic_hq:4.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.1cx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:hyperic_hq:4.6.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure:-`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure:3`,
        fs:  `cpe:2.3:h:ibm:security_network_protection_xgs_4100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_client:2.5.0.64207`,
        fs:  `cpe:2.3:a:dell:sonicwall_scrutinizer:9.5.2:-:free:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_client:2.5.0.64227`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_client:2.5.0.64228`,
        fs:  `cpe:2.3:a:altiris:context_factory:6.0.1127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_client:2.5.0.64237`,
        fs:  `cpe:2.3:a:jzip:jzip:2.0.0.132900:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_client:2.5.0.64247`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_client:2.5.0.64257`,
        fs:  `cpe:2.3:o:yahama:rt105i:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_client:2.5.0.64258`,
        fs:  `cpe:2.3:a:savage_nation_mobile_web_project:savage_nation_mobile_web:0.57.13354.63350:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_update:2.5.0.64207`,
        fs:  `cpe:2.3:a:hp:array_diagnostic_utility:8.25.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_update:2.5.0.64227`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_update:2.5.0.64237`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_update:2.5.0.64247`,
        fs:  `cpe:2.3:a:adobe:flash_media_server:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:infrastructure_virtualcenter:-`,
        fs:  `cpe:2.3:a:sophos:unified_threat_management_software:9.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:license_server:2.5.0.64237`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:license_server:2.5.0.64247`,
        fs:  `cpe:2.3:a:schneider-electric:ofs_test_client_tlxcdltofs33:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:movie_decoder:6.5.2`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.4\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:movie_decoder:6.5.3`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:movie_decoder:6.5.4`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:movie_decoder:6.5.5`,
        fs:  `cpe:2.3:a:gentoo:nvclock:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:movie_decoder:7.0`,
        fs:  `cpe:2.3:a:adbnewssender_project:adbnewssender:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:movie_decoder:7.1.2`,
        fs:  `cpe:2.3:a:serena:pvcs_version_manager:8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:movie_decoder:9.0.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:openpegasus_management_server:-`,
        fs:  `cpe:2.3:a:python:setuptools:0.6.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ovf_tool:0.9`,
        fs:  `cpe:2.3:a:sourcefabric:newscoop:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ovf_tool:1.0`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.11:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ovf_tool:2.0.1`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ovf_tool:2.1`,
        fs:  `cpe:2.3:a:bea:weblogic_integration:8.1:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:ovf_tool:3.0.1`,
        fs:  `cpe:2.3:a:piwik:piwik:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:vmware:photon_os:1.0:2016-08-14`,
        fs:  `cpe:2.3:a:autodesk:material_library_2012:2.5.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:-`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.3\(0.876\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.0`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110920:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.1`,
        fs:  `cpe:2.3:a:microsoft:sna_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.2`,
        fs:  `cpe:2.3:a:pinnaclesys:instant_dvd_recorder:2.0.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.3`,
        fs:  `cpe:2.3:a:pocketmags:old_bike_mart:\@7f08017e:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.4`,
        fs:  `cpe:2.3:a:rsa:pluggable_authentication_module_agent:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.5`,
        fs:  `cpe:2.3:a:livezilla:livezilla:5.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.5_build_56455`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.6`,
        fs:  `cpe:2.3:a:orchardproject:orchard:1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.7`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.8`,
        fs:  `cpe:2.3:a:zeus:zeus_web_server:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:1.0.9`,
        fs:  `cpe:2.3:a:apple:webkit:512.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.0`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.00:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.0.1`,
        fs:  `cpe:2.3:a:mcafee:epo_mcafee_virtual_technician:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.0.1_build_55017`,
        fs:  `cpe:2.3:a:samsung:masetupcaller_activex_control:1.4.2012.508:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.0.2`,
        fs:  `cpe:2.3:a:google:chrome:15.0.870.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.0.3`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1670.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.0.4`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.06.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.0.5`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center:2011.524.2259.39378:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.5`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.415:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.5.1`,
        fs:  `cpe:2.3:a:google:android_debug_bridge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.5.2`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.5.3`,
        fs:  `cpe:2.3:h:3com:3c17204-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.5.4`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1033.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:2.5.5`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.15:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.0`,
        fs:  `cpe:2.3:a:otrs:otrs:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.0.1`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1`,
        fs:  `cpe:2.3:a:sun:ray_windows_connector:1.1:*:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1.0.12623`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1.2`,
        fs:  `cpe:2.3:a:jenkins:git:3.5.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1.3`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2su:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1.4.16648`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1.5`,
        fs:  `cpe:2.3:a:redhat:cloudforms_management_engine:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:3.1.6`,
        fs:  `cpe:2.3:a:oracle:report_manager:12.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:4.0`,
        fs:  `cpe:2.3:a:maxthon:maxthon_browser:2.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:4.0.0.18997`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:4.0.1`,
        fs:  `cpe:2.3:a:validated_plugin_project:validated_plugin:1.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:4.0.2`,
        fs:  `cpe:2.3:h:cisco:pix_asa:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:4.0.3`,
        fs:  `cpe:2.3:a:sun:java_system_application_server:8.1:*:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:4.0.4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1038:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:4.0.5`,
        fs:  `cpe:2.3:a:x2go:x2go_server:4.0.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:4.0.6`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:5.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:5.0`,
        fs:  `cpe:2.3:o:xen:xen:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:5.0.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4500_series_software:4.2\(1.46\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:5.0.2`,
        fs:  `cpe:2.3:o:cisco:mds_9000_san-os:3.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:7.0`,
        fs:  `cpe:2.3:a:freemind:freemind:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:7.1`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:player:7.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:remote_console:1.5.0`,
        fs:  `cpe:2.3:a:lars_hjemli:cgit:0.8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:remote_console_plug-in:2.5.0.122581`,
        fs:  `cpe:2.3:a:debian:dpkg:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:-`,
        fs:  `cpe:2.3:a:nancy_wichmann:sitedoc:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0`,
        fs:  `cpe:2.3:a:cognos:cognos_enterprise_planning_client:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.1`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_express:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.1_build_29996`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:9.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.2`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.3`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.4`,
        fs:  `cpe:2.3:a:bea:logging_utilities:6.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.4_build_56528`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.5`,
        fs:  `cpe:2.3:a:altiris:pxe_manager:6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.6`,
        fs:  `cpe:2.3:a:tasofro:touhou-hisouten:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.7`,
        fs:  `cpe:2.3:a:masahiko_watanabe:apsaly:3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.8`,
        fs:  `cpe:2.3:a:roxio:creator_copy:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:1.0.9`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:2.0.0`,
        fs:  `cpe:2.3:h:cisco:asa_1000v_cloud_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:2.0.0.2712`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:2.0.1`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:14.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:server:2.0.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.17.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:springsource_spring_security:2.0.7`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.5.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:springsource_spring_security:3.0.6`,
        fs:  `cpe:2.3:a:buffalotech:wzr-ampg144nh_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:springsource_spring_security:3.1.1`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:springsource_spring_security:3.1.2`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.5.5.2:-:liberty_profile:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:springsource_spring_security:3.1.3`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.4:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:-`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.0.0`,
        fs:  `cpe:2.3:a:avast:avast_antivirus_free:5.0.594:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.1.0`,
        fs:  `cpe:2.3:a:google:checkout-php:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.1.2.10559`,
        fs:  `cpe:2.3:a:winzip:winzip:6.0a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.1.2.12031`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.2:*:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.1.2.12548`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.4\(0.109\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.1.2.14166`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3a8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.1.2.14664`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.1.2.15040`,
        fs:  `cpe:2.3:a:roxio:cd_creator:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:3.1.2.20911`,
        fs:  `cpe:2.3:o:redhat:linux:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.0.1.12458`,
        fs:  `cpe:2.3:a:cambridge_enterprise:jbig-kit:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.0.2.14744`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.0.2.16474`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.0.2.17586`,
        fs:  `cpe:2.3:a:alienvault:unified_security_management:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.0.3.17828`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.0.3.19531`,
        fs:  `cpe:2.3:a:adobe:flash_player:15.0.0.189:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.0.3.21653`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.26.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.0.4.24748`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.3.2.1593`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.3.7.3827`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.3.7.4937`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.5-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.3.12.8191`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.4.6.16648::~~freebsd~~~`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.4.6.16648::~~linux~~~`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0:beta_1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.4.6.16648::~~netware~~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.320:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.4.6.16648::~~solaris~~~`,
        fs:  `cpe:2.3:a:ibm:db2:8.2:fp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.4.6.16648::~~windows~~~`,
        fs:  `cpe:2.3:a:microsoft:windows_media_format_runtime:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.4.6.16648::~~winpre2k~~~`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.6.0.6261`,
        fs:  `cpe:2.3:a:gnome:glib:2.31.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.0.7539`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:10.00.tc5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.0.471780::~~freebsd~~~`,
        fs:  `cpe:2.3:a:perl:perl:2.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.0.471780::~~linux~~~`,
        fs:  `cpe:2.3:a:isc:bind:9.2.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.0.471780::~~netware~~~`,
        fs:  `cpe:2.3:a:typsoft:typsoft_ftp_server:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.0.471780::~~solaris~~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.105:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.0.471780::~~windows~~~`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.10.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.0.471780::~~winpre2k~~~`,
        fs:  `cpe:2.3:h:cisco:business_edition_3000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.1.9139`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.1.528992::~~freebsd~~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.1.528992::~~linux~~~`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.1.5:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.1.528992::~~netware~~~`,
        fs:  `cpe:2.3:a:pbboard:pbboard:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.1.528992::~~solaris~~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.1.528992::~~windows~~~`,
        fs:  `cpe:2.3:a:apple:quicktime:7.2.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:8.8.1.528992::~~winpre2k~~~`,
        fs:  `cpe:2.3:a:gnupg:gnupg:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.1`,
        fs:  `cpe:2.3:a:sun:jre:1.6.0:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.5`,
        fs:  `cpe:2.3:a:redhat:daredevil_skk:11.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.10`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.11`,
        fs:  `cpe:2.3:a:google:chrome:5.0.322.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.12`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.13`,
        fs:  `cpe:2.3:a:johtru:gymnoovp:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.15`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.16`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1275.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.0.17`,
        fs:  `cpe:2.3:a:python:python:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.4.0`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_password_manager_pro:6.2:*:*:*:managed_service_providers:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.4.5`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:g05.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.4.10`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.240:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.4.11`,
        fs:  `cpe:2.3:h:symantec:web_gateway_appliance_8490:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.4.12`,
        fs:  `cpe:2.3:a:cisco:application_policy_infrastructure_controller:1.0\(1h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.4.15`,
        fs:  `cpe:2.3:a:mattias_hutterer:taxonomy_manager:7.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.10.0`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.10.1`,
        fs:  `cpe:2.3:a:vmware:vsphere_client:6.0:u1b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:9.10.5`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:10.0.0`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:0.98.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:10.0.6`,
        fs:  `cpe:2.3:a:buffalotech:wer-amg54_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:tools:10.0.8`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.11.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:update_manager:1.0.0.63985`,
        fs:  `cpe:2.3:a:mcafee:virusscan_security_center:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:update_manager:1.0.0.63995`,
        fs:  `cpe:2.3:a:openjpeg:openjpeg:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_chargeback_manager:1.5.0`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_chargeback_manager:1.6.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_chargeback_manager:1.6.1`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.6.5.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_chargeback_manager:1.6.2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_chargeback_manager:2.0.0`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_chargeback_manager:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.485.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_chargeback_manager:2.5.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_chargeback_manager:2.5.1`,
        fs:  `cpe:2.3:a:mcafee:quickclean:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter:4.1.1.6534`,
        fs:  `cpe:2.3:a:apache:camel:2.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter:4.2.1.327369`,
        fs:  `cpe:2.3:a:isc:bind:4.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_agent:4.1.1.6534`,
        fs:  `cpe:2.3:a:nagios:nagios_xi:2012r2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_agent:4.2.0.254483`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:10.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_client:4.1.1.6534`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:8.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_client:4.2.0.254483`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_client:4.2.1.327369`,
        fs:  `cpe:2.3:a:redmine:redmine:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_standalone:4.0.0.146302`,
        fs:  `cpe:2.3:a:apache:http_server:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_standalone:4.0.1.161434`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_standalone:4.3.0.292238`,
        fs:  `cpe:2.3:h:cisco:telepresence_video_communication_server:-:*:control:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_standalone:5.0.0.470252`,
        fs:  `cpe:2.3:a:ca:license_software:1.62.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_standalone_agent:4.0.1.161434`,
        fs:  `cpe:2.3:a:aol:aim:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_converter_standalone_agent:4.3.0.292238`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.1.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_guided_consolidation:4.0.0.7797`,
        fs:  `cpe:2.3:a:werdswords:download_shortcode:0.2.3:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_inventory_service:5.0.0.16964`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro_advanced:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_operations:1.0.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_operations:1.0.1`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_operations:1.0.2`,
        fs:  `cpe:2.3:a:urs_maag:maag_form_captcha:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_operations:5.0.0`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_operations:5.0.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_operations:5.0.2`,
        fs:  `cpe:2.3:a:vips:vips:7.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_operations:5.0.3`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:4.0.1.4502`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.12:ga12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:4.0.2.4639`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:4.1.1.733`,
        fs:  `cpe:2.3:a:avaya:vpnremote:4.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:4.1.2.27`,
        fs:  `cpe:2.3:a:git-scm:git:2.15.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:4.2.0.5277`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:5.5`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:5.5.1`,
        fs:  `cpe:2.3:a:karsten_dusterloh:mnenhy:0.7.5.666:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:5.5.2`,
        fs:  `cpe:2.3:a:redhat:spacewalk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_orchestrator:5.5.2.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:4.0.0.10021`,
        fs:  `cpe:2.3:a:nist:hipaa_security_rule_toolkit:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:4.0.0.12305`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:4.1`,
        fs:  `cpe:2.3:a:adcillc:simplemeta:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:4.1:update_1`,
        fs:  `cpe:2.3:a:usvn:user-friendly_svn:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:4.1:update_2`,
        fs:  `cpe:2.3:a:microsoft:ie:7.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:4.1.0.12319`,
        fs:  `cpe:2.3:a:x:libxtst:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:4.1.0.14766`,
        fs:  `cpe:2.3:a:microsoft:visio_multilingual_user_interface_pack:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:4.1.0.17435`,
        fs:  `cpe:2.3:a:iphone4:iphone4.tw:3.3.20:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p76:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.0:beta`,
        fs:  `cpe:2.3:a:ipswitch:whatsup:2006:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.0:update_1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.0:update_2_rc`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:101k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.0.0.16964`,
        fs:  `cpe:2.3:a:rack_project:rack:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.5`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.5:u1`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.5:u2`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.5:u3a`,
        fs:  `cpe:2.3:a:ibm:platform_symphony:5.2:*:*:*:developer:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:5.5:u3b`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:6.0`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.112:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:6.0:2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.14:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:6.0:2m`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:6.0:a`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:6.0:b`,
        fs:  `cpe:2.3:a:cobbler_project:cobbler:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:6.0:u1`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server:6.0:u1b`,
        fs:  `cpe:2.3:a:safenet-inc:luna_sa_software_development_kit:4.4.1:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server_appliance:5.0`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_service_platform:07-60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server_appliance:5.0:update_1`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.45.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server_appliance:5.0:update_2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server_appliance:5.1`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.56.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_server_appliance:5.1:update_1`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_update_manager:4.0.0.3194`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_update_manager:4.0.0.3971`,
        fs:  `cpe:2.3:a:solarwinds:firewall_security_manager:6.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_update_manager:4.0.0.5332`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_update_manager:4.1.0.5142`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management_essentials:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_update_manager:4.1.0.6589`,
        fs:  `cpe:2.3:h:cisco:catalyst_2900_vlan:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_update_manager:4.1.0.6589:update_1`,
        fs:  `cpe:2.3:h:hp:storageworks_p2000_g3_msa_fibre_channel_dual_controller_lff_array_system:ap845a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_update_manager:4.1.0.8977`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr0804hd-l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcenter_update_manager:4.1.0.8977:update_2`,
        fs:  `cpe:2.3:a:seeddms:seeddms:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_automation_center:6.0.1`,
        fs:  `cpe:2.3:o:ibm:system_storage_virtualization_engine_ts7700_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_automation_center:6.0.1.1`,
        fs:  `cpe:2.3:a:openvas:openvas_administrator:1.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_automation_center:6.0.1.2`,
        fs:  `cpe:2.3:a:libav:libav:11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_automation_center:6.1`,
        fs:  `cpe:2.3:a:apache:myfaces:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_automation_center:6.1.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:4.4:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_director:5.1.0`,
        fs:  `cpe:2.3:a:animoca:star_girl\:_colors_of_spring:3.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_director:5.1.1`,
        fs:  `cpe:2.3:a:bmc:control-m\/agent:6.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_director:5.1.2`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vcloud_director:5.1.3`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.237:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:4.0.0`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.8.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:4.0.0:u2`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.3r1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:4.5`,
        fs:  `cpe:2.3:a:roxio:cineplayer_decoder_pack:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:4.6.0`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server_solution_engine:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:4.6.1`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ece:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:4.6.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:5.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.12.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:5.0.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:5.0.0:u2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:5.0.1`,
        fs:  `cpe:2.3:a:cgi_rescue:blobee:0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:5.1.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:5.1.1`,
        fs:  `cpe:2.3:a:xnau:participants_database:1.5.4.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view:5.1.2`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:view_client:4.6.0.366101`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtual_disk_development_kit:1.0.0`,
        fs:  `cpe:2.3:o:cisco:staros:19.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtual_infrastructure_client:-`,
        fs:  `cpe:2.3:a:cisco:tidal_enterprise_scheduler:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtual_infrastructure_client:2.0.2.50618`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtual_infrastructure_client:2.0.2.62345`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtual_infrastructure_remote_command_line_interface:.26`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.2\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtual_infrastructure_remote_command_line_interface:.278`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtualcenter:1.4.1`,
        fs:  `cpe:2.3:a:augeas:augeas:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtualcenter:2.0:unknown:client`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtualcenter:2.0.1`,
        fs:  `cpe:2.3:a:projeqtor:projeqtor:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:virtualcenter_server:2.5.0.64247`,
        fs:  `cpe:2.3:a:vips:vips:7.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vix:1.10.0.12331`,
        fs:  `cpe:2.3:a:microsoft:ie:7.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vm-support:0.88`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vma:4.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.1.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vma:4.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.1.0:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vma:5.0.0.1`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vmci_sockets:9.1.54.1`,
        fs:  `cpe:2.3:a:microsoft:teredo:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.0.0`,
        fs:  `cpe:2.3:h:netgear:wg602:1.5.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.0.1`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.0.1.1`,
        fs:  `cpe:2.3:h:lexmark:cs725dte:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.0.1.2`,
        fs:  `cpe:2.3:a:portaplus:porta\&#43;_ftp_client:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.1.0`,
        fs:  `cpe:2.3:h:cisco:nexus_93128tx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.1.1`,
        fs:  `cpe:2.3:a:rack_project:rack:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.2.0`,
        fs:  `cpe:2.3:a:hp:hpssupply:2.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.2.1`,
        fs:  `cpe:2.3:a:dell:system_customization_wizard:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.2.2`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.2.3`,
        fs:  `cpe:2.3:a:samba:samba:3.0.2:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_automation:6.2.4`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:alpha12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_operations:6.0.0`,
        fs:  `cpe:2.3:a:microsoft:network_monitor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_operations:6.1.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.550.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_operations:6.2.0a`,
        fs:  `cpe:2.3:a:kde:koffice:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_operations:6.2.1`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_brms_platform:5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_operations:6.3.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_orchestrator:6.0.1`,
        fs:  `cpe:2.3:a:hitachi:ibm_xl_c\/c\&#43;\&#43;_v8_for_aix_\&amp;_hitachi_developer\&#39;s_kit_for_java:02-05-\/q:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_orchestrator:6.0.2`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.4.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vrealize_orchestrator:6.0.3`,
        fs:  `cpe:2.3:a:arcsoft:photostudio:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.0:update_4`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.0.0.7797`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.0.0.10021`,
        fs:  `cpe:2.3:a:sybase:adaptive_server_enterprise:15.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.0.0.12305`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.0.0.14874`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.157:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.0.0.15751`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.1:update_3`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.1.0.12319`,
        fs:  `cpe:2.3:a:foswiki:foswiki:1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.1.0.14766`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:pl:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:4.1.0.17435`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:5.0`,
        fs:  `cpe:2.3:a:securecomputing:securityreporter:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:5.0.0.16964`,
        fs:  `cpe:2.3:a:redmine:redmine:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:5.1`,
        fs:  `cpe:2.3:a:typo3:typo3:7.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:5.5`,
        fs:  `cpe:2.3:a:projectforge:projectforge:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:5.5:u1`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:5.5:u2`,
        fs:  `cpe:2.3:h:cisco:b22_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:5.5:u3a`,
        fs:  `cpe:2.3:h:3com:3crwe754g72-a:1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:5.5:u3b`,
        fs:  `cpe:2.3:a:winscp:winscp:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:6.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ixc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:6.0:2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:6.0:2m`,
        fs:  `cpe:2.3:a:google:v8:3.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:6.0:a`,
        fs:  `cpe:2.3:h:huawei:campus_s9300e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:6.0:b`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:6.0:u1`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_client:6.0:u1b`,
        fs:  `cpe:2.3:a:axis:camera_station_one:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.5.1`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.1.5.1551:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.5.5`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.5.6`,
        fs:  `cpe:2.3:a:metalogix:migration_manager_for_sharepoint:4.1.1303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.5.7`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.5.8`,
        fs:  `cpe:2.3:a:individualsoftware:professor_teaches_excel:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.5.9`,
        fs:  `cpe:2.3:a:rpm:rpm:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.5.10`,
        fs:  `cpe:2.3:h:yokogawa:exaquantum\/batch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.5.11`,
        fs:  `cpe:2.3:o:a10networks:advanced_core_operating_system:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.8.0`,
        fs:  `cpe:2.3:a:boxes_project:boxes:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.8.1`,
        fs:  `cpe:2.3:a:docebo:docebolms:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.8.2`,
        fs:  `cpe:2.3:a:barcode_scanner_project:barcode_scanner:2.3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.8.3`,
        fs:  `cpe:2.3:a:citrix:online_plug-in:12.0.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:5.8.4`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.0.0`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.0.1`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.15:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.0.2`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.5\(2\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.0.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.11.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.0.4`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.1.0`,
        fs:  `cpe:2.3:o:yahama:rt102i:3.00.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.1.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.1.2`,
        fs:  `cpe:2.3:a:keepass:keepass:0.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_data_protection:6.1.3`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_host_update_utility:4.0.0.7797`,
        fs:  `cpe:2.3:a:netsarang:xmanager:4.0.165:*:*:*:enterprise_beta:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_host_update_utility:4.0.0.10021`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:9.0.432:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_host_update_utility:4.0.0.12305`,
        fs:  `cpe:2.3:a:mark_evans:fog-dragonfly:0.8.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_host_update_utility:4.0.0.15751`,
        fs:  `cpe:2.3:a:keycloak:keycloak-nodejs-auth-utils:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_profile-driven_storage:5.0.0.16964`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:5.5`,
        fs:  `cpe:2.3:a:isc:bind:9.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:5.5:u1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.40:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:5.5:u2`,
        fs:  `cpe:2.3:a:weathernews:weathernews_touch:1.35:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:5.5:u3a`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:5.5:u3b`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:6.0`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.1:-:mac:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:6.0:2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:6.0:2m`,
        fs:  `cpe:2.3:a:atlassian:hipchat:6.29.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:6.0:a`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(13\)w5\(19c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:6.0:b`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:6.0:u1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.6.21737:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_server:6.0:u1b`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_update_manager:5.0.0.8039`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:vsphere_update_manager_client:5.0.0.8039`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:-`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:2.0`,
        fs:  `cpe:2.3:a:sun:jre:1.4.2_35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:2.0.1`,
        fs:  `cpe:2.3:a:ibm:aix_5l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:3.2.1:patch1`,
        fs:  `cpe:2.3:a:microsoft:office_web_apps:2010:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:3.4`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:4.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall_software:4.4\(7.202\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:4.0.1`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:4.0.1_build_5289`,
        fs:  `cpe:2.3:a:google:chrome:4.0.304.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:4.0.2`,
        fs:  `cpe:2.3:a:cisco:webns:7.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:4.5`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.12.1204:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:4.5.2`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.6.0\(3954\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:4.5.2_build_8848`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.0.104:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.0.0_build_13124`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5`,
        fs:  `cpe:2.3:h:apple:imac:mb199xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.0_build_13124`,
        fs:  `cpe:2.3:h:adb:p.dga4001n:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.1`,
        fs:  `cpe:2.3:o:asus:rt-ac66u_firmware:3.0.0.4.260:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.1_build_19175`,
        fs:  `cpe:2.3:a:tinycouch:tiny_password:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.2`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.3`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.1\(5b\)su5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.3_build_34685`,
        fs:  `cpe:2.3:a:mozilla:firefox:30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.3_build_42958`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.35:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.240:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.4_build_44386`,
        fs:  `cpe:2.3:o:apple:iphone_os:7.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.5`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.5_build_56455`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.6`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.7`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:5.5.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2013.09.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.0.1`,
        fs:  `cpe:2.3:a:freedomscientific:document_server:10.16.3519.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.0.1_build_55017`,
        fs:  `cpe:2.3:o:huawei:s7703_firmware:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.0.2`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow_set:07-50-09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.0.3`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.4:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.0.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.0.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.3.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.5.0`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.8:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.5.1`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_30-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.5.2`,
        fs:  `cpe:2.3:a:jenkins-ci:subversion-plugin:1.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.5.3`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.5.4`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.5.4.11892`,
        fs:  `cpe:2.3:o:cisco:ios:12.2mrb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:6.5.5`,
        fs:  `cpe:2.3:a:redhat:rhel_extras:5:*:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.0`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.0.1`,
        fs:  `cpe:2.3:a:busybox:busybox:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.1`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.1.1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.1.2`,
        fs:  `cpe:2.3:a:exponentcms:exponent_cms:2.1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.1.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:p6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.1.4`,
        fs:  `cpe:2.3:a:emc:navisphere_command_line_interface:26.10.0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.1.4.16648`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.5.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.1.5`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:7.1.6`,
        fs:  `cpe:2.3:a:sun:patchpro:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0.0.18997`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0.1`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0.1.27038`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.636:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.403.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0.4`,
        fs:  `cpe:2.3:h:foscam:h.264_hi3510\/11\/12_ip_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0.5`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:8.0.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.49b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:9.0`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:9.0.1`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:9.0.2`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:9.0.3`,
        fs:  `cpe:2.3:a:hp:openvms_secure_web_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:10.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p398:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:10.0.1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:10.0.2`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:10.0.3`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:11.0`,
        fs:  `cpe:2.3:a:ibm:maximo_for_transportation:7.5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:11.1`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:11.1.1`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.8.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:12.0.0`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:12.5.0`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:12.5.4`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:12.5.5`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:12.5.6`,
        fs:  `cpe:2.3:a:mortbay:jetty:5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation:12.5.7`,
        fs:  `cpe:2.3:a:siemens:teamcenter\&#39;s_community_collaboration:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_player:12.0.0`,
        fs:  `cpe:2.3:a:ultraseek:ultraseek:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_player:12.0.1`,
        fs:  `cpe:2.3:a:logitech:video_enumerator:10.50.1096:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_player:12.1.0`,
        fs:  `cpe:2.3:h:broadcom:pipa_c211:-:rev2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_player:12.5.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(5a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_player:12.5.1`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_pro:12.0.0`,
        fs:  `cpe:2.3:a:apache:struts:2.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_pro:12.0.1`,
        fs:  `cpe:2.3:a:atlassian:jira_integration_for_hipchat:7.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_pro:12.1.0`,
        fs:  `cpe:2.3:a:mysqldumper:mysqldumper:1.24.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_pro:12.5.0`,
        fs:  `cpe:2.3:a:digium:asterisk:12.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:workstation_pro:12.5.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:15.006.30354:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:zimbra_desktop:2.0`,
        fs:  `cpe:2.3:a:perl:perl:5.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:zimbra_desktop:7.1`,
        fs:  `cpe:2.3:a:debian:apt:0.8.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:zimbra_desktop:7.1.1`,
        fs:  `cpe:2.3:h:xerox:workcentre_m175:6.47.30.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:zimbra_desktop:7.1.2`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.091:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vmware:zimbra_desktop:7.1.2:b10978`,
        fs:  `cpe:2.3:a:netweblogic:login_with_ajax:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vn-calendar_project:vn-calendar:1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:5.0\(0\):sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vodafone:vodafone_avantaj_cepte:1.4::~~~android~~`,
        fs:  `cpe:2.3:a:qemu:qemu:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vodafone:vodafone_mobile_connect_lite:9.3.3.10523`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.15:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:voetbal_project:voetbal:4.7.2::~~~android~~`,
        fs:  `cpe:2.3:a:php:php:5.6.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vortexgroup:light_alloy:4.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.0xa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vortexgroup:light_alloy:4.7.4`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.4:mp1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:votecount_for_balatarin_project:votecount_for_balatarin:0.1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:texinfo:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:voucherry:vouch%21:2.1.6::~~~android~~`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:crm:6.4.0`,
        fs:  `cpe:2.3:a:intel:network_connections:13.1.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:1.0`,
        fs:  `cpe:2.3:a:opensolution:quick_cart:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:2.0`,
        fs:  `cpe:2.3:a:sun:java_system_portal_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:2.0.1`,
        fs:  `cpe:2.3:a:suse:kiwi:4.98.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:2.1`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:3.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.0dpa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:3.0:beta`,
        fs:  `cpe:2.3:a:nsclient:nsclient\&#43;\&#43;:0.3.8.76:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:3.2`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4`,
        fs:  `cpe:2.3:o:gentoo:linux:1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4:beta`,
        fs:  `cpe:2.3:a:feep:libtar:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4:beta::it`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:10.20b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4:rc1`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.870:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4.0.1`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1006.101.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4.2`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4.2::validation`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4.2:patch1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:254:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:4.2.4`,
        fs:  `cpe:2.3:a:geeklog:geeklog:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.11:cert5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.0.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4:ch6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.0.1`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2:final:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.0.2`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-400_cpu_414-3_pn\/dp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.0.3`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.0.4`,
        fs:  `cpe:2.3:a:yahoo:messenger:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.0.4:rc`,
        fs:  `cpe:2.3:a:apache:poi:3.5:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.1.0`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.1.0:rc`,
        fs:  `cpe:2.3:a:debugbar:debugbar_for_internet_explorer:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.2.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.2.1`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.3.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:5.4.0`,
        fs:  `cpe:2.3:a:motorola:air_defense:3.3.0.3:*:*:*:personal:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:6.0.0`,
        fs:  `cpe:2.3:h:3com:3cradsl72:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:6.0.0:beta`,
        fs:  `cpe:2.3:h:yokogawa:prm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:6.0.0:rc`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vtiger:vtiger_crm:6.0.0:sp1`,
        fs:  `cpe:2.3:a:infoblox:netmri:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.0`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.1`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:256:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.2`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_server:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.4`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.08.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.5`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.6`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.2.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.7`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update4:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.8`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.0.9`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.18.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.1`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.2`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.3`,
        fs:  `cpe:2.3:a:ipswitch:imail:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.4`,
        fs:  `cpe:2.3:a:ibm:connections:4.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.5`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.6`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.7`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.1.8`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:8.15.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.2.0`,
        fs:  `cpe:2.3:a:3s-software:codesys_runtime_system:2.3.9.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.2.1`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.2.2`,
        fs:  `cpe:2.3:h:cisco:as5400xm_media_gateway:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.3`,
        fs:  `cpe:2.3:a:winmerge:winmerge:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.4`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2010.211.1740.31663:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.5`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.5.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.8.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.5.0:r1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:vwar:virtual_war:1.6.1:r2`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:2015.008.20082:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w-cms:w-cms:2.01`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.2.0`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_database_server:9.40.uc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.2.1`,
        fs:  `cpe:2.3:a:snort:snort:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.2.2`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.2.4`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.3.0`,
        fs:  `cpe:2.3:a:rts:rtsinfo:1.4.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.3.1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.3.2`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:13.8:cert1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.3.3`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.3.4`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.3.5`,
        fs:  `cpe:2.3:a:owncloud:owncloud:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.3.7`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.0191:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.4.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.3\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.4.1`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.4.2`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.4.3`,
        fs:  `cpe:2.3:a:canon:canoscan_toolbox:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.4.4`,
        fs:  `cpe:2.3:a:cisco:ids_sensor_software:4.1\(5c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.4.5`,
        fs:  `cpe:2.3:a:oracle:application_server:9.2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.4.6`,
        fs:  `cpe:2.3:a:kaseya:virtual_system_administrator:9.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.f1:hostapd:0.4.7`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.2.0`,
        fs:  `cpe:2.3:a:dell:system_e-support_tool:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.2.1`,
        fs:  `cpe:2.3:h:cisco:content_services_switch_11800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.2.2`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.2.2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.2.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.3.0`,
        fs:  `cpe:2.3:a:batavi:batavi:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.3.1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.3.2`,
        fs:  `cpe:2.3:a:siege:phpmyid:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.3.3`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.3.4`,
        fs:  `cpe:2.3:a:oracle:jai:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.3.5`,
        fs:  `cpe:2.3:a:libexpat:expat:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.3.7`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.4.0`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.4.1`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.4.2`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.4.3`,
        fs:  `cpe:2.3:a:perl:perl:0.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.4.4`,
        fs:  `cpe:2.3:a:haxx:curl:7.19.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.4.5`,
        fs:  `cpe:2.3:a:altiris:software_delivery_solution_for_mac:6.1.2032:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.4.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.4.7`,
        fs:  `cpe:2.3:a:xnview:xnview:1.94.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.5.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.5.1`,
        fs:  `cpe:2.3:a:ibm:gentran_integration_suite:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.5.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.5.3`,
        fs:  `cpe:2.3:a:apache:subversion:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.5.4`,
        fs:  `cpe:2.3:a:apache:apr-util:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.5.5`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.5.6`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.6.0`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.6.1`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.6.2`,
        fs:  `cpe:2.3:a:postfix_admin_project:postfix_admin:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.6.3`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:gold:media_center:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.6.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.5h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.6.5`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.6.6`,
        fs:  `cpe:2.3:a:digium:asterisk:10.11.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.6.7`,
        fs:  `cpe:2.3:a:gopivotal:grails:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.7.0`,
        fs:  `cpe:2.3:a:hp:virtual_connect_enterprise_manager_sdk:7.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.7.1`,
        fs:  `cpe:2.3:a:ibm:embedded_websphere_application_server:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.7.2`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:0.7.3`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:1.1`,
        fs:  `cpe:2.3:a:hp:solution_center:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:2.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_localization:2008.1201.1504.27008:*:*:tr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:2.1`,
        fs:  `cpe:2.3:a:avaya:ip600_media_servers:r10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:2.2`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:hostapd:2.5`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.8_pre3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:0.7.0`,
        fs:  `cpe:2.3:a:apple:apple_tv:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:0.7.1`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-35:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:0.7.2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:0.7.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:0.72`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:2.0`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:2.1`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:2015.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:2.2`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:2.3`,
        fs:  `cpe:2.3:h:foundrynet:fastiron_ii_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w1.fi:wpa_supplicant:2.4`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.5\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:w3:jigsaw:2.2.5`,
        fs:  `cpe:2.3:a:friendcasterapp:friendcaster:5.4.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:w3edge:total_cache:0.9.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.20.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wafer:webmatic:3.1.1`,
        fs:  `cpe:2.3:a:deliciousdays:cformsii:14.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:wago:wago_i%2fo_system_758_industrial_pc_device:758-876`,
        fs:  `cpe:2.3:h:hp:laserjet_5000:r.25.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wali:walisms_cn:1.8`,
        fs:  `cpe:2.3:a:apache:solr:3.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wali:walisms_cn:2.1.2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wali:walisms_cn:2.7.0`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wali:walisms_cn:2.9.2`,
        fs:  `cpe:2.3:a:sun:ray_server_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wali:walisms_cn:3.0.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.13a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wali:walisms_cn:3.3.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wali:walisms_cn:3.5.0`,
        fs:  `cpe:2.3:a:sfiab:science_fair_in_a_box:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wali:walisms_cn:3.7.0`,
        fs:  `cpe:2.3:a:microsoft:dynamics_ax:4.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walk_score_project:walk_score:0.5.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:sgi:propack:3:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wallpaperscript:wallpaperscript:3.5.0082`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.0.1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:4.2m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.1`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.2`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.3`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.4`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.6`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.7`,
        fs:  `cpe:2.3:a:tucarro:tucarro:2.0.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.8`,
        fs:  `cpe:2.3:a:david_king:vino:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:1.1.9`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:2.0.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:2.0.2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:2.0.3`,
        fs:  `cpe:2.3:a:perl:perl:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:2.0.4`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp2c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:2.0.5`,
        fs:  `cpe:2.3:a:nvidia:control_panel:275.89:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:2.0.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.5:*:*:*:advanced_workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:walrus_digit:walrack:2.0.7`,
        fs:  `cpe:2.3:a:devexpress:ajax_control_toolkit:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wamba:dating_for_everyone_-_mamba%21:3.5::~~~android~~`,
        fs:  `cpe:2.3:a:john_nunemaker:crack:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wamba:wamba-meet_women_and_men:3.0::~~~android~~`,
        fs:  `cpe:2.3:o:openbsd:openbsd:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wampserver:wampserver:2.0`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.4b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wampserver:wampserver:2.2`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wandisco:wandisco_subversion:1.6.16-5`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:wangkongbao:cns-1000:-`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:wangkongbao:cns-1100:-`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:wansview:h.264_hi3510%2f11%2f12_ip_camera:-`,
        fs:  `cpe:2.3:a:dell:kace_k1000_systems_management_virtual_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wargaming:world_of_tanks_assistant:1.7.5::~~~android~~`,
        fs:  `cpe:2.3:a:atlassian:crowd:1.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:warrior_beach_retreat_project:warrior_beach_retreat:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wasen:mod_simplefileupload:1.0`,
        fs:  `cpe:2.3:a:apple:pages:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wasen:mod_simplefileupload:1.1`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.130:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wasen:mod_simplefileupload:1.3`,
        fs:  `cpe:2.3:o:vmware:esxi:3.5:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wasen:mod_simplefileupload:1.3.5`,
        fs:  `cpe:2.3:a:linux:linux_kernel:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watch4net:apg:4.3u3`,
        fs:  `cpe:2.3:a:ibm:http_server:1.3.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watch4net:apg:5.1`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watcha:watcha:2.0.2::~~~android~~`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watchdog_aggregator_project:watchdog_aggregator:-::~~~drupal~~`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.0.2`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.1`,
        fs:  `cpe:2.3:a:google_calendar_events_project:google_calendar_events:2.0.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.2.3`,
        fs:  `cpe:2.3:a:python:python:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.3`,
        fs:  `cpe:2.3:a:skype:skype:3.0.0.214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.3.6`,
        fs:  `cpe:2.3:o:juniper:junos_space:15.2:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.4`,
        fs:  `cpe:2.3:a:google:chrome:0.3.154.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.4.2`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.5.1`,
        fs:  `cpe:2.3:o:freebsd:freebsd:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.5.3`,
        fs:  `cpe:2.3:a:intel:proset_wireless:10.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.6`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.6.1`,
        fs:  `cpe:2.3:a:ibm:inotes:9.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.6.3`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:554:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.6.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.6.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:7.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.7`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:60.2:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.7.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sga:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.7.3`,
        fs:  `cpe:2.3:a:microsoft:active_directory_lightweight_directory_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.7.4`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.8`,
        fs:  `cpe:2.3:a:gnome:glib:2.31.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.8.1`,
        fs:  `cpe:2.3:a:7-zip:7-zip:9.07:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:watchguard:fireware:11.8.3`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je074a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watchguard:server_center:11.7.3`,
        fs:  `cpe:2.3:a:digia:qt:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watchguard:server_center:11.7.4`,
        fs:  `cpe:2.3:a:simon_tatham:putty:0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watchguard:watchguard_system_manager:-`,
        fs:  `cpe:2.3:a:apache:solr:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watchguard:xcs:9.2`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.8.0.5:*:*:*:unlimited:*:*:*`,
    },
     
    {
        uri: `cpe:/a:watchguard:xcs:10.0`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.1264:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:water_wish:shop_love:1.05::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:document_manager_lite:6.9.0.159`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.6_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:embassy_remote_administration_server:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch_1700-8:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:embassy_remote_administration_server_help_desk:-`,
        fs:  `cpe:2.3:a:aertherwide:exiftags:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:embassy_security_center:1.1.8.19`,
        fs:  `cpe:2.3:a:ca:cohesion_agent:4.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:embassy_security_center:4.0.0.101`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool_application_service_monitors:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:embassy_security_center:4.2.0.72`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.1:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:embassy_security_setup:4.0.0.90`,
        fs:  `cpe:2.3:a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:embassy_trust_suite:3.5.4.2`,
        fs:  `cpe:2.3:o:rockwellautomation:rslogix_emulate_5000_firmware:21.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:esc_home_page_plugin:4.0.0.18`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:3.36.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:preboot_manager:1.0.3.47`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:preboot_manager:2.0.0.102`,
        fs:  `cpe:2.3:a:goforandroid:go_message_widget:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:preboot_manager:2.4.0.244`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:preboot_manager:3.0.0.154`,
        fs:  `cpe:2.3:h:hp:jg779a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:preboot_manager:3.2.0.66`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:195.22:-:*:*:freebsd:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:private_information_manager:6.4.0.65`,
        fs:  `cpe:2.3:a:google:google_chart_server:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:private_information_manager:7.0.0.26`,
        fs:  `cpe:2.3:h:visioneer:onetouch_8650:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:trusted_drive_manager:3.3.3.104`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.11:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:trusted_drive_manager:4.0.0.512`,
        fs:  `cpe:2.3:a:novell:groupwise:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:wave_infrastructure_installer:7.1.31.0`,
        fs:  `cpe:2.3:a:celeryproject:celery:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:wave_infrastructure_installer:7.2.40.8`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:wave_support_software:5.10.0.73`,
        fs:  `cpe:2.3:a:vmware:tools:10.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wave:wave_support_software_installer:5.12.0.12`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wavea:toraware_takojyou:1.3::~~~android~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wayne_allen:postie:1.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wayne_allen:postie:1.5.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:2.0.0:preview1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wayne_allen:postie:1.5.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:git:0.7.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:wb-i:contents-mall:14.00`,
        fs:  `cpe:2.3:a:altiris:dell_client_manager_solution:2.2.1019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wb-i:contents-mall:15.00`,
        fs:  `cpe:2.3:h:cisco:cache_engine_570:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wcs4web:easywebrealestate:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.16.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:arkeia_virtual_appliance:-`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:wdc:arkeia_virtual_appliance_firmware:10.2.7`,
        fs:  `cpe:2.3:a:f5:big-ip:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:wdc:arkeia_virtual_appliance_firmware:10.2.9`,
        fs:  `cpe:2.3:o:cisco:ons_15454sdh:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:diagnostics:1.7.0`,
        fs:  `cpe:2.3:a:drupal:drupal:7.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:diagnostics:1.9.2`,
        fs:  `cpe:2.3:o:xen:xen:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:drive_manager:2.93`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:fat32_formatter:1.0.9`,
        fs:  `cpe:2.3:a:oracle:enterpriseone:8.96.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:fat32_formatter:2.0.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:wdc:my_net_firmware:1.03.12`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.44.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:wdc:my_net_firmware:1.04.16`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:wdc:my_net_firmware:1.05.12`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:wdc:my_net_firmware:1.06.18`,
        fs:  `cpe:2.3:a:microsoft:virtual_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:wdc:my_net_firmware:1.06.28`,
        fs:  `cpe:2.3:a:autodesk:autocad_lt:2002:sp1:*:de:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:wdc:my_net_n600:-`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:wdc:my_net_n750:-`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.07:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:wdc:my_net_n900:-`,
        fs:  `cpe:2.3:a:mit:kerberos:5-1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:wdc:my_net_n900c:-`,
        fs:  `cpe:2.3:a:analog:soundmax:5.10.01.5851:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:smartware:1.1.0.2`,
        fs:  `cpe:2.3:a:oracle:jrockit:r27.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:smartware:1.1.0.7`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:smartware:1.2.0.8`,
        fs:  `cpe:2.3:a:schneider-electric:sft2841:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:smartware:1.2.0.20`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:smartware:1.3.0.16`,
        fs:  `cpe:2.3:a:antoine_beaupre:hostmaster:6.x-1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:smartware:1.3.1.6`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.11:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:smartware:1.4.5.5`,
        fs:  `cpe:2.3:a:freerdp_project:freerdp:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:software_upgrader:1.4.5.5`,
        fs:  `cpe:2.3:a:oracle:jd_edwards_products:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wdc:wd_my_cloud:4.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wearegumball:comment-attachment:1.0`,
        fs:  `cpe:2.3:a:apple:webkit:103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wearepropeople:glossify_internal_links_auto_seo:6.x-2.5`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.20:-:~~~android~~`,
        fs:  `cpe:2.3:a:php:php:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.23:-:~~~android~~`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.33:-:~~~android~~`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.35:-:~~~android~~`,
        fs:  `cpe:2.3:h:cisco:cache_engine_505:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.38:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.39:-:~~~android~~`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.40:-:~~~android~~`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.43:-:~~~android~~`,
        fs:  `cpe:2.3:a:hp:secure_web_server_for_tru64:5.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.44:-:~~~android~~`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:7.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.49:-:~~~android~~`,
        fs:  `cpe:2.3:a:plone:plone:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.50:-:~~~android~~`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.51:-:~~~android~~`,
        fs:  `cpe:2.3:h:planex:brl-04cw:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.53:-:~~~android~~`,
        fs:  `cpe:2.3:a:softerra:ldap_browser:4.5.10625.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.55:-:~~~android~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.58:-:~~~android~~`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.64:-:~~~android~~`,
        fs:  `cpe:2.3:a:joshua_peek:rack-ssl:1.3.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.65:-:~~~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.66:-:~~~android~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.67:-:~~~android~~`,
        fs:  `cpe:2.3:a:wppa.opajaap:wp-photo-album-plus:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:1.68:-:~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:2.0.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:autonomy:keyview_idol:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:2.1.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:cisco:anyconnect_vpn_client:2.2.136:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:2.1.1:-:~~~android~~`,
        fs:  `cpe:2.3:a:palm:blazer:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:2.2.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.92.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:2.3.1:-:~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:2.3.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:busybox:busybox:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weathernews:weathernews_touch:2.3.4:-:~~~android~~`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:ecommerce_wd:1.2.5::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:jambatan_pbb_semporna_project:jambatan_pbb_semporna:13523.82613:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:photo_gallery:1.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:canon:captureperfect:3.0.9009.710:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:photo_gallery:1.2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_graphics_previews_common:2009.113.2222.40119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:spider_calendar:1.4.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.2.0:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:spider_facebook:1.0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:web-dorado_spider_video_player:1.4.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager:9.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:web-dorado_spider_video_player:1.4.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:web-dorado_spider_video_player:1.4.9::~~~wordpress~~`,
        fs:  `cpe:2.3:h:nortel:switched_firewall_5000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:web-dorado_spider_video_player:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web-dorado:web-dorado_spider_video_player:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web_browser_for_android_project:web_browser_for_android:1.2::~~~android~~`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.40`,
        fs:  `cpe:2.3:a:djangoproject:django:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.41`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.42`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.43`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.44`,
        fs:  `cpe:2.3:o:cisco:ons_15327:4.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.45`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.2.1:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.46`,
        fs:  `cpe:2.3:a:inmatrix:zoom_player:8.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.47`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2ldap:web2ldap:1.1.48`,
        fs:  `cpe:2.3:a:mozilla:firefox:17.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.76.1`,
        fs:  `cpe:2.3:a:isc:bind:9.5.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.76.2`,
        fs:  `cpe:2.3:a:maynard_johnson:oprofile:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.76.3`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.76.4`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.76.5`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:0.7.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.77.1`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.77.2`,
        fs:  `cpe:2.3:a:symantec:im_manager:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.77.3`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.78.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.78.3`,
        fs:  `cpe:2.3:a:samba:samba:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.79.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.79.2`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.0:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.80.1`,
        fs:  `cpe:2.3:a:nodewords_project:nodewords:6.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.81.1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.81.2`,
        fs:  `cpe:2.3:a:libreswan:libreswan:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.81.3`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5504:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.81.4`,
        fs:  `cpe:2.3:a:squid-cache:squid:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.81.5`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:167:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.82.1`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.83.1`,
        fs:  `cpe:2.3:a:cisco:finesse:9.1\(1\)_su1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.83.2`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.84.1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.84.4`,
        fs:  `cpe:2.3:a:xchat:xchat:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.85.1`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.35.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.85.3`,
        fs:  `cpe:2.3:a:gcspublishing:home_repair:3.7.9:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.86.1`,
        fs:  `cpe:2.3:a:vmware:vcenter_inventory_service:5.0.0.16964:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.86.3`,
        fs:  `cpe:2.3:o:d-link:dsr-250_firmware:1.01b46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.87.1`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.87.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.4-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.87.3`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.88.1`,
        fs:  `cpe:2.3:a:siteminder_for_secure_proxy_server:12.5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.89.1`,
        fs:  `cpe:2.3:h:d-link:dcs-934l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.89.5`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.90.1`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.90.2`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.90.4`,
        fs:  `cpe:2.3:a:google:chrome:16.0.889.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.90.5`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.8.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.90.6`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.91.1`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.91.2`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.91.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.91.6`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.96:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.92.1`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.93.1`,
        fs:  `cpe:2.3:a:apache:httpclient:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.93.2`,
        fs:  `cpe:2.3:h:ds3:authentication_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.94.1`,
        fs:  `cpe:2.3:a:isc:bind:9.1.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.94.2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.94.3`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.94.4`,
        fs:  `cpe:2.3:a:xnview:xnview:1.80.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.94.5`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.94.6`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.95.1`,
        fs:  `cpe:2.3:a:jenkins:git:1.1.10:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.96.1`,
        fs:  `cpe:2.3:o:asus:rt-ac66u_firmware:3.0.0.4.140:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.96.2`,
        fs:  `cpe:2.3:a:dynpg:dynpg_cms:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.96.4`,
        fs:  `cpe:2.3:o:apple:iphone_os:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.97.1`,
        fs:  `cpe:2.3:a:ssh:tectia_server:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.98.1`,
        fs:  `cpe:2.3:a:entrouvert:lasso:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.98.2`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.99.1`,
        fs:  `cpe:2.3:a:sap:solution_manager:7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.99.2`,
        fs:  `cpe:2.3:a:netiq:security_manager:6.5.4.349:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.99.3`,
        fs:  `cpe:2.3:a:mongodb:mongodb:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.99.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.99.5`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:1.99.7`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1511-1_pn_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:2.0.1-11`,
        fs:  `cpe:2.3:a:adobe:after_effects:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:2.1.0`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:2.2.1`,
        fs:  `cpe:2.3:a:heliconsoft:isapi_rewrite_lite:2.15.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:2.3.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jc103a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:web2py:web2py:2.14.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webassist:powerstore:2.0`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.92:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webassist:powerstore:3.0`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webassist:powerstore:4.0`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webasyst:shop-script:5.2.2.30933`,
        fs:  `cpe:2.3:a:google:chrome:7.0.500.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webbynode:webbynode:1.0.5:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:redhat:tcpdump:3.7.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webbynode:webbynode:1.0.5.1:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webbynode:webbynode:1.0.5.2:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:uplawski:creme_fraiche:0.4.5.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:webbynode:webbynode:1.0.5.3:-:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:4.6\(2\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webbynode:webbynode:1.1.0:beta1:~-~-~ruby~~`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webcrafted_project:webcrafted:-`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.7.0.1953:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webcreate:web_mart:1.7`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)ja1m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webcreate:web_mart:2.0`,
        fs:  `cpe:2.3:a:xcloner:xcloner:3.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webcreate:web_mart:2.8`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.9.254:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webcreate:webforum:5.1`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.21.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webcreate:webforum:6.3`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.6:sp1c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webcreate:webforum:6.41`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:3.8.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webedition:webedition_cms:6.2.7.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webedition:webedition_cms:6.3.3.0`,
        fs:  `cpe:2.3:h:hp:jf237a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webedition:webedition_cms:6.3.8.0`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3q\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webelinx:_beauty_bible_-_app_for_girls_:5::~~~android~~`,
        fs:  `cpe:2.3:a:plogger:plogger:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:1.6.0`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:515:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:1.6.1`,
        fs:  `cpe:2.3:a:sun:solstice_x.25:9.2:unknown:sparc:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:1.6.2`,
        fs:  `cpe:2.3:a:graphicsmagick:graphicsmagick:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:1.6.3`,
        fs:  `cpe:2.3:a:mahara:mahara:16.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:1.7.0`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:2.0.1`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:10.0.xc3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:2.0.2`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:2.0.3`,
        fs:  `cpe:2.3:a:ibm:optim_performance_manager:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:2.0.4`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webempoweredchurch:wec_discussion:2.1.0`,
        fs:  `cpe:2.3:a:oracle:balanced_scorecard:12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webengage_project:webengage:2.0.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:spa_514g_4-line_ip_phone:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_invitation_project:webform_invitation:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:php:php:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_invitation_project:webform_invitation:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_invitation_project:webform_invitation:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:leap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_invitation_project:webform_invitation:7.x-2.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_invitation_project:webform_invitation:7.x-2.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:red-gate:sql_doc:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_invitation_project:webform_invitation:7.x-2.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.1.2:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_invitation_project:webform_invitation:7.x-2.3::~~~drupal~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.22.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_multiple_file_upload_project:webform_multiple_file_upload:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios:11.0\(17\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_multiple_file_upload_project:webform_multiple_file_upload:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:isc:bind:9.2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_multiple_file_upload_project:webform_multiple_file_upload:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_multiple_file_upload_project:webform_multiple_file_upload:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:adobe:bridge_start_meeting:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_multiple_file_upload_project:webform_multiple_file_upload:7.x-1.x:dev:~~~drupal~~`,
        fs:  `cpe:2.3:a:infoblox:netmri:6.8.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_prepopulate_block_project:webform_prepopulate_block:7.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:acme:mini_httpd:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:0.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:2013.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:h:linksys:befsr81:2.42.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.3.22::~~~drupal~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.0.0.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.5::~~~drupal~~`,
        fs:  `cpe:2.3:h:huawei:e303_modem:ch2e303sm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:5.2.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:kozos:easyctf:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.9::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe_16.1:16.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.252:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.12::~~~drupal~~`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.13::~~~drupal~~`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:9.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.14::~~~drupal~~`,
        fs:  `cpe:2.3:a:symantec:pgp_universal_server:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.15::~~~drupal~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.16::~~~drupal~~`,
        fs:  `cpe:2.3:a:redhat:redhat_package_manager:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.17::~~~drupal~~`,
        fs:  `cpe:2.3:a:cisco:secure_desktop:3.4.1108:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.18::~~~drupal~~`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.19::~~~drupal~~`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:6.x-3.21::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:cloudscape:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:redgraphic:sapid_cms:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.416.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:hp:icewall_mcrp:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.1-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.6::~~~drupal~~`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.7::~~~drupal~~`,
        fs:  `cpe:2.3:a:canon:captureperfect:3.0.2306.216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.8::~~~drupal~~`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.21-69.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.9::~~~drupal~~`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise_users:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.10::~~~drupal~~`,
        fs:  `cpe:2.3:a:gnu:gnash:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.11::~~~drupal~~`,
        fs:  `cpe:2.3:a:irfanview:irfanview:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.12::~~~drupal~~`,
        fs:  `cpe:2.3:a:mozilla:firefox:24.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.13::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.14::~~~drupal~~`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.15::~~~drupal~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.16::~~~drupal~~`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.17::~~~drupal~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.18::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:micros_cwdirect:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.19::~~~drupal~~`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.20::~~~drupal~~`,
        fs:  `cpe:2.3:o:iij:seil\/x1_firmware:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.21::~~~drupal~~`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.552:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-3.22::~~~drupal~~`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-4.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-4.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-4.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-4.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_project:webform:7.x-4.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:hitachi:electronic_form_workflow_set:07-60-\/i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:6.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:6.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.17s_3.17.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:6.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:bluecoat:webproxy:5.0:r1b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:6.x-1.4::~~~drupal~~`,
        fs:  `cpe:2.3:a:oracle:jdk:1.5.0:update_41:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:6.x-1.5::~~~drupal~~`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.0:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:7.x-1.0::~~~drupal~~`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:7.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.7:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:7.x-1.2::~~~drupal~~`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webform_validation_project:webform_validation:7.x-1.3::~~~drupal~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1-esv:r12:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webgate:webgate_embedded_standard_protocol_sdk:-`,
        fs:  `cpe:2.3:a:intel:2100_proset_wireless:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webgateinc:webeyeaudio:-`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.02.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webgateinc:winrds:-`,
        fs:  `cpe:2.3:a:tenable:nessus:6.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webges:imig_2012:1.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.2.0`,
        fs:  `cpe:2.3:a:convert-in:pdf-to-word:3.1_demo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.2.1`,
        fs:  `cpe:2.3:a:openstack:horizon:2014.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.2.2`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.3.1`,
        fs:  `cpe:2.3:a:apache:poi:0.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.3.3`,
        fs:  `cpe:2.3:o:yahama:rt80i:3.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.4.0`,
        fs:  `cpe:2.3:a:irfanview:irfanview:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.4.6`,
        fs:  `cpe:2.3:h:f5:big-ip_protocol_security_manager:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.5.1`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.5.4`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.6.2`,
        fs:  `cpe:2.3:a:ibm:distributed_marketing:8.6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.6.7`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.7.4`,
        fs:  `cpe:2.3:a:mesa3d:mesa:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.7.6`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf013:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.7.7`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.7.8`,
        fs:  `cpe:2.3:a:horde:groupware:1.1.2:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.8.0`,
        fs:  `cpe:2.3:a:acronis:true_image_server:9.1.3534:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.8.1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.3.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.10.1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.10.2`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.10.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool_security_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.11.0`,
        fs:  `cpe:2.3:a:digium:asterisk:10.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.12.0`,
        fs:  `cpe:2.3:a:php:pear:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.12.2`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.028:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.13.0`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:5.1.3:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.13.1`,
        fs:  `cpe:2.3:a:apple:itunes:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.13.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)t8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.0`,
        fs:  `cpe:2.3:a:suse:suse_linux_connectivity_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.1`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.2`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.3`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.5`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.6`,
        fs:  `cpe:2.3:a:s9y:serendipity:0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.7`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.8`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.14.9`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:0.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.15.0`,
        fs:  `cpe:2.3:a:systemtools:ost_recovery:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.15.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_te_software:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.15.5`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.16.2`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.8:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.16.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.16.4`,
        fs:  `cpe:2.3:a:lemonldap-ng:lemonldap\:\::1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.17.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.1r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.17.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:31.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.17.2`,
        fs:  `cpe:2.3:a:pansi:pansi_sms:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.17.3`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.05.316:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.18.4`,
        fs:  `cpe:2.3:a:prochatrooms:text_chat_rooms:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.18.5`,
        fs:  `cpe:2.3:a:cisco:ids_sensor_software:4.1\(5b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.18.8`,
        fs:  `cpe:2.3:a:cisco:server_provisioner:6.4.0:patch_1204040128:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webglimpse:webglimpse:2.20.0`,
        fs:  `cpe:2.3:a:novell:data_synchronizer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webhive:timeline:4.2.5:p9`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.9.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webidsupport:webid:1.1.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webizz:alma_corinthiana:1::~~~android~~`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webizz:apostilas_musicais:1::~~~android~~`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkit:webkit:2.4.11`,
        fs:  `cpe:2.3:h:hp:psc_2200:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.10.0`,
        fs:  `cpe:2.3:a:getjar:azkend_gold:1.2.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.10.1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.10.2`,
        fs:  `cpe:2.3:a:openstack:telemetry_\(ceilometer\):2014.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.11.1`,
        fs:  `cpe:2.3:a:openstack:juno:2014.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.11.2`,
        fs:  `cpe:2.3:a:tryton:tryton:3.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.11.4`,
        fs:  `cpe:2.3:o:cisco:catos:5.4\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.11.5`,
        fs:  `cpe:2.3:a:sap:afaria:7.0.6001.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.11.90`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.11.91`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:1.11.92`,
        fs:  `cpe:2.3:a:cisco:ip_interoperability_and_collaboration_system:4.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.0.0`,
        fs:  `cpe:2.3:a:nginx:nginx:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.0.1`,
        fs:  `cpe:2.3:a:gnu:gettext:0.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.0.2`,
        fs:  `cpe:2.3:a:apache:groovy:1.8.0:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.0.3`,
        fs:  `cpe:2.3:o:yahama:rt57i:8.00.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.0.4`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.1.1`,
        fs:  `cpe:2.3:a:cisco:unified_application_environment_media_engine:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.1.2`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.1.3`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.1.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.1.4`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.3.2:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.1.90`,
        fs:  `cpe:2.3:a:exfo:otdr_viewer:6.13.0.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.1.91`,
        fs:  `cpe:2.3:a:gnome:gnumeric:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.1.92a`,
        fs:  `cpe:2.3:a:trioniclabs:sentinel:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.0a`,
        fs:  `cpe:2.3:a:trianglemicroworks:scada_data_gateway:2.54.0592:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.1a`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.5.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.2a`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.3a`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.17.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.4a`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(3.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.5a`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.6a`,
        fs:  `cpe:2.3:a:akiva:webboard:2.90:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.7a`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.2.8`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.3.1a`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.3.2a`,
        fs:  `cpe:2.3:a:telos:amhs:12.11.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.3.3a`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.3.4a`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.3.5a`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.3.90a`,
        fs:  `cpe:2.3:h:ibm:system_x3650_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.3.91a`,
        fs:  `cpe:2.3:a:privatemsg_project:privatemsg:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.3.92a`,
        fs:  `cpe:2.3:a:wikkawiki:wikkawiki:1.1.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.0a`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.3.0:pre0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.1a`,
        fs:  `cpe:2.3:a:lina_wolf:seo_pack_for_tt_news:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.2a`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:6.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.3a`,
        fs:  `cpe:2.3:a:broadcom:management_programs:10.38.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.4a`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2009.0312.2223.38381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.5a`,
        fs:  `cpe:2.3:o:d-link:dcs-7000l_firmware:1.04.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.6`,
        fs:  `cpe:2.3:a:atlassian:confluence:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.7`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:0.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.8`,
        fs:  `cpe:2.3:a:epson:event_manager:2.40.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.9`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.10`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.4.11`,
        fs:  `cpe:2.3:a:microsoft:project:2003:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.5.1a`,
        fs:  `cpe:2.3:a:combodo:itop:1.0.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.5.2a`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.5.3a`,
        fs:  `cpe:2.3:a:apache:subversion:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.5.90`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.25.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.6.0`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.6.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.6.2`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.1\(60\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.6.3`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.6.4`,
        fs:  `cpe:2.3:a:adobe:freehand_mx:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.6.5`,
        fs:  `cpe:2.3:a:dell:poweredge_diagnostics:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.6.6`,
        fs:  `cpe:2.3:a:powerdns:recursor:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.7.1`,
        fs:  `cpe:2.3:a:docker:docker:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.7.2`,
        fs:  `cpe:2.3:a:apple:iphoto:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.7.3`,
        fs:  `cpe:2.3:a:pgp:corporate_desktop:9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.7.4`,
        fs:  `cpe:2.3:a:panduit:design_tool_for_visio:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.7.90`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.7.91`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:6.x-6.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.7.92`,
        fs:  `cpe:2.3:a:apple:cups:1.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.8.0`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:10.1.056.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.8.1`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.62:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.8.2`,
        fs:  `cpe:2.3:a:foodplannerapp:food_planner:4.8.4.3-google:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.8.3`,
        fs:  `cpe:2.3:o:cisco:ios:15.0\(2\)se11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.8.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p139:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.8.5`,
        fs:  `cpe:2.3:a:cisco:unity_express_software:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.9.1`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.9.2`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.9.3`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup:6.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.9.4`,
        fs:  `cpe:2.3:a:symantec:liveupdate:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.9.5`,
        fs:  `cpe:2.3:h:cisco:886va-w_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.9.90`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.9.91`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.9.92`,
        fs:  `cpe:2.3:a:microsoft:office:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.0`,
        fs:  `cpe:2.3:a:sqltools:sqltools:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.1`,
        fs:  `cpe:2.3:a:milesj:decoda:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2009.1124.2131.38610:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.4`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.5`,
        fs:  `cpe:2.3:a:orangehrm:orangehrm:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.6`,
        fs:  `cpe:2.3:a:rsa:authentication_manager:7.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.7`,
        fs:  `cpe:2.3:a:nec:universal_raid_utility:1.40:rev_680:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.8`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.10.9`,
        fs:  `cpe:2.3:a:ibm:packaging_utility:1.8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.11.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.11.2`,
        fs:  `cpe:2.3:a:demosphere:agc:3.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.11.3`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:8.0r2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.11.4`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.11.5`,
        fs:  `cpe:2.3:a:tumbleweed:desktop_validator:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.11.90`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.11.91`,
        fs:  `cpe:2.3:a:perl:perl:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.11.92`,
        fs:  `cpe:2.3:a:altiris:task_server_documentation:6.0.1013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.12.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.312.2222.38381:*:*:it:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.12.1`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.12.2`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.12.3`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.9:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.12.4`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.1.2.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.12.5`,
        fs:  `cpe:2.3:o:cisco:rv_series_router_firmware:1.0.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.13.1`,
        fs:  `cpe:2.3:h:dell:latitude_d631:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.13.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.13.3`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.13.4`,
        fs:  `cpe:2.3:a:nvidia:geforce_experience:gfe_2.11.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.13.90`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.13.91`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.13.92`,
        fs:  `cpe:2.3:a:barebones:yojimbo:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.14.0`,
        fs:  `cpe:2.3:a:trianglemicroworks:.net_communication_protocol_components:3.08.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.14.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.14.2`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.14.3`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.14.4`,
        fs:  `cpe:2.3:o:huawei:secospace_usg6300_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.14.5`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1059.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.14.6`,
        fs:  `cpe:2.3:a:zroadster:zroadster.com:2.4.13.17:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.14.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.15.1`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.15.2`,
        fs:  `cpe:2.3:a:bea:weblogic_mobility_server:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.15.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.15.4`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.15.90`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.15.91`,
        fs:  `cpe:2.3:o:juniper:junos:12.1x47:d15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.15.92`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.16.0`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.16.1`,
        fs:  `cpe:2.3:a:oracle:oracle_data_provider_for_.net_help:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.16.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.16.3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.16.4`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.16.5`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.16.6`,
        fs:  `cpe:2.3:h:supermicro:x9drg-htf:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.17.1`,
        fs:  `cpe:2.3:a:nagios:nagios:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.17.2`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:08-00:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.17.3`,
        fs:  `cpe:2.3:a:intel:indeo_video:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.17.4`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(5\)sr1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.17.5`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.17.90`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.17.91`,
        fs:  `cpe:2.3:a:daemontools:daemon_tools:3.47.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.17.92`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.18.0`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.18.1`,
        fs:  `cpe:2.3:a:yahoo:yui:3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.18.2`,
        fs:  `cpe:2.3:a:redgraphic:sapid_cms:1.2.3:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.18.3`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.19.1`,
        fs:  `cpe:2.3:a:apple:darwin_streaming_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webkitgtk:webkitgtk%2b:2.19.2`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:kdebase:3.0.3-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.3.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:shopware:shopware:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.3.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:php:php:5.5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.3.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:homepage_decorator_perlmailer_project:homepage_decorator_perlmailer:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:groovy:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:0.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:b200_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:email_center:12.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:xen:xen:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.4.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:2.4.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.5.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmaster-source:wp125:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmastersite:wsn_guest:1.24`,
        fs:  `cpe:2.3:a:roboticoverlords:arch_friend:0.4.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webmd:webmd:3.5::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.4`,
        fs:  `cpe:2.3:a:vortexgroup:light_alloy:4.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.5`,
        fs:  `cpe:2.3:a:novell:netmail:3.5.2e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.6`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:7.x-1.11:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.7`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.80`,
        fs:  `cpe:2.3:a:qemu:qemu:1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.90`,
        fs:  `cpe:2.3:h:foundrynet:fastiron_iii_switch:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.910`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.929`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.930`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.940`,
        fs:  `cpe:2.3:a:ibm:websphere_service_registry_and_repository:6.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.950`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.960`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.970`,
        fs:  `cpe:2.3:o:cisco:sn_5420_storage_router:1.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.980`,
        fs:  `cpe:2.3:a:intel:ipmi:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:0.990`,
        fs:  `cpe:2.3:o:yahama:rt200i:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.000`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.04b58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.010`,
        fs:  `cpe:2.3:a:x:libxfont:1.4.99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.020`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.14.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.030`,
        fs:  `cpe:2.3:a:hp:copy:90.0.146.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.040`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.050`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2012:-:business_intelligence:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.051`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.060`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.070`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.080`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(31\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.090`,
        fs:  `cpe:2.3:a:webprancer:garfield\&#39;s_diner:1.4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.100`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.7.2.1\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.110`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.120`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.130`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.140`,
        fs:  `cpe:2.3:a:phplist:phplist:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.150`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.57.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.160`,
        fs:  `cpe:2.3:a:hulihanapplications:amethyst:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.170`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.180`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.190`,
        fs:  `cpe:2.3:a:gnome:update-manager-core:0.152.25.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.200`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.210`,
        fs:  `cpe:2.3:a:sun:sdk:1.4.2_4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.220`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.09.019:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.230`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.240`,
        fs:  `cpe:2.3:a:jordy_meow:media_file_renamer:0.32:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.250`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p453:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.260`,
        fs:  `cpe:2.3:a:redhat:openshift:2.0.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.270`,
        fs:  `cpe:2.3:a:netiq:unix_manager:5.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.280`,
        fs:  `cpe:2.3:a:emc:my_documentum_for_microsoft_outlook:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.290`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:git2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.300`,
        fs:  `cpe:2.3:a:openssl:openssl:1.0.1f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.310`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.320`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11\)ea1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.330`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.340`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.350`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.360`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.23:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.370`,
        fs:  `cpe:2.3:a:google:chrome:0.4.154.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.380`,
        fs:  `cpe:2.3:o:d-link:dsr-1000_firmware:1.06b53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.390`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.400`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-51-\/b:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.410`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.420`,
        fs:  `cpe:2.3:a:oracle:primavera_products_suite:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.430`,
        fs:  `cpe:2.3:o:google:android:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.440`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.450`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.6:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.460`,
        fs:  `cpe:2.3:a:git-scm:git:2.4.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.470`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0_2r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.480`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.490`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r006c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.500`,
        fs:  `cpe:2.3:a:ecava:integraxor:3.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.510`,
        fs:  `cpe:2.3:a:apache:apr-util:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.520`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.530`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.540`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.40:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.550`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:0.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.560`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.3.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.570`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.580`,
        fs:  `cpe:2.3:a:altiris:software_management:6.2.4270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.590`,
        fs:  `cpe:2.3:h:cisco:2700_wireless_location_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:usermin:1.600`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.8.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.600`,
        fs:  `cpe:2.3:o:huawei:s5700_firmware:v200r001c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.610`,
        fs:  `cpe:2.3:a:gstreamer_project:gstreamer:0.10.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.620`,
        fs:  `cpe:2.3:a:intel:network_connections:14.8.43.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.630`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr1604hd-l:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.640`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.650`,
        fs:  `cpe:2.3:a:ca:siteminder_federation:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.660`,
        fs:  `cpe:2.3:a:crossmo:crossmo_calendar:1.7.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.670`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.680`,
        fs:  `cpe:2.3:o:cisco:catos:8.4\(2\)glx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.720`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.5\(1\)su2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.820`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.840`,
        fs:  `cpe:2.3:a:apple:cups:1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webmin:webmin:1.850`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webpagetest_project:webpagetest:3.0`,
        fs:  `cpe:2.3:a:ibm:storwize_v3500_software:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webprancer:garfield%27s_defense:1.5.4::~~~android~~`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webprancer:garfield%27s_diner:1.4.0::~~~android~~`,
        fs:  `cpe:2.3:a:brokenscreencrank_project:brokenscreencrank:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webpromoexperts:webpromoexperts:1.8::~~~android~~`,
        fs:  `cpe:2.3:a:symantec:pgp_desktop:10.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webroot:internet_security_essentials:6.1.0.145`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:15.006.30244:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webroot:msxml_4.0_sp2_and_soap_toolkit_3.0:1.0.0.0`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webroot:security_-_complete:3.6.0.6610::~~~android~~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.0:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webroot:security_-_free:3.6.0.6610::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webrtc_project:webrtc:-`,
        fs:  `cpe:2.3:o:rockwellautomation:softlogix_5800_controller_firmware:20.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:enterprise:5.2`,
        fs:  `cpe:2.3:a:e-press:one_office_author:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:enterprise:5.5`,
        fs:  `cpe:2.3:a:apache:struts:2.5.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:enterprise:6.1`,
        fs:  `cpe:2.3:a:envato:complete_gallery_manager_plugin:3.2.7:rev36257:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:enterprise:6.2`,
        fs:  `cpe:2.3:a:emc:centera:3.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:enterprise:6.3`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton:7.8.3`,
        fs:  `cpe:2.3:a:typo3:typo3:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_unified_security_center:7.7.3`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_web_filter:7.7.3`,
        fs:  `cpe:2.3:o:debian:debian_linux:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_web_filter:7.8.3`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_web_security:7.7.3`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_web_security:7.8.3`,
        fs:  `cpe:2.3:a:mybb:mybb:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_web_security_gateway:7.7.3`,
        fs:  `cpe:2.3:a:cimon:ultimateaccess:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_web_security_gateway:7.8.3`,
        fs:  `cpe:2.3:h:cisco:nexus_5010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_web_security_gateway_anywhere:7.7.3`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.3\(13\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:triton_web_security_gateway_anywhere:7.8.3`,
        fs:  `cpe:2.3:a:bamboosolutions:bulk_export:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense:6.3.0:-:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense:6.3.1:-:enterprise`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.2.012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense:6.3.3:-:enterprise`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.20:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_content_content_gateway:7.7`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_content_content_gateway:7.7.3`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(24c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_email_security:6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_email_security:6.1:sp1`,
        fs:  `cpe:2.3:a:docker:docker:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_email_security:7.0`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_email_security:7.1`,
        fs:  `cpe:2.3:a:antoine_beaupre:hostmaster:6.x-1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_email_security:7.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.12.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_filter:6.3.0`,
        fs:  `cpe:2.3:a:nullsoft:nullsoft_install_system:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_filter:6.3.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.180:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_filter:6.3.2`,
        fs:  `cpe:2.3:a:freedomscientific:synthesizer_eloquence:6.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_filter:6.3.3`,
        fs:  `cpe:2.3:a:runtastic:runtastic_timer:1.0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_filter:7.0`,
        fs:  `cpe:2.3:a:plone:plone:5.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_filter:7.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/reporter:2.2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_security:6.3.0`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.15.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_security:6.3.1`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.11.99.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_security:6.3.2`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_security:6.3.3`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_security:7.0`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websense:websense_web_security:7.1`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webservice-dic:yoyaku:41.0`,
        fs:  `cpe:2.3:a:busybox:busybox:1.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webshophun:webshop_hun:1.062s`,
        fs:  `cpe:2.3:a:norman:norman_antivirus_\&amp;_antispyware:6.06.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitebaker:websitebaker:2.8.3:sp3`,
        fs:  `cpe:2.3:a:samba:samba:4.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitepanel:websitepanel:1.0.0`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance_software:9.2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitepanel:websitepanel:1.0.1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.2:*:*:*:*:ach_services:*:*`,
    },
     
    {
        uri: `cpe:/a:websitepanel:websitepanel:1.0.2`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update7:desktop:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitepanel:websitepanel:1.1.0`,
        fs:  `cpe:2.3:a:ibm:maximo_industry_solutions:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitepanel:websitepanel:1.1.2`,
        fs:  `cpe:2.3:a:buffalotech:whr-hp-g54_firmware:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitepanel:websitepanel:1.2.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitepanel:websitepanel:1.2.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitepanel:websitepanel:1.2.2.1`,
        fs:  `cpe:2.3:a:adobe:onlocation_cs4:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websitesrus:accessories_me_php_affiliate_script:1.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3xo.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websquare:job_web_system:1.0.6::~~high_income~~~`,
        fs:  `cpe:2.3:o:sgi:irix:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websquare:job_web_system:1.2.1`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websunlimited:j-bots_plus_2004:6.0.1`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websupergoo:abcpdf_.net:8.10.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.447.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websupergoo:abcpdf_asp:5.0.8`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websupergoo:abcupload:4.60.0`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websupporter:wp_amasin_-_the_amazon_affiliate_shop:0.9.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pgp:universal_server:2.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:1.61`,
        fs:  `cpe:2.3:a:field_group_project:field_group:7.x-1.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:2.0`,
        fs:  `cpe:2.3:a:tribiq:tribiq_cms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:2.1.0`,
        fs:  `cpe:2.3:a:md-systems:simplenews:7.x-1.x:dev:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:2.2.0`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:2.2.1`,
        fs:  `cpe:2.3:a:cisco:prime_security_manager:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:2.3.0`,
        fs:  `cpe:2.3:a:sun:one_messaging_server:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:2.3.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.2.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:2.3.2`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:websvn:websvn:2.3.3`,
        fs:  `cpe:2.3:a:samba:samba:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtitan:webtitan:4.01`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtitan:webtitan:4.04`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p132:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtree:printkey:2000`,
        fs:  `cpe:2.3:h:cisco:firewall_services_module:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrees:webtrees:1.5.1`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:5.1.2:stable:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:analysis:8.7.4.122`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:data_retention_services:8.7.4.122`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:geotrends:8.7.4.122`,
        fs:  `cpe:2.3:a:hp:sitescope:11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:main_application:8.7.4.122`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.420:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:marketing_lab:8.7.4`,
        fs:  `cpe:2.3:a:microsoft:outlook.com:7.8.2.12.49.6434:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:scheduler_agent:8.7.4.122`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:system_database:8.7.4.122`,
        fs:  `cpe:2.3:o:cisco:ios:3.6.2ae:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:system_repository:8.7.4.122`,
        fs:  `cpe:2.3:a:apache:http_server:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:ui_server_modules:8.7.4.122`,
        fs:  `cpe:2.3:o:vmware:esxi:4.0:4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webtrends:webservices:8.7.4.122`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:5.21`,
        fs:  `cpe:2.3:a:cognos:planning_client_framework:8.4.2513.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:5.22`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.0`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:1.4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.0:beta1`,
        fs:  `cpe:2.3:a:quest:intrust:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.0:beta2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.0:beta3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.0:beta4`,
        fs:  `cpe:2.3:a:nishishi:fumy_news_clipper:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.0:beta5`,
        fs:  `cpe:2.3:a:arcanadev:adtempus:3.00.0800:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.0:beta6`,
        fs:  `cpe:2.3:o:greenbone:greenbone_os:3.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.10`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.16.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.11`,
        fs:  `cpe:2.3:a:usr:netwaiting:2.5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.12`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.20`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.21`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.22`,
        fs:  `cpe:2.3:a:google:chrome:7.0.531.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.23`,
        fs:  `cpe:2.3:a:embedthis:appweb:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.24`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.25`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.26`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.27`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.28`,
        fs:  `cpe:2.3:a:libav:libav:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.29`,
        fs:  `cpe:2.3:a:jean-paul_calderone:pyopenssl:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.30`,
        fs:  `cpe:2.3:a:rocomotion:pplog:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.32`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxh4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.33`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:6.34`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.5\(3\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.0:beta1`,
        fs:  `cpe:2.3:a:digia:qt:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.0:beta2`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.0:beta3`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.0:beta4`,
        fs:  `cpe:2.3:a:sks_keyserver_project:sks_keyserver:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.0:rc1`,
        fs:  `cpe:2.3:a:siemens:scalance_s_firmware:2.3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.01`,
        fs:  `cpe:2.3:a:hp:creativeprojects_atenashokunin1config:53.0.13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.5`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.5:beta1`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.6`,
        fs:  `cpe:2.3:a:alkacon:opencms:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.7`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.10.5:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.7:a`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.7:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.8`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.9`,
        fs:  `cpe:2.3:a:vmware:workstation:8.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.51`,
        fs:  `cpe:2.3:a:hitachi:it_operations_analyzer:02-53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.51:a`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:5.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.92`,
        fs:  `cpe:2.3:a:roxio:drag-to-disc:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.95`,
        fs:  `cpe:2.3:a:adopt_o_pet_project:adopt_o_pet:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:7.96`,
        fs:  `cpe:2.3:h:cooperindustries:smp_4\/dp_gateway_\(data_concentrator\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.0`,
        fs:  `cpe:2.3:a:isc:bind:9.5.0:p2_w2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.0:beta1`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1298.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.0:beta2`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.0:rc1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.0:rc1.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.01`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.02`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.03`,
        fs:  `cpe:2.3:a:altiris:patch_management_for_windows_dell_servers_language_pack:6.2.3647:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.04`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.05`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20021106:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.05:a`,
        fs:  `cpe:2.3:a:telerik:ui_for_asp.net_ajax:2014.3.1209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:8.06`,
        fs:  `cpe:2.3:a:justsystems:ichitaro_viewer:19.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.0`,
        fs:  `cpe:2.3:a:utorrent:utorrent:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.0:beta1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.0:beta2`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.01`,
        fs:  `cpe:2.3:a:hp:imaging_device_functions:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.02`,
        fs:  `cpe:2.3:a:adobe:pdf_ifilter:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.03`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.04`,
        fs:  `cpe:2.3:a:f5:big-iq_cloud:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.05`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.06`,
        fs:  `cpe:2.3:a:ibm:director_agent_pefix_su2:5.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.07`,
        fs:  `cpe:2.3:a:pocketmags:superbike_magazine:\@7f08017a:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.08`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.50`,
        fs:  `cpe:2.3:a:david_king:vino:2.28.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.51`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.52`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.53`,
        fs:  `cpe:2.3:a:polycom:cma_system_software:5.2.0j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.54`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.1.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.55`,
        fs:  `cpe:2.3:h:hp:apache-based_web_server:1.3.27.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.56`,
        fs:  `cpe:2.3:a:sapien:primalscript:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.56:a`,
        fs:  `cpe:2.3:a:askbot:askbot:0.7.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.60`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.61`,
        fs:  `cpe:2.3:a:google:chrome:29.0.1547.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.62`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xr:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.63`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.64`,
        fs:  `cpe:2.3:o:cisco:ios:12.4jdd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.65`,
        fs:  `cpe:2.3:a:adobe:livecycle_form_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.66`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.67`,
        fs:  `cpe:2.3:a:apache:subversion:0.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.68`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_forums:9.69`,
        fs:  `cpe:2.3:a:zkoss:zk_framework:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_newspad:1.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.1r4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_newspad:1.01`,
        fs:  `cpe:2.3:a:gentoo:mirrorselect:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_newspad:1.02`,
        fs:  `cpe:2.3:a:owncloud:owncloud:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_newspad:1.03`,
        fs:  `cpe:2.3:a:commerce_ogone_project:commerce_ogone:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_rich_text_editor:4.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.143:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_rich_text_editor:4.01`,
        fs:  `cpe:2.3:a:sun:java_system_messaging_server:6.3:_nil_:x86:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_rich_text_editor:4.02`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.22.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_rich_text_editor:4.03`,
        fs:  `cpe:2.3:a:apache:jakarta_isapi_redirector:1.2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_rich_text_editor:4.04`,
        fs:  `cpe:2.3:a:mozilla:firefox:41.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webwiz:web_wiz_rich_text_editor:4.05`,
        fs:  `cpe:2.3:a:x.org:libx11:1.1.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:0.9:-`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:0.9:-:community`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:0.9:-:enterprise`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:1.71`,
        fs:  `cpe:2.3:a:vmware:vrealize_automation:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:1.71:-:community`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:1.71:-:enterprise`,
        fs:  `cpe:2.3:a:sielcosistemi:winlog_lite:2.07.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:2.5`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:2.5:-:community`,
        fs:  `cpe:2.3:a:hexagon:erdas_er_viewer:13.0.1.1301:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:2.5:-:enterprise`,
        fs:  `cpe:2.3:a:djangoproject:django:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:2.51`,
        fs:  `cpe:2.3:a:niif:shibb_auth:6.x-4.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:2.51:-:community`,
        fs:  `cpe:2.3:a:totalshopuk:ecommerce:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:2.51:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:ios_xe:13.10.2s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.11.330:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.0:-:community`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.0:-:enterprise`,
        fs:  `cpe:2.3:a:apple:quicktime:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.1`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.01`,
        fs:  `cpe:2.3:a:webform_multiple_file_upload_project:webform_multiple_file_upload:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.01:-:community`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.1:-:community`,
        fs:  `cpe:2.3:o:cisco:epc3928_docsis_3.0_8x4_wireless_residential_gateway_with_embedded_digital_voice_adapter:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.1:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime:8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.01:-:enterprise`,
        fs:  `cpe:2.3:a:microsoft:ie:5.50.4807.2300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.02`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:12.2.7.197:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.02:-:community`,
        fs:  `cpe:2.3:a:login_widget_with_shortcode_project:login_widget_with_shortcode:2.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.02:-:enterprise`,
        fs:  `cpe:2.3:a:absolutengine:absolut_engine:1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.03`,
        fs:  `cpe:2.3:a:hp:cio_components_installer:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.03:-:community`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.03:-:enterprise`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.5`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1010.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.5:-:community`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.5:-:enterprise`,
        fs:  `cpe:2.3:a:atlassian:jira:3.3.2:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.6`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:06-00:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.6:-:community`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.21:pre4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.6:-:enterprise`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.16:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.7`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.7:-:community`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.7:-:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1305.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.11`,
        fs:  `cpe:2.3:o:y-cam:ycblhd5_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.11:-:community`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.2.152:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.11:-:enterprise`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.31:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.51`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.51:-:community`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.3s.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.51:-:enterprise`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.0.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.52`,
        fs:  `cpe:2.3:a:jenkins:role-based_authorization_strategy:2.3.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.52:-:community`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.52:-:enterprise`,
        fs:  `cpe:2.3:a:jquery:jquery:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.61`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.61:-:community`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.61:-:enterprise`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.62`,
        fs:  `cpe:2.3:a:pulseaudio:pulseaudio:1.99.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.62:-:community`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(11\)t4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.62:-:enterprise`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.63`,
        fs:  `cpe:2.3:a:prestashop:prestashop:0.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.63:-:community`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.63:-:enterprise`,
        fs:  `cpe:2.3:a:hiphop_virtual_machine_for_php_project:hiphop_virtual_machine_for_php:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.64`,
        fs:  `cpe:2.3:a:nagios:plugins:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.64:-:community`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:3.64:-:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.0`,
        fs:  `cpe:2.3:a:symantec:security_information_manager:4.0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.0:-:community`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.0:-:enterprise`,
        fs:  `cpe:2.3:a:mcafee:agent:4.5.0.1817:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.01`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.1`,
        fs:  `cpe:2.3:a:cisco:unified_meetingplace_web_conferencing:8.5\(2\)_sr2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.1:-:community`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5e\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.01:-:community`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.01:-:enterprise`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.5.99:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.1:-:enterprise`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.509:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.02`,
        fs:  `cpe:2.3:a:gmarket:gmarket:5.1.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.02:-:community`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.02:-:enterprise`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.03`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.03:-:community`,
        fs:  `cpe:2.3:a:libav:libav:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.03:-:enterprise`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.04`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.19:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.04:-:community`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.04:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.05`,
        fs:  `cpe:2.3:h:cisco:pix_firewall_535:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.05:-:community`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.6-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.05:-:enterprise`,
        fs:  `cpe:2.3:a:protected_pages_project:protected_pages:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.06`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.06:-:community`,
        fs:  `cpe:2.3:a:libpng:libpng:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.06:-:enterprise`,
        fs:  `cpe:2.3:h:axis:serial_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.07`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(4\)xg2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.07:-:community`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:4.07:-:enterprise`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.0`,
        fs:  `cpe:2.3:a:telelogic:doors:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.0:-:community`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.0:-:enterprise`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.1`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.01`,
        fs:  `cpe:2.3:a:ibm:powervc:1.2.0.0:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.01:-:community`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(14\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.1:-:community`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.0b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.1:-:enterprise`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.01:-:enterprise`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.34.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.02`,
        fs:  `cpe:2.3:a:php-fusion:php-fusion:6.01.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.02:-:community`,
        fs:  `cpe:2.3:o:raritan:px:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.02:-:enterprise`,
        fs:  `cpe:2.3:a:digium:asterisk:0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.11`,
        fs:  `cpe:2.3:o:canonical:ubuntu_linux:9.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.11:-:community`,
        fs:  `cpe:2.3:a:vmware:vcenter_server_appliance:5.0:update_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.11:-:enterprise`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.12`,
        fs:  `cpe:2.3:a:emc:networker:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.12:-:community`,
        fs:  `cpe:2.3:a:mightymess:soundcloud_is_gold:1.0.7:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.12:-:enterprise`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.13`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.13:-:community`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.13:-:enterprise`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.14`,
        fs:  `cpe:2.3:a:altiris:software_delivery_task_server_plug-in:6.1.1030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.14:-:community`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.14:-:enterprise`,
        fs:  `cpe:2.3:a:ca:cleverpath_portal:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.15`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:5.0.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.15:-:community`,
        fs:  `cpe:2.3:a:microsoft:learning_essentials:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.15:-:enterprise`,
        fs:  `cpe:2.3:a:ipswitch:imail_express:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.16`,
        fs:  `cpe:2.3:o:hp:thinpro:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.16:-:community`,
        fs:  `cpe:2.3:a:safer_networking:filealyzer:1.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.16:-:enterprise`,
        fs:  `cpe:2.3:o:apple:iphone_os:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.17`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.17:-:community`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.884:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.17:-:enterprise`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.18`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sv:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.18:-:community`,
        fs:  `cpe:2.3:a:splunk:splunk:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.18:-:enterprise`,
        fs:  `cpe:2.3:a:samba:samba:3.0.25:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.19`,
        fs:  `cpe:2.3:a:apache:subversion:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.19:-:community`,
        fs:  `cpe:2.3:a:ca:ehealth_systemedge:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.19:-:enterprise`,
        fs:  `cpe:2.3:a:apache:cloudstack:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.20`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent_option:8.0:*:*:*:2007:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.20:-:community`,
        fs:  `cpe:2.3:a:skype:skype:3.8.0.115:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.20:-:enterprise`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:29-11-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.21`,
        fs:  `cpe:2.3:o:cisco:ios_xr:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.21:-:community`,
        fs:  `cpe:2.3:a:ibm:integration_bus:10.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.21:-:enterprise`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.22`,
        fs:  `cpe:2.3:a:google:chrome:17.0.928.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.22:-:community`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.22:-:enterprise`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.23`,
        fs:  `cpe:2.3:a:adobe:experience_manager:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.23:-:community`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.23:-:enterprise`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.92.p-1.0.2.1-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.24`,
        fs:  `cpe:2.3:a:oracle:mysql:5.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.24:-:community`,
        fs:  `cpe:2.3:a:copadata:zenon_dnp3_ng_driver:7.11:sp0_build_10238:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.24:-:enterprise`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.30`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_installproxy:2011.707.2315.39839:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.30:-:community`,
        fs:  `cpe:2.3:h:emerson:roc_800_remote_terminal_unit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.30:-:enterprise`,
        fs:  `cpe:2.3:a:techsmith:snagit:8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.31`,
        fs:  `cpe:2.3:a:limesurvey:limesurvey:1.53\&#43;:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.31:-:community`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.31:-:enterprise`,
        fs:  `cpe:2.3:a:roxio:dla:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.32`,
        fs:  `cpe:2.3:o:cisco:adaptive_security_appliance:7.2\(2.15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.32:-:community`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:5.32:-:enterprise`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.30.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.0`,
        fs:  `cpe:2.3:a:ibm:websphere_host_on-demand:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.0:-:community`,
        fs:  `cpe:2.3:a:cgiirc:cgi\:irc:0.3:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.0:-:enterprise`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.01`,
        fs:  `cpe:2.3:a:eye:eye-fi_helper:2.5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.1`,
        fs:  `cpe:2.3:a:elasticsearch:kibana:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.1:-:community`,
        fs:  `cpe:2.3:a:dan_kubb:extlib:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.01:-:community`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.01:-:enterprise`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.1:-:enterprise`,
        fs:  `cpe:2.3:a:ssh:ssh:1.2.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.02`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.02:-:community`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.02:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:tivoli_integrated_portal:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.03`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.03:-:community`,
        fs:  `cpe:2.3:a:eeye:retina:5.13.2.2394:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.03:-:enterprise`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:sp1:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.04`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.04:-:community`,
        fs:  `cpe:2.3:a:x:x.org_x11:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.04:-:enterprise`,
        fs:  `cpe:2.3:o:huawei:s5700_firmware:v200r002c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.05`,
        fs:  `cpe:2.3:a:yahoo:yahoo\!_browser:1.4.2:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.5:-:community`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.05:-:community`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.05:-:enterprise`,
        fs:  `cpe:2.3:a:apple:imovie:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.5:-:enterprise`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.602:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.06`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.06:-:community`,
        fs:  `cpe:2.3:a:tibco:spotfire_web_player:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.06:-:enterprise`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.623.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.07`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_tools:8.47:ga:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.07:-:community`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.9-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.07:-:enterprise`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.11`,
        fs:  `cpe:2.3:o:cisco:mds_9000:1.3\(3.33\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.11:-:community`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.11:-:enterprise`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.12`,
        fs:  `cpe:2.3:a:apple:itunes:12.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.12:-:community`,
        fs:  `cpe:2.3:a:gemalto:smartdiag:2.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.12:-:enterprise`,
        fs:  `cpe:2.3:a:stripshow_plugin_project:stripshow:2.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.13`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.13:-:community`,
        fs:  `cpe:2.3:a:apache:cassandra:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.13:-:enterprise`,
        fs:  `cpe:2.3:h:nvidia:quadro_m2000m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.14`,
        fs:  `cpe:2.3:a:dotpdn:paint.net:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.14:-:community`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.14:-:enterprise`,
        fs:  `cpe:2.3:a:teradata:dynamic_workload_manager:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.15`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.15:-:community`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.3-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.15:-:enterprise`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:27.21.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.16`,
        fs:  `cpe:2.3:a:physics_chemistry_biology_quiz_project:physics_chemistry_biology_quiz:1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.16:-:community`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.8:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.16:-:enterprise`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_enterprise:2016.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.51`,
        fs:  `cpe:2.3:a:pcre:pcre:8.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.51:-:community`,
        fs:  `cpe:2.3:a:opnet:sp_guru_transport_planner_documentation:16.0.0.10215:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.51:-:enterprise`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.52`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.52:-:community`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web_software:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.52:-:enterprise`,
        fs:  `cpe:2.3:a:logitech:lws_pictures_and_video:13.25.1010.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.53`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.7:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.53:-:community`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2009.0211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.53:-:enterprise`,
        fs:  `cpe:2.3:a:andrew_simpson:webcollab:1.62a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.54`,
        fs:  `cpe:2.3:a:moodle:moodle:1.9.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.54:-:community`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.54:-:enterprise`,
        fs:  `cpe:2.3:a:cisco:unity_connection:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.55`,
        fs:  `cpe:2.3:a:ansible:tower:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.55:-:community`,
        fs:  `cpe:2.3:a:intel:network_connections:15.1.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.55:-:enterprise`,
        fs:  `cpe:2.3:o:linux:linux_kernel:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.56`,
        fs:  `cpe:2.3:a:sitaram_chamarty:gitolite:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.56:-:community`,
        fs:  `cpe:2.3:a:dell:touchpad:version_7.1.101.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:6.56:-:enterprise`,
        fs:  `cpe:2.3:o:yahama:rt80i:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.0`,
        fs:  `cpe:2.3:a:qualcomm:yagattatalk_messenger:1.00.01.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.0:-:community`,
        fs:  `cpe:2.3:a:fusetalk:fusetalk:2.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.0:-:enterprise`,
        fs:  `cpe:2.3:h:axis:2130_ptz_network_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.01`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.5:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.1`,
        fs:  `cpe:2.3:a:redhat:libreport:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.1:-:community`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:11.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.01:-:community`,
        fs:  `cpe:2.3:a:cisco:webex_productivity_tools:2.20.2200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.01:-:enterprise`,
        fs:  `cpe:2.3:h:siemens:simatic_s7_cpu_1217c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.1:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.1.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.02`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.02:-:community`,
        fs:  `cpe:2.3:a:md-systems:simplenews:7.x-1.0:rc1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.02:-:enterprise`,
        fs:  `cpe:2.3:a:foolabs:xpdf:0.93:c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.11`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm:7.0.337.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.11:-:community`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.11:-:enterprise`,
        fs:  `cpe:2.3:a:jazan_24_project:jazan_24:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.12`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.12:-:community`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.12:-:enterprise`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.13`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.13:-:community`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.13:-:enterprise`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:12.0.1:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.14`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.14:-:community`,
        fs:  `cpe:2.3:a:x:libxrandr:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.14:-:enterprise`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.15`,
        fs:  `cpe:2.3:a:atlassian:bamboo:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.15:-:community`,
        fs:  `cpe:2.3:a:python:python:3.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:7.15:-:enterprise`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p248:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.0:-:community`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.0:-:enterprise`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:3.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.1`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.01`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_261_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.01:-:community`,
        fs:  `cpe:2.3:a:hp:jg810a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.1:-:community`,
        fs:  `cpe:2.3:a:ipswitch:imail:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.1:-:enterprise`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:a3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.01:-:enterprise`,
        fs:  `cpe:2.3:a:erikwebb:password_policy:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.02`,
        fs:  `cpe:2.3:a:hummingbird:hostexplorer:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.02:-:community`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_7900_series_firmware:9.9\(9.99001.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.02:-:enterprise`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.2:rc2`,
        fs:  `cpe:2.3:a:arco_van_geest:goof_fotoboek:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.2:rc2:community`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.2:rc2:enterprise`,
        fs:  `cpe:2.3:a:debian:debmake:3.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.03`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.21:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.03:-:community`,
        fs:  `cpe:2.3:a:curtis_galloway:exif:0.6.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.03:-:enterprise`,
        fs:  `cpe:2.3:a:moodle:moodle:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.04`,
        fs:  `cpe:2.3:o:apple:iphone_os:1.1.1:-:iphone:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.04:-:community`,
        fs:  `cpe:2.3:a:marketpress:backwpup_plugin:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.04:-:enterprise`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.05`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.8.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.05:-:community`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.05:-:enterprise`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.16:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.11`,
        fs:  `cpe:2.3:h:lexmark:c510:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.11:-:community`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.11:-:enterprise`,
        fs:  `cpe:2.3:o:cisco:rv215w_firmware:1.2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.12`,
        fs:  `cpe:2.3:a:apple:bomarchivehelper:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.12:-:community`,
        fs:  `cpe:2.3:a:apache:poi:0.14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.12:-:enterprise`,
        fs:  `cpe:2.3:a:ibm:sterling_secure_proxy:3.4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.13`,
        fs:  `cpe:2.3:a:aphpkb:aphpkb:0.95.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.13:-:community`,
        fs:  `cpe:2.3:a:emberjs:ember.js:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.13:-:enterprise`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.14`,
        fs:  `cpe:2.3:a:scripteen:free_image_hosting_script:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.14:-:community`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.14:-:enterprise`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.15`,
        fs:  `cpe:2.3:h:siemens:simatic_s7-1517-3_pn\/dp_cpu:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.15:-:community`,
        fs:  `cpe:2.3:o:cisco:nx-os:6.0\(2\)n2\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.15:-:enterprise`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(7h\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.16`,
        fs:  `cpe:2.3:a:oracle:formsbuilder:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.16:-:community`,
        fs:  `cpe:2.3:a:namazu:namazu:1.3.1.0:alpha8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.16:-:enterprise`,
        fs:  `cpe:2.3:a:school_administration_project:school_administration:7.x-1.6:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.17`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.22:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.17:-:community`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.7.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.17:-:enterprise`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.16-64.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.18`,
        fs:  `cpe:2.3:a:soft4study:testinside:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.18:-:community`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.22:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:webyog:sqlyog:8.18:-:enterprise`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20000426:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wec_map_project:wec_map:3.0.0::~~~typo3~~`,
        fs:  `cpe:2.3:a:ubercart_discount_coupons_project:ubercart_discount_coupons:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wec_map_project:wec_map:3.0.1::~~~typo3~~`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wec_map_project:wec_map:3.0.2::~~~typo3~~`,
        fs:  `cpe:2.3:a:kernel:util-linux:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weddingselections:my_wedding_planner:1.5::~~~android~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weeverapps:mcmaster_marauders:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wegoi:re-volt_2_%3a_best_rc_3d_racing:1.2.6::~~~android~~`,
        fs:  `cpe:2.3:a:aol:aim:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wegoi:re-volt_2_%3a_multiplayer:1.1.4::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:weibo_project:weibo:1.2::~~~android~~`,
        fs:  `cpe:2.3:a:skype:skype:3.2.0.53:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:e-commerce:1.3.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:e-commerce:1.8.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:visualsoftru:visual_quickbar:4.4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:jira:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.core:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:13.0.773.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:visual_interdev:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.7::~~~wordpress~~`,
        fs:  `cpe:2.3:h:sony:vaio_media_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:update:4.0.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:openssl:0.9.6b-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:fp1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.525:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.16::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:unified_intelligence_center:10.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.0.14:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:operational_decision_manager:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.19::~~~wordpress~~`,
        fs:  `cpe:2.3:h:intel:5520_chipset:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.4.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:citrix:ica_web_client:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart:1.5.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:siebel_e-billing:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart_plugin:0.5`,
        fs:  `cpe:2.3:a:nathan_haug:webform:6.x-3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart_plugin:0.9.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart_plugin:1.2.1`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:welcart:welcart_plugin:1.2.2`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingalarm%26event:2.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingalarm%26event:3.1`,
        fs:  `cpe:2.3:a:emc:cloud_tiering_appliance_software:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kinggraphic:3.1`,
        fs:  `cpe:2.3:a:rsbac:rule_set_based_access_control:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kinggraphic:3.1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kinghistorian:3.0`,
        fs:  `cpe:2.3:a:hp:hppscanto:2.102.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingscada:3.1`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingscada:3.1.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingscada:3.1.2.13`,
        fs:  `cpe:2.3:a:vmware:infrastructure_client:2.5.0.64228:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingview:3.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingview:6.5.30.2010.18018`,
        fs:  `cpe:2.3:a:namazu:namazu:1.2.1.0:beta8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingview:6.52`,
        fs:  `cpe:2.3:a:barebones:textwrangler:4.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingview:6.53`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingview:6.55`,
        fs:  `cpe:2.3:a:veritas:netbackup:5.0.0:mp4:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingview:65.30.2010.18018`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellintech:kingview:65.30.17249`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wellteksoftware:001_file_joiner_%26_splitter:4.0.5.0`,
        fs:  `cpe:2.3:a:ask:ask_toolbar:1.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:1.0`,
        fs:  `cpe:2.3:a:bundler:bundler:1.13.0:pre.1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:2.0`,
        fs:  `cpe:2.3:a:cisco:intercloud_fabric:2.2.1_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:3.0`,
        fs:  `cpe:2.3:o:f5:tmos:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(7c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:3.2`,
        fs:  `cpe:2.3:a:apache:geronimo:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:3.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.2.16:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:3.4`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:3.4.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:4.0`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:4.1`,
        fs:  `cpe:2.3:a:synology:cloud_station:1.1-2291:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wenlin_institute:wenlin:4.02`,
        fs:  `cpe:2.3:a:ps_project_management_team:libunity-webapps:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wephoneapp:wephone_-_phone_calls_vs_skype:1.03.00::~~~android~~`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.26.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:werdswords:download_shortcode:0.1:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:werdswords:download_shortcode:0.2:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:symantec:mail_security:4.6_build_97:*:exchange:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:werdswords:download_shortcode:0.2.2:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:werdswords:download_shortcode:0.2.3:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je097a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:werdswords:download_shortcode:1.0:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:werdswords:download_shortcode:1.1:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:hp:instant_share_devices:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:werner_baumann:davfs2:1.4.6`,
        fs:  `cpe:2.3:a:opera:opera_browser:9.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:werner_baumann:davfs2:1.4.7`,
        fs:  `cpe:2.3:a:google:chrome:11.0.675.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wernerd:zrtpcpp:2.1.2`,
        fs:  `cpe:2.3:a:apache:wicket:1.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wernerd:zrtpcpp:2.2.0`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wernerd:zrtpcpp:2.3.0`,
        fs:  `cpe:2.3:h:cisco:small_business_ip_phone:spa525g2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wernerd:zrtpcpp:3.0.0:alpha`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wernerd:zrtpcpp:3.1.0`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3.dfsg-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wernerd:zrtpcpp:3.2.0`,
        fs:  `cpe:2.3:a:nathan_haug:filefield_sources:7.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wernerd:zrtpcpp:3.2.1`,
        fs:  `cpe:2.3:a:redhat:icedtea6:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesjones:multisite_search:6.x-2.2`,
        fs:  `cpe:2.3:a:ibm:smart_analytics_system_7710:1.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesley_destailleur:todoo_forum:2.0`,
        fs:  `cpe:2.3:a:webmin:usermin:1.300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.0`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:0.5:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.1`,
        fs:  `cpe:2.3:a:adobe:illustrator:16.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.2`,
        fs:  `cpe:2.3:a:kay_framework_project:kay_framework:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.4`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.5`,
        fs:  `cpe:2.3:a:apple:itunes:7.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.6`,
        fs:  `cpe:2.3:o:cisco:ios_xe_2.1:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.7`,
        fs:  `cpe:2.3:a:cisco:webns:7.40.1.05s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.8:beta1`,
        fs:  `cpe:2.3:a:airdroid:airdroid:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.9:beta2`,
        fs:  `cpe:2.3:a:web2py:web2py:1.91.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.10-1.8:beta3`,
        fs:  `cpe:2.3:a:devincentiis:gazie:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.11-1.8:beta4`,
        fs:  `cpe:2.3:o:google:android:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.12-1.8:beta5`,
        fs:  `cpe:2.3:a:pureedge:pureedge_viewer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.13-1.8:beta6`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.14-1.8:beta7`,
        fs:  `cpe:2.3:a:litronic:argus:3.15.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.7.15-1.8:rc1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.8.0`,
        fs:  `cpe:2.3:a:debian:amaya:9.2.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.0`,
        fs:  `cpe:2.3:a:netscape:communicator:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.2`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.3`,
        fs:  `cpe:2.3:h:softbank:nec_3g_handset:940n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.4`,
        fs:  `cpe:2.3:a:altiris:software_delivery_solution_documentation:6.1.1041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.5`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.7.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.6`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.78:-:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.7`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.8`,
        fs:  `cpe:2.3:a:suse:studio_extension_for_system_z:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.9`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.190:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.10`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.11`,
        fs:  `cpe:2.3:a:csc:mqmonitorinstaller:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.12`,
        fs:  `cpe:2.3:a:dell:openmanage_server_administrator:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.13`,
        fs:  `cpe:2.3:a:atlassian:crowd:0.3.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.9.14`,
        fs:  `cpe:2.3:a:smarty:smarty:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.10.0`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:9.0\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.0`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.1`,
        fs:  `cpe:2.3:a:trendmicro:internet_security:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.3`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.4`,
        fs:  `cpe:2.3:a:snort:snort:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.5`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.6`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.7`,
        fs:  `cpe:2.3:a:amos_benari:rbovirt:0.0.10:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.8`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.9`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.10`,
        fs:  `cpe:2.3:a:safenet-inc:protectdrive:9.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.11`,
        fs:  `cpe:2.3:a:aegirproject:hostmaster:6.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.12`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.13`,
        fs:  `cpe:2.3:a:e107:e107:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.14`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.15`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update7:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.16`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.17`,
        fs:  `cpe:2.3:a:devincentiis:gazie:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.18`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.11.19`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.12.0`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wesnoth:battle_for_wesnoth:1.12.1`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:westermo:weos:4.18.0`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.2.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:western:western_federal_credit_union:2.1::~~~android~~`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:westerndeal:advanced_dewplayer:1.2`,
        fs:  `cpe:2.3:h:nvidia:quadro_k620:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:westpac:westpac_mobile_banking:5.21::~~~android~~`,
        fs:  `cpe:2.3:a:kernel:util-linux:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wetstonetech:gargoyle_investigator:3.1`,
        fs:  `cpe:2.3:a:martin_pitt:jockey:0.9.7-0ubuntu7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wftpserver:wing_ftp_server:4.4.6`,
        fs:  `cpe:2.3:h:lexmark:e360dn:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whcms_project:whcms:0.115:alpha`,
        fs:  `cpe:2.3:a:debian:apt:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:where2stop:where2stop-cardlocks-free:6.1::~~~android~~`,
        fs:  `cpe:2.3:a:perl:perl:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whisper:whisper:4.0.6::~~~android~~`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2019:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:3.0.0`,
        fs:  `cpe:2.3:a:mobgams:fairy_princess_makeover_salon:1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.0.0`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:1.9.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.0.1`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.0.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.1.0`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.1.1`,
        fs:  `cpe:2.3:a:usebb:usebb:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.1.2`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.9.0.1030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.2.0`,
        fs:  `cpe:2.3:a:redhat:libreport:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.2.0:beta_r1`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.2.0:beta_r2`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:17.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.2.0:beta_r3`,
        fs:  `cpe:2.3:a:vmware:gsx_server:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.2.1`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.3.0`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.47.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.3.1`,
        fs:  `cpe:2.3:a:ca:igateway:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.4.0`,
        fs:  `cpe:2.3:a:redhat:spice-gtk:0.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.4.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.60.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.4.2`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.5.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.340:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.5.1`,
        fs:  `cpe:2.3:a:cyrus:imap:2.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:4.5.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:5.0.0`,
        fs:  `cpe:2.3:a:google:chrome:7.0.507.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:5.0.1`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:5.0.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcompletesolution:5.0.3`,
        fs:  `cpe:2.3:a:persits:xupload:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whmcs:whmcs:4.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.446:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whoisit:who-is-it%3f_lite_name_caller_time_limited_free:1::~~~android~~`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:whydowork_adsense_project:whydowork_adsense:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.4.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wibu:codemeter_runtime:5.10c`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wibusys:codemeter_runtime_kit:3.30.0.500`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wiccle:wiccle_web_builder:1.00`,
        fs:  `cpe:2.3:h:hp:color_laserjet_3800:q5981a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wiccle:wiccle_web_builder:1.0.1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.5.8:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:wideimage_project:wideimage:11.02.19`,
        fs:  `cpe:2.3:a:horde:groupware:1.0:rc2:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.0:beta8`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.0:rc1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1xu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.0:rc2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20\)sx:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.2`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.4`,
        fs:  `cpe:2.3:o:yamaha:rta52i:4.01.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.5`,
        fs:  `cpe:2.3:a:python:python:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.6`,
        fs:  `cpe:2.3:a:novell:ichain:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.7`,
        fs:  `cpe:2.3:h:axis:2490_serial_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.8`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ew:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.9`,
        fs:  `cpe:2.3:a:gnu:findutils:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.10`,
        fs:  `cpe:2.3:a:google:chrome:5.0.319.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.11`,
        fs:  `cpe:2.3:a:apple:apple_tv:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.12`,
        fs:  `cpe:2.3:a:hp:inode_management_center_pc:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.13`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p300:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.14`,
        fs:  `cpe:2.3:a:mailenable:mailenable:1.703:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.15`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.16`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.17`,
        fs:  `cpe:2.3:a:piwik:piwik:0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.18`,
        fs:  `cpe:2.3:a:openstack:keystone:2013.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.19`,
        fs:  `cpe:2.3:a:vmware:player:2.0.1_build_55017:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.20`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:2.6.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.0.21`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.2.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.1.0`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.1.1`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.1.2`,
        fs:  `cpe:2.3:a:microsoft:office:2010:sp1:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.1.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_identity_manager:5.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.0`,
        fs:  `cpe:2.3:a:swi-prolog:swi-prolog:5.6.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.1.1`,
        fs:  `cpe:2.3:a:openstack:havana:havana-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.1.2`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.2`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.3`,
        fs:  `cpe:2.3:o:d-link:dsr-1000n_firmware:1.08b77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.4`,
        fs:  `cpe:2.3:a:adobe:dreamweaver:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.5`,
        fs:  `cpe:2.3:a:microsoft:excel_viewer:2007:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.5.1`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.5.2`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_desktop:7.0:ebf:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.5.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:widgetfactorylimited:com_jce:2.2.7`,
        fs:  `cpe:2.3:a:znc:znc-msvc:0.090:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:widgets_project:widgets:-::~~~mediawiki~~`,
        fs:  `cpe:2.3:o:conectiva:linux:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikidforum:wikidforum:0.10`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikidforum:wikidforum:2.10`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:617:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikidforum:wikidforum:2.20`,
        fs:  `cpe:2.3:a:kernel:linux-pam:0.99.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikipop_plugin_project:wikipop:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikiwig_project:wikiwig:5.0.1`,
        fs:  `cpe:2.3:a:xinetd:xinetd:2.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikiwiki_project:wikiwiki:6.x-1.1::~~~drupal~~`,
        fs:  `cpe:2.3:a:evan_dandrea:usb-creator:0.2.38.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.1.6.3`,
        fs:  `cpe:2.3:a:sprockets_project:sprockets:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.1.6.4`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.1.6.5`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd010a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.1.6.6`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.1.6.7`,
        fs:  `cpe:2.3:a:mediafront:mediafront:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.3.1`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.3.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.3.3`,
        fs:  `cpe:2.3:a:cisco:webex_meeting_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wikkawiki:wikkawiki:1.3.4`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wildpackets:ip_subnet_calculator:3.2.1`,
        fs:  `cpe:2.3:o:corel:linux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wildpackets:omniengine:6.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wildpackets:omnipeek:6.0.2`,
        fs:  `cpe:2.3:a:avast:premier:11.1.2253:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wildpackets:omnipeek:6.0.7`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wildpackets:omnipeek:6.5.0`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wildpackets:remote_update_service:6.0.2`,
        fs:  `cpe:2.3:a:ibm:worklight:5.0.5.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/h:willcom-inc:android_smartphone:wx04k`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:.1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:willcom-inc:android_smartphone:wx06k`,
        fs:  `cpe:2.3:a:axel_jung:js_css_optimizer:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:willcom-inc:wi-fi_application:1.7.0`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wilson_steven:mangosweb_enhanced:3.0.3`,
        fs:  `cpe:2.3:a:aol:aim:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wimba:pronto:3.1.0-d`,
        fs:  `cpe:2.3:a:dell:equallogic_host_integration_tools:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wimleers:cdn:6.x-2.2`,
        fs:  `cpe:2.3:a:emc:documentum_wdk:6.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wimleers:cdn:7.x-2.2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.603:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winace:unace:1.2b`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:bsdos:-`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:8.0\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:bsdos:4.2`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.12-60.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:bsdos:4.3.1`,
        fs:  `cpe:2.3:a:redhat:rhel_virtualization:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:bsdos:5.0`,
        fs:  `cpe:2.3:a:cybozu:garoon:3.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:platform_sa:-`,
        fs:  `cpe:2.3:a:netiq:endpoint:5.0.3186:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:platform_sa:1.0`,
        fs:  `cpe:2.3:a:pligg:pligg_cms:9.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:vxworks:5`,
        fs:  `cpe:2.3:a:getid3:getid3:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:vxworks:5.5`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:vxworks:6`,
        fs:  `cpe:2.3:a:netscout:ngenius_performance_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:vxworks:6.4`,
        fs:  `cpe:2.3:a:redmine:redmine:0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:vxworks:6.6`,
        fs:  `cpe:2.3:a:busybox:busybox:1.0.0:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:vxworks:6.8`,
        fs:  `cpe:2.3:a:zeromq:zeromq:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:wrlinux:8.0`,
        fs:  `cpe:2.3:a:fedoraproject:sssd:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:windriver:wrlinux:9.0`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wingrep:windows_grep:2.3`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2008.717.2342.40629:*:*:pt:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmagic:securedoc_disk_encryption:4.60.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2003_server:-:r2:x64-standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:1.7.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_databases_data_protection_for_microsoft_sql_server:7.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.0`,
        fs:  `cpe:2.3:a:imagely:nextgen_gallery:1.9.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.0.2`,
        fs:  `cpe:2.3:a:telos:amhs_activex_cab_update:1.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.2.0`,
        fs:  `cpe:2.3:a:python:python:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.2.2`,
        fs:  `cpe:2.3:a:sonarsource:sonarqube:3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.2.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.4.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.4:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.4.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.26a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.4.4`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.3.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.4.6`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.4.8`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.4.10`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.6.0`,
        fs:  `cpe:2.3:o:cisco:ios:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.6.2`,
        fs:  `cpe:2.3:a:autodesk:autocad:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.6.4`,
        fs:  `cpe:2.3:a:clamav:clamav:0.14:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.6.6`,
        fs:  `cpe:2.3:a:travis_shirk:eyed3:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.6.8`,
        fs:  `cpe:2.3:a:google:chrome:5.0.307.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.6.12`,
        fs:  `cpe:2.3:a:ckeditor:ckeditor:6.x-1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.6.14`,
        fs:  `cpe:2.3:a:livetecs:timeline:2.94:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.8.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.2\(2\):sr3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.8.2`,
        fs:  `cpe:2.3:a:apache:struts:2.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.8.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.8.6`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.10.0`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:6.0.199.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.10.0:rc`,
        fs:  `cpe:2.3:a:openstack:neutron:2014.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.10.2`,
        fs:  `cpe:2.3:a:skyboxsecurity:skybox_view_appliance_iso:6.4.46-2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.10.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.11.2:beta`,
        fs:  `cpe:2.3:o:y-cam:ycblb3_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.12.0`,
        fs:  `cpe:2.3:h:cisco:aironet_1830i:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.12.2`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.12.4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:winmerge:winmerge:2.19.10:beta`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.12:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:1.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:10.10c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:2.0`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.18m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:2.1`,
        fs:  `cpe:2.3:a:imsidesign:turbocad_symbols:16.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:2.2`,
        fs:  `cpe:2.3:a:serf_project:serf:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:2.02`,
        fs:  `cpe:2.3:a:apache:apache-ssl:1.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:2.3`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.7.2.f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.0`,
        fs:  `cpe:2.3:a:atutor:atutor:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.0:alpha_2`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.11:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.0:alpha_3`,
        fs:  `cpe:2.3:a:ibm:websphere_mq:7.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.0:beta_10`,
        fs:  `cpe:2.3:o:cisco:ios:12.2ixf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.01:alpha`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.1:beta`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.0:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.1:beta2`,
        fs:  `cpe:2.3:a:gnu:zlib:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.1:beta3`,
        fs:  `cpe:2.3:a:krisonav:krisonav:1.0.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.1:beta4`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.1.0.27`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.11:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.1_beta4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:3.2:alpha1`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.0`,
        fs:  `cpe:2.3:a:polycom:dma_system_software:2.1.1j:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.0:alpha1`,
        fs:  `cpe:2.3:a:hp:openview_cross_platform_component:2.61.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.0:beta1`,
        fs:  `cpe:2.3:a:microsoft:money:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.0:beta2`,
        fs:  `cpe:2.3:a:kashif_masud:textdroid:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.0:beta3`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.0.0.1040`,
        fs:  `cpe:2.3:a:techsmith:snagit:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.0.1`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.0.1-8:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.33.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1`,
        fs:  `cpe:2.3:a:websense:websense_web_security:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1:beta`,
        fs:  `cpe:2.3:o:dell:idrac7_firmware:1.40.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1:beta2`,
        fs:  `cpe:2.3:o:ibm:flashsystem_v9000_firmware:7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1:beta3`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1:beta4`,
        fs:  `cpe:2.3:a:moodle:moodle:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1:beta5`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1.0.1753`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1.0.2001`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winpcap:winpcap:4.1.1`,
        fs:  `cpe:2.3:a:gnome:evolution:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:3.7.6`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:3.8.2`,
        fs:  `cpe:2.3:a:moodle:moodle:3.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:3.8_beta`,
        fs:  `cpe:2.3:a:novell:edirectory:8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.0.4`,
        fs:  `cpe:2.3:a:samba:samba:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.0.5`,
        fs:  `cpe:2.3:a:openbsd:openssh:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.2.6`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.2.7`,
        fs:  `cpe:2.3:a:ibm:filenet_p8_application_engine:4.0.2:004:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.2.8`,
        fs:  `cpe:2.3:a:python-requests:requests:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.2.9`,
        fs:  `cpe:2.3:a:gopivotal:grails-resources:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.3.2`,
        fs:  `cpe:2.3:h:nvidia:nvs_810:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.3.4`,
        fs:  `cpe:2.3:a:ibm:integration_bus:9.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.3.5`,
        fs:  `cpe:2.3:a:abbyy:finereader:10.0:-:corporate:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.3.6`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.3.7`,
        fs:  `cpe:2.3:a:isc:bind:9.2.1:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.3.8`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.30.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.3.9`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_system:5.5.0.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:4.4.0`,
        fs:  `cpe:2.3:a:divx:codec:6.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0:beta`,
        fs:  `cpe:2.3:a:ca:inoculateit:4.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.1:beta`,
        fs:  `cpe:2.3:a:isc:dhcp:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.2:beta`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.3:beta`,
        fs:  `cpe:2.3:a:samba-tng:samba-tng:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.4:beta`,
        fs:  `cpe:2.3:a:jgrasp:jgrasp:1.8.8_01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.5:beta`,
        fs:  `cpe:2.3:a:hp:toolbox:140.0.428.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.6:beta`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.7:beta`,
        fs:  `cpe:2.3:a:microsoft:outlook_2013_rt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.8:rc`,
        fs:  `cpe:2.3:a:mindreantre:threewp_email_reflector:1.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.0.9:rc`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc2100:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.1`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.1.1`,
        fs:  `cpe:2.3:a:spumko_project:hapi_server_framework:2.1.2:*:*:*:*:node.js:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.1.2`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:10.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.1.3`,
        fs:  `cpe:2.3:a:apache:struts:2.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.1.4`,
        fs:  `cpe:2.3:a:keepass:keepass:0.92:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.1.5`,
        fs:  `cpe:2.3:a:cisco:unified_presence_server:1.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.1.6`,
        fs:  `cpe:2.3:a:drupal:drupal:6.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.1.7`,
        fs:  `cpe:2.3:a:phpmailer_project:phpmailer:5.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.5`,
        fs:  `cpe:2.3:a:samba:samba:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.5.1`,
        fs:  `cpe:2.3:a:ibm:maximo_for_government:7.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.5.2`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winscp:winscp:5.5.3`,
        fs:  `cpe:2.3:a:microsoft:security_compliance_manager:1.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:winwebmail:winwebmail_server:3.8.1.6`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:self-extractor:2.0`,
        fs:  `cpe:2.3:o:suse:linux_enterprise_server:11:sp3:vmware:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:self-extractor:2.1`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:self-extractor:2.2`,
        fs:  `cpe:2.3:h:cisco:traffic_anomaly_detector_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:self-extractor:3.0`,
        fs:  `cpe:2.3:a:hp:icewall_sso_agent:8.0:r2:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:self-extractor:3.1`,
        fs:  `cpe:2.3:a:nortel:communications_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:self-extractor:4.0`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:-`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.12:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:_9.0_sr-1_%286224%29`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s\(.6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:5.5`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:5.6`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:6.0a`,
        fs:  `cpe:2.3:a:ibm:curam_social_program_management:5.2:sp6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:6.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.0:test10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:6.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:6.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:7.0`,
        fs:  `cpe:2.3:a:barton:ngircd:20.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:8.0`,
        fs:  `cpe:2.3:a:invensys:wonderware_application_server:3.0.200:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:8.1`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:8.1:sr1`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:8.1.4331`,
        fs:  `cpe:2.3:a:techsmith:snagit:7.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:9.0`,
        fs:  `cpe:2.3:a:tm_software:tempo:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:9.0:sr1`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:9.0.6028`,
        fs:  `cpe:2.3:a:adobe:acrobat:3.0:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:10.0`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.2.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:10.0.6698`,
        fs:  `cpe:2.3:a:schneems:wicked:1.0.2:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:10.0.7245`,
        fs:  `cpe:2.3:a:wysigot:wysigot:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:10.0_build_6667`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.5.5233.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:11.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:11.1`,
        fs:  `cpe:2.3:a:broadcom:management_programs:4.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:11.1.7466`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:11.2`,
        fs:  `cpe:2.3:a:ftprush:ftprush:1.0.0.620:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:11.2:sr1`,
        fs:  `cpe:2.3:a:gajim:gajim:0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:11.2.8094`,
        fs:  `cpe:2.3:a:adobe:adobe_air:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:11.3.8261`,
        fs:  `cpe:2.3:a:polarssl:polarssl:0.99:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:12.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:7.0.0:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:12.0.8252`,
        fs:  `cpe:2.3:o:cisco:staros:18.1.0.59776:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:12.1`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:12.1.8497`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.9:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:12.1.8519`,
        fs:  `cpe:2.3:a:narr8:spin_-_motion_comic:2.1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:14.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:14.0.8652`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:14.0.8688`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.2sg:3.2.1sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:14.5.9095`,
        fs:  `cpe:2.3:a:bestpractical:rt:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:15.0.9302`,
        fs:  `cpe:2.3:h:axis:2100_network_camera:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:15.0.9327`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:10.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:15.0.9334`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:15.0.9411`,
        fs:  `cpe:2.3:a:vmware:tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:15.5.9468`,
        fs:  `cpe:2.3:a:oracle:mysql:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:15.5.9510`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:15.5.9579`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:16.0.9661`,
        fs:  `cpe:2.3:h:hp:jg782a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip:16.0.9686`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:3.0.0r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip_command_line_support_add-on:1.1`,
        fs:  `cpe:2.3:a:find_color_project:find_color:1.1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip_command_line_support_add-on:1.1:sr-1`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip_command_line_support_add-on:2.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p250_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip_command_line_support_add-on:2.3`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip_command_line_support_add-on:3.0`,
        fs:  `cpe:2.3:o:f5:tmos:9.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip_command_line_support_add-on:3.1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzip_command_line_support_add-on:3.2`,
        fs:  `cpe:2.3:a:hp:webinspect:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:winzip:winzipbar_toolbar:6.7.0.6`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:0.99.2`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:0.99.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:0.99.4`,
        fs:  `cpe:2.3:a:apache:qpid:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:0.99.5`,
        fs:  `cpe:2.3:a:hp:client_automation_administrator:7.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:0.99.6`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:0.99.7`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:0.99.8`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.0`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.5.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.2`,
        fs:  `cpe:2.3:a:pulsecms:pulse_cms:1.0:-:basic:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.3`,
        fs:  `cpe:2.3:a:monster_menus_module_project:monster_menus:7.x-1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.4`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.5`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.6`,
        fs:  `cpe:2.3:a:samba:samba:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.7`,
        fs:  `cpe:2.3:a:hp:photosmart_essential:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.8`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.24.352:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.9`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.10`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.11`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2000:gold:adv_srv:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.0.12`,
        fs:  `cpe:2.3:a:atanasoft:atanasuite_2011:9.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.0`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.1`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.2`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.3`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.4`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.5`,
        fs:  `cpe:2.3:a:freetype:freetype:2.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.6`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.7`,
        fs:  `cpe:2.3:a:openstack:compute:2013.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.8`,
        fs:  `cpe:2.3:a:perl:perl:5.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.9`,
        fs:  `cpe:2.3:o:omron:ns_series_system_program_firmware:8.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.10`,
        fs:  `cpe:2.3:a:sun:jre:6.0.210:update21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.2.11`,
        fs:  `cpe:2.3:a:intel:network_connections:16.3.48.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.0`,
        fs:  `cpe:2.3:a:phorum:phorum:5.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.0::~~~~itanium~`,
        fs:  `cpe:2.3:a:google:chrome:4.0.251.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.0::~~~~sparc~`,
        fs:  `cpe:2.3:a:fortinet:connect:16.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.1`,
        fs:  `cpe:2.3:a:abeel:simple_php_agenda:0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.1::~~~~itanium~`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.1::~~~~sparc~`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.2`,
        fs:  `cpe:2.3:a:nagios:nagios:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.2::~~~~itanium~`,
        fs:  `cpe:2.3:a:mcafee:entercept_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.2::~~~~sparc~`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.3`,
        fs:  `cpe:2.3:a:thegr:dl:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.3::~~~~itanium~`,
        fs:  `cpe:2.3:a:f5:icontrol_service_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.3::~~~~sparc~`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.4`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(18\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.4::~~~~itanium~`,
        fs:  `cpe:2.3:a:microsoft:isa_server:2004:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.4::~~~~sparc~`,
        fs:  `cpe:2.3:a:adobe:version_cue_cs4_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.5`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_random:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.5::~~~~itanium~`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.5::~~~~sparc~`,
        fs:  `cpe:2.3:a:primetek:primefaces:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.6`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.6::~~~~itanium~`,
        fs:  `cpe:2.3:a:docebo:docebolms:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.6::~~~~sparc~`,
        fs:  `cpe:2.3:a:cybozu:garoon:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.7`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.7::~~~~itanium~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.7::~~~~sparc~`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.8`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp_server_with_ssh:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.8::~~~~itanium~`,
        fs:  `cpe:2.3:a:projectforge:projectforge:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.8::~~~~sparc~`,
        fs:  `cpe:2.3:a:hp:proliant_integrated_management_log_viewer:5.24.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.9`,
        fs:  `cpe:2.3:a:git-scm:git:1.3.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.9::~~~~itanium~`,
        fs:  `cpe:2.3:a:ibm:security_appscan:8.7.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.9::~~~~sparc~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p320:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.10`,
        fs:  `cpe:2.3:a:altiris:dell_client_manager_language_pack:2.2.1010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.10::~~~~itanium~`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:8.0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.10::~~~~sparc~`,
        fs:  `cpe:2.3:o:xen:xen:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.11`,
        fs:  `cpe:2.3:a:facebook:bilingual_magic_ball_relajo:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.11::~~~~itanium~`,
        fs:  `cpe:2.3:a:seagullproject:seagull:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.11::~~~~sparc~`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(3a\)su1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.12`,
        fs:  `cpe:2.3:a:ibm:tivoli_firewall_toolbox:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.12::~~~~itanium~`,
        fs:  `cpe:2.3:a:techsmith:camtasia_relay:7.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.12::~~~~sparc~`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.13`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.13::~~~~itanium~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.5-cucm:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.13::~~~~sparc~`,
        fs:  `cpe:2.3:o:apple:mac_os_x_server:10.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.14`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.4.15`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(2\)t8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.0`,
        fs:  `cpe:2.3:a:gnu:glibc:2.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.0::~~~~itanium~`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.4.0:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.0::~~~~sparc~`,
        fs:  `cpe:2.3:o:yamaha:rt57i:8.00.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.1`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.0.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.1::~~~~itanium~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.1::~~~~sparc~`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.2`,
        fs:  `cpe:2.3:a:tenable:nessus:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.2::~~~~itanium~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.2::~~~~sparc~`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:4.6.7h:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.3`,
        fs:  `cpe:2.3:a:ibm:infosphere_optim_performance_manager:5.1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.3::~~~~itanium~`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.0:beta-rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.3::~~~~sparc~`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.0.0_a:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.4`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.4::~~~~itanium~`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-03-29:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.4::~~~~sparc~`,
        fs:  `cpe:2.3:a:belkin:switch2:1.0.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.5`,
        fs:  `cpe:2.3:a:hp:sitescope:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.5::~~~~itanium~`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.5::~~~~sparc~`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.6`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.8f:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.6::~~~~itanium~`,
        fs:  `cpe:2.3:a:malcolm_nooning:pirpc:0.2013:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.6::~~~~sparc~`,
        fs:  `cpe:2.3:o:google:chrome_os:21.0.1180.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.7`,
        fs:  `cpe:2.3:a:savsoft_technologies:savsoft_quiz:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.7::~~~~itanium~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.9-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.7::~~~~sparc~`,
        fs:  `cpe:2.3:o:cisco:rv110w_wireless-n_vpn_firewall_firmware:1.2.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.8`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.8::~~~~itanium~`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:2.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.8::~~~~sparc~`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.9`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:484:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.10`,
        fs:  `cpe:2.3:a:mcafee:privacy_service:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.11`,
        fs:  `cpe:2.3:a:apple:cups:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.12`,
        fs:  `cpe:2.3:a:hp:bpd_scan:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.13`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.14`,
        fs:  `cpe:2.3:a:isc:bind:9.7.1b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.15`,
        fs:  `cpe:2.3:a:openstack:compute:2013.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.6.16`,
        fs:  `cpe:2.3:a:maxtom:atomymaxsite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.0`,
        fs:  `cpe:2.3:a:adobe:flash_cs3:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.0::~~~~itanium~`,
        fs:  `cpe:2.3:a:geoff_davies:contact_forms:6.x-1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.0::~~~~sparc~`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.1`,
        fs:  `cpe:2.3:h:siemens:sinamics_g110d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.2`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.25.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.3`,
        fs:  `cpe:2.3:o:dlink:dir865l_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.4`,
        fs:  `cpe:2.3:a:dlguard:dlguard:4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.5`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.6`,
        fs:  `cpe:2.3:a:spip:spip:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.7`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:4.31.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.8`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.9`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:3.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.10`,
        fs:  `cpe:2.3:h:apple:imac:ma878xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.11`,
        fs:  `cpe:2.3:a:sourcetreesolutions:mojoportal:2.3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.12`,
        fs:  `cpe:2.3:a:ibm:rational_developer_for_system_z:7.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.8.13`,
        fs:  `cpe:2.3:a:moodle:moodle:2.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10`,
        fs:  `cpe:2.3:a:modsecurity:modsecurity:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.0`,
        fs:  `cpe:2.3:a:rik_de_boer:revisioning:7.x-1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.1`,
        fs:  `cpe:2.3:a:dounokouno:transmitmail:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.2`,
        fs:  `cpe:2.3:a:ntp:ntp:p97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(8\)ja1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.4`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.5`,
        fs:  `cpe:2.3:o:juniper:junos:13.2x52:d25:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.6`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.7`,
        fs:  `cpe:2.3:a:adobe:illustrator:13.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.8`,
        fs:  `cpe:2.3:a:serv-u:serv-u:10.5.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.9`,
        fs:  `cpe:2.3:a:oracle:interaction_blending:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.11`,
        fs:  `cpe:2.3:a:typo3:typo3:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.12`,
        fs:  `cpe:2.3:a:google:chrome:7.0.536.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.13`,
        fs:  `cpe:2.3:a:ca:etrust_admin:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.10.14`,
        fs:  `cpe:2.3:h:oracle:sparc_t3-1:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.0`,
        fs:  `cpe:2.3:a:orientdb:orientdb:2.1.0:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.1`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.9:pre6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.3`,
        fs:  `cpe:2.3:a:ibm:security_access_manager:7.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.4`,
        fs:  `cpe:2.3:a:oneorzero:action_and_information_management_system:2.7.0:-:trial:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.5`,
        fs:  `cpe:2.3:o:juniper:ive_os:7.3r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.6`,
        fs:  `cpe:2.3:a:orchardproject:orchard:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.8`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.272:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.9`,
        fs:  `cpe:2.3:a:hp:system_health_application_and_command_line_utilities:8.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.10`,
        fs:  `cpe:2.3:a:clamav:clamav:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.11`,
        fs:  `cpe:2.3:a:djangoproject:django:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:1.12.12`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.0`,
        fs:  `cpe:2.3:a:tibco:activematrix_management_agent:1.2.0:*:*:*:*:websphere:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.1`,
        fs:  `cpe:2.3:a:ati:software_uninstall_utility:6.14.10.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.2`,
        fs:  `cpe:2.3:a:symantec:norton_security:13.0.1:*:*:*:*:mac:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.3`,
        fs:  `cpe:2.3:a:darold:squidclamav:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.4`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(28\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.6`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.7`,
        fs:  `cpe:2.3:a:squareup:okhttp3:3.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.8`,
        fs:  `cpe:2.3:a:thinkleft:submenu_tree:5.x-0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.9`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0:preview_release:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.10`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:h06.25.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.0.12`,
        fs:  `cpe:2.3:a:omeka:omeka:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.2.0`,
        fs:  `cpe:2.3:a:phorum:phorum:3.1.1:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.2.1`,
        fs:  `cpe:2.3:a:hp:enterprise_npi:70.0.200.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.2.2`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.5.3:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.2.3`,
        fs:  `cpe:2.3:a:apache:http_server:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.2.4`,
        fs:  `cpe:2.3:a:telaxus:epesi:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wireshark:wireshark:2.2.6`,
        fs:  `cpe:2.3:o:dell:bios:a15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wisdomsoft:screenhunter:5.1::~~free~~~`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:11.5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:witcustomcontrols:witcustomcontrols:2010`,
        fs:  `cpe:2.3:a:cisco:webns:7.50.0.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:withbuddies:slots_vacation_-_free_slots_:1.47.2::~~~android~~`,
        fs:  `cpe:2.3:a:hp:storage_data_protector:8.0:-:*:*:*:windows_server_2008:*:*`,
    },
     
    {
        uri: `cpe:/a:withdata:oraloader:2.6`,
        fs:  `cpe:2.3:a:joedolson:my-calendar:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:withhive:9_innings%3a_2014_pro_baseball:4.0.3::~~~android~~`,
        fs:  `cpe:2.3:o:yamaha:rtx1000:7.01.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:withhive:actionpuzzlefamily_for_kakao:1.4.3::~~~android~~`,
        fs:  `cpe:2.3:a:suse:opensuse_osc:0.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:withhive:homerun_battle_2:1.2.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:withhive:puzzle_family:1.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:withhive:tiny_farm:2.02.00::~~~android~~`,
        fs:  `cpe:2.3:h:hp:h3c_high_performance_main_processing_unit:msr_50_3ge:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wizaz:wizaz_forum:3.6.4::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/c:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wk12olslogin_project:wk12olslogin:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a99:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wokamoto:wp-cron_dashboard:1.1.0`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wokamoto:wp-cron_dashboard:1.1.1`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wokamoto:wp-cron_dashboard:1.1.2`,
        fs:  `cpe:2.3:a:gnu:gdb:6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wokamoto:wp-cron_dashboard:1.1.3`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wokamoto:wp-cron_dashboard:1.1.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wokamoto:wp-cron_dashboard:1.1.5`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfcms:wolf_cms:0.5.0`,
        fs:  `cpe:2.3:a:sagecrm:sagecrm:7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfcms:wolf_cms:0.5.5`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfcms:wolf_cms:0.6.0`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux_virtualization:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfcms:wolf_cms:0.7.0`,
        fs:  `cpe:2.3:o:buffalotech:bhr-4grv2_firmware:1.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfcms:wolf_cms:0.7.2`,
        fs:  `cpe:2.3:a:rack_project:rack:1.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfcms:wolf_cms:0.7.3`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfcms:wolf_cms:0.7.5`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_201_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfcms:wolf_cms:0.8.3`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.17:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfssl:wolfssl:3.6.6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfssl:wolfssl:3.10.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfssl:wolfssl:3.10.0a`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolfssl:wolfssl:3.10.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.2-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wolterskluwer:teammate_audit_management_software_suite:8.0:2`,
        fs:  `cpe:2.3:a:cbi_referral_manager_project:cbi_referral_manager:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wondercms:wondercms:0.3.3`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wondercms:wondercms:2.0.2`,
        fs:  `cpe:2.3:a:petition_project:petition:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wonderplugin:audio_player:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.3\(3.102\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:woocommerce:woocommerce:2.6.8::~~~wordpress~~`,
        fs:  `cpe:2.3:h:3com:3c17100-us:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:woocommerce_sagepay_direct_payment_gateway_project:woocommerce_sagepay_direct_payment_gateway:0.1.6.6:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:suse:studio_onsite:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:woodforest:woodforest_mobile_banking:3.1::~~~android~~`,
        fs:  `cpe:2.3:a:ibm:spectrum_lsf:9.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wooga:jelly_splash:1.11.3::~~~android~~`,
        fs:  `cpe:2.3:a:zope:zope:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:woothemes:woocommerce:2.2.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:array_configuration_utility:8.70.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordbox:algeria_radio:2.5::~~~android~~`,
        fs:  `cpe:2.3:a:checkpoint:zonealarm_extreme_security:9.3.037.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordbox:mahabharata_audiocast:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordboxapps:afghan_radio:2.5::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:tomboy:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:libx11:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:8.0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:huawei:s9306_firmware:v200r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:hadoop:0.20.204.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atar2b:atar2b_cms:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:aix_enetwork_firewall:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordfence_security_project:wordfence_security:5.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pygments:pygments:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:plugin_newsletter_plugin:1.5`,
        fs:  `cpe:2.3:a:mahara:mahara:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:slideshow_gallery2:-`,
        fs:  `cpe:2.3:a:bayashi:dopvcomet\*:0006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:-`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:0.71`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_conductor:xc2.4:prealpha0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.0.1`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.8e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.0.2`,
        fs:  `cpe:2.3:a:digitalzoomstudio:video_gallery:-:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.1.1`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.2.1`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.2.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.2.3`,
        fs:  `cpe:2.3:a:hp:openmail:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.2.4`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.2.5`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.5.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.2.5:a`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.3`,
        fs:  `cpe:2.3:a:mit:pgp_public_key_server:0.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.3.2`,
        fs:  `cpe:2.3:a:seasarfoundation:s2struts:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.3.3`,
        fs:  `cpe:2.3:a:oracle:common_applications:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.5`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:7.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.5.1`,
        fs:  `cpe:2.3:a:techsmith:snagit:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.5.1.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.33.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.5.1.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p218:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.5.1.3`,
        fs:  `cpe:2.3:a:surfcontrol:superscout_email_filter:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.5.2`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_forums:9.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:1.6.2`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0`,
        fs:  `cpe:2.3:a:emc:records_client:6.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.1`,
        fs:  `cpe:2.3:a:altiris:real-time_system_manager_language_pack:6.3.1016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.2`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.4`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.5`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.00.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.6`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.7`,
        fs:  `cpe:2.3:a:apple:itunes:12.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.8`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.9`,
        fs:  `cpe:2.3:a:skype:skype:3.1.0.144:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.10`,
        fs:  `cpe:2.3:h:3com:3crwe454g72:1.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.0.11`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:4.9.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.1`,
        fs:  `cpe:2.3:a:seeds:acmailer:3.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.1.1`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.1.2`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.1.3`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.2.1`,
        fs:  `cpe:2.3:a:netcreators:irfaq:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.2.2`,
        fs:  `cpe:2.3:a:nokia:qt_creator:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.2.3`,
        fs:  `cpe:2.3:a:mawashimono:nikki:3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.3`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.3.1`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.170:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.3.2`,
        fs:  `cpe:2.3:a:sentinels_randomizer_project:sentinels_randomizer:1.1.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.3.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.5`,
        fs:  `cpe:2.3:a:freemind:freemind:0.9.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.5.1`,
        fs:  `cpe:2.3:a:migrate_project:migrate:7.x-2.1:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.6`,
        fs:  `cpe:2.3:a:tenable:nessus:6.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.6.1`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.6.2`,
        fs:  `cpe:2.3:o:checkpoint:ipso_os:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.6.3`,
        fs:  `cpe:2.3:a:adobe:adobe_presenter:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.6.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.7-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.7`,
        fs:  `cpe:2.3:a:modwsgi:mod_wsgi:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.7.1`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.3`,
        fs:  `cpe:2.3:a:bueltge:adminimize:0.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.4`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.4:a`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.5`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.5.1`,
        fs:  `cpe:2.3:a:google:chrome:5.0.393.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.5.2`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.8.6`,
        fs:  `cpe:2.3:o:mandrakesoft:mandrake_linux:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.9`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.9.1`,
        fs:  `cpe:2.3:a:innominate:mguard_blade:hw-104020:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.9.1.1`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:2.9.2`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(3\)xe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.0.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.0.2`,
        fs:  `cpe:2.3:a:debian:cfingerd:1.4.3-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.0.3`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:3.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.0.4`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.47.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.0.5`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.0.6`,
        fs:  `cpe:2.3:a:docker:docker:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.1`,
        fs:  `cpe:2.3:a:oracle:database_server:9.0.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.1.1`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.1.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.5.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.1.3`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.1.4`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6.7e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.2`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.2:beta1`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.2.1`,
        fs:  `cpe:2.3:a:ibm:bigfix_inventory:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.3`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.3.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1084.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.3.2`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.3.3`,
        fs:  `cpe:2.3:a:ati:skins:2009.0211.2225.40219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.4.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:6.0.0_a:unknown:offline:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.4.1`,
        fs:  `cpe:2.3:a:baramundi:management_suite:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.4.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.5.0`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:7.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.5.1`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.6`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_collaboration:06-20-\/e-:server:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.6.1`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.7.1`,
        fs:  `cpe:2.3:a:webbynode:webbynode:1.1.0:beta1:-:*:-:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.7.4`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.7.5`,
        fs:  `cpe:2.3:a:fujitsu:scansnap_organizer:v3.2l13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.8`,
        fs:  `cpe:2.3:a:public_knowledge_project:open_conference_systems:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.8.1`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.8.2`,
        fs:  `cpe:2.3:a:hp:product_assistant:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.8.3`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.8.4`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6ecf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.9`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.9.0`,
        fs:  `cpe:2.3:a:ajenti:ajenti:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.9.1`,
        fs:  `cpe:2.3:a:roger_padilla_camacho:easy_breadcrumb:7.x-2.10:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.9.2`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:3.9.3`,
        fs:  `cpe:2.3:a:chaos_tool_suite_project:ctools:6.x-1.0:beta2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.0`,
        fs:  `cpe:2.3:a:apache:struts:2.3.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.0.1`,
        fs:  `cpe:2.3:a:adobe:customization_wizard:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.1`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.1.1`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.2`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.2.1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update3:ws:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.2.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.2.3`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.3.0`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.4.0`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.4.1`,
        fs:  `cpe:2.3:h:cisco:ips_4510_sensor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.4.2`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.4.4`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.5.1`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:rc3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.5.2`,
        fs:  `cpe:2.3:o:cisco:ons_15454e_optical_transport_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.5.3`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.5.5`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1.102.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.7`,
        fs:  `cpe:2.3:a:google:chrome:21.0.1180.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.7.1`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.1.4390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.7.2`,
        fs:  `cpe:2.3:a:bea:tuxedo:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.7.3`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.7.5`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.8`,
        fs:  `cpe:2.3:a:oracle:industry_applications:12.0:in:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress:wordpress:4.8.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.0.8223:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.4\(1b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.1:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1015.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.2:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.3:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:typo3:typo3:6.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.9:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.91:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:act:compass:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.92:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:6.2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.0:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:6.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.0:b:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:hp:lights-out_online_configuration_utility:1.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.0:b2:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:9.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.1:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:h:lexmark:x1185:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.3:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:smarty:smarty:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.4:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:avg:safeguard:18.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.2.5:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:8.1.4:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:2.0:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:2.0.1:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:o:dell:idrac6_firmware:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_mobile_pack_project:wordpress_mobile_pack:2.0.2:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_responsive_preview_project:wordpress_responsive_preview:1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:310.44:-:*:*:sunos:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_social_login_project:wordpress_social_login:2.0.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wordpress_spreadsheet_project:wordpress_spreadsheet:0.62::~~~wordpress~~`,
        fs:  `cpe:2.3:o:netgear:d6220_firmware:1.0.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:worldtamilbayan:world_tamil_bayan:0.1::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ons_15327:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:worldwinner:worldwinner_games:1.9.0.23`,
        fs:  `cpe:2.3:a:cart-app:cart_app:1.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wotlab:community_gallery:2.0`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.7.5`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.8.0`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.10.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.8.2`,
        fs:  `cpe:2.3:a:horde:horde_image_api:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.8.4`,
        fs:  `cpe:2.3:a:mozilla:firefox:19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.8.5`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.8.6`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.8.7`,
        fs:  `cpe:2.3:a:devsaran:fresh:7.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.0`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.1`,
        fs:  `cpe:2.3:a:playstudio:brisbane_\&amp;_queensland_alert:2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.2`,
        fs:  `cpe:2.3:a:x:libxrandr:1.2.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.3`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.466.13.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.4`,
        fs:  `cpe:2.3:a:david_stosik:comment_moderation:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.5`,
        fs:  `cpe:2.3:o:smc:smc8024l2_switch_firmware:2.4a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.6`,
        fs:  `cpe:2.3:a:x:libxxf86vm:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.7`,
        fs:  `cpe:2.3:a:gnustep:base:1.24.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.8`,
        fs:  `cpe:2.3:a:ca:license_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.9`,
        fs:  `cpe:2.3:a:sap:solution_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.10`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.11`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p153:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.12`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.13`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:162:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.14`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.15`,
        fs:  `cpe:2.3:a:isc:bind:9.9.0:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.16`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.17`,
        fs:  `cpe:2.3:a:saltstack:salt:0.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.18`,
        fs:  `cpe:2.3:a:cisco:webns:7.40.1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.19`,
        fs:  `cpe:2.3:a:oracle:industry_applications:5.0:sp0a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.20`,
        fs:  `cpe:2.3:a:isc:bind:9.9.1:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.21`,
        fs:  `cpe:2.3:a:welcart:welcart:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.22`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.23`,
        fs:  `cpe:2.3:a:gentoo:security:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.24`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2008:sp2:x64:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:2.9.25`,
        fs:  `cpe:2.3:o:huawei:secospace_usg6500_firmware:v500r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:3.0`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.2:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:3.1`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:3.1.1`,
        fs:  `cpe:2.3:h:hp:hp_laserjet_pro_m1214nfh_mfp:ce842a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:3.2`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:3.3`,
        fs:  `cpe:2.3:a:google:talk:1.0.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:3.4`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.0.10.640:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wouter_verhelst:nbd:3.5`,
        fs:  `cpe:2.3:a:bundler:bundler:1.3.0:pre.6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-business_directory_project:wp-business_directory:1.0.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.6:r6_b1:*:*:esv:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-contact_plugin_project:wp-contact-sidebar-widget:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-dbmanager_project:wp-dbmanager:2.71::~~~wordpress~~`,
        fs:  `cpe:2.3:a:saltstack:salt:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-easybooking_plugin_project:wp-easybooking:1.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ronan_dowling:node_hierarchy:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.00:-:~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:less:381:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.00:a:~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.01::~~~wordpress~~`,
        fs:  `cpe:2.3:a:juniper:junos_pulse_secure_access_service:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.02::~~~wordpress~~`,
        fs:  `cpe:2.3:a:matrikonopc:dnp3_opc_server:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.03::~~~wordpress~~`,
        fs:  `cpe:2.3:a:softartisans:officewriter:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.04::~~~wordpress~~`,
        fs:  `cpe:2.3:h:huawei:nip100:v100r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.05::~~~wordpress~~`,
        fs:  `cpe:2.3:a:f5:3_dns:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.06::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_ip_gateway:2.0.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:splunk:splunk:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sqlalchemy:sqlalchemy:0.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.30::~~~wordpress~~`,
        fs:  `cpe:2.3:a:prosody:prosody:0.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:workstation:12.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.40::~~~wordpress~~`,
        fs:  `cpe:2.3:a:busybox:busybox:1.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.50::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.008.20082:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.51::~~~wordpress~~`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp-plugins:wp-print:2.52::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:libtirpc:0.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_app_maker_project:wp_app_maker:1.0.16.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_appointments_schedules_project:wp_appointments_schedules:1.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:change_and_configuration_management_database:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_ban_project:wp_ban:1.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_r5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_blipbot_project:wp_blipbot:3.0.9:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:3com:total_control_netserver_card:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_consultant_project:wp_consultant:1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:slideshow_project:slideshow:2.2.20:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_content_source_control_project:wp_content_source_control:3.0.0:-:~-~-~wordpress~~:-`,
        fs:  `cpe:2.3:a:jasig:phpcas:1.3.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_easy_post_types_project:wp_easy_post_types:1.4.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ubnt:unifi_controller:3.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_guestmap_project:wp_guestmap_project:1.8:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_limit_posts_automatically_project:wp_limit_posts_automatically:0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ipswitch:ws_ftp:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_media_cleaner_project:wp_media_cleaner:2.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:peta:peta:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_microblogs_project:wp_microblogs:0.4.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:haxx:curl:7.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_php_widget_project:wp_php_widget:1.0.2`,
        fs:  `cpe:2.3:a:google:chrome:2.0.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_picasa_image_project:wp_picasa_image:1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpx100\/120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_plugin_manager_project:wp_plugin_manager:1.6.4.b:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_restful_project:wp_restful:0.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.2-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_rss_poster_plugin_project:wp-rss-poster:1.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.0\(3\)u3\(2b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_silverlight_media_player_project:wp_silverlight_media_player:0.8:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_simplemail_project:wp_simplemail:1.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moodle:moodle:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_smiley_project:wp_smiley:1.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:piriform:ccleaner:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_social_invitations_project:wp_social_invitations:1.4.4.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_ultimate_email_marketer_project:wp_ultimate_email_marketer:1.1.0`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wp_unique_article_header_image_project:wp_unique_article_header_image:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:intel:2915abg_proset_wireless:10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpbeginner:floating_social_bar:1.1.5::~~wordpress~~~`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpcommenttwit_project:wpcommenttwit:0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpdatatables:wpdatatables:1.5.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:suse:suse_linux:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.1.30::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.1.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.22.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.1.32::~~~wordpress~~`,
        fs:  `cpe:2.3:h:oracle:sun_fire_x4270_m2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.1.33::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.1.34::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.0.002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.1.35::~~~wordpress~~`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.1.36::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tapatalk:tapatalk:2.0:*:*:*:*:vbulletin:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:apex:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:qemu:qemu:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apple:itunes:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:csounds:csound:5.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:f5:big-ip_access_policy_manager:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:yahoo:yui:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.3.148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_application_dependency_discovery_manager:7.2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:informix_web_datablade:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20161012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:postfix:postfix:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:infrastructure_client:2.5.0.64257:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:1.2.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:samba:samba:2.0.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.1%40824267::~~~wordpress~~`,
        fs:  `cpe:2.3:a:otrs:otrs:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:sna_server:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tibco:managed_file_transfer_internet_server:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:schneider-electric:ofs_test_client_tlxcdlfofs33:3.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:microsoft:windows_vista:-:sp1:x64-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vips:vips:7.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:henner_zeller:henplus:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.1.2:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.15::~~~wordpress~~`,
        fs:  `cpe:2.3:o:rockwellautomation:1768_compact_guardlogix_l4xs_controller_firmware:18.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:55.0.2883.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:datadog:0.1.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:creative_suite:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.21::~~~wordpress~~`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.0.22::~~~wordpress~~`,
        fs:  `cpe:2.3:a:david_king:vino:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.61:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:vbscript:5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:flash_player:7.0.66.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:process-one:ejabberd:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:4.10.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:spip:spip:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:coldfusion:10.0:update_14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.13::~~~wordpress~~`,
        fs:  `cpe:2.3:a:quest:toad_data_modeler:3.4.14.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.14::~~~wordpress~~`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpr362:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:cxf:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:1.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:python:python:3.2.2150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.19::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.21::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:3.3\(2\)spb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.22::~~~wordpress~~`,
        fs:  `cpe:2.3:a:algisinfo:aicontactsafe:2.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.23::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.51a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.24::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.25::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:13.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.26::~~~wordpress~~`,
        fs:  `cpe:2.3:a:content_construction_kit_project:content_construction_kit:6.x-2.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.27::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:hp-ux:9.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.28::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:outlook:97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.29::~~~wordpress~~`,
        fs:  `cpe:2.3:a:network_vision:intravue:2.3.0a11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.30::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:node.js:0.10.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.31::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tryton:tryton:3.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.32::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.33::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.34::~~~wordpress~~`,
        fs:  `cpe:2.3:a:doapps:go_msx_mls:2.3.4.mr3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.35::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:access:2002:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:2.1.36::~~~wordpress~~`,
        fs:  `cpe:2.3:h:f5:big-ip_access_policy_manager:11.0.0:*:*:*:*:*:*:standalone`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)by2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sap:sap_netweaver_application_server_java:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kanich:com_searchlog:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:skyarc:multifileuploader:0.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:cordova:3.5.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:4.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:h:unisys:libra_4300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jd242b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.11::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.12::~~~wordpress~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.13::~~~wordpress~~`,
        fs:  `cpe:2.3:h:ibm:system_x3500_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.14::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gnu:grep:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:8.2.2:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1081.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.17::~~~wordpress~~`,
        fs:  `cpe:2.3:o:redhat:linux:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.19::~~~wordpress~~`,
        fs:  `cpe:2.3:o:hp:ignite-ux:c.7.0.212:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpeasycart:wp_easycart:3.0.20::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:domino:8.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpgetready:nextcellent_gallery:1.9.14::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:scanjet_8250:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpgetready:nextcellent_gallery:1.9.15::~~~wordpress~~`,
        fs:  `cpe:2.3:a:novell:edirectory:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpgetready:nextcellent_gallery:1.9.16::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jogamp:jogamp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpgetready:nextcellent_gallery:1.9.17::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:unified_callmanager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpgetready:nextcellent_gallery:1.9.18::~~~wordpress~~`,
        fs:  `cpe:2.3:a:atlassian:jira:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpmembership:wpmembership:1.2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ez:ez_publish:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpml:wpml:3.1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:enterprise_manager_grid_control:10.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wppa.opajaap:wp-photo-album-plus:5.0.0`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wppa.opajaap:wp-photo-album-plus:5.0.1`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wppa.opajaap:wp-photo-album-plus:5.0.2`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wppa.opajaap:wp-photo-album-plus:5.0.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wppa.opajaap:wp-photo-album-plus:5.0.3.001`,
        fs:  `cpe:2.3:a:businessobjects:crystal_reports_runtime:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wppa.opajaap:wp-photo-album-plus:6.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kadinlar_kulubu_kkmobileapp_project:kadinlar_kulubu_kkmobileapp:3.4.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:2.2.1:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rsgallery2:com_rsgallery2:1.11.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:spss_collaboration_and_deployment_services:4.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:7.0.511.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server_software:x8.5.2:*:*:*:expressway:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emeric_vernat:javamelody:1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mcafee:host_intrusion_prevention_server:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.9.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fujitsu:scansnap:5.0.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.9.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.13.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:1.10::~~~wordpress~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.580.2:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:microsoft_data_access_components:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpshopstyling:wp-ecommerce-shop-styling:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:v8:2.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpslideshow:image_news_slider:3.0`,
        fs:  `cpe:2.3:a:juniper:secure_access_virtual_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpslideshow:image_news_slider:3.1`,
        fs:  `cpe:2.3:a:apple:java_1.4:1:08:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpslideshow:image_news_slider:3.2`,
        fs:  `cpe:2.3:a:cisco:jabber_software_development_kit:9.3\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpsolr:wpsolr-search-engine:7.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpsymposium:wp_symposium:13.02::~~~wordpress~~`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha22:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpsymposium:wp_symposium:13.04::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.3\(7\)xr3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpsymposium:wp_symposium:14.10::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpsymposium:wp_symposium:14.11::~~~wordpress~~`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpsymposium:wp_symposium:15.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:unicenter_nsm:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wpsymposium:wp_symposium:15.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.0.0`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.1.0`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.1.1`,
        fs:  `cpe:2.3:a:theforeman:kafo:0.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.1.2`,
        fs:  `cpe:2.3:a:pngquant:pngquant:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.1.3`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.2.0`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.03.249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.3.0`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.4.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.5.0`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.6.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.416:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.6.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.7.0`,
        fs:  `cpe:2.3:a:itd-inc:bingo\!cms:1.1:b:core:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.8.0`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.7.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:1.9.0`,
        fs:  `cpe:2.3:a:libevent_project:libevent:2.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.0.0`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_software:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.1.0`,
        fs:  `cpe:2.3:a:isc:bind:9.8.5:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.2.0`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.2.1`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:1.0.1.4o:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.3.0`,
        fs:  `cpe:2.3:a:ericsson:drutt_mobile_service_delivery_platform:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.4.0`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.4.1`,
        fs:  `cpe:2.3:a:orchardproject:orchard:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.5.0`,
        fs:  `cpe:2.3:a:samba:samba:3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.5.1`,
        fs:  `cpe:2.3:a:nextapp:echo:2.0:alpha9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.5.2`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.6.0`,
        fs:  `cpe:2.3:o:oracle:linux:7:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.7.0`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.7.1`,
        fs:  `cpe:2.3:a:crawltrack:crawltrack:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.8.0`,
        fs:  `cpe:2.3:a:android_excellence_project:android_excellence:1.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.8.1`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.8.2`,
        fs:  `cpe:2.3:a:ibm:powerkvm:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.9.0`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:2.9.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.0.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.1.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.0.1`,
        fs:  `cpe:2.3:h:hp:procurve_switch_2610-48-pwr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.0.2`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.0.3`,
        fs:  `cpe:2.3:h:cisco:content_services_switch_11500:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.1.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.2.0`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.2.1`,
        fs:  `cpe:2.3:a:ibm:connections:5.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.3.0`,
        fs:  `cpe:2.3:a:ibm:data_studio_web_console:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.3.1`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wptrafficanalyzer:trafficanalyzer:3.3.2`,
        fs:  `cpe:2.3:a:vips:vips:7.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wt_directory_project:wt_directory:1.4.1::~~~typo3~~`,
        fs:  `cpe:2.3:o:cisco:ios_xr_software:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wtmdesktop_project:wtmdesktop:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:gnu:glibc:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wtradersactivity_project:wtradersactivity:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wtrootrootvizle_project:wtrootrootvizle:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wu-rating_project:wu-rating:1.0_12319:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:xnview:xnview:1.93.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wvware:libwmf:0.2.8.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wxwidgets:wxwidgets:2.8.12`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysigot:wysigot:5.40`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysigot:wysigot:5.50`,
        fs:  `cpe:2.3:a:vips:vips:7.7.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysigot:wysigot:5.51`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.4:1025:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysigot:wysigot:6.00`,
        fs:  `cpe:2.3:a:microsoft:project:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysigot:wysigot:6.01`,
        fs:  `cpe:2.3:a:gnupg:gnupg:0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysigot:wysigot:6.02`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysigot:wysigot:6.10`,
        fs:  `cpe:2.3:h:dell:idrac6_monolithic:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p350:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:anyconnect_vpn_client:2.5.3041:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:pcanywhere:11.0.0.730:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:splunk:splunk:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.5.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cdrl:cdrl:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.03.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:o:debian:debian_linux:0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.0:deprecated:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.0.9.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:liveupdate:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:moodle:moodle:2.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cognos:ticket_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:h:hp:laserjet_9040_mfp:q3721a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:samsung:samsung_security_manager:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:gentoo:xdg-utils:1.1.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:kindsoft:kindeditor:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:apache:subversion:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.1.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:directx:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:wysija_newsletters_project:wysija_newsletters:2.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libchromexvmc:-`,
        fs:  `cpe:2.3:h:cisco:telepresence_system_tx1310_65:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libchromexvmcpro:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libdmx:1.0.2`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_server:5.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libdmx:1.0.99.1`,
        fs:  `cpe:2.3:a:atmail:atmail:6.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libdmx:1.1.0`,
        fs:  `cpe:2.3:a:bitcoin:bitcoind:0.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libdmx:1.1.1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libdmx:1.1.2`,
        fs:  `cpe:2.3:a:digium:asterisk:12.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libfs:1.0.1`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libfs:1.0.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.18.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libfs:1.0.3`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libfs:1.0.4`,
        fs:  `cpe:2.3:a:tibco:activematrix_policy_agent:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libfs:1.0.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libglx:-`,
        fs:  `cpe:2.3:a:drupac:touch:7.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libx11:1.5.0`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libx11:1.5.99.901`,
        fs:  `cpe:2.3:a:oracle:odac_documentation_for_visual_studio_2010:11.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.1.90.1`,
        fs:  `cpe:2.3:a:x.org:xfree86:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.1.91`,
        fs:  `cpe:2.3:o:huawei:p8_firmware:gra-ul100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.1.92`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p193:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.1.93`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpq3212:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(16\)s8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.3`,
        fs:  `cpe:2.3:h:netgear:wnr1000v3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.4`,
        fs:  `cpe:2.3:a:kopf:outlook_attachment_remover:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.5`,
        fs:  `cpe:2.3:o:xen:xen:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.6`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:4.7.5:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.7`,
        fs:  `cpe:2.3:a:piwigo:piwigo:1.0.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.8`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.8.1`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.44:test3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcb:1.9`,
        fs:  `cpe:2.3:a:alienvault:open_source_security_information_management:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.6`,
        fs:  `cpe:2.3:a:microsoft:directx:10.1:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.7`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20020804:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.8`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.9`,
        fs:  `cpe:2.3:a:omeka:omeka:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.10`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.11`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:5.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.12`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.13`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:14.00a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxcursor:1.1.14`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.0.99.2`,
        fs:  `cpe:2.3:a:web2py:web2py:1.89.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.0.99.3`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.0.99.4`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.1.1`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.6-113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.1.2`,
        fs:  `cpe:2.3:a:siemens:scalance_xr-300_firmware:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.2.0`,
        fs:  `cpe:2.3:h:cisco:sf300-24mp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.3.0`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.3.1`,
        fs:  `cpe:2.3:a:sun:iplanet_web_server:4.1:sp9:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxext:1.3.2`,
        fs:  `cpe:2.3:o:huawei:5300hi_firmware:v200r005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfixes:4.0`,
        fs:  `cpe:2.3:o:juniper:junos:13.3:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfixes:4.0.1`,
        fs:  `cpe:2.3:a:myclientbase:myclientbase:0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfixes:4.0.2`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfixes:4.0.3`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfixes:4.0.4`,
        fs:  `cpe:2.3:a:pivotal_software:redis:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfixes:4.0.5`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfixes:5.0`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfixes:5.0.1`,
        fs:  `cpe:2.3:a:ibm:campaign:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.1.0`,
        fs:  `cpe:2.3:a:cisco:pgw_2200:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.0`,
        fs:  `cpe:2.3:a:google:chrome:8.0.555.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.1`,
        fs:  `cpe:2.3:a:emc:captiva_capture:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.2`,
        fs:  `cpe:2.3:a:adobe:formflow_filler:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.3`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.4`,
        fs:  `cpe:2.3:a:tenable:nessus:6.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.5`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.2.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.6`,
        fs:  `cpe:2.3:h:zte:f460:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.7`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0051:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p287:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.2.9`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.3.0`,
        fs:  `cpe:2.3:a:autodesk:autocad_mechanical:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.3.1`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.apiexplorer:1.1.0:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.3.2`,
        fs:  `cpe:2.3:a:ca:license_software:1.70.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.3.3`,
        fs:  `cpe:2.3:a:apache:http_server:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.3.4`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.0`,
        fs:  `cpe:2.3:o:cray:unicos:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.1`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.3`,
        fs:  `cpe:2.3:a:hp:centralview_dealer_performance_audit:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.4`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.5`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.6`,
        fs:  `cpe:2.3:o:yahama:rt100i:3.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.7`,
        fs:  `cpe:2.3:a:serf_project:serf:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.99`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.webapicompatshim:1.0.3:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxfont:1.4.99.901`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.5.0`,
        fs:  `cpe:2.3:o:yamaha:rtv700:8.00.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.5.99.2`,
        fs:  `cpe:2.3:a:ca:unicenter_management_lotus_note_domino:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.5.99.3`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta32:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.6.0`,
        fs:  `cpe:2.3:a:vmware:view:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.6.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.6.2`,
        fs:  `cpe:2.3:a:adiscon:loganalyzer:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.6.99.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.7`,
        fs:  `cpe:2.3:a:coppermine-gallery:coppermine_photo_gallery:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxi:1.7.1`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxinerama:1.0.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.424.1.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxinerama:1.0.3`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.1.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxinerama:1.0.99.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:24.0.0.221:*:*:*:*:edge:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxinerama:1.1`,
        fs:  `cpe:2.3:a:tribiq:tribiq_cms:5.0.11e:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxinerama:1.1.1`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxinerama:1.1.2`,
        fs:  `cpe:2.3:a:usebb:usebb:0.2.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxp:1.0.0`,
        fs:  `cpe:2.3:a:adobe:photoshop:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxp:1.0.1`,
        fs:  `cpe:2.3:a:hp:select_access:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.2.3`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.356:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.2.99.1`,
        fs:  `cpe:2.3:a:redhat:libreport:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.2.99.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.2.99.3`,
        fs:  `cpe:2.3:a:john_nunemaker:httparty:0.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.2.99.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.3.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.308:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.3.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.27.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.3.2`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.06.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.4.0`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:2.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxrandr:1.4.1`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxres:1.0.1`,
        fs:  `cpe:2.3:a:catalin_florian_radut:zeropoint:6.x-1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxres:1.0.2`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxres:1.0.3`,
        fs:  `cpe:2.3:o:huawei:s12700_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxres:1.0.4`,
        fs:  `cpe:2.3:a:password_policy_project:password_policy:7.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxres:1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxres:1.0.6`,
        fs:  `cpe:2.3:a:apache:xalan-java:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxres:1.0.7`,
        fs:  `cpe:2.3:a:isc:bind:9.10.3:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.0.3`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.0.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.0.5`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.0.6`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.0.7`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.0.8`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.2\(2\):sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.0.9`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.1.1`,
        fs:  `cpe:2.3:a:symantec:web_security:3.01.63:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.1.2`,
        fs:  `cpe:2.3:a:samba:samba:3.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxt:1.1.3`,
        fs:  `cpe:2.3:a:ibm:infosphere_information_server:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxtst:1.0.2`,
        fs:  `cpe:2.3:a:razorcms:razorcms:1.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxtst:1.0.3`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxtst:1.0.99.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.2.202.327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxtst:1.0.99.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p285:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxtst:1.1.0`,
        fs:  `cpe:2.3:a:gnome:glib:2.17.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxtst:1.2.0`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxtst:1.2.1`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxv:1.0.2`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxv:1.0.3`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.2.0:test1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxv:1.0.4`,
        fs:  `cpe:2.3:a:xnview:xnview:1.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxv:1.0.5`,
        fs:  `cpe:2.3:a:hp:solution_center:120.0.194.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxv:1.0.6`,
        fs:  `cpe:2.3:a:boson:exam_environment:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxv:1.0.7`,
        fs:  `cpe:2.3:a:cdotech:pics_dashboard:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxvmc:1.0.2`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxvmc:1.0.3`,
        fs:  `cpe:2.3:a:phpunit_project:phpunit:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxvmc:1.0.4`,
        fs:  `cpe:2.3:h:intel:d845pt_motherboard:p05-0024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxvmc:1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxvmc:1.0.6`,
        fs:  `cpe:2.3:a:ibm:informix_open_admin_tool:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxvmc:1.0.7`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxvmc:1.0.8`,
        fs:  `cpe:2.3:a:oracle:application_server_portal:3.0.9.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.0.1`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.0.2`,
        fs:  `cpe:2.3:a:apple:java_1.6:0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.0.99.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.0.99.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_utility:2010.910.2122.36517:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.1`,
        fs:  `cpe:2.3:a:sambar:sambar_server:6.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.1.1`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.168:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.1.2`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.1.3`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86dga:1.1.4`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86vm:1.0.1`,
        fs:  `cpe:2.3:a:spambot_module_project:spambot:6.x-3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86vm:1.0.2`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86vm:1.0.99.1`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86vm:1.1.0`,
        fs:  `cpe:2.3:a:google:update_helper:1.2.183.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86vm:1.1.1`,
        fs:  `cpe:2.3:a:artonx.org:activescriptruby:1.6.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86vm:1.1.2`,
        fs:  `cpe:2.3:a:haxx:curl:7.45.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:libxxf86vm:1.1.3`,
        fs:  `cpe:2.3:a:redmine:redmine:0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org-xserver:1.7`,
        fs:  `cpe:2.3:a:intel:network_connections:16.2.49.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org-xserver:1.7.6.902`,
        fs:  `cpe:2.3:a:blackberry:blackberry_link:1.1.1.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org-xserver:1.7.7`,
        fs:  `cpe:2.3:a:redhat:rhel_cluster_storage:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org-xserver:1.7.7:rc2`,
        fs:  `cpe:2.3:a:winzip:winzip:15.0.9327:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:1.0`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.9:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:3.0`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.9.2.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:4.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2sxe:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:5.0`,
        fs:  `cpe:2.3:o:cisco:nx-os:7.2\(0\)zz\(99.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.0`,
        fs:  `cpe:2.3:a:hitachi:jp1\/performance_management-manager_web_option:07-54:*:*:*:*:solaris:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.1`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.3`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.5.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.0_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.7`,
        fs:  `cpe:2.3:a:isaac_sukin:shorten:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.8`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup:-:*:netware:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.8.1`,
        fs:  `cpe:2.3:o:yamaha:rt100i:2.02.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.8.2`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:6.1\(2\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:6.9.0`,
        fs:  `cpe:2.3:a:businessobjects:webintelligence:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.0`,
        fs:  `cpe:2.3:a:microsoft:outlook:2000:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.1`,
        fs:  `cpe:2.3:a:symantec:liveupdate:3.3.0.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.2`,
        fs:  `cpe:2.3:a:gnu:glibc:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.3`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.06.011:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.4`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2n:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.5`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.3\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.5:rc1`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.6`,
        fs:  `cpe:2.3:a:ibm:tivoli_common_reporting:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.6:rc1`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.7`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x.org_x11:7.7:rc1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x_display_manager:1.1.10`,
        fs:  `cpe:2.3:a:php:php:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x_display_manager:1.1.11`,
        fs:  `cpe:2.3:a:typo3:typo3:4.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x_server:-`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.1:*:*:*:workgroup:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x_server:1.11.0`,
        fs:  `cpe:2.3:a:apache:camel:2.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x_server:1.11.1`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.25:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:x:x_server:1.11.2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.22.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x:xf86-video-intel:2.99.911`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.13:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.0.1`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.1`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.2.185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.1:rc1`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.1:rc2`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.1.4`,
        fs:  `cpe:2.3:a:cob\&#39;s_products:cobime:0.9.3:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.1.5`,
        fs:  `cpe:2.3:o:cisco:ios:12.2xq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.1.6`,
        fs:  `cpe:2.3:a:igor_vlasenko:html-template-pro:0.65:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.1.99.1`,
        fs:  `cpe:2.3:a:mawashimono:nikki:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.1.99.2`,
        fs:  `cpe:2.3:a:ilia_alshanetsky:fudforum:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.2`,
        fs:  `cpe:2.3:a:tigervnc:tigervnc:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.2.1`,
        fs:  `cpe:2.3:a:swagger:swagger-parser:1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.2.2`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3`,
        fs:  `cpe:2.3:a:jenkins:config_file_provider:2.7.2:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.1`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.2`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:185:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.3`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_social_it_plus:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.4`,
        fs:  `cpe:2.3:a:digium:asterisk:11.7.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.5`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp1:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.6`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.2:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.99.901`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.99.902`,
        fs:  `cpe:2.3:a:gnome:glib:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.3.99.903`,
        fs:  `cpe:2.3:a:hp:network_virtualization:11.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.4.0`,
        fs:  `cpe:2.3:a:wiccle:wiccle_web_builder:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.4.1`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.4.2`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.4.3`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.4.4`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:5.3\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.4.99.901`,
        fs:  `cpe:2.3:a:php:php:5.3.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.4.99.902`,
        fs:  `cpe:2.3:a:matthias_graubner:mg_help:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libx11:1.5.99.902`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxrender:0.9.1`,
        fs:  `cpe:2.3:a:apple:itunes:10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxrender:0.9.2`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.0.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxrender:0.9.3`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxrender:0.9.4`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxrender:0.9.5`,
        fs:  `cpe:2.3:a:gentoo:nview:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxrender:0.9.6`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxrender:0.9.7`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxv:1.0.2`,
        fs:  `cpe:2.3:a:blackberry:qnx_momentics_tool_suite:6.5.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxv:1.0.3`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxv:1.0.4`,
        fs:  `cpe:2.3:a:att:connect_participant_application:8.9.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxv:1.0.5`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1281.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxv:1.0.6`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:libxv:1.0.7`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:1.0`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:6.0:beta_2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:4.0`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:5.0`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.8:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.0`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.16:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.1`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.3`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:8.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.4`,
        fs:  `cpe:2.3:a:apache:mod_python:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.5.1`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.7`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.8`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.19:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.8.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.8.1`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:2.1.4560.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.8.2`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.302.2232.40412:*:*:en:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:6.9`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.12.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:r5`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:x11:r6.7`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r008c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xfree86:4.0`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xfree86:4.0.1`,
        fs:  `cpe:2.3:a:wali:walisms_cn:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xfree86:4.2.0`,
        fs:  `cpe:2.3:o:google:chrome:21.0.1180.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.0`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.0.901`,
        fs:  `cpe:2.3:a:jforum:jforum:3.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.0.902`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.47.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.1`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s9508e-v:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.1.901`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.1.902`,
        fs:  `cpe:2.3:a:foolabs:xpdf:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.2`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.2.901`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.2.902`,
        fs:  `cpe:2.3:a:otrs:otrs:2.4.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.3`,
        fs:  `cpe:2.3:a:openbsd:openssh:6.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.3.901`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.3.902`,
        fs:  `cpe:2.3:a:isc:dhcp:4.3.0:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.4`,
        fs:  `cpe:2.3:a:justsystems:hanako:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.4.901`,
        fs:  `cpe:2.3:a:mollify:mollify:0.9.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.4.902`,
        fs:  `cpe:2.3:a:landing_pages_project:landing_pages_plugin:1.0.3.9:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.5`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.35.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.5.901`,
        fs:  `cpe:2.3:h:ibm:xiv_storage_system_gen3:2810:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.5.902`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.2.0:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.6`,
        fs:  `cpe:2.3:o:freebsd:freebsd:9.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.6.901`,
        fs:  `cpe:2.3:o:loytec:l-switch_and_l-ip_firmware:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.6.902`,
        fs:  `cpe:2.3:a:cybozu:remote_service_manager:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.7`,
        fs:  `cpe:2.3:a:ows:scald:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.99.1`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.99.2`,
        fs:  `cpe:2.3:a:emc:networker:7.5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.99.901`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.7.99.902`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.1-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.0`,
        fs:  `cpe:2.3:a:netgear:ma521_driver:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.0.901`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.2.3\(1101\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.0.902`,
        fs:  `cpe:2.3:h:softbank:panasonic_3g_handset:941p:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.1`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.1:-:syslog:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.1.901`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:alpha5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.1.902`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.2.901`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_3s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.2.902`,
        fs:  `cpe:2.3:a:wordpress_mobile_pack_project:wordpress_mobile_pack:1.1.1:-:-:-:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.99.901`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.99.902`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.99.903`,
        fs:  `cpe:2.3:a:oracle:fusion_applications:11.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.99.904`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.8.99.905`,
        fs:  `cpe:2.3:a:ssh:tectia_client:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.0`,
        fs:  `cpe:2.3:a:equis:metastock:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.0.901`,
        fs:  `cpe:2.3:a:apache:xml_security_for_java:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.0.902`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.1`,
        fs:  `cpe:2.3:a:iss:blackice_pc_protection:3.6cpj:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.2`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.2.901`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.2.902`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p3_rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.3`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.9:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.3.901`,
        fs:  `cpe:2.3:a:mike_stefanello:og_features:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.3.902`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:2.8.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.4`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.4.901`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.2-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.5`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.99.901`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.99.902`,
        fs:  `cpe:2.3:o:yamaha:rtx1100:8.03.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.9.99.903`,
        fs:  `cpe:2.3:a:gnu:grep:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.0`,
        fs:  `cpe:2.3:a:hp:nonstop_seeview_server_gateway:d47.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.0.901`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.0:alpha17:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.0.902`,
        fs:  `cpe:2.3:a:ibm:storwize_unified_v7000_software:1.4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.1`,
        fs:  `cpe:2.3:o:fortinet:fortios:5.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.1.901`,
        fs:  `cpe:2.3:a:serv-u:serv-u:8.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.1.902`,
        fs:  `cpe:2.3:h:seagate:goflex_sattelite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.2`,
        fs:  `cpe:2.3:a:apache:derby:10.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.2.901`,
        fs:  `cpe:2.3:a:novell:kanaka:2.7.1:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.2.902`,
        fs:  `cpe:2.3:a:busybox:busybox:1.22.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.3`,
        fs:  `cpe:2.3:a:duckcorp:bip:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.3.901`,
        fs:  `cpe:2.3:a:atmarkweb:\@web_shoppingcart:1.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.3.902`,
        fs:  `cpe:2.3:a:fonality:trixbox:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.4`,
        fs:  `cpe:2.3:a:nancy_wichmann:announcements:6.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.6`,
        fs:  `cpe:2.3:a:pheonixcontact-software:multiprog:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.99.901`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:6.0.181.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.10.99.902`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:1.0.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.0`,
        fs:  `cpe:2.3:a:ibm:campaign:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.1`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.1.901`,
        fs:  `cpe:2.3:a:unixodbc:unixodbc:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.1.902`,
        fs:  `cpe:2.3:a:ibm:informix_dynamic_server:11.70.xc7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.2`,
        fs:  `cpe:2.3:a:ibm:maximo_for_nuclear_power:7.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.2.901`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.2.902`,
        fs:  `cpe:2.3:a:custom_search_project:custom_search:6.x-1.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.3`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.3.901`,
        fs:  `cpe:2.3:o:cisco:ios:3.6.0e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.3.902`,
        fs:  `cpe:2.3:a:ultraiso:ultraiso:9.35:*:*:*:premium:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.4`,
        fs:  `cpe:2.3:a:goodiware:goodreader:3.14.1:-:*:*:*:iphone_os:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.99.1`,
        fs:  `cpe:2.3:o:xen:xen:4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.99.2`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.99.901`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.99.902`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.14.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.11.99.903`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(4\)t1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.0.901`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.0.902`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2003:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.1.901`,
        fs:  `cpe:2.3:a:iain:gypsy:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.1.902`,
        fs:  `cpe:2.3:a:eucalyptus:eucalyptus:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.2`,
        fs:  `cpe:2.3:a:f5:big-ip_global_traffic_manager:11.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.2.901`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.2.902`,
        fs:  `cpe:2.3:a:sun:java_plug-in:1.4.2_04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.3`,
        fs:  `cpe:2.3:a:ibm:storwize_v3700_software:7.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.3.901`,
        fs:  `cpe:2.3:a:hitachi:it_operations_director:03-00-04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.3.902`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0:b6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.4`,
        fs:  `cpe:2.3:h:rockwellautomation:rslinx_enterprise:cpr9:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.99.901`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.99.902`,
        fs:  `cpe:2.3:a:afnetworking_project:afnetworking:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.99.903`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:3.4:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.99.904`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:3.6.7d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.12.99.905`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.0`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_server_sensor:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.0.901`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.0.902`,
        fs:  `cpe:2.3:a:codecguide:real_alternative:1.8.2:-:lite:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.1`,
        fs:  `cpe:2.3:a:dell:online_diagnostics:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.1.901`,
        fs:  `cpe:2.3:h:cisco:catalyst_6000_ws-x6380-nam:3.1\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.2`,
        fs:  `cpe:2.3:a:irfanview:irfanview:1.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.2.901`,
        fs:  `cpe:2.3:a:louis_jimenez:custom_meta:6.x-1.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.2.902`,
        fs:  `cpe:2.3:a:oracle:internet_expenses:11.5.10.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.3`,
        fs:  `cpe:2.3:a:microsoft:business_solutions_crm:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.4`,
        fs:  `cpe:2.3:a:rsa:envision:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.99.901`,
        fs:  `cpe:2.3:a:inclind:custom_pub:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.13.99.902`,
        fs:  `cpe:2.3:a:zarafa:zarafa:6.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.0`,
        fs:  `cpe:2.3:o:fedoraproject:fedora:21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.1`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:1.3.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.1.901`,
        fs:  `cpe:2.3:a:google:chrome:11.0.693.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.1.902`,
        fs:  `cpe:2.3:a:macromedia:flash_player:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.2`,
        fs:  `cpe:2.3:a:gnu:libtasn1:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.2:rc1`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.2.901`,
        fs:  `cpe:2.3:o:zyxel:pmg5318-b20a_firmware:v100aanc0b5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.2.902`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.3`,
        fs:  `cpe:2.3:a:att:connect_participant_application:9.3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.3.901`,
        fs:  `cpe:2.3:a:php:php:5.4.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.3.901:rc1`,
        fs:  `cpe:2.3:h:hp:procurve_router:jd967a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.4`,
        fs:  `cpe:2.3:a:ibm:tivoli_netcool\/omnibus:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.4.901`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.5`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:5.6:5102:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.5.901`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6\(3\)_b47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.6`,
        fs:  `cpe:2.3:a:digium:asterisk:b.2.5.2:-:business:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.7`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:5.5:u2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.99.1`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-rc3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.99.2`,
        fs:  `cpe:2.3:a:firebirdsql:firebird:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.99.3`,
        fs:  `cpe:2.3:a:cisco:carrier_routing_system:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.99.901`,
        fs:  `cpe:2.3:a:microsoft:outlook.com:7.8.2.12.49.5701:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.99.902`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.99.903`,
        fs:  `cpe:2.3:a:cybozu:dezie:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.99.904`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.0.9.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.14.99.905`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.15.0`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.15.0.901`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20031005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.15.1`,
        fs:  `cpe:2.3:a:deakin:deakin_university:1.1.729.1694:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.15.2`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.15.99.901`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:8.6\(.2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.15.99.902`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.15.99.903`,
        fs:  `cpe:2.3:a:cisco:media_origination_system_suite:2.5\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.15.99.904`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.16.0`,
        fs:  `cpe:2.3:a:nero:dolbyfiles:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.16.0.901`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.16.1`,
        fs:  `cpe:2.3:a:hp:identity_driven_manager:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.16.1.901`,
        fs:  `cpe:2.3:a:videousermanuals:white-label-cms:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.16.2`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.16.2.99.901`,
        fs:  `cpe:2.3:a:ibm:lotus_domino_web_server:6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.16.2.901`,
        fs:  `cpe:2.3:a:smarty:smarty:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.16.3`,
        fs:  `cpe:2.3:a:apache:cxf:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x.org:xorg-server:1.17.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1293.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x10media:.x10_automatic_mp3_script:1.5.5`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:1.0`,
        fs:  `cpe:2.3:a:phpcheckz:phpcheckz:0.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:1.0.1`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:7.8.1388.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:1.1.0`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:1.2.0`,
        fs:  `cpe:2.3:a:wppa.opajaap:wp-photo-album-plus:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:1.2.1`,
        fs:  `cpe:2.3:a:appthemes:classipress:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:1.2.2`,
        fs:  `cpe:2.3:a:adobe:acrobat:8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:1.3`,
        fs:  `cpe:2.3:a:php-nuke:iframe_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:1.3.1`,
        fs:  `cpe:2.3:a:x7_group:x7_chat:1.3.1b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.2`,
        fs:  `cpe:2.3:a:x7chat:x7_chat:2.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.2.1`,
        fs:  `cpe:2.3:a:apache:xml_security_for_c\&#43;\&#43;:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.5`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.5.2`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.7`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.7.1`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:10.2.0.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.7.2`,
        fs:  `cpe:2.3:a:notepad_plus_plus:notepad\&#43;\&#43;:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.8`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.8.1`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.17:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.9`,
        fs:  `cpe:2.3:a:altiris:realtime_system_manager_solution_documentation:6.3.1009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:2.9.1`,
        fs:  `cpe:2.3:a:cisco:webex_recording_format_player:27.11.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.0.1`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:4.2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.0.2`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.1`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.5.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.1.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(11\)t8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.1.2`,
        fs:  `cpe:2.3:a:hans_nilsson:video_filter:7.x-3.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.2`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_reader:3.1.2.1030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.3`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:6.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.3.1`,
        fs:  `cpe:2.3:h:cisco:catalyst_7600_ws-svc-nam-2:2.2\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.3.2`,
        fs:  `cpe:2.3:a:f5:big-ip_application_security_manager:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.4`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.4.1`,
        fs:  `cpe:2.3:a:omeka:omeka:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.5`,
        fs:  `cpe:2.3:a:tincan:phplist:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.5.1`,
        fs:  `cpe:2.3:h:linksys:befsr41:1.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2engine:x2crm:3.5.2`,
        fs:  `cpe:2.3:a:hp:dtmail:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.0.0`,
        fs:  `cpe:2.3:h:hp:color_laserjet_m775f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.0.1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.0.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:xp:sp1:embedded:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.0.3`,
        fs:  `cpe:2.3:a:roundcube:webmail:0.1:20050811:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.0.4`,
        fs:  `cpe:2.3:a:controlsystemworks:csworks:1.0.813.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.0.6`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.0.7`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.0.8`,
        fs:  `cpe:2.3:a:gnu:flim:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:3.0.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.1`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.18.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(31\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.3`,
        fs:  `cpe:2.3:a:pnp4nagios:pnp4nagios:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.4`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.1:sp7:express:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.5`,
        fs:  `cpe:2.3:o:ge:multilink_ml1200_firmware:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.6`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.7`,
        fs:  `cpe:2.3:a:microsoft:sna_server:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.8`,
        fs:  `cpe:2.3:a:hp:ignite-ux:c.7.10.472:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.9`,
        fs:  `cpe:2.3:a:codesector:teracopy:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x2go:x2go_server:4.0.1.10`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x3cms:x3_cms:0.4:rc2`,
        fs:  `cpe:2.3:a:fortinet:fortimail:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x3cms:x3_cms:0.4.0.3`,
        fs:  `cpe:2.3:a:google:chrome:6.0.465.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x3cms:x3_cms:0.4.1`,
        fs:  `cpe:2.3:a:sun:jdk:1.5.0:update8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x3cms:x3_cms:0.4.2`,
        fs:  `cpe:2.3:a:sitracker:support_incident_tracker:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x3cms:x3_cms:0.4.2.1`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0b4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x3cms:x3_cms:0.4.3.1`,
        fs:  `cpe:2.3:a:cisco:prime_lan_management_solution:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.0.0b`,
        fs:  `cpe:2.3:a:freedesktop:dbus-glib:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.1.1b`,
        fs:  `cpe:2.3:o:juniper:junos:15.1x53:d21:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.1.2b`,
        fs:  `cpe:2.3:a:splunk:splunk:4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.2.0b`,
        fs:  `cpe:2.3:a:monotone:monotone:0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.3.0b`,
        fs:  `cpe:2.3:a:apple:quicktime:7.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.3.1b`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.1.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.3.2b`,
        fs:  `cpe:2.3:a:apple:safari:1.0.3:85.8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.3.3b`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.3.4b`,
        fs:  `cpe:2.3:a:sympa:sympa:3.3b.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.3.5b`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:1.3.6`,
        fs:  `cpe:2.3:a:openstack:python-keystoneclient:1.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:2.0.0`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:2.98:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:2.0.2`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:2.0.3`,
        fs:  `cpe:2.3:a:netfilter:libmnl:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:2.0.4.4`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7_group:x7_chat:2.0.5.1`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.02:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.0`,
        fs:  `cpe:2.3:a:prosody:prosody:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.0:a1`,
        fs:  `cpe:2.3:a:microsoft:directx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.0:a2`,
        fs:  `cpe:2.3:o:microsoft:windows_xp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.0:a3`,
        fs:  `cpe:2.3:a:latex2rtf_project:latex2rtf:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.0:b1`,
        fs:  `cpe:2.3:a:opera:opera_browser:10.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.0:b2`,
        fs:  `cpe:2.3:a:php:php:5.4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.1:a1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.2`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.3`,
        fs:  `cpe:2.3:a:apache:hadoop:0.23.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.4`,
        fs:  `cpe:2.3:a:nodejs:node.js:7.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.4.1`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:beta6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.4.3`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.4.4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:4.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.5`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.46.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:x7chat:x7_chat:2.0.5.1`,
        fs:  `cpe:2.3:a:x:libxcb:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xangati:xangati_software_release:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.259:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xangati:xangati_software_release:11.0`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xangati:xangati_xnr:-`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xangati:xangati_xnr:7.0`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xaos:space_cinema:2.0.6::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1j\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xaraya:xaraya:2.4.0:b1`,
        fs:  `cpe:2.3:a:marc_lehmann:rxvt-unicode:9.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xavi:x7968:-`,
        fs:  `cpe:2.3:a:flowplayer:flowplayer_flash:3.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xavier_beaudouin:mod_vhs:1.0.30`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.975:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xavoc:xepan_cms:1.0.1`,
        fs:  `cpe:2.3:a:ibm:emptoris_supplier_lifecycle_management:10.0.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xavoc:xepan_cms:1.0.4`,
        fs:  `cpe:2.3:a:cisco:ip_contact_center_enterprise:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xavoc:xepan_cms:1.0.4.1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xbuffy_project:xbuffy:3.3`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xceed:xceed_components:3.2.8312.9580`,
        fs:  `cpe:2.3:a:buffalotech:whr-am54g54_firmware:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xceedium:xsuite:2.3.0`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:6.5.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xceedium:xsuite:2.4.3.0`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.21:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.2.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:2.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.3.9`,
        fs:  `cpe:2.3:a:geodesicsolutions:geocore_max:7.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.3.10`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1.7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.3.11`,
        fs:  `cpe:2.3:a:context_project:context:7.x-3.4:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.3.12`,
        fs:  `cpe:2.3:a:openldap:openldap:2.4.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.3.13`,
        fs:  `cpe:2.3:h:hp:psc_1210_all-in-one:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.4`,
        fs:  `cpe:2.3:a:utorrent:utorrent:1.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.4.1`,
        fs:  `cpe:2.3:a:dataparadigm:acn2go:1.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.4.2`,
        fs:  `cpe:2.3:a:exim:exim:4.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.4.3`,
        fs:  `cpe:2.3:a:microsoft:ie:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.5.6`,
        fs:  `cpe:2.3:a:scilab:scilab:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.0`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.1`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.11:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.2`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110930:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.3`,
        fs:  `cpe:2.3:a:atmail:atmail:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.4`,
        fs:  `cpe:2.3:a:adobe:acrobat_elements:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.5`,
        fs:  `cpe:2.3:a:git_for_windows_project:git_for_windows:1.8.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.6`,
        fs:  `cpe:2.3:a:netiq:appmanager_console:7.0.41018.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.7`,
        fs:  `cpe:2.3:a:opsview:opsview:3.4:-:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.8`,
        fs:  `cpe:2.3:a:sun:secure_global_desktop:3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.8.9`,
        fs:  `cpe:2.3:a:x10media:.x10_automatic_mp3_script:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.0`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.1`,
        fs:  `cpe:2.3:o:ubnt:airvision_firmware:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.2`,
        fs:  `cpe:2.3:a:oracle:database_server_lite:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.3`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.3:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.4`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.5`,
        fs:  `cpe:2.3:a:rockwellautomation:1763-l16awa_series_b:15.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.6`,
        fs:  `cpe:2.3:a:emc:unisphere:1.6:-:*:*:*:vmax:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.7`,
        fs:  `cpe:2.3:a:gnu:patch:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.8`,
        fs:  `cpe:2.3:o:intel:sinit_authenticated_code_module:i5_i7_dual_sinit_51.bin:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:1.9.9`,
        fs:  `cpe:2.3:a:apache:hbase:0.94.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.0`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.1`,
        fs:  `cpe:2.3:a:bmc:remedy_action_request_system_administrator:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.2`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p292:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.3`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.4`,
        fs:  `cpe:2.3:a:checkpoint:endpoint_security:e80.20:-:vpn_blade:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.5`,
        fs:  `cpe:2.3:a:keepass:keepass:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.6`,
        fs:  `cpe:2.3:h:grandstream:gxv3651fhd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.7`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.0.8`,
        fs:  `cpe:2.3:a:keepass:keepass:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.6.7`,
        fs:  `cpe:2.3:o:zyxel:n300_netusb_nbg-419n_firmware:1.00\(bfq_6\)c0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.0`,
        fs:  `cpe:2.3:a:freedesktop:udisks:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.1`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.3`,
        fs:  `cpe:2.3:a:studiohitori:twitrocker2_android:1.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.3:c`,
        fs:  `cpe:2.3:a:dominique_clause:search_autocomplete:7.x-2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.3:e`,
        fs:  `cpe:2.3:a:skype:skype:4.2.0.155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.4`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p163:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.5:b`,
        fs:  `cpe:2.3:h:tp-link:tl-wr841n_\(10.0\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.5:e`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.6`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.7:a`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.7:b`,
        fs:  `cpe:2.3:a:microsoft:pinyin_ime:2010:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.7:c`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.7:d`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.18_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.7:e`,
        fs:  `cpe:2.3:a:soprano:fonecta_verify:7.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.7:f`,
        fs:  `cpe:2.3:a:busybox:busybox:0.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.7b`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.8`,
        fs:  `cpe:2.3:a:ross_burton:libsocialweb:0.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xchat:xchat:2.8.9`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ca:etrust_ez_antivirus:7.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:2.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:e-catchup:basercms:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:2.2.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:typo3:typo3:4.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:bind:9.7.3:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:wellintech:kingview:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:emergency_responder:10.5\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:caucho:resin:3.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:connections:2.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:virusbuster:virusbuster_internet_securit_suite:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.0.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:inotes:8.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:php:php:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.217:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.5::standalone`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.3.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xcloner:xcloner:3.5.1::~~~joomla%21~~`,
        fs:  `cpe:2.3:a:isc:bind:9.6-esv-r5:p1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xda-developers:xda-developers:3.9.8::~~~android~~`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xdelta:xdelta3:3.0.8`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xdforum:xd_forum:3.9.17::~~~android~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xelex:mobiletrack:2.3.7`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.13:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:-`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.0.2`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.120:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.0.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\)n1\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.0.4`,
        fs:  `cpe:2.3:a:php:php:5.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.1.3`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.1.4`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.2.0`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.2.1`,
        fs:  `cpe:2.3:a:intergraph:sales_price_generator:1.4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.2.2`,
        fs:  `cpe:2.3:a:apache:struts:1.1:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.2.3`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:1.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.3.0`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.4.1:offline:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.3.1`,
        fs:  `cpe:2.3:a:apache:struts:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.3.2`,
        fs:  `cpe:2.3:o:cisco:email_security_appliance_firmware:7.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.4.0`,
        fs:  `cpe:2.3:a:cisco:cloud_portal:2008.3:sp8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.4.1`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:9.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.4.2`,
        fs:  `cpe:2.3:a:google:chrome:31.0.1650.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.4.3`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:3.4.4`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.0.0`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.0.1`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p81:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.0.2`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.0.3`,
        fs:  `cpe:2.3:a:invisionpower:invision_power_board:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.0.4`,
        fs:  `cpe:2.3:a:sync:oxygen_xml_editor:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.1.0`,
        fs:  `cpe:2.3:a:emc:eroom:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.1.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5.7.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.1.2`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.1.3`,
        fs:  `cpe:2.3:a:digium:asterisk:11.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.1.4`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.1.5`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:4.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.1.6`,
        fs:  `cpe:2.3:a:glub:secure_ftp:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.1.6.1`,
        fs:  `cpe:2.3:h:nvidia:geforce_940mx:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.2.0`,
        fs:  `cpe:2.3:a:vasthtml:forumpress:1.6.2:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.2.1`,
        fs:  `cpe:2.3:a:rocomotion:p_forum:1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.2.2`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.2.3`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.2.4`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1660.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.2.5`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.3.0`,
        fs:  `cpe:2.3:a:usebb:usebb:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.3.1`,
        fs:  `cpe:2.3:a:isc:inn:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.3.2`,
        fs:  `cpe:2.3:a:apache:camel:2.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.3.3`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.3.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5\)t2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xen:xen:4.4.0`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.26.1:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.4.0`,
        fs:  `cpe:2.3:a:dm_computer_solutions:ultraedit:14.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.4.0:-`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r001c01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.4.0:rc1`,
        fs:  `cpe:2.3:o:huawei:s9303_firmware:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xen:xen:4.4.1`,
        fs:  `cpe:2.3:a:cisco:ucs_director:4.1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.4.1`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xen:xen:4.4.2`,
        fs:  `cpe:2.3:o:netbsd:netbsd:6.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.4.2`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.4.3`,
        fs:  `cpe:2.3:a:ibm:internet_security_systems_blackice_defender:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.4.4`,
        fs:  `cpe:2.3:a:lunascape:lunascape:4.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xen:xen:4.5.0`,
        fs:  `cpe:2.3:a:novell:kanaka:2.8:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.5.0`,
        fs:  `cpe:2.3:a:nokia:groupwise_mobile_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xen:xen:4.5.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.6:beta14:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.5.1`,
        fs:  `cpe:2.3:h:hp:psc_700:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.5.2`,
        fs:  `cpe:2.3:a:invincea:browser_protection:2.3.6596:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.5.3`,
        fs:  `cpe:2.3:h:hp:officejet_d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.5.5`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.13:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.6.0`,
        fs:  `cpe:2.3:h:h3c:sr66_gigabit_firewall_module:0231a88a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.6.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(6\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.6.2`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:12.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.6.4`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:7.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.6.5`,
        fs:  `cpe:2.3:a:freeradius:freeradius:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.7.1`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20110811:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.8.0`,
        fs:  `cpe:2.3:a:jan_engelhardt:libhx:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.8.1`,
        fs:  `cpe:2.3:a:csphere:clansphere:2011.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xen:xen:4.9.0:rc7`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.0.0:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xen_carousel_plugin_project:xen_carousel:0.12.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:redhat:openshift:1.2.3:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:colorqube_8570:-`,
        fs:  `cpe:2.3:a:hp:data_protector:8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:colorqube_9201:-`,
        fs:  `cpe:2.3:a:compaq:insight_manager_xe:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:colorqube_9203:-`,
        fs:  `cpe:2.3:o:grandstream:gxv_device_firmware:1.0.4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:contents_bridge_utility:4.6`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:copycentre_c65:1.001.02.073`,
        fs:  `cpe:2.3:a:digium:asterisk:0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:copycentre_c65:1.001.02.0715`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:copycentre_c75:1.001.02.073`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:copycentre_c75:1.001.02.0715`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:copycentre_c90:1.001.02.073`,
        fs:  `cpe:2.3:a:debian:internet_message:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:copycentre_c90:1.001.02.0715`,
        fs:  `cpe:2.3:a:symantec:automated_support_assistant:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:device_agent:3.8.24`,
        fs:  `cpe:2.3:a:ibm:db2:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:docucolor_4lp:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.31:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_220:-`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.razor.host:1.1.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_230:-`,
        fs:  `cpe:2.3:h:hp:jd672a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_240:-`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_255:-`,
        fs:  `cpe:2.3:o:hp:800_series_firmware:2.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_265:-`,
        fs:  `cpe:2.3:a:ibm:java_sdk:6.0.15.0:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_332:-`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:7.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_340:-`,
        fs:  `cpe:2.3:a:opera:opera_browser:8.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_420:-`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_425:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.15.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_426:-`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_430:-`,
        fs:  `cpe:2.3:a:ibm:hardware_management_console:3.3.0:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_432:-`,
        fs:  `cpe:2.3:a:nlnetlabs:ldns:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_440:-`,
        fs:  `cpe:2.3:o:siemens:simatic_s7_cpu_1200_firmware:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_460:-`,
        fs:  `cpe:2.3:a:microsoft:expression_design:3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_470:-`,
        fs:  `cpe:2.3:a:user_import_project:user_import:6.x-4.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_480:-`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_490:-`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_535:-`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system:3.5.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_545:-`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:document_centre_555:-`,
        fs:  `cpe:2.3:a:ibm:host_on-demand:11.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:docuprint_n40:-`,
        fs:  `cpe:2.3:h:hp:h3c_router:rt-msr3016-ac-ovs-h3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:docushare:6.5.3:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.12:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:docushare:6.5.3:patch6`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:docushare:6.6.1:-`,
        fs:  `cpe:2.3:a:dell:remote_access_configuration_tool:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:docushare:6.6.1:update1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:docushare:6.6.1:update2`,
        fs:  `cpe:2.3:a:apache:struts:2.2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:docutech_6110:-`,
        fs:  `cpe:2.3:a:digia:qt:4.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:docutech_6115:-`,
        fs:  `cpe:2.3:a:phpmanufaktur:kitform:0.26:*:*:*:*:keepintouch:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:freeflow_print_server:8.0`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:freeflow_print_server:8.0:sp1`,
        fs:  `cpe:2.3:a:pakan_ken_tube_project:pakan_ken_tube:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xerox:freeflow_print_server:8.0:sp2`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:phaser_6130n:-`,
        fs:  `cpe:2.3:a:freedesktop:systemd:233:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:phaser_6180mfp:-`,
        fs:  `cpe:2.3:a:opscode:chef:0.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:phaser_7500:-`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7910g\&#43;sw:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:phaser_8560:-`,
        fs:  `cpe:2.3:o:suse:suse_linux_enterprise_desktop:11:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:232`,
        fs:  `cpe:2.3:a:f5:big-ip_webaccelerator:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:238`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:245`,
        fs:  `cpe:2.3:a:isc:bind:9.1.1:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:255`,
        fs:  `cpe:2.3:a:teradata:data_connector:13.10.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:265`,
        fs:  `cpe:2.3:a:python:python:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:275`,
        fs:  `cpe:2.3:a:iss:blackice_agent_server:3.6ecf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:5623`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:5635`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:5645`,
        fs:  `cpe:2.3:a:sybase:powerdesigner:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:5655`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:5665`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:5675`,
        fs:  `cpe:2.3:a:miniupnp_project:miniupnpd:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:5685`,
        fs:  `cpe:2.3:a:novell:groupwise:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:7655`,
        fs:  `cpe:2.3:a:livetecs:timeline:4.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:7665`,
        fs:  `cpe:2.3:a:artifex:afpl_ghostscript:8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:7675`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:5.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:m123`,
        fs:  `cpe:2.3:a:microsoft:jet:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:m123:unknown:pro`,
        fs:  `cpe:2.3:a:bit51:better-wp-security:-:alpha11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:m128`,
        fs:  `cpe:2.3:a:microsoft:ie:6.00.3790.3959:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:m128:unknown:pro`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:m133`,
        fs:  `cpe:2.3:a:solarwinds:network_configuration_manager:7.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre:m133:unknown:pro`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:12.20a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_232:-`,
        fs:  `cpe:2.3:a:docker:docker:1.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_238:-`,
        fs:  `cpe:2.3:a:pedro_castro:gnome-subtitles:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_245:-`,
        fs:  `cpe:2.3:a:gridgain:gridgain:1.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_255:-`,
        fs:  `cpe:2.3:a:apache:open_for_business_project:10.04.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_265:-`,
        fs:  `cpe:2.3:a:bea:weblogic_server:8.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_275:-`,
        fs:  `cpe:2.3:a:vmware:tools:3.1.2.14664:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_32_color:01.00.060`,
        fs:  `cpe:2.3:a:argyllcms:argyllcms:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_32_color:01.02.053.1`,
        fs:  `cpe:2.3:a:lxml:lxml:3.3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_32_color:01.02.058.4`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.3.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_32_color:01.02.077.1`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.06.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_3325:-`,
        fs:  `cpe:2.3:a:udesign_project:udesign:2.4.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_40_color:01.00.060`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_40_color:01.02.053.1`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_40_color:01.02.058.4`,
        fs:  `cpe:2.3:a:nobexrc:house365_radio:3.2.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_40_color:01.02.65.1`,
        fs:  `cpe:2.3:a:george_karpouzas:yet_another_question_\&amp;_answer_system:1.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_40_color:01.02.077.1`,
        fs:  `cpe:2.3:a:zemanta:related_posts:1.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_5135:-`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_5150:-`,
        fs:  `cpe:2.3:a:preemptive_solutions:dotfuscator:5.0.2500.0:*:*:*:community_edition:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_5655:-`,
        fs:  `cpe:2.3:a:roxio:creator_content:2012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_5755:-`,
        fs:  `cpe:2.3:a:kde:ark:2.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_5855:-`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:17.0.8.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_7225:-`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sp6:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_7556:-`,
        fs:  `cpe:2.3:h:sophos:unified_threat_management:220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m165:-`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.1\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m165:6.47.30.000`,
        fs:  `cpe:2.3:a:shopware:shopware:5.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m165:6.47.33.008`,
        fs:  `cpe:2.3:h:polycom:viavideo:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m165:8.47.30.000`,
        fs:  `cpe:2.3:a:janetter:janetter:2.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m165:8.47.33.008`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m175:-`,
        fs:  `cpe:2.3:a:websense:triton_web_filter:7.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m175:6.47.30.000`,
        fs:  `cpe:2.3:a:shibboleth:shibboleth-sp:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m175:6.47.33.008`,
        fs:  `cpe:2.3:a:microsoft:jet:4.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m175:8.47.30.000`,
        fs:  `cpe:2.3:a:sybase:easerver:4.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m175:8.47.33.008`,
        fs:  `cpe:2.3:a:eric_m_ludlam:cedet:1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m35:-`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m35:2.28.11.000`,
        fs:  `cpe:2.3:a:civicrm:civicrm:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m35:2.97.20.032`,
        fs:  `cpe:2.3:h:hp:jd666a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m35:4.84.16.000`,
        fs:  `cpe:2.3:a:foxitsoftware:foxit_pdf_sdk_activex:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m35:4.97.20.025`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m35:4.97.20.032`,
        fs:  `cpe:2.3:a:creative_core:app_lock:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m45:-`,
        fs:  `cpe:2.3:a:trexart:campaignmonitor:6.x-2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m45:2.28.11.000`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m45:2.97.20.032`,
        fs:  `cpe:2.3:a:juniper:installer_service:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m45:4.84.16.000`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m45:4.97.20.025`,
        fs:  `cpe:2.3:a:osirix-viewer:osirix:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m45:4.97.20.032`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m55:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.2srd:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m55:2.28.11.000`,
        fs:  `cpe:2.3:a:ssh:tectia_connector:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m55:2.97.20.032`,
        fs:  `cpe:2.3:a:novell:iprint:5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m55:4.84.16.000`,
        fs:  `cpe:2.3:o:yamaha:rt56v:4.07.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m55:4.97.20.025`,
        fs:  `cpe:2.3:a:catapultsoftware:catapult_dnp3_i\/o_driver:7.2.0.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_m55:4.97.20.032`,
        fs:  `cpe:2.3:a:novell:edirectory:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro:232`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.68:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro:238`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:2.1.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro:245`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro:255`,
        fs:  `cpe:2.3:h:selinc:sel-2241:r113-v0-z001001-d20110721:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro:265`,
        fs:  `cpe:2.3:a:adobe:bridge:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro:275`,
        fs:  `cpe:2.3:a:siemens:simatic_pcs7:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro_35:-`,
        fs:  `cpe:2.3:a:php:php_script_index:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro_55:-`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xerox:workcentre_pro_65:-`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.76:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:x11perf:1.5`,
        fs:  `cpe:2.3:a:monotone:monotone:0.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:x11perf:1.5.1`,
        fs:  `cpe:2.3:a:elasticsearch:logstash:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:x11perf:1.5.2`,
        fs:  `cpe:2.3:o:cisco:unified_wireless_ip_phone_7920_firmware:1.0\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:x11perf:1.5.3`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:x11perf:1.5.4`,
        fs:  `cpe:2.3:a:ibm:java:6.0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:3.3.2`,
        fs:  `cpe:2.3:h:hp:procurve_switch:658247-b21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:3.3.3`,
        fs:  `cpe:2.3:a:lucent:vitalnet:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:3.3.3.1`,
        fs:  `cpe:2.3:a:google:chrome:26.0.1410.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:3.3.4`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:3.3.5`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:3.3.6`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.0.0`,
        fs:  `cpe:2.3:a:ibm:urbancode_deploy:6.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.0.1`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.0.2`,
        fs:  `cpe:2.3:a:cisco:firesight_system_software:5.3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.0.3`,
        fs:  `cpe:2.3:a:activedev:active_cms:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.1.0`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.2.0`,
        fs:  `cpe:2.3:a:ibm:smartcloud_control_desk:7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.2.1`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.3.0`,
        fs:  `cpe:2.3:a:adobe:version_cue:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.5.0`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.6.0`,
        fs:  `cpe:2.3:a:atlassian:confluence:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xfree86:xfree86:4.7.0`,
        fs:  `cpe:2.3:a:google:chrome:16.0.896.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.5.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:debian:bsdmainutils:6.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.5.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:supmua:sup:0.13.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.9.5-37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:nisuta:ns-wir300n_firmware:5.07.36_nis01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.2:pre16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.5::~~~wordpress~~`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.6::~~~wordpress~~`,
        fs:  `cpe:2.3:h:nortel:wlan_handset_2212:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:debian:dpkg:1.17.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.6.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:emergency_responder:10.5\(3.10000.9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.7.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:videoscape_distribution_suite_for_internet_streaming:2.6\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisofy:lynis:1.5.1:*:*:*:*:aix:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mautic:mautic:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.7.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.7.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:opennms:opennms:1.10.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.7.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:protected_pages_project:protected_pages:7.x-2.2:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:xhanch:my_twitter:2.7.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:netscape:directory_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xiaowen_huang:yingzhi_python_programming_language:1.9::~~~iphone_os~~`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:-`,
        fs:  `cpe:2.3:h:ge:intelligent_platforms_proficy_process_systems:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.5`,
        fs:  `cpe:2.3:a:recruit:dokodemo_rikunabi_2013:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.6`,
        fs:  `cpe:2.3:a:genetechsolutions:pie-register:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.7`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.0.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.8`,
        fs:  `cpe:2.3:o:nec:asl_ux_4800:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.10`,
        fs:  `cpe:2.3:a:divx:player:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.11`,
        fs:  `cpe:2.3:a:oracle:financial_services_software:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.12`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.13`,
        fs:  `cpe:2.3:a:redhat:freeipa:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.14`,
        fs:  `cpe:2.3:a:progress:webspeed_messenger:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinetd:xinetd:2.3.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.0ev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xinhua-news:xinhua_international:5.5.0::~~~android~~`,
        fs:  `cpe:2.3:a:pkware:pkzip_for_windows:9.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xiph:icecast:2.4.1`,
        fs:  `cpe:2.3:a:thoughtbot:cocaine:0.3.1:-:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:xiph:vorbis-tools:1.4.0`,
        fs:  `cpe:2.3:a:lunascape:lunascape:3.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xixun:xixuntiantian:0.6.2:beta`,
        fs:  `cpe:2.3:a:altiris:connector_for_veritas_configuration_manager:6.0.1039:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xlabz:sketch_w_friends_free_-tablets:5.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:wordpress:wordpress:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xml-dt_project:xml-dt:0.60`,
        fs:  `cpe:2.3:h:zyxel:p-660h-63:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xml-dt_project:xml-dt:0.61`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xml-dt_project:xml-dt:0.62`,
        fs:  `cpe:2.3:h:cisco:c240_m3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xml-dt_project:xml-dt:0.63`,
        fs:  `cpe:2.3:a:git-scm:git:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xml-libxml_project:xml-libxml:2.0118`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:-`,
        fs:  `cpe:2.3:a:cisco:mobility_services_engine:7.6.132.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.7.0`,
        fs:  `cpe:2.3:a:afro-beat_project:afro-beat:0.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.7.1`,
        fs:  `cpe:2.3:a:isc:bind:9.7.6:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.7.2`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.7.3`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.7.4`,
        fs:  `cpe:2.3:a:adobe:adobe_update_manager_core:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.0`,
        fs:  `cpe:2.3:a:psecu:psecu_mobile\&#43;:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.1`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.3`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.4`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.5`,
        fs:  `cpe:2.3:a:memcache_project:memcache:5.x-1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.6`,
        fs:  `cpe:2.3:a:nginx:nginx:1.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.7`,
        fs:  `cpe:2.3:a:redmine:redmine:0.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.9`,
        fs:  `cpe:2.3:a:9gag:9gag_-_funny_pics_and_videos:2.4.10:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.10`,
        fs:  `cpe:2.3:h:cisco:ace_4700_series_application_control_engine_appliance_a3:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.14`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(10g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:1.8.16`,
        fs:  `cpe:2.3:a:nginx:nginx:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.0.0`,
        fs:  `cpe:2.3:a:altiris:report_pack_for_software_delivery_solution:6.1.1101:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.1.0`,
        fs:  `cpe:2.3:a:microsoft:office:2007:sp1:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.1.1`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:2.30.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.0`,
        fs:  `cpe:2.3:a:js-yaml_project:js-yaml:0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.0:beta`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5.29.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.1`,
        fs:  `cpe:2.3:o:cisco:universal_small_cell_firmware:r3.4_2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.2`,
        fs:  `cpe:2.3:a:cubettechnologies:cloud_manager:1.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.3`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.4`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.5`,
        fs:  `cpe:2.3:a:devsaran:clean_theme:7.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.6`,
        fs:  `cpe:2.3:a:citrix:presentation_server_client:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.8`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.9`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.18.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.10`,
        fs:  `cpe:2.3:a:yokogawa:centum_vp:r5.03.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.2.11`,
        fs:  `cpe:2.3:a:apache:mod_perl:1.99:16:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.0`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.1`,
        fs:  `cpe:2.3:a:cisco:vpn_client:5.0.06.0160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.2`,
        fs:  `cpe:2.3:a:debian:phpbb3:3.0.0-rc4-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.3`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.4`,
        fs:  `cpe:2.3:a:systemtools:hyena:6.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.5`,
        fs:  `cpe:2.3:a:gnome:glib:2.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.6`,
        fs:  `cpe:2.3:a:mariadb:mariadb:5.5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.7`,
        fs:  `cpe:2.3:o:univention:univention_corporate_server:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.8`,
        fs:  `cpe:2.3:a:splunk:splunk:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.9`,
        fs:  `cpe:2.3:a:syntevo:smartsvn:4.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.10`,
        fs:  `cpe:2.3:h:huawei:s3900:r6305:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.11`,
        fs:  `cpe:2.3:a:tenable:nessus:6.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.12`,
        fs:  `cpe:2.3:a:7-zip:7-zip:4.45:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.13`,
        fs:  `cpe:2.3:a:oracle:weblogic_server:12.2.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.3.14`,
        fs:  `cpe:2.3:a:hp:icewall_java_agent_library:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.1`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.2`,
        fs:  `cpe:2.3:a:ibm:web_content_manager:7.0.0.1:cf003:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.3`,
        fs:  `cpe:2.3:a:ibm:cognos_analytics:11.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.4`,
        fs:  `cpe:2.3:a:fortinet:forticlient_lite:4.3.3.445:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.5`,
        fs:  `cpe:2.3:a:sun:storedge_enterprise_backup_software:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.6`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.7`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.8`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.7-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.9`,
        fs:  `cpe:2.3:a:sun:one_administration_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.10`,
        fs:  `cpe:2.3:a:mutiny:standard:4.5-1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.11`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r6a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.12`,
        fs:  `cpe:2.3:h:cisco:catalyst_3500_xl:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.13`,
        fs:  `cpe:2.3:o:emc:isilon_onefs:7.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.14`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l23x_controller_firmware:16.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.15`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.16`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1.111.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.17`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.6:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.18`,
        fs:  `cpe:2.3:a:piwik:piwik:0.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.19`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.12.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.20`,
        fs:  `cpe:2.3:a:cisco:netflow_collection_engine:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.21`,
        fs:  `cpe:2.3:a:cloudfoundry:capi-release:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.22`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.23`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.24`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.25`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.26`,
        fs:  `cpe:2.3:a:vwar:virtual_war:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.27`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.28`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.29`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.4.30`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(3.210\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.5.0`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.5.4`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.5.7`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.5.8`,
        fs:  `cpe:2.3:a:gnome:update-manager-core:0.156.14.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.5.10`,
        fs:  `cpe:2.3:a:hostbillapp:hostbill:06-11-2013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.5.11`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.0`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.7.2p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.1`,
        fs:  `cpe:2.3:a:mcafee:spamkiller:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.2`,
        fs:  `cpe:2.3:a:eset:personal_firewall_ndis_filter:1183_\(20140214\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.3`,
        fs:  `cpe:2.3:a:iss:realsecure_guard:3.6:ebu:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.4`,
        fs:  `cpe:2.3:a:emc:networker:7.5.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.5`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.6`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.1118.1259.23275:*:*:ru:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.7`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:1.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.8`,
        fs:  `cpe:2.3:a:privoxy:privoxy:3.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.9`,
        fs:  `cpe:2.3:a:citrix:program_neighborhood_client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.11`,
        fs:  `cpe:2.3:a:virt-who_project:virt-who:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.12`,
        fs:  `cpe:2.3:a:hp:onboard_administrator:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.13`,
        fs:  `cpe:2.3:h:lucent:brick_80_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.14`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.16`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.3.3.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.17`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.18`,
        fs:  `cpe:2.3:a:dell:client_configuration_toolkit:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.20`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:6:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.21`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l27erm-qbfc1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.22`,
        fs:  `cpe:2.3:a:citrix:xenapp_administration:4.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.23`,
        fs:  `cpe:2.3:a:djangoproject:django:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.24`,
        fs:  `cpe:2.3:a:apphp:hotel_site:3.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.25`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.22.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.26`,
        fs:  `cpe:2.3:a:fenrir-inc:sleipnir_mobile:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.27`,
        fs:  `cpe:2.3:a:3com:3cserver:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.28`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.29`,
        fs:  `cpe:2.3:a:rockmongo:rockmongo:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.30`,
        fs:  `cpe:2.3:a:ibm:tivoli_base_services:1.0.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.31`,
        fs:  `cpe:2.3:a:bestpractical:rt-extension-mobileui:1.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.6.32`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.0`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.98.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.1`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1036.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.2`,
        fs:  `cpe:2.3:a:apache:apache-ssl:1.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.3`,
        fs:  `cpe:2.3:a:canon:imagerunner:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.4`,
        fs:  `cpe:2.3:a:oracle:weblogic_portal:8.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.5`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.5.1025:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.6`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.7`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.134:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.7.8`,
        fs:  `cpe:2.3:a:cisco:fog_director:1.0\(0\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.8.0`,
        fs:  `cpe:2.3:a:percipientstudios:imagen:2.5.5:-:*:*:*:umbraco_cms:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.9.0`,
        fs:  `cpe:2.3:o:juniper:unified_access_control_software:4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.9.0:rc1`,
        fs:  `cpe:2.3:a:jruby:jruby:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.9.1`,
        fs:  `cpe:2.3:a:invensys:wonderware_information_server:4.0:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.9.2`,
        fs:  `cpe:2.3:a:hp:insight_management_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxml2:2.9.3`,
        fs:  `cpe:2.3:o:3com:tippingpoint_ips_tos:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.0.1`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:6.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.1.0`,
        fs:  `cpe:2.3:o:yamaha:rt100i:3.00.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.2.0`,
        fs:  `cpe:2.3:o:microsoft:windows_2000:-:gold:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.3.0`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.4.0`,
        fs:  `cpe:2.3:a:jeff_kreitner:hms-testimonials:2.0.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.5.0`,
        fs:  `cpe:2.3:o:cisco:ios:15.2\(5b\)e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.6.0`,
        fs:  `cpe:2.3:a:bestpractical:request_tracker:3.8.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.7.0`,
        fs:  `cpe:2.3:a:digium:asterisk:11.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.8.0`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.6.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.9.0`,
        fs:  `cpe:2.3:a:exactcode:exactimage:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.10.0`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.11.0`,
        fs:  `cpe:2.3:h:huawei:campus_s3300hi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.12.0`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.596:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.13.0`,
        fs:  `cpe:2.3:a:apple:safari:6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:0.14.0`,
        fs:  `cpe:2.3:a:soprano:fonecta_verify:7.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.0`,
        fs:  `cpe:2.3:h:lexmark:x26x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.1`,
        fs:  `cpe:2.3:o:trendnet:tew-812dru_firmware:1.0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.3`,
        fs:  `cpe:2.3:a:microsoft:ie:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.4`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.5`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.6`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.4.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.7`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.8`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p173:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.9`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.13.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.10`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.11`,
        fs:  `cpe:2.3:a:boost:boost:1.34.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.12`,
        fs:  `cpe:2.3:a:apache:subversion:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.13`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.14`,
        fs:  `cpe:2.3:a:ibm:sterling_selling_and_fulfillment_foundation:9.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.15`,
        fs:  `cpe:2.3:h:moxa:iologic_e2260-t:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.16`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.17`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.18`,
        fs:  `cpe:2.3:a:jenkins:git:2.3.0:beta-2:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.19`,
        fs:  `cpe:2.3:a:cisco:webns:8.10.4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.20`,
        fs:  `cpe:2.3:a:cisco:ace_application_control_engine_module_a5:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.21`,
        fs:  `cpe:2.3:a:bundler:bundler:1.1:pre:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.22`,
        fs:  `cpe:2.3:a:hp:nonstop_netbatch:j06.13.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.23`,
        fs:  `cpe:2.3:a:apache:qpid:0.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.24`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.26.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.25`,
        fs:  `cpe:2.3:a:mark_pilgrim:feedparser:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.26`,
        fs:  `cpe:2.3:a:ca:license_software:1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.27`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:6:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.28`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.43:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.29`,
        fs:  `cpe:2.3:a:seebeyond:seebeyond_editors:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.30`,
        fs:  `cpe:2.3:h:hp:0235a268:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.31`,
        fs:  `cpe:2.3:h:kddi:home_spot_cube:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.32`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.0.33`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:13.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.0`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.1`,
        fs:  `cpe:2.3:a:cisco:meeting_app:1.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.2`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.3`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.7c:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.4`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.60.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.5`,
        fs:  `cpe:2.3:a:citrix:xendesktop:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.6`,
        fs:  `cpe:2.3:a:ibm:dashdb_local:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.7`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.8`,
        fs:  `cpe:2.3:a:projectsend:projectsend:561:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.9`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.10`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics:7.8.0-159:unknown:online_linux:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.11`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.12`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.20:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.13`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.14`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.16`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.17`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.18`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:3.2.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.19`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1056.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.20`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.21`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.22`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.241:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.23`,
        fs:  `cpe:2.3:a:kbd-project:kbd:1.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.24`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:581:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.25`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(4\)db:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.26`,
        fs:  `cpe:2.3:a:piwigo:piwigo:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.27`,
        fs:  `cpe:2.3:a:google:mod_pagespeed:0.9.18.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlsoft:libxslt:1.1.28`,
        fs:  `cpe:2.3:a:ibm:websphere_commerce:8.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmlswf:com_picsell:1.0`,
        fs:  `cpe:2.3:o:rockwellautomation:controllogix_5560_redundant_controller_firmware:20.055:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xmltooling_project:xmltooling:1.5.4`,
        fs:  `cpe:2.3:a:oracle:e-business_suite:11.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tag1consulting:support:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:luracast:restler:1.6.2:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.25.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:vpn_client:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:mnogosearch:mnogosearch:3.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:vmware:horizon_view:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.15.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnau:participants_database:1.5.4.9::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:catos:2.1\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnotestopwatch:xnote_stopwatch:1.60`,
        fs:  `cpe:2.3:a:openafs:openafs:1.5.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.0:a`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.01`,
        fs:  `cpe:2.3:o:ibm:advanced_management_module_firmware:3.64:bpeo64c:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.02`,
        fs:  `cpe:2.3:a:microsoft:ie:5.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.03`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.04`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.05`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.05:b`,
        fs:  `cpe:2.3:a:apple:itunes:12.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.05:c`,
        fs:  `cpe:2.3:h:rockwellautomation:compactlogix_1769-l24er-qb1b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.06`,
        fs:  `cpe:2.3:a:analogx:proxy:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.07`,
        fs:  `cpe:2.3:a:mike_carr:flogr:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.08`,
        fs:  `cpe:2.3:a:jamroom:search_module:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.09`,
        fs:  `cpe:2.3:a:merethis:centreon:1.4.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.10`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:6.7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.11`,
        fs:  `cpe:2.3:a:teradata:index_wizard:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.12`,
        fs:  `cpe:2.3:a:perl:perl:2.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.13`,
        fs:  `cpe:2.3:a:bandisoft:bandizip:3.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.14`,
        fs:  `cpe:2.3:a:mawashimono:nikki:6.62:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.15`,
        fs:  `cpe:2.3:a:tryton:tryton:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.16`,
        fs:  `cpe:2.3:a:altiris:monitor_agent_for_windows:6.0.1341:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.17`,
        fs:  `cpe:2.3:a:digium:asterisk:10.2.0:rc2:digiumphones:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.17:a`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.023.20070:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.18`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:4.4.1.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.18.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.1.10:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.19`,
        fs:  `cpe:2.3:a:internet-works:nus_newssystem:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.20`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:4:update4:es:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.21`,
        fs:  `cpe:2.3:o:cisco:ios:12.2yl:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.22`,
        fs:  `cpe:2.3:a:ibm:san_volume_controller_software:6.4.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.23`,
        fs:  `cpe:2.3:a:thecartpress:thecartpress:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.24`,
        fs:  `cpe:2.3:a:ca:etrust_security_command_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.25`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.67:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.25:a`,
        fs:  `cpe:2.3:a:iconics:genesis32:9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.30`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:31.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.31`,
        fs:  `cpe:2.3:o:juniper:junose_t:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.32`,
        fs:  `cpe:2.3:a:google:chrome:13.0.757.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.33`,
        fs:  `cpe:2.3:a:oracle:virtualization_secure_global_desktop:4.71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.34`,
        fs:  `cpe:2.3:a:openswan:openswan:2.5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.35`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4\(3p\)5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.36`,
        fs:  `cpe:2.3:a:redhat:resteasy:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.37`,
        fs:  `cpe:2.3:a:monotone:monotone:0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.40`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.41`,
        fs:  `cpe:2.3:a:typoheads:formhandler:0.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.45`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.1d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.46`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.50`,
        fs:  `cpe:2.3:o:asus:rt-n56u_firmware:1.0.1.8l:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.50.1`,
        fs:  `cpe:2.3:a:isc:bind:9.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.55`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.16.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.60`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.61`,
        fs:  `cpe:2.3:a:apache:roller:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.65`,
        fs:  `cpe:2.3:a:gnu:libmicrohttpd:0.9.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.66`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.67`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.68`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.4.4:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.68.1`,
        fs:  `cpe:2.3:a:iata:airlines_international:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.70`,
        fs:  `cpe:2.3:a:mediafront:mediafront:7.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.70.2`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.70.3`,
        fs:  `cpe:2.3:a:sgi:performance_co-pilot:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.70.4`,
        fs:  `cpe:2.3:a:oracle:customer_intelligence:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.74`,
        fs:  `cpe:2.3:h:hp:procurve_switch_5400zl:k.11.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.80`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.80.1`,
        fs:  `cpe:2.3:o:microsoft:windows_98se:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.80.2`,
        fs:  `cpe:2.3:a:libraw:libraw:0.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.80.3`,
        fs:  `cpe:2.3:a:ibm:db2:10.5.0.2:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.82`,
        fs:  `cpe:2.3:a:citrix:delivery_client:11.0.0.5284:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.82.2`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1_firewall-1_next_generation:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.82.3`,
        fs:  `cpe:2.3:a:context_project:context:7.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.82.4`,
        fs:  `cpe:2.3:a:cagintranetworks:getsimple_cms:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.90`,
        fs:  `cpe:2.3:a:mime_mail_module_project:mimemail:6.x-1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.90.1`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.90.3`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.91`,
        fs:  `cpe:2.3:a:alawar:motor_town\:_machine_soul_free:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.91.1`,
        fs:  `cpe:2.3:a:ibm:websphere_real_time:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.91.2`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.91.3`,
        fs:  `cpe:2.3:a:withhive:homerun_battle_2:1.2.2.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.91.4`,
        fs:  `cpe:2.3:a:hp:insight_control_performance_management:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.91.5`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.91.6`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.92`,
        fs:  `cpe:2.3:a:apache:juddi:2.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.92.1`,
        fs:  `cpe:2.3:a:bouncycastle:legion-of-the-bouncy-castle-c\#-cryptography-api:1.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.93`,
        fs:  `cpe:2.3:a:atlassian:fisheye:2.7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.93.1`,
        fs:  `cpe:2.3:a:bpvn:pipeboost:2.4.256:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.93.2`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.0.18:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.93.3`,
        fs:  `cpe:2.3:a:vmware:vcenter_server:6.0:2m:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.93.4`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.93.6`,
        fs:  `cpe:2.3:a:php:php:5.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.94`,
        fs:  `cpe:2.3:h:lexmark:cs820dtfe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.94.1`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.94.2`,
        fs:  `cpe:2.3:a:hp:mercury_quality_center:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.95`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.6.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.95.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.4.11:pre3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.95.2`,
        fs:  `cpe:2.3:a:puppetlabs:puppet_dashboard:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.95.3`,
        fs:  `cpe:2.3:a:fontforge_project:fontforge:20161001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.95.4`,
        fs:  `cpe:2.3:a:wp-plugins:wp-print:2.51:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.96`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.3.5:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.96.1`,
        fs:  `cpe:2.3:a:kde:ark:2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.96.2`,
        fs:  `cpe:2.3:a:x.org:xorg-server:1.13.0.902:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.96.5`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97.2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.316:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97.3`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97.4`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97.5`,
        fs:  `cpe:2.3:a:samba:samba:4.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97.6`,
        fs:  `cpe:2.3:a:ibm:db2:10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97.7`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.7.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.97.8`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98`,
        fs:  `cpe:2.3:a:att:communication_manager:6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98.1`,
        fs:  `cpe:2.3:a:phpalbum:phpalbum:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98.2`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration:11.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98.3`,
        fs:  `cpe:2.3:a:huawei:espace_7950:v200r002c00spc300:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98.4`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98.5`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.154:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98.6`,
        fs:  `cpe:2.3:a:cisco:network_assistant:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98.7`,
        fs:  `cpe:2.3:a:liftweb:lift:2.5:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.98.8`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.99`,
        fs:  `cpe:2.3:a:cisco:webns:7.50.1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:1.99.1`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:r.11.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:2.00`,
        fs:  `cpe:2.3:h:cisco:nexus_7000_18-slot:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:2.03`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:2.10`,
        fs:  `cpe:2.3:a:koha:koha:3.16.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:2.11`,
        fs:  `cpe:2.3:a:google:chrome:8.0.551.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:2.12`,
        fs:  `cpe:2.3:o:cisco:nx-os:5.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:2.13`,
        fs:  `cpe:2.3:o:rockwellautomation:softlogic:19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xnview:xnview:2.40`,
        fs:  `cpe:2.3:a:endian:firewall:2.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xoops:glossaire_module:1.0::~~~xoops~~`,
        fs:  `cpe:2.3:a:scriptlogic:active_administrator_console:5.0.322.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xoops:xoops:2.5.6:final`,
        fs:  `cpe:2.3:a:isc:bind:9.3.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xoops:xoops:2.5.7:final`,
        fs:  `cpe:2.3:a:eliteladders:elite_gaming_ladders:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xoops:xoops:2.5.7.2`,
        fs:  `cpe:2.3:a:serv-u:serv-u:9.2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xoops:xoops:2.5.7.3`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.203:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xoops:xoops:2.5.8.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xornic:contact_us:1.0`,
        fs:  `cpe:2.3:a:cisco:telepresence_mcu_4500_series_software:4.1\(1.59\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xrdp:xrdp:0.8.0`,
        fs:  `cpe:2.3:a:qemu:qemu:0.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xrms_crm_project:xrms_crm:1.99.2`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xscreensaver_project:xscreensaver:5.33`,
        fs:  `cpe:2.3:a:topdesk:topdesk:6.07.022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xtendcu:xtendcu_mobile:1.0.28::~~~android~~`,
        fs:  `cpe:2.3:a:hp:smart_array_sas\/sata_event_notification_service:6.0.0.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.0`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.0.1`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.0.2`,
        fs:  `cpe:2.3:a:freedesktop:poppler:0.16.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.0.3`,
        fs:  `cpe:2.3:a:adobe:camera_raw:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.0.4`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.1.0`,
        fs:  `cpe:2.3:a:gnu:gnump3d:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.1.1`,
        fs:  `cpe:2.3:a:google:chrome:15.0.863.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.1.2`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.1.2:p1`,
        fs:  `cpe:2.3:a:webmaster-source:wp125:1.1.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.1.2:p2`,
        fs:  `cpe:2.3:o:huawei:s5300_firmware:v100r006c03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.2:alfa`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.7.84.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.2:beta20060605`,
        fs:  `cpe:2.3:a:netcreators:irfaq:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.2:rc20060712`,
        fs:  `cpe:2.3:a:mysql:mysql:3.23.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.2.0`,
        fs:  `cpe:2.3:a:ibm:websphere_portal:7.0.0.2:cf016:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.2.2`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.1.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.2.2:rc1`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.2.3`,
        fs:  `cpe:2.3:a:google:chrome:16.0.891.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.2.3:rc1`,
        fs:  `cpe:2.3:o:lexmark:printer_firmware:atl.02.048:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.0`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_35:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.0:beta1`,
        fs:  `cpe:2.3:a:microsoft:sql_srv:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.0:beta2`,
        fs:  `cpe:2.3:o:cisco:nx-os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.0:beta3`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:528:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.0:rc1`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.1`,
        fs:  `cpe:2.3:a:rockwellautomation:1763-l16bwa_series_b:15.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.3`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.4.15.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.4`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.5`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:4.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.6`,
        fs:  `cpe:2.3:a:bannersky:bsk_pdf_manager:1.3.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.7`,
        fs:  `cpe:2.3:a:rack_project:rack:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.8`,
        fs:  `cpe:2.3:a:puppetlabs:puppet:2.7.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.9`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.10`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.37.387:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.11`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.5\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.12`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.13`,
        fs:  `cpe:2.3:a:libpng:libpng:0.99e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.14`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.15`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a5\(1.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.16`,
        fs:  `cpe:2.3:a:samba:samba:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.17`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.18`,
        fs:  `cpe:2.3:a:mahara:mahara:1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.19`,
        fs:  `cpe:2.3:a:hp:scanjet_8200c_firmware:1.06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.19:rc1`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.20`,
        fs:  `cpe:2.3:o:freenas:freenas:0.69:-:i386:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.21`,
        fs:  `cpe:2.3:a:gnupg:gnupg:1.9.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.22`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.23`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:600:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xymon:xymon:4.3.24`,
        fs:  `cpe:2.3:a:david_paleino:wicd:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xyplex:maxserver_1620_terminal_server:-`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xyplex:maxserver_1640_terminal_server:-`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xyplex:maxserver_xyplex_terminal_server:-`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.11.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:axigen:axigen_mail_server:8.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.0.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cubecart:cubecart:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.0.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:ilearning:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.1.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.2.2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.40.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.2.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:emc:documentum_eroom:7.4.4:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.2.2:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:h:advantech:eki-1361:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.2.3:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.2.4:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:moodle:moodle:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.2.5:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:storwize_v7000_software:6.2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:xyzscripts:newsletter_manager:1.2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:xzeres:442sr:-`,
        fs:  `cpe:2.3:a:idevspot:phplinkexchange:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:xzeres:442sr_os:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycb001:-`,
        fs:  `cpe:2.3:a:moodle:moodle:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycb001_firmware:4.30`,
        fs:  `cpe:2.3:a:serv-u:serv-u:6.4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycb002:-`,
        fs:  `cpe:2.3:h:oracle:sparc_t3-2:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycb002_firmware:4.30`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:2.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycb003:-`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycb003_firmware:4.30`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.1:rc9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycb004:-`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.335:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycb004_firmware:4.30`,
        fs:  `cpe:2.3:a:isc:bind:9.3.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycbl03:-`,
        fs:  `cpe:2.3:a:oracle:industry_applications:10.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycbl03_firmware:4.30`,
        fs:  `cpe:2.3:a:tollgrade:smartgrid_lighthouse_sensor_management_system:4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycblb3:-`,
        fs:  `cpe:2.3:a:monkey-project:monkey_http_daemon:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycblb3_firmware:4.30`,
        fs:  `cpe:2.3:a:lexmark:markvision:4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycblhd5:-`,
        fs:  `cpe:2.3:a:libmms_project:libmms:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycblhd5_firmware:4.30`,
        fs:  `cpe:2.3:a:fork-cms:fork_cms:2.6.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:yceb03:-`,
        fs:  `cpe:2.3:a:gnome:glib:2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:yceb03_firmware:4.30`,
        fs:  `cpe:2.3:a:microsoft:sql_server:2005:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:yck002:-`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:yck002_firmware:4.30`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:yck003:-`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:yck003_firmware:4.30`,
        fs:  `cpe:2.3:a:squid-cache:squid:4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:yck004:-`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:yck004_firmware:4.30`,
        fs:  `cpe:2.3:h:cisco:as5350:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycw001:-`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycw001_firmware:4.30`,
        fs:  `cpe:2.3:a:apache:jackrabbit:2.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycw002:-`,
        fs:  `cpe:2.3:a:icinga:icinga:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycw002_firmware:4.30`,
        fs:  `cpe:2.3:a:thekelleys:dnsmasq:2.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycw003:-`,
        fs:  `cpe:2.3:a:cisco:jabber:9.1:-:-:*:-:windows:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycw003_firmware:4.30`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:y-cam:ycw004:-`,
        fs:  `cpe:2.3:a:hp:laserjet_toolbox:1.0.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:y-cam:ycw004_firmware:4.30`,
        fs:  `cpe:2.3:a:f5:big-ip_link_controller:11.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.02.05`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.02.08`,
        fs:  `cpe:2.3:a:microsoft:outlook:2013:-:-:*:-:-:x86:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.02.16`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.11.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.03.08`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.12:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.03.12`,
        fs:  `cpe:2.3:a:david_king:vino:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.03.15`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.03.24`,
        fs:  `cpe:2.3:a:emc:avamar:5.0.4-26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.03.25`,
        fs:  `cpe:2.3:a:apache:mod_python:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.03.30`,
        fs:  `cpe:2.3:a:google:chrome:17.0.941.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.04.03`,
        fs:  `cpe:2.3:h:cisco:voip_phone_cp-7940:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.04.06`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:5.2\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.04.09`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:4.0.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.05.05`,
        fs:  `cpe:2.3:a:roxio:creator_tools:3.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.05.07`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.05.09`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.2.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.05.10`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:4.2.1.15.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.05.13`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(10\)da2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.06.08`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.06.10`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.06.12`,
        fs:  `cpe:2.3:a:hitachi:tuning_manager:7.1.0:*:*:*:*:linux_kernel:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.06.14`,
        fs:  `cpe:2.3:a:persits:aspupload:1.4.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.06.15`,
        fs:  `cpe:2.3:a:intel:driver_update_utility:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.06.22`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.07.01`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:-:*:*:*:expressway:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.07.05`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:1.07.07`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.0.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.01.07`,
        fs:  `cpe:2.3:a:hp:ibrix:6.1.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.01.11`,
        fs:  `cpe:2.3:a:solarwinds:tftp_server:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.01.14`,
        fs:  `cpe:2.3:a:novell:iprint:5.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.01.19`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.01.20`,
        fs:  `cpe:2.3:a:alstom:e-terracontrol:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.01.21`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.15`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.12s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.17`,
        fs:  `cpe:2.3:a:cloudera:cdh:5.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.19`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.23`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.27`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.28`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.29`,
        fs:  `cpe:2.3:a:barton:ngircd:19.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.31`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:7.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.33`,
        fs:  `cpe:2.3:a:openswan:openswan:2.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.34`,
        fs:  `cpe:2.3:a:google:v8:3.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.35`,
        fs:  `cpe:2.3:h:d-link:dap_1150:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.36`,
        fs:  `cpe:2.3:a:hp:performance_insight:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.38`,
        fs:  `cpe:2.3:o:google:chrome_os:26.0.1410.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.39`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(1\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.40`,
        fs:  `cpe:2.3:a:gimp:gimp:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.41`,
        fs:  `cpe:2.3:a:elgg:elgg:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.44`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.45`,
        fs:  `cpe:2.3:a:adobe:customization_wizard_x:10.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:2.02.46`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.8.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.09`,
        fs:  `cpe:2.3:a:microsoft:ie:5.5:preview:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.16`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.18`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.149:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.23`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.71.1:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.28`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.30`,
        fs:  `cpe:2.3:a:ibm:personal_communications:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.31`,
        fs:  `cpe:2.3:a:openafs:openafs:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.33`,
        fs:  `cpe:2.3:a:oracle:mojarra:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.35`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.49.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.36`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.37`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:304.00:-:*:*:sunos:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.42`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.0:alpha3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.44`,
        fs:  `cpe:2.3:a:gisle_aas:libwww-perl:5.79:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.45`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.46`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p1_rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt100i:3.00.47`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.06.08`,
        fs:  `cpe:2.3:a:redhat:pre-execution_environment:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.06.10`,
        fs:  `cpe:2.3:a:techsmith:snagit:9.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.06.12`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_3010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.06.14`,
        fs:  `cpe:2.3:a:bernhard_wymann:torcs:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.06.15`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.06.22`,
        fs:  `cpe:2.3:a:skype:skype:4.0.0.176:beta_3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.07.01`,
        fs:  `cpe:2.3:a:intel:proset_wireless:11.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.07.05`,
        fs:  `cpe:2.3:o:xzeres:442sr_os:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:1.07.07`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager:6.2.2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.01.07`,
        fs:  `cpe:2.3:a:automattic:jetpack:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.01.11`,
        fs:  `cpe:2.3:a:libav:libav:0.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.01.14`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.01.19`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.01.20`,
        fs:  `cpe:2.3:a:oracle:financial_services_asset_liability_management:8.0.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.01.21`,
        fs:  `cpe:2.3:a:otrs:otrs_help_desk:3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.15`,
        fs:  `cpe:2.3:a:divx:aac_decoder:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.17`,
        fs:  `cpe:2.3:a:php:pear:1.4.0a9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.19`,
        fs:  `cpe:2.3:a:hp:sonic_primo_sdk:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.23`,
        fs:  `cpe:2.3:o:cisco:unified_computing_system_infrastructure_and_unified_computing_system_software:1.4\(4f\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.27`,
        fs:  `cpe:2.3:a:oracle:jdk:1.6.0:update_37:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.28`,
        fs:  `cpe:2.3:a:steve_souza:java_application_monitor:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.29`,
        fs:  `cpe:2.3:a:headlightinc:getright:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.31`,
        fs:  `cpe:2.3:a:redhat:openshift:2.1.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.33`,
        fs:  `cpe:2.3:a:mysql:maxdb:7.6.00.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.34`,
        fs:  `cpe:2.3:a:novell:mobility_pack:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.35`,
        fs:  `cpe:2.3:a:adobe:media_player:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.36`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:3.0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.38`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.14.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.39`,
        fs:  `cpe:2.3:a:hp:document_manager:120.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.40`,
        fs:  `cpe:2.3:a:hp:operations_orchestration:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.41`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.44`,
        fs:  `cpe:2.3:a:plone:plone:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.45`,
        fs:  `cpe:2.3:a:busybox:busybox:1.17.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:2.02.46`,
        fs:  `cpe:2.3:a:google:chrome:4.0.294.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.09`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.16`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.18`,
        fs:  `cpe:2.3:o:huawei:s9312_firmware:v200r001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.23`,
        fs:  `cpe:2.3:o:siemens:cfmw3025_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.28`,
        fs:  `cpe:2.3:o:yamaha:rt300i:6.02.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.30`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:9.1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.31`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0080:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.33`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(23\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.35`,
        fs:  `cpe:2.3:a:phpmoneybooks:phpmoneybooks:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.36`,
        fs:  `cpe:2.3:a:mysql:mysql:4.1.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.37`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:388:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.42`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.44`,
        fs:  `cpe:2.3:o:sun:solaris:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.45`,
        fs:  `cpe:2.3:a:drupalisme:tinybox:7.x-1.0:alpha3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.46`,
        fs:  `cpe:2.3:a:logitech:lws_launcher:13.20.1166.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt102i:3.00.47`,
        fs:  `cpe:2.3:a:omeka:omeka:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.02`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.05`,
        fs:  `cpe:2.3:a:symantec:livestate:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.07`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:27.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.09`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.49.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.10`,
        fs:  `cpe:2.3:a:debian:dpkg:1.9.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.11`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.13`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:3.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.14`,
        fs:  `cpe:2.3:a:blackberry:blackberry_link:1.2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.21`,
        fs:  `cpe:2.3:a:theforeman:foreman:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.22`,
        fs:  `cpe:2.3:a:f5:linerate:2.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.24`,
        fs:  `cpe:2.3:o:tp-link:archer_c8_\(1.0\)_firmware:141023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.25`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.33`,
        fs:  `cpe:2.3:h:cisco:sf302-08p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.35`,
        fs:  `cpe:2.3:a:google:v8:2.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.36`,
        fs:  `cpe:2.3:a:alphabetic_sitemap_project:alphabetic_sitemap:0.0.3:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.37`,
        fs:  `cpe:2.3:h:enterasys:aps_3000_7000:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.38`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.39`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.40`,
        fs:  `cpe:2.3:a:hummingbird:connectivity:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.44`,
        fs:  `cpe:2.3:a:hp:performance_core:10.50.225:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.48`,
        fs:  `cpe:2.3:a:ibm:maximo_asset_management:7.1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.53`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt103i:4.00.54`,
        fs:  `cpe:2.3:a:redhat:certificate_system:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.02.03`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.02.04`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.02.07`,
        fs:  `cpe:2.3:a:unace_project:unace:1.2b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.02.16`,
        fs:  `cpe:2.3:o:cisco:aironet_access_point_software:7.3_base:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.02.19`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p239:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.04`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.08`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.11`,
        fs:  `cpe:2.3:h:buffalotech:wzr-ampg144nh:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.15`,
        fs:  `cpe:2.3:a:ibm:infosphere_streams:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.18`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:1.91.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.25`,
        fs:  `cpe:2.3:a:citrix:group_policy_client-side_extension:1.0.0.416:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.28`,
        fs:  `cpe:2.3:a:greenbone:greenbone_security_assistant:4.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.33`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup:6.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105e:6.03.34`,
        fs:  `cpe:2.3:a:tigase:tigase:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.02.03`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.273:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.02.04`,
        fs:  `cpe:2.3:a:cisco:business_edition_5000_software:8.5\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.02.07`,
        fs:  `cpe:2.3:h:huawei:e200_usg2200:v200r003c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.02.16`,
        fs:  `cpe:2.3:a:f5:big-iq_device:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.02.19`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.3.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.04`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.08`,
        fs:  `cpe:2.3:a:hp:systems_insight_manager:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.11`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.15`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:3.20100122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.18`,
        fs:  `cpe:2.3:a:webyog:sqlyog:6.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.25`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:4.4\(7.202\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.28`,
        fs:  `cpe:2.3:a:samlify_project:samlify:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.33`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.23:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105i:6.03.34`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.83.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.02.03`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.02.04`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.02.07`,
        fs:  `cpe:2.3:a:mistelix:mistelix:0.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.02.16`,
        fs:  `cpe:2.3:h:oracle:netra_sparc_t4-2b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.02.19`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.8.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.04`,
        fs:  `cpe:2.3:a:ibm:api_management:3.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.08`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.48.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.11`,
        fs:  `cpe:2.3:a:dell:touchpad:7.1007.101.210:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.15`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:6.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.18`,
        fs:  `cpe:2.3:o:apple:iphone_os:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.25`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.28`,
        fs:  `cpe:2.3:a:opalvoip:portable_tool_library:2.10.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.33`,
        fs:  `cpe:2.3:a:laurent_destailleur:awstats:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt105p:6.03.34`,
        fs:  `cpe:2.3:a:bestpractical:rt:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.06`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.08`,
        fs:  `cpe:2.3:h:cisco:ons_15305_multiservice_customer_access_platform:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.24`,
        fs:  `cpe:2.3:a:wellintech:kingview:65.30.17249:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.26`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.11.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.37`,
        fs:  `cpe:2.3:a:bmc:software_control-m_agent:6.1.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.41`,
        fs:  `cpe:2.3:a:koha:koha:3.14.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.42`,
        fs:  `cpe:2.3:a:pantech:pc_card_software:2.2.3738.1006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.46`,
        fs:  `cpe:2.3:a:otrs:faq:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.60`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.17.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.61`,
        fs:  `cpe:2.3:a:nashtech:easy_php_calendar:7.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.68`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.70`,
        fs:  `cpe:2.3:a:apache:ignite:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.75`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.76`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.77`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:1.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.78`,
        fs:  `cpe:2.3:a:adobe:download_manager:1.6.2.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.80`,
        fs:  `cpe:2.3:a:x:libxext:1.0.99.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.82`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.83`,
        fs:  `cpe:2.3:o:paloaltonetworks:pan-os:5.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.87`,
        fs:  `cpe:2.3:a:gnu:gettext:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.88`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.91.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt107e:8.03.90`,
        fs:  `cpe:2.3:a:entrouvert:lasso:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.01.06`,
        fs:  `cpe:2.3:a:ibm:storwize_v5000_software:7.1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.01.07`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.01.09`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.02.03`,
        fs:  `cpe:2.3:a:google:chrome:13.0.777.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.02.04`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.02.07`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.02.16`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.02.19`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.04`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.0.1.1:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.08`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.11`,
        fs:  `cpe:2.3:a:ibm:db2:8.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.15`,
        fs:  `cpe:2.3:a:ibm:rational_engineering_lifecycle_manager:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.18`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.25`,
        fs:  `cpe:2.3:h:iss:proventia_g_series_xpu:22.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.28`,
        fs:  `cpe:2.3:a:openstack:neutron:2015.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.33`,
        fs:  `cpe:2.3:a:typo3:typo3:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140e:6.03.34`,
        fs:  `cpe:2.3:o:oracle:vm_server:3.1:*:*:*:*:*:sparc:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.01.06`,
        fs:  `cpe:2.3:a:cisco:ips_sensor_software:7.0\(2\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.01.07`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.01.09`,
        fs:  `cpe:2.3:o:seagate:blackarmor_nas_220_firmware:sg2000-2000.1331:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.02.03`,
        fs:  `cpe:2.3:a:keepass:keepass:0.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.02.04`,
        fs:  `cpe:2.3:a:spreecommerce:spree:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.02.07`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.02.16`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.02.19`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.04`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.08`,
        fs:  `cpe:2.3:a:debian:mit_kerberos:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.11`,
        fs:  `cpe:2.3:a:eterna:bozohttpd:20040808:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.15`,
        fs:  `cpe:2.3:a:vips:vips:7.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.18`,
        fs:  `cpe:2.3:a:cisco:wide_area_application_services:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.25`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.5.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.28`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.19.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.33`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140f:6.03.34`,
        fs:  `cpe:2.3:a:libpng:libpng:1.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.01.06`,
        fs:  `cpe:2.3:a:emc:networker:8.2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.01.07`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.3.2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.01.09`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:sp1:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.02.03`,
        fs:  `cpe:2.3:a:flurry:flurry-analytics-android:3.4.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.02.04`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:4.2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.02.07`,
        fs:  `cpe:2.3:a:python:python:2.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.02.16`,
        fs:  `cpe:2.3:a:djangoproject:django:1.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.02.19`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.04`,
        fs:  `cpe:2.3:a:sun:java_system_content_delivery_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.08`,
        fs:  `cpe:2.3:h:hp:jf813a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.11`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.49.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.15`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.18`,
        fs:  `cpe:2.3:o:microsoft:windows:server_2008:unknown:itanium:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.25`,
        fs:  `cpe:2.3:a:nodejs:node.js:4.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.28`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.33`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.5\(1\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140i:6.03.34`,
        fs:  `cpe:2.3:h:hp:carrier_grade_server_cc3300:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.01.06`,
        fs:  `cpe:2.3:a:umich:libgssglue:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.01.07`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.01.09`,
        fs:  `cpe:2.3:a:digium:asterisk:13.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.02.03`,
        fs:  `cpe:2.3:a:topdesk:topdesk:7.04.023:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.02.04`,
        fs:  `cpe:2.3:a:ait-pro:bulletproof-security:.46.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.02.07`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.02.16`,
        fs:  `cpe:2.3:o:yahama:rt140f:6.01.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.02.19`,
        fs:  `cpe:2.3:a:novell:zenworks_configuration_management:11.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.04`,
        fs:  `cpe:2.3:a:apache:subversion:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.08`,
        fs:  `cpe:2.3:o:yahama:rt200i:4.00.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.11`,
        fs:  `cpe:2.3:a:microsoft:excel:2010:sp2:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.15`,
        fs:  `cpe:2.3:a:google:chrome:28.0.1500.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.18`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.3.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.25`,
        fs:  `cpe:2.3:a:mongodb:mongodb:3.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.28`,
        fs:  `cpe:2.3:o:cisco:ios_xe:2.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.33`,
        fs:  `cpe:2.3:a:microsoft:ie:5.01:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt140p:6.03.34`,
        fs:  `cpe:2.3:o:yamaha:rt80i:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.00.06`,
        fs:  `cpe:2.3:a:hp:service_manager_web_tier:9.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.00.07`,
        fs:  `cpe:2.3:a:niif:shibb_auth:7.x-4.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.01.07`,
        fs:  `cpe:2.3:a:shopware:shopware:5.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.01.11`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.01.14`,
        fs:  `cpe:2.3:a:citrix:common_commands:1.1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.01.19`,
        fs:  `cpe:2.3:a:kmonos:xacrett:51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.01.20`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.01.21`,
        fs:  `cpe:2.3:a:jam-software:treesize:2.43:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.15`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.9s.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.17`,
        fs:  `cpe:2.3:a:atlassian:fisheye:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.19`,
        fs:  `cpe:2.3:a:gnome:glib:2.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.23`,
        fs:  `cpe:2.3:o:juniper:junos:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.27`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:49.1.2:*:*:*:*:c\/c\&#43;\&#43;:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.28`,
        fs:  `cpe:2.3:a:gitphp_project:gitphp:0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.29`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.29-76.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.31`,
        fs:  `cpe:2.3:a:devsaran:responsive:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.33`,
        fs:  `cpe:2.3:a:rpm:rpm:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.34`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.12.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.35`,
        fs:  `cpe:2.3:a:goo:health_assistance_service:2.4.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.36`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.38`,
        fs:  `cpe:2.3:a:justsystems:shuriken:2009:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.39`,
        fs:  `cpe:2.3:a:oracle:sysfw:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.40`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.41`,
        fs:  `cpe:2.3:h:hp:procurve_switch:je094a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.44`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.45`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.6:p4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:2.02.46`,
        fs:  `cpe:2.3:a:softaculous:webuzo:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.09`,
        fs:  `cpe:2.3:a:winscp:winscp:4.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.16`,
        fs:  `cpe:2.3:a:primetek:primefaces:6.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.18`,
        fs:  `cpe:2.3:o:apple:watch_os:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.23`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.28`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.30`,
        fs:  `cpe:2.3:a:gethook:hook:0.9.3:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.31`,
        fs:  `cpe:2.3:o:juniper:junos:11.4:r5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.33`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.35`,
        fs:  `cpe:2.3:a:boost:boost:1.61.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.36`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:3.0.0629:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.37`,
        fs:  `cpe:2.3:a:symantec:veritas_dmp_dsm_solution:5.1.20000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.42`,
        fs:  `cpe:2.3:a:shavlik:netchk_protect:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.44`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.45`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.46`,
        fs:  `cpe:2.3:a:aol:aim:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:3.00.47`,
        fs:  `cpe:2.3:a:gpsd_project:gpsd:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.02`,
        fs:  `cpe:2.3:h:axis:2110_network_camera:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.05`,
        fs:  `cpe:2.3:a:google:chrome:17.0.933.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.07`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.06b53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.09`,
        fs:  `cpe:2.3:o:cisco:staros:20.0.m0.63229:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.11`,
        fs:  `cpe:2.3:a:avast:endpoint_protection:8.0.1609:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.13`,
        fs:  `cpe:2.3:a:veritas:backup_exec_remote_agent:9.1.4691:sp2:windows_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.14`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.18`,
        fs:  `cpe:2.3:h:ibm:security_access_manager_for_web_appliance:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.21`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.22`,
        fs:  `cpe:2.3:a:tm_software:tempo:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.24`,
        fs:  `cpe:2.3:a:dlitz:pycrypto:1.9:alpha6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.25`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(25\)sec1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.33`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20:rc7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.35`,
        fs:  `cpe:2.3:a:samba:jitterbug:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.36`,
        fs:  `cpe:2.3:a:hp:shop_for_hp_supplies:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.37`,
        fs:  `cpe:2.3:a:activcard:activcard_gold_for_cac:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.38`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.39`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb166xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.40`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.1.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.44`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.48`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.53`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt200i:4.00.54`,
        fs:  `cpe:2.3:a:sympa:sympa:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.19`,
        fs:  `cpe:2.3:a:zarafa:zarafa_collaboration_platform:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.28`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale_client:8.6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.31`,
        fs:  `cpe:2.3:a:torproject:tor:0.0.8:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.35`,
        fs:  `cpe:2.3:a:microsoft:html_help_workshop:4.02.0002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.36`,
        fs:  `cpe:2.3:a:apache:cxf:2.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.40`,
        fs:  `cpe:2.3:a:php:php:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.42`,
        fs:  `cpe:2.3:a:sun:jdk:1.3.1_11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.43`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(7b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.48`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(10a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt250i:8.02.50`,
        fs:  `cpe:2.3:a:ajaxplorer:ajaxplorer:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.00.09`,
        fs:  `cpe:2.3:a:docker:docker:0.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.00.11`,
        fs:  `cpe:2.3:a:redhat:jboss_web_framework_kit:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.00.15`,
        fs:  `cpe:2.3:o:cisco:unified_ip_phone_8900_series_firmware:9.4\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.00.17`,
        fs:  `cpe:2.3:a:symantec:netbackup_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.00.20`,
        fs:  `cpe:2.3:o:yamaha:rt100i:1.06.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.00.22`,
        fs:  `cpe:2.3:a:mcafee:epolicy_orchestrator:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.00.25`,
        fs:  `cpe:2.3:a:tenable:nessus:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.00.27`,
        fs:  `cpe:2.3:a:gnu:libtasn1:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.01.06`,
        fs:  `cpe:2.3:o:apple:mac_os:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.01.07`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.205:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.01.09`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:06-70-\/f:-:light:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.02.03`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)e2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.02.04`,
        fs:  `cpe:2.3:a:google:chrome:11.0.696.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.02.07`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.02.16`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.07.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.02.19`,
        fs:  `cpe:2.3:a:samba:samba:3.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.03.04`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/net:6.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.03.08`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.4_4k:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.03.11`,
        fs:  `cpe:2.3:a:ibm:filenet_image_services_remote_admin_console:4.0.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.03.15`,
        fs:  `cpe:2.3:a:ulli_horlacher:fex:20111230:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.03.18`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.10.3\(41\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.03.25`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_static:2008.1201.1504.27008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.03.28`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.15.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt300i:6.03.34`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt56v:4.07.11`,
        fs:  `cpe:2.3:a:nagios:nagios:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt56v:4.07.19`,
        fs:  `cpe:2.3:a:igreks:milkystep_professional:1.73:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt56v:4.07.22`,
        fs:  `cpe:2.3:a:oracle:industry_applications:4.5:sp3i:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt56v:4.07.30`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt56v:4.07.37`,
        fs:  `cpe:2.3:a:honeywell:enterprise_buildings_integrator:r410.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt56v:4.07.45`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.2.3:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt56v:4.07.49`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.81:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt56v:4.07.54`,
        fs:  `cpe:2.3:a:horde:dynamic_imp:1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.13`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.14`,
        fs:  `cpe:2.3:a:google:chrome:4.0.249.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.19`,
        fs:  `cpe:2.3:a:citrix:metaframe:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.27`,
        fs:  `cpe:2.3:a:macromedia:flash_communication_server:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.41`,
        fs:  `cpe:2.3:a:ovirt:ovirt:4.1.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.46`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)ec2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.48`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.2.0.p-1.0.2.1-17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.57`,
        fs:  `cpe:2.3:a:quiz_project:quiz:-:*:*:*:*:mediawiki:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.66`,
        fs:  `cpe:2.3:a:horde:groupware:1.0.4:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.70`,
        fs:  `cpe:2.3:a:web2py:web2py:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.71`,
        fs:  `cpe:2.3:a:sun:jre:1.4.1:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.83`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.87`,
        fs:  `cpe:2.3:a:david_shadoff:mednafen:0.8.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.89`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b_pk1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt57i:8.00.91`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:1.001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.11`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.13`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.8:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.18`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.32.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.19`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.21`,
        fs:  `cpe:2.3:a:enyetech:coca-cola_fm_honduras:2.0.41725:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.29`,
        fs:  `cpe:2.3:a:hp:customer_participation_program:14.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.33`,
        fs:  `cpe:2.3:a:mysql:mysql:5.1.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.36`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.3\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.41`,
        fs:  `cpe:2.3:a:apc:powerchute:2.1.1:-:personal:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.44`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.48`,
        fs:  `cpe:2.3:a:ocportal:ocportal:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt58i:9.01.49`,
        fs:  `cpe:2.3:h:buffalotech:wmr-300_firmware:1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt60w:5.01.14`,
        fs:  `cpe:2.3:a:sophos:web_appliance:3.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt60w:5.01.16`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt60w:5.01.21`,
        fs:  `cpe:2.3:a:ibm:network_station_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.15`,
        fs:  `cpe:2.3:a:oracle:developer_suite:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.17`,
        fs:  `cpe:2.3:a:igreks:milkystep_light:0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.19`,
        fs:  `cpe:2.3:h:cisco:catalyst_4506-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.23`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.27`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.390:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.28`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.29`,
        fs:  `cpe:2.3:a:rocomotion:pplog:3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.31`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.33`,
        fs:  `cpe:2.3:a:atlassian:jira:3.12:*:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.34`,
        fs:  `cpe:2.3:a:watchdog_aggregator_project:watchdog_aggregator:-:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.35`,
        fs:  `cpe:2.3:o:adtran:aos:10.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.36`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(11\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.38`,
        fs:  `cpe:2.3:a:apple:cups:1.1.21:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.39`,
        fs:  `cpe:2.3:a:sefrengo:sefrengo:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.40`,
        fs:  `cpe:2.3:a:feedweb:feedweb:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.41`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.2.1.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.44`,
        fs:  `cpe:2.3:a:apple:safari:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.45`,
        fs:  `cpe:2.3:a:gnu:gnutls:1.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:2.02.46`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.8.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.09`,
        fs:  `cpe:2.3:a:jenkins:github_branch_source:2.0.1:beta-4:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.16`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.06:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.18`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:2.0.8:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.23`,
        fs:  `cpe:2.3:a:mailenable:mailenable:3.5:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.28`,
        fs:  `cpe:2.3:a:adobe:acrobat:10.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.30`,
        fs:  `cpe:2.3:a:typo3:typo3:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.31`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.33`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.3.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.35`,
        fs:  `cpe:2.3:a:ultraedit:ultraedit:9.10a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.36`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.66:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.37`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:1.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.42`,
        fs:  `cpe:2.3:a:smoelenboek_project:smoelenboek:1.0.8:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.44`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:7.1.3.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.45`,
        fs:  `cpe:2.3:a:adaptivecomputing:torque_resource_manager:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.46`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:6.0\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rt80i:3.00.47`,
        fs:  `cpe:2.3:a:ibm:websphere_extreme_scale:8.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.02.15`,
        fs:  `cpe:2.3:h:t-com:speedport_500v:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.02.17`,
        fs:  `cpe:2.3:a:quagga:quagga:0.99.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.02.19`,
        fs:  `cpe:2.3:a:winmerge:winmerge:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.02.21`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.03.25`,
        fs:  `cpe:2.3:a:dest-unreach:socat:1.3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.03.28`,
        fs:  `cpe:2.3:o:iij:seil\/x2_firmware:4.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.03.29`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:6.0\(0\):sr4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.03.34`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.03.35`,
        fs:  `cpe:2.3:h:hp:h3c_ethernet_switch:s7502e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.04.39`,
        fs:  `cpe:2.3:a:jenkins-ci:exclusion:0.9:-:*:*:*:cloudbees_jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.04.44`,
        fs:  `cpe:2.3:a:gradkell:dbsign_for_html_applications:3.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.04.47`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.05.28`,
        fs:  `cpe:2.3:h:hp:jf238a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.05.30`,
        fs:  `cpe:2.3:a:attachmate:reflection_for_the_web_2008:10.1.549:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.05.35`,
        fs:  `cpe:2.3:a:bea:tuxedo:10.3.0.0:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.05.38`,
        fs:  `cpe:2.3:a:janesoft:janetter:1.6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta50i:3.05.42`,
        fs:  `cpe:2.3:a:apple:apple_mobile_device_support:3.4.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta52i:3.06.20`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta52i:3.06.25`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.17.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta52i:4.01.06`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta52i:4.01.09`,
        fs:  `cpe:2.3:a:torproject:tor:0.1.1.13:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta52i:4.01.11`,
        fs:  `cpe:2.3:a:snort:snort:2.6.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta52i:4.01.14`,
        fs:  `cpe:2.3:a:netwin:surgeftp:2.3a6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta52i:4.01.15`,
        fs:  `cpe:2.3:a:adersoft:vbsedit:3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta52i:4.01.17`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta54i:4.03.12`,
        fs:  `cpe:2.3:a:atlassian:jira:3.13.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta54i:4.04.03`,
        fs:  `cpe:2.3:a:ibm:os2_ftp_server:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta54i:4.04.05`,
        fs:  `cpe:2.3:a:cms_tree_page_view_project:cms_tree_page_view:1.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta54i:4.04.08`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta54i:4.05.14`,
        fs:  `cpe:2.3:a:malwarebytes:malwarebytes_anti-malware:2.02:*:*:*:consumer:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta55i:4.06.28`,
        fs:  `cpe:2.3:a:checkpoint:secureclient_ng:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta55i:4.06.35`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta55i:4.06.47`,
        fs:  `cpe:2.3:a:futomi:mp_form_mail_cgi:2.0.10:*:*:*:ecommerce:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta55i:4.06.54`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server_toolkit:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta55i:4.06.60`,
        fs:  `cpe:2.3:a:samba:samba:4.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rta55i:4.06.67`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.9-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.31`,
        fs:  `cpe:2.3:a:apple:apple_application_support:1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.39`,
        fs:  `cpe:2.3:a:vmware:horizon_view:5.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.45`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.53`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.56`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.16.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.60`,
        fs:  `cpe:2.3:a:hierarchial_select_project:hierarchical_select:6.x-3.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.62`,
        fs:  `cpe:2.3:a:mawashimono:nikki:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.69`,
        fs:  `cpe:2.3:a:redhat:enterprise_virtualization:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.72`,
        fs:  `cpe:2.3:a:recurly:recurly_client_ruby:2.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.77`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.80`,
        fs:  `cpe:2.3:a:arcsoft:photoimpression:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.81`,
        fs:  `cpe:2.3:a:infradead:openconnect:3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.84`,
        fs:  `cpe:2.3:a:icinga:icinga:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.86`,
        fs:  `cpe:2.3:a:gitlab:gitlab:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtv700:8.00.88`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtw65b:5.03.11`,
        fs:  `cpe:2.3:a:hp:software_jre:1.4.250:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtw65b:5.03.15`,
        fs:  `cpe:2.3:a:connections_project:connections:0.6.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtw65b:5.03.25`,
        fs:  `cpe:2.3:a:silanis:approveit_desktop:6.10.10.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtw65i:5.03.11`,
        fs:  `cpe:2.3:a:cisco:ciscoworks_common_services:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtw65i:5.03.15`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtw65i:5.03.25`,
        fs:  `cpe:2.3:a:skype:skype:3.5.0.239:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.00.14`,
        fs:  `cpe:2.3:o:moxa:edr_g903_firmware:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.00.15`,
        fs:  `cpe:2.3:h:supermicro:x7spe-hf-d525:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.00.16`,
        fs:  `cpe:2.3:a:killer_screen_lock_project:killer_screen_lock:0.5:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.00.19`,
        fs:  `cpe:2.3:a:spip:spip:2.1.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.00.26`,
        fs:  `cpe:2.3:a:commerceguys:commerce:7.x-1.0:beta3:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.00.29`,
        fs:  `cpe:2.3:a:kent-web:joyful_note:5.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.00.30`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.04`,
        fs:  `cpe:2.3:a:modsimconnected:modsim_world_2014:2.0.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.05`,
        fs:  `cpe:2.3:a:zemanta:related_posts:2.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.08`,
        fs:  `cpe:2.3:a:apprenticeuitgevers:schoolxm:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.15`,
        fs:  `cpe:2.3:a:juniper:installer_service:2.0.1.4429:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.16`,
        fs:  `cpe:2.3:a:redhat:enterprise_mrg:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.17`,
        fs:  `cpe:2.3:a:adobe:flash_player:13.0.0.223:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.26`,
        fs:  `cpe:2.3:h:ibm:xiv_storage_system:2812-114:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.29`,
        fs:  `cpe:2.3:a:microsoft:word:2000:sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.34`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.26.0:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.41`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.47`,
        fs:  `cpe:2.3:a:postgresql:postgresql:8.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.48`,
        fs:  `cpe:2.3:o:google:android:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.49`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.53`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_cms:5.0.1:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1000:7.01.54`,
        fs:  `cpe:2.3:a:microsoft:commercial_internet_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.06`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.13:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.08`,
        fs:  `cpe:2.3:a:freetype:freetype:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.24`,
        fs:  `cpe:2.3:o:microsoft:windows_mobile:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.26`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:2.4.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.37`,
        fs:  `cpe:2.3:a:ibm:tririga_application_platform:3.4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.41`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.42`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.46`,
        fs:  `cpe:2.3:o:huawei:s9306_firmware:v100r006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.60`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.01.05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.61`,
        fs:  `cpe:2.3:a:google:chrome:5.0.375.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.68`,
        fs:  `cpe:2.3:a:google:chrome:18.0.1025.166:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.70`,
        fs:  `cpe:2.3:a:isc:bind:9.4.0:b4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.75`,
        fs:  `cpe:2.3:a:bsdperimeter:pfsense:1.2:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.76`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.77`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.78`,
        fs:  `cpe:2.3:a:ultimus:adaptive_bpm_suite:8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.80`,
        fs:  `cpe:2.3:a:metaclassy:byword:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.82`,
        fs:  `cpe:2.3:a:perl:perl:0.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.83`,
        fs:  `cpe:2.3:o:juniper:junos:15.1:f1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.87`,
        fs:  `cpe:2.3:a:automattic:jetpack:2.0.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.88`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:2.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1100:8.03.90`,
        fs:  `cpe:2.3:a:ibm:tivoli_netview:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1200:10.01.08`,
        fs:  `cpe:2.3:a:ibm:marketing_platform:8.5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1200:10.01.11`,
        fs:  `cpe:2.3:a:sun:sdk:1.2.2_10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1200:10.01.16`,
        fs:  `cpe:2.3:a:autodesk:map_3d:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1200:10.01.22`,
        fs:  `cpe:2.3:a:gnu:automake:1.4:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1200:10.01.24`,
        fs:  `cpe:2.3:a:skype:skype:3.5.0.214:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1200:10.01.29`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.06`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.08`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.147:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.24`,
        fs:  `cpe:2.3:a:google:chrome:12.0.742.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.26`,
        fs:  `cpe:2.3:a:adobe:csi:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.37`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.41`,
        fs:  `cpe:2.3:a:businessobjects:infoview:5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.42`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.466.1:*:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.46`,
        fs:  `cpe:2.3:a:puppetlabs:stdlib:4.3.0:*:*:*:*:puppet:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.60`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p1_beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.61`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.44:test4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.68`,
        fs:  `cpe:2.3:a:busybox:busybox:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.70`,
        fs:  `cpe:2.3:a:tipsandtricks-hq:wordpress_simple_paypal_shopping_cart:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.75`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.76`,
        fs:  `cpe:2.3:a:gnu:gzip:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.77`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.6:1018:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.78`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(9\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.80`,
        fs:  `cpe:2.3:a:ibm:spss_statistics:23.0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.82`,
        fs:  `cpe:2.3:a:activehelper:activehelper_livehelp_live_chat:2.9.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.83`,
        fs:  `cpe:2.3:a:hp:release_control:9.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.87`,
        fs:  `cpe:2.3:a:ibm:tivoli_federated_identity_manager_business_gateway:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.88`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx1500:8.03.90`,
        fs:  `cpe:2.3:a:cmu:cyrus_imap_server:2.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.00.14`,
        fs:  `cpe:2.3:a:google:chrome:33.0.1750.109:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.00.15`,
        fs:  `cpe:2.3:a:dlc_solutions:course:7.x-1.0-rc3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.00.16`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.4sq:3.4.0sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.00.19`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:6.3.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.00.26`,
        fs:  `cpe:2.3:a:mcafee:email_and_web_security:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.00.29`,
        fs:  `cpe:2.3:o:linux:kernel:2.6.11.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.00.30`,
        fs:  `cpe:2.3:h:cisco:1861_integrated_service_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.17`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.0.4.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.26`,
        fs:  `cpe:2.3:a:mcafee:linuxshield:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.29`,
        fs:  `cpe:2.3:a:madeofcode:omniauth-facebook:1.2.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.34`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:5.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.41`,
        fs:  `cpe:2.3:a:x.org:libx11:1.3.99.903:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.47`,
        fs:  `cpe:2.3:o:juniper:junose_m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.48`,
        fs:  `cpe:2.3:a:rocomotion:p_board_ri:1.12:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.49`,
        fs:  `cpe:2.3:a:agilebits:knox:2.2.0:-:*:*:*:mac_os_x:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.53`,
        fs:  `cpe:2.3:a:gigablast:gigabot:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx2000:7.01.54`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.142:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.15`,
        fs:  `cpe:2.3:a:php-nuke:downloads_module:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.20`,
        fs:  `cpe:2.3:a:hitachi:processing_kit_for_xml:02-05-\/e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.22`,
        fs:  `cpe:2.3:a:apache:ignite:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.24`,
        fs:  `cpe:2.3:a:reviewboard:review_board:1.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.25`,
        fs:  `cpe:2.3:a:pearlsw:echo:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.31`,
        fs:  `cpe:2.3:a:moxiecode:plupload:1.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.37`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.7:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.40`,
        fs:  `cpe:2.3:a:bundler:bundler:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.43`,
        fs:  `cpe:2.3:a:wxwidgets:wxwidgets:2.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.44`,
        fs:  `cpe:2.3:o:d-link:dsr-500_firmware:1.03b36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.47`,
        fs:  `cpe:2.3:a:rocomotion:pplog_2:2.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:rtx3000:9.00.48`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_server:04-01-\/a:-:web:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.09`,
        fs:  `cpe:2.3:a:dolphin-browser:dolphin_browser_hd:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.19`,
        fs:  `cpe:2.3:a:ibm:soliddb:6.5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.21`,
        fs:  `cpe:2.3:a:smarty:smarty:2.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.22`,
        fs:  `cpe:2.3:a:php:php:3.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.27`,
        fs:  `cpe:2.3:a:google:chrome:15.0.874.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.28`,
        fs:  `cpe:2.3:a:mcafee:dlp_agent:9.0.104.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.31`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.38`,
        fs:  `cpe:2.3:a:gnu:gnutls:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.40`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.44`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.46`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.49`,
        fs:  `cpe:2.3:a:dosfstools_project:dosfstools:3.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.52`,
        fs:  `cpe:2.3:h:sophos:web_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.53`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.84:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yahama:srt100:10.00.56`,
        fs:  `cpe:2.3:a:cartpauj:mingle-forum:1.0.32.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:audio_conferencing_activex_control:-`,
        fs:  `cpe:2.3:a:augeas:augeas:0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:autosync:1.0.4.9`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:2.4.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:desktop_login:1.0.1`,
        fs:  `cpe:2.3:a:imember360:imember360:3.7.001:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:japan_shopping:1.4`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:-`,
        fs:  `cpe:2.3:a:piwik:piwik:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:0.99.17-1`,
        fs:  `cpe:2.3:o:hp:integrated_lights-out_firmware:1.41a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:1.0`,
        fs:  `cpe:2.3:a:nagios:nagios:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:1.0.4`,
        fs:  `cpe:2.3:a:md-systems:simplenews:6.x-1.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:1.0.6`,
        fs:  `cpe:2.3:a:gnu:glibc:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:2.0.1.4`,
        fs:  `cpe:2.3:a:dave_coffin:dcraw:0.8.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:3.0`,
        fs:  `cpe:2.3:a:ibm:db2:10.1.0.3:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:3.0.1`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:4.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:3.0.1:beta-35554`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.0.19:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:3.5`,
        fs:  `cpe:2.3:a:cisco:webex_advanced_recording_format_player:t29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:4.0`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:4.1`,
        fs:  `cpe:2.3:a:hitachi:jp1\/serverconductor\/deploymentmanager:08-50-\/b:-:enterprise:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.0`,
        fs:  `cpe:2.3:a:adobe:adobe_air_sdk:14.0.0.137:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.0.1046`,
        fs:  `cpe:2.3:a:apache:httpclient:4.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.0.1065`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.0.1232`,
        fs:  `cpe:2.3:a:ca:antivirus_sdk:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.5`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.5.1249`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.3.1:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.6`,
        fs:  `cpe:2.3:a:mathjs:math.js:3.16.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.6.0.1347`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.4.12:*:*:*:*:*:itanium:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.6.0.1351`,
        fs:  `cpe:2.3:a:quick_tabs_module_project:quicktabs:6.x-3.0:beta1:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.6.0.1355`,
        fs:  `cpe:2.3:a:portrait:acer_edisplay_management:1.20.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.6.0.1356`,
        fs:  `cpe:2.3:h:cisco:sg500x-48p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:5.6.0.1358`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_client:06-71:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:6.0`,
        fs:  `cpe:2.3:o:motorola:moscad_ip_gateway_firmware:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:6.0.0.1643`,
        fs:  `cpe:2.3:a:leadoctopus:lead_octopus:-:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:6.0.0.1750`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.0.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:6.0.0.1921`,
        fs:  `cpe:2.3:a:sympa:sympa:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:6.1`,
        fs:  `cpe:2.3:a:gnome:at-spi2-atk:0.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:7.0`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:2.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:7.0.0.426`,
        fs:  `cpe:2.3:o:apple:mac_os_x:10.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:7.0.0.437`,
        fs:  `cpe:2.3:o:conectiva:linux:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:7.0.438`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:1.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:7.5`,
        fs:  `cpe:2.3:a:ibm:infoprint_controller:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:7.5.0.814`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.0`,
        fs:  `cpe:2.3:a:emc:networker:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.0.0.505`,
        fs:  `cpe:2.3:a:hitachi:cobol2002_net_client_suite:02-00-\/d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.0.0.508`,
        fs:  `cpe:2.3:a:stanislas_rolland:sr_feuser_register:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.0.0.701`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.0.0.716`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:gold:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.0.0.863`,
        fs:  `cpe:2.3:a:adobe:flash_player:16.0.0.234:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.0.1`,
        fs:  `cpe:2.3:a:mariadb:mariadb:10.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.0_2005.1.1.4`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.9b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1`,
        fs:  `cpe:2.3:a:moodle:moodle:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.195`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(7\)ca:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.209`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver:195.22:-:*:*:sunos:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.239`,
        fs:  `cpe:2.3:a:ibm:db2_connect:9.7.0.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.244`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_linux:9.0.124.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.249`,
        fs:  `cpe:2.3:a:php:php:4.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.401`,
        fs:  `cpe:2.3:a:live555:streaming_media:2012.01.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.402`,
        fs:  `cpe:2.3:a:organizer_project:organizer:1.1.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.413`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.416`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:7.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.419`,
        fs:  `cpe:2.3:a:lighttpd:lighttpd:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:8.1.0.421`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:201m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.797:beta`,
        fs:  `cpe:2.3:a:jason_a_donenfeld:cgit:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.907:beta`,
        fs:  `cpe:2.3:a:hp:jetadmin:6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.922:beta`,
        fs:  `cpe:2.3:a:adobe:homesite:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.1389:beta`,
        fs:  `cpe:2.3:a:oracle:configurator:11.5.6.16.52:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.1912`,
        fs:  `cpe:2.3:a:ssh:ssh2:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2018`,
        fs:  `cpe:2.3:a:christos_zoulas:file:5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2034`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p439:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2112`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.8.1:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2123`,
        fs:  `cpe:2.3:a:atlassian:jira:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2128`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2133`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.2\(4.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2136`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2152`,
        fs:  `cpe:2.3:o:cisco:catos:6.3\(1a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2160`,
        fs:  `cpe:2.3:a:sun:jdk:1.4.1:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2161`,
        fs:  `cpe:2.3:a:mozilla:firefox:2.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:9.0.0.2162`,
        fs:  `cpe:2.3:a:symantec:livestate_recovery:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.331:pre-alpha`,
        fs:  `cpe:2.3:a:opera:opera_browser:7.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.525:beta`,
        fs:  `cpe:2.3:a:zenphoto:zenphoto:0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.542:beta`,
        fs:  `cpe:2.3:a:skype:skype:2.0.0.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.1102`,
        fs:  `cpe:2.3:a:sap:businessobjects:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.1241`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.981:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.1258`,
        fs:  `cpe:2.3:a:intel:pro_network_connections:10.0.27.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.1264`,
        fs:  `cpe:2.3:a:ibm:db2_connect:10.5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.1267`,
        fs:  `cpe:2.3:a:lhaplus:lhaplus:1.59:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:10.0.0.1270`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:1.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:11.0.0.1751`,
        fs:  `cpe:2.3:a:git-scm:git:2.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:11.0.0.2009`,
        fs:  `cpe:2.3:a:hp:instant_share:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:11.0.0.2014`,
        fs:  `cpe:2.3:a:disqus:disqus_comment_system:2.70:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:messenger:11.5.0.152`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:music_jukebox:-`,
        fs:  `cpe:2.3:a:open-xchange:open-xchange_appsuite:7.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:music_jukebox:2.2.2.056`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.367:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:pager:-`,
        fs:  `cpe:2.3:a:ssh:tectia_client_server_connector:5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:toolbar:-`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:toolbar:1.0.0.5`,
        fs:  `cpe:2.3:a:ibm:db2:9.8.0.1:*:*:*:advanced_enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:toolbar:1.4.1`,
        fs:  `cpe:2.3:a:keepass:keepass:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:tumblr:3.4.0:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:tumblr:3.4.1:-:~~~iphone_os~~`,
        fs:  `cpe:2.3:a:remote_login_service_hackers:remote_login_service:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:ui_library:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p382:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:widgets:-`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(17\)s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:widgets:4.0.5`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yafuoku%21:4.3.0::~~~android~~`,
        fs:  `cpe:2.3:a:efrontlearning:efront:3.5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yafuoku%21:4.3.0::~~~iphone_os~~`,
        fs:  `cpe:2.3:h:huawei:cx600:v200r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yahoo%21_browser:1.2.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:citrix:metaframe_presentation_server:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yahoo%21_browser:1.4.2:-:~~~android~~`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yahoo%21_browser:1.4.3:-:~~~android~~`,
        fs:  `cpe:2.3:a:ibm:iss_realsecure_network:7.0:xpu_20.9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yahoo%21_browser:1.4.4:-:~~~android~~`,
        fs:  `cpe:2.3:a:hp:icewall_sso:10.0:*:*:*:dfw:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yahoo%21_browser:1.4.5:-:~~~android~~`,
        fs:  `cpe:2.3:a:microsoft:msn_messenger:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yahoo%21_browser:1.4.6:-:~~~android~~`,
        fs:  `cpe:2.3:a:mkssoftware:mks_platform_components_x:8.6.200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.4.0`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.4.1`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.5.0`,
        fs:  `cpe:2.3:a:citrix:offline_plug-in:6.0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.5.1`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.5.2`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.15:cert1_rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.6.0`,
        fs:  `cpe:2.3:a:pixman:pixman:0.28.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.7.0`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.09.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.8.0`,
        fs:  `cpe:2.3:a:razorcms:razorcms:1.0:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.8.1`,
        fs:  `cpe:2.3:a:suse:suse_linux_admin-cd_for_firewall:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.8.1:pr1`,
        fs:  `cpe:2.3:a:pivotal_software:rabbitmq:1.6.10:*:*:*:*:pivotal_cloud_foundry:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.8.2`,
        fs:  `cpe:2.3:a:openssl:fips_object_module:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.9.0`,
        fs:  `cpe:2.3:a:oracle:mysql:5.1.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.9.0:pr2`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.317:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:2.9.0:pr4`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.0.0`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.447.3.1:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.1.0`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p278:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.1.1`,
        fs:  `cpe:2.3:a:solarwinds:orion_network_atlas:1.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.1.2`,
        fs:  `cpe:2.3:a:umi-cms:umi.cms:2.8.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.2.0`,
        fs:  `cpe:2.3:a:oracle:retail_applications_xstore:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.3.0`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2b1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.4.0`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.4.1`,
        fs:  `cpe:2.3:a:apache:solr:4.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.5.0`,
        fs:  `cpe:2.3:a:vmware:hyperic_hq:4.6.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.5.1`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.6.0`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.7.0`,
        fs:  `cpe:2.3:a:nih:libzip:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.7.1`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.7.2`,
        fs:  `cpe:2.3:a:user_read-only_project:user_readonly:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.7.3`,
        fs:  `cpe:2.3:a:zikula:zikula_application_framework:1.4.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.8.0`,
        fs:  `cpe:2.3:a:novell:client:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.8.1`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.9.0`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_client:06-00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.9.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.5-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.10.0`,
        fs:  `cpe:2.3:a:krzysztof_kowalczyk:sumatrapdf:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.10.1`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yahoo:yui:3.10.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(1\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.02.05`,
        fs:  `cpe:2.3:h:alcatel:speed_touch_home:khdsaa.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.02.08`,
        fs:  `cpe:2.3:o:xen:xen:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.02.16`,
        fs:  `cpe:2.3:a:ratbox:ircd-ratbox:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.03.08`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:8.5.0.1:*:*:*:standard:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.03.12`,
        fs:  `cpe:2.3:a:adobe:golive:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.03.15`,
        fs:  `cpe:2.3:a:opennms:opennms:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.03.24`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.03.25`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.9.8:*:*:*:*:*:arm64:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.03.30`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.04.03`,
        fs:  `cpe:2.3:h:huawei:s9706:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.04.06`,
        fs:  `cpe:2.3:a:pocket_cam_photo_editor_project:pocket_cam_photo_editor:3.0:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.04.09`,
        fs:  `cpe:2.3:a:adobe:connect:9.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.05.05`,
        fs:  `cpe:2.3:a:emc:networker:8.1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.05.07`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_uaa_bosh:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.05.09`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:6.5.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.05.10`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:5.4.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.05.13`,
        fs:  `cpe:2.3:a:karen_stevenson:date:6.x-2.0:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.06.08`,
        fs:  `cpe:2.3:a:zarafa:zarafa:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.06.10`,
        fs:  `cpe:2.3:a:gnome:evolution:2.3.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.06.12`,
        fs:  `cpe:2.3:a:ge:intelligent_platforms_proficy_hmi\/scada_cimplicity:4.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.06.14`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.06.15`,
        fs:  `cpe:2.3:a:nick_copeland:bristol:0.20.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.06.22`,
        fs:  `cpe:2.3:a:microsoft:windows_nt_helper_components:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.07.01`,
        fs:  `cpe:2.3:a:clamav:clamav:0.97.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.07.05`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:1.07.07`,
        fs:  `cpe:2.3:o:yahama:rta50i:3.05.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.01.07`,
        fs:  `cpe:2.3:a:hp:xp_9000_command_view:7.0.0:*:*:*:advanced:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.01.11`,
        fs:  `cpe:2.3:a:gitlab:gitlab:3.0.2:*:*:*:community:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.01.14`,
        fs:  `cpe:2.3:a:citrix:delivery_services_console_framework:5.0.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.01.19`,
        fs:  `cpe:2.3:a:arcsight:arcsight_console:4.0.3.5:sp3_patch_5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.01.20`,
        fs:  `cpe:2.3:a:schneems:wicked:0.1.0:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.01.21`,
        fs:  `cpe:2.3:o:cisco:skinny_client_control_protocol_software:8.5\(3\):sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.15`,
        fs:  `cpe:2.3:a:ibm:db2:8.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.17`,
        fs:  `cpe:2.3:h:selinc:sel-3530-4:r123-v0-z002001-d20130117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.19`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.23`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.1.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.27`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpc\/epc3010:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.28`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:18.009.20050:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.29`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.31`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.33`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:59.1:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.34`,
        fs:  `cpe:2.3:a:php-calendar:php-calendar:0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.35`,
        fs:  `cpe:2.3:a:git-scm:git:1.6.6:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.36`,
        fs:  `cpe:2.3:o:yamaha:rt102i:3.00.42:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.38`,
        fs:  `cpe:2.3:a:simon_brown:pebble:1.5:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.39`,
        fs:  `cpe:2.3:o:yamaha:rtx3000:9.00.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.40`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.41`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.44`,
        fs:  `cpe:2.3:h:intel:active_management_technology:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.45`,
        fs:  `cpe:2.3:a:schneider-electric:scada_expert_clearscada:2013:r1.1a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:2.02.46`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager:6.4.2.500:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.09`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:4.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.16`,
        fs:  `cpe:2.3:a:apache:roller:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.18`,
        fs:  `cpe:2.3:a:cisco:prime_network_registrar:8.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.23`,
        fs:  `cpe:2.3:a:boehm-demers-weiser:garbage_collector:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.28`,
        fs:  `cpe:2.3:a:eliteladders:elite_gaming_ladders:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.30`,
        fs:  `cpe:2.3:a:isc:bind:9.8.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.31`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.33`,
        fs:  `cpe:2.3:a:mozilla:mozilla:1.6:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.35`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.36`,
        fs:  `cpe:2.3:a:alejandro_garza:apachesolr_autocomplete:6.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.37`,
        fs:  `cpe:2.3:o:yamaha:rt105p:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.42`,
        fs:  `cpe:2.3:a:symantec:netbackup_opscenter:7.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.44`,
        fs:  `cpe:2.3:a:f5:big-ip_local_traffic_manager:11.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.45`,
        fs:  `cpe:2.3:o:huawei:s6700_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.46`,
        fs:  `cpe:2.3:a:mumble:mumble:1.2.3:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt100i:3.00.47`,
        fs:  `cpe:2.3:a:ibm:marketing_operations:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.06.08`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.06.10`,
        fs:  `cpe:2.3:a:wptrafficanalyzer:trafficanalyzer:3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.06.12`,
        fs:  `cpe:2.3:a:microsoft:visual_studio_.net:2005:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.06.14`,
        fs:  `cpe:2.3:a:x:libxxf86vm:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.06.15`,
        fs:  `cpe:2.3:a:vmware:workstation:11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.06.22`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.07.01`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.07.05`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.1.125:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:1.07.07`,
        fs:  `cpe:2.3:a:plogger:plogger:2.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.01.07`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.01.11`,
        fs:  `cpe:2.3:a:qemu:qemu:1.6.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.01.14`,
        fs:  `cpe:2.3:a:bufferapp:digg_digg:5.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.01.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.15.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.01.20`,
        fs:  `cpe:2.3:a:mediaelementjs:mediaelement.js:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.01.21`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.324:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.15`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.409:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.17`,
        fs:  `cpe:2.3:a:thulasidas:easy-adsense-lite:2.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.19`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:5.0.148.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.23`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8ex:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.27`,
        fs:  `cpe:2.3:a:gitlab:gitlab-shell:1.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.28`,
        fs:  `cpe:2.3:a:hp:ignite-ux:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.29`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.31`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.33`,
        fs:  `cpe:2.3:a:cisco:router_web_setup:3.3.0_build_30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.34`,
        fs:  `cpe:2.3:a:blinkwebeffects:social-media-widget:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.35`,
        fs:  `cpe:2.3:a:andre_wiethoff:exact_audio_copy:1.0beta1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.36`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:4.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.38`,
        fs:  `cpe:2.3:a:google:chrome:16.0.912.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.39`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.0\(1x\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.40`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.5-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.41`,
        fs:  `cpe:2.3:a:iss:blackice_agent_server:3.6ecc:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.44`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.45`,
        fs:  `cpe:2.3:a:git-scm:git:2.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:2.02.46`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board_i:1.11:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.09`,
        fs:  `cpe:2.3:a:sawmill:sawmill:8.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.16`,
        fs:  `cpe:2.3:a:ikiwiki:ikiwiki:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.18`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.64:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.23`,
        fs:  `cpe:2.3:a:apple:apple_tv:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.28`,
        fs:  `cpe:2.3:a:actividentity:activclient_cac:6.2.0.81:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.30`,
        fs:  `cpe:2.3:a:ibm:installation_manager:1.8.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.31`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp1:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.33`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.35`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.36`,
        fs:  `cpe:2.3:a:ssh:tectia_server:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.37`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.42`,
        fs:  `cpe:2.3:a:hp:cluster_object_manager:a.01.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.44`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.45`,
        fs:  `cpe:2.3:a:islonline:isl_desktop_plugin:1.3.3:-:-:*:windows:isl_light:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.46`,
        fs:  `cpe:2.3:a:apache:qpid:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt102i:3.00.47`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.02`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.05`,
        fs:  `cpe:2.3:h:hp:color_laserjet_cm2320n_multifunction_printer:cc434a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.07`,
        fs:  `cpe:2.3:a:apache:tomcat:7.0.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.09`,
        fs:  `cpe:2.3:a:janesoft:janetter:2.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.10`,
        fs:  `cpe:2.3:a:emc:networker:7.4:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.11`,
        fs:  `cpe:2.3:a:ibm:tivoli_secureway_policy_director:3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.13`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p137:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.14`,
        fs:  `cpe:2.3:o:asus:rt-n66u_firmware:3.0.0.4.376.3715:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.18`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.21`,
        fs:  `cpe:2.3:a:holding_pattern_project:holding_pattern:0.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.22`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.2.0:mu_\#7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.24`,
        fs:  `cpe:2.3:a:apple:java_1.4:1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.25`,
        fs:  `cpe:2.3:a:aol:toolbar:5.74.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.33`,
        fs:  `cpe:2.3:a:zingiri:zingiri_web_shop:2.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.35`,
        fs:  `cpe:2.3:a:digium:asterisk:14.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.36`,
        fs:  `cpe:2.3:a:susanglathar:suzanne_glathar:1.399:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.37`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.86:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.38`,
        fs:  `cpe:2.3:a:redhat:libvirt:1.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.39`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.1.008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.40`,
        fs:  `cpe:2.3:a:simon_brown:pebble:2.0.0:m1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.44`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.48`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_application_platform:6.4.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.53`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt103i:4.00.54`,
        fs:  `cpe:2.3:a:hp:linux_imaging_and_printing_project:3.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.02.03`,
        fs:  `cpe:2.3:a:gnome:glib:2.17.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.02.04`,
        fs:  `cpe:2.3:a:nagios:nagios:3.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.02.07`,
        fs:  `cpe:2.3:a:bottlepy:bottle:0.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.02.16`,
        fs:  `cpe:2.3:a:palletsprojects:werkzeug:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.02.19`,
        fs:  `cpe:2.3:a:devsaran:business:7.x-1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.04`,
        fs:  `cpe:2.3:a:buffalotech:bbr-4hg_firmware:1.43:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.08`,
        fs:  `cpe:2.3:a:ibm:websphere_edge_server_caching_proxy:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.11`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.15`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(19\)ew3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.18`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.25`,
        fs:  `cpe:2.3:a:sparxsystems:mdg_integration_for_microsoft_visual_studio:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.28`,
        fs:  `cpe:2.3:a:botan_project:botan:1.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.33`,
        fs:  `cpe:2.3:a:digium:asterisk:10.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105e:6.03.34`,
        fs:  `cpe:2.3:a:adobe:help_center:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.02.03`,
        fs:  `cpe:2.3:a:fengoffice:feng_office:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.02.04`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.02.07`,
        fs:  `cpe:2.3:a:digium:asterisk:13.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.02.16`,
        fs:  `cpe:2.3:a:dbd-mysql_project:dbd-mysql:3.0002_4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.02.19`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_preinstall:2009.1118.1260.23275:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.04`,
        fs:  `cpe:2.3:a:lennart_poettering:systemd:013:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.08`,
        fs:  `cpe:2.3:a:apache:hbase:0.98.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.11`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:3.2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.15`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.18`,
        fs:  `cpe:2.3:h:cisco:ie-4000-4gc4gp4g-e:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.25`,
        fs:  `cpe:2.3:a:roderich_schupp:par-packer_module:0.992_05:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.28`,
        fs:  `cpe:2.3:a:pivotal_software:cloud_foundry_ops_manager:1.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.33`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105i:6.03.34`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.4-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.02.03`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(22\)ea3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.02.04`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.02.07`,
        fs:  `cpe:2.3:a:phusionpassenger:phusion_passenger:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.02.16`,
        fs:  `cpe:2.3:a:organic_groups_project:organic_groups:7.x-2.0:beta4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.02.19`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:4.0.0r3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.04`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.08`,
        fs:  `cpe:2.3:a:ibm:lotus_inotes:229.231:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.11`,
        fs:  `cpe:2.3:a:sap:crystal_reports_basic_for_visual_studio:10.5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.15`,
        fs:  `cpe:2.3:h:cisco:telepresence_profile_65:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.18`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.25`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.28`,
        fs:  `cpe:2.3:a:email\:\:address_module_project:email\:\:address:1.900:*:*:*:*:perl:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.33`,
        fs:  `cpe:2.3:o:cisco:catos:4.1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt105p:6.03.34`,
        fs:  `cpe:2.3:a:oscommerce:oscommerce:2.2ms1j-r5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.06`,
        fs:  `cpe:2.3:a:securecomputing:safeword_remoteaccess:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.08`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.24`,
        fs:  `cpe:2.3:a:microsoft:antispyware:1.0.509:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.26`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.150:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.37`,
        fs:  `cpe:2.3:h:hp:zbook_17_g3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.41`,
        fs:  `cpe:2.3:a:vmturbo:operations_manager:4.5:1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.42`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:3:update7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.46`,
        fs:  `cpe:2.3:a:jeff_sterup:plugin-organizer:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.60`,
        fs:  `cpe:2.3:a:nicolas_tormo:phppaleo:4.8b155:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.61`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.68`,
        fs:  `cpe:2.3:a:sophos:sophos_anti-virus:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.70`,
        fs:  `cpe:2.3:a:cisco:intrusion_prevention_system:7.0\(8\)e4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.75`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p420:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.76`,
        fs:  `cpe:2.3:h:schneider-electric:bmxp342020h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.77`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.78`,
        fs:  `cpe:2.3:a:mozilla:seamonkey:2.17:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.80`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(2\)e1\(1g\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.82`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.15.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.83`,
        fs:  `cpe:2.3:a:ibm:watson_developer_cloud:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.87`,
        fs:  `cpe:2.3:a:google:chrome:10.0.648.126:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.88`,
        fs:  `cpe:2.3:a:apple:cups:1.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt107e:8.03.90`,
        fs:  `cpe:2.3:a:openbsd:openssh:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.01.06`,
        fs:  `cpe:2.3:a:hp:photosmart_essential:1.8.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.01.07`,
        fs:  `cpe:2.3:a:devicelock:devicelock:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.01.09`,
        fs:  `cpe:2.3:a:elite-board:elite_bulletin_board:2.1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.02.03`,
        fs:  `cpe:2.3:a:aviosoft:dtv_player:1.0.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.02.04`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.02.07`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.409:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.02.16`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:3.7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.02.19`,
        fs:  `cpe:2.3:a:pluck-cms:pluck:4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.04`,
        fs:  `cpe:2.3:a:nongnu:oath_toolkit:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.08`,
        fs:  `cpe:2.3:a:buffalotech:wer-amg54_firmware:1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.11`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6.0.0:alpha:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.15`,
        fs:  `cpe:2.3:a:google:android_api:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.18`,
        fs:  `cpe:2.3:a:ca:common_services:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.25`,
        fs:  `cpe:2.3:a:vandyke:securecrt:6.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.28`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1307.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.33`,
        fs:  `cpe:2.3:a:hitachi:ucosminexus_developer:07-00-10:-:pro:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140e:6.03.34`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p88:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.01.06`,
        fs:  `cpe:2.3:a:bigtreecms:bigtree_cms:4.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.01.07`,
        fs:  `cpe:2.3:a:2glux:com_sexypolling:1.0.9:-:-:*:-:joomla\!:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.01.09`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.583:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.02.03`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.5s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.02.04`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.02.07`,
        fs:  `cpe:2.3:h:cisco:nexus_5548up:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.02.16`,
        fs:  `cpe:2.3:a:mawashimono:nikki:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.02.19`,
        fs:  `cpe:2.3:a:download_manager_project:download_manager:1.2.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.04`,
        fs:  `cpe:2.3:a:trihedral:vtscada:10.2.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.08`,
        fs:  `cpe:2.3:a:mirror_photo_\&amp;_shape_project:mirror_photo_\&amp;_shape:1.4:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.11`,
        fs:  `cpe:2.3:a:susumu_terao:terapad:0.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.15`,
        fs:  `cpe:2.3:a:conky:conky:1.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.18`,
        fs:  `cpe:2.3:o:cisco:ios:12.3xy:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.25`,
        fs:  `cpe:2.3:a:danielb:finder:6.x-1.x-dev:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.28`,
        fs:  `cpe:2.3:a:ibm:web_experience_factory:6.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.33`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.42.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140f:6.03.34`,
        fs:  `cpe:2.3:a:symantec:im_manager:8.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.01.06`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.01.07`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.01.09`,
        fs:  `cpe:2.3:a:happyworm:jplayer:0.2.2:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.02.03`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.02.04`,
        fs:  `cpe:2.3:a:atheme:atheme:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.02.07`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.9.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.02.16`,
        fs:  `cpe:2.3:a:allroundautomations:pl\/sql_developer:11.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.02.19`,
        fs:  `cpe:2.3:a:microsoft:office:2001:sr1:mac_os:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.04`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.08`,
        fs:  `cpe:2.3:a:pureftpd:pure-ftpd:0.99:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.11`,
        fs:  `cpe:2.3:a:pgp:desktop_for_mac:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.15`,
        fs:  `cpe:2.3:a:torproject:tor:0.2.3.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.18`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.237:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.25`,
        fs:  `cpe:2.3:a:shrew:vpn_client:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.28`,
        fs:  `cpe:2.3:a:rsa:envision:4.0:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.33`,
        fs:  `cpe:2.3:a:bundler:bundler:1.7.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140i:6.03.34`,
        fs:  `cpe:2.3:a:oracle:mysql_connector\/j:5.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.01.06`,
        fs:  `cpe:2.3:a:hp:hppscanto:1.0.119:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.01.07`,
        fs:  `cpe:2.3:a:boatmob:boat_browser:4.5.1:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.01.09`,
        fs:  `cpe:2.3:a:freemind:freemind:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.02.03`,
        fs:  `cpe:2.3:a:merethis:centreon:2.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.02.04`,
        fs:  `cpe:2.3:a:phpfox:phpfox:3.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.02.07`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(20\)st2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.02.16`,
        fs:  `cpe:2.3:a:textpattern:textpattern:1.0:rc5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.02.19`,
        fs:  `cpe:2.3:a:adobe:experience_manager:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.04`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.08`,
        fs:  `cpe:2.3:a:mysql:community_server:5.0.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.11`,
        fs:  `cpe:2.3:a:google_site_search_project:google_site_search_module:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.15`,
        fs:  `cpe:2.3:a:filemaker:filemaker_pro:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.18`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.16:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.25`,
        fs:  `cpe:2.3:o:schneider_electric:struxureware_building_operations_automation_server_as-p_firmware:1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.28`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)sxd6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.33`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt140p:6.03.34`,
        fs:  `cpe:2.3:a:mozilla:firefox_esr:24.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.00.06`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.10.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.00.07`,
        fs:  `cpe:2.3:a:google:v8:3.22.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.01.07`,
        fs:  `cpe:2.3:a:apache:subversion:1.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.01.11`,
        fs:  `cpe:2.3:a:trick_question_project:trick_question:6.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.01.14`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.10.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.01.19`,
        fs:  `cpe:2.3:h:supermicro:x8dtn\&#43;-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.01.20`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:5.0:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.01.21`,
        fs:  `cpe:2.3:a:djangoproject:django:1.6.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.15`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.17`,
        fs:  `cpe:2.3:a:microsoft:bing:4.2.0:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.19`,
        fs:  `cpe:2.3:a:otrs:otrs:3.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.23`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4.8sg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.27`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.27.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.28`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.3.181415.1237:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.29`,
        fs:  `cpe:2.3:a:actividentity:desktop_validation_client:3.1.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.31`,
        fs:  `cpe:2.3:a:cs-cart:cs-cart:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.33`,
        fs:  `cpe:2.3:h:sendmail:sentrion:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.34`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.35`,
        fs:  `cpe:2.3:a:ca:etrust_antivirus:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.36`,
        fs:  `cpe:2.3:a:jcore:jcore:1.0:pre1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.38`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.99.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.39`,
        fs:  `cpe:2.3:a:postfix:postfix:2.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.40`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator_series_software:3.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.41`,
        fs:  `cpe:2.3:h:axis:2420_network_camera:2.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.44`,
        fs:  `cpe:2.3:a:igniterealtime:smack:4.0.0:snapshot-2014-04-06:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.45`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:2.02.46`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:2.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.09`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(1\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.16`,
        fs:  `cpe:2.3:h:lexmark:n8120:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.18`,
        fs:  `cpe:2.3:a:altiris:veritas_configuration_manager_integration_component:6.0.1005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.23`,
        fs:  `cpe:2.3:a:perl:perl:0.97:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.28`,
        fs:  `cpe:2.3:a:hp:storeonce_2620_iscsi_backup_system:3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.30`,
        fs:  `cpe:2.3:a:web-dorado:web-dorado_spider_video_player:1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.31`,
        fs:  `cpe:2.3:a:vmware:vcenter_converter_client:4.2.1.327369:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.33`,
        fs:  `cpe:2.3:a:davistribe:google_doc_embedder:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.35`,
        fs:  `cpe:2.3:a:activestate:activepython:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.36`,
        fs:  `cpe:2.3:o:ibm:vios:2.2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.37`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_enterprise:7.5\(9\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.42`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.44`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:3.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.45`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.46`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.20.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:3.00.47`,
        fs:  `cpe:2.3:a:adobe:flash_player:23.0.0.185:*:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.02`,
        fs:  `cpe:2.3:a:splunk:splunk:3.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.05`,
        fs:  `cpe:2.3:a:lansweeper:lansweeper:5.3.0.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.07`,
        fs:  `cpe:2.3:o:d-link:dir-619l_firmware:2.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.09`,
        fs:  `cpe:2.3:h:sony:playstation_portable:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.11`,
        fs:  `cpe:2.3:h:cisco:6400_nrp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.13`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p173:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.14`,
        fs:  `cpe:2.3:a:symantec:ghost_console_client:115.0.2141:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.18`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.21`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.5-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.22`,
        fs:  `cpe:2.3:a:apache:zookeeper:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.24`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:6.x-1.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.25`,
        fs:  `cpe:2.3:a:connect2id:nimbus_jose\&#43;jwt:2.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.33`,
        fs:  `cpe:2.3:a:typo3:typo3:4.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.35`,
        fs:  `cpe:2.3:o:cisco:vpn_3000_concentrator:4.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.36`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.2.0.899:p5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.37`,
        fs:  `cpe:2.3:a:oracle:vm_virtualbox:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.38`,
        fs:  `cpe:2.3:a:microsoft:ie:5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.39`,
        fs:  `cpe:2.3:o:yamaha:rt102i:1.06.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.40`,
        fs:  `cpe:2.3:h:hp:proliant_dl585:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.44`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:8.4\(.4.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.48`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.53`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt200i:4.00.54`,
        fs:  `cpe:2.3:a:clamav:clamav:0.80:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.19`,
        fs:  `cpe:2.3:h:swann:swnvw-470cam:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.28`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.38.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.31`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.35`,
        fs:  `cpe:2.3:a:haxx:libcurl:7.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.36`,
        fs:  `cpe:2.3:a:google:chrome:6.0.452.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.40`,
        fs:  `cpe:2.3:a:comodo:comodo_internet_security:5.3.174622.1216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.42`,
        fs:  `cpe:2.3:a:telos:amhs:12.10.0.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.43`,
        fs:  `cpe:2.3:a:matchalabs:metaslider:2.9:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.48`,
        fs:  `cpe:2.3:a:google:chrome:5.0.353.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt250i:8.02.50`,
        fs:  `cpe:2.3:a:gnu:libtasn1:2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.00.09`,
        fs:  `cpe:2.3:a:redhat:jboss_enterprise_soa_platform:4.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.00.11`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.00.15`,
        fs:  `cpe:2.3:a:botan_project:botan:1.11.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.00.17`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:2.16.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.00.20`,
        fs:  `cpe:2.3:a:isc:bind:9.2.4:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.00.22`,
        fs:  `cpe:2.3:a:isc:bind:9.10.1:b2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.00.25`,
        fs:  `cpe:2.3:a:ca:adviseit:2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.00.27`,
        fs:  `cpe:2.3:h:hp:procurve_router:jf237a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.01.06`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.12.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.01.07`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4:rc2:*:*:*:*:x86:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.01.09`,
        fs:  `cpe:2.3:a:citrix:xenapp_group_policy_management_experience:1.0.2.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.02.03`,
        fs:  `cpe:2.3:a:whmcs:whmcompletesolution:4.2.0:beta_r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.02.04`,
        fs:  `cpe:2.3:o:cisco:ios:11.1\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.02.07`,
        fs:  `cpe:2.3:a:bea:weblogic_server:5.1:sp4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.02.16`,
        fs:  `cpe:2.3:a:imember360:imember360:3.9.006:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.02.19`,
        fs:  `cpe:2.3:a:altiris:asset_management_report_pack:6.5.1049:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.03.04`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.4.0:rc6:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.03.08`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.03.11`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.03.15`,
        fs:  `cpe:2.3:h:brickom:wfb-100ap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.03.18`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:r2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.03.25`,
        fs:  `cpe:2.3:a:microsoft:orca:3.1.4000.1830:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.03.28`,
        fs:  `cpe:2.3:a:gemalto:smartdiag:2.0.67.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt300i:6.03.34`,
        fs:  `cpe:2.3:a:redhat:libvirt:0.8.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt56v:4.07.11`,
        fs:  `cpe:2.3:h:schneider_electric:sage_2400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt56v:4.07.19`,
        fs:  `cpe:2.3:a:hp:trayapp:70.0.170.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt56v:4.07.22`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt56v:4.07.30`,
        fs:  `cpe:2.3:a:igniterealtime:smack:3.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt56v:4.07.37`,
        fs:  `cpe:2.3:a:perl:perl:5.13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt56v:4.07.45`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1700.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt56v:4.07.49`,
        fs:  `cpe:2.3:h:softbank:android_smartphone:200sh:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt56v:4.07.54`,
        fs:  `cpe:2.3:a:revouninstaller:uninstaller:2.0:*:*:*:professional:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.13`,
        fs:  `cpe:2.3:a:pixman:pixman:0.20.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.14`,
        fs:  `cpe:2.3:a:debian:apt:0.7.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.19`,
        fs:  `cpe:2.3:a:ca:total_defense:r12:se2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.27`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.41`,
        fs:  `cpe:2.3:a:novell:edirectory:8.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.46`,
        fs:  `cpe:2.3:a:kelly_d._redding:kelredd-pruview:0.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.48`,
        fs:  `cpe:2.3:a:apple:safari:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.57`,
        fs:  `cpe:2.3:h:toshibatec:e-studio-283:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.66`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.70`,
        fs:  `cpe:2.3:o:iij:seil_x86_fuji_firmware:1.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.71`,
        fs:  `cpe:2.3:a:apache:tomcat:5.5.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.83`,
        fs:  `cpe:2.3:o:iij:seil\%2fb1_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.87`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:sp4:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.89`,
        fs:  `cpe:2.3:a:simple_retail_menus_plugin_project:simple-retail-menus:4.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt57i:8.00.91`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.11`,
        fs:  `cpe:2.3:a:httplib2_project:httplib2:0.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.13`,
        fs:  `cpe:2.3:a:techsmith:camtasia_relay:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.18`,
        fs:  `cpe:2.3:a:apexsql:apexsql_log:2008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.19`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.21`,
        fs:  `cpe:2.3:a:objective_development:little_snitch:3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.29`,
        fs:  `cpe:2.3:a:emery_berger:hoard:3.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.33`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.36`,
        fs:  `cpe:2.3:a:smb4k_project:smb4k:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.41`,
        fs:  `cpe:2.3:h:sierrawireless:airlink_mp_verizon_wifi:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.44`,
        fs:  `cpe:2.3:a:stunnel:stunnel:5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.48`,
        fs:  `cpe:2.3:a:jenkins:owasp_dependency-check:1.4.0:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt58i:9.01.49`,
        fs:  `cpe:2.3:a:coolpdf:coolpdf:3.0.2.256:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt60w:5.01.14`,
        fs:  `cpe:2.3:a:florian_weber:spaces:6.x-3.0:r2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt60w:5.01.16`,
        fs:  `cpe:2.3:a:nullsoft:winamp:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt60w:5.01.21`,
        fs:  `cpe:2.3:a:irods:irods:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.15`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:7.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.17`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.19`,
        fs:  `cpe:2.3:h:cisco:pix_vpn_accelerator_card\&#43;:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.23`,
        fs:  `cpe:2.3:a:typo3:typo3:6.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.27`,
        fs:  `cpe:2.3:a:linuxfoundation:foomatic-filters:4.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.28`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.29`,
        fs:  `cpe:2.3:a:webyog:sqlyog:4.02:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.31`,
        fs:  `cpe:2.3:a:oracle:exalogic_infrastructure:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.33`,
        fs:  `cpe:2.3:a:intelliants:subrion_cms:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.34`,
        fs:  `cpe:2.3:h:hp:jc125b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.35`,
        fs:  `cpe:2.3:a:herry:sfpagent:0.1.12:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.36`,
        fs:  `cpe:2.3:a:autodesk:raster_design:2006:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.38`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.39`,
        fs:  `cpe:2.3:a:dameware:nt_utilities:6.8.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.40`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.3.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.41`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.0.72:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.44`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.45`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:1.5.11\(3659\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:2.02.46`,
        fs:  `cpe:2.3:o:debian:debian_linux:9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.09`,
        fs:  `cpe:2.3:a:cisco:asr_5000_software:18.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.16`,
        fs:  `cpe:2.3:o:huawei:s7706_firmware:v100r002:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.18`,
        fs:  `cpe:2.3:o:freebsd:freebsd:6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.23`,
        fs:  `cpe:2.3:a:atlassian:confluence:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.28`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.30`,
        fs:  `cpe:2.3:a:pocoo:jinja2:2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.31`,
        fs:  `cpe:2.3:a:buddypress:buddypress_plugin:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.33`,
        fs:  `cpe:2.3:a:devscripts_devel_team:devscripts:2.13.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.35`,
        fs:  `cpe:2.3:a:strongswan:strongswan:2.6.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.36`,
        fs:  `cpe:2.3:a:fogproject:fog:0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.37`,
        fs:  `cpe:2.3:a:openstack:havana:2013.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.42`,
        fs:  `cpe:2.3:o:moxa:ioadmin_firmware:3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.44`,
        fs:  `cpe:2.3:a:emc:engineering_plant_facilities_management_solution_for_documentum:1.7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.45`,
        fs:  `cpe:2.3:o:fortinet:fortianalyzer_firmware:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.46`,
        fs:  `cpe:2.3:a:vmware:vrealize_orchestrator:6.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rt80i:3.00.47`,
        fs:  `cpe:2.3:a:avaya:ip_soft_phone:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.02.15`,
        fs:  `cpe:2.3:a:cmu:carnegie_mellon_silicon_valley:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.02.17`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.02.19`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:3.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.02.21`,
        fs:  `cpe:2.3:a:buydot:funny_\&amp;_interesting_things:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.03.25`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.03.28`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:7.0.6.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.03.29`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.102:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.03.34`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:6.0.303.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.03.35`,
        fs:  `cpe:2.3:o:netgear:d6400_firmware:1.0.0.56:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.04.39`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.14:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.04.44`,
        fs:  `cpe:2.3:a:connections_project:connections:0.7.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.04.47`,
        fs:  `cpe:2.3:a:david_king:vino:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.05.28`,
        fs:  `cpe:2.3:a:microsoft:netmeeting:3.0.1_4.4.3385:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.05.30`,
        fs:  `cpe:2.3:o:iij:seil\/b1_firmware:3.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.05.35`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.0.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.05.38`,
        fs:  `cpe:2.3:a:gpeasy:gpeasy_cms:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta50i:3.05.42`,
        fs:  `cpe:2.3:h:cisco:ids_4215:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta52i:3.06.20`,
        fs:  `cpe:2.3:o:sgi:irix:4.0.5e:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta52i:3.06.25`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:2.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta52i:4.01.06`,
        fs:  `cpe:2.3:a:phorum:phorum:5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta52i:4.01.09`,
        fs:  `cpe:2.3:a:gnome:librsvg:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta52i:4.01.11`,
        fs:  `cpe:2.3:o:yamaha:rtx2000:7.01.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta52i:4.01.14`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:h.10.54:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta52i:4.01.15`,
        fs:  `cpe:2.3:a:freetype:freetype:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta52i:4.01.17`,
        fs:  `cpe:2.3:a:google:chrome:8.0.552.342:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta54i:4.03.12`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)yb:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta54i:4.04.03`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0065:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta54i:4.04.05`,
        fs:  `cpe:2.3:a:robo-ftp:robo-ftp:3.0.0:-:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta54i:4.04.08`,
        fs:  `cpe:2.3:a:google:chrome:25.0.1364.118:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta54i:4.05.14`,
        fs:  `cpe:2.3:a:sap:netweaver_solution_manager:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta55i:4.06.28`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:3.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta55i:4.06.35`,
        fs:  `cpe:2.3:a:shaarli_project:shaarli:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta55i:4.06.47`,
        fs:  `cpe:2.3:a:ntp:ntp:4.3.69:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta55i:4.06.54`,
        fs:  `cpe:2.3:o:yahama:rt100i:2.02.44:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta55i:4.06.60`,
        fs:  `cpe:2.3:a:hp:veritas_recordnow:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rta55i:4.06.67`,
        fs:  `cpe:2.3:a:google:chrome:9.0.579.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.31`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1028:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.39`,
        fs:  `cpe:2.3:a:ibm:domino_web_access:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.45`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:7.0.2-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.53`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.0-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.56`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.60`,
        fs:  `cpe:2.3:a:groups_communities_and_co_project:gcc:7.x-1.0:alpha2:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.62`,
        fs:  `cpe:2.3:o:sgi:irix:6.5.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.69`,
        fs:  `cpe:2.3:o:microsoft:windows:vista:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.72`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.77`,
        fs:  `cpe:2.3:a:role_scoper_project:role_scoper:1.2.7:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.80`,
        fs:  `cpe:2.3:a:apache:cloudstack:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.81`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.84`,
        fs:  `cpe:2.3:h:siemens:scalance_x202-2p_irt_pro:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.86`,
        fs:  `cpe:2.3:a:atlassian:jira:5.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtv700:8.00.88`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtw65b:5.03.11`,
        fs:  `cpe:2.3:a:mongodb:mongodb:2.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtw65b:5.03.15`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:4.10.256:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtw65b:5.03.25`,
        fs:  `cpe:2.3:a:angusj:resource_hacker:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtw65i:5.03.11`,
        fs:  `cpe:2.3:a:webmin:usermin:1.060:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtw65i:5.03.15`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:05-01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtw65i:5.03.25`,
        fs:  `cpe:2.3:a:keepass:keepass:1.09:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.00.14`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.6e.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.00.15`,
        fs:  `cpe:2.3:a:ibm:websphere_message_broker:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.00.16`,
        fs:  `cpe:2.3:a:ibm:java:1.4.2.13.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.00.19`,
        fs:  `cpe:2.3:a:sophos:safeguard_enterprise_device_encryption:5.50.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.00.26`,
        fs:  `cpe:2.3:a:libav:libav:0.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.00.29`,
        fs:  `cpe:2.3:a:widgetfactorylimited:com_jce:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.00.30`,
        fs:  `cpe:2.3:h:swann:dvr4-securanet:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.04`,
        fs:  `cpe:2.3:a:mesa3d:mesa:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.05`,
        fs:  `cpe:2.3:a:isc:bind:9.10.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.08`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1685.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.15`,
        fs:  `cpe:2.3:h:hp:jd663b:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.16`,
        fs:  `cpe:2.3:a:hummingbird:docs_admin_tools:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.17`,
        fs:  `cpe:2.3:a:sybase:powerbuilder_virtual_machine:11.5.0.3127:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.26`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.29`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.34`,
        fs:  `cpe:2.3:a:digium:asterisk:11.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.41`,
        fs:  `cpe:2.3:a:vips:vips:7.12.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.47`,
        fs:  `cpe:2.3:a:emc:rsa_web_threat_detection:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.48`,
        fs:  `cpe:2.3:a:mysql:mysql:5.0.3a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.49`,
        fs:  `cpe:2.3:a:google:chrome:12.0.732.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.53`,
        fs:  `cpe:2.3:a:apple:itunes:4.5:*:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1000:7.01.54`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:414:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.06`,
        fs:  `cpe:2.3:a:cisco:unified_communications_domain_manager:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.08`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:2003:gold:x64-enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.24`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.16:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.26`,
        fs:  `cpe:2.3:a:atlassian:jira:3.0.3:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.37`,
        fs:  `cpe:2.3:a:siemens:scalance_xr-300_firmware:3.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.41`,
        fs:  `cpe:2.3:a:novell:netware_ftp_server:5.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.42`,
        fs:  `cpe:2.3:a:chatelao:php_address_book:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.46`,
        fs:  `cpe:2.3:a:ppfeufer:2-click-social-media-buttons:0.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.60`,
        fs:  `cpe:2.3:a:grape_project:grape:0.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.61`,
        fs:  `cpe:2.3:a:jenkins:git:2.0.4:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.68`,
        fs:  `cpe:2.3:o:sfr:sfr_box_router_firmware:nb6-main-r3.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.70`,
        fs:  `cpe:2.3:a:google:chrome:32.0.1659.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.75`,
        fs:  `cpe:2.3:a:apple:quicktime:6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.76`,
        fs:  `cpe:2.3:a:webyog:sqlyog:8.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.77`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.78`,
        fs:  `cpe:2.3:o:tvt:dvr_firmware:3.1.87.p-1.0.4.2-17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.80`,
        fs:  `cpe:2.3:h:cabletron:6h302-48:5.07.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.82`,
        fs:  `cpe:2.3:a:x.org:x11:6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.83`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.5.5sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.87`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.88`,
        fs:  `cpe:2.3:a:martin_lee:multi-lingual_e-commerce_system:0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1100:8.03.90`,
        fs:  `cpe:2.3:a:apache:http_server:2.0.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1200:10.01.08`,
        fs:  `cpe:2.3:o:microsoft:windows_nt:4.0:sru:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1200:10.01.11`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1200:10.01.16`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1200:10.01.22`,
        fs:  `cpe:2.3:a:vmware:ace:1.0.3_build_54075:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1200:10.01.24`,
        fs:  `cpe:2.3:a:cisco:wireless_control_system_software:4.1.83.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1200:10.01.29`,
        fs:  `cpe:2.3:a:ibm:rational_team_concert:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.06`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.8-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.08`,
        fs:  `cpe:2.3:a:prismmicrosys:eventtracker:7.0:beta:opsconsole:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.24`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.26`,
        fs:  `cpe:2.3:a:adobe:acrobat:9.4.6:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.37`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(8\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.41`,
        fs:  `cpe:2.3:a:spamdyke:spamdyke:4.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.42`,
        fs:  `cpe:2.3:a:paul_mattes:x3270:3.3.14:ga11:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.46`,
        fs:  `cpe:2.3:a:openvas:openvas_scanner:4.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.60`,
        fs:  `cpe:2.3:o:redhat:linux:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.61`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:16.0.0.282:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.68`,
        fs:  `cpe:2.3:a:getshopped:wp_e-commerce:3.6.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.70`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.2.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.75`,
        fs:  `cpe:2.3:a:symantec:client_security:3.0.2.2000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.76`,
        fs:  `cpe:2.3:a:moinmo:moinmoin:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.77`,
        fs:  `cpe:2.3:a:cisco:personal_assistant:1.3\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.78`,
        fs:  `cpe:2.3:o:juniper:screenos:6.2.0r18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.80`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.82`,
        fs:  `cpe:2.3:a:checkpoint:firewall-1:4.1:sp5a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.83`,
        fs:  `cpe:2.3:a:ibm:security_access_manager_for_web:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.87`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:2.2\(4b\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.88`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx1500:8.03.90`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.2.602:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.00.14`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:1.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.00.15`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.00.16`,
        fs:  `cpe:2.3:a:jenkins:script_security:1.20:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.00.19`,
        fs:  `cpe:2.3:a:hp:solution_center:12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.00.26`,
        fs:  `cpe:2.3:a:kurt_gusbeth:myquizpoll:2.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.00.29`,
        fs:  `cpe:2.3:a:tumbleweed:desktop_validator:4.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.00.30`,
        fs:  `cpe:2.3:a:apache:subversion:0.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.17`,
        fs:  `cpe:2.3:a:google:chrome:4.0.256.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.26`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_for_websphere_software:9.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.29`,
        fs:  `cpe:2.3:a:splunk:splunk:6.1.6:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.34`,
        fs:  `cpe:2.3:a:google:chrome:17.0.963.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.41`,
        fs:  `cpe:2.3:a:ibm:bootable_media_creator:9.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.47`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.48`,
        fs:  `cpe:2.3:a:connections_project:connections:0.5.47:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.49`,
        fs:  `cpe:2.3:a:gajennings:this:1.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.53`,
        fs:  `cpe:2.3:a:symantec:vrtsperl:5.1.10000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx2000:7.01.54`,
        fs:  `cpe:2.3:a:openvswitch:openvswitch:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.15`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:2.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.20`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.22`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.24`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.25`,
        fs:  `cpe:2.3:a:yahoo:autosync:1.0.4.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.31`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:4.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.37`,
        fs:  `cpe:2.3:a:pulsesecure:pulse_connect_secure:7.4r13.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.40`,
        fs:  `cpe:2.3:a:samba:samba:4.1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.43`,
        fs:  `cpe:2.3:a:apache:myfaces:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.44`,
        fs:  `cpe:2.3:a:blackberry:blackberry_link:1.1.1.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.47`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.20.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:rtx3000:9.00.48`,
        fs:  `cpe:2.3:a:pmwiki:pmwiki:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.09`,
        fs:  `cpe:2.3:o:cisco:asa_cx_context-aware_security_software:9.1.3-13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.19`,
        fs:  `cpe:2.3:a:adobe:kuler:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.21`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.22`,
        fs:  `cpe:2.3:o:cisco:ios_xr:5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.27`,
        fs:  `cpe:2.3:a:novell:client:4.91:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.28`,
        fs:  `cpe:2.3:a:docker:docker:0.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.31`,
        fs:  `cpe:2.3:a:ibm:tivoli_monitoring:6.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.38`,
        fs:  `cpe:2.3:a:parallels:parallels_plesk_panel:10.0.1:mu_\#10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.40`,
        fs:  `cpe:2.3:a:menalto:gallery:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.44`,
        fs:  `cpe:2.3:a:sun:rpc.ruserd:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.46`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.49`,
        fs:  `cpe:2.3:o:cisco:ios_xe_3.5sq:3.5.3sq:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.52`,
        fs:  `cpe:2.3:a:assyrianapp:assyrian:2.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.53`,
        fs:  `cpe:2.3:a:jasper_project:jasper:1.900.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yamaha:srt100:10.00.56`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.4.3:1037:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yaml-fuer-drupal:linkchecker:6.x-2.0`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yaml-fuer-drupal:linkchecker:6.x-2.1`,
        fs:  `cpe:2.3:o:cisco:wireless_lan_controller_software:7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yaml-fuer-drupal:linkchecker:6.x-2.2`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:9.1:-:lts:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yaml-fuer-drupal:linkchecker:6.x-2.3`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yaml-fuer-drupal:linkchecker:6.x-2.4`,
        fs:  `cpe:2.3:a:vmware:player:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yaml-fuer-drupal:linkchecker:6.x-2.5`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yaml-fuer-drupal:linkchecker:6.x-2.x:dev`,
        fs:  `cpe:2.3:a:adobe:extendscript_toolkit:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:6.x-1.0`,
        fs:  `cpe:2.3:a:philippe_jounin:tftpd32:2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:6.x-1.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:6.x-1.2`,
        fs:  `cpe:2.3:a:rocomotion:p_board_r:1.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:6.x-1.3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.17.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:6.x-1.4`,
        fs:  `cpe:2.3:a:op5:monitor:5.3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:6.x-1.5`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:6.x-1.6`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:5.5.2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:6.x-1.x:dev`,
        fs:  `cpe:2.3:a:quartz_plugin_project:quartz_plugin:1.01.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:7.x-1.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:7.x-1.1`,
        fs:  `cpe:2.3:a:openstack:neutron:2015.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:7.x-1.2`,
        fs:  `cpe:2.3:a:ibm:rational_clearquest:5.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:7.x-1.3`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:7.x-1.4`,
        fs:  `cpe:2.3:a:atlassian:jira:2.6.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:7.x-1.5`,
        fs:  `cpe:2.3:a:ibm:tivoli_business_service_manager:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yandex.metrics_project:yandex_metrics:7.x-1.x:dev`,
        fs:  `cpe:2.3:a:ibm:websphere_business_modeler_advanced:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yard_radius:yard_radius:1.0.16`,
        fs:  `cpe:2.3:a:smarty:smarty:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yard_radius_project:yard_radius:1.0.16`,
        fs:  `cpe:2.3:a:pidgin:pidgin:2.10.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yard_radius_project:yard_radius:1.1.2-4`,
        fs:  `cpe:2.3:o:ibm:security_access_manager_for_web_7.0_firmware:7.0.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yassl:cyassl:2.5.0`,
        fs:  `cpe:2.3:o:tp-link:archer_c9_\(1.0\)_firmware:150122:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yassl:cyassl:2.6.0`,
        fs:  `cpe:2.3:a:webyog:sqlyog:3.5:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yassl:cyassl:2.7.0`,
        fs:  `cpe:2.3:a:wireshark:wireshark:1.8.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yassl:cyassl:2.8.0`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.8u:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yassl:cyassl:2.9.0`,
        fs:  `cpe:2.3:a:horde:groupware:1.1.3:*:webmail:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yassl:cyassl:2.9.4`,
        fs:  `cpe:2.3:a:magentocommerce:magento:1.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yealink:sip-t38g:-`,
        fs:  `cpe:2.3:a:papercut:papercut_ng:14.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yealink:voip_phone:28.2.0.128.0.0.0`,
        fs:  `cpe:2.3:a:apple:xcode:3.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:yealink:voip_phone_firmware:28.72.0.2`,
        fs:  `cpe:2.3:a:gnome:glib:2.23.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yeast_infection_project:yeast_infection:0.1::~~~android~~`,
        fs:  `cpe:2.3:a:redhat:icedtea-web:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yellowbook:yellow_pages_local_search:11.0.0`,
        fs:  `cpe:2.3:a:yahoo:messenger:10.0.0.1258:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.0`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.2.8:p2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.1`,
        fs:  `cpe:2.3:a:cisco:telepresence_system_software:6.1.0\(90\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.2`,
        fs:  `cpe:2.3:a:brian_akers:mod_layout:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.3`,
        fs:  `cpe:2.3:h:cisco:sg500-28mpp:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.4`,
        fs:  `cpe:2.3:a:hp:nonstop_server_software:h06.20.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.5`,
        fs:  `cpe:2.3:a:pgp:personal_security:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.6`,
        fs:  `cpe:2.3:a:blackberry:enterprise_server:5.0.4:mr6:*:*:*:lotus_domino:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.7`,
        fs:  `cpe:2.3:a:cmsimple:cmsimple_classic:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.8`,
        fs:  `cpe:2.3:a:strongswan:strongswan:5.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.9`,
        fs:  `cpe:2.3:a:huawei:espace_8950:v200r003c00spc200:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.10`,
        fs:  `cpe:2.3:a:teampass:teampass:2.1.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.11`,
        fs:  `cpe:2.3:o:yamaha:rt107e:8.03.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.13`,
        fs:  `cpe:2.3:a:atlassian:oauth:1.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.14`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:8.0\(2c\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.15`,
        fs:  `cpe:2.3:a:apache:wicket:1.4.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:1.1.16`,
        fs:  `cpe:2.3:a:oracle:jdk:1.7.0:update_91:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yiiframework:yiiframework:2.0.3`,
        fs:  `cpe:2.3:a:ibm:websphere_mq_explorer:8.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yikyakapp:yik_yak:2.0.002::~~~android~~`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(3\)jaa:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.5.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.6.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.352:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.6.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:microsoft.aspnetcore.mvc.formatters.json:1.0.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.6.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fluik:office_zombie:1.3.13:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.6.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:clamav:clamav:0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:saia_burgess_controls:pcd7.d4xxwtpf_wvga_mb_firmware:1.24.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:flag_module_project:flag:7.x-3.0:alpha4:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.7.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(18\)s10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.7.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cubecart:cubecart:3.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.7.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:daniel_friesel:feh:1.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:1.7.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:oracle:opus_10g_ethernet_switch_family:1.2.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoast:wordpress_seo:2.1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:cognos_business_intelligence:10.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yodl_project:yodl:3.06.00`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yodobashi:yodobashi:1.2.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:shinephp:thank_you_counter_button:1.6.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yodobashi:yodobashi:1.4.4::~~~android~~`,
        fs:  `cpe:2.3:a:xerox:docushare:6.5.3:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:aaasuite:-`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.111.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:b%2fm9000_vp:-`,
        fs:  `cpe:2.3:a:primetek:primefaces:3.4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:b%2fm9000_vp_software:7.03.01`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:b%2fm9000cs:-`,
        fs:  `cpe:2.3:a:botan_project:botan:1.10.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:b%2fm9000cs_software:5.05.01`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.13.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:centum_cs_1000:-`,
        fs:  `cpe:2.3:a:mcafee:web_gateway:7.4.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_1000_software:-`,
        fs:  `cpe:2.3:a:marvell:mrvlusgtracking:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:centum_cs_3000:-`,
        fs:  `cpe:2.3:o:yahama:rt105p:6.02.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.01`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.02`,
        fs:  `cpe:2.3:a:google:chrome:13.0.782.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.03`,
        fs:  `cpe:2.3:a:orchardproject:orchard:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.04`,
        fs:  `cpe:2.3:a:smackcoders:wp_ultimate_email_marketer_plugin:1.0.3:-:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.05`,
        fs:  `cpe:2.3:a:microsoft:outlook:2000:sr1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.06`,
        fs:  `cpe:2.3:h:hp:jc124a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.07`,
        fs:  `cpe:2.3:o:yahama:rt100i:1.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.08`,
        fs:  `cpe:2.3:a:hp:insight_diagnostics_online_edition_for_windows:8.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.08.50`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.08.70`,
        fs:  `cpe:2.3:a:andy_armstrong:cgi.pm:2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.09`,
        fs:  `cpe:2.3:a:sightlinesystems:power_agent_for_windows_2000_datacenter:6.3.502:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.09.50`,
        fs:  `cpe:2.3:a:verifone:vericentre_web_console:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000:r3.09.76`,
        fs:  `cpe:2.3:a:oxid-esales:eshop:5.0.8:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:centum_cs_3000_entry_class:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.7-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000_entry_class_software:3.09.50`,
        fs:  `cpe:2.3:a:mailpoet:mailpoet_newsletters:2.5.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_cs_3000_software:2.23.00`,
        fs:  `cpe:2.3:a:gnu:privacy_guard:1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:centum_event_viewer_package:-`,
        fs:  `cpe:2.3:a:cisco:unified_communications_manager:7.0\(1\)su1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:centum_long-term_trend_historian:-`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:centum_vp:-`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.72:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_vp:r4.03.00`,
        fs:  `cpe:2.3:a:web2py:web2py:1.80.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_vp:r5.01.00`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_vp:r5.01.20`,
        fs:  `cpe:2.3:a:hp:esupportdiagnostics:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_vp:r5.02.00`,
        fs:  `cpe:2.3:a:oracle:supply_chain_products_suite:9.3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_vp:r5.03.00`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(4\)xe1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:centum_vp_entry_class:-`,
        fs:  `cpe:2.3:a:xoops:xoops:2.5.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_vp_entry_class_software:5.03.00`,
        fs:  `cpe:2.3:o:compaq:tru64:5.1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_vp_software:4.03.00`,
        fs:  `cpe:2.3:a:isc:bind:9.7.0a2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:centum_vp_software:5.03.20`,
        fs:  `cpe:2.3:a:broadcom:management_programs:12.30.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:daqopc:-`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:daqopc_for_darwin:-`,
        fs:  `cpe:2.3:a:microsoft:silverlight:4.1.10111:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:ejxmvtool:-`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.15.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:exaopc:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.6-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:exaopc:3.71.02`,
        fs:  `cpe:2.3:a:gnu:gdb:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:exaopc:3.71.10`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:exaopc:3.72.00`,
        fs:  `cpe:2.3:a:bfgminer:bfgminer:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:exaplog:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p233:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:exaquantum:-`,
        fs:  `cpe:2.3:a:ntp:ntp:p93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:exaquantum%2fbatch:-`,
        fs:  `cpe:2.3:o:cisco:pix_firewall:6.0\(3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:exarqe:-`,
        fs:  `cpe:2.3:a:mahara:mahara:15.04.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:exasmoc:-`,
        fs:  `cpe:2.3:a:ibm:lotus_notes_traveler:8.5.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:fast%2ftools:r9.01`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:fast%2ftools:r9.02`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:fast%2ftools:r9.03`,
        fs:  `cpe:2.3:a:rimarts:becky\!_internet_mail:2.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:fast%2ftools:r9.04`,
        fs:  `cpe:2.3:a:gradkell:dbsign_administration_tools:3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yokogawa:fast%2ftools:r9.05`,
        fs:  `cpe:2.3:a:metalogix:sharepoint_extensions_web_service:4.1.1303:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:field_wireless_device_opc_server:-`,
        fs:  `cpe:2.3:a:zimbra:collaboration_server:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:fieldmate:-`,
        fs:  `cpe:2.3:a:mm_forum_project:mm_forum:1.9.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:omegaland%2fopc_server_interface_module:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:3.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:prm:-`,
        fs:  `cpe:2.3:h:grandstream:gxv3615w\/p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:prosafe-rs:-`,
        fs:  `cpe:2.3:a:cisco:optical_networking_systems_software:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:prosafe-rs_%28chs2200%3a_soe_opc_interface_package%29:-`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p223:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:rpo_production_supervisor_vp:-`,
        fs:  `cpe:2.3:a:contao:contao_cms:2.1.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:yokogawa:stardom_fcn%2ffcj_opc_server:-::~~~windows~~`,
        fs:  `cpe:2.3:a:s9y:serendipity:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoshinori_tahara:mycaljp:2.0.0`,
        fs:  `cpe:2.3:o:innominate:mguard_firmware:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoshinori_tahara:mycaljp:2.0.1`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect_realtime:9.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoshinori_tahara:mycaljp:2.0.2`,
        fs:  `cpe:2.3:a:elasticsearch:elasticsearch:1.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoshinori_tahara:mycaljp:2.0.3`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.6.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoshinori_tahara:mycaljp:2.0.4`,
        fs:  `cpe:2.3:a:libpng:libpng:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoshinori_tahara:mycaljp:2.0.5`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoshinori_tahara:mycaljp:2.0.6`,
        fs:  `cpe:2.3:a:microsoft:word:2001:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yoshinori_tahara:mycaljp:2.0.7`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:youmail:youmail_visual_voicemail_plus:2.0.45`,
        fs:  `cpe:2.3:a:dalbum:dalbum:1.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:youmail:youmail_visual_voicemail_plus:2.1.43`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:your-text-manager_project:your-text-manager:0.3.0:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:nvidia:gpu_driver_r340:341.43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yourfreeworld:banner_management:-`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.4:r3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yourkit:java_profiler:7.0.9`,
        fs:  `cpe:2.3:a:barnowl:barnowl:1.4:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yourls:yourls:1.7`,
        fs:  `cpe:2.3:h:cisco:nexus_1000v:4.2\(1\)sv1\(5.2b\):-:*:*:*:vmware_vsphere:*:*`,
    },
     
    {
        uri: `cpe:/a:yourmembers_project:yourmembers:-::~~~wordpress~~`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.6:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yourtango:your_tango:1::~~~android~~`,
        fs:  `cpe:2.3:a:gnome:glib:2.10.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:youtube_embed_project:youtube_embed:3.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:telepresence_serial_gateway:1.0.1.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yuba:u5cms:3.9.3`,
        fs:  `cpe:2.3:a:veritas:netbackup_appliance:2.6.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yuichiro_okuyama:tetra_filer:1.5.1:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yuichiro_okuyama:tetra_filer:2.3.1:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:heinz_mauelshagen:lvm2:2.02.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yuichiro_okuyama:tetra_filer_free:1.5.1:-:~-~-~android~~`,
        fs:  `cpe:2.3:h:huawei:espace_8950:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yuichiro_okuyama:tetra_filer_free:2.3.1:-:~-~-~android~~`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.7.1-5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yumenomachi:demaecan:2.0.0::~~~android~~`,
        fs:  `cpe:2.3:a:skyphe:file-gallery:1.5.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:yumenomachi:demaecan:2.1.0::~~~android~~`,
        fs:  `cpe:2.3:a:libmspack_project:libmspack:0.4-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yumenomachi:demaecan:2.2.0::~~~android~~`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.93:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yumenomachi:demaecan:2.2.1::~~~android~~`,
        fs:  `cpe:2.3:a:digium:asterisk:11.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yunlai:a%2b:1.0.1::~~~android~~`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.0.34:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yuriy_v_semenikhin:yvs_image_gallery:-`,
        fs:  `cpe:2.3:a:campaign_monitor_project:campaign_monitor:7.x-1.0:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:yurl_retwitt_project:yurl_retwitt:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.1\(.3\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:yysun:git_source_control_provider:0.6.2`,
        fs:  `cpe:2.3:a:amazon:elastic_load_balancing_api_tools:1.0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1`,
        fs:  `cpe:2.3:o:citrix:netscaler_gateway_firmware:10.1.129:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta10`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.2.31:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta11`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta12`,
        fs:  `cpe:2.3:a:cisco:telepresence_video_communication_server:x8.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta2`,
        fs:  `cpe:2.3:a:microsoft:visio:2007:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta3`,
        fs:  `cpe:2.3:a:danielb:cool_aid:6.x-1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta4`,
        fs:  `cpe:2.3:a:notredame:notredame_seguradora:1.2:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta5`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:3.0.0.a8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta6`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta7`,
        fs:  `cpe:2.3:a:cisco:web_security_virtual_appliance:7.1.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta8`,
        fs:  `cpe:2.3:h:cisco:wide_area_application_engine:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1:beta9`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1.1`,
        fs:  `cpe:2.3:a:newrelic:ruby_agent:3.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1.2`,
        fs:  `cpe:2.3:a:webyog:sqlyog:5.19:-:community:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1.3`,
        fs:  `cpe:2.3:a:gnu:cfengine:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1.4`,
        fs:  `cpe:2.3:a:x:libxres:1.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1.5`,
        fs:  `cpe:2.3:o:moxa:miineport_e3_firmware:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1.6`,
        fs:  `cpe:2.3:a:oracle:application_server_portal:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.1.7`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3:beta`,
        fs:  `cpe:2.3:a:adobe:acrobat_dc:17.012.20095:*:*:*:continuous:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3.1:beta`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.377:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3.2:beta`,
        fs:  `cpe:2.3:a:david_king:vino:2.99.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3.3:beta`,
        fs:  `cpe:2.3:a:barebones:bbedit:10.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3.4:beta`,
        fs:  `cpe:2.3:a:activestate:activeperl:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3.5:beta`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.1.0.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3.6:beta`,
        fs:  `cpe:2.3:o:linux:linux_kernel:4.10.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3.7:beta`,
        fs:  `cpe:2.3:a:microsoft:outlook:2007:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.3.8:beta`,
        fs:  `cpe:2.3:a:debian:apt:0.7.15:exp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.4.2`,
        fs:  `cpe:2.3:a:pintsized:synx_addictive_puzzle_game:1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.4.3`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.5:p166:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.4.4`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.1.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.4.5`,
        fs:  `cpe:2.3:a:gnupg:libgcrypt:1.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.4.6`,
        fs:  `cpe:2.3:a:apple:cups:1.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.5:beta`,
        fs:  `cpe:2.3:o:cisco:staros:18.0.l0.59219:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.5.1:beta`,
        fs:  `cpe:2.3:a:microsoft:ie:5.00.3700.1000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.5.2:beta`,
        fs:  `cpe:2.3:a:phorum:phorum:3.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.5.3:beta`,
        fs:  `cpe:2.3:a:ca:license_software:1.62.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.5.4:beta`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_client:06-51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6`,
        fs:  `cpe:2.3:a:redhat:automatic_bug_reporting_tool:1.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.1`,
        fs:  `cpe:2.3:a:quest:application_integration_tool:1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.2`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.37:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.3`,
        fs:  `cpe:2.3:o:juniper:junos:12.3:r4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.4`,
        fs:  `cpe:2.3:a:netscape:enterprise_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.5`,
        fs:  `cpe:2.3:o:citrix:netscaler_application_delivery_controller_firmware:10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.6`,
        fs:  `cpe:2.3:a:featurific_for_wordpress_project:featurific-for-wordpress:1.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.7`,
        fs:  `cpe:2.3:a:bestpractical:rt:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.8`,
        fs:  `cpe:2.3:a:symantec:veritas_netbackup_enterprise_server:5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.6.9`,
        fs:  `cpe:2.3:a:tryton:tryton:1.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.7`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.5:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.7.1`,
        fs:  `cpe:2.3:a:rubyonrails:ruby_on_rails:0.14.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.7.2`,
        fs:  `cpe:2.3:a:drupal:drupal:8.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.7.3`,
        fs:  `cpe:2.3:a:hp:vertica:7.0.2.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.7.4`,
        fs:  `cpe:2.3:a:keepass:keepass:1.00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8`,
        fs:  `cpe:2.3:a:http-body_project:http-body:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.1`,
        fs:  `cpe:2.3:a:microsoft:orca:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.2`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.3:rc1`,
        fs:  `cpe:2.3:h:apple:imac:mb391xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.3:rc2`,
        fs:  `cpe:2.3:a:mutt:mutt:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.3:rc3`,
        fs:  `cpe:2.3:a:google:chrome:37.0.2062.74:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.10:rc1`,
        fs:  `cpe:2.3:a:nginx:nginx:1.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.10:rc2`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:3.2\(23\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.15:rc1`,
        fs:  `cpe:2.3:a:cisco:unified_contact_center_express_editor_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.16`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30173:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.18`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:2.1.1.0:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.19`,
        fs:  `cpe:2.3:a:mortbay:jetty:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:1.8.21`,
        fs:  `cpe:2.3:a:exim:exim:4.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.0`,
        fs:  `cpe:2.3:o:yamaha:rt140f:6.03.28:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.0:rc1`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.0:rc2`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.40:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.0:rc3`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.0.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.0:rc4`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.07:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.0:rc5`,
        fs:  `cpe:2.3:a:hp:insight_management_wbem_providers_for_windows_server_2003\/2008:2.3.0.0:*:*:*:*:*:x64:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.0:rc6`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.6:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.1`,
        fs:  `cpe:2.3:a:randall_hand:yerase\&#39;s_tnef_stream_reader:1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.1:rc1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.1:rc2`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7i:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.2`,
        fs:  `cpe:2.3:a:apple:safari:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.2:rc1`,
        fs:  `cpe:2.3:a:commentluv:commentluv:2.81.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.2:rc2`,
        fs:  `cpe:2.3:h:cisco:wireless_control_system:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.3`,
        fs:  `cpe:2.3:a:ca:messaging:1.07.220.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.3:rc1`,
        fs:  `cpe:2.3:a:apache:libcloud:0.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.3:rc2`,
        fs:  `cpe:2.3:a:fanshawec:fol:3.0.729.1459:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.4`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.0.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.4:rc1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.5`,
        fs:  `cpe:2.3:a:percona:percona_server:5.6.25-73.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.5:rc1`,
        fs:  `cpe:2.3:a:redhat:rhel_application_server:2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.6`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.11.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.6:rc1`,
        fs:  `cpe:2.3:a:roundcube:roundcube_webmail:1.2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.7:rc1`,
        fs:  `cpe:2.3:a:fail2ban:fail2ban:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.8:rc1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.13:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.8:rc2`,
        fs:  `cpe:2.3:o:valvesoftware:steam_link_firmware:628:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.9:rc1`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.9:rc2`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.7.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.10:rc1`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:ga:client:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.11:rc1`,
        fs:  `cpe:2.3:h:cisco:asa_5500:7.2\(2\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.11:rc2`,
        fs:  `cpe:2.3:a:mercurial:mercurial:3.7.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.12:rc1`,
        fs:  `cpe:2.3:a:zend:zend_framework:2.0.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.12:rc2`,
        fs:  `cpe:2.3:a:adobe:download_manager:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.12:rc3`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.13`,
        fs:  `cpe:2.3:a:umn:mapserver:7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.13:rc1`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.14`,
        fs:  `cpe:2.3:a:webform_validation_project:webform_validation:6.x-1.1:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.15`,
        fs:  `cpe:2.3:a:calligra:calligra:2.4:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.16`,
        fs:  `cpe:2.3:a:postgresql:postgresql:9.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.0.17`,
        fs:  `cpe:2.3:a:apple:safari:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.1.0`,
        fs:  `cpe:2.3:a:atlassian:jira:3.5.1:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.1.1`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.4:rc0:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.0:-`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:2.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.0:rc1`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mb985xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.0:rc2`,
        fs:  `cpe:2.3:a:cisco:prime_collaboration_assurance:10.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.1:-`,
        fs:  `cpe:2.3:a:opensis:opensis:4.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.1:rc1`,
        fs:  `cpe:2.3:a:google:chrome:7.0.517.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.2:-`,
        fs:  `cpe:2.3:a:symantec:veritas_enterprise_administrator_service:3.3.1064:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.2:rc1`,
        fs:  `cpe:2.3:a:augeas:augeas:0.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.2:rc2`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.2:rc3`,
        fs:  `cpe:2.3:a:adobe:flash_player:18.0.0.194:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.3:-`,
        fs:  `cpe:2.3:a:steven_jones:context:7.x-3.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.3:rc1`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.3:rc2`,
        fs:  `cpe:2.3:o:cisco:catos:3.2\(7\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.4`,
        fs:  `cpe:2.3:a:apache:opennlp:1.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.4:rc1`,
        fs:  `cpe:2.3:a:yoshinori_tahara:mycaljp:2.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.4:rc2`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:2.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.4:rc3`,
        fs:  `cpe:2.3:a:ca:unicenter_asset_management:3.2:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.4:rc4`,
        fs:  `cpe:2.3:a:getgosoft:getgo_download_manager:4.8.2.1346:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.5`,
        fs:  `cpe:2.3:a:novell:netware_client:4.82:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.5:rc1`,
        fs:  `cpe:2.3:a:atmail:atmail:6.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.6`,
        fs:  `cpe:2.3:a:janetter:janetter:1.7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.6:rc1`,
        fs:  `cpe:2.3:a:ibm:egatherer:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.7`,
        fs:  `cpe:2.3:a:apache:tomcat:8.5.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.7:rc1`,
        fs:  `cpe:2.3:a:isc:dhcpd:3.0.1:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.7:rc2`,
        fs:  `cpe:2.3:a:centrify:centrify_deployment_manager:2.1.0.283:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.8`,
        fs:  `cpe:2.3:a:symantec:protection_for_sharepoint_servers:6.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.9`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p75:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.10`,
        fs:  `cpe:2.3:a:prestashop:prestashop:1.4.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.11`,
        fs:  `cpe:2.3:a:kde:kdelibs:4.12.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:2.2.12`,
        fs:  `cpe:2.3:a:ruby-lang:ruby:1.8.7:p352:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:3.0.0`,
        fs:  `cpe:2.3:a:photogallerycreator:flash-album-gallery:2.55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zabbix:zabbix:3.0.2`,
        fs:  `cpe:2.3:a:bea:weblogic_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zanematthew:zm_ajax_login_%26_register:1.0.9::~~~wordpress~~`,
        fs:  `cpe:2.3:a:b2evolution:b2evolution:6-9-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:webapp:1.5`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7:*:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:webapp:1.6`,
        fs:  `cpe:2.3:a:microsoft:proxy_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:webapp:2.0:beta2`,
        fs:  `cpe:2.3:a:cisco:unified_computing_system:1.3\(1t\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:5.00`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:1.8.1:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:5.01`,
        fs:  `cpe:2.3:a:debian:dpkg:1.4.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:5.02`,
        fs:  `cpe:2.3:a:clamav:clamav:0.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:5.10`,
        fs:  `cpe:2.3:a:cisco:hosted_collaboration_solution:8.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:5.11`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:2.6.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:5.20`,
        fs:  `cpe:2.3:a:netscape:fasttrack_server:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:5.22`,
        fs:  `cpe:2.3:a:liferay:liferay_portal:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.00`,
        fs:  `cpe:2.3:a:ibm:emptoris_spend_analysis:10.0.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.01`,
        fs:  `cpe:2.3:a:boltwire:boltwire:3.2.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.02`,
        fs:  `cpe:2.3:a:quest:intrust_report_pack_for_oracle:10.2.5.1024:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.03`,
        fs:  `cpe:2.3:a:gnu:grep:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.10`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.11`,
        fs:  `cpe:2.3:a:kayako:fusion:4.40.1148:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:2.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20.2`,
        fs:  `cpe:2.3:a:smithmicro:vzaccess_manager:6.7.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20.3`,
        fs:  `cpe:2.3:a:bueltge:adminimize:1.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20.5`,
        fs:  `cpe:2.3:a:debian:trousers:0.2.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20.6`,
        fs:  `cpe:2.3:a:avscripts:av_arcade_pro:5.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20.7`,
        fs:  `cpe:2.3:a:ca:cohesion_agent:4.5.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20.10`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20.11`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.11:*:open_source:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.20.12`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2010.211.1739.31663:*:*:cs:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.0`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.5.8:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.3`,
        fs:  `cpe:2.3:a:bayashi:dopvstar\*:0008:b:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.4`,
        fs:  `cpe:2.3:a:kde:kde_sc:4.0.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.5`,
        fs:  `cpe:2.3:a:irfanview:irfanview:3.75:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.6`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.34.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.7`,
        fs:  `cpe:2.3:o:citrix:netscaler_access_gateway_firmware:10.1.123.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.8`,
        fs:  `cpe:2.3:a:qemu:qemu:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.9`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.0.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.10`,
        fs:  `cpe:2.3:a:ovirt:ovirt:3.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.11`,
        fs:  `cpe:2.3:a:checkpoint:ng-ai:r55:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.13`,
        fs:  `cpe:2.3:a:ca:mlink:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.16`,
        fs:  `cpe:2.3:a:samba:samba:2.2.7a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.30.17`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.8.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.0`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_core_implementation:2009.0925.1707.28889:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.2`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.3`,
        fs:  `cpe:2.3:a:schedmd:slurm:16.05.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.4`,
        fs:  `cpe:2.3:a:symantec:data_center_security_server:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.5`,
        fs:  `cpe:2.3:a:hp:version_control_agent:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.6`,
        fs:  `cpe:2.3:a:typo3:typo3:4.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.7`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.15:rc8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.8`,
        fs:  `cpe:2.3:a:deltek:open_plan_professional:3.2.0.864:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.9`,
        fs:  `cpe:2.3:a:adobe:acrobat_reader_dc:15.006.30394:*:*:*:classic:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.10`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.2:1007:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.11`,
        fs:  `cpe:2.3:a:quiz_module_project:quiz:6.x-4.0:-:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.12`,
        fs:  `cpe:2.3:h:hp:jetdirect_380x:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.13`,
        fs:  `cpe:2.3:a:pharscape:hsolink:1.0.118-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.14`,
        fs:  `cpe:2.3:a:cisco:adaptive_security_appliance_software:9.2.4.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.15`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.12:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.16`,
        fs:  `cpe:2.3:a:digium:asterisk:10.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:6.40.17`,
        fs:  `cpe:2.3:o:yahama:rt107e:8.03.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0`,
        fs:  `cpe:2.3:o:microsoft:windows:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.7-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.2`,
        fs:  `cpe:2.3:o:bluecoat:sgos:4.2.3.26:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.3`,
        fs:  `cpe:2.3:a:tryton:tryton:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.4`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.5`,
        fs:  `cpe:2.3:a:apache:struts:2.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.6`,
        fs:  `cpe:2.3:a:ibm:director_agent:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.7`,
        fs:  `cpe:2.3:a:baramundi:management_suite:8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.8`,
        fs:  `cpe:2.3:a:spreecommerce:spree:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.9`,
        fs:  `cpe:2.3:a:openstack:pycadf:0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.10`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.11`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1005:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.12`,
        fs:  `cpe:2.3:a:oracle:retail_order_management_system_cloud_service:3.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.0.13`,
        fs:  `cpe:2.3:a:tracker-software:pdf-xchange:2.5.208:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.1.0`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:4.12.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.1.1`,
        fs:  `cpe:2.3:a:oracle:knowledge_management:12.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.1.2`,
        fs:  `cpe:2.3:a:hitachi:serverconductor\/deploymentmanager:06-00-\/a:-:-:ja:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.1.3`,
        fs:  `cpe:2.3:a:mozilla:firefox:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.1.4`,
        fs:  `cpe:2.3:a:jens_vagelpohl:zope-ldapuserfolder:2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.1.8`,
        fs:  `cpe:2.3:a:lockon:ec-cube:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.1.9`,
        fs:  `cpe:2.3:a:compaq:foundation_agents:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa:7.1.10`,
        fs:  `cpe:2.3:a:wordpress:wordpress:3.8.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.0`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:2.1.28:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.1`,
        fs:  `cpe:2.3:a:f5:big-ip_edge_gateway:10.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.2`,
        fs:  `cpe:2.3:a:oracle:retail_order_broker_cloud_service:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.3`,
        fs:  `cpe:2.3:a:apple:motion:5.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.4`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.6:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.5`,
        fs:  `cpe:2.3:a:obm:open_business_management:2.2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.6`,
        fs:  `cpe:2.3:o:microsoft:windows_server_2008:-:sp2:x32:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.7`,
        fs:  `cpe:2.3:a:quantum:scalar_i500_firmware:i6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.8`,
        fs:  `cpe:2.3:a:emberjs:ember.js:1.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.9`,
        fs:  `cpe:2.3:a:ganeti_project:ganeti:2.15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.10`,
        fs:  `cpe:2.3:h:iss:proventia_m_series_xpu:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.11`,
        fs:  `cpe:2.3:a:microsoft:word:95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.12`,
        fs:  `cpe:2.3:a:ssh:tectia_client:6.2.2.198:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.0.13`,
        fs:  `cpe:2.3:a:ibm:java_2_sdk:5.0.16.13:*:*:*:technology:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.0`,
        fs:  `cpe:2.3:a:symantec:norton_antivirus:10.0.1.1008:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.1`,
        fs:  `cpe:2.3:a:redhat:jboss_operations_network:3.3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.2`,
        fs:  `cpe:2.3:a:yokogawa:centum_cs_3000:r3.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.3`,
        fs:  `cpe:2.3:h:juniper:mx10:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.4`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.5`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-452_firmware:t364sy0j354:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.6`,
        fs:  `cpe:2.3:a:daum_communications:daumgame_activex_control:1.1.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.7`,
        fs:  `cpe:2.3:a:icu-project:international_components_for_unicode:3.4:*:*:*:*:java:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.8`,
        fs:  `cpe:2.3:a:ssh:tectia_server:5.0.0_a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.9`,
        fs:  `cpe:2.3:a:siteminder_for_secure_proxy_server:6.0:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.10`,
        fs:  `cpe:2.3:o:cisco:vpn_3060_concentrator:3.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.11`,
        fs:  `cpe:2.3:a:openttd:openttd:0.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.1.12`,
        fs:  `cpe:2.3:a:3s-software:codesys_runtime_system:2.3.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zarafa:zarafa_collaboration_platform:7.2.0`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.12:rc4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zcms_project:zcms:1.1`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.0:beta15:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zcubes:zpaint:1.4`,
        fs:  `cpe:2.3:a:boombatower:subuser:6.x-1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zdstatistics_project:zdstatistics:2.0.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:skysa:skysa_app_bar_integration_plugin:1.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zebra:zp_450:-`,
        fs:  `cpe:2.3:a:cyberlink:powerdirector:8.00.3022:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zebra_technologies:setup_utilities:1.0.0`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zebra_technologies:setup_utilities:1.1.4.838`,
        fs:  `cpe:2.3:a:winpcap:winpcap:3.1:beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zed_shaw:mongrel:0.3.13.3`,
        fs:  `cpe:2.3:a:emc:avamar:6.1.100-402:-:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:zed_shaw:mongrel:0.3.13.4`,
        fs:  `cpe:2.3:a:google:chrome:10.0.611.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zed_shaw:mongrel:0.3.13.5`,
        fs:  `cpe:2.3:a:rubygems:rubygems:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zed_shaw:mongrel:1.0.1`,
        fs:  `cpe:2.3:a:sympa:sympa:6.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeenshare_project:zeenshare:1.0.1:-:~-~-~wordpress~~`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.433:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection:11.0.1:mp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.1::~~~wordpress~~`,
        fs:  `cpe:2.3:o:watchguard:fireware:11.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(6.8\)t1a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.3::~~~wordpress~~`,
        fs:  `cpe:2.3:o:huawei:s9700_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.3.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:openssl:openssl:0.9.7m:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.3.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:integration_bus:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.3.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:microsoft:directx:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.4::~~~wordpress~~`,
        fs:  `cpe:2.3:o:sun:solaris:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ecava:integraxor:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:igniterealtime:smack_api:4.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:southrivertech:titan_ftp_server:5.23.351:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.8::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cisco:secure_access_control_server:5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:1.8.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:zulip:zulip_server:1.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:2.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:rim:blackberry_software:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:2.4.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:flatnux:flatnux:2008-12-11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:2.5.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:labtam-inc:proftp:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:2.6::~~~wordpress~~`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.90:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:2.7::~~~wordpress~~`,
        fs:  `cpe:2.3:a:ibm:lotus_symphony:3.0.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:2.7.1::~~~wordpress~~`,
        fs:  `cpe:2.3:a:emc:vplex_geosynchrony:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:related_posts:2.7.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:djangoproject:django:1.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:search_everything:7.0.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.77:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:search_everything:7.0.3::~~~wordpress~~`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.4:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zemanta:search_everything:8.0::~~~wordpress~~`,
        fs:  `cpe:2.3:a:adobe:flash_player_for_android:11.1.115.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:-`,
        fs:  `cpe:2.3:a:rapid7:nexpose:5.5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.1.0`,
        fs:  `cpe:2.3:a:vips:vips:7.7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.1.3`,
        fs:  `cpe:2.3:a:ibm:connections:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.0d`,
        fs:  `cpe:2.3:a:dotnetnuke:dotnetnuke:7.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.1:patch1`,
        fs:  `cpe:2.3:o:huawei:s7706_firmware:v100r003:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.1d`,
        fs:  `cpe:2.3:a:adobe:adobe_air:3.6.0.6090:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.2d`,
        fs:  `cpe:2.3:a:hp:photosmart_disclabel_plugin:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.3d`,
        fs:  `cpe:2.3:a:oracle:commerce_guided_search_and_experience_manager:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.4.1`,
        fs:  `cpe:2.3:a:cisco:security_manager:3.2.2:-:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.4d`,
        fs:  `cpe:2.3:a:opendocman:opendocman:1.2.6.7:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.5d`,
        fs:  `cpe:2.3:a:florian_heidenreich:mp3tag:v2.46a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.2.6d`,
        fs:  `cpe:2.3:a:wordpress:wordpress:2.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3`,
        fs:  `cpe:2.3:a:cisco:application_control_engine_software:a3\(2.5\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3:::ja`,
        fs:  `cpe:2.3:a:ixiacom:ixia_tcl:8.4.14.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.0.1:::ja`,
        fs:  `cpe:2.3:a:ibm:business_process_manager:7.5.1.1:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.0.2`,
        fs:  `cpe:2.3:a:alex_kellner:powermail:1.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.0.2:::ja`,
        fs:  `cpe:2.3:a:openafs:openafs:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.2`,
        fs:  `cpe:2.3:a:openswan:openswan:2.6.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.5`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.92:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.6`,
        fs:  `cpe:2.3:a:mcafee:common_management_agent:3.5.5.580:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.7`,
        fs:  `cpe:2.3:a:uoregon:tau:2.16.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.8`,
        fs:  `cpe:2.3:a:yoast:wordpress_seo:1.7.3.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.8a`,
        fs:  `cpe:2.3:a:altiris:out_of_band_setup_and_configuration_solution:6.2.1040:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.9`,
        fs:  `cpe:2.3:a:mortbay:jetty:6.1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.3.9h`,
        fs:  `cpe:2.3:a:k5n:webcalendar:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.5`,
        fs:  `cpe:2.3:a:zabbix:zabbix:1.8.3:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.5:::ja`,
        fs:  `cpe:2.3:a:wesnoth:battle_for_wesnoth:1.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.5.1:::ja`,
        fs:  `cpe:2.3:a:linuxfoundation:cups-filters:1.18.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:1.6.0`,
        fs:  `cpe:2.3:a:namazu:namazu:1.4.0.0:beta5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart:zen_cart:2008`,
        fs:  `cpe:2.3:a:xfree86:xfree86:4.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart.jp:zen_cart:1.3:::ja-jp`,
        fs:  `cpe:2.3:a:cisco:telepresence_tc_software:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart.jp:zen_cart:1.3.0.1:::ja-jp`,
        fs:  `cpe:2.3:a:mlmmj:mlmmj:1.2.9:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart.jp:zen_cart:1.3.0.2:::ja-jp`,
        fs:  `cpe:2.3:a:ibm:rational_quality_manager:3.0.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zen-cart.jp:zen_cart:1.5.0:::ja-jp`,
        fs:  `cpe:2.3:a:wonderplugin:audio_player:2.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.00.12`,
        fs:  `cpe:2.3:a:seeon:seeon:4.0.7:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.00.19`,
        fs:  `cpe:2.3:a:tecnick:tcexam:11.3.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.01.06`,
        fs:  `cpe:2.3:a:ibm:openpages_grc_platform:7.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.02.08`,
        fs:  `cpe:2.3:a:nuance:omnipage_web:1.0:*:*:*:personal:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.02.10`,
        fs:  `cpe:2.3:a:boost:boost:1.53.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.02.11`,
        fs:  `cpe:2.3:a:accomplishtechnology:phpmydirectory:1.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.02.12`,
        fs:  `cpe:2.3:a:opsview:opsview:4.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.03.13`,
        fs:  `cpe:2.3:a:samba:samba:3.6.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:1.04.06`,
        fs:  `cpe:2.3:a:google:chrome:22.0.1229.51:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zencast:zencast:2.00.07`,
        fs:  `cpe:2.3:o:yamaha:rta55i:4.06.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.0`,
        fs:  `cpe:2.3:a:hp:photo_and_imaging_software:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.0:rc1`,
        fs:  `cpe:2.3:a:apache:hadoop:2.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.0:rc2`,
        fs:  `cpe:2.3:h:dahuasecurity:dvr5108h:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.0:rc2a`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.0:rc3`,
        fs:  `cpe:2.3:a:macromedia:coldfusion:6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.1`,
        fs:  `cpe:2.3:a:glpi-project:glpi:0.80:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.2`,
        fs:  `cpe:2.3:a:todd_miller:sudo:1.8.6p3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.3`,
        fs:  `cpe:2.3:a:mobiloud:mobiloud:1.5.4:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.0.4`,
        fs:  `cpe:2.3:a:drupal:drupal:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.0`,
        fs:  `cpe:2.3:a:inkscape:inkscape:0.48.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.0:pl`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.3-7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.0:pr`,
        fs:  `cpe:2.3:a:namazu:namazu:1.1.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.0:rc1`,
        fs:  `cpe:2.3:a:php_font_lib_project:php_font_lib:0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.0:rc2`,
        fs:  `cpe:2.3:a:joomla:joomla\!:2.5.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.0:rc3`,
        fs:  `cpe:2.3:a:atlassian:bamboo:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.1`,
        fs:  `cpe:2.3:a:cubecart:cubecart:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.2`,
        fs:  `cpe:2.3:a:viewvc:viewvc:1.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.5.3`,
        fs:  `cpe:2.3:a:microsoft:system.net.http:4.3.1:*:*:*:*:asp.net:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.6.0`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.6.0:rc1`,
        fs:  `cpe:2.3:a:haxx:libcurl:6.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.6.0:rc2`,
        fs:  `cpe:2.3:a:bftpd_project:bftpd:1.0.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.6.0:rc3`,
        fs:  `cpe:2.3:a:microsoft:expression_design:4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.6.1`,
        fs:  `cpe:2.3:a:niif:shibb_auth:5.x-2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.6.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_fastback:5.5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.0`,
        fs:  `cpe:2.3:a:impresscms:impresscms:1.2.3:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.0:pl1`,
        fs:  `cpe:2.3:a:simplemachines:simple_machines_forum:1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.0:pr`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.1.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.1`,
        fs:  `cpe:2.3:h:generaldynamics:taclane:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.2:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.3`,
        fs:  `cpe:2.3:a:ps_project_management_team:unity-firefox-extension:2.3.3:-:*:*:*:firefox:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.3:pl1`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:4.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.4`,
        fs:  `cpe:2.3:a:winscp:winscp:5.0.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.5`,
        fs:  `cpe:2.3:h:huawei:honor_4c:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.6`,
        fs:  `cpe:2.3:a:antoine_beaupre:hostmaster:6.x-1.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.7`,
        fs:  `cpe:2.3:h:emc:rsa_data_protection_manager_appliance:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.8`,
        fs:  `cpe:2.3:a:bas_van_beek:multishop:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.7.9`,
        fs:  `cpe:2.3:a:apple:cups:1.1.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.0`,
        fs:  `cpe:2.3:a:google:chrome:24.0.1312.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.0:a1`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.0:a1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.0:b1`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5120-28p-pwr-si:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.1`,
        fs:  `cpe:2.3:a:google:chrome:23.0.1271.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.2`,
        fs:  `cpe:2.3:o:microsoft:windows-nt:4.0:gold:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.3`,
        fs:  `cpe:2.3:a:citrix:access_gateway_plug-in:9.0:*:*:*:enterprise:windows:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.4`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:4.1:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.4:pl1`,
        fs:  `cpe:2.3:a:oracle:jinitiator:1.1.8.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.8.5`,
        fs:  `cpe:2.3:a:lyesoft:andexplorer:1.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.0`,
        fs:  `cpe:2.3:a:ibm:lotus_sametime_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.0:a1`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.0.2.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.0:b1`,
        fs:  `cpe:2.3:a:tinc-vpn:tinc:1.1:pre5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.0:rc1`,
        fs:  `cpe:2.3:a:google:chrome:14.0.798.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.1`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:11.1.1.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.2`,
        fs:  `cpe:2.3:h:cisco:unified_ip_phone_7961g-ge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.3`,
        fs:  `cpe:2.3:a:websvn:websvn:1.61:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.3:pl1`,
        fs:  `cpe:2.3:a:checkpoint:check_point_integrity_client:4.5.122.000:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.4`,
        fs:  `cpe:2.3:a:nginx:nginx:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.5`,
        fs:  `cpe:2.3:a:hp:system_management_homepage:2.1.8.179:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.6`,
        fs:  `cpe:2.3:a:ibm:websphere_transformation_extender:8.3.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.7`,
        fs:  `cpe:2.3:a:zen-cart:zen_cart:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.9.8`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.1\(3\)es07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.0`,
        fs:  `cpe:2.3:a:onefile:onefile_ignite:1.19:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.0:alpha1`,
        fs:  `cpe:2.3:h:apple:macbook_pro:mc371xx\/a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.0:beta1`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.0:rc1`,
        fs:  `cpe:2.3:a:symantec:symav_filter_domino_nt:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.1`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.4.88:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.2`,
        fs:  `cpe:2.3:h:kepware:kepserverex_communications_platform:5.5.98.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.3`,
        fs:  `cpe:2.3:a:cakefoundation:cakephp:2.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.4`,
        fs:  `cpe:2.3:a:tincan:phplist:2.10.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.5`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.6.1-2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.6`,
        fs:  `cpe:2.3:h:loytec:lip-me201:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.7`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.8`,
        fs:  `cpe:2.3:a:civicrm:civicrm:4.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.10.9`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.0`,
        fs:  `cpe:2.3:a:enl_newsletter_plugin_project:enl-newsletter:1.0.1:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.0:b1`,
        fs:  `cpe:2.3:a:devsaran:creative:7.x-1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.0:rc1`,
        fs:  `cpe:2.3:o:ibm:power_5_system_firmware:sf240_202_201:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.1`,
        fs:  `cpe:2.3:a:jonathan_leung:show_in_browser:0.0.3:*:*:*:*:ruby:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.2`,
        fs:  `cpe:2.3:o:codeaurora:android-msm:3.12.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.3`,
        fs:  `cpe:2.3:a:zabbix:zabbix:2.0.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.4`,
        fs:  `cpe:2.3:o:trustix:secure_linux:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.5`,
        fs:  `cpe:2.3:a:acquia:mollom:6.x-2.7:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.6`,
        fs:  `cpe:2.3:h:cisco:886va_integrated_services_router:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.7`,
        fs:  `cpe:2.3:a:openbsd:openssh:4.4p1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.8`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.20.1:patch:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.9`,
        fs:  `cpe:2.3:a:simplejson_project:simplejson:3.0.9:*:*:*:*:python:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.10`,
        fs:  `cpe:2.3:a:tntnet:tntnet:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.11`,
        fs:  `cpe:2.3:a:tumbleweed:messaging_management_system:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.12`,
        fs:  `cpe:2.3:a:hp:instant_toptools:5.04:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.11.13`,
        fs:  `cpe:2.3:a:koha:koha:3.14.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.0`,
        fs:  `cpe:2.3:a:emc:controlcenter_master_agent:6.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.0:rc1`,
        fs:  `cpe:2.3:a:horde:horde_application_framework:3.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.0:rc2`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:3.1.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.0:rc3`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.0:beta4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.0:rc4`,
        fs:  `cpe:2.3:a:isc:bind:9.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.4`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.6`,
        fs:  `cpe:2.3:a:google:v8:3.23.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.8`,
        fs:  `cpe:2.3:a:apache:myfaces:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.9`,
        fs:  `cpe:2.3:a:user_relationships_project:user_relationships:6.x-1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.10`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.0:alpha1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.11`,
        fs:  `cpe:2.3:a:mozilla:bugzilla:3.4.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.12`,
        fs:  `cpe:2.3:a:google:chrome:9.0.597.100:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.13`,
        fs:  `cpe:2.3:a:hp:alm_synchronizer:1.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.15`,
        fs:  `cpe:2.3:a:redmine:redmine:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:1.12.19`,
        fs:  `cpe:2.3:a:citrix:xenapp_management:6.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.0`,
        fs:  `cpe:2.3:a:emc:navisphere_command_line_interface:26.5.0.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.0:rc1`,
        fs:  `cpe:2.3:a:apple:itunes:6.0.0:-:windows:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.0:rc2`,
        fs:  `cpe:2.3:a:microsoft:visio:2016:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.0:rc3`,
        fs:  `cpe:2.3:a:adobe:framemaker:9.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.0:rc4`,
        fs:  `cpe:2.3:a:roundup-tracker:roundup:1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.0:rc5`,
        fs:  `cpe:2.3:a:citrix:xenapp_advanced_configuration:4.5.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.0:rc6`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_manager_for_virtual_environments:6.3.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.0:rc7`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(21\)st7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.1`,
        fs:  `cpe:2.3:a:google:chrome:30.0.1599.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.2`,
        fs:  `cpe:2.3:a:ibm:rational_focal_point:6.6.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.3`,
        fs:  `cpe:2.3:a:pivotal_software:spring_framework:3.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.4`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.0.9:pre2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.5`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.6`,
        fs:  `cpe:2.3:a:ffmpeg:ffmpeg:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.0.7`,
        fs:  `cpe:2.3:o:yamaha:rta54i:4.05.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.1.0`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.1.1`,
        fs:  `cpe:2.3:a:clipbucket_project:clipbucket:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.1.2`,
        fs:  `cpe:2.3:a:angrydonuts:ctools:7.x-1.0:alpha2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.1.3`,
        fs:  `cpe:2.3:a:apple:safari:8.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.1.4`,
        fs:  `cpe:2.3:a:vtiger:vtiger_crm:6.0.0:rc:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.1.5`,
        fs:  `cpe:2.3:a:good:good_for_enterprise:2.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.1.6`,
        fs:  `cpe:2.3:a:ca:license_software:1.60.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.2.0`,
        fs:  `cpe:2.3:a:ifdefined:bugtracker.net:0.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.2.1`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:p7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.2.8`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.45.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.2.9`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.95:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.2.10`,
        fs:  `cpe:2.3:a:hp:mercury_performance_center_agent:8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.3.3`,
        fs:  `cpe:2.3:a:avaya:intuity_audix:5.1.46:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.3.4`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.3.5`,
        fs:  `cpe:2.3:a:ganglia:ganglia-web:3.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.3.6`,
        fs:  `cpe:2.3:a:novell:groupwise:6.5.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.3.7`,
        fs:  `cpe:2.3:a:sap:business_object_processing_framework_for_abap:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.3.8`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.3.9`,
        fs:  `cpe:2.3:h:hp:h3c_switch:s5100-26c-ei_ls-5100-26c-ei-ovs:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.4.0`,
        fs:  `cpe:2.3:a:davidsneal:simple_share_buttons_adder:3.6:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.4.1`,
        fs:  `cpe:2.3:a:hp:copy:45.4.157.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.4.2`,
        fs:  `cpe:2.3:a:platinum_seo_project:platinum_seo_plugin:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.4.3`,
        fs:  `cpe:2.3:a:eliteweaver:xclick_cart:1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.4.4`,
        fs:  `cpe:2.3:h:iss:proventia_a_series_xpu:22.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.4.5`,
        fs:  `cpe:2.3:a:apple:safari:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.5.0`,
        fs:  `cpe:2.3:a:sensiolabs:symfony:2.3.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_framework:2.5.1`,
        fs:  `cpe:2.3:a:l-3com:decision_agent_migration_tools_installer:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zend_server:5.1.0`,
        fs:  `cpe:2.3:a:apple:safari:1.3.2:312.5:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendopenid:2.0.1`,
        fs:  `cpe:2.3:o:ge:multilink_ml3100_firmware:5.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendrest:2.0.1`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendservice_amazon:2.0.2`,
        fs:  `cpe:2.3:o:cisco:ios_xr:4.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendservice_api:1.0.0`,
        fs:  `cpe:2.3:a:google:v8:3.12.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendservice_audioscrobbler:2.0.1`,
        fs:  `cpe:2.3:a:realnetworks:realplayer:11.0.2.2315:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendservice_nirvanix:2.0.1`,
        fs:  `cpe:2.3:o:enea:ose:1.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendservice_slideshare:2.0.1`,
        fs:  `cpe:2.3:a:mortbay:jetty:3.0.a2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendservice_technorati:2.0.1`,
        fs:  `cpe:2.3:a:ibm:infoprint_21:1.047012:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendservice_windowsazure:2.0.1`,
        fs:  `cpe:2.3:a:tryton:tryton:2.8.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.00`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.138:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.01`,
        fs:  `cpe:2.3:a:rocomotion:p_up_board:1.03:*:gbo:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.02`,
        fs:  `cpe:2.3:a:image_metadata_cruncher_project:image_metadata_cruncher:-:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.03-3`,
        fs:  `cpe:2.3:a:otrs:otrs:0.5:beta7:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.05-2`,
        fs:  `cpe:2.3:a:atlassian:jira:3.7.4:*:professional:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.06-2`,
        fs:  `cpe:2.3:a:cdsincdesign:simple_dropbox_upload_form:1.8.8.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.07-1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.4s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.08-4`,
        fs:  `cpe:2.3:a:rpm:rpm:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.09-1`,
        fs:  `cpe:2.3:a:ibm:financial_transaction_manager:3.0.0.6:*:*:*:*:cps_services:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.10-4`,
        fs:  `cpe:2.3:a:redhat:lvm2:2.02.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.10-5`,
        fs:  `cpe:2.3:a:avto-russia:russian_federation_traffic_rules:1.21:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-1`,
        fs:  `cpe:2.3:o:juniper:junos:13.2:r7-s1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-2`,
        fs:  `cpe:2.3:a:elxis:elxis_cms:2008.1:revision_2204:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-3`,
        fs:  `cpe:2.3:a:gnu:libtool:1.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-4`,
        fs:  `cpe:2.3:a:formsplayer:formsplayer:1.5.1:1029:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-5`,
        fs:  `cpe:2.3:a:devexpress:aspxfilemanager_control_for_webforms_and_mvc:11.2.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-7`,
        fs:  `cpe:2.3:a:heimdal_project:heimdal:0.2r:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-8`,
        fs:  `cpe:2.3:a:mozilla:firefox:1.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-9`,
        fs:  `cpe:2.3:a:haudenschilt:family_connections_cms:1.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-10`,
        fs:  `cpe:2.3:a:puppetlabs:facter:1.6.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-11`,
        fs:  `cpe:2.3:a:openwebanalytics:open_web_analytics:1.2.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-12`,
        fs:  `cpe:2.3:a:codiad:codiad:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-13`,
        fs:  `cpe:2.3:a:gnu:grub2:2.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zend:zendto:4.11-14`,
        fs:  `cpe:2.3:a:ibm:rational_software_architect:9.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenoss:zenoss:4.2.5`,
        fs:  `cpe:2.3:a:web2py:web2py:1.90.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:0.9`,
        fs:  `cpe:2.3:a:marked_project:marked:0.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.0:beta`,
        fs:  `cpe:2.3:a:apache:myfaces:2.1.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.0.1:beta`,
        fs:  `cpe:2.3:a:postgresql:postgresql:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.0.4`,
        fs:  `cpe:2.3:a:atlassian:bamboo:5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.0.5`,
        fs:  `cpe:2.3:a:lunascape:lunascape:6.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.0.6`,
        fs:  `cpe:2.3:a:david_king:vino:3.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.1`,
        fs:  `cpe:2.3:a:bmc:bladelogic_server_automation_rscd_agent:8.0.7.711:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.1.1`,
        fs:  `cpe:2.3:o:cisco:ios_xr:3.3\(.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.1.2`,
        fs:  `cpe:2.3:o:cisco:catos:7.6\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.1.3`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.1.7`,
        fs:  `cpe:2.3:a:webkitgtk:webkitgtk\&#43;:2.4.5a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.2.5`,
        fs:  `cpe:2.3:o:cisco:vpn_3005_concentrator:3.6.7.d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.3`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.3.1.2`,
        fs:  `cpe:2.3:o:rockwellautomation:1769_compactlogix_l3x_controller_firmware:20.010:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.2`,
        fs:  `cpe:2.3:o:iij:seil_b1_firmware:3.32:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise_portal:8.9:bundle2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(8b\)e15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5.2`,
        fs:  `cpe:2.3:a:zencast:zencast:2.00.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5.3`,
        fs:  `cpe:2.3:a:apache:tomcat:8.0.39:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5.4`,
        fs:  `cpe:2.3:a:google:chrome:27.0.1453.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5.5`,
        fs:  `cpe:2.3:a:git-scm:git:2.7.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5.6`,
        fs:  `cpe:2.3:a:freedownloadmanager:free_download_manager:3.9.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5.7`,
        fs:  `cpe:2.3:a:adobe:acrobat:7.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.5.8`,
        fs:  `cpe:2.3:o:cisco:ios:3.3.2xo:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenphoto:zenphoto:1.4.7`,
        fs:  `cpe:2.3:a:adobe:robohelp:7.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenprise:zenprise_device_manager:6.0`,
        fs:  `cpe:2.3:a:jenkins:git:2.2.11:*:*:*:*:jenkins:*:*`,
    },
     
    {
        uri: `cpe:/a:zenprise:zenprise_device_manager:6.1.0`,
        fs:  `cpe:2.3:a:cloudfoundry:cf-release:216:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenprise:zenprise_device_manager:6.1.5`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.1.3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenprise:zenprise_device_manager:6.1.6`,
        fs:  `cpe:2.3:h:siemens:sinamics_s120cm:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zenprise:zenprise_device_manager:6.1.8`,
        fs:  `cpe:2.3:h:axis:2400_video_server:2.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeptolab:cut_the_rope%3a_time_travel:1.3.4::~~~android~~`,
        fs:  `cpe:2.3:a:wpeasycart:wp_easycart:1.2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.0.5`,
        fs:  `cpe:2.3:a:rom_walton:boinc:7.1.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.0.7`,
        fs:  `cpe:2.3:a:3com:tippingpoint_ips_tos:2.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.0.8`,
        fs:  `cpe:2.3:a:joomla:joomla\!:1.5.22:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.1.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.5.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.1.1`,
        fs:  `cpe:2.3:h:linksys:wrt54gs:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.1.2`,
        fs:  `cpe:2.3:a:happyworm:jplayer:2.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.1.3`,
        fs:  `cpe:2.3:h:hp:ca251a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.1.4`,
        fs:  `cpe:2.3:a:git-scm:git:0.99.8g:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.1.5`,
        fs:  `cpe:2.3:a:mozilla:network_security_services:3.19.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.1.6`,
        fs:  `cpe:2.3:o:google:chrome_os:25.0.1364.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.1.7`,
        fs:  `cpe:2.3:a:hp:procurve_manager:4.0:*:*:*:*:plus:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.2.0`,
        fs:  `cpe:2.3:a:apache:xerces-c\&#43;\&#43;:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.2.1`,
        fs:  `cpe:2.3:h:nortel:universal_signaling_point:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.2.2`,
        fs:  `cpe:2.3:a:cisco:identity_services_engine_software:1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.2.3`,
        fs:  `cpe:2.3:a:apache:openoffice:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.3.0`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-tf-182_with_network_printer_kit_firmware:t282cn0j421:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeroclipboard_project:zeroclipboard:1.3.1`,
        fs:  `cpe:2.3:a:cisco:network_admission_control_manager_and_server_system_software:4.0.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeromq:zeromq:4.0.5`,
        fs:  `cpe:2.3:a:nordugrid:nordugrid-arc:0.4.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeromq:zeromq:4.1.0:rc1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3`,
        fs:  `cpe:2.3:a:businessobjects:crystal_enterprise_xi:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3.1`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3.2`,
        fs:  `cpe:2.3:o:bluecoat:proxysg:5.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3.3`,
        fs:  `cpe:2.3:h:symantec:mail_security_8820_appliance:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3.4`,
        fs:  `cpe:2.3:a:motorola:123scan2:1.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3.5`,
        fs:  `cpe:2.3:o:cisco:ios:15.3\(2\)s1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3.6`,
        fs:  `cpe:2.3:a:isc:bind:9.7.3:b1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3.7`,
        fs:  `cpe:2.3:a:citrix:access_management_console_knowledge_base:4.8.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.3.8`,
        fs:  `cpe:2.3:a:cmscout:cmscout:1.02.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:3.4`,
        fs:  `cpe:2.3:a:xyzscripts:newsletter_manager:1.0.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:4.1`,
        fs:  `cpe:2.3:a:novell:zenworks_server_management:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:4.1:r1`,
        fs:  `cpe:2.3:a:salome-platform:salome:5.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:4.2`,
        fs:  `cpe:2.3:a:xymon:xymon:4.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:4.2:r2`,
        fs:  `cpe:2.3:a:oracle:peoplesoft_enterprise:8.8:bundle13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:4.3`,
        fs:  `cpe:2.3:a:check_mk_project:check_mk:1.4.0:b9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:4.3:r3`,
        fs:  `cpe:2.3:a:vmware:vsphere_data_protection:5.5.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:4.3:r4`,
        fs:  `cpe:2.3:h:cisco:asa_5500:7.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus:zeus_web_server:4.3r5`,
        fs:  `cpe:2.3:a:ibm:security_identity_manager:5.1.0.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.05%2f21`,
        fs:  `cpe:2.3:a:ibm:general_parallel_file_system_storage_server:2.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.05%2f22`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.3.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.05%2f29`,
        fs:  `cpe:2.3:a:ipswitch:whatsup_gold:11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.05%2f31`,
        fs:  `cpe:2.3:a:checkpoint:provider-1:4.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.05%2f32`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.05%2f33`,
        fs:  `cpe:2.3:a:hp:marketresearch:140.0.212.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.06%2f02`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.7.4:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.06%2f07`,
        fs:  `cpe:2.3:a:claws-mail:claws-mail:1.9.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f02`,
        fs:  `cpe:2.3:a:fiyo:fiyo_cms:2.0.1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f03`,
        fs:  `cpe:2.3:a:sympa:sympa:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f09`,
        fs:  `cpe:2.3:a:red-gate:sql_backup:5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f14`,
        fs:  `cpe:2.3:o:siemens:simatic_s7_cpu_1200_firmware:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f18`,
        fs:  `cpe:2.3:a:cerberusftp:ftp_server:4.0.9.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f20`,
        fs:  `cpe:2.3:o:microsoft:windows_95:-:sr2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f22`,
        fs:  `cpe:2.3:a:microsoft:office:xp:sp3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f25`,
        fs:  `cpe:2.3:a:hp:update:4.0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f26`,
        fs:  `cpe:2.3:a:novell:opensuse_build_service:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f27`,
        fs:  `cpe:2.3:a:jpchacha:chasys_draw_ies:4.20.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f28`,
        fs:  `cpe:2.3:a:adobe:adobe_update_manager_language_resource:1.0.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f29`,
        fs:  `cpe:2.3:a:debian:apt:0.8.15.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f30`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.10.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f32`,
        fs:  `cpe:2.3:a:thomas_seidl:search_api:7.x-1.0:beta3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:4.07%2f35`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.41:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:5.03`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.2:p3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:5.05`,
        fs:  `cpe:2.3:a:ibm:tivoli_access_manager_for_e-business:3.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:5.06`,
        fs:  `cpe:2.3:a:pass4sure:pass4sure_for_comptia_sy0-201:3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:5.10`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:5.11`,
        fs:  `cpe:2.3:o:dell:bios:a10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:5.12`,
        fs:  `cpe:2.3:a:digium:asterisk:1.2.12.1:netsec:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:5.13`,
        fs:  `cpe:2.3:h:cisco:call_manager:4.3\(1\)sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeus.physik.uni-bonn:mn_fit:5.14`,
        fs:  `cpe:2.3:a:mozilla:netscape_portable_runtime:4.10.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zeuscart:zeuscart:4.0`,
        fs:  `cpe:2.3:a:apple:keynote:5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zfcuser_project:zfcuser:1.2.1`,
        fs:  `cpe:2.3:a:sun:java_system_web_proxy_server:3.6:sp10:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zhang_zhijun_taiwan_visit_2014-06-25_project:zhang_zhijun_taiwan_visit_2014-06-25:1.0::~~~android~~`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2014.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zhone_technologies:gpon_2520:-`,
        fs:  `cpe:2.3:a:zend:zend_framework:1.9.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zhone_technologies:gpon_2520_firmware:r4.0.2.566b`,
        fs:  `cpe:2.3:a:adobe:premiere_pro_cs3:3.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zhtiantian:kuailecaidengmi:1.7.12.15::~~~android~~`,
        fs:  `cpe:2.3:a:ca:brightstor_arcserve_backup_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zhwnl:ecalendar2:4.5.3::~~~android~~`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.0`,
        fs:  `cpe:2.3:a:ibm:rational_clearcase:7.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.1`,
        fs:  `cpe:2.3:a:mathjs:math.js:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.2`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.3`,
        fs:  `cpe:2.3:a:squid-cache:squid:3.0.stable12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.4`,
        fs:  `cpe:2.3:a:cloudbees:jenkins:1.367:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.5`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p291:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.6`,
        fs:  `cpe:2.3:a:hrblock:taxcut_basic\&#43;efile_2008:8.03:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.7`,
        fs:  `cpe:2.3:a:pivotx:pivotx:2.3.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.8`,
        fs:  `cpe:2.3:a:otrs:otrs:2.2.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.9`,
        fs:  `cpe:2.3:o:juniper:junose_m:6.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.10`,
        fs:  `cpe:2.3:a:haproxy:haproxy:1.4.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.3.10:rc1`,
        fs:  `cpe:2.3:a:apple:safari:8.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.0`,
        fs:  `cpe:2.3:a:softsphere:defensewall_personal_firewall:3.24:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.0:rc1`,
        fs:  `cpe:2.3:a:jasig:phpcas:0.4.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.0:rc2`,
        fs:  `cpe:2.3:a:stanislas_rolland:static_info_tables:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.0:rc3`,
        fs:  `cpe:2.3:a:google:chrome:35.0.1916.103:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.0:rc4`,
        fs:  `cpe:2.3:a:i-doit:i-doit:1.2.3:*:*:*:pro:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.1`,
        fs:  `cpe:2.3:a:oracle:mojarra:1.2_15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.2`,
        fs:  `cpe:2.3:a:moodle:moodle:1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.3`,
        fs:  `cpe:2.3:a:oracle:retail_point-of-service:15.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.3:rc1`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.8:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.3:rc2`,
        fs:  `cpe:2.3:a:nikhilk:web_development_helper:0.8.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zikula:zikula_application_framework:1.4.3:rc3`,
        fs:  `cpe:2.3:a:f5:big-ip_wan_optimization_manager:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zillionmuslims:zillion_muslims:1.1::~~~android~~`,
        fs:  `cpe:2.3:a:adobe:illustrator:7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.0.0`,
        fs:  `cpe:2.3:a:piwik:piwik:0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.0.1`,
        fs:  `cpe:2.3:a:kolja_schleich:leaguemanager:3.6.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.1.0`,
        fs:  `cpe:2.3:a:herac:tuxguitar:0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.1.1`,
        fs:  `cpe:2.3:a:atlassian:crowd:2.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.1.2`,
        fs:  `cpe:2.3:h:huawei:s9712:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.1.3`,
        fs:  `cpe:2.3:h:iodata:ts-ptcam\/poe_camera:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.1.4`,
        fs:  `cpe:2.3:a:thinkshout:mailchimp:7.x-2.0:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.2.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.2eu:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.2.1`,
        fs:  `cpe:2.3:a:ati:catalyst_control_center_help:2009.211.2224.40219:*:*:fr:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.2.2`,
        fs:  `cpe:2.3:a:intel:network_connections:15.6.25.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.2.3`,
        fs:  `cpe:2.3:o:hp:procurve_switch_software:pb.02.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.2.4`,
        fs:  `cpe:2.3:a:google_authenticator_login_project:ga_login:6.x-1.x:dev:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.2.5`,
        fs:  `cpe:2.3:a:emc:networker:7.6.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:7.2.6`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.8:p1_beta2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:8.0.0`,
        fs:  `cpe:2.3:a:intel:network_connections:15.0.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:8.0.1`,
        fs:  `cpe:2.3:a:pizzashack:rssh:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:8.0.2`,
        fs:  `cpe:2.3:a:google:chrome:14.0.835.113:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:8.0.3`,
        fs:  `cpe:2.3:a:redhat:rhel_application_server:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:8.0.4`,
        fs:  `cpe:2.3:a:gitlab:gitlab:8.9.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:collaboration_server:8.0.5`,
        fs:  `cpe:2.3:a:primetek:primefaces:5.3.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0`,
        fs:  `cpe:2.3:a:ibm:tivoli_storage_flashcopy_manager_for_vmware:3.1:*:*:*:*:vmware:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.1`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.9.900.117:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.2`,
        fs:  `cpe:2.3:a:appa-apps:top_roller_coasters_europe_1:\@7f050001:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.3`,
        fs:  `cpe:2.3:a:martin_nagy:bind-dyndb-ldap:1.0.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.4`,
        fs:  `cpe:2.3:a:saltstack:salt:0.6.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.5`,
        fs:  `cpe:2.3:a:microsoft:visual_studio:2005:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.6`,
        fs:  `cpe:2.3:a:webglimpse:webglimpse:2.16.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.7`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.16:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.8`,
        fs:  `cpe:2.3:a:octopus:octopus_deploy:3.10.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.9`,
        fs:  `cpe:2.3:o:d-link:dsr-500n_firmware:1.06b43:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.10`,
        fs:  `cpe:2.3:h:hp:advancestack_10base-t_switching_hub_j3210a:a.03.07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.12`,
        fs:  `cpe:2.3:o:cisco:aironet_access_point_software:8.2\(121.12\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.13`,
        fs:  `cpe:2.3:a:alps:touch_pad_driver:6.0.303.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.14`,
        fs:  `cpe:2.3:o:arubanetworks:arubaos:6.2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.15`,
        fs:  `cpe:2.3:a:adobe:flash_player:11.6.602.171:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zimbra:zimbra_collaboration_suite:6.0.16`,
        fs:  `cpe:2.3:a:apache:axis2:1.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.0.0`,
        fs:  `cpe:2.3:a:live555:streaming_media:2014.01.14:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.0.1`,
        fs:  `cpe:2.3:a:libpng:libpng:1.4.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.0.2`,
        fs:  `cpe:2.3:a:dameware:mini_remote_control:7.5.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.0.3`,
        fs:  `cpe:2.3:a:ponsoftware:explzh:4.76:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.0.4`,
        fs:  `cpe:2.3:a:texmacs:texmacs:1.0.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.1.0`,
        fs:  `cpe:2.3:o:silex:sx-2000wg_firmware:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.1.1`,
        fs:  `cpe:2.3:a:symantec:web_gateway:5.0.3.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.0`,
        fs:  `cpe:2.3:a:plone:plone:4.2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.1`,
        fs:  `cpe:2.3:h:hp:ce989a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.2`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(3\)n1\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.3`,
        fs:  `cpe:2.3:a:don_ho:notepad\&#43;\&#43;:4.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.4`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(33\)sxi6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.5`,
        fs:  `cpe:2.3:a:openvas:openvas_manager:1.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.6`,
        fs:  `cpe:2.3:a:cotonti:cotonti_siena:0.9.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.7`,
        fs:  `cpe:2.3:a:google:v8:3.24.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.8`,
        fs:  `cpe:2.3:a:digium:asterisk:10.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.2.9`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.12.17:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.0`,
        fs:  `cpe:2.3:a:webmin:usermin:1.560:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.0.1`,
        fs:  `cpe:2.3:a:google:chrome:6.0.472.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.1`,
        fs:  `cpe:2.3:o:d-link:dcs-934l_firmware:1.04.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.2`,
        fs:  `cpe:2.3:h:intel:d845hv_motherboard:p08-0031:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.3`,
        fs:  `cpe:2.3:a:redhat:interchange:4.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.4`,
        fs:  `cpe:2.3:a:oracle:database_server:8.1.7.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.5`,
        fs:  `cpe:2.3:a:webwiz:web_wiz_newspad:1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.6`,
        fs:  `cpe:2.3:a:oracle:oracle_and_sun_systems_product_suite:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.3.7`,
        fs:  `cpe:2.3:a:symantec:messaging_gateway:9.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.0`,
        fs:  `cpe:2.3:a:boonex:dolphin:7.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.1`,
        fs:  `cpe:2.3:a:elfutils_project:elfutils:0.158:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.2`,
        fs:  `cpe:2.3:a:cmsmadesimple:cms_made_simple:2.3:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.3`,
        fs:  `cpe:2.3:a:dovecot:dovecot:2.2:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.5`,
        fs:  `cpe:2.3:a:php:php:5.5.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.6`,
        fs:  `cpe:2.3:a:hexagon:erdas_apollo_ecwp:13.00.0000:-:*:*:*:chrome:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.7`,
        fs:  `cpe:2.3:a:mozilla:firefox:3.5.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.4.8`,
        fs:  `cpe:2.3:a:altiris:monitor_solution_documentation:6.0.1074:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.0`,
        fs:  `cpe:2.3:a:horde:imp:5.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.1`,
        fs:  `cpe:2.3:a:novell:zenworks:7:sp1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.2`,
        fs:  `cpe:2.3:a:ipswitch:imail:7.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.3`,
        fs:  `cpe:2.3:o:redhat:enterprise_linux:5:unknown:server:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.4`,
        fs:  `cpe:2.3:a:debian:dpkg:1.18.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.5`,
        fs:  `cpe:2.3:o:iij:seil_x1_firmware:4.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.6`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.7`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.8.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.8`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.132:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.5.9`,
        fs:  `cpe:2.3:o:huawei:s9300_firmware:v200r005c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.6.0`,
        fs:  `cpe:2.3:a:bart_feenstra:payment:-:7.x-1.0:alpha6:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.6.1`,
        fs:  `cpe:2.3:a:ca:etrust_integrated_threat_management:8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.6.2`,
        fs:  `cpe:2.3:a:dest-unreach:socat:2.0.0:b3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.6.3`,
        fs:  `cpe:2.3:a:tweet-blender:tweet-blender:3.1.1:-:-:*:-:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.8.1`,
        fs:  `cpe:2.3:a:splunk:splunk:5.0.12:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.8.2`,
        fs:  `cpe:2.3:a:fedoraproject:389_directory_server:1.2.11.23:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:1.8.3`,
        fs:  `cpe:2.3:a:rocomotion:p_board:1.12:*:g:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.0.0`,
        fs:  `cpe:2.3:a:littlecms:little_cms_color_engine:1.19:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.0.1`,
        fs:  `cpe:2.3:a:debian:xbuffy:3.3.bl.3-1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.0.2`,
        fs:  `cpe:2.3:a:silverstripe:silverstripe:2.3.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.0.3`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_developer:6:-:standard:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.0.4`,
        fs:  `cpe:2.3:a:gnome:gnome_display_manager:3.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.0.5`,
        fs:  `cpe:2.3:a:eclipse:eclipse_ide:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.1.0`,
        fs:  `cpe:2.3:a:rack_project:rack:1.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.1.1`,
        fs:  `cpe:2.3:a:slickremix:design_approval_system_plugin:3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.1.2`,
        fs:  `cpe:2.3:a:ibm:tivoli_directory_server:6.3.0.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.1.3`,
        fs:  `cpe:2.3:a:tejimaya:openpne:3.4.21:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.2.0`,
        fs:  `cpe:2.3:a:gnu:mailman:2.1.1:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.2.1`,
        fs:  `cpe:2.3:a:joomla:joomla\!:3.6.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.2.2`,
        fs:  `cpe:2.3:a:mediawiki:mediawiki:1.15.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.2.3`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.9.9-0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.2.4`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.209:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(20\)e3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.1`,
        fs:  `cpe:2.3:a:elgg:elgg:1.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.2`,
        fs:  `cpe:2.3:o:iij:seil_x2_firmware:3.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.3`,
        fs:  `cpe:2.3:a:mailenable:mailenable:4.25:-:std:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.4`,
        fs:  `cpe:2.3:a:google:chrome:20.0.1132.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.5`,
        fs:  `cpe:2.3:a:nuance:paperport:9.2.827:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.6`,
        fs:  `cpe:2.3:a:cisco:unity_connection:1.1\(1\)_sr1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.7`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.3.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.3.8`,
        fs:  `cpe:2.3:a:adjam:rekonq:0.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.0`,
        fs:  `cpe:2.3:h:hp:cz249a:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.1`,
        fs:  `cpe:2.3:o:cisco:ios_xe:3.8.0s:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.2`,
        fs:  `cpe:2.3:o:cisco:ios:12.1\(5\)t:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.3`,
        fs:  `cpe:2.3:a:vmware:movie_decoder:7.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.4`,
        fs:  `cpe:2.3:a:apple:webobjects:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.5`,
        fs:  `cpe:2.3:a:palemoon:pale_moon:15.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.6`,
        fs:  `cpe:2.3:a:ajaydsouza:contextual_related_posts:1.8.10:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.7`,
        fs:  `cpe:2.3:a:octobercms:october_cms:1.0.292:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.8`,
        fs:  `cpe:2.3:a:digitalvolcano:duplicate_cleaner:2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.4.9`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.8-6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.0`,
        fs:  `cpe:2.3:a:python_bugzilla_project:python-bugzilla:0.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.1`,
        fs:  `cpe:2.3:h:irislink:iriscan_pro_office_3:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.2`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.218:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.3`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0.13:pre8:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.4`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.7.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.5`,
        fs:  `cpe:2.3:a:solarwinds:ipmonitor:10.0.1368.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.6`,
        fs:  `cpe:2.3:h:cisco:catalyst_6608:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.7`,
        fs:  `cpe:2.3:a:lotro:lord_of_the_rings_online:1.0.0:*:*:*:free_trial:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.8`,
        fs:  `cpe:2.3:a:easyxdm:easyxdm:2.4.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.5.9`,
        fs:  `cpe:2.3:h:f5:big-ip_3400:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zingiri:zingiri_web_shop:2.6.0`,
        fs:  `cpe:2.3:a:sawmill:sawmill:7.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zip_attachments_project:zip_attachments:1.5::~~~wordpress~~`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.8:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zipcar:zipcar:3.4.2::~~~android~~`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:5.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zippyyum:subway_ordering_for_california:3.4:-:~-~-~iphone_os~~`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:1.7.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zippyyum:subway_ordering_for_california:3.7.1:-:~-~-~iphone_os~~`,
        fs:  `cpe:2.3:a:clubpersonal:club_personal:2.6:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.0`,
        fs:  `cpe:2.3:a:veritas:netbackup:4.5.0:mp1:netware_media_servers:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.346:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.2`,
        fs:  `cpe:2.3:o:yahama:rt105e:6.03.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.3`,
        fs:  `cpe:2.3:h:cisco:sf500-24p:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.4`,
        fs:  `cpe:2.3:a:symantec:veritas_backup_exec_remote_agent_for_windows_systems:12.0.1364:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.5`,
        fs:  `cpe:2.3:a:gnu:gdb:6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.6`,
        fs:  `cpe:2.3:a:apache:tomcat:6.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.7`,
        fs:  `cpe:2.3:a:fte:fte_text_editor:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.7.1`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.8`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.3.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.9`,
        fs:  `cpe:2.3:a:softwaretoolbox:top_server:5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.10`,
        fs:  `cpe:2.3:a:emc:rsa_bsafe:4.0.2:*:*:*:micro_edition_suite:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.11`,
        fs:  `cpe:2.3:a:atlassian:crucible:2.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.12`,
        fs:  `cpe:2.3:a:hitachi:cosminexus_application_server:06-51-\/e:-:enterprise:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zkoss:zk_framework:5.0.13`,
        fs:  `cpe:2.3:a:phpmyadmin:phpmyadmin:3.3.9.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zlib:pigz:2.3.1`,
        fs:  `cpe:2.3:a:ephiphanyheathdata:cardio_server:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc:1.0`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:2.5.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc:1.2`,
        fs:  `cpe:2.3:a:cyberlink:powerdvd:2.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.076:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:microsoft:ie:3.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.077:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:symantec:endpoint_protection_manager:12.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.078:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:systemtap:systemtap:0.5.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.079:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:microsoft:winsock:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.080:-:~-~-~windows~~`,
        fs:  `cpe:2.3:h:supermicro:x9qri-f:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.089:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:sixapart:movable_type:4.15:beta1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.090:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:nlnetlabs:nsd:3.0.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.093:-:~-~-~windows~~`,
        fs:  `cpe:2.3:h:hp:0235a38q:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.094:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:apple:java_1.5:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.095:-:~-~-~windows~~`,
        fs:  `cpe:2.3:o:d-link:dap-2660_firmware:1.11:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.097:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:phorum:phorum:5.0.13:a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.098:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:gecad:axigen_mail_server:1.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.202:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:koha:koha:3.16.08:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:znc:znc-msvc:0.206:-:~-~-~windows~~`,
        fs:  `cpe:2.3:a:tigris:tortoisesvn:0.5.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zodiacdm:aboutme-plugin:0.9`,
        fs:  `cpe:2.3:a:freeipa:freeipa:4.5.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zodiacdm:aboutme-plugin:1.0`,
        fs:  `cpe:2.3:h:hp:jh075a\):-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zodiacdm:aboutme-plugin:1.1`,
        fs:  `cpe:2.3:a:gnu:enscript:1.6.4:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zodiacdm:aboutme-plugin:1.1.1`,
        fs:  `cpe:2.3:a:bea:weblogic_server:9.2:mp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_admanager_plus:6.2`,
        fs:  `cpe:2.3:a:plugin-organizer_project:plugin-organizer:3.0.8:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4001`,
        fs:  `cpe:2.3:a:hardened-php:suhosin:0.9.6.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4002`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.58:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4004`,
        fs:  `cpe:2.3:a:digium:asterisk:1.6.0.21:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4005`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.3:*:*:*:express:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4008`,
        fs:  `cpe:2.3:a:fca:uconnect:15.26.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4009`,
        fs:  `cpe:2.3:a:aokitaka:zip_with_pass_pro:6.3.7:-:-:*:-:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4010`,
        fs:  `cpe:2.3:a:sun:javamail:1.3.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4011`,
        fs:  `cpe:2.3:a:justsystems:ichitaro_portable_with_oreplug:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4012`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.48:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4013`,
        fs:  `cpe:2.3:a:igor_sysoev:nginx:0.7.57:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4014`,
        fs:  `cpe:2.3:a:strongswan:strongswan:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4015`,
        fs:  `cpe:2.3:a:google:chrome:19.0.1032.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4016`,
        fs:  `cpe:2.3:a:atlassian:crucible:1.5.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:4.0:4017`,
        fs:  `cpe:2.3:o:yamaha:rt56v:4.07.45:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5000`,
        fs:  `cpe:2.3:a:adobe:adobe_air:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5001`,
        fs:  `cpe:2.3:a:clamav:clamav:0.95.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5002`,
        fs:  `cpe:2.3:a:zeus.physik.uni-bonn:mn_fit:4.06\/07:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5003`,
        fs:  `cpe:2.3:a:hp:insight_management_agents:7.51.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5004`,
        fs:  `cpe:2.3:a:dovestones:true_last_logon:2.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5005`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5100`,
        fs:  `cpe:2.3:a:mozilla:thunderbird:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5101`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5102`,
        fs:  `cpe:2.3:a:dhcpcd_project:dhcpcd:4.0.0:rc3:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5103`,
        fs:  `cpe:2.3:o:ibm:vios:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5500`,
        fs:  `cpe:2.3:a:xchat:xchat:1.8.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5501`,
        fs:  `cpe:2.3:a:oracle:glassfish_server:2.1.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5502`,
        fs:  `cpe:2.3:a:gnu:gdb:7.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5503`,
        fs:  `cpe:2.3:a:proftpd:proftpd:1.3.3:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5504`,
        fs:  `cpe:2.3:a:adobe:flash_player:20.0.0.306:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5600`,
        fs:  `cpe:2.3:o:freebsd:freebsd:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5601`,
        fs:  `cpe:2.3:o:cisco:ios:12.2\(2\)xj1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5602`,
        fs:  `cpe:2.3:a:nullsoft:winamp:2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5603`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1:update1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5604`,
        fs:  `cpe:2.3:a:horde:kronolith_h4:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5605`,
        fs:  `cpe:2.3:a:webmin:usermin:1.270:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5606`,
        fs:  `cpe:2.3:a:intermesh:group-office:3.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5607`,
        fs:  `cpe:2.3:h:hp:procurve_switch:jg254a:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5608`,
        fs:  `cpe:2.3:h:cisco:scientific_atlanta_dpx110:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5609`,
        fs:  `cpe:2.3:a:ntp:ntp:4.2.7:p216:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5610`,
        fs:  `cpe:2.3:a:all_video_gallery_plugin_project:all_video_gallery_plugin:1.0.0:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5611`,
        fs:  `cpe:2.3:a:buffalotech:bhr-4rv_firmware:2.49:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5612`,
        fs:  `cpe:2.3:o:netbsd:netbsd:1.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5613`,
        fs:  `cpe:2.3:a:ibm:lotus_notes:5.0.1.02:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:5.6:5614`,
        fs:  `cpe:2.3:a:facebook:pakan_ken_tube:0.1:*:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_assetexplorer:6.1`,
        fs:  `cpe:2.3:a:gentoo:webmin:1.220:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_desktop_central:9.0`,
        fs:  `cpe:2.3:a:ibm:lotus_domino:8.5.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_desktop_central:9.0::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:ibm:bigfix_platform:9.0.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_eventlog_analyzer:7.0`,
        fs:  `cpe:2.3:a:ibm:infosphere_master_data_management_server:9.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_eventlog_analyzer:9.0:9000`,
        fs:  `cpe:2.3:a:symantec:intruder_alert:3.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_eventlog_analyzer:9.0:9002`,
        fs:  `cpe:2.3:a:sixapart:movable_type:5.1:*:advanced:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_it360:10.3.3`,
        fs:  `cpe:2.3:a:ibm:emptoris_strategic_supply_management:10.1.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_it360:10.3.3::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:gnu:gnutls:3.2.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_opmanager:11.4`,
        fs:  `cpe:2.3:a:dan_kogai:encode_module:2.01:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_opmanager:11.5`,
        fs:  `cpe:2.3:a:sun:jre:1.3.1_12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_opstor:8.3`,
        fs:  `cpe:2.3:a:apache:cxf:3.1.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_opstor:8.5`,
        fs:  `cpe:2.3:a:marketo_ma_project:marketo_ma:7.x-1.3:*:*:*:*:drupal:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:5.0::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:o:google:android:4.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:5.1::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:moinejf:abcm2ps:5.4.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:5.2::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:microsoft:.net_framework:1.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:5.3::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:geeklog:geeklog:1.5.2:*:ja:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:5.4::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.8.18:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.0::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:schneider-electric:scada_expert_clearscada:2013:r1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.1::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:phpnuke:phpnuke:7.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.2`,
        fs:  `cpe:2.3:a:google:chrome:9.0.588.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.2::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.1\(3\)n2\(1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.3`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.78:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.3::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:devincentiis:gazie:2.0.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.4`,
        fs:  `cpe:2.3:o:hp:tru64:5.1b1_pk3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.4::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:ibm:db2:9.1.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.5`,
        fs:  `cpe:2.3:a:adobe:shockwave_player:11.5.8.612:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.5::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:digium:asterisk:1.8.24.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.9`,
        fs:  `cpe:2.3:a:memcached:memcached:1.4.12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:6.9::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:magnolia-cms:magnolia_form_module:2.0.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:7.0`,
        fs:  `cpe:2.3:o:altaware:palo_alto_networks_panos:5.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:7.0::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:o:yahama:rt58i:9.01.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:7.1`,
        fs:  `cpe:2.3:a:acronis:backup_\&amp;_recovery_bootable_media_builder:10.0.11639:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_password_manager_pro:7.1::~~managed_service_providers~~~`,
        fs:  `cpe:2.3:a:moodle:moodle:3.1.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_social_it_plus:11.0`,
        fs:  `cpe:2.3:a:hp:marketresearch:140.0.214.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_supportcenter_plus:7.9`,
        fs:  `cpe:2.3:a:search.cpan:libwww-perl:5.833:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:manageengine_supportcenter_plus:7.90`,
        fs:  `cpe:2.3:h:cisco:catalyst_8510msr:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zohocorp:servicedesk_plus:9.0`,
        fs:  `cpe:2.3:a:diversesolutions:dsidxpress_idx_plugin:2.1.5:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zombie_detector_project:zombie_detector:1.2::~~~android~~`,
        fs:  `cpe:2.3:o:yahama:rt103i:4.00.38:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:imsecure:-`,
        fs:  `cpe:2.3:a:news_pack_project:news_pack:0.1.0:*:*:*:*:typo3:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:imsecure:1.0.0.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.6.15.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:imsecure:1.0.1.0`,
        fs:  `cpe:2.3:a:sun:sdk:1.3.1_06:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:imsecure:1.0.2.0`,
        fs:  `cpe:2.3:a:cisco:unity_connection:7.1\(3a\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:integrity:-`,
        fs:  `cpe:2.3:a:matthew_booth:virt-v2v:0.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:integrity:4.0`,
        fs:  `cpe:2.3:a:ssh:secure_shell_for_servers:3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:-`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.85:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:1.0`,
        fs:  `cpe:2.3:a:adobe:bridge:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:2.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.625:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:2.2`,
        fs:  `cpe:2.3:a:services_twitter_group:services_twitter:0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:2.3`,
        fs:  `cpe:2.3:a:namazu:namazu:2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:2.4`,
        fs:  `cpe:2.3:a:netty_project:netty:4.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:2.5`,
        fs:  `cpe:2.3:a:otrs:faq:5.0.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:2.6`,
        fs:  `cpe:2.3:a:matt_johnston:dropbear_ssh_server:0.50:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:3.0`,
        fs:  `cpe:2.3:a:checkpoint:vpn-1:4.1:sp5a:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:4.0`,
        fs:  `cpe:2.3:a:mysql:mysql:5.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:5.5`,
        fs:  `cpe:2.3:a:xmlsoft:libxslt:1.0.13:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:5.5.062.011`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.5.5-10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm:6.0`,
        fs:  `cpe:2.3:a:reportico:php_report_designer:4.1:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_anti-spyware:-`,
        fs:  `cpe:2.3:a:oracle:data_provider_.net:10.1.0.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_anti-spyware:6.0`,
        fs:  `cpe:2.3:a:ibm:db2:9.7.0.11:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_anti-spyware:6.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.8.3-4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_antivirus:-`,
        fs:  `cpe:2.3:a:novell:web_server_examples_toolkit:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_antivirus:6.0`,
        fs:  `cpe:2.3:a:git-scm:git:1.7.10:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_internet_security_suite:-`,
        fs:  `cpe:2.3:a:adobe:flash_player:10.3.183.29:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_security_suite:-`,
        fs:  `cpe:2.3:o:linux:linux_kernel:3.18.35:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_security_suite:6.0`,
        fs:  `cpe:2.3:a:wpshopstyling:wp-ecommerce-shop-styling:2.2:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_security_suite:6.1.737.000`,
        fs:  `cpe:2.3:a:mybb:mybb:1.6.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_security_suite:6.1.744.000`,
        fs:  `cpe:2.3:a:synology:video_station:1.2-0439:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_security_suite:6.5.722.000`,
        fs:  `cpe:2.3:a:linuxcontainers:lxc:0.6.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_wireless_security:-`,
        fs:  `cpe:2.3:a:libtiff:libtiff:3.5.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zonelabs:zonealarm_wireless_security:5.5.080.000`,
        fs:  `cpe:2.3:h:hp:h3c_router:msr_20-12:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zoneminder:zoneminder:1.29.0`,
        fs:  `cpe:2.3:h:linksys:wag200g:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zoneo-soft:phptraffica:2.2.1`,
        fs:  `cpe:2.3:a:netsweeper:netsweeper:2.6.29.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zoneo-soft:phptraffica:2.3`,
        fs:  `cpe:2.3:a:hp:openview_configuration:1.10.30:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zoner:zoner_antivirus_free:-:-:~~~android~~`,
        fs:  `cpe:2.3:a:gnome:evolution:1.2.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zoner:zoner_antivirus_free:1.7.0:-:~~~android~~`,
        fs:  `cpe:2.3:a:projectsend:projectsend:110:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zoodles:kid_mode%3a_free_games_%2b_lock:4.9.8::~~~android~~`,
        fs:  `cpe:2.3:a:sun:jdk:1.6.0:update_13:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zooeffect:zooeffect:1.0`,
        fs:  `cpe:2.3:a:microsoft:windows_media_player:9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zooeffect:zooeffect:1.01`,
        fs:  `cpe:2.3:a:xmlsoft:libxml2:1.8.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zooeffect:zooeffect:1.02`,
        fs:  `cpe:2.3:a:ibm:java:5.0.11.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zooeffect:zooeffect:1.03`,
        fs:  `cpe:2.3:h:cisco:arrowpoint:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zooeffect:zooeffect:1.04`,
        fs:  `cpe:2.3:a:livetecs:timeline:2.91:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zoom:zoom_cloud_meetings:%407f060008::~~~android~~`,
        fs:  `cpe:2.3:a:janrain:rpx:7.x-2.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.5.1`,
        fs:  `cpe:2.3:a:d-bus_project:d-bus:1.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.6.1`,
        fs:  `cpe:2.3:a:postfix:postfix:2.2.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.6.4`,
        fs:  `cpe:2.3:a:transmissionbt:transmission:2.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.7.0`,
        fs:  `cpe:2.3:a:tiki:tikiwiki_cms\/groupware:4.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.7.3`,
        fs:  `cpe:2.3:a:quest:activeroles_management_shell_for_active_directory:1.4.0.2139:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.7.4`,
        fs:  `cpe:2.3:a:emorym:android_pusher:-:-:*:*:*:android:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.7.5`,
        fs:  `cpe:2.3:a:openvpn:openvpn:1.2.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.7.6`,
        fs:  `cpe:2.3:h:hp:0235a0e6:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.7.7`,
        fs:  `cpe:2.3:a:wpgetready:nextcellent_gallery:1.9.15:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.7.8`,
        fs:  `cpe:2.3:a:cisco:firewall_services_module_software:4.1\(15\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.8.1`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.7-3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.8.4`,
        fs:  `cpe:2.3:a:red-gate:sql_data_generator:1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.8.6`,
        fs:  `cpe:2.3:a:isc:dhcp:4.2.2:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.8.8`,
        fs:  `cpe:2.3:a:kanboard:kanboard:1.0.36:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.9.2`,
        fs:  `cpe:2.3:h:huawei:nip5100:v100r001c00:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.9.3`,
        fs:  `cpe:2.3:a:google:chrome:4.1.249.1030:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.9.4`,
        fs:  `cpe:2.3:a:fetchmail:fetchmail:5.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.9.5`,
        fs:  `cpe:2.3:a:call-cc:chicken:4.12.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.9.6`,
        fs:  `cpe:2.3:a:deliciousdays:cforms:11.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.9.7`,
        fs:  `cpe:2.3:a:google:chrome:34.0.1847.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.10.3`,
        fs:  `cpe:2.3:a:bib2html_project:bib2html:0.9.3:*:*:*:*:wordpress:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.10.8`,
        fs:  `cpe:2.3:a:nodejs:node.js:8.8.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.11.0`,
        fs:  `cpe:2.3:a:videolan:vlc_media_player:0.2.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.11.1`,
        fs:  `cpe:2.3:o:yahama:rtx1100:8.03.60:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.11.2`,
        fs:  `cpe:2.3:a:gitlab:gitlab:9.0.3:*:*:*:enterprise:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:2.11.3`,
        fs:  `cpe:2.3:a:adobe:help_viewer:2.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zope:3.4.0`,
        fs:  `cpe:2.3:o:cisco:ios:12.0\(5.4\)wc1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zserver:1.1`,
        fs:  `cpe:2.3:a:phpmyfaq:phpmyfaq:1.3.10:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zserver:1.1b1`,
        fs:  `cpe:2.3:a:ibm:rational_policy_tester:8.0.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zope:zserver:11.1`,
        fs:  `cpe:2.3:a:firedaemon:firedaemon_pro:3.0.2437:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zotpress_project:zotpress:6.1.2::~~~wordpress~~`,
        fs:  `cpe:2.3:a:tejimaya:openpne:2.6.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zpanelcp:zpanel:10.0.1`,
        fs:  `cpe:2.3:a:cisco:meeting_server:2.0.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zroadster:zroadster.com:2.4.13.17::~~~android~~`,
        fs:  `cpe:2.3:o:microsoft:windows_8.1:-:-:-:*:-:-:x86:*`,
    },
     
    {
        uri: `cpe:/h:zte:f460:-`,
        fs:  `cpe:2.3:o:yahama:rt300i:6.02.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zte:f660:-`,
        fs:  `cpe:2.3:h:htc:thunderbolt_4g:frg83d:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zte:zxdsl_831:-`,
        fs:  `cpe:2.3:a:caucho:resin:4.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zte:zxdsl_831cii:-`,
        fs:  `cpe:2.3:a:imagemagick:imagemagick:6.4.5-9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zte:zxhn_h108l:-`,
        fs:  `cpe:2.3:a:cisco:anyconnect_secure_mobility_client:2.2.133:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zte:zxhn_h108l_firmware:4.0.0d_zrq_gr4`,
        fs:  `cpe:2.3:a:oracle:fusion_middleware:12.1.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zte:zxhn_h108n_r1a:-`,
        fs:  `cpe:2.3:a:mysql:mysql:4.0.25:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zte:zxhn_h108n_r1a_firmware:zte.bhs.zxhnh108nr1a.h_pe`,
        fs:  `cpe:2.3:a:google:chrome:2.0.172.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zte:zxv10_w300:-`,
        fs:  `cpe:2.3:a:oracle:mysql:5.5.33:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zte:zxv10_w300_firmware:1.0.0a_zrd_lk`,
        fs:  `cpe:2.3:a:ssh:tectia_manager:1.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zte:zxv10_w300_firmware:w300v1.0.0f_er1_pe`,
        fs:  `cpe:2.3:a:solarwinds:orion_core_services:111.1.3.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:ztree_project:ztree:3.5.19.1`,
        fs:  `cpe:2.3:a:jenkins:jenkins:1.160:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.0`,
        fs:  `cpe:2.3:a:digium:certified_asterisk:1.8.28:cert2:*:*:lts:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.1`,
        fs:  `cpe:2.3:o:cisco:ios:12.3yf:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.2`,
        fs:  `cpe:2.3:a:cisco:application_and_content_networking_system_software:5.1.11.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.3`,
        fs:  `cpe:2.3:a:nodejs:nodejs:0.6.16:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.4`,
        fs:  `cpe:2.3:a:zohocorp:manageengine_assetexplorer:4.0:4002:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.6`,
        fs:  `cpe:2.3:o:cisco:ios:12.0xg:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.7`,
        fs:  `cpe:2.3:a:lsi:megaraid_storage_manager:2.29.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.8`,
        fs:  `cpe:2.3:a:modssl:mod_ssl:2.2.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.9`,
        fs:  `cpe:2.3:a:ibm:websphere_application_server:6.1.0.27:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.10`,
        fs:  `cpe:2.3:h:cisco:ids:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.11`,
        fs:  `cpe:2.3:o:juniper:netscreen_screenos:5.4.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.12`,
        fs:  `cpe:2.3:a:libguestfs:libguestfs:1.21.15:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.3.13`,
        fs:  `cpe:2.3:a:sun:one_directory_server:5.1:sp2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.4.0`,
        fs:  `cpe:2.3:o:linux:linux_kernel:2.5.53:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.4.1`,
        fs:  `cpe:2.3:a:opennms:opennms:1.12.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.4.2`,
        fs:  `cpe:2.3:a:bestpractical:rt:3.6.3:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.4.3`,
        fs:  `cpe:2.3:a:rubygems:rubygems:1.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.5.0`,
        fs:  `cpe:2.3:a:zope:zope:2.8.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zulip:zulip_server:1.5.1`,
        fs:  `cpe:2.3:a:openstack:image_registry_and_delivery_service_\(glance\):2013.2:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/a:zurmo:zurmo_crm:3.0.2`,
        fs:  `cpe:2.3:a:netgear:readynas_surveillance:1.2.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:n300_netusb_nbg-419n:-`,
        fs:  `cpe:2.3:a:libpng:libpng:1.6.10:beta:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zyxel:n300_netusb_nbg-419n_firmware:1.00%28bfq_6%29c0`,
        fs:  `cpe:2.3:a:robert_ancell:lightdm:0.9.7:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:nbg-418n:-`,
        fs:  `cpe:2.3:a:codehaus:redback:1.0:alpha4:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zyxel:nbg-418n_firmware:1.00%28aadz.3%29c0`,
        fs:  `cpe:2.3:a:oracle:micros_cwdirect:13.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660h-61:-`,
        fs:  `cpe:2.3:o:cisco:nx-os:4.2\(1\)sv1\(5.1\):*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660h-63:-`,
        fs:  `cpe:2.3:a:danny_morris:lazy_seo:1.2.8:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660h-67:-`,
        fs:  `cpe:2.3:a:cakephp:cakephp:2.4.0:rc2:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660h-d1:-`,
        fs:  `cpe:2.3:a:samba:samba:3.5.20:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660h-d3:-`,
        fs:  `cpe:2.3:a:persits:xupload:3.0.0.4:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660h-t1:-`,
        fs:  `cpe:2.3:a:papercut:papercut_mf:13.5:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660h-t1:v2`,
        fs:  `cpe:2.3:a:toshibatec:e-studio-255_firmware:t470sy0j302:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660h-t3:v2`,
        fs:  `cpe:2.3:a:redhat:resteasy:3.0:rc1:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw:_t1:-`,
        fs:  `cpe:2.3:a:ryan_davis:ruby_parser:2.0.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw:_t1:v2`,
        fs:  `cpe:2.3:a:frontrange:goldmine:5.70:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw:_t1:v3`,
        fs:  `cpe:2.3:a:pidgin:libpurple:2.3.1:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw-t1_2:-`,
        fs:  `cpe:2.3:a:samba:samba:3.0.23b:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw_d1:-`,
        fs:  `cpe:2.3:h:nvidia:geforce_910m:-:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw_d1:v2`,
        fs:  `cpe:2.3:a:clamav:clamav:0.87:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw_d3:-`,
        fs:  `cpe:2.3:a:ibm:rhapsody_design_manager:4.0.6:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw_t3:-`,
        fs:  `cpe:2.3:a:nuance:omnipage:15.1.0:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/h:zyxel:p-660hw_t3:v2`,
        fs:  `cpe:2.3:a:fruux:sabredav:1.7.9:*:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zyxel:pmg5318-b20a_firmware:v100aanc0b5`,
        fs:  `cpe:2.3:a:jan_kara:linux_diskquota:3.01:pre9:*:*:*:*:*:*`,
    },
     
    {
        uri: `cpe:/o:zyxel:zynos_firmware:3.40%28axh.0%29`,
        fs:  `cpe:2.3:a:dokuwiki:dokuwiki:release_2005-09-19:*:*:*:*:*:*:*`,
    },
    }

    for i, v := range vectors {
		wfn, err := naming.UnbindURI(v.uri)
        if err != nil{
            t.Errorf("test %d, Unexpected error: %s, URI: %s", i, err, v.uri)
        }
		wfn2, err := naming.UnbindFS(v.fs)
        if err != nil{
            t.Errorf("test %d, Unexpected error: %s, FS: %s", i, err, v.fs)
        }
    	matching.IsEqual(wfn, wfn2)
    	matching.IsEqual(wfn2, wfn)
    }
}
 